{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# <center> Hamiltoniano para semimetales de Weyl tipo I --Minimal Models </center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "El **objetivo general** de este notebook es explorar el Hamiltoniano presentado en el artículo [1] \n",
    "\n",
    "Los conceptos a introducir serán:\n",
    "* Hamiltoniano para un semimetal del Weyl \n",
    "* Relación de dispersión generada por este tipo de materiales\n",
    "\n",
    "A diferencia del hamiltoniano explorado anteriormente, este econtiene un parametro $\\gamma$, que permite estudiar la transición de fase de un semimetal de Weyl tipo I  a uno tipo II. Adicionalmente, este notebook se enfocara sólo en la fase correspondiente al semimemtal de Weyl tipo I ($\\gamma$ = 0).\n",
    "\n",
    "---\n",
    "<sup>Fuente:  T. M. McCormick, I. Kimchi, and N. Trivedi. Minimal Models for Topological Weyl Semimetals.Phys. Rev. B, 95(7):075133, Feb 2017</sup>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Multiprocesing \n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "import multiprocessing as mp\n",
    "import plotly.graph_objects as go"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Populating the interactive namespace from numpy and matplotlib\n"
     ]
    }
   ],
   "source": [
    "%pylab inline\n",
    "%matplotlib inline"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "def EigenV(k):\n",
    "    k_x,k_y,k_z=k\n",
    "    E=eigvalsh(HWeyl(k_x,k_y,k_z))\n",
    "    return E"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "res=pi/101 #resolucion\n",
    "\n",
    "k_xb,k_yb,k_zb=arange(-pi,pi,res),arange(-pi,pi,res),arange(-pi,pi,res)\n",
    "\n",
    "a  = 1\n",
    "k_0= pi/2\n",
    "   #Weyl positions\n",
    "tx = 1.0/2      \n",
    "t  = 1.0/2\n",
    "m  = 2*t\n",
    "γ  = 0\n",
    "def HWeyl(k_x,k_y,k_z):   \n",
    "    HW = array([[γ*(cos(k_x)-cos(k_0))-2*t*sin(k_z),   -(m*(2-cos(k_y)-cos(k_z))+2*tx*(cos(k_x)-cos(k_0)))+2J*t*sin(k_y)],\n",
    "                [ -(m*(2-cos(k_y)-cos(k_z))+2*tx*(cos(k_x)-cos(k_0)))-2J*t*sin(k_y), γ*(cos(k_x)-cos(k_0))+2*t*sin(k_z)]])\n",
    "    return HW\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "a_d= len(k_xb) #dimension del arreglo\n",
    "KX,KZ = meshgrid(k_xb,k_zb)\n",
    "KX    = KX.reshape((a_d*a_d,))\n",
    "KZ    = KZ.reshape((a_d*a_d,))\n",
    "\n",
    "k     = column_stack((KX,zeros_like(KX),KZ))\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "[[-1.          1.        ]\n",
      " [-1.00048372  1.00048372]\n",
      " [-1.0019344   1.0019344 ]\n",
      " ...\n",
      " [-1.00434856  1.00434856]\n",
      " [-1.00193347  1.00193347]\n",
      " [-1.00048348  1.00048348]]\n",
      "CPU times: user 1.63 s, sys: 8.25 ms, total: 1.64 s\n",
      "Wall time: 1.64 s\n"
     ]
    }
   ],
   "source": [
    "%%time \n",
    "\n",
    "Ek = map(EigenV,k) #función  y los valores que toma\n",
    "Ek = array(list(Ek))\n",
    "print(Ek)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "Enm = Ek.T[0].reshape((a_d,a_d)).T#primer T para +/- segundo para X->Z\n",
    "Enp = Ek.T[1].reshape((a_d,a_d)).T\n",
    "\n",
    "\n",
    "KX,KZ = meshgrid(k_xb,k_zb)\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "DATA = [ go.Surface( z=Enm, x=(KX),y=(KZ),opacity=0.9,  colorbar_x=0.75,colorscale='deep'),\n",
    "        go.Surface( z=Enp,x=KX,y=KZ,opacity=0.6, colorbar_x=0.9)]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        define('plotly', function(require, exports, module) {\n",
       "            /**\n",
       "* plotly.js v1.56.0\n",
       "* Copyright 2012-2020, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}((function(){return function t(e,r,n){function a(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(i)return i(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,(function(t){return a(e[o][1][t]||t)}),u,u.exports,t,e,r,n)}return r[o].exports}for(var i=\"function\"==typeof require&&require,o=0;o<n.length;o++)a(n[o]);return a}({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),a={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans', verdana, arial, sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var i in a){var o=i.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,a[i])}},{\"../src/lib\":749}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1334}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":899}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":912}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":922}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":613}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":931}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":950}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":964}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":971}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":977}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":992}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":1003}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":726}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":1011}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1335}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":1021}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":1030}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1336}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1043}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1053}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1065}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1071}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1075}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/image\")},{\"../src/traces/image\":1082}],26:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./image\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./treemap\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./image\":25,\"./indicator\":27,\"./isosurface\":28,\"./mesh3d\":29,\"./ohlc\":30,\"./parcats\":31,\"./parcoords\":32,\"./pie\":33,\"./pointcloud\":34,\"./sankey\":35,\"./scatter3d\":36,\"./scattercarpet\":37,\"./scattergeo\":38,\"./scattergl\":39,\"./scattermapbox\":40,\"./scatterpolar\":41,\"./scatterpolargl\":42,\"./scatterternary\":43,\"./sort\":44,\"./splom\":45,\"./streamtube\":46,\"./sunburst\":47,\"./surface\":48,\"./table\":49,\"./treemap\":50,\"./violin\":51,\"./volume\":52,\"./waterfall\":53}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1090}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1096}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1101}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1106}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1115}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1125}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1136}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1145}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1151}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1189}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1196}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1204}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1217}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1227}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1235}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1242}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1250}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1338}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1259}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1267}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1275}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1284}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1292}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/treemap\")},{\"../src/traces/treemap\":1301}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1313}],52:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1321}],53:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1329}],54:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=a(),f=i();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),a=t(\"orbit-camera-controller\"),i=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach((function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var a=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(a))})),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],a=Math.max(r.lastT(),n.lastT());r.recalcMatrix(a),n.setMatrix(a,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":454,\"orbit-camera-controller\":475,\"turntable-camera-controller\":553}],55:[function(t,e,r){!function(n,a){\"object\"==typeof r&&\"undefined\"!=typeof e?a(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)}(this,(function(t,e,r,n,a){\"use strict\";function i(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}a=a&&a.hasOwnProperty(\"default\")?a.default:a;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function m(t){return t.index}function v(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}function _(t,e,r){var n=0;if(null===r){for(var i=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;i[l]||(i[l]=[]),i[c]||(i[c]=[]),-1===i[l].indexOf(c)&&i[l].push(c)}var u=a(i);u.sort((function(t,e){return t.length-e.length}));var h={};for(o=0;o<u.length;o++){var f=u[o].slice(-2);h[f[0]]||(h[f[0]]={}),h[f[0]][f[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}function w(t,e){var r=0,n=0;t.links.forEach((function(a){a.circular&&(a.source.circularLinkType||a.target.circularLinkType?a.circularLinkType=a.source.circularLinkType?a.source.circularLinkType:a.target.circularLinkType:a.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==a.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){b(t,e)!=b(a.source,e)&&b(t,e)!=b(a.target,e)||(t.circularLinkType=a.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),H(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function T(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function k(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!H(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!H(t,e)?n+1:n})),r+n}function M(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,a=0;return n.forEach((function(t){a=t.circular?a+1:a})),!(r>1||a>1)}function A(t,e,r){return t.sort(E),t.forEach((function(n,a){var i,o,s=0;if(H(n,r)&&M(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<a;l++)if(i=t[a],o=t[l],!(i.source.column<o.target.column||i.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function S(t,r,a,i){var o=e.min(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),A(t.links.filter((function(t){return\"top\"==t.circularLinkType})),r,i),A(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),r,i),t.links.forEach((function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+10,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,H(e,i)&&M(e))e.circularPathData.leftSmallArcRadius=10+e.width/2,e.circularPathData.leftLargeArcRadius=10+e.width/2,e.circularPathData.rightSmallArcRadius=10+e.width/2,e.circularPathData.rightLargeArcRadius=10+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==e.circularLinkType?c.sort(L):c.sort(C);var u=0;c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=10+e.width/2+u,e.circularPathData.leftLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),s=e.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(P),u=0,c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=10+e.width/2+u,e.circularPathData.rightLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(a,e.source.y1,e.target.y1)+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));e.path=h(e)}}))}function E(t,e){return z(t)==z(e)?\"bottom\"==t.circularLinkType?L(t,e):C(t,e):z(e)-z(t)}function C(t,e){return t.y0-e.y0}function L(t,e){return e.y0-t.y0}function P(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function z(t){return t.target.column-t.source.column}function O(t){return t.target.x0-t.source.x1}function D(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1+n:t.y1-n}function R(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1-n:t.y1+n}function F(t,e,r,n){t.links.forEach((function(a){if(!a.circular&&a.target.column-a.source.column>1){var i=a.source.column+1,o=a.target.column-1,s=1,l=o-i+1;for(s=1;i<=o;i++,s++)t.nodes.forEach((function(o){if(o.column==i){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*a.y0+f*a.y0+p*a.y1+d*a.y1,m=g-a.width/2,v=g+a.width/2;m>o.y0&&m<o.y1?(c=o.y1-m+10,c=\"bottom\"==o.circularLinkType?c:-c,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&B(o,t)&&N(t,c,e,r)}))):(v>o.y0&&v<o.y1||m<o.y0&&v>o.y1)&&(c=v-o.y0+10,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&N(t,c,e,r)})))}}))}}))}function B(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function N(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function j(t,e,r,n){t.nodes.forEach((function(a){n&&a.y+(a.y1-a.y0)>e&&(a.y=a.y-(a.y+(a.y1-a.y0)-e));var i=t.links.filter((function(t){return b(t.source,r)==b(a,r)})),o=i.length;o>1&&i.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!V(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=R(e,t);return t.y1-r}if(e.target.column>t.target.column)return R(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=a.y0;i.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),i.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=i[r].width;t.y0=a.y1-n-t.width/2}}))}))}function U(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return b(t.target,r)==b(e,r)})),a=n.length;a>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!V(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=D(e,t);return t.y0-r}if(t.source.column<e.source.column)return D(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var i=e.y0;n.forEach((function(t){t.y1=i+t.width/2,i+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var i=r+1,o=0;i<a;i++)o+=n[i].width;t.y1=e.y1-o-t.width/2}}))}))}function V(t,e){return q(t)==q(e)}function q(t){return t.y0-t.y1>0?\"up\":\"down\"}function H(t,e){return b(t.source,e)==b(t.target,e)}function G(t,r,n){var a=t.nodes,i=t.links,o=!1,s=!1;if(i.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=e.min(a,(function(t){return t.y0})),c=(n-r)/(e.max(a,(function(t){return t.y1}))-l);a.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),i.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}t.sankeyCircular=function(){var t,n,a=0,i=0,b=1,T=1,M=24,A=m,E=o,C=v,L=y,P=32,I=2,z=null;function O(){var t={nodes:C.apply(null,arguments),links:L.apply(null,arguments)};D(t),_(t,A,z),R(t),B(t),w(t,A),N(t,P,A),V(t);for(var e=4,r=0;r<e;r++)j(t,T,A),U(t,T,A),F(t,i,T,A),j(t,T,A),U(t,T,A);return G(t,i,T),S(t,I,T,A),t}function D(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,A);return t.links.forEach((function(t,r){t.index=r;var n=t.source,a=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof a?\"undefined\":l(a))&&(a=t.target=x(e,a)),n.sourceLinks.push(t),a.targetLinks.push(t)})),t}function R(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}function B(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(E.call(null,t,n))}))}function N(o,s,l){var c=r.nest().key((function(t){return t.column})).sortKeys(e.ascending).entries(o.nodes).map((function(t){return t.values}));!function(r){if(n){var s=1/0;c.forEach((function(t){var e=T*n/(t.length+1);s=e<s?e:s})),t=s}var l=e.min(c,(function(r){return(T-i-(r.length-1)*t)/e.sum(r,f)}));l*=.3,o.links.forEach((function(t){t.width=t.value*l}));var u=function(t){var r=0,n=0,a=0,i=0,o=e.max(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(i+=t.width),t.source.column==o&&(a+=t.width))})),{top:r=r>0?r+25+10:r,bottom:n=n>0?n+25+10:n,left:i=i>0?i+25+10:i,right:a=a>0?a+25+10:a}}(o),h=function(t,r){var n=e.max(t.nodes,(function(t){return t.column})),o=b-a,s=T-i,l=o/(o+r.right+r.left),c=s/(s+r.top+r.bottom);return a=a*l+r.left,b=0==r.right?b:b*l,i=i*c+r.top,T*=c,t.nodes.forEach((function(t){t.x0=a+t.column*((b-a-M)/n),t.x1=t.x0+M})),c}(o,u);l*=h,o.links.forEach((function(t){t.width=t.value*l})),c.forEach((function(t){var e=t.length;t.forEach((function(t,n){t.depth==c.length-1&&1==e||0==t.depth&&1==e?(t.y0=T/2-t.value*l,t.y1=t.y0+t.value*l):t.partOfCycle?0==k(t,r)?(t.y0=T/2+n,t.y1=t.y0+t.value*l):\"top\"==t.circularLinkType?(t.y0=i+n,t.y1=t.y0+t.value*l):(t.y0=T-t.value*l-n,t.y1=t.y0+t.value*l):0==u.top||0==u.bottom?(t.y0=(T-i)/e*n,t.y1=t.y0+t.value*l):(t.y0=(T-i)/2-e/2+n,t.y1=t.y0+t.value*l)}))}))}(l),y();for(var u=1,m=s;m>0;--m)v(u*=.99,l),y();function v(t,r){var n=c.length;c.forEach((function(a){var i=a.length,o=a[0].depth;a.forEach((function(a){var s;if(a.sourceLinks.length||a.targetLinks.length)if(a.partOfCycle&&k(a,r)>0);else if(0==o&&1==i)s=a.y1-a.y0,a.y0=T/2-s/2,a.y1=T/2+s/2;else if(o==n-1&&1==i)s=a.y1-a.y0,a.y0=T/2-s/2,a.y1=T/2+s/2;else{var l=e.mean(a.sourceLinks,g),c=e.mean(a.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(a))*t;a.y0+=u,a.y1+=u}}))}))}function y(){c.forEach((function(e){var r,n,a,o=i,s=e.length;for(e.sort(h),a=0;a<s;++a)(n=o-(r=e[a]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-T)>0)for(o=r.y0-=n,r.y1-=n,a=s-2;a>=0;--a)(n=(r=e[a]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}function V(t){t.nodes.forEach((function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,a=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=a-t.width/2,a-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return O.nodeId=function(t){return arguments.length?(A=\"function\"==typeof t?t:s(t),O):A},O.nodeAlign=function(t){return arguments.length?(E=\"function\"==typeof t?t:s(t),O):E},O.nodeWidth=function(t){return arguments.length?(M=+t,O):M},O.nodePadding=function(e){return arguments.length?(t=+e,O):t},O.nodes=function(t){return arguments.length?(C=\"function\"==typeof t?t:s(t),O):C},O.links=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),O):L},O.size=function(t){return arguments.length?(a=i=0,b=+t[0],T=+t[1],O):[b-a,T-i]},O.extent=function(t){return arguments.length?(a=+t[0][0],b=+t[1][0],i=+t[0][1],T=+t[1][1],O):[[a,i],[b,T]]},O.iterations=function(t){return arguments.length?(P=+t,O):P},O.circularLinkGap=function(t){return arguments.length?(I=+t,O):I},O.nodePaddingRatio=function(t){return arguments.length?(n=+t,O):n},O.sortNodes=function(t){return arguments.length?(z=t,O):z},O.update=function(t){return w(t,A),V(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<T?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),j(t,T,A,!1),U(t,T,A),S(t,I,T,A),t},O},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165,\"elementary-circuits-directed-graph\":179}],56:[function(t,e,r){!function(n,a){\"object\"==typeof r&&\"undefined\"!=typeof e?a(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3)}(this,(function(t,e,r,n){\"use strict\";function a(t){return t.target.depth}function i(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function m(t){return t.links}function v(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,a=1,y=1,x=24,b=8,_=d,w=i,T=g,k=m,M=32;function A(){var t={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return S(t),E(t),C(t),L(t),P(t),t}function S(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,_);t.links.forEach((function(t,r){t.index=r;var n=t.source,a=t.target;\"object\"!=typeof n&&(n=t.source=v(e,n)),\"object\"!=typeof a&&(a=t.target=v(e,a)),n.sourceLinks.push(t),a.targetLinks.push(t)}))}function E(t){t.nodes.forEach((function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))}))}function C(e){var r,n,i;for(r=e.nodes,n=[],i=0;r.length;++i,r=n,n=[])r.forEach((function(t){t.depth=i,t.sourceLinks.forEach((function(t){n.indexOf(t.target)<0&&n.push(t.target)}))}));for(r=e.nodes,n=[],i=0;r.length;++i,r=n,n=[])r.forEach((function(t){t.height=i,t.targetLinks.forEach((function(t){n.indexOf(t.source)<0&&n.push(t.source)}))}));var o=(a-t-x)/(i-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(i-1,Math.floor(w.call(null,e,i))))*o)+x}))}function L(t){var a=r.nest().key((function(t){return t.x0})).sortKeys(e.ascending).entries(t.nodes).map((function(t){return t.values}));!function(){var r=e.max(a,(function(t){return t.length})),i=2/3*(y-n)/(r-1);b>i&&(b=i);var o=e.min(a,(function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)}));a.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*o}))})),t.links.forEach((function(t){t.width=t.value*o}))}(),d();for(var i=1,o=M;o>0;--o)l(i*=.99),d(),s(i),d();function s(t){a.forEach((function(r){r.forEach((function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}}))}))}function l(t){a.slice().reverse().forEach((function(r){r.forEach((function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}}))}))}function d(){a.forEach((function(t){var e,r,a,i=n,o=t.length;for(t.sort(c),a=0;a<o;++a)(r=i-(e=t[a]).y0)>0&&(e.y0+=r,e.y1+=r),i=e.y1+b;if((r=i-b-y)>0)for(i=e.y0-=r,e.y1-=r,a=o-2;a>=0;--a)(r=(e=t[a]).y1+b-i)>0&&(e.y0-=r,e.y1-=r),i=e.y0}))}}function P(t){t.nodes.forEach((function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return A.update=function(t){return P(t),t},A.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),A):_},A.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),A):w},A.nodeWidth=function(t){return arguments.length?(x=+t,A):x},A.nodePadding=function(t){return arguments.length?(b=+t,A):b},A.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),A):T},A.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),A):k},A.size=function(e){return arguments.length?(t=n=0,a=+e[0],y=+e[1],A):[a-t,y-n]},A.extent=function(e){return arguments.length?(t=+e[0][0],a=+e[1][0],n=+e[0][1],y=+e[1][1],A):[[t,n],[a,y]]},A.iterations=function(t){return arguments.length?(M=+t,A):M},A},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=i,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165}],57:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":58}],58:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),a=t(\"clamp\"),i=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],i=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=a((t[2*l]-r)*i,0,1),s[2*l+1]=a((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),a=l(e.bounds,o(t,2));a[0]===a[2]&&a[2]++,a[1]===a[3]&&a[3]++;var d,g=p(t,a),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(m):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=m));for(var v=0;v<m;++v)d[v]=v;var y=[],x=[],b=[],_=[];!function t(e,n,a,i,o,s){if(!i.length)return null;var l=y[o]||(y[o]=[]),c=b[o]||(b[o]=[]),u=x[o]||(x[o]=[]),h=l.length;if(++o>r||s>1073741824){for(var f=0;f<i.length;f++)l.push(i[f]),c.push(s),u.push(null,null,null,null);return h}if(l.push(i[0]),c.push(s),i.length<=1)return u.push(null,null,null,null),h;for(var p=.5*a,d=e+p,m=n+p,v=[],_=[],w=[],T=[],k=1,M=i.length;k<M;k++){var A=i[k],S=g[2*A],E=g[2*A+1];S<d?E<m?v.push(A):_.push(A):E<m?w.push(A):T.push(A)}return s<<=2,u.push(t(e,n,p,v,o,s),t(e,m,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,m,p,T,o,s+3)),h}(0,0,1,d,0,1);for(var w=0,T=0;T<y.length;T++){var k=y[T];if(d.set)d.set(k,w);else for(var M=0,A=k.length;M<A;M++)d[M+w]=k[M];var S=w+y[T].length;_[T]=[w,S],w=S}return d.range=function(){var e,r=[],n=arguments.length;for(;n--;)r[n]=arguments[n];if(u(r[r.length-1])){var o=r.pop();r.length||null==o.x&&null==o.l&&null==o.left||(r=[o],e={}),e=s(o,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=a);var c=i.apply(void 0,r),h=[Math.min(c.x,c.x+c.width),Math.min(c.y,c.y+c.height),Math.max(c.x,c.x+c.width),Math.max(c.y,c.y+c.height)],d=h[0],g=h[1],m=h[2],v=h[3],b=p([d,g,m,v],a),_=b[0],w=b[1],T=b[2],k=b[3],M=l(e.level,y.length);if(null!=e.d){var A;\"number\"==typeof e.d?A=[e.d,e.d]:e.d.length&&(A=e.d),M=Math.min(Math.max(Math.ceil(-f(Math.abs(A[0])/(a[2]-a[0]))),Math.ceil(-f(Math.abs(A[1])/(a[3]-a[1])))),M)}if(M=Math.min(M,y.length),e.lod)return E(_,w,T,k,M);var S=[];function C(e,r,n,a,i,o){if(null!==i&&null!==o&&!(_>e+n||w>r+n||T<e||k<r||a>=M||i===o)){var s=y[a];void 0===o&&(o=s.length);for(var l=i;l<o;l++){var c=s[l],u=t[2*c],h=t[2*c+1];u>=d&&u<=m&&h>=g&&h<=v&&S.push(c)}var f=x[a],p=f[4*i+0],b=f[4*i+1],A=f[4*i+2],E=f[4*i+3],P=L(f,i+1),I=.5*n,z=a+1;C(e,r,I,z,p,b||A||E||P),C(e,r+I,I,z,b,A||E||P),C(e+I,r,I,z,A,E||P),C(e+I,r+I,I,z,E,P)}}function L(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}return C(0,0,1,0,0,1),S},d;function E(t,e,r,a,i){for(var o=[],s=0;s<i;s++){var l=b[s],c=_[s][0],u=C(t,e,s),h=C(r,a,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}function C(t,e,r){for(var n=1,a=.5,i=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<a?e<i?0:1:e<i?2:3,o*=.5,a+=t<a?-o:o,i+=e<i?-o:o;return n}}},{\"array-bounds\":70,\"binary-search-bounds\":96,clamp:120,defined:170,dtype:175,\"flatten-vertex-data\":244,\"is-obj\":442,\"math-log2\":453,\"parse-rect\":478,\"pick-by-alias\":485}],59:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(i(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(i(t[r]))}return e}function i(t){var e,r,n,a,i,s,l=0,c=t.length;if(c>2){for(s=0;s<c;s++)s===c-2?(n=c-2,a=c-1,i=0):s===c-1?(n=c-1,a=0,i=1):(n=s,a=s+1,i=s+2),e=t[n],r=t[a],l+=(o(t[i][0])-o(e[0]))*Math.sin(o(r[1]));l=6378137*l*6378137/2}return l}function o(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,(function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)}),0)}},{\"@turf/meta\":63}],60:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");r.default=function(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,(function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])})),e}},{\"@turf/meta\":63}],61:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),a=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,i=0,o=0;return n.coordEach(t,(function(t){r+=t[0],i+=t[1],o++})),a.point([r/o,i/o],e.properties)}},{\"@turf/helpers\":62,\"@turf/meta\":63}],62:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function a(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function i(t,e,r){void 0===r&&(r={});for(var a=0,i=t;a<i.length;a++){var o=i[a];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return a(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return i(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=a,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.polygon=i,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var a=r.areaFactors[e];if(!a)throw new Error(\"invalid original units\");var i=r.areaFactors[n];if(!i)throw new Error(\"invalid final units\");return t/a*i},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],63:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function a(t,e,r){if(null!==t)for(var n,i,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,m=\"Feature\"===d,v=g?t.features.length:1,y=0;y<v;y++){l=(h=!!(u=g?t.features[y].geometry:m?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(i=0;i<c[n].length-f;i++){if(!1===e(c[n][i],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,i=0;i<c[n].length;i++){for(o=0;o<c[n][i].length-f;o++){if(!1===e(c[n][i][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===a(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function i(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,a,i,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,a=0;a<o;a++)if(null!==(i=l?s.geometries[a]:s))switch(i.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(i,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<i.geometries.length;n++)if(!1===e(i.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,(function(t,r,a,i,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,a,{bbox:i,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,a),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,i){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==a(t,(function(a,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=a,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,a],t.properties);if(!1===e(g,r,i,d,o))return!1;o++,l=a}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,a){if(null!==t.geometry){var i=t.geometry.type,o=t.geometry.coordinates;switch(i){case\"LineString\":if(!1===e(t,r,a,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,a,s))return!1}}}))}r.coordEach=a,r.coordReduce=function(t,e,r,n){var i=r;return a(t,(function(t,n,a,o,s){i=0===n&&void 0===r?t:e(i,t,n,a,o,s)}),n),i},r.propEach=i,r.propReduce=function(t,e,r){var n=r;return i(t,(function(t,a){n=0===a&&void 0===r?t:e(n,t,a)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,a){n=0===a&&void 0===r?t:e(n,t,a)})),n},r.coordAll=function(t){var e=[];return a(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,a,i,o,s){n=0===a&&void 0===r?t:e(n,t,a,i,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,a,i){n=0===a&&0===i&&void 0===r?t:e(n,t,a,i)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,a=!1;return c(t,(function(t,i,o,s,l){n=!1===a&&void 0===r?t:e(n,t,i,o,s,l),a=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,a,i,o){n=0===a&&void 0===r?t:e(n,t,a,i,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,a=e.featureIndex||0,i=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":a<0&&(a=t.features.length+a),l=l||t.features[a].properties,r=t.features[a].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return i<0&&(i=c.length+i),s<0&&(s=c[i].length+s-1),n.lineString([c[i][s],c[i][s+1]],l,e);case\"MultiPolygon\":return i<0&&(i=c.length+i),o<0&&(o=c[i].length+o),s<0&&(s=c[i][o].length-s-1),n.lineString([c[i][o][s],c[i][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,a=e.featureIndex||0,i=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":a<0&&(a=t.features.length+a),l=l||t.features[a].properties,r=t.features[a].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return i<0&&(i=c.length+i),n.point(c[i],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return i<0&&(i=c.length+i),s<0&&(s=c[i].length+s),n.point(c[i][s],l,e);case\"MultiPolygon\":return i<0&&(i=c.length+i),o<0&&(o=c[i].length+o),s<0&&(s=c[i][o].length-s),n.point(c[i][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":62}],64:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,a=t(\"gl-buffer\"),i=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=a(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=i(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":258,\"gl-vao\":332,\"weak-map\":574}],65:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,a=0;return t.map((function(t){var i=(t=t.slice())[0],o=i.toUpperCase();if(i!=o)switch(t[0]=o,i){case\"a\":t[6]+=n,t[7]+=a;break;case\"v\":t[1]+=a;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=a}switch(o){case\"Z\":n=e,a=r;break;case\"H\":n=t[1];break;case\"V\":a=t[1];break;case\"M\":n=e=t[1],a=r=t[2];break;default:n=t[t.length-2],a=t[t.length-1]}return t}))}},{}],66:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var a=t.split(/\\r?\\n/),i=String(a.length+e-1).length;return a.map((function(t,a){var o=a+e,s=String(o).length;return n(o,i-s)+r+t})).join(\"\\n\")}},{\"pad-left\":476}],67:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],i=[0],o=1;o<e;++o)if(n.push(t[o]),a(n,r)){if(i.push(o),i.length===r+1)return i}else n.pop();return i};var n=t(\"robust-orientation\");function a(t,e){for(var r=new Array(e+1),a=0;a<t.length;++a)r[a]=t[a];for(a=0;a<=t.length;++a){for(var i=t.length;i<=e;++i){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(i+1-a,s);r[i]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":520}],68:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),i=0;i<r.length;++i)n[i]=e[r[i]];return a(n)*t<1}))};var n=t(\"delaunay-triangulate\"),a=t(\"circumradius\")},{circumradius:119,\"delaunay-triangulate\":171}],69:[function(t,e,r){e.exports=function(t,e){return a(n(t,e))};var n=t(\"alpha-complex\"),a=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":68,\"simplicial-complex-boundary\":527}],70:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var a=-1/0,i=1/0,o=n,s=t.length;o<s;o+=e)t[o]>a&&(a=t[o]),t[o]<i&&(i=t[o]);r[n]=i,r[e+n]=a}return r}},{}],71:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var a=0;a<e;a++){var i=r[e+a],o=r[a],s=a,l=t.length;if(i===1/0&&o===-1/0)for(s=a;s<l;s+=e)t[s]=t[s]===i?1:t[s]===o?0:.5;else if(i===1/0)for(s=a;s<l;s+=e)t[s]=t[s]===i?1:0;else if(o===-1/0)for(s=a;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=i-o;for(s=a;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{\"array-bounds\":70}],72:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var a=(e|=0)-(t|=0);if(a<0)throw new Error(\"array length must be positive\");for(var i=new Array(a),o=0,s=t;o<a;o++,s++)i[o]=s;return i}},{}],73:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>\n",
       " * @license  MIT\n",
       " */function a(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,a=0,i=Math.min(r,n);a<i;++a)if(t[a]!==e[a]){r=t[a],n=e[a];break}return r<n?-1:n<r?1:0}function i(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!i(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function m(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,a){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:a})}function y(t,e){t||v(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(i(t)&&i(e))return 0===a(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===a(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(i(t)!==i(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var a=b(t),i=b(e);if(a&&!i||!a&&i)return!1;if(a)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=T(t),h=T(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var a;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),a=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!a&&v(a,r,\"Missing expected exception\"+n);var i=\"string\"==typeof n,s=!t&&a&&!r;if((!t&&o.isError(a)&&i&&_(a,r)||s)&&v(a,r,\"Got unwanted exception\"+n),t&&a&&r&&!_(a,r)||!t&&a)throw a}f.AssertionError=function(t){this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=function(t){return g(m(t.actual),128)+\" \"+t.operator+\" \"+g(m(t.expected),128)}(this),this.generatedMessage=!0);var e=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,e);else{var r=new Error;if(r.stack){var n=r.stack,a=d(e),i=n.indexOf(\"\\n\"+a);if(i>=0){var o=n.indexOf(\"\\n\",i+1);n=n.substring(o+1)}this.stack=n}}},o.inherits(f.AssertionError,Error),f.fail=v,f.ok=y,f.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||v(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||v(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&v(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n((function t(e,r){e||v(e,!0,r,\"==\",t)}),f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var T=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":473,\"util/\":76}],74:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],75:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],76:[function(t,e,r){(function(e,n){var a=/%[sdj%]/g;r.format=function(t){if(!v(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,i=n.length,o=String(t).replace(a,(function(t){if(\"%%\"===t)return\"%\";if(r>=i)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),l=n[r];r<i;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,a){if(y(n.process))return function(){return r.deprecate(t,a).apply(this,arguments)};if(!0===e.noDeprecation)return t;var i=!1;return function(){if(!i){if(e.throwDeprecation)throw new Error(a);e.traceDeprecation?console.trace(a):console.error(a),i=!0}return t.apply(this,arguments)}};var i,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&T(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var a=e.inspect(n,t);return v(a)||(a=u(t,a,n)),a}var i=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(v(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(m(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(i)return i;var o=Object.keys(e),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(T(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",k=!1,M=[\"{\",\"}\"];(p(e)&&(k=!0,M=[\"[\",\"]\"]),T(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||k&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=k?function(t,e,r,n,a){for(var i=[],o=0,s=e.length;o<s;++o)E(e,String(o))?i.push(f(t,e,r,n,String(o),!0)):i.push(\"\");return a.forEach((function(a){a.match(/^\\d+$/)||i.push(f(t,e,r,n,a,!0))})),i}(t,e,n,s,o):o.map((function(r){return f(t,e,n,s,r,k)})),t.seen.pop(),function(t,e,r){if(t.reduce((function(t,e){return e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,M)):M[0]+b+M[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,a,i){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,a)||{value:e[a]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),E(n,a)||(o=\"[\"+a+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=i?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(i&&a.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+a)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function m(t){return\"number\"==typeof t}function v(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===k(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===k(t)}function w(t){return b(t)&&(\"[object Error]\"===k(t)||t instanceof Error)}function T(t){return\"function\"==typeof t}function k(t){return Object.prototype.toString.call(t)}function M(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(i)&&(i=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(i)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=m,r.isString=v,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=T,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var A=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(){var t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(\":\");return[t.getDate(),A[t.getMonth()],e].join(\" \")}function E(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){console.log(\"%s - %s\",S(),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":75,_process:500,inherits:74}],77:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],78:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,i=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];i[o]=s}i[r]=new Array(r+1);for(o=0;o<=r;++o)i[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(i,c),h=a(u[r+1]);0===h&&(h=1);var f=new Array(r+1);for(o=0;o<=r;++o)f[o]=a(u[o])/h;return f};var n=t(\"robust-linear-solve\");function a(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":519}],79:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new i(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,h=s>0?o-4:o;for(r=0;r<h;r+=4)e=a[t.charCodeAt(r)]<<18|a[t.charCodeAt(r+1)]<<12|a[t.charCodeAt(r+2)]<<6|a[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=a[t.charCodeAt(r)]<<2|a[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=a[t.charCodeAt(r)]<<10|a[t.charCodeAt(r+1)]<<4|a[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,a=r%3,i=[],o=0,s=r-a;o<s;o+=16383)i.push(u(t,o,o+16383>s?s:o+16383));1===a?(e=t[r-1],i.push(n[e>>2]+n[e<<4&63]+\"==\")):2===a&&(e=(t[r-2]<<8)+t[r-1],i.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return i.join(\"\")};for(var n=[],a=[],i=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],a[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var a,i,o=[],s=e;s<r;s+=3)a=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(i=a)>>18&63]+n[i>>12&63]+n[i>>6&63]+n[63&i]);return o.join(\"\")}a[\"-\".charCodeAt(0)]=62,a[\"_\".charCodeAt(0)]=63},{}],80:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],81:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],82:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":90}],83:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),a=t(\"./lib/is-bn\"),i=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,h=0;if(a(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[i(0),i(1)];if(e===Math.floor(e))c=i(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),h-=256;c=i(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(a(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=i(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),h+=256;u=i(r)}else u=i(1);h>0?c=c.ushln(h):h<0&&(u=u.ushln(-h));return s(c,u)}},{\"./div\":82,\"./is-rat\":84,\"./lib/is-bn\":88,\"./lib/num-to-bn\":89,\"./lib/rationalize\":90,\"./lib/str-to-bn\":91}],84:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":88}],85:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":99}],86:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,a=0;if(1===e)a=r[0];else if(2===e)a=r[0]+67108864*r[1];else for(var i=0;i<e;i++){var o=r[i];a+=o*Math.pow(67108864,i)}return n(t)*a}},{\"./bn-sign\":85}],87:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),a=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=a(n.lo(t));if(e<32)return e;var r=a(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":97,\"double-bits\":173}],88:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":99}],89:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),a=t(\"double-bits\");e.exports=function(t){var e=a.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":99,\"double-bits\":173}],90:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),a=t(\"./bn-sign\");e.exports=function(t,e){var r=a(t),i=a(e);if(0===r)return[n(0),n(1)];if(0===i)return[n(0),n(0)];i<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":85,\"./num-to-bn\":89}],91:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":99}],92:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],93:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":85}],94:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],95:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),a=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var i=e.abs().divmod(r.abs()),o=i.div,s=n(o),l=i.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=a(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53;h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":86,\"./lib/ctz\":87}],96:[function(t,e,r){\"use strict\";function n(t,e,r,n,a){var i=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return a?e.indexOf(\"c\")<0?i.push(\";if(x===y){return m}else if(x<=y){\"):i.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):i.push(\";if(\",e,\"){i=m;\"),r?i.push(\"l=m+1}else{h=m-1}\"):i.push(\"h=m-1}else{l=m+1}\"),i.push(\"}\"),a?i.push(\"return -1};\"):i.push(\"return i};\"),i.join(\"\")}function a(t,e,r,a){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],a),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],a),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:a(\">=\",!1,\"GE\"),gt:a(\">\",!1,\"GT\"),lt:a(\"<\",!0,\"LT\"),le:a(\"<=\",!0,\"LE\"),eq:a(\"-\",!0,\"EQ\",!0)}},{}],97:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var a=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,a=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--a;t[e]=n<<a&255}}(a),r.reverse=function(t){return a[255&t]<<24|a[t>>>8&255]<<16|a[t>>>16&255]<<8|a[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],98:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,m=null==e.cutoff?.25:e.cutoff,v=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,g=r*o;d<g;d++){var M=l[d];x[d]=1===M?0:0===M?a:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?a:0===M?0:Math.pow(Math.max(0,M-.5),2)}i(x,r,o,_,w,k,T),i(b,r,o,_,w,k,T);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)A[d]=n(1-((x[d]-b[d])/v+m),0,1);return A};var a=1e20;function i(t,e,r,n,a,i,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,a,i,s,r),c=0;c<r;c++)t[c*e+l]=a[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,a,i,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(a[l])}}function o(t,e,r,n,i){r[0]=0,n[0]=-a,n[1]=+a;for(var o=1,s=0;o<i;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+a}for(o=0,s=0;o<i;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:120}],99:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function a(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function i(t,e,r){if(i.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=i:r.BN=i,i.BN=i,i.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,a=Math.min(t.length,r),i=e;i<a;i++){var o=t.charCodeAt(i)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var a=0,i=Math.min(t.length,r),o=e;o<i;o++){var s=t.charCodeAt(o)-48;a*=n,a+=s>=49?s-49+10:s>=17?s-17+10:s}return a}i.isBN=function(t){return t instanceof i||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===i.wordSize&&Array.isArray(t.words)},i.max=function(t,e){return t.cmp(e)>0?t:e},i.min=function(t,e){return t.cmp(e)<0?t:e},i.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var a=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&a++,16===e?this._parseHex(t,a):this._parseBase(t,e,a),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},i.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},i.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var a=0;a<this.length;a++)this.words[a]=0;var i,o,s=0;if(\"be\"===r)for(a=t.length-1,i=0;a>=0;a-=3)o=t[a]|t[a-1]<<8|t[a-2]<<16,this.words[i]|=o<<s&67108863,this.words[i+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,i++);else if(\"le\"===r)for(a=0,i=0;a<t.length;a+=3)o=t[a]|t[a+1]<<8|t[a+2]<<16,this.words[i]|=o<<s&67108863,this.words[i+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,i++);return this.strip()},i.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,a,i=0;for(r=t.length-6,n=0;r>=e;r-=6)a=s(t,r,r+6),this.words[n]|=a<<i&67108863,this.words[n+1]|=a>>>26-i&4194303,(i+=24)>=26&&(i-=26,n++);r+6!==e&&(a=s(t,e,r+6),this.words[n]|=a<<i&67108863,this.words[n+1]|=a>>>26-i&4194303),this.strip()},i.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,a=1;a<=67108863;a*=e)n++;n--,a=a/e|0;for(var i=t.length-r,o=i%n,s=Math.min(i,i-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(a),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},i.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},i.prototype.clone=function(){var t=new i(null);return this.copy(t),t},i.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},i.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},i.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},i.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var a=0|t.words[0],i=0|e.words[0],o=a*i,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(a=0|t.words[d])*(i=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}i.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var a=0,i=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<a|i)).toString(16);r=0!==(i=s>>>24-a&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(a+=2)>=26&&(a-=26,o--)}for(0!==i&&(r=i.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},i.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},i.prototype.toJSON=function(){return this.toString(16)},i.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},i.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},i.prototype.toArrayLike=function(t,e,r){var a=this.byteLength(),i=r||Math.max(1,a);n(a<=i,\"byte array longer than desired length\"),n(i>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(i),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<i;s++)c[s]=0}else{for(s=0;s<i-a;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[i-s-1]=o}return c},Math.clz32?i.prototype._countBits=function(t){return 32-Math.clz32(t)}:i.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},i.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},i.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},i.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},i.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},i.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},i.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},i.prototype.isNeg=function(){return 0!==this.negative},i.prototype.neg=function(){return this.clone().ineg()},i.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},i.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},i.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},i.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},i.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},i.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},i.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},i.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},i.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},i.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},i.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},i.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},i.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},i.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var a=0;a<e;a++)this.words[a]=67108863&~this.words[a];return r>0&&(this.words[a]=~this.words[a]&67108863>>26-r),this.strip()},i.prototype.notn=function(t){return this.clone().inotn(t)},i.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,a=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<a:this.words[r]&~(1<<a),this.strip()},i.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var a=0,i=0;i<n.length;i++)e=(0|r.words[i])+(0|n.words[i])+a,this.words[i]=67108863&e,a=e>>>26;for(;0!==a&&i<r.length;i++)e=(0|r.words[i])+a,this.words[i]=67108863&e,a=e>>>26;if(this.length=r.length,0!==a)this.words[this.length]=a,this.length++;else if(r!==this)for(;i<r.length;i++)this.words[i]=r.words[i];return this},i.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},i.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,a=this.cmp(t);if(0===a)return this.negative=0,this.length=1,this.words[0]=0,this;a>0?(r=this,n=t):(r=t,n=this);for(var i=0,o=0;o<n.length;o++)i=(e=(0|r.words[o])-(0|n.words[o])+i)>>26,this.words[o]=67108863&e;for(;0!==i&&o<r.length;o++)i=(e=(0|r.words[o])+i)>>26,this.words[o]=67108863&e;if(0===i&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},i.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,a,i,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,m=0|o[2],v=8191&m,y=m>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],I=8191&P,z=P>>>13,O=0|o[8],D=8191&O,R=O>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,Z=Y>>>13,X=0|s[3],J=8191&X,K=X>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,at=0|s[6],it=8191&at,ot=at>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var mt=(c+(n=Math.imul(h,U))|0)+((8191&(a=(a=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((i=Math.imul(f,V))+(a>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(d,U),a=(a=Math.imul(d,V))+Math.imul(g,U)|0,i=Math.imul(g,V);var vt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(a=(a=a+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((i=i+Math.imul(f,G)|0)+(a>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(v,U),a=(a=Math.imul(v,V))+Math.imul(y,U)|0,i=Math.imul(y,V),n=n+Math.imul(d,H)|0,a=(a=a+Math.imul(d,G)|0)+Math.imul(g,H)|0,i=i+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(a=(a=a+Math.imul(h,Z)|0)+Math.imul(f,W)|0))<<13)|0;c=((i=i+Math.imul(f,Z)|0)+(a>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),a=(a=Math.imul(b,V))+Math.imul(_,U)|0,i=Math.imul(_,V),n=n+Math.imul(v,H)|0,a=(a=a+Math.imul(v,G)|0)+Math.imul(y,H)|0,i=i+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,a=(a=a+Math.imul(d,Z)|0)+Math.imul(g,W)|0,i=i+Math.imul(g,Z)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(a=(a=a+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((i=i+Math.imul(f,K)|0)+(a>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),a=(a=Math.imul(T,V))+Math.imul(k,U)|0,i=Math.imul(k,V),n=n+Math.imul(b,H)|0,a=(a=a+Math.imul(b,G)|0)+Math.imul(_,H)|0,i=i+Math.imul(_,G)|0,n=n+Math.imul(v,W)|0,a=(a=a+Math.imul(v,Z)|0)+Math.imul(y,W)|0,i=i+Math.imul(y,Z)|0,n=n+Math.imul(d,J)|0,a=(a=a+Math.imul(d,K)|0)+Math.imul(g,J)|0,i=i+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,$)|0)|0)+((8191&(a=(a=a+Math.imul(h,tt)|0)+Math.imul(f,$)|0))<<13)|0;c=((i=i+Math.imul(f,tt)|0)+(a>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,U),a=(a=Math.imul(A,V))+Math.imul(S,U)|0,i=Math.imul(S,V),n=n+Math.imul(T,H)|0,a=(a=a+Math.imul(T,G)|0)+Math.imul(k,H)|0,i=i+Math.imul(k,G)|0,n=n+Math.imul(b,W)|0,a=(a=a+Math.imul(b,Z)|0)+Math.imul(_,W)|0,i=i+Math.imul(_,Z)|0,n=n+Math.imul(v,J)|0,a=(a=a+Math.imul(v,K)|0)+Math.imul(y,J)|0,i=i+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,a=(a=a+Math.imul(d,tt)|0)+Math.imul(g,$)|0,i=i+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(a=(a=a+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((i=i+Math.imul(f,nt)|0)+(a>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),a=(a=Math.imul(C,V))+Math.imul(L,U)|0,i=Math.imul(L,V),n=n+Math.imul(A,H)|0,a=(a=a+Math.imul(A,G)|0)+Math.imul(S,H)|0,i=i+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,a=(a=a+Math.imul(T,Z)|0)+Math.imul(k,W)|0,i=i+Math.imul(k,Z)|0,n=n+Math.imul(b,J)|0,a=(a=a+Math.imul(b,K)|0)+Math.imul(_,J)|0,i=i+Math.imul(_,K)|0,n=n+Math.imul(v,$)|0,a=(a=a+Math.imul(v,tt)|0)+Math.imul(y,$)|0,i=i+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,a=(a=a+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,i=i+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,it)|0)|0)+((8191&(a=(a=a+Math.imul(h,ot)|0)+Math.imul(f,it)|0))<<13)|0;c=((i=i+Math.imul(f,ot)|0)+(a>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(I,U),a=(a=Math.imul(I,V))+Math.imul(z,U)|0,i=Math.imul(z,V),n=n+Math.imul(C,H)|0,a=(a=a+Math.imul(C,G)|0)+Math.imul(L,H)|0,i=i+Math.imul(L,G)|0,n=n+Math.imul(A,W)|0,a=(a=a+Math.imul(A,Z)|0)+Math.imul(S,W)|0,i=i+Math.imul(S,Z)|0,n=n+Math.imul(T,J)|0,a=(a=a+Math.imul(T,K)|0)+Math.imul(k,J)|0,i=i+Math.imul(k,K)|0,n=n+Math.imul(b,$)|0,a=(a=a+Math.imul(b,tt)|0)+Math.imul(_,$)|0,i=i+Math.imul(_,tt)|0,n=n+Math.imul(v,rt)|0,a=(a=a+Math.imul(v,nt)|0)+Math.imul(y,rt)|0,i=i+Math.imul(y,nt)|0,n=n+Math.imul(d,it)|0,a=(a=a+Math.imul(d,ot)|0)+Math.imul(g,it)|0,i=i+Math.imul(g,ot)|0;var Tt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(a=(a=a+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((i=i+Math.imul(f,ct)|0)+(a>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),a=(a=Math.imul(D,V))+Math.imul(R,U)|0,i=Math.imul(R,V),n=n+Math.imul(I,H)|0,a=(a=a+Math.imul(I,G)|0)+Math.imul(z,H)|0,i=i+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,a=(a=a+Math.imul(C,Z)|0)+Math.imul(L,W)|0,i=i+Math.imul(L,Z)|0,n=n+Math.imul(A,J)|0,a=(a=a+Math.imul(A,K)|0)+Math.imul(S,J)|0,i=i+Math.imul(S,K)|0,n=n+Math.imul(T,$)|0,a=(a=a+Math.imul(T,tt)|0)+Math.imul(k,$)|0,i=i+Math.imul(k,tt)|0,n=n+Math.imul(b,rt)|0,a=(a=a+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,i=i+Math.imul(_,nt)|0,n=n+Math.imul(v,it)|0,a=(a=a+Math.imul(v,ot)|0)+Math.imul(y,it)|0,i=i+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,a=(a=a+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,i=i+Math.imul(g,ct)|0;var kt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(a=(a=a+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((i=i+Math.imul(f,ft)|0)+(a>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),a=(a=Math.imul(B,V))+Math.imul(N,U)|0,i=Math.imul(N,V),n=n+Math.imul(D,H)|0,a=(a=a+Math.imul(D,G)|0)+Math.imul(R,H)|0,i=i+Math.imul(R,G)|0,n=n+Math.imul(I,W)|0,a=(a=a+Math.imul(I,Z)|0)+Math.imul(z,W)|0,i=i+Math.imul(z,Z)|0,n=n+Math.imul(C,J)|0,a=(a=a+Math.imul(C,K)|0)+Math.imul(L,J)|0,i=i+Math.imul(L,K)|0,n=n+Math.imul(A,$)|0,a=(a=a+Math.imul(A,tt)|0)+Math.imul(S,$)|0,i=i+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,a=(a=a+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,i=i+Math.imul(k,nt)|0,n=n+Math.imul(b,it)|0,a=(a=a+Math.imul(b,ot)|0)+Math.imul(_,it)|0,i=i+Math.imul(_,ot)|0,n=n+Math.imul(v,lt)|0,a=(a=a+Math.imul(v,ct)|0)+Math.imul(y,lt)|0,i=i+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,a=(a=a+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,i=i+Math.imul(g,ft)|0;var Mt=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(a=(a=a+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((i=i+Math.imul(f,gt)|0)+(a>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),a=(a=Math.imul(B,G))+Math.imul(N,H)|0,i=Math.imul(N,G),n=n+Math.imul(D,W)|0,a=(a=a+Math.imul(D,Z)|0)+Math.imul(R,W)|0,i=i+Math.imul(R,Z)|0,n=n+Math.imul(I,J)|0,a=(a=a+Math.imul(I,K)|0)+Math.imul(z,J)|0,i=i+Math.imul(z,K)|0,n=n+Math.imul(C,$)|0,a=(a=a+Math.imul(C,tt)|0)+Math.imul(L,$)|0,i=i+Math.imul(L,tt)|0,n=n+Math.imul(A,rt)|0,a=(a=a+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,i=i+Math.imul(S,nt)|0,n=n+Math.imul(T,it)|0,a=(a=a+Math.imul(T,ot)|0)+Math.imul(k,it)|0,i=i+Math.imul(k,ot)|0,n=n+Math.imul(b,lt)|0,a=(a=a+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,i=i+Math.imul(_,ct)|0,n=n+Math.imul(v,ht)|0,a=(a=a+Math.imul(v,ft)|0)+Math.imul(y,ht)|0,i=i+Math.imul(y,ft)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(a=(a=a+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((i=i+Math.imul(g,gt)|0)+(a>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),a=(a=Math.imul(B,Z))+Math.imul(N,W)|0,i=Math.imul(N,Z),n=n+Math.imul(D,J)|0,a=(a=a+Math.imul(D,K)|0)+Math.imul(R,J)|0,i=i+Math.imul(R,K)|0,n=n+Math.imul(I,$)|0,a=(a=a+Math.imul(I,tt)|0)+Math.imul(z,$)|0,i=i+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,a=(a=a+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,i=i+Math.imul(L,nt)|0,n=n+Math.imul(A,it)|0,a=(a=a+Math.imul(A,ot)|0)+Math.imul(S,it)|0,i=i+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,a=(a=a+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,i=i+Math.imul(k,ct)|0,n=n+Math.imul(b,ht)|0,a=(a=a+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,i=i+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(v,dt)|0)|0)+((8191&(a=(a=a+Math.imul(v,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((i=i+Math.imul(y,gt)|0)+(a>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),a=(a=Math.imul(B,K))+Math.imul(N,J)|0,i=Math.imul(N,K),n=n+Math.imul(D,$)|0,a=(a=a+Math.imul(D,tt)|0)+Math.imul(R,$)|0,i=i+Math.imul(R,tt)|0,n=n+Math.imul(I,rt)|0,a=(a=a+Math.imul(I,nt)|0)+Math.imul(z,rt)|0,i=i+Math.imul(z,nt)|0,n=n+Math.imul(C,it)|0,a=(a=a+Math.imul(C,ot)|0)+Math.imul(L,it)|0,i=i+Math.imul(L,ot)|0,n=n+Math.imul(A,lt)|0,a=(a=a+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,i=i+Math.imul(S,ct)|0,n=n+Math.imul(T,ht)|0,a=(a=a+Math.imul(T,ft)|0)+Math.imul(k,ht)|0,i=i+Math.imul(k,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(a=(a=a+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((i=i+Math.imul(_,gt)|0)+(a>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),a=(a=Math.imul(B,tt))+Math.imul(N,$)|0,i=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,a=(a=a+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,i=i+Math.imul(R,nt)|0,n=n+Math.imul(I,it)|0,a=(a=a+Math.imul(I,ot)|0)+Math.imul(z,it)|0,i=i+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,a=(a=a+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,i=i+Math.imul(L,ct)|0,n=n+Math.imul(A,ht)|0,a=(a=a+Math.imul(A,ft)|0)+Math.imul(S,ht)|0,i=i+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(a=(a=a+Math.imul(T,gt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((i=i+Math.imul(k,gt)|0)+(a>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),a=(a=Math.imul(B,nt))+Math.imul(N,rt)|0,i=Math.imul(N,nt),n=n+Math.imul(D,it)|0,a=(a=a+Math.imul(D,ot)|0)+Math.imul(R,it)|0,i=i+Math.imul(R,ot)|0,n=n+Math.imul(I,lt)|0,a=(a=a+Math.imul(I,ct)|0)+Math.imul(z,lt)|0,i=i+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,a=(a=a+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,i=i+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(a=(a=a+Math.imul(A,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((i=i+Math.imul(S,gt)|0)+(a>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,it),a=(a=Math.imul(B,ot))+Math.imul(N,it)|0,i=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,a=(a=a+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,i=i+Math.imul(R,ct)|0,n=n+Math.imul(I,ht)|0,a=(a=a+Math.imul(I,ft)|0)+Math.imul(z,ht)|0,i=i+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(a=(a=a+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((i=i+Math.imul(L,gt)|0)+(a>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),a=(a=Math.imul(B,ct))+Math.imul(N,lt)|0,i=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,a=(a=a+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,i=i+Math.imul(R,ft)|0;var It=(c+(n=n+Math.imul(I,dt)|0)|0)+((8191&(a=(a=a+Math.imul(I,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((i=i+Math.imul(z,gt)|0)+(a>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,ht),a=(a=Math.imul(B,ft))+Math.imul(N,ht)|0,i=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(a=(a=a+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((i=i+Math.imul(R,gt)|0)+(a>>>13)|0)+(zt>>>26)|0,zt&=67108863;var Ot=(c+(n=Math.imul(B,dt))|0)+((8191&(a=(a=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((i=Math.imul(N,gt))+(a>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,l[0]=mt,l[1]=vt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=It,l[17]=zt,l[18]=Ot,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),i.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,a=0,i=0;i<r.length-1;i++){var o=a;a=0;for(var s=67108863&n,l=Math.min(i,e.length-1),c=Math.max(0,i-t.length+1);c<=l;c++){var u=i-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),a+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[i]=s,n=o,o=a}return 0!==n?r.words[i]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=i.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,a=0;a<e;a++)n|=(1&t)<<e-a-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,a,i){for(var o=0;o<i;o++)n[o]=e[t[o]],a[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,a,i){this.permute(i,t,e,r,n,a);for(var o=1;o<a;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<a;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],m=r[u+p+o],v=n[u+p+o],y=h*m-f*v;v=h*v+f*m,m=y,r[u+p]=d+m,n[u+p]=g+v,r[u+p+o]=d-m,n[u+p+o]=g-v,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,a=0;for(r=r/2|0;r;r>>>=1)a++;return 1<<a+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var a=t[n];t[n]=t[r-n-1],t[r-n-1]=a,a=e[n],e[n]=-e[r-n-1],e[r-n-1]=-a}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var a=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&a,r=a<67108864?0:a/67108864|0}return t},g.prototype.convert13b=function(t,e,r,a){for(var i=0,o=0;o<e;o++)i+=0|t[o],r[2*o]=8191&i,i>>>=13,r[2*o+1]=8191&i,i>>>=13;for(o=2*e;o<a;++o)r[o]=0;n(0===i),n(0==(-8192&i))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),a=this.makeRBT(n),i=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,i,s,l,n,a),this.transform(c,i,u,h,n,a);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,i,n,a),this.conjugate(f,i,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},i.prototype.mul=function(t){var e=new i(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},i.prototype.mulf=function(t){var e=new i(null);return e.words=new Array(this.length+t.length),d(this,t,e)},i.prototype.imul=function(t){return this.clone().mulTo(t,this)},i.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var a=(0|this.words[r])*t,i=(67108863&a)+(67108863&e);e>>=26,e+=a/67108864|0,e+=i>>>26,this.words[r]=67108863&i}return 0!==e&&(this.words[r]=e,this.length++),this},i.prototype.muln=function(t){return this.clone().imuln(t)},i.prototype.sqr=function(){return this.mul(this)},i.prototype.isqr=function(){return this.imul(this.clone())},i.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,a=r%26;e[r]=(t.words[n]&1<<a)>>>a}return e}(t);if(0===e.length)return new i(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var a=r.sqr();n<e.length;n++,a=a.sqr())0!==e[n]&&(r=r.mul(a));return r},i.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,a=(t-r)/26,i=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&i,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==a){for(e=this.length-1;e>=0;e--)this.words[e+a]=this.words[e];for(e=0;e<a;e++)this.words[e]=0;this.length+=a}return this.strip()},i.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},i.prototype.iushrn=function(t,e,r){var a;n(\"number\"==typeof t&&t>=0),a=e?(e-e%26)/26:0;var i=t%26,o=Math.min((t-i)/26,this.length),s=67108863^67108863>>>i<<i,l=r;if(a-=o,a=Math.max(0,a),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=a);c--){var h=0|this.words[c];this.words[c]=u<<26-i|h>>>i,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},i.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},i.prototype.shln=function(t){return this.clone().ishln(t)},i.prototype.ushln=function(t){return this.clone().iushln(t)},i.prototype.shrn=function(t){return this.clone().ishrn(t)},i.prototype.ushrn=function(t){return this.clone().iushrn(t)},i.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,a=1<<e;return!(this.length<=r)&&!!(this.words[r]&a)},i.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var a=67108863^67108863>>>e<<e;this.words[this.length-1]&=a}return this.strip()},i.prototype.maskn=function(t){return this.clone().imaskn(t)},i.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},i.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},i.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},i.prototype.addn=function(t){return this.clone().iaddn(t)},i.prototype.subn=function(t){return this.clone().isubn(t)},i.prototype.iabs=function(){return this.negative=0,this},i.prototype.abs=function(){return this.clone().iabs()},i.prototype._ishlnsubmul=function(t,e,r){var a,i,o=t.length+r;this._expand(o);var s=0;for(a=0;a<t.length;a++){i=(0|this.words[a+r])+s;var l=(0|t.words[a])*e;s=((i-=67108863&l)>>26)-(l/67108864|0),this.words[a+r]=67108863&i}for(;a<this.length-r;a++)s=(i=(0|this.words[a+r])+s)>>26,this.words[a+r]=67108863&i;if(0===s)return this.strip();for(n(-1===s),s=0,a=0;a<this.length;a++)s=(i=-(0|this.words[a])+s)>>26,this.words[a]=67108863&i;return this.negative=1,this.strip()},i.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),a=t,o=0|a.words[a.length-1];0!==(r=26-this._countBits(o))&&(a=a.ushln(r),n.iushln(r),o=0|a.words[a.length-1]);var s,l=n.length-a.length;if(\"mod\"!==e){(s=new i(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(a,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[a.length+h])+(0|n.words[a.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(a,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(a,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},i.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new i(0),mod:new i(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(a=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:a,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(a=s.div.neg()),{div:a,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new i(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new i(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new i(this.modn(t.words[0]))}:this._wordDiv(t,e);var a,o,s},i.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},i.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},i.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},i.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),a=t.andln(1),i=r.cmp(n);return i<0||1===a&&0===i?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},i.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,a=this.length-1;a>=0;a--)r=(e*r+(0|this.words[a]))%t;return r},i.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var a=(0|this.words[r])+67108864*e;this.words[r]=a/t|0,e=a%t}return this.strip()},i.prototype.divn=function(t){return this.clone().idivn(t)},i.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var a=new i(1),o=new i(0),s=new i(0),l=new i(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(a.isOdd()||o.isOdd())&&(a.iadd(u),o.isub(h)),a.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),a.isub(s),o.isub(l)):(r.isub(e),s.isub(a),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},i.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var a,o=new i(1),s=new i(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(a=0===e.cmpn(1)?o:s).cmpn(0)<0&&a.iadd(t),a},i.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var a=e.cmp(r);if(a<0){var i=e;e=r,r=i}else if(0===a||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},i.prototype.invm=function(t){return this.egcd(t).a.umod(t)},i.prototype.isEven=function(){return 0==(1&this.words[0])},i.prototype.isOdd=function(){return 1==(1&this.words[0])},i.prototype.andln=function(t){return this.words[0]&t},i.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,a=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=a,this;for(var i=a,o=r;0!==i&&o<this.length;o++){var s=0|this.words[o];i=(s+=i)>>>26,s&=67108863,this.words[o]=s}return 0!==i&&(this.words[o]=i,this.length++),this},i.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},i.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var a=0|this.words[0];e=a===t?0:a<t?-1:1}return 0!==this.negative?0|-e:e},i.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},i.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],a=0|t.words[r];if(n!==a){n<a?e=-1:n>a&&(e=1);break}}return e},i.prototype.gtn=function(t){return 1===this.cmpn(t)},i.prototype.gt=function(t){return 1===this.cmp(t)},i.prototype.gten=function(t){return this.cmpn(t)>=0},i.prototype.gte=function(t){return this.cmp(t)>=0},i.prototype.ltn=function(t){return-1===this.cmpn(t)},i.prototype.lt=function(t){return-1===this.cmp(t)},i.prototype.lten=function(t){return this.cmpn(t)<=0},i.prototype.lte=function(t){return this.cmp(t)<=0},i.prototype.eqn=function(t){return 0===this.cmpn(t)},i.prototype.eq=function(t){return 0===this.cmp(t)},i.red=function(t){return new w(t)},i.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},i.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},i.prototype._forceRed=function(t){return this.red=t,this},i.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},i.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},i.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},i.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},i.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},i.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},i.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},i.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},i.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},i.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},i.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},i.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},i.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},i.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var m={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new i(e,16),this.n=this.p.bitLength(),this.k=new i(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=i._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function T(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new i(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new i(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},a(y,v),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var a=t.words[9];for(e.words[e.length++]=4194303&a,n=10;n<t.length;n++){var i=0|t.words[n];t.words[n-10]=(4194303&i)<<4|a>>>22,a=i}a>>>=22,t.words[n-10]=a,0===a&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},a(x,v),a(b,v),a(_,v),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,a=67108863&n;n>>>=26,t.words[r]=a,e=n}return 0!==e&&(t.words[t.length++]=e),t},i._prime=function(t){if(m[t])return m[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return m[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new i(1)).iushrn(2);return this.pow(t,r)}for(var a=this.m.subn(1),o=0;!a.isZero()&&0===a.andln(1);)o++,a.iushrn(1);n(!a.isZero());var s=new i(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new i(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,a),f=this.pow(t,a.addn(1).iushrn(1)),p=this.pow(t,a),d=o;0!==p.cmp(s);){for(var g=p,m=0;0!==g.cmp(s);m++)g=g.redSqr();n(m<d);var v=this.pow(h,new i(1).iushln(d-m-1));f=f.redMul(v),h=v.redSqr(),p=p.redMul(h),d=m}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new i(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new i(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var a=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;a!==r[0]&&(a=this.sqr(a)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(a=this.mul(a,r[o]),s=0,o=0)):s=0}l=26}return a},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},i.mont=function(t){return new T(t)},a(T,w),T.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},T.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},T.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),a=r.isub(n).iushrn(this.shift),i=a;return a.cmp(this.m)>=0?i=a.isub(this.m):a.cmpn(0)<0&&(i=a.iadd(this.m)),i._forceRed(this)},T.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new i(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),a=r.isub(n).iushrn(this.shift),o=a;return a.cmp(this.m)>=0?o=a.isub(this.m):a.cmpn(0)<0&&(o=a.iadd(this.m)),o._forceRed(this)},T.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:108}],100:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,a=t.length,i=0;for(e=0;e<a;++e)i+=t[e].length;var o=new Array(i),s=0;for(e=0;e<a;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return h(t);case 2:return\"function\"==typeof e?c(t,t,e,!0):f(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}};var n,a=t(\"typedarray-pool\"),i=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var a=0,i=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[a++]=c[u];n[i++]=o}}return i}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=a.mallocDouble(2*u*s),p=a.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)i.init(s),h=i.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=a.mallocDouble(2*u*c),g=a.mallocInt32(c);(c=l(e,u,d,g))>0&&(i.init(s+c),h=1===u?i.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),a.free(d),a.free(g))}a.free(f),a.free(p)}return h}}}function u(t,e){n.push([t,e])}function h(t){return n=[],c(t,t,u,!0),n}function f(t,e){return n=[],c(t,e,u,!1),n}},{\"./lib/intersect\":103,\"./lib/sweep\":107,\"typedarray-pool\":567}],102:[function(t,e,r){\"use strict\";var n=[\"d\",\"ax\",\"vv\",\"rs\",\"re\",\"rb\",\"ri\",\"bs\",\"be\",\"bb\",\"bi\"];function a(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],a=n.slice();t||a.splice(3,0,\"fp\");var i=[\"function \"+e+\"(\"+a.join()+\"){\"];function o(e,a){var o=function(t,e,r){var a=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),i=[\"function \",a,\"(\",n.join(),\"){\",\"var \",\"es\",\"=2*\",\"d\",\";\"],o=\"for(var i=rs,rp=es*rs;i<re;++i,rp+=es){var x0=rb[ax+rp],x1=rb[ax+rp+d],xi=ri[i];\",s=\"for(var j=bs,bp=es*bs;j<be;++j,bp+=es){var y0=bb[ax+bp],\"+(r?\"y1=bb[ax+bp+d],\":\"\")+\"yi=bi[j];\";return t?i.push(o,\"Q\",\":\",s):i.push(s,\"Q\",\":\",o),r?i.push(\"if(y1<x0||x1<y0)continue;\"):e?i.push(\"if(y0<=x0||x1<y0)continue;\"):i.push(\"if(y0<x0||x1<y0)continue;\"),i.push(\"for(var k=ax+1;k<d;++k){var r0=rb[k+rp],r1=rb[k+d+rp],b0=bb[k+bp],b1=bb[k+d+bp];if(r1<b0||b1<r0)continue Q;}var rv=vv(\"),e?i.push(\"yi,xi\"):i.push(\"xi,yi\"),i.push(\");if(rv!==void 0)return rv;}}}\"),{name:a,code:i.join(\"\")}}(e,a,t);r.push(o.code),i.push(\"return \"+o.name+\"(\"+n.join()+\");\")}i.push(\"if(re-rs>be-bs){\"),t?(o(!0,!1),i.push(\"}else{\"),o(!1,!1)):(i.push(\"if(fp){\"),o(!0,!0),i.push(\"}else{\"),o(!0,!1),i.push(\"}}else{if(fp){\"),o(!1,!0),i.push(\"}else{\"),o(!1,!1),i.push(\"}\")),i.push(\"}}return \"+e);var s=r.join(\"\")+i.join(\"\");return new Function(s)()}r.partial=a(!1),r.full=a(!0)},{}],103:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i,u,w,T,k,M){!function(t,e){var r=8*a.log2(e+1)*(t+1)|0,i=a.nextPow2(6*r);v.length<i&&(n.free(v),v=n.mallocInt32(i));var o=a.nextPow2(2*r);y.length<o&&(n.free(y),y=n.mallocDouble(o))}(t,i+T);var A,S=0,E=2*t;x(S++,0,0,i,0,T,r?16:0,-1/0,1/0),r||x(S++,0,0,T,0,i,1,-1/0,1/0);for(;S>0;){var C=6*(S-=1),L=v[C],P=v[C+1],I=v[C+2],z=v[C+3],O=v[C+4],D=v[C+5],R=2*S,F=y[R],B=y[R+1],N=1&D,j=!!(16&D),U=u,V=w,q=k,H=M;if(N&&(U=k,V=M,q=u,H=w),!(2&D&&(I=p(t,L,P,I,U,V,B),P>=I)||4&D&&(P=d(t,L,P,I,U,V,F))>=I)){var G=I-P,Y=O-z;if(j){if(t*G*(G+Y)<1<<22){if(void 0!==(A=l.scanComplete(t,L,e,P,I,U,V,z,O,q,H)))return A;continue}}else{if(t*Math.min(G,Y)<128){if(void 0!==(A=o(t,L,e,N,P,I,U,V,z,O,q,H)))return A;continue}if(t*G*Y<1<<22){if(void 0!==(A=l.scanBipartite(t,L,e,N,P,I,U,V,z,O,q,H)))return A;continue}}var W=h(t,L,P,I,U,V,F,B);if(P<W)if(t*(W-P)<128){if(void 0!==(A=s(t,L+1,e,P,W,U,V,z,O,q,H)))return A}else if(L===t-2){if(void 0!==(A=N?l.sweepBipartite(t,e,z,O,q,H,P,W,U,V):l.sweepBipartite(t,e,P,W,U,V,z,O,q,H)))return A}else x(S++,L+1,P,W,z,O,N,-1/0,1/0),x(S++,L+1,z,O,P,W,1^N,-1/0,1/0);if(W<I){var Z=c(t,L,z,O,q,H),X=q[E*Z+L],J=f(t,L,Z,O,q,H,X);if(J<O&&x(S++,L,W,I,J,O,(4|N)+(j?16:0),X,B),z<Z&&x(S++,L,W,I,z,Z,(2|N)+(j?16:0),F,X),Z+1===J){if(void 0!==(A=j?_(t,L,e,W,I,U,V,Z,q,H[Z]):b(t,L,e,N,W,I,U,V,Z,q,H[Z])))return A}else if(Z<J){var K;if(j){if(K=g(t,L,W,I,U,V,X),W<K){var Q=f(t,L,W,K,U,V,X);if(L===t-2){if(W<Q&&void 0!==(A=l.sweepComplete(t,e,W,Q,U,V,Z,J,q,H)))return A;if(Q<K&&void 0!==(A=l.sweepBipartite(t,e,Q,K,U,V,Z,J,q,H)))return A}else W<Q&&x(S++,L+1,W,Q,Z,J,16,-1/0,1/0),Q<K&&(x(S++,L+1,Q,K,Z,J,0,-1/0,1/0),x(S++,L+1,Z,J,Q,K,1,-1/0,1/0))}}else K=N?m(t,L,W,I,U,V,X):g(t,L,W,I,U,V,X),W<K&&(L===t-2?A=N?l.sweepBipartite(t,e,Z,J,q,H,W,K,U,V):l.sweepBipartite(t,e,W,K,U,V,Z,J,q,H):(x(S++,L+1,W,K,Z,J,N,-1/0,1/0),x(S++,L+1,Z,J,W,K,1^N,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),a=t(\"bit-twiddle\"),i=t(\"./brute\"),o=i.partial,s=i.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),f=u(\"lo===p0\",[\"p0\"]),p=u(\"lo<p0\",[\"p0\"]),d=u(\"hi<=p0\",[\"p0\"]),g=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),m=u(\"lo<p0&&p0<=hi\",[\"p0\"]),v=n.mallocInt32(1024),y=n.mallocDouble(1024);function x(t,e,r,n,a,i,o,s,l){var c=6*t;v[c]=e,v[c+1]=r,v[c+2]=n,v[c+3]=a,v[c+4]=i,v[c+5]=o;var u=2*t;y[u]=s,y[u+1]=l}function b(t,e,r,n,a,i,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=a,g=a*h;d<i;++d,g+=h){var m=o[g+e],v=o[g+e+t];if(!(p<m||v<p)&&(!n||p!==m)){for(var y,x=s[d],b=e+1;b<t;++b){m=o[g+b],v=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(v<_||w<m)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function _(t,e,r,n,a,i,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<a;++p,d+=u){var g=o[p];if(g!==c){var m=i[d+e],v=i[d+e+t];if(!(f<m||v<f)){for(var y=e+1;y<t;++y){m=i[d+y],v=i[d+y+t];var x=l[h+y],b=l[h+y+t];if(v<x||b<m)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":102,\"./median\":104,\"./partition\":105,\"./sweep\":107,\"bit-twiddle\":97,\"typedarray-pool\":567}],104:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i,o,s){if(i<=r+1)return r;var l=r,c=i,u=i+r>>>1,h=2*t,f=u,p=o[h*u+e];for(;l<c;){if(c-l<8){a(t,e,l,c,o,s),p=o[h*u+e];break}var d=c-l,g=Math.random()*d+l|0,m=o[h*g+e],v=Math.random()*d+l|0,y=o[h*v+e],x=Math.random()*d+l|0,b=o[h*x+e];m<=y?b>=y?(f=v,p=y):m>=b?(f=g,p=m):(f=x,p=b):y>=b?(f=v,p=y):b>=m?(f=g,p=m):(f=x,p=b);for(var _=h*(c-1),w=h*f,T=0;T<h;++T,++_,++w){var k=o[_];o[_]=o[w],o[w]=k}var M=s[c-1];s[c-1]=s[f],s[f]=M,f=n(t,e,l,c-1,o,s,p);for(_=h*(c-1),w=h*f,T=0;T<h;++T,++_,++w){k=o[_];o[_]=o[w],o[w]=k}M=s[c-1];if(s[c-1]=s[f],s[f]=M,u<f){for(c=f-1;l<c&&o[h*(c-1)+e]===p;)c-=1;c+=1}else{if(!(f<u))break;for(l=f+1;l<c&&o[h*l+e]===p;)l+=1}}return n(t,e,r,u,o,s,o[h*u+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]);function a(t,e,r,n,a,i){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=a[s],u=l,h=o*(l-1);u>r&&a[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=a[f];a[f]=a[p],a[p]=g}var m=i[u];i[u]=i[u-1],i[u-1]=m}}},{\"./partition\":105}],105:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),n=[];t.indexOf(\"lo\")>=0&&n.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&n.push(\"hi=e[k+o]\");return r.push(\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\".replace(\"_\",n.join()).replace(\"$\",t)),Function.apply(void 0,r)}},{}],106:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=128?n(0,e-1,t):function t(e,r,u){var h=(r-e+1)/6|0,f=e+h,p=r-h,d=e+r>>1,g=d-h,m=d+h,v=f,y=g,x=d,b=m,_=p,w=e+1,T=r-1,k=0;l(v,y,u)&&(k=v,v=y,y=k);l(b,_,u)&&(k=b,b=_,_=k);l(v,x,u)&&(k=v,v=x,x=k);l(y,x,u)&&(k=y,y=x,x=k);l(v,b,u)&&(k=v,v=b,b=k);l(x,b,u)&&(k=x,x=b,b=k);l(y,_,u)&&(k=y,y=_,_=k);l(y,x,u)&&(k=y,y=x,x=k);l(b,_,u)&&(k=b,b=_,_=k);for(var M=u[2*y],A=u[2*y+1],S=u[2*b],E=u[2*b+1],C=2*v,L=2*x,P=2*_,I=2*f,z=2*d,O=2*p,D=0;D<2;++D){var R=u[C+D],F=u[L+D],B=u[P+D];u[I+D]=R,u[z+D]=F,u[O+D]=B}i(g,e,u),i(m,r,u);for(var N=w;N<=T;++N)if(c(N,M,A,u))N!==w&&a(N,w,u),++w;else if(!c(N,S,E,u))for(;;){if(c(T,S,E,u)){c(T,M,A,u)?(o(N,w,T,u),++w,--T):(a(N,T,u),--T);break}if(--T<N)break}s(e,w-1,M,A,u),s(r,T+1,S,E,u),w-2-e<=32?n(e,w-2,u):t(e,w-2,u);r-(T+2)<=32?n(T+2,r,u):t(T+2,r,u);T-w<=32?n(w,T,u):t(w,T,u)}(0,e-1,t)};function n(t,e,r){for(var n=2*(t+1),a=t+1;a<=e;++a){for(var i=r[n++],o=r[n++],s=a,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<i)break;if(c===i&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=i,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],a=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=a}function i(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function o(t,e,r,n){e*=2,r*=2;var a=n[t*=2],i=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=a,n[r+1]=i}function s(t,e,r,n,a){e*=2,a[t*=2]=a[e],a[e]=r,a[t+1]=a[e+1],a[e+1]=n}function l(t,e,r){e*=2;var n=r[t*=2],a=r[e];return!(n<a)&&(n!==a||r[t+1]>r[e+1])}function c(t,e,r,n){var a=n[t*=2];return a<e||a===e&&n[t+1]<r}},{}],107:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=a.nextPow2(t);o.length<e&&(n.free(o),o=n.mallocInt32(e));s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));var r=8*e;f.length<r&&(n.free(f),f=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,a,u,h,g,m,v){for(var y=0,x=2*t,b=t-1,_=x-1,w=r;w<n;++w){var T=u[w],k=x*w;f[y++]=a[k+b],f[y++]=-(T+1),f[y++]=a[k+_],f[y++]=T}for(w=h;w<g;++w){T=v[w]+(1<<28);var M=x*w;f[y++]=m[M+b],f[y++]=-T,f[y++]=m[M+_],f[y++]=T}var A=y>>>1;i(f,A);var S=0,E=0;for(w=0;w<A;++w){var C=0|f[2*w+1];if(C>=1<<28)p(l,c,E--,C=C-(1<<28)|0);else if(C>=0)p(o,s,S--,C);else if(C<=-(1<<28)){C=-C-(1<<28)|0;for(var L=0;L<S;++L){if(void 0!==(P=e(o[L],C)))return P}d(l,c,E++,C)}else{C=-C-1|0;for(L=0;L<E;++L){var P;if(void 0!==(P=e(C,l[L])))return P}d(o,s,S++,C)}}},sweepComplete:function(t,e,r,n,a,g,m,v,y,x){for(var b=0,_=2*t,w=t-1,T=_-1,k=r;k<n;++k){var M=g[k]+1<<1,A=_*k;f[b++]=a[A+w],f[b++]=-M,f[b++]=a[A+T],f[b++]=M}for(k=m;k<v;++k){M=x[k]+1<<1;var S=_*k;f[b++]=y[S+w],f[b++]=1|-M,f[b++]=y[S+T],f[b++]=1|M}var E=b>>>1;i(f,E);var C=0,L=0,P=0;for(k=0;k<E;++k){var I=0|f[2*k+1],z=1&I;if(k<E-1&&I>>1==f[2*k+3]>>1&&(z=2,k+=1),I<0){for(var O=-(I>>1)-1,D=0;D<P;++D){if(void 0!==(R=e(u[D],O)))return R}if(0!==z)for(D=0;D<C;++D){if(void 0!==(R=e(o[D],O)))return R}if(1!==z)for(D=0;D<L;++D){var R;if(void 0!==(R=e(l[D],O)))return R}0===z?d(o,s,C++,O):1===z?d(l,c,L++,O):2===z&&d(u,h,P++,O)}else{O=(I>>1)-1;0===z?p(o,s,C--,O):1===z?p(l,c,L--,O):2===z&&p(u,h,P--,O)}}},scanBipartite:function(t,e,r,n,a,l,c,u,h,g,m,v){var y=0,x=2*t,b=e,_=e+t,w=1,T=1;n?T=1<<28:w=1<<28;for(var k=a;k<l;++k){var M=k+w,A=x*k;f[y++]=c[A+b],f[y++]=-M,f[y++]=c[A+_],f[y++]=M}for(k=h;k<g;++k){M=k+T;var S=x*k;f[y++]=m[S+b],f[y++]=-M}var E=y>>>1;i(f,E);var C=0;for(k=0;k<E;++k){var L=0|f[2*k+1];if(L<0){var P=!1;if((M=-L)>=1<<28?(P=!n,M-=1<<28):(P=!!n,M-=1),P)d(o,s,C++,M);else{var I=v[M],z=x*M,O=m[z+e+1],D=m[z+e+1+t];t:for(var R=0;R<C;++R){var F=o[R],B=x*F;if(!(D<c[B+e+1]||c[B+e+1+t]<O)){for(var N=e+2;N<t;++N)if(m[z+N+t]<c[B+N]||c[B+N+t]<m[z+N])continue t;var j,U=u[F];if(void 0!==(j=n?r(I,U):r(U,I)))return j}}}}else p(o,s,C--,L-w)}},scanComplete:function(t,e,r,n,a,s,l,c,u,h,p){for(var d=0,g=2*t,m=e,v=e+t,y=n;y<a;++y){var x=y+(1<<28),b=g*y;f[d++]=s[b+m],f[d++]=-x,f[d++]=s[b+v],f[d++]=x}for(y=c;y<u;++y){x=y+1;var _=g*y;f[d++]=h[_+m],f[d++]=-x}var w=d>>>1;i(f,w);var T=0;for(y=0;y<w;++y){var k=0|f[2*y+1];if(k<0){if((x=-k)>=1<<28)o[T++]=x-(1<<28);else{var M=p[x-=1],A=g*x,S=h[A+e+1],E=h[A+e+1+t];t:for(var C=0;C<T;++C){var L=o[C],P=l[L];if(P===M)break;var I=g*L;if(!(E<s[I+e+1]||s[I+e+1+t]<S)){for(var z=e+2;z<t;++z)if(h[A+z+t]<s[I+z]||s[I+z+t]<h[A+z])continue t;var O=r(P,M);if(void 0!==O)return O}}}}else{for(x=k-(1<<28),C=T-1;C>=0;--C)if(o[C]===x){for(z=C+1;z<T;++z)o[z-1]=o[z];break}--T}}}};var n=t(\"typedarray-pool\"),a=t(\"bit-twiddle\"),i=t(\"./sort\"),o=n.mallocInt32(1024),s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocDouble(8192);function p(t,e,r,n){var a=e[n],i=t[r-1];t[a]=i,e[i]=a}function d(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":106,\"bit-twiddle\":97,\"typedarray-pool\":567}],108:[function(t,e,r){},{}],109:[function(t,e,r){arguments[4][108][0].apply(r,arguments)},{dup:108}],110:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},a=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},i=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r){if(e)t.call(r);else for(var n=t.length,a=_(t,n),i=0;i<n;++i)a[i].call(r)}function f(t,e,r,n){if(e)t.call(r,n);else for(var a=t.length,i=_(t,a),o=0;o<a;++o)i[o].call(r,n)}function p(t,e,r,n,a){if(e)t.call(r,n,a);else for(var i=t.length,o=_(t,i),s=0;s<i;++s)o[s].call(r,n,a)}function d(t,e,r,n,a,i){if(e)t.call(r,n,a,i);else for(var o=t.length,s=_(t,o),l=0;l<o;++l)s[l].call(r,n,a,i)}function g(t,e,r,n){if(e)t.apply(r,n);else for(var a=t.length,i=_(t,a),o=0;o<a;++o)i[o].apply(r,n)}function m(t,e,r,a){var i,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=a?[r,s]:[s,r]:a?s.unshift(r):s.push(r),!s.warned&&(i=u(t))&&i>0&&s.length>i){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function v(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function y(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},a=i.call(v,n);return a.listener=r,n.wrapFn=a,a}function x(t,e,r){var n=t._events;if(!n)return[];var a=n[e];return a?\"function\"==typeof a?r?[a.listener||a]:[a]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(a):_(a,a.length):[]}function b(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function _(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,a,i,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:h(r,c,this);break;case 2:f(r,c,this,arguments[1]);break;case 3:p(r,c,this,arguments[1],arguments[2]);break;case 4:d(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(a=new Array(n-1),i=1;i<n;i++)a[i-1]=arguments[i];g(r,c,this,a)}return!0},o.prototype.addListener=function(t,e){return m(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return m(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,y(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,y(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,a,i,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(a=this._events))return this;if(!(r=a[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete a[t],a.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,i=o;break}if(i<0)return this;0===i?r.shift():function(t,e){for(var r=e,n=r+1,a=t.length;n<a;r+=1,n+=1)t[r]=t[n];t.pop()}(r,i),1===r.length&&(a[t]=r[0]),a.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,i;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=a(r);for(i=0;i<s.length;++i)\"removeListener\"!==(o=s[i])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(i=e.length-1;i>=0;i--)this.removeListener(t,e[i]);return this},o.prototype.listeners=function(t){return x(this,t,!0)},o.prototype.rawListeners=function(t){return x(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):b.call(t,e)},o.prototype.listenerCount=b,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],111:[function(t,e,r){(function(e){\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "\"use strict\";var n=t(\"base64-js\"),a=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;function i(t){if(t>2147483647)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return l(t)}return o(t,e,r)}function o(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|h(t,r),a=i(n),o=a.write(t,r);o!==n&&(a=a.slice(0,o));return a}(t,r);if(ArrayBuffer.isView(t))return c(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(B(t,ArrayBuffer)||t&&B(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var a;a=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return a.__proto__=e.prototype,a}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var a=t.valueOf&&t.valueOf();if(null!=a&&a!==t)return e.from(a,r,n);var o=function(t){if(e.isBuffer(t)){var r=0|u(t.length),n=i(r);return 0===n.length||t.copy(n,0,0,r),n}if(void 0!==t.length)return\"number\"!=typeof t.length||N(t.length)?i(0):c(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return c(t.data)}(t);if(o)return o;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function s(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function l(t){return s(t),i(t<0?0:0|u(t))}function c(t){for(var e=t.length<0?0:0|u(t.length),r=i(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function u(t){if(t>=2147483647)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+2147483647..toString(16)+\" bytes\");return 0|t}function h(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||B(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,a=arguments.length>2&&!0===arguments[2];if(!a&&0===n)return 0;for(var i=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return D(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return R(t).length;default:if(i)return a?-1:D(t).length;r=(\"\"+r).toLowerCase(),i=!0}}function f(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return A(this,e,r);case\"utf8\":case\"utf-8\":return T(this,e,r);case\"ascii\":return k(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return S(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,a,i){if(0===t.length)return-1;if(\"string\"==typeof n?(a=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),N(n=+n)&&(n=i?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(i)return-1;n=t.length-1}else if(n<0){if(!i)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,a)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,a,i);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,a,i);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,a){var i,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(a){var u=-1;for(i=r;i<s;i++)if(c(t,i)===c(e,-1===u?0:i-u)){if(-1===u&&(u=i),i-u+1===l)return u*o}else-1!==u&&(i-=i-u),u=-1}else for(r+l>s&&(r=s-l),i=r;i>=0;i--){for(var h=!0,f=0;f<l;f++)if(c(t,i+f)!==c(e,f)){h=!1;break}if(h)return i}return-1}function m(t,e,r,n){r=Number(r)||0;var a=t.length-r;n?(n=Number(n))>a&&(n=a):n=a;var i=e.length;n>i/2&&(n=i/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(N(s))return o;t[r+o]=s}return o}function v(t,e,r,n){return F(D(e,t.length-r),t,r,n)}function y(t,e,r,n){return F(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return F(R(e),t,r,n)}function _(t,e,r,n){return F(function(t,e){for(var r,n,a,i=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,a=r%256,i.push(a),i.push(n);return i}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],a=e;a<r;){var i,o,s,l,c=t[a],u=null,h=c>239?4:c>223?3:c>191?2:1;if(a+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(i=t[a+1]))&&(l=(31&c)<<6|63&i)>127&&(u=l);break;case 3:i=t[a+1],o=t[a+2],128==(192&i)&&128==(192&o)&&(l=(15&c)<<12|(63&i)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:i=t[a+1],o=t[a+2],s=t[a+3],128==(192&i)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&i)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),a+=h}return function(t){var e=t.length;if(e<=4096)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=4096));return r}(n)}r.kMaxLength=2147483647,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return o(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?i(t):void 0!==e?\"string\"==typeof r?i(t).fill(e,r):i(t).fill(e):i(t)}(t,e,r)},e.allocUnsafe=function(t){return l(t)},e.allocUnsafeSlow=function(t){return l(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(B(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),B(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,a=r.length,i=0,o=Math.min(n,a);i<o;++i)if(t[i]!==r[i]){n=t[i],a=r[i];break}return n<a?-1:a<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var a=e.allocUnsafe(r),i=0;for(n=0;n<t.length;++n){var o=t[n];if(B(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(a,i),i+=o.length}return a},e.byteLength=h,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?T(this,0,t):f.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,a,i){if(B(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===a&&(a=0),void 0===i&&(i=this.length),r<0||n>t.length||a<0||i>this.length)throw new RangeError(\"out of range index\");if(a>=i&&r>=n)return 0;if(a>=i)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(a>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(a,i),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var a=this.length-e;if((void 0===r||r>a)&&(r=a),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var i=!1;;)switch(n){case\"hex\":return m(this,t,e,r);case\"utf8\":case\"utf-8\":return v(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(i)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),i=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};function k(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(127&t[a]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(t[a]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var a=\"\",i=e;i<r;++i)a+=O(t[i]);return a}function S(t,e,r){for(var n=t.slice(e,r),a=\"\",i=0;i<n.length;i+=2)a+=String.fromCharCode(n[i]+256*n[i+1]);return a}function E(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function C(t,r,n,a,i,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>i||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+a>t.length)throw new RangeError(\"Index out of range\")}function L(t,e,r,n,a,i){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i){return e=+e,r>>>=0,i||L(t,0,r,4),a.write(t,e,r,n,23,4),r+4}function I(t,e,r,n,i){return e=+e,r>>>=0,i||L(t,0,r,8),a.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var a=this.subarray(t,r);return a.__proto__=e.prototype,a},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],a=1,i=0;++i<e&&(a*=256);)n+=this[t+i]*a;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t+--e],a=1;e>0&&(a*=256);)n+=this[t+--e]*a;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],a=1,i=0;++i<e&&(a*=256);)n+=this[t+i]*a;return n>=(a*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=e,a=1,i=this[t+--n];n>0&&(a*=256);)i+=this[t+--n]*a;return i>=(a*=128)&&(i-=Math.pow(2,8*e)),i},e.prototype.readInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||E(t,4,this.length),a.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||E(t,4,this.length),a.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||E(t,8,this.length),a.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||E(t,8,this.length),a.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var a=1,i=0;for(this[e]=255&t;++i<r&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var a=r-1,i=1;for(this[e+a]=255&t;--a>=0&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);C(this,t,e,r,a-1,-a)}var i=0,o=1,s=0;for(this[e]=255&t;++i<r&&(o*=256);)t<0&&0===s&&0!==this[e+i-1]&&(s=1),this[e+i]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);C(this,t,e,r,a-1,-a)}var i=r-1,o=1,s=0;for(this[e+i]=255&t;--i>=0&&(o*=256);)t<0&&0===s&&0!==this[e+i+1]&&(s=1),this[e+i]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return P(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return P(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return I(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return I(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,a){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),a||0===a||(a=this.length),r>=t.length&&(r=t.length),r||(r=0),a>0&&a<n&&(a=n),a===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(a<0)throw new RangeError(\"sourceEnd out of bounds\");a>this.length&&(a=this.length),t.length-r<a-n&&(a=t.length-r+n);var i=a-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,a);else if(this===t&&n<r&&r<a)for(var o=i-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,a),r);return i},e.prototype.fill=function(t,r,n,a){if(\"string\"==typeof t){if(\"string\"==typeof r?(a=r,r=0,n=this.length):\"string\"==typeof n&&(a=n,n=this.length),void 0!==a&&\"string\"!=typeof a)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof a&&!e.isEncoding(a))throw new TypeError(\"Unknown encoding: \"+a);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===a&&i<128||\"latin1\"===a)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,a),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var z=/[^+/0-9A-Za-z-_]/g;function O(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function D(t,e){var r;e=e||1/0;for(var n=t.length,a=null,i=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!a){if(r>56319){(e-=3)>-1&&i.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&i.push(239,191,189);continue}a=r;continue}if(r<56320){(e-=3)>-1&&i.push(239,191,189),a=r;continue}r=65536+(a-55296<<10|r-56320)}else a&&(e-=3)>-1&&i.push(239,191,189);if(a=null,r<128){if((e-=1)<0)break;i.push(r)}else if(r<2048){if((e-=2)<0)break;i.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;i.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;i.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return i}function R(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(z,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function F(t,e,r,n){for(var a=0;a<n&&!(a+r>=e.length||a>=t.length);++a)e[a+r]=t[a];return a}function B(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function N(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":79,buffer:111,ieee754:416}],112:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),a=t(\"./lib/triangulation\"),i=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=a(t.length,function(t){return t.map(s).sort(l)}(e)),m=0;m<d.length;++m){var v=d[m];g.addTriangle(v[0],v[1],v[2])}return u&&i(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":113,\"./lib/filter\":114,\"./lib/monotone\":115,\"./lib/triangulation\":116}],113:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function a(t,e,r,a,i,o){var s=e.opposite(a,i);if(!(s<0)){if(i<a){var l=a;a=i,i=l,l=o,o=s,s=l}e.isConstraint(a,i)||n(t[a],t[i],t[o],t[s])<0&&r.push(a,i)}}e.exports=function(t,e){for(var r=[],i=t.length,o=e.stars,s=0;s<i;++s)for(var l=o[s],c=1;c<l.length;c+=2){if(!((p=l[c])<s)&&!e.isConstraint(s,p)){for(var u=l[c-1],h=-1,f=1;f<l.length;f+=2)if(l[f-1]===p){h=l[f];break}h<0||n(t[s],t[p],t[u],t[h])<0&&r.push(s,p)}}for(;r.length>0;){for(var p=r.pop(),d=(s=r.pop(),u=-1,h=-1,l=o[s],1);d<l.length;d+=2){var g=l[d-1],m=l[d];g===p?h=m:m===p&&(u=g)}u<0||h<0||(n(t[s],t[p],t[u],t[h])>=0||(e.flip(s,p),a(t,e,r,u,s,h),a(t,e,r,s,h,u),a(t,e,r,h,p,u),a(t,e,r,p,u,h)))}}},{\"binary-search-bounds\":96,\"robust-in-sphere\":518}],114:[function(t,e,r){\"use strict\";var n,a=t(\"binary-search-bounds\");function i(t,e,r,n,a,i,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=a,this.next=i,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,a=0;a<n;++a){var s=(v=r[a])[0],l=v[1],c=v[2];l<c?l<s&&(v[0]=l,v[1]=c,v[2]=s):c<s&&(v[0]=c,v[1]=s,v[2]=l)}r.sort(o);var u=new Array(n);for(a=0;a<u.length;++a)u[a]=0;var h=[],f=[],p=new Array(3*n),d=new Array(3*n),g=null;e&&(g=[]);var m=new i(r,p,d,u,h,f,g);for(a=0;a<n;++a)for(var v=r[a],y=0;y<3;++y){s=v[y],l=v[(y+1)%3];var x=p[3*a+y]=m.locate(l,s,t.opposite(l,s)),b=d[3*a+y]=t.isConstraint(s,l);x<0&&(b?f.push(a):(h.push(a),u[a]=1),e&&g.push([l,s,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var a=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-a){c[p]=a;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=a))}}}var m=l;l=s,s=m,l.length=0,a=-a}var v=function(t,e,r){for(var n=0,a=0;a<t.length;++a)e[a]===r&&(t[n++]=t[a]);return t.length=n,t}(u,c,e);if(r)return v.concat(n.boundary);return v},i.prototype.locate=(n=[0,0,0],function(t,e,r){var i=t,s=e,l=r;return e<r?e<t&&(i=e,s=r,l=t):r<t&&(i=r,s=t,l=e),i<0?-1:(n[0]=i,n[1]=s,n[2]=l,a.eq(this.cells,n,o))})},{\"binary-search-bounds\":96}],115:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),a=t(\"robust-orientation\")[3];function i(t,e,r,n,a){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=a}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=a(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return a(t.a,t.b,e)}function c(t,e,r,i,o){for(var s=n.lt(e,i,l),c=n.gt(e,i,l),u=s;u<c;++u){for(var h=e[u],f=h.lowerIds,p=f.length;p>1&&a(r[f[p-2]],r[f[p-1]],i)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=h.upperIds;for(p=d.length;p>1&&a(r[d[p-2]],r[d[p-1]],i)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?a(t.a,t.b,e.a):a(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?a(t.a,t.b,e.b):a(e.b,e.a,t.b))||t.idx-e.idx}function h(t,e,r){var a=n.le(t,r,u),o=t[a],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(a+1,0,new i(r.a,r.b,r.idx,[l],s))}function f(t,e,r){var a=r.a;r.a=r.b,r.b=a;var i=n.eq(t,r,u),o=t[i];t[i-1].upperIds=o.upperIds,t.splice(i,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,a=[],l=0;l<r;++l)a.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?a.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&a.push(new o(d,p,2,l),new o(p,d,1,l))}a.sort(s);for(var g=a[0].a[0]-(1+Math.abs(a[0].a[0]))*Math.pow(2,-52),m=[new i([g,1],[g,0],-1,[],[],[],[])],v=[],y=(l=0,a.length);l<y;++l){var x=a[l],b=x.type;0===b?c(v,m,t,x.a,x.idx):2===b?h(m,t,x):f(m,t,x)}return v}},{\"binary-search-bounds\":96,\"robust-orientation\":520}],116:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function a(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new a(r,e)};var i=a.prototype;function o(t,e,r){for(var n=1,a=t.length;n<a;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[a-2],t[n]=t[a-1],void(t.length=a-2)}i.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,a){return t[0]=Math.min(r,a),t[1]=Math.max(r,a),n.eq(this.edges,t,e)>=0}}(),i.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},i.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},i.opposite=function(t,e){for(var r=this.stars[e],n=1,a=r.length;n<a;n+=2)if(r[n]===t)return r[n-1];return-1},i.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},i.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;i+=2)e.push([a[i],a[i+1]]);return e},i.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;i+=2){var s=a[i],l=a[i+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":96}],117:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],118:[function(t,e,r){\"use strict\";var n=t(\"dup\"),a=t(\"robust-linear-solve\");function i(t,e){for(var r=0,n=t.length,a=0;a<n;++a)r+=t[a]*e[a];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*i(t[s],t[l]);o[s]=i(t[s],t[s])}var c=a(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),a=o(t),i=0;i<t.length;++i)for(var s=0;s<e;++s)r[s]+=t[i][s]*a[i];return r}s.barycenetric=o,e.exports=s},{dup:176,\"robust-linear-solve\":519}],119:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,a=0;a<t.length;++a)for(var i=t[a],o=0;o<e.length;++o)r+=Math.pow(i[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:118}],120:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],121:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var a=new Array(e.length),i=0;i<e.length;++i){var o=e[i];a[i]=[o[0],o[1],r[i]]}e=a}var s=function(t,e,r){var n=d(t,[],p(t));return v(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(i=0;i<e.length;++i){o=e[i];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),a=t(\"box-intersect\"),i=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var i=e.length,o=new n(i),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}a(s,(function(t,e){o.link(t,e)}));var d=!0,g=new Array(i);for(l=0;l<i;++l){(v=o.find(l))!==l&&(d=!1,t[v]=[Math.min(t[l][0],t[v][0]),Math.min(t[l][1],t[v][1])])}if(d)return null;var m=0;for(l=0;l<i;++l){var v;(v=o.find(l))===l?(g[l]=m,t[m++]=t[l]):g[l]=-1}t.length=m;for(l=0;l<i;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function m(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function v(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var a=e[(o=t[n])[0]],i=e[o[1]];o[0]=Math.min(a,i),o[1]=Math.max(a,i)}else for(n=0;n<t.length;++n){var o;a=(o=t[n])[0],i=o[1];o[0]=Math.min(a,i),o[1]=Math.max(a,i)}r?t.sort(m):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var a=e[n],i=t[a[0]],o=t[a[1]];r[n]=[u(Math.min(i[0],o[0]),-1/0),u(Math.min(i[1],o[1]),-1/0),u(Math.max(i[0],o[0]),1/0),u(Math.max(i[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return a(r,(function(r,a){var o=e[r],s=e[a];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];i(l,c,u,h)&&n.push([r,a])}})),n}(t,e,n),g=p(t),m=function(t,e,r,n){var o=[];return a(r,n,(function(r,n){var a=e[r];if(a[0]!==n&&a[1]!==n){var s=t[n],l=t[a[0]],c=t[a[1]];i(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,g),y=d(t,function(t,e,r,n,a){var i,u,f=t.map((function(t){return[o(t[0]),o(t[1])]}));for(i=0;i<r.length;++i){var p=r[i];u=p[0];var d=p[1],g=e[u],m=e[d],v=h(c(t[g[0]]),c(t[g[1]]),c(t[m[0]]),c(t[m[1]]));if(v){var y=t.length;t.push([l(v[0]),l(v[1])]),f.push(v),n.push([u,y],[d,y])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),i=n.length-1;i>=0;--i){var x=e[u=(S=n[i])[0]],b=x[0],_=x[1],w=t[b],T=t[_];if((w[0]-T[0]||w[1]-T[1])<0){var k=b;b=_,_=k}x[0]=b;var M,A=x[1]=S[1];for(a&&(M=x[2]);i>0&&n[i-1][0]===u;){var S,E=(S=n[--i])[1];a?e.push([A,E,M]):e.push([A,E]),A=E}a?e.push([A,_,M]):e.push([A,_])}return f}(t,e,f,m,r));return v(e,y,r),!!y||(f.length>0||m.length>0)}},{\"./lib/rat-seg-intersect\":122,\"big-rat\":83,\"big-rat/cmp\":81,\"big-rat/to-float\":95,\"box-intersect\":101,nextafter:470,\"rat-vec\":504,\"robust-segment-intersect\":523,\"union-find\":568}],122:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=s(e,t),h=s(n,r),f=u(i,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=a(d,f),m=c(i,g);return l(t,m)};var n=t(\"big-rat/mul\"),a=t(\"big-rat/div\"),i=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return i(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":82,\"big-rat/mul\":92,\"big-rat/sign\":93,\"big-rat/sub\":94,\"rat-vec/add\":503,\"rat-vec/muls\":505,\"rat-vec/sub\":506}],123:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function a(t,e){null==e&&(e=!0);var r=t[0],a=t[1],i=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,a*=255,i*=255,o*=255),16777216*(r=255&n(r,0,255))+((a=255&n(a,0,255))<<16)+((i=255&n(i,0,255))<<8)+(o=255&n(o,0,255))}e.exports=a,e.exports.to=a,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,a=(65280&t)>>>8,i=255&t;return!1===e?[r,n,a,i]:[r/255,n/255,a/255,i/255]}},{clamp:120}],124:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],125:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),i=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,i&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(i?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=Math.min(Math.max(Math.floor(255*t[0]),0),255),r[1]=Math.min(Math.max(Math.floor(255*t[1]),0),255),r[2]=Math.min(Math.max(Math.floor(255*t[2]),0),255),r[3]=null==t[3]?255:Math.min(Math.max(Math.floor(255*t[3]),0),255)),r)}},{\"color-rgba\":126,dtype:175}],126:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),a=t(\"color-space/hsl\");e.exports=function(t){var e;Array.isArray(t)&&t.raw&&(t=String.raw.apply(null,arguments));var r=n(t);return r.space?((e=Array(3))[0]=Math.min(Math.max(r.values[0],0),255),e[1]=Math.min(Math.max(r.values[1],0),255),e[2]=Math.min(Math.max(r.values[2],0),255),\"h\"===r.space[0]&&(e=a.rgb(e)),e.push(Math.min(Math.max(r.alpha,0),1)),e):[]}},{\"color-parse\":127,\"color-space/hsl\":128}],127:[function(t,e,r){\"use strict\";var n=t(\"color-name\");e.exports=function(t){var e,r,i=[],o=1;if(\"string\"==typeof t)if(n[t])i=n[t].slice(),r=\"rgb\";else if(\"transparent\"===t)o=0,r=\"rgb\",i=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var s=(u=t.slice(1)).length;o=1,s<=4?(i=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===s&&(o=parseInt(u[3]+u[3],16)/255)):(i=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===s&&(o=parseInt(u[6]+u[7],16)/255)),i[0]||(i[0]=0),i[1]||(i[1]=0),i[2]||(i[2]=0),r=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var l=e[1],c=\"rgb\"===l,u=l.replace(/a$/,\"\");r=u;s=\"cmyk\"===u?4:\"gray\"===u?1:3;i=e[2].trim().split(/\\s*[,\\/]\\s*|\\s+/).map((function(t,e){if(/%$/.test(t))return e===s?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==a[t])return a[t]}return parseFloat(t)})),l===u&&i.push(1),o=c||void 0===i[s]?1:i[s],i=i.slice(0,s)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(i=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),r=t.match(/([a-z])/gi).join(\"\").toLowerCase());else isNaN(t)?Array.isArray(t)||t.length?(i=[t[0],t[1],t[2]],r=\"rgb\",o=4===t.length?t[3]:1):t instanceof Object&&(null!=t.r||null!=t.red||null!=t.R?(r=\"rgb\",i=[t.r||t.red||t.R||0,t.g||t.green||t.G||0,t.b||t.blue||t.B||0]):(r=\"hsl\",i=[t.h||t.hue||t.H||0,t.s||t.saturation||t.S||0,t.l||t.lightness||t.L||t.b||t.brightness]),o=t.a||t.alpha||t.opacity||1,null!=t.opacity&&(o/=100)):(r=\"rgb\",i=[t>>>16,(65280&t)>>>8,255&t]);return{space:r,values:i,alpha:o}};var a={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}},{\"color-name\":124}],128:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,a,i,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[i=255*l,i,i];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),a=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,i=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,a[c]=255*i;return a}},n.hsl=function(t){var e,r,n=t[0]/255,a=t[1]/255,i=t[2]/255,o=Math.min(n,a,i),s=Math.max(n,a,i),l=s-o;return s===o?e=0:n===s?e=(a-i)/l:a===s?e=2+(i-n)/l:i===s&&(e=4+(n-a)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":129}],129:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],130:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],131:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),a=t(\"lerp\");function i(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var m=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),v=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=m[g],l=m[g+1];for(var y=0;y<c;y++){var x=y/c;v.push([Math.round(a(r[0],l[0],x)),Math.round(a(r[1],l[1],x)),Math.round(a(r[2],l[2],x)),a(r[3],l[3],x)])}}v.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?v=v.map(o):\"rgbaString\"===f?v=v.map(s):\"float\"===f&&(v=v.map(i));return v}},{\"./colorScale\":130,lerp:446}],132:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var o=n(e,r,i);if(0===o){var s=a(n(t,e,r)),c=a(n(t,e,i));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,i);return u===h?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,i)?-1:1:0===s?c>0||l(t,e,r)?1:-1:a(c-s)}var f=n(t,e,r);return f>0?o>0&&n(t,e,i)>0?1:-1:f<0?o>0||n(t,e,i)>0?1:-1:n(t,e,i)>0||l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),a=t(\"signum\"),i=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=i(t[0],-e[0]),a=i(t[1],-e[1]),l=i(r[0],-e[0]),c=i(r[1],-e[1]),u=s(o(n,l),o(a,c));return u[u.length-1]>=0}},{\"robust-orientation\":520,\"robust-product\":521,\"robust-sum\":525,signum:526,\"two-sum\":555}],133:[function(t,e,r){e.exports=function(t,e){var r=t.length,i=t.length-e.length;if(i)return i;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(i=o+t[2]-(s+e[2]))return i;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],m=e[2],v=e[3];return u+h+f+p-(d+g+m+v)||n(u,h,f,p)-n(d,g,m,v,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+m,d+v,g+m,g+v,m+v)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+m,d+g+v,d+m+v,g+m+v);default:for(var y=t.slice().sort(a),x=e.slice().sort(a),b=0;b<r;++b)if(i=y[b]-x[b])return i;return 0}};var n=Math.min;function a(t,e){return t-e}},{}],134:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),a=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||a(t)-a(e)}},{\"cell-orientation\":117,\"compare-cell\":133}],135:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),a=t(\"./lib/ch2d\"),i=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return a(t);return i(t,r)}},{\"./lib/ch1d\":136,\"./lib/ch2d\":137,\"./lib/chnd\":138}],136:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],137:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var a=new Array(r),i=e[r-1],o=0;o<r;++o){var s=e[o];a[o]=[i,s],i=s}return a};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":456}],138:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(o){var r=a(t);if(r.length<=e)return[];var i=function(t,e){for(var r=t.length,n=new Array(r),a=0;a<e.length;++a)n[a]=t[e[a]];var i=e.length;for(a=0;a<r;++a)e.indexOf(a)<0&&(n[i++]=t[a]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,a=0;a<r;++a)for(var i=t[a],o=0;o<i.length;++o){var s=i[o];if(s<n)i[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);i[o]=s}}return t}(n(i,!0),r)}};var n=t(\"incremental-convex-hull\"),a=t(\"affine-hull\")},{\"affine-hull\":67,\"incremental-convex-hull\":433}],139:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],140:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],141:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],142:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],143:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],144:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":146,\"./stringify\":147}],145:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":140}],146:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),a=t(\"css-global-keywords\"),i=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==i.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==a.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"string-split-by\":540,unquote:570}],147:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),a=t(\"./lib/util\").isSize,i=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!i[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!a)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map((function(t){return h[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"pick-by-alias\":485}],148:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],149:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],150:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a,i){var o=a-1,s=a*a,l=o*o,c=(1+2*a)*l,u=a*l,h=s*(3-2*a),f=s*o;if(t.length){i||(i=new Array(t.length));for(var p=t.length-1;p>=0;--p)i[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return i}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,a,i){var o=6*a*a-6*a,s=3*a*a-4*a+1,l=-6*a*a+6*a,c=3*a*a-2*a;if(t.length){i||(i=new Array(t.length));for(var u=t.length-1;u>=0;--u)i[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return i}return o*t+s*e+l*r[u]+c*n}},{}],151:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function a(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new a;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var i=0;i<r.length;++i){var o=r[i];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[i]=\"array\",e.arrayArgs.push(i),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+i),i<e.pre.args.length&&e.pre.args[i].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(i<e.post.args.length&&e.post.args[i].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(i),e.shimArgs.push(\"scalar\"+i);else if(\"index\"===o){if(e.indexArgs.push(i),i<e.pre.args.length&&e.pre.args[i].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(i<e.body.args.length&&e.body.args[i].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(i<e.post.args.length&&e.post.args[i].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(i),i<e.pre.args.length&&e.pre.args[i].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(i<e.body.args.length&&e.body.args[i].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(i<e.post.args.length&&e.post.args[i].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[i]);e.argTypes[i]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(i)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":153}],152:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function a(t,e,r){var n,a,i=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<i;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(a=0;a<o;++a)for(n=0;n<i;++n)h=u,u=t[n],0===n?c.push([\"d\",a,\"s\",n,\"=t\",a,\"p\",u].join(\"\")):c.push([\"d\",a,\"s\",n,\"=(t\",a,\"p\",u,\"-s\",h,\"*t\",a,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=i-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<i;++n){for(h=u,u=t[n],a=0;a<o;++a)l.push([\"p\",a,\"+=d\",a,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function i(t,e,r){for(var n=t.body,a=[],i=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(a.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),i.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(a.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&i.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(a.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&i.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],m=0;m<Math.abs(e.arrayBlockIndices[u]);m++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(m+1)+\"*t\"+u+\"b\"+m);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[a.join(\"\\n\"),n,i.join(\"\\n\")].join(\"\\n\").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var a=t[n],i=a.match(/\\d+/);i=i?i[0]:\"\",0===a.charAt(0)?e[n]=\"u\"+a.charAt(1)+i:e[n]=a.charAt(0)+i,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],h=[],f=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(f.push(0),p.push(r),u.push(r),h.push(r+t.arrayBlockIndices[c])):(f.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),h.push(t.arrayBlockIndices[c]));for(var g=[],m=0;m<s[c].length;m++)f[c]<=s[c][m]&&s[c][m]<p[c]&&g.push(s[c][m]-f[c]);d.push(g)}var v=[\"SS\"],y=[\"'use strict'\"],x=[];for(m=0;m<r;++m)x.push([\"s\",m,\"=SS[\",m,\"]\"].join(\"\"));for(c=0;c<t.arrayArgs.length;++c){v.push(\"a\"+c),v.push(\"t\"+c),v.push(\"p\"+c);for(m=0;m<r;++m)x.push([\"t\",c,\"p\",m,\"=t\",c,\"[\",f[c]+m,\"]\"].join(\"\"));for(m=0;m<Math.abs(t.arrayBlockIndices[c]);++m)x.push([\"t\",c,\"b\",m,\"=t\",c,\"[\",u[c]+m,\"]\"].join(\"\"))}for(c=0;c<t.scalarArgs.length;++c)v.push(\"Y\"+c);if(t.shapeArgs.length>0&&x.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]=\"0\";x.push([\"index=[\",b.join(\",\"),\"]\"].join(\"\"))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(m=0;m<_.offset.length;++m)0!==_.offset[m]&&(1===_.offset[m]?w.push([\"t\",_.array,\"p\",m].join(\"\")):w.push([_.offset[m],\"*t\",_.array,\"p\",m].join(\"\")));0===w.length?x.push(\"q\"+c+\"=0\"):x.push([\"q\",c,\"=\",w.join(\"+\")].join(\"\"))}var T=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(T)).length>0&&y.push(\"var \"+x.join(\",\")),c=0;c<t.arrayArgs.length;++c)y.push(\"p\"+c+\"|=0\");t.pre.body.length>3&&y.push(i(t.pre,t,l));var k=i(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var i=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<i;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<i;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(a(e,r,n)),u=t;u<i;++u)c.push(\"}\");return c.join(\"\\n\")}(M,d[0],t,k)):y.push(a(d[0],t,k)),t.post.body.length>3&&y.push(i(t.post,t,l)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+y.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",s[0].join(\"s\"),\"m\",M,o(l)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",y.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:569}],153:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],a=t.funcName+\"_cwise_thunk\";e.push([\"return function \",a,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var i=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),i.push(\"t\"+h),i.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",i.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":152}],154:[function(t,e,r){\"use strict\";var n,a=t(\"type/value/is\"),i=t(\"type/value/ensure\"),o=t(\"type/plain-function/ensure\"),s=t(\"es5-ext/object/copy\"),l=t(\"es5-ext/object/normalize-options\"),c=t(\"es5-ext/object/map\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=i(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=l(arguments[1]);return a(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},{\"es5-ext/object/copy\":196,\"es5-ext/object/map\":204,\"es5-ext/object/normalize-options\":205,\"type/plain-function/ensure\":561,\"type/value/ensure\":565,\"type/value/is\":566}],155:[function(t,e,r){\"use strict\";var n=t(\"type/value/is\"),a=t(\"type/plain-function/is\"),i=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/normalize-options\"),s=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),a=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,a=!1),u={value:e,configurable:r,enumerable:a,writable:l},c?i(o(c),u):u}).gs=function(t,e,r){var l,c,u,h;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?a(e)?n(r)?a(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),h={get:e,set:r,configurable:l,enumerable:c},u?i(o(u),h):h}},{\"es5-ext/object/assign\":193,\"es5-ext/object/normalize-options\":205,\"es5-ext/string/#/contains\":212,\"type/plain-function/is\":562,\"type/value/is\":566}],156:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,a){for(null==n&&(n=0),null==a&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)<0?n=i+1:a=i}return n},right:function(e,r,n,a){for(null==n&&(n=0),null==a&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)>0?a=i:n=i+1}return n}}}var n=r(e),a=n.right,i=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,a=t.length,i=0,o=-1,l=0,c=0;if(null==e)for(;++o<a;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++i)));else for(;++o<a;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++i)));if(i>1)return c/(i-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,a,i=t.length,o=-1;if(null==e){for(;++o<i;)if(null!=(r=t[o])&&r>=r)for(n=a=r;++o<i;)null!=(r=t[o])&&(n>r&&(n=r),a<r&&(a=r))}else for(;++o<i;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=a=r;++o<i;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),a<r&&(a=r));return[n,a]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function m(t,e,r){t=+t,e=+e,r=(a=arguments.length)<2?(e=t,t=0,1):a<3?1:+r;for(var n=-1,a=0|Math.max(0,Math.ceil((e-t)/r)),i=new Array(a);++n<a;)i[n]=t+n*r;return i}var v=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),a=Math.floor(Math.log(n)/Math.LN10),i=n/Math.pow(10,a);return a>=0?(i>=v?10:i>=y?5:i>=x?2:1)*Math.pow(10,a):-Math.pow(10,-a)/(i>=v?10:i>=y?5:i>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),a=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),i=n/a;return i>=v?a*=10:i>=y?a*=5:i>=x&&(a*=2),e<t?-a:a}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function T(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,a=(n-1)*e,i=Math.floor(a),o=+r(t[i],i,t);return o+(+r(t[i+1],i+1,t)-o)*(a-i)}}function k(t,e){var r,n,a=t.length,i=-1;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r)for(n=r;++i<a;)null!=(r=t[i])&&n>r&&(n=r)}else for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r)for(n=r;++i<a;)null!=(r=e(t[i],i,t))&&n>r&&(n=r);return n}function M(t){if(!(a=t.length))return[];for(var e=-1,r=k(t,A),n=new Array(r);++e<r;)for(var a,i=-1,o=n[e]=new Array(a);++i<a;)o[i]=t[i][e];return n}function A(t){return t.length}t.bisect=a,t.bisectRight=a,t.bisectLeft=i,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,a,i,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=i=0;n<l;++n)for(s=t[n],a=0;a<c;++a,++i)u[i]=r(s,e[a]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var i,o,s=n.length,l=new Array(s);for(i=0;i<s;++i)l[i]=t(n[i],i,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=m(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(i=0;i<=p;++i)(d=g[i]=[]).x0=i>0?f[i-1]:u,d.x1=i<p?f[i]:h;for(i=0;i<s;++i)u<=(o=l[i])&&o<=h&&g[a(f,o,0,p)].push(n[i]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(T(t,.75)-T(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,a=t.length,i=-1;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r)for(n=r;++i<a;)null!=(r=t[i])&&r>n&&(n=r)}else for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r)for(n=r;++i<a;)null!=(r=e(t[i],i,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,a=n,i=-1,o=0;if(null==e)for(;++i<n;)isNaN(r=s(t[i]))?--a:o+=r;else for(;++i<n;)isNaN(r=s(e(t[i],i,t)))?--a:o+=r;if(a)return o/a},t.median=function(t,r){var n,a=t.length,i=-1,o=[];if(null==r)for(;++i<a;)isNaN(n=s(t[i]))||o.push(n);else for(;++i<a;)isNaN(n=s(r(t[i],i,t)))||o.push(n);return T(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,a=t.length,i=-1,o=0;++i<a;)o+=t[i].length;for(r=new Array(o);--a>=0;)for(e=(n=t[a]).length;--e>=0;)r[--o]=n[e];return r},t.min=k,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,a=t[0],i=new Array(n<0?0:n);r<n;)i[r]=e(a,a=t[++r]);return i},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=T,t.range=m,t.scan=function(t,r){if(n=t.length){var n,a,i=0,o=0,s=t[o];for(null==r&&(r=e);++i<n;)(r(a=t[i],s)<0||0!==r(s,s))&&(s=a,o=i);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,a,i=(null==r?t.length:r)-(e=null==e?0:+e);i;)a=Math.random()*i--|0,n=t[i+e],t[i+e]=t[a+e],t[a+e]=n;return t},t.sum=function(t,e){var r,n=t.length,a=-1,i=0;if(null==e)for(;++a<n;)(r=+t[a])&&(i+=r);else for(;++a<n;)(r=+e(t[a],a,t))&&(i+=r);return i},t.ticks=function(t,e,r){var n,a,i,o,s=-1;if(r=+r,(t=+t)===(e=+e)&&r>0)return[t];if((n=e<t)&&(a=t,t=e,e=a),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),i=new Array(a=Math.ceil(e-t+1));++s<a;)i[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),i=new Array(a=Math.ceil(t-e+1));++s<a;)i[s]=(t-s)/o;return n&&i.reverse(),i},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],157:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each((function(t,e){n.set(e,t)}));else if(Array.isArray(t)){var a,i=-1,o=t.length;if(null==r)for(;++i<o;)n.set(i,t[i]);else for(;++i<o;)n.set(r(a=t[i],i,t),a)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function a(t,e,r){t[e]=r}function i(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each((function(t){r.add(t)}));else if(t){var n=-1,a=t.length;if(null==e)for(;++n<a;)r.add(t[n]);else for(;++n<a;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,a,i,o){if(a>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[a++],g=r(),m=i();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each((function(t,e){o(m,e,u(t,a,i,o))})),m}return s={object:function(t){return u(t,0,n,a)},map:function(t){return u(t,0,i,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var a,i=c[n-1];return null!=e&&n>=l.length?a=r.entries():(a=[],r.each((function(e,r){a.push({key:r,values:t(e,n)})}))),null!=i?a.sort((function(t,e){return i(t.key,e.key)})):a}(u(t,0,i,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],158:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var a=\"\\\\s*([+-]?\\\\d+)\\\\s*\",i=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3,8})$/,l=new RegExp(\"^rgb\\\\(\"+[a,a,a]+\"\\\\)$\"),c=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),u=new RegExp(\"^rgba\\\\(\"+[a,a,a,i]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[o,o,o,i]+\"\\\\)$\"),f=new RegExp(\"^hsl\\\\(\"+[i,o,o]+\"\\\\)$\"),p=new RegExp(\"^hsla\\\\(\"+[i,o,o,i]+\"\\\\)$\"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function g(){return this.rgb().formatHex()}function m(){return this.rgb().formatRgb()}function v(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?x(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?x(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=h.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=f.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):\"transparent\"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=v(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function T(){return\"#\"+M(this.r)+M(this.g)+M(this.b)}function k(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new C(t,e,r,n)}function S(t){if(t instanceof C)return new C(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new C;if(t instanceof C)return t;var e=(t=t.rgb()).r/255,r=t.g/255,a=t.b/255,i=Math.min(e,r,a),o=Math.max(e,r,a),s=NaN,l=o-i,c=(o+i)/2;return l?(s=e===o?(r-a)/l+6*(r<a):r===o?(a-e)/l+2:(e-r)/l+4,l/=c<.5?o+i:2-o-i,s*=60):l=c>0&&c<1?0:s,new C(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new C(t,e,r,null==n?1:n)}function C(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function L(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:g,formatHex:g,formatHsl:function(){return S(this).formatHsl()},formatRgb:m,toString:m}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:T,formatHex:T,formatRgb:k,toString:k})),e(C,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new C(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new C(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,a=2*r-n;return new w(L(t>=240?t-240:t+120,a,n),L(t,a,n),L(t<120?t+240:t-120,a,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"hsl(\":\"hsla(\")+(this.h||0)+\", \"+100*(this.s||0)+\"%, \"+100*(this.l||0)+\"%\"+(1===t?\")\":\", \"+t+\")\")}}));var P=Math.PI/180,I=180/Math.PI,z=6/29,O=3*z*z;function D(t){if(t instanceof F)return new F(t.l,t.a,t.b,t.opacity);if(t instanceof H)return G(t);t instanceof w||(t=b(t));var e,r,n=U(t.r),a=U(t.g),i=U(t.b),o=B((.2225045*n+.7168786*a+.0606169*i)/1);return n===a&&a===i?e=r=o:(e=B((.4360747*n+.3850649*a+.1430804*i)/.96422),r=B((.0139322*n+.0971045*a+.7141733*i)/.82521)),new F(116*o-16,500*(e-o),200*(o-r),t.opacity)}function R(t,e,r,n){return 1===arguments.length?D(t):new F(t,e,r,null==n?1:n)}function F(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function B(t){return t>.008856451679035631?Math.pow(t,1/3):t/O+4/29}function N(t){return t>z?t*t*t:O*(t-4/29)}function j(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function V(t){if(t instanceof H)return new H(t.h,t.c,t.l,t.opacity);if(t instanceof F||(t=D(t)),0===t.a&&0===t.b)return new H(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*I;return new H(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function q(t,e,r,n){return 1===arguments.length?V(t):new H(t,e,r,null==n?1:n)}function H(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function G(t){if(isNaN(t.h))return new F(t.l,0,0,t.opacity);var e=t.h*P;return new F(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(F,R,r(n,{brighter:function(t){return new F(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new F(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(j(3.1338561*(e=.96422*N(e))-1.6168667*(t=1*N(t))-.4906146*(r=.82521*N(r))),j(-.9787684*e+1.9161415*t+.033454*r),j(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(H,q,r(n,{brighter:function(t){return new H(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new H(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return G(this).rgb()}}));var Y=-.14861,W=1.78277,Z=-.29227,X=-.90649,J=1.97294,K=J*X,Q=J*W,$=W*Z-X*Y;function tt(t){if(t instanceof rt)return new rt(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,a=($*n+K*e-Q*r)/($+K-Q),i=n-a,o=(J*(r-a)-Z*i)/X,s=Math.sqrt(o*o+i*i)/(J*a*(1-a)),l=s?Math.atan2(o,i)*I-120:NaN;return new rt(l<0?l+360:l,s,a,t.opacity)}function et(t,e,r,n){return 1===arguments.length?tt(t):new rt(t,e,r,null==n?1:n)}function rt(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(rt,et,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*P,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),a=Math.sin(t);return new w(255*(e+r*(Y*n+W*a)),255*(e+r*(Z*n+X*a)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.cubehelix=et,t.gray=function(t,e){return new F(t,0,0,null==e?1:e)},t.hcl=q,t.hsl=E,t.lab=R,t.lch=function(t,e,r,n){return 1===arguments.length?V(t):new H(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],159:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,a={};e<r;++e){if(!(t=arguments[e]+\"\")||t in a||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);a[t]=[]}return new n(a)}function n(t){this._=t}function a(t,e){return t.trim().split(/^|\\s+/).map((function(t){var r=\"\",n=t.indexOf(\".\");if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t&&!e.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:r}}))}function i(t,e){for(var r,n=0,a=t.length;n<a;++n)if((r=t[n]).name===e)return r.value}function o(t,r,n){for(var a=0,i=t.length;a<i;++a)if(t[a].name===r){t[a]=e,t=t.slice(0,a).concat(t.slice(a+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n=this._,s=a(t+\"\",n),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)n[r]=o(n[r],t.name,e);else if(null==e)for(r in n)n[r]=o(n[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(n[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,a=new Array(r),i=0;i<r;++i)a[i]=arguments[i+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(i=0,r=(n=this._[t]).length;i<r;++i)n[i].value.apply(e,a)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],a=0,i=n.length;a<i;++a)n[a].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],160:[function(t,e,r){!function(n,a){\"object\"==typeof r&&\"undefined\"!=typeof e?a(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)}(this,(function(t,e,r,n,a){\"use strict\";function i(t){return function(){return t}}function o(){return 1e-6*(Math.random()-.5)}function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,a,i=r.length,o=0,s=0;for(n=0;n<i;++n)o+=(a=r[n]).x,s+=a.y;for(o=o/i-t,s=s/i-e,n=0;n<i;++n)(a=r[n]).x-=o,a.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,a=1,c=1;function u(){for(var t,i,u,f,p,d,g,m=r.length,v=0;v<c;++v)for(i=e.quadtree(r,s,l).visitAfter(h),t=0;t<m;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,i.visit(y);function y(t,e,r,n,i){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||i<p-c;if(s.index>u.index){var h=f-s.x-s.vx,m=p-s.y-s.vy,v=h*h+m*m;v<c*c&&(0===h&&(v+=(h=o())*h),0===m&&(v+=(m=o())*m),v=(c-(v=Math.sqrt(v)))/v*a,u.vx+=(h*=v)*(c=(l*=l)/(g+l)),u.vy+=(m*=v)*c,s.vx-=h*(c=1-c),s.vy-=m*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,a,i=r.length;for(n=new Array(i),e=0;e<i;++e)a=r[e],n[a.index]=+t(a,e,r)}}return\"function\"!=typeof t&&(t=i(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(a=+t,u):a},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),f(),u):t},u},t.forceLink=function(t){var e,n,a,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=i(30),d=1;function g(r){for(var a=0,i=t.length;a<d;++a)for(var s,c,u,h,f,p,g,m=0;m<i;++m)c=(s=t[m]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[m])/p*r*e[m],f*=p,u.vx-=h*(g=l[m]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function m(){if(a){var i,o,c=a.length,f=t.length,p=r.map(a,h);for(i=0,s=new Array(c);i<f;++i)(o=t[i]).index=i,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(i=0,l=new Array(f);i<f;++i)o=t[i],l[i]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),v(),n=new Array(f),y()}}function v(){if(a)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(a)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){a=t,m()},g.links=function(e){return arguments.length?(t=e,m(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:i(+t),v(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:i(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,a,s=i(-30),l=1,c=1/0,u=.81;function p(a){var i,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=a,i=0;i<o;++i)r=t[i],s.visit(m)}function d(){if(t){var e,r,n=t.length;for(a=new Array(n),e=0;e<n;++e)r=t[e],a[r.index]=+s(r,e,t)}}function g(t){var e,r,n,i,o,s=0,l=0;if(t.length){for(n=i=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,i+=r*e.y);t.x=n/l,t.y=i/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=a[e.data.index]}while(e=e.next)}t.value=s}function m(t,e,i,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=a[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:i(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,a,o,s=i(.1);function l(t){for(var i=0,s=n.length;i<s;++i){var l=n[i],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[i]-h)*a[i]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(a=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),a[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=i(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:i(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,i=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=a.timer(d),f=n.dispatch(\"tick\",\"end\");function d(){g(),f.call(\"tick\",e),i<o&&(h.stop(),f.call(\"end\",e))}function g(r){var n,a,o=t.length;void 0===r&&(r=1);for(var h=0;h<r;++h)for(i+=(l-i)*s,u.each((function(t){t(i)})),n=0;n<o;++n)null==(a=t[n]).fx?a.x+=a.vx*=c:(a.x=a.fx,a.vx=0),null==a.fy?a.y+=a.vy*=c:(a.y=a.fy,a.vy=0);return e}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var a=10*Math.sqrt(r),i=r*p;e.x=a*Math.cos(i),e.y=a*Math.sin(i)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function v(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:g,restart:function(){return h.restart(d),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(v),e):t},alpha:function(t){return arguments.length?(i=+t,e):i},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,v(r)),e):u.get(t)},find:function(e,r,n){var a,i,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(a=e-(s=t[c]).x)*a+(i=r-s.y)*i)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,a=i(.1);function o(t){for(var a,i=0,o=e.length;i<o;++i)(a=e[i]).vx+=(n[i]-a.x)*r[i]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return\"function\"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a=\"function\"==typeof t?t:i(+t),s(),o):a},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,a=i(.1);function o(t){for(var a,i=0,o=e.length;i<o;++i)(a=e[i]).vy+=(n[i]-a.y)*r[i]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return\"function\"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a=\"function\"==typeof t?t:i(+t),s(),o):a},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:i(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-collection\":157,\"d3-dispatch\":159,\"d3-quadtree\":164,\"d3-timer\":168}],161:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function a(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function i(t,e){var r,n,a,i,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(a=e(r.data))&&(s=a.length))for(r.children=new Array(s),i=s-1;i>=0;--i)f.push(n=r.children[i]=new c(a[i])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=i.prototype={constructor:c,count:function(){return this.eachAfter(a)},each:function(t){var e,r,n,a,i=this,o=[i];do{for(e=o.reverse(),o=[];i=e.pop();)if(t(i),r=i.children)for(n=0,a=r.length;n<a;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,a=this,i=[a],o=[];a=i.pop();)if(o.push(a),e=a.children)for(r=0,n=e.length;r<n;++r)i.push(e[r]);for(;a=o.pop();)t(a);return this},eachBefore:function(t){for(var e,r,n=this,a=[n];n=a.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)a.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,a=n&&n.length;--a>=0;)r+=n[a].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),a=null;t=r.pop(),e=n.pop();for(;t===e;)a=t,t=r.pop(),e=n.pop();return a}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var a=n.length;t!==r;)n.splice(a,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return i(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,a=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,i=[];n<a;)e=t[n],r&&d(r,e)?++n:(r=m(i=f(i,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(v(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(v(t[r],t[n]),e)&&p(v(t[r],e),t[n])&&p(v(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,a=e.y-t.y;return r<0||r*r<n*n+a*a}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,a=e.y-t.y;return r>0&&r*r>n*n+a*a}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function m(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return v(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function v(t,e){var r=t.x,n=t.y,a=t.r,i=e.x,o=e.y,s=e.r,l=i-r,c=o-n,u=s-a,h=Math.sqrt(l*l+c*c);return{x:(r+i+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+a+s)/2}}function y(t,e,r){var n=t.x,a=t.y,i=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=a-s,g=a-u,m=l-i,v=h-i,y=n*n+a*a-i*i,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,T=(g*m-d*v)/_,k=(p*x-f*b)/(2*_)-a,M=(f*v-p*m)/_,A=T*T+M*M-1,S=2*(i+w*T+k*M),E=w*w+k*k-i*i,C=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+T*C,y:a+k+M*C,r:C}}function x(t,e,r){var n,a,i,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(a=e.r+r.r,a*=a,o=t.r+r.r,a>(o*=o)?(n=(c+o-a)/(2*c),i=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-i*l,r.y=t.y-n*l+i*s):(n=(c+a-o)/(2*c),i=Math.sqrt(Math.max(0,a/c-n*n)),r.x=e.x+n*s-i*l,r.y=e.y+n*l+i*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,a=e.y-t.y;return r>0&&r*r>n*n+a*a}function _(t){var e=t._,r=t.next._,n=e.r+r.r,a=(e.x*r.r+r.x*e.r)/n,i=(e.y*r.r+r.y*e.r)/n;return a*a+i*i}function w(t){this._=t,this.next=null,this.previous=null}function T(t){if(!(a=t.length))return 0;var e,r,n,a,i,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(a>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(a>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<a;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,i=_(e);(n=n.next)!==r;)(o=_(n))<i&&(e=n,i=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<a;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function k(t){return null==t?null:M(t)}function M(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function S(t){return function(){return t}}function E(t){return Math.sqrt(t.value)}function C(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,a,i,o=n.length,s=t(r)*e||0;if(s)for(a=0;a<o;++a)n[a].r+=s;if(i=T(n),s)for(a=0;a<o;++a)n[a].r-=s;r.r=i+s}}}function P(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function I(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function z(t,e,r,n,a){for(var i,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(i=o[s]).y0=r,i.y1=a,i.x0=e,i.x1=e+=i.value*c}var O={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,a){for(var i,o=t.children,s=-1,l=o.length,c=t.value&&(a-r)/t.value;++s<l;)(i=o[s]).x0=e,i.x1=n,i.y0=r,i.y1=r+=i.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,a,i){for(var o,s,l,c,u,h,f,p,d,g,m,v=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=a-r,c=i-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,m=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/m,m/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),m=u*u*g,(p=Math.max(f/m,m/h))>d){u-=s;break}d=p}v.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?z(o,r,n,a,w?n+=c*u/w:i):H(o,r,n,w?r+=l*u/w:a,i),w-=u,x=b}return v}var W=function t(e){function r(t,r,n,a,i){Y(e,t,r,n,a,i)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var Z=function t(e){function r(t,r,n,a,i){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?z(s,r,n,a,n+=(i-n)*s.value/p):H(s,r,n,r+=(a-r)*s.value/p,i),p-=s.value}else t._squarify=o=Y(e,t,r,n,a,i),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,a=1,i=1,o=!1;function s(e){var s,l=0;e.eachAfter((function(e){var a=e.children;a?(e.x=function(t){return t.reduce(r,0)/t.length}(a),e.y=function(t){return 1+t.reduce(n,0)}(a)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*a,t.y=(e.y-t.y)*i}:function(t){t.x=(t.x-h)/(f-h)*a,t.y=(1-(e.y?t.y/e.y:1))*i})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,a=+t[0],i=+t[1],s):o?null:[a,i]},s.nodeSize=function(t){return arguments.length?(o=!0,a=+t[0],i=+t[1],s):o?[a,i]:null},s},t.hierarchy=i,t.pack=function(){var t=null,e=1,r=1,n=A;function a(a){return a.x=e/2,a.y=r/2,t?a.eachBefore(C(t)).eachAfter(L(n,.5)).eachBefore(P(1)):a.eachBefore(C(E)).eachAfter(L(A,1)).eachAfter(L(n,a.r/Math.min(e,r))).eachBefore(P(Math.min(e,r)/(2*a.r))),a}return a.radius=function(e){return arguments.length?(t=k(e),a):t},a.size=function(t){return arguments.length?(e=+t[0],r=+t[1],a):[e,r]},a.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:S(+t),a):n},a},t.packEnclose=h,t.packSiblings=function(t){return T(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function a(a){var i=a.height+1;return a.x0=a.y0=r,a.x1=t,a.y1=e/i,a.eachBefore(function(t,e){return function(n){n.children&&z(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var a=n.x0,i=n.y0,o=n.x1-r,s=n.y1-r;o<a&&(a=o=(a+o)/2),s<i&&(i=s=(i+s)/2),n.x0=a,n.y0=i,n.x1=o,n.y1=s}}(e,i)),n&&a.eachBefore(I),a}return a.round=function(t){return arguments.length?(n=!!t,a):n},a.size=function(r){return arguments.length?(t=+r[0],e=+r[1],a):[t,e]},a.padding=function(t){return arguments.length?(r=+t,a):r},a},t.stratify=function(){var t=R,e=F;function r(r){var n,a,i,o,s,u,h,f=r.length,p=new Array(f),d={};for(a=0;a<f;++a)n=r[a],s=p[a]=new c(n),null!=(u=t(n,a,r))&&(u+=\"\")&&(d[h=\"$\"+(s.id=u)]=h in d?D:s);for(a=0;a<f;++a)if(s=p[a],null!=(u=e(r[a],a,r))&&(u+=\"\")){if(!(o=d[\"$\"+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(i)throw new Error(\"multiple roots\");i=s}if(!i)throw new Error(\"no root\");if(i.parent=O,i.eachBefore((function(t){t.depth=t.parent.depth+1,--f})).eachBefore(l),i.parent=null,f>0)throw new Error(\"cycle\");return i}return r.id=function(e){return arguments.length?(t=M(e),r):t},r.parentId=function(t){return arguments.length?(e=M(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function a(a){var l=function(t){for(var e,r,n,a,i,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(i=n.length),a=i-1;a>=0;--a)s.push(r=e.children[a]=new q(n[a],a)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(a);if(l.eachAfter(i),l.parent.m=-l.z,l.eachBefore(o),n)a.eachBefore(s);else{var c=a,u=a,h=a;a.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)}));var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);a.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*g}))}return a}function i(e){var r=e.children,n=e.parent.children,a=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,a=t.children,i=a.length;--i>=0;)(e=a[i]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var i=(r[0].z+r[r.length-1].z)/2;a?(e.z=a.z+t(e._,a._),e.m=e.z-i):e.z=i}else a&&(e.z=a.z+t(e._,a._));e.parent.A=function(e,r,n){if(r){for(var a,i=e,o=e,s=r,l=i.parent.children[0],c=i.m,u=o.m,h=s.m,f=l.m;s=j(s),i=N(i),s&&i;)l=N(l),(o=j(o)).a=e,(a=s.z+h-i.z-c+t(s._,i._))>0&&(U(V(s,e,n),e,a),c+=a,u+=a),h+=s.m,c+=i.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),i&&!N(l)&&(l.t=i,l.m+=c-f,n=e)}return n}(e,a,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return a.separation=function(e){return arguments.length?(t=e,a):t},a.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],a):n?null:[e,r]},a.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],a):n?[e,r]:null},a},t.treemap=function(){var t=W,e=!1,r=1,n=1,a=[0],i=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),a=[0],e&&t.eachBefore(I),t}function h(e){var r=a[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=a[e.depth+1]=i(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=M(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(i=\"function\"==typeof t?t:S(+t),u):i},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:S(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:S(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:S(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:S(+t),u):c},u},t.treemapBinary=function(t,e,r,n,a){var i,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=i=0;i<l;++i)c[i+1]=o+=s[i].value;!function t(e,r,n,a,i,o,l){if(e>=r-1){var u=s[e];return u.x0=a,u.y0=i,u.x1=o,void(u.y1=l)}var h=c[e],f=n/2+h,p=e+1,d=r-1;for(;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var m=c[p]-h,v=n-m;if(o-a>l-i){var y=(a*v+o*m)/n;t(e,p,m,a,i,y,l),t(p,r,v,y,i,o,l)}else{var x=(i*v+l*m)/n;t(e,p,m,a,i,o,x),t(p,r,v,a,x,o,l)}}(0,l,t.value,e,r,n,a)},t.treemapDice=z,t.treemapResquarify=Z,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,a){(1&t.depth?H:z)(t,e,r,n,a)},t.treemapSquarify=W,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],162:[function(t,e,r){!function(n,a){\"object\"==typeof r&&\"undefined\"!=typeof e?a(r,t(\"d3-color\")):a((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t,e,r,n,a){var i=t*t,o=i*t;return((1-3*t+3*i-o)*e+(4-6*i+3*o)*r+(1+3*t+3*i-3*o)*n+o*a)/6}function n(t){var e=t.length-1;return function(n){var a=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),i=t[a],o=t[a+1],s=a>0?t[a-1]:2*i-o,l=a<e-1?t[a+2]:2*o-i;return r((n-a/e)*e,s,i,o,l)}}function a(t){var e=t.length;return function(n){var a=Math.floor(((n%=1)<0?++n:n)*e),i=t[(a+e-1)%e],o=t[a%e],s=t[(a+1)%e],l=t[(a+2)%e];return r((n-a/e)*e,i,o,s,l)}}function i(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):i(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):i(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):i(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function a(t,r){var a=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),i=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=a(e),t.g=i(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return a.gamma=t,a}(1);function h(t){return function(r){var n,a,i=r.length,o=new Array(i),s=new Array(i),l=new Array(i);for(n=0;n<i;++n)a=e.rgb(r[n]),o[n]=a.r||0,s[n]=a.g||0,l[n]=a.b||0;return o=t(o),s=t(s),l=t(l),a.opacity=1,function(t){return a.r=o(t),a.g=s(t),a.b=l(t),a+\"\"}}}var f=h(n),p=h(a);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,a=e.slice();return function(i){for(r=0;r<n;++r)a[r]=t[r]*(1-i)+e[r]*i;return a}}function g(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function m(t,e){var r,n=e?e.length:0,a=t?Math.min(n,t.length):0,i=new Array(a),o=new Array(n);for(r=0;r<a;++r)i[r]=T(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<a;++r)o[r]=i[r](t);return o}}function v(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},a={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=T(t[r],e[r]):a[r]=e[r];return function(t){for(r in n)a[r]=n[r](t);return a}}var b=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,_=new RegExp(b.source,\"g\");function w(t,e){var r,n,a,i=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=b.exec(t))&&(n=_.exec(e));)(a=n.index)>i&&(a=e.slice(i,a),s[o]?s[o]+=a:s[++o]=a),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),i=_.lastIndex;return i<e.length&&(a=e.slice(i),s[o]?s[o]+=a:s[++o]=a),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function T(t,r){var n,a=typeof r;return null==r||\"boolean\"===a?i(r):(\"number\"===a?y:\"string\"===a?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?v:g(r)?d:Array.isArray(r)?m:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var k,M,A,S,E=180/Math.PI,C={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function L(t,e,r,n,a,i){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:a,translateY:i,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function P(t,e,r,n){function a(t){return t.length?t.pop()+\" \":\"\"}return function(i,o){var s=[],l=[];return i=t(i),o=t(o),function(t,n,a,i,o,s){if(t!==a||n!==i){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:y(t,a)},{i:l-2,x:y(n,i)})}else(a||i)&&o.push(\"translate(\"+a+e+i+r)}(i.translateX,i.translateY,o.translateX,o.translateY,s,l),function(t,e,r,i){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),i.push({i:r.push(a(r)+\"rotate(\",null,n)-2,x:y(t,e)})):e&&r.push(a(r)+\"rotate(\"+e+n)}(i.rotate,o.rotate,s,l),function(t,e,r,i){t!==e?i.push({i:r.push(a(r)+\"skewX(\",null,n)-2,x:y(t,e)}):e&&r.push(a(r)+\"skewX(\"+e+n)}(i.skewX,o.skewX,s,l),function(t,e,r,n,i,o){if(t!==r||e!==n){var s=i.push(a(i)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||i.push(a(i)+\"scale(\"+r+\",\"+n+\")\")}(i.scaleX,i.scaleY,o.scaleX,o.scaleY,s,l),i=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var I=P((function(t){return\"none\"===t?C:(k||(k=document.createElement(\"DIV\"),M=document.documentElement,A=document.defaultView),k.style.transform=t,t=A.getComputedStyle(M.appendChild(k),null).getPropertyValue(\"transform\"),M.removeChild(k),L(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}),\"px, \",\"px)\",\"deg)\"),z=P((function(t){return null==t?C:(S||(S=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),S.setAttribute(\"transform\",t),(t=S.transform.baseVal.consolidate())?L((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):C)}),\", \",\")\",\")\"),O=Math.SQRT2;function D(t){return((t=Math.exp(t))+1/t)/2}function R(t){return function(r,n){var a=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),i=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=a(t),r.s=i(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var F=R(s),B=R(c);function N(t){return function(r,n){var a=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),i=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=a(t),r.c=i(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var j=N(s),U=N(c);function V(t){return function r(n){function a(r,a){var i=t((r=e.cubehelix(r)).h,(a=e.cubehelix(a)).h),o=c(r.s,a.s),s=c(r.l,a.l),l=c(r.opacity,a.opacity);return function(t){return r.h=i(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,a.gamma=r,a}(1)}var q=V(s),H=V(c);t.interpolate=T,t.interpolateArray=function(t,e){return(g(e)?d:m)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=a,t.interpolateCubehelix=q,t.interpolateCubehelixLong=H,t.interpolateDate=v,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=j,t.interpolateHclLong=U,t.interpolateHsl=F,t.interpolateHslLong=B,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),a=c(t.a,r.a),i=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=a(e),t.b=i(e),t.opacity=o(e),t+\"\"}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=I,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,a=t[0],i=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-a,h=l-i,f=u*u+h*h;if(f<1e-12)n=Math.log(c/o)/O,r=function(t){return[a+t*u,i+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/O,r=function(t){var e,r=t*n,s=D(m),l=o/(2*p)*(s*(e=O*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[a+l*u,i+l*h,o*s/D(O*r+m)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,a=e[0],i=new Array(n<0?0:n);r<n;)i[r]=t(a,a=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return i[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-color\":158}],163:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function a(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function i(){return new a}a.prototype=i.prototype={constructor:a,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,a,i){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+a)+\",\"+(this._y1=+i)},arcTo:function(t,r,n,a,i){t=+t,r=+r,n=+n,a=+a,i=+i;var o=this._x1,s=this._y1,l=n-t,c=a-r,u=o-t,h=s-r,f=u*u+h*h;if(i<0)throw new Error(\"negative radius: \"+i);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&i){var p=n-o,d=a-s,g=l*l+c*c,m=p*p+d*d,v=Math.sqrt(g),y=Math.sqrt(f),x=i*Math.tan((e-Math.acos((g+f-m)/(2*v*y)))/2),b=x/y,_=x/v;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+i+\",\"+i+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,a,i,o,s,l){t=+t,a=+a,l=!!l;var c=(i=+i)*Math.cos(o),u=i*Math.sin(o),h=t+c,f=a+u,p=1^l,d=l?o-s:s-o;if(i<0)throw new Error(\"negative radius: \"+i);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),i&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+i+\",\"+i+\",0,1,\"+p+\",\"+(t-c)+\",\"+(a-u)+\"A\"+i+\",\"+i+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+i+\",\"+i+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+i*Math.cos(s))+\",\"+(this._y1=a+i*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=i,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],164:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var a,i,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,m=t._y0,v=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(i=(g+v)/2))?g=i:v=i,(u=r>=(o=(m+y)/2))?m=o:y=o,a=p,!(p=p[h=u<<1|c]))return a[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,a?a[h]=d:t._root=d,t;do{a=a?a[h]=new Array(4):t._root=new Array(4),(c=e>=(i=(g+v)/2))?g=i:v=i,(u=r>=(o=(m+y)/2))?m=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=i));return a[f]=p,a[h]=d,t}function r(t,e,r,n,a){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=a}function n(t){return t[0]}function a(t){return t[1]}function i(t,e,r){var i=new o(null==e?n:e,null==r?a:r,NaN,NaN,NaN,NaN);return null==t?i:i.addAll(t)}function o(t,e,r,n,a,i){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=a,this._y1=i,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=i.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var a=0;a<4;++a)(e=n.source[a])&&(e.length?t.push({source:e,target:n.target[a]=new Array(4)}):n.target[a]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,a,i,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(a=+this._x.call(null,r=t[n]))||isNaN(i=+this._y.call(null,r))||(s[n]=a,l[n]=i,a<c&&(c=a),a>h&&(h=a),i<u&&(u=i),i>f&&(f=i));if(c>h||u>f)return this;for(this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,a=this._x1,i=this._y1;if(isNaN(r))a=(r=Math.floor(t))+1,i=(n=Math.floor(e))+1;else{for(var o,s,l=a-r,c=this._root;r>t||t>=a||n>e||e>=i;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:a=r+l,i=n+l;break;case 1:r=a-l,i=n+l;break;case 2:a=r+l,n=i-l;break;case 3:r=a-l,n=i-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=a,this._y1=i,this},l.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var a,i,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],m=this._root;for(m&&g.push(new r(m,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(m=c.node)||(i=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(m.length){var v=(i+s)/2,y=(o+l)/2;g.push(new r(m[3],v,y,s,l),new r(m[2],i,y,v,l),new r(m[1],v,o,s,y),new r(m[0],i,o,v,y)),(u=(e>=y)<<1|t>=v)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,m.data),b=e-+this._y.call(null,m.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,a=m.data}}return a},l.remove=function(t){if(isNaN(i=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,a,i,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,m=this._x1,v=this._y1;if(!p)return this;if(p.length)for(;;){if((c=i>=(s=(d+m)/2))?d=s:m=s,(u=o>=(l=(g+v)/2))?g=l:v=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(a=p.next)&&delete p.next,n?(a?n.next=a:delete n.next,this):e?(a?e[h]=a:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=a,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},l.visit=function(t){var e,n,a,i,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,a=e.x0,i=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(a+o)/2,h=(i+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,a,h,u,s)),(n=c[1])&&l.push(new r(n,u,i,o,h)),(n=c[0])&&l.push(new r(n,a,i,u,h))}return this},l.visitAfter=function(t){var e,n=[],a=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var i=e.node;if(i.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=i[0])&&n.push(new r(o,s,l,h,f)),(o=i[1])&&n.push(new r(o,h,l,c,f)),(o=i[2])&&n.push(new r(o,s,f,h,u)),(o=i[3])&&n.push(new r(o,h,f,c,u))}a.push(e)}for(;e=a.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=i,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],165:[function(t,e,r){!function(n,a){\"object\"==typeof r&&\"undefined\"!=typeof e?a(r,t(\"d3-path\")):a((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,a=Math.atan2,i=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=Math.PI,h=u/2,f=2*u;function p(t){return t>1?0:t<-1?u:Math.acos(t)}function d(t){return t>=1?h:t<=-1?-h:Math.asin(t)}function g(t){return t.innerRadius}function m(t){return t.outerRadius}function v(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,a,i,o,s){var l=r-t,c=n-e,u=o-a,h=s-i,f=h*l-u*c;if(!(f*f<1e-12))return[t+(f=(u*(e-i)-h*(t-a))/f)*l,e+f*c]}function _(t,e,r,n,a,i,s){var l=t-r,u=e-n,h=(s?i:-i)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,m=r+f,v=n+p,y=(d+m)/2,x=(g+v)/2,b=m-d,_=v-g,w=b*b+_*_,T=a-i,k=d*v-m*g,M=(_<0?-1:1)*c(o(0,T*T*w-k*k)),A=(k*_-b*M)/w,S=(-k*b-_*M)/w,E=(k*_+b*M)/w,C=(-k*b+_*M)/w,L=A-y,P=S-x,I=E-y,z=C-x;return L*L+P*P>I*I+z*z&&(A=E,S=C),{cx:A,cy:S,x01:-f,y01:-p,x11:A*(a/T-1),y11:S*(a/T-1)}}function w(t){this._context=t}function T(t){return new w(t)}function k(t){return t[0]}function M(t){return t[1]}function A(){var t=k,n=M,a=r(!0),i=null,o=T,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==i&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&a(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(!!t),l):a},l.curve=function(t){return arguments.length?(o=t,null!=i&&(s=o(i)),l):o},l.context=function(t){return arguments.length?(null==t?i=s=null:s=o(i=t),l):i},l}function S(){var t=k,n=null,a=r(0),i=M,o=r(!0),s=null,l=T,c=null;function u(r){var u,h,f,p,d,g=r.length,m=!1,v=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===m)if(m=!m)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(v[f],y[f]);c.lineEnd(),c.areaEnd()}m&&(v[u]=+t(p,u,r),y[u]=+a(p,u,r),c.point(n?+n(p,u,r):v[u],i?+i(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),i=null,u):a},u.y0=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),u):a},u.y1=function(t){return arguments.length?(i=null==t?null:\"function\"==typeof t?t:r(+t),u):i},u.lineX0=u.lineY0=function(){return h().x(t).y(a)},u.lineY1=function(){return h().x(t).y(i)},u.lineX1=function(){return h().x(n).y(a)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function E(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function C(t){return t}w.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=I(T);function P(t){this._curve=t}function I(t){function e(e){return new P(t(e))}return e._curve=t,e}function z(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(I(t)):e()._curve},t}function O(){return z(A().curve(L))}function D(){var t=S().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,a=t.lineY0,i=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return z(r())},delete t.lineX0,t.lineEndAngle=function(){return z(n())},delete t.lineX1,t.lineInnerRadius=function(){return z(a())},delete t.lineY0,t.lineOuterRadius=function(){return z(i())},delete t.lineY1,t.curve=function(t){return arguments.length?e(I(t)):e()._curve},t}function R(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}P.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var F=Array.prototype.slice;function B(t){return t.source}function N(t){return t.target}function j(t){var n=B,a=N,i=k,o=M,s=null;function l(){var r,l=F.call(arguments),c=n.apply(this,l),u=a.apply(this,l);if(s||(s=r=e.path()),t(s,+i.apply(this,(l[0]=c,l)),+o.apply(this,l),+i.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(a=t,l):a},l.x=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),l):i},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function U(t,e,r,n,a){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,a,n,a)}function V(t,e,r,n,a){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+a)/2,n,r,n,a)}function q(t,e,r,n,a){var i=R(e,r),o=R(e,r=(r+a)/2),s=R(n,r),l=R(n,a);t.moveTo(i[0],i[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var H={draw:function(t,e){var r=Math.sqrt(e/u);t.moveTo(r,0),t.arc(0,0,r,0,f)}},G={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},Y=Math.sqrt(1/3),W=2*Y,Z={draw:function(t,e){var r=Math.sqrt(e/W),n=r*Y;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(u/10)/Math.sin(7*u/10),J=Math.sin(f/10)*X,K=-Math.cos(f/10)*X,Q={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=J*r,a=K*r;t.moveTo(0,-r),t.lineTo(n,a);for(var i=1;i<5;++i){var o=f*i/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*a,l*n+s*a)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},tt=Math.sqrt(3),et={draw:function(t,e){var r=-Math.sqrt(e/(3*tt));t.moveTo(0,2*r),t.lineTo(-tt*r,-r),t.lineTo(tt*r,-r),t.closePath()}},rt=-.5,nt=Math.sqrt(3)/2,at=1/Math.sqrt(12),it=3*(at/2+1),ot={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,a=r*at,i=n,o=r*at+r,s=-i,l=o;t.moveTo(n,a),t.lineTo(i,o),t.lineTo(s,l),t.lineTo(rt*n-nt*a,nt*n+rt*a),t.lineTo(rt*i-nt*o,nt*i+rt*o),t.lineTo(rt*s-nt*l,nt*s+rt*l),t.lineTo(rt*n+nt*a,rt*a-nt*n),t.lineTo(rt*i+nt*o,rt*o-nt*i),t.lineTo(rt*s+nt*l,rt*l-nt*s),t.closePath()}},st=[H,G,Z,$,Q,et,ot];function lt(){}function ct(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t){this._context=t}function pt(t,e){this._basis=new ut(t),this._beta=e}ut.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},pt.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,a=t[0],i=e[0],o=t[r]-a,s=e[r]-i,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(a+n*o),this._beta*e[l]+(1-this._beta)*(i+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var dt=function t(e){function r(t){return 1===e?new ut(t):new pt(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function gt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:gt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function yt(t,e){this._context=t,this._k=(1-e)/6}yt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var xt=function t(e){function r(t){return new yt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function bt(t,e){this._context=t,this._k=(1-e)/6}bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var _t=function t(e){function r(t){return new bt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function wt(t,e,r){var n=t._x1,a=t._y1,i=t._x2,o=t._y2;if(t._l01_a>1e-12){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,a=(a*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>1e-12){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,u=3*t._l23_a*(t._l23_a+t._l12_a);i=(i*c+t._x1*t._l23_2a-e*t._l12_2a)/u,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/u}t._context.bezierCurveTo(n,a,i,o,t._x2,t._y2)}function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Mt(t,e):new yt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function St(t,e){this._context=t,this._alpha=e}St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Et=function t(e){function r(t){return e?new St(t,e):new bt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Ct(t){this._context=t}function Lt(t){return t<0?-1:1}function Pt(t,e,r){var n=t._x1-t._x0,a=e-t._x1,i=(t._y1-t._y0)/(n||a<0&&-0),o=(r-t._y1)/(a||n<0&&-0),s=(i*a+o*n)/(n+a);return(Lt(i)+Lt(o))*Math.min(Math.abs(i),Math.abs(o),.5*Math.abs(s))||0}function It(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function zt(t,e,r){var n=t._x0,a=t._y0,i=t._x1,o=t._y1,s=(i-n)/3;t._context.bezierCurveTo(n+s,a+s*e,i-s,o-s*r,i,o)}function Ot(t){this._context=t}function Dt(t){this._context=new Rt(t)}function Rt(t){this._context=t}function Ft(t){this._context=t}function Bt(t){var e,r,n=t.length-1,a=new Array(n),i=new Array(n),o=new Array(n);for(a[0]=0,i[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)a[e]=1,i[e]=4,o[e]=4*t[e]+2*t[e+1];for(a[n-1]=2,i[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=a[e]/i[e-1],i[e]-=r,o[e]-=r*o[e-1];for(a[n-1]=o[n-1]/i[n-1],e=n-2;e>=0;--e)a[e]=(o[e]-a[e+1])/i[e];for(i[n-1]=(t[n]+a[n-1])/2,e=0;e<n-1;++e)i[e]=2*t[e+1]-a[e+1];return[a,i]}function Nt(t,e){this._context=t,this._t=e}function jt(t,e){if((a=t.length)>1)for(var r,n,a,i=1,o=t[e[0]],s=o.length;i<a;++i)for(n=o,o=t[e[i]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function Ut(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function qt(t){var e=t.map(Ht);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Ht(t){for(var e,r=-1,n=0,a=t.length,i=-1/0;++r<a;)(e=+t[r][1])>i&&(i=e,n=r);return n}function Gt(t){var e=t.map(Yt);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Yt(t){for(var e,r=0,n=-1,a=t.length;++n<a;)(e=+t[n][1])&&(r+=e);return r}Ct.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},Ot.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:zt(this,this._t0,It(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,zt(this,It(this,r=Pt(this,t,e)),r);break;default:zt(this,this._t0,r=Pt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(Dt.prototype=Object.create(Ot.prototype)).point=function(t,e){Ot.prototype.point.call(this,e,t)},Rt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,a,i){this._context.bezierCurveTo(e,t,n,r,i,a)}},Ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Bt(t),a=Bt(e),i=0,o=1;o<r;++i,++o)this._context.bezierCurveTo(n[0][i],a[0][i],n[1][i],a[1][i],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Nt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=m,w=r(0),T=null,k=v,M=y,A=x,S=null;function E(){var r,g,m=+t.apply(this,arguments),v=+o.apply(this,arguments),y=k.apply(this,arguments)-h,x=M.apply(this,arguments)-h,E=n(x-y),C=x>y;if(S||(S=r=e.path()),v<m&&(g=v,v=m,m=g),v>1e-12)if(E>f-1e-12)S.moveTo(v*i(y),v*l(y)),S.arc(0,0,v,y,x,!C),m>1e-12&&(S.moveTo(m*i(x),m*l(x)),S.arc(0,0,m,x,y,C));else{var L,P,I=y,z=x,O=y,D=x,R=E,F=E,B=A.apply(this,arguments)/2,N=B>1e-12&&(T?+T.apply(this,arguments):c(m*m+v*v)),j=s(n(v-m)/2,+w.apply(this,arguments)),U=j,V=j;if(N>1e-12){var q=d(N/m*l(B)),H=d(N/v*l(B));(R-=2*q)>1e-12?(O+=q*=C?1:-1,D-=q):(R=0,O=D=(y+x)/2),(F-=2*H)>1e-12?(I+=H*=C?1:-1,z-=H):(F=0,I=z=(y+x)/2)}var G=v*i(I),Y=v*l(I),W=m*i(D),Z=m*l(D);if(j>1e-12){var X,J=v*i(z),K=v*l(z),Q=m*i(O),$=m*l(O);if(E<u&&(X=b(G,Y,Q,$,J,K,W,Z))){var tt=G-X[0],et=Y-X[1],rt=J-X[0],nt=K-X[1],at=1/l(p((tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))/2),it=c(X[0]*X[0]+X[1]*X[1]);U=s(j,(m-it)/(at-1)),V=s(j,(v-it)/(at+1))}}F>1e-12?V>1e-12?(L=_(Q,$,G,Y,v,V,C),P=_(J,K,W,Z,v,V,C),S.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?S.arc(L.cx,L.cy,V,a(L.y01,L.x01),a(P.y01,P.x01),!C):(S.arc(L.cx,L.cy,V,a(L.y01,L.x01),a(L.y11,L.x11),!C),S.arc(0,0,v,a(L.cy+L.y11,L.cx+L.x11),a(P.cy+P.y11,P.cx+P.x11),!C),S.arc(P.cx,P.cy,V,a(P.y11,P.x11),a(P.y01,P.x01),!C))):(S.moveTo(G,Y),S.arc(0,0,v,I,z,!C)):S.moveTo(G,Y),m>1e-12&&R>1e-12?U>1e-12?(L=_(W,Z,J,K,m,-U,C),P=_(G,Y,Q,$,m,-U,C),S.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?S.arc(L.cx,L.cy,U,a(L.y01,L.x01),a(P.y01,P.x01),!C):(S.arc(L.cx,L.cy,U,a(L.y01,L.x01),a(L.y11,L.x11),!C),S.arc(0,0,m,a(L.cy+L.y11,L.cx+L.x11),a(P.cy+P.y11,P.cx+P.x11),C),S.arc(P.cx,P.cy,U,a(P.y11,P.x11),a(P.y01,P.x01),!C))):S.arc(0,0,m,D,O,C):S.lineTo(W,Z)}else S.moveTo(0,0);if(S.closePath(),r)return S=null,r+\"\"||null}return E.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +M.apply(this,arguments))/2-u/2;return[i(r)*e,l(r)*e]},E.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),E):t},E.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),E):o},E.cornerRadius=function(t){return arguments.length?(w=\"function\"==typeof t?t:r(+t),E):w},E.padRadius=function(t){return arguments.length?(T=null==t?null:\"function\"==typeof t?t:r(+t),E):T},E.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),E):k},E.endAngle=function(t){return arguments.length?(M=\"function\"==typeof t?t:r(+t),E):M},E.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),E):A},E.context=function(t){return arguments.length?(S=null==t?null:t,E):S},E},t.area=S,t.areaRadial=D,t.curveBasis=function(t){return new ut(t)},t.curveBasisClosed=function(t){return new ht(t)},t.curveBasisOpen=function(t){return new ft(t)},t.curveBundle=dt,t.curveCardinal=vt,t.curveCardinalClosed=xt,t.curveCardinalOpen=_t,t.curveCatmullRom=kt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=Et,t.curveLinear=T,t.curveLinearClosed=function(t){return new Ct(t)},t.curveMonotoneX=function(t){return new Ot(t)},t.curveMonotoneY=function(t){return new Dt(t)},t.curveNatural=function(t){return new Ft(t)},t.curveStep=function(t){return new Nt(t,.5)},t.curveStepAfter=function(t){return new Nt(t,1)},t.curveStepBefore=function(t){return new Nt(t,0)},t.line=A,t.lineRadial=O,t.linkHorizontal=function(){return j(U)},t.linkRadial=function(){var t=j(q);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.linkVertical=function(){return j(V)},t.pie=function(){var t=C,e=E,n=null,a=r(0),i=r(f),o=r(0);function s(r){var s,l,c,u,h,p=r.length,d=0,g=new Array(p),m=new Array(p),v=+a.apply(this,arguments),y=Math.min(f,Math.max(-f,i.apply(this,arguments)-v)),x=Math.min(Math.abs(y)/p,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<p;++s)(h=m[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort((function(t,r){return e(m[t],m[r])})):null!=n&&g.sort((function(t,e){return n(r[t],r[e])})),s=0,c=d?(y-p*b)/d:0;s<p;++s,v=u)l=g[s],u=v+((h=m[l])>0?h*c:0)+b,m[l]={data:r[l],index:s,value:h,startAngle:v,endAngle:u,padAngle:x};return m}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.endAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.pointRadial=R,t.radialArea=D,t.radialLine=O,t.stack=function(){var t=r([]),e=Ut,n=jt,a=Vt;function i(r){var i,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(i=0;i<c;++i){for(var h,f=s[i],p=u[i]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+a(r[d],f,d,r)],h.data=r[d];p.key=f}for(i=0,o=e(u);i<c;++i)u[o[i]].index=i;return n(u,o),u}return i.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(F.call(e)),i):t},i.value=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),i):a},i.order=function(t){return arguments.length?(e=null==t?Ut:\"function\"==typeof t?t:r(F.call(t)),i):e},i.offset=function(t){return arguments.length?(n=null==t?jt:t,i):n},i},t.stackOffsetDiverging=function(t,e){if((s=t.length)>0)for(var r,n,a,i,o,s,l=0,c=t[e[0]].length;l<c;++l)for(i=o=0,r=0;r<s;++r)(a=(n=t[e[r]][l])[1]-n[0])>0?(n[0]=i,n[1]=i+=a):a<0?(n[1]=o,n[0]=o+=a):(n[0]=0,n[1]=a)},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,a,i=0,o=t[0].length;i<o;++i){for(a=r=0;r<n;++r)a+=t[r][i][1]||0;if(a)for(r=0;r<n;++r)t[r][i][1]/=a}jt(t,e)}},t.stackOffsetNone=jt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,a=t[e[0]],i=a.length;n<i;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;a[n][1]+=a[n][0]=-s/2}jt(t,e)}},t.stackOffsetWiggle=function(t,e){if((a=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,a,i=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<a;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=i,l&&(i-=c/l)}r[o-1][1]+=r[o-1][0]=i,jt(t,e)}},t.stackOrderAppearance=qt,t.stackOrderAscending=Gt,t.stackOrderDescending=function(t){return Gt(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,a=t.map(Yt),i=qt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=i[e],o<s?(o+=a[r],l.push(r)):(s+=a[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=Ut,t.stackOrderReverse=function(t){return Ut(t).reverse()},t.symbol=function(){var t=r(H),n=r(64),a=null;function i(){var r;if(a||(a=r=e.path()),t.apply(this,arguments).draw(a,+n.apply(this,arguments)),r)return a=null,r+\"\"||null}return i.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),i):t},i.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),i):n},i.context=function(t){return arguments.length?(a=null==t?null:t,i):a},i},t.symbolCircle=H,t.symbolCross=G,t.symbolDiamond=Z,t.symbolSquare=$,t.symbolStar=Q,t.symbolTriangle=et,t.symbolWye=ot,t.symbols=st,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-path\":163}],166:[function(t,e,r){!function(n,a){\"object\"==typeof r&&\"undefined\"!=typeof e?a(r,t(\"d3-time\")):a((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function n(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function a(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function i(t){var i=t.dateTime,o=t.date,l=t.time,c=t.periods,u=t.days,h=t.shortDays,f=t.months,yt=t.shortMonths,xt=p(c),bt=d(c),_t=p(u),wt=d(u),Tt=p(h),kt=d(h),Mt=p(f),At=d(f),St=p(yt),Et=d(yt),Ct={a:function(t){return h[t.getDay()]},A:function(t){return u[t.getDay()]},b:function(t){return yt[t.getMonth()]},B:function(t){return f[t.getMonth()]},c:null,d:D,e:D,f:j,H:R,I:F,j:B,L:N,m:U,M:V,p:function(t){return c[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:mt,s:vt,S:q,u:H,U:G,V:Y,w:W,W:Z,x:null,X:null,y:X,Y:J,Z:K,\"%\":gt},Lt={a:function(t){return h[t.getUTCDay()]},A:function(t){return u[t.getUTCDay()]},b:function(t){return yt[t.getUTCMonth()]},B:function(t){return f[t.getUTCMonth()]},c:null,d:Q,e:Q,f:nt,H:$,I:tt,j:et,L:rt,m:at,M:it,p:function(t){return c[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:mt,s:vt,S:ot,u:st,U:lt,V:ct,w:ut,W:ht,x:null,X:null,y:ft,Y:pt,Z:dt,\"%\":gt},Pt={a:function(t,e,r){var n=Tt.exec(e.slice(r));return n?(t.w=kt[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=_t.exec(e.slice(r));return n?(t.w=wt[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=St.exec(e.slice(r));return n?(t.m=Et[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Mt.exec(e.slice(r));return n?(t.m=At[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,e,r){return Ot(t,i,e,r)},d:M,e:M,f:P,H:S,I:S,j:A,L:L,m:k,M:E,p:function(t,e,r){var n=xt.exec(e.slice(r));return n?(t.p=bt[n[0].toLowerCase()],r+n[0].length):-1},q:T,Q:z,s:O,S:C,u:m,U:v,V:y,w:g,W:x,x:function(t,e,r){return Ot(t,o,e,r)},X:function(t,e,r){return Ot(t,l,e,r)},y:_,Y:b,Z:w,\"%\":I};function It(t,e){return function(r){var n,a,i,o=[],l=-1,c=0,u=t.length;for(r instanceof Date||(r=new Date(+r));++l<u;)37===t.charCodeAt(l)&&(o.push(t.slice(c,l)),null!=(a=s[n=t.charAt(++l)])?n=t.charAt(++l):a=\"e\"===n?\" \":\"0\",(i=e[n])&&(n=i(r,a)),o.push(n),c=l+1);return o.push(t.slice(c,l)),o.join(\"\")}}function zt(t,i){return function(o){var s,l,c=a(1900,void 0,1);if(Ot(c,t,o+=\"\",0)!=o.length)return null;if(\"Q\"in c)return new Date(c.Q);if(\"s\"in c)return new Date(1e3*c.s+(\"L\"in c?c.L:0));if(i&&!(\"Z\"in c)&&(c.Z=0),\"p\"in c&&(c.H=c.H%12+12*c.p),void 0===c.m&&(c.m=\"q\"in c?c.q:0),\"V\"in c){if(c.V<1||c.V>53)return null;\"w\"in c||(c.w=1),\"Z\"in c?(l=(s=n(a(c.y,0,1))).getUTCDay(),s=l>4||0===l?e.utcMonday.ceil(s):e.utcMonday(s),s=e.utcDay.offset(s,7*(c.V-1)),c.y=s.getUTCFullYear(),c.m=s.getUTCMonth(),c.d=s.getUTCDate()+(c.w+6)%7):(l=(s=r(a(c.y,0,1))).getDay(),s=l>4||0===l?e.timeMonday.ceil(s):e.timeMonday(s),s=e.timeDay.offset(s,7*(c.V-1)),c.y=s.getFullYear(),c.m=s.getMonth(),c.d=s.getDate()+(c.w+6)%7)}else(\"W\"in c||\"U\"in c)&&(\"w\"in c||(c.w=\"u\"in c?c.u%7:\"W\"in c?1:0),l=\"Z\"in c?n(a(c.y,0,1)).getUTCDay():r(a(c.y,0,1)).getDay(),c.m=0,c.d=\"W\"in c?(c.w+6)%7+7*c.W-(l+5)%7:c.w+7*c.U-(l+6)%7);return\"Z\"in c?(c.H+=c.Z/100|0,c.M+=c.Z%100,n(c)):r(c)}}function Ot(t,e,r,n){for(var a,i,o=0,l=e.length,c=r.length;o<l;){if(n>=c)return-1;if(37===(a=e.charCodeAt(o++))){if(a=e.charAt(o++),!(i=Pt[a in s?e.charAt(o++):a])||(n=i(t,r,n))<0)return-1}else if(a!=r.charCodeAt(n++))return-1}return n}return Ct.x=It(o,Ct),Ct.X=It(l,Ct),Ct.c=It(i,Ct),Lt.x=It(o,Lt),Lt.X=It(l,Lt),Lt.c=It(i,Lt),{format:function(t){var e=It(t+=\"\",Ct);return e.toString=function(){return t},e},parse:function(t){var e=zt(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=It(t+=\"\",Lt);return e.toString=function(){return t},e},utcParse:function(t){var e=zt(t+=\"\",!0);return e.toString=function(){return t},e}}}var o,s={\"-\":\"\",_:\" \",0:\"0\"},l=/^\\s*\\d+/,c=/^%/,u=/[\\\\^$*+?|[\\]().{}]/g;function h(t,e,r){var n=t<0?\"-\":\"\",a=(n?-t:t)+\"\",i=a.length;return n+(i<r?new Array(r-i+1).join(e)+a:a)}function f(t){return t.replace(u,\"\\\\$&\")}function p(t){return new RegExp(\"^(?:\"+t.map(f).join(\"|\")+\")\",\"i\")}function d(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function g(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function m(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function v(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function y(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function x(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function b(t,e,r){var n=l.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function _(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function w(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function T(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function k(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function M(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function A(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function S(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function E(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function C(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function L(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function P(t,e,r){var n=l.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function I(t,e,r){var n=c.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function z(t,e,r){var n=l.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function O(t,e,r){var n=l.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function D(t,e){return h(t.getDate(),e,2)}function R(t,e){return h(t.getHours(),e,2)}function F(t,e){return h(t.getHours()%12||12,e,2)}function B(t,r){return h(1+e.timeDay.count(e.timeYear(t),t),r,3)}function N(t,e){return h(t.getMilliseconds(),e,3)}function j(t,e){return N(t,e)+\"000\"}function U(t,e){return h(t.getMonth()+1,e,2)}function V(t,e){return h(t.getMinutes(),e,2)}function q(t,e){return h(t.getSeconds(),e,2)}function H(t){var e=t.getDay();return 0===e?7:e}function G(t,r){return h(e.timeSunday.count(e.timeYear(t)-1,t),r,2)}function Y(t,r){var n=t.getDay();return t=n>=4||0===n?e.timeThursday(t):e.timeThursday.ceil(t),h(e.timeThursday.count(e.timeYear(t),t)+(4===e.timeYear(t).getDay()),r,2)}function W(t){return t.getDay()}function Z(t,r){return h(e.timeMonday.count(e.timeYear(t)-1,t),r,2)}function X(t,e){return h(t.getFullYear()%100,e,2)}function J(t,e){return h(t.getFullYear()%1e4,e,4)}function K(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+h(e/60|0,\"0\",2)+h(e%60,\"0\",2)}function Q(t,e){return h(t.getUTCDate(),e,2)}function $(t,e){return h(t.getUTCHours(),e,2)}function tt(t,e){return h(t.getUTCHours()%12||12,e,2)}function et(t,r){return h(1+e.utcDay.count(e.utcYear(t),t),r,3)}function rt(t,e){return h(t.getUTCMilliseconds(),e,3)}function nt(t,e){return rt(t,e)+\"000\"}function at(t,e){return h(t.getUTCMonth()+1,e,2)}function it(t,e){return h(t.getUTCMinutes(),e,2)}function ot(t,e){return h(t.getUTCSeconds(),e,2)}function st(t){var e=t.getUTCDay();return 0===e?7:e}function lt(t,r){return h(e.utcSunday.count(e.utcYear(t)-1,t),r,2)}function ct(t,r){var n=t.getUTCDay();return t=n>=4||0===n?e.utcThursday(t):e.utcThursday.ceil(t),h(e.utcThursday.count(e.utcYear(t),t)+(4===e.utcYear(t).getUTCDay()),r,2)}function ut(t){return t.getUTCDay()}function ht(t,r){return h(e.utcMonday.count(e.utcYear(t)-1,t),r,2)}function ft(t,e){return h(t.getUTCFullYear()%100,e,2)}function pt(t,e){return h(t.getUTCFullYear()%1e4,e,4)}function dt(){return\"+0000\"}function gt(){return\"%\"}function mt(t){return+t}function vt(t){return Math.floor(+t/1e3)}function yt(e){return o=i(e),t.timeFormat=o.format,t.timeParse=o.parse,t.utcFormat=o.utcFormat,t.utcParse=o.utcParse,o}yt({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});var xt=Date.prototype.toISOString?function(t){return t.toISOString()}:t.utcFormat(\"%Y-%m-%dT%H:%M:%S.%LZ\");var bt=+new Date(\"2000-01-01T00:00:00.000Z\")?function(t){var e=new Date(t);return isNaN(e)?null:e}:t.utcParse(\"%Y-%m-%dT%H:%M:%S.%LZ\");t.isoFormat=xt,t.isoParse=bt,t.timeFormatDefaultLocale=yt,t.timeFormatLocale=i,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-time\":167}],167:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=new Date,r=new Date;function n(t,a,i,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(e){return t(e=new Date(e-1)),a(e,1),t(e),e},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,e){return a(t=new Date(+t),null==e?1:Math.floor(e)),t},s.range=function(e,r,n){var i,o=[];if(e=s.ceil(e),n=null==n?1:Math.floor(n),!(e<r&&n>0))return o;do{o.push(i=new Date(+e)),a(e,n),t(e)}while(i<e&&e<r);return o},s.filter=function(e){return n((function(r){if(r>=r)for(;t(r),!e(r);)r.setTime(r-1)}),(function(t,r){if(t>=t)if(r<0)for(;++r<=0;)for(;a(t,-1),!e(t););else for(;--r>=0;)for(;a(t,1),!e(t););}))},i&&(s.count=function(n,a){return e.setTime(+n),r.setTime(+a),t(e),t(r),Math.floor(i(e,r))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}var a=n((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));a.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?n((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):a:null};var i=a.range,o=n((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+1e3*e)}),(function(t,e){return(e-t)/1e3}),(function(t){return t.getUTCSeconds()})),s=o.range,l=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds())}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getMinutes()})),c=l.range,u=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds()-6e4*t.getMinutes())}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getHours()})),h=u.range,f=n((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/864e5}),(function(t){return t.getDate()-1})),p=f.range;function d(t){return n((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/6048e5}))}var g=d(0),m=d(1),v=d(2),y=d(3),x=d(4),b=d(5),_=d(6),w=g.range,T=m.range,k=v.range,M=y.range,A=x.range,S=b.range,E=_.range,C=n((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),L=C.range,P=n((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));P.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null};var I=P.range,z=n((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getUTCMinutes()})),O=z.range,D=n((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getUTCHours()})),R=D.range,F=n((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/864e5}),(function(t){return t.getUTCDate()-1})),B=F.range;function N(t){return n((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/6048e5}))}var j=N(0),U=N(1),V=N(2),q=N(3),H=N(4),G=N(5),Y=N(6),W=j.range,Z=U.range,X=V.range,J=q.range,K=H.range,Q=G.range,$=Y.range,tt=n((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),et=tt.range,rt=n((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));rt.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null};var nt=rt.range;t.timeDay=f,t.timeDays=p,t.timeFriday=b,t.timeFridays=S,t.timeHour=u,t.timeHours=h,t.timeInterval=n,t.timeMillisecond=a,t.timeMilliseconds=i,t.timeMinute=l,t.timeMinutes=c,t.timeMonday=m,t.timeMondays=T,t.timeMonth=C,t.timeMonths=L,t.timeSaturday=_,t.timeSaturdays=E,t.timeSecond=o,t.timeSeconds=s,t.timeSunday=g,t.timeSundays=w,t.timeThursday=x,t.timeThursdays=A,t.timeTuesday=v,t.timeTuesdays=k,t.timeWednesday=y,t.timeWednesdays=M,t.timeWeek=g,t.timeWeeks=w,t.timeYear=P,t.timeYears=I,t.utcDay=F,t.utcDays=B,t.utcFriday=G,t.utcFridays=Q,t.utcHour=D,t.utcHours=R,t.utcMillisecond=a,t.utcMilliseconds=i,t.utcMinute=z,t.utcMinutes=O,t.utcMonday=U,t.utcMondays=Z,t.utcMonth=tt,t.utcMonths=et,t.utcSaturday=Y,t.utcSaturdays=$,t.utcSecond=o,t.utcSeconds=s,t.utcSunday=j,t.utcSundays=W,t.utcThursday=H,t.utcThursdays=K,t.utcTuesday=V,t.utcTuesdays=X,t.utcWednesday=q,t.utcWednesdays=J,t.utcWeek=j,t.utcWeeks=W,t.utcYear=rt,t.utcYears=nt,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],168:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e,r,n=0,a=0,i=0,o=0,s=0,l=0,c=\"object\"==typeof performance&&performance.now?performance:Date,u=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function h(){return s||(u(f),s=c.now()+l)}function f(){s=0}function p(){this._call=this._time=this._next=null}function d(t,e,r){var n=new p;return n.restart(t,e,r),n}function g(){h(),++n;for(var t,r=e;r;)(t=s-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){s=(o=c.now())+l,n=a=0;try{g()}finally{n=0,function(){var t,n,a=e,i=1/0;for(;a;)a._call?(i>a._time&&(i=a._time),t=a,a=a._next):(n=a._next,a._next=null,a=t?t._next=n:e=n);r=t,y(i)}(),s=0}}function v(){var t=c.now(),e=t-o;e>1e3&&(l-=e,o=t)}function y(t){n||(a&&(a=clearTimeout(a)),t-s>24?(t<1/0&&(a=setTimeout(m,t-c.now()-l)),i&&(i=clearInterval(i))):(i||(o=c.now(),i=setInterval(v,1e3)),n=1,u(m)))}p.prototype=d.prototype={constructor:p,restart:function(t,n,a){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");a=(null==a?h():+a)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=a,y()},stop:function(){this._call&&(this._call=null,this._time=1/0,y())}},t.interval=function(t,e,r){var n=new p,a=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?h():+r,n.restart((function i(o){o+=a,n.restart(i,a+=e,r),t(o)}),e,r),n)},t.now=h,t.timeout=function(t,e,r){var n=new p;return e=null==e?0:+e,n.restart((function(r){n.stop(),t(r+e)}),e,r),n},t.timer=d,t.timerFlush=g,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],169:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},a=this.document;function i(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(a)try{n(a.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),a)try{a.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,a){for(arguments.length<3&&(n=0),arguments.length<4&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)<0?n=i+1:a=i}return n},right:function(e,r,n,a){for(arguments.length<3&&(n=0),arguments.length<4&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)>0?a=i:n=i+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,a=-1,i=t.length;if(1===arguments.length){for(;++a<i;)if(null!=(n=t[a])&&n>=n){r=n;break}for(;++a<i;)null!=(n=t[a])&&r>n&&(r=n)}else{for(;++a<i;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=n;break}for(;++a<i;)null!=(n=e.call(t,t[a],a))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,a=-1,i=t.length;if(1===arguments.length){for(;++a<i;)if(null!=(n=t[a])&&n>=n){r=n;break}for(;++a<i;)null!=(n=t[a])&&n>r&&(r=n)}else{for(;++a<i;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=n;break}for(;++a<i;)null!=(n=e.call(t,t[a],a))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,a,i=-1,o=t.length;if(1===arguments.length){for(;++i<o;)if(null!=(n=t[i])&&n>=n){r=a=n;break}for(;++i<o;)null!=(n=t[i])&&(r>n&&(r=n),a<n&&(a=n))}else{for(;++i<o;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=a=n;break}for(;++i<o;)null!=(n=e.call(t,t[i],i))&&(r>n&&(r=n),a<n&&(a=n))}return[r,a]},t.sum=function(t,e){var r,n=0,a=t.length,i=-1;if(1===arguments.length)for(;++i<a;)d(r=+t[i])&&(n+=r);else for(;++i<a;)d(r=+e.call(t,t[i],i))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,a=t.length,i=-1,o=a;if(1===arguments.length)for(;++i<a;)d(r=p(t[i]))?n+=r:--o;else for(;++i<a;)d(r=p(e.call(t,t[i],i)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),a=+t[n-1],i=r-n;return i?a+i*(t[n]-a):a},t.median=function(e,r){var n,a=[],i=e.length,o=-1;if(1===arguments.length)for(;++o<i;)d(n=p(e[o]))&&a.push(n);else for(;++o<i;)d(n=p(r.call(e,e[o],o)))&&a.push(n);if(a.length)return t.quantile(a.sort(f),.5)},t.variance=function(t,e){var r,n,a=t.length,i=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<a;)d(r=p(t[s]))&&(o+=(n=r-i)*(r-(i+=n/++l)));else for(;++s<a;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-i)*(r-(i+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var m=g(f);function v(t){return t.length}t.bisectLeft=m.left,t.bisect=t.bisectRight=m.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(i=arguments.length)<3&&(r=t.length,i<2&&(e=0));for(var n,a,i=r-e;i;)a=Math.random()*i--|0,n=t[i+e],t[i+e]=t[a+e],t[a+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],a=new Array(r<0?0:r);e<r;)a[e]=[n,n=t[++e]];return a},t.transpose=function(e){if(!(i=e.length))return[];for(var r=-1,n=t.min(e,v),a=new Array(n);++r<n;)for(var i,o=-1,s=a[r]=new Array(i);++o<i;)s[o]=e[o][r];return a},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,a=t.length,i=-1,o=0;++i<a;)o+=t[i].length;for(r=new Array(o);--a>=0;)for(e=(n=t[a]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t){for(var e=1;t*e%1;)e*=10;return e}function b(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function _(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,a=[],i=x(y(r)),o=-1;if(t*=i,e*=i,(r*=i)<0)for(;(n=t+r*++o)>e;)a.push(n/i);else for(;(n=t+r*++o)<e;)a.push(n/i);return a},t.map=function(t,e){var r=new _;if(t instanceof _)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,a=-1,i=t.length;if(1===arguments.length)for(;++a<i;)r.set(a,t[a]);else for(;++a<i;)r.set(e.call(t,n=t[a],a),n)}else for(var o in t)r.set(o,t[o]);return r};function w(t){return\"__proto__\"==(t+=\"\")||\"\\0\"===t[0]?\"\\0\"+t:t}function T(t){return\"\\0\"===(t+=\"\")[0]?t.slice(1):t}function k(t){return w(t)in this._}function M(t){return(t=w(t))in this._&&delete this._[t]}function A(){var t=[];for(var e in this._)t.push(T(e));return t}function S(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function L(t){return t}function P(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function I(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=z.length;r<n;++r){var a=z[r]+e;if(a in t)return a}}b(_,{has:k,get:function(t){return this._[w(t)]},set:function(t,e){return this._[w(t)]=e},remove:M,keys:A,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},a=[],i=[];function o(t,i,s){if(s>=a.length)return r?r.call(n,i):e?i.sort(e):i;for(var l,c,u,h,f=-1,p=i.length,d=a[s++],g=new _;++f<p;)(h=g.get(l=d(c=i[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=a.length)return e;var n=[],o=i[r++];return e.forEach((function(e,a){n.push({key:e,values:t(a,r)})})),o?n.sort((function(t,e){return o(t.key,e.key)})):n}(o(t.map,e,0),0)},n.key=function(t){return a.push(t),n},n.sortKeys=function(t){return i[a.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},b(C,{has:k,add:function(t){return this._[w(t+=\"\")]=!0,t},remove:M,values:A,size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,a=arguments.length;++n<a;)t[r=arguments[n]]=P(t,e,e[r]);return t};var z=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function O(){}function D(){}function R(t){var e=[],r=new _;function n(){for(var r,n=e,a=-1,i=n.length;++a<i;)(r=n[a].on)&&r.apply(this,arguments);return t}return n.on=function(n,a){var i,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,i=e.indexOf(o)).concat(e.slice(i+1)),r.remove(n)),a&&e.push(r.set(n,{on:a})),t)},n}function F(){t.event.preventDefault()}function B(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function N(e){for(var r=new D,n=0,a=arguments.length;++n<a;)r[arguments[n]]=R(r);return r.of=function(n,a){return function(i){try{var o=i.sourceEvent=t.event;i.target=e,t.event=i,r[i.type].apply(n,a)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new D,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=R(t);return t},D.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(j,\"\\\\$&\")};var j=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function V(t){return U(t,Y),t}var q=function(t,e){return e.querySelector(t)},H=function(t,e){return e.querySelectorAll(t)},G=function(t,e){var r=t.matches||t[I(t,\"matchesSelector\")];return(G=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(q=function(t,e){return Sizzle(t,e)[0]||null},H=Sizzle,G=Sizzle.matchesSelector),t.selection=function(){return t.select(a.documentElement)};var Y=t.selection.prototype=[];function W(t){return\"function\"==typeof t?t:function(){return q(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return H(t,this)}}Y.select=function(t){var e,r,n,a,i=[];t=W(t);for(var o=-1,s=this.length;++o<s;){i.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(a=n[l])?(e.push(r=t.call(a,a.__data__,l,o)),r&&\"__data__\"in a&&(r.__data__=a.__data__)):e.push(null)}return V(i)},Y.selectAll=function(t){var e,r,a=[];t=Z(t);for(var i=-1,o=this.length;++i<o;)for(var s=this[i],l=-1,c=s.length;++l<c;)(r=s[l])&&(a.push(e=n(t.call(r,r.__data__,l,i))),e.parentNode=r);return V(a)};var X=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:X,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function $(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function tt(t){return(t+\"\").trim().split(/^|\\s+/)}function et(t,e){var r=(t=tt(t).map(rt)).length;return\"function\"==typeof e?function(){for(var n=-1,a=e.apply(this,arguments);++n<r;)t[n](this,a)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function rt(t){var e=$(t);return function(r,n){if(a=r.classList)return n?a.add(t):a.remove(t);var a=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(a)||r.setAttribute(\"class\",Q(a+\" \"+t))):r.setAttribute(\"class\",Q(a.replace(e,\" \")))}}function nt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function it(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===X&&t.documentElement.namespaceURI===X?t.createElement(e):t.createElementNS(r,e)}}function ot(){var t=this.parentNode;t&&t.removeChild(this)}function st(t){return{__data__:t}}function lt(t){return function(){return G(this,t)}}function ct(t){return arguments.length||(t=f),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var a,i=t[r],o=0,s=i.length;o<s;o++)(a=i[o])&&e(a,o,r);return t}function ht(t){return U(t,ft),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=tt(t)).length,a=-1;if(e=r.classList){for(;++a<n;)if(!e.contains(t[a]))return!1}else for(e=r.getAttribute(\"class\");++a<n;)if(!$(t[a]).test(e))return!1;return!0}for(e in t)this.each(et(e,t[e]));return this}return this.each(et(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(nt(r,t[r],e));return this}if(n<2){var a=this.node();return o(a).getComputedStyle(a,null).getPropertyValue(t)}r=\"\"}return this.each(nt(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=it(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},Y.insert=function(t,e){return t=it(t),e=W(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},Y.remove=function(){return this.each(ot)},Y.data=function(t,e){var r,n,a=-1,i=this.length;if(!arguments.length){for(t=new Array(i=(r=this[0]).length);++a<i;)(n=r[a])&&(t[a]=n.__data__);return t}function o(t,r){var n,a,i,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,m=new _,v=new Array(o);for(n=-1;++n<o;)(a=t[n])&&(m.has(g=e.call(a,a.__data__,n))?d[n]=a:m.set(g,a),v[n]=g);for(n=-1;++n<u;)(a=m.get(g=e.call(r,i=r[n],n)))?!0!==a&&(f[n]=a,a.__data__=i):p[n]=st(i),m.set(g,!0);for(n=-1;++n<o;)n in v&&!0!==m.get(v[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)a=t[n],i=r[n],a?(a.__data__=i,f[n]=a):p[n]=st(i);for(;n<u;++n)p[n]=st(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=V([]),c=V([]);if(\"function\"==typeof t)for(;++a<i;)o(r=this[a],t.call(r,r.parentNode.__data__,a));else for(;++a<i;)o(r=this[a],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,a=[];\"function\"!=typeof t&&(t=lt(t));for(var i=0,o=this.length;i<o;i++){a.push(e=[]),e.parentNode=(r=this[i]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,i)&&e.push(n)}return V(a)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],a=n.length-1,i=n[a];--a>=0;)(r=n[a])&&(i&&i!==r.nextSibling&&i.parentNode.insertBefore(r,i),i=r);return this},Y.sort=function(t){t=ct.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,a=r.length;n<a;n++){var i=r[n];if(i)return i}return null},Y.size=function(){var t=0;return ut(this,(function(){++t})),t};var ft=[];function pt(t){var e,r;return function(n,a,i){var o,s=t[i].update,l=s.length;for(i!=r&&(r=i,e=0),a>=e&&(e=a+1);!(o=s[e])&&++e<l;);return o}}function dt(e,r,a){var i=\"__on\"+e,o=e.indexOf(\".\"),s=mt;o>0&&(e=e.slice(0,o));var l=gt.get(e);function c(){var t=this[i];t&&(this.removeEventListener(e,t,t.$),delete this[i])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[i]=t,t.$=a),t._=r}:c:r?O:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var a in this)if(r=a.match(n)){var i=this[a];this.removeEventListener(r[1],i,i.$),delete this[a]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=Y.append,ft.empty=Y.empty,ft.node=Y.node,ft.call=Y.call,ft.size=Y.size,ft.select=function(t){for(var e,r,n,a,i,o=[],s=-1,l=this.length;++s<l;){n=(a=this[s]).update,o.push(e=[]),e.parentNode=a.parentNode;for(var c=-1,u=a.length;++c<u;)(i=a[c])?(e.push(n[c]=r=t.call(a.parentNode,i.__data__,c,s)),r.__data__=i.__data__):e.push(null)}return V(o)},ft.insert=function(t,e){return arguments.length<2&&(e=pt(this)),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[q(t,a)]).parentNode=a.documentElement:(e=[t]).parentNode=i(t),V([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(H(t,a))).parentNode=a.documentElement:(e=n(t)).parentNode=null,V([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(dt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(dt(t,e,r))};var gt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function mt(e,r){return function(n){var a=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=a}}}function vt(t,e){var r=mt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}a&&gt.forEach((function(t){\"on\"+t in a&&gt.remove(t)}));var yt,xt=0;function bt(e){var r=\".dragsuppress-\"+ ++xt,n=\"click\"+r,a=t.select(o(e)).on(\"touchmove\"+r,F).on(\"dragstart\"+r,F).on(\"selectstart\"+r,F);if(null==yt&&(yt=!(\"onselectstart\"in e)&&I(e.style,\"userSelect\")),yt){var s=i(e).style,l=s[yt];s[yt]=\"none\"}return function(t){if(a.on(r,null),yt&&(s[yt]=l),t){var e=function(){a.on(n,null)};a.on(n,(function(){F(),e()}),!0),setTimeout(e,0)}}}t.mouse=function(t){return wt(t,B())};var _t=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function wt(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var a=n.createSVGPoint();if(_t<0){var i=o(e);if(i.scrollX||i.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();_t=!(s.f||s.e),n.remove()}}return _t?(a.x=r.pageX,a.y=r.pageY):(a.x=r.clientX,a.y=r.clientY),[(a=a.matrixTransform(e.getScreenCTM().inverse())).x,a.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function Tt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=B().changedTouches),e)for(var n,a=0,i=e.length;a<i;++a)if((n=e[a]).identifier===r)return wt(t,n)},t.behavior.drag=function(){var e=N(i,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(O,t.mouse,o,\"mousemove\",\"mouseup\"),a=s(Tt,t.touch,L,\"touchmove\",\"touchend\");function i(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",a)}function s(n,a,i,o,s){return function(){var l,c=this,u=t.event.target.correspondingElement||t.event.target,h=c.parentNode,f=e.of(c,arguments),p=0,d=n(),g=\".drag\"+(null==d?\"\":\"-\"+d),m=t.select(i(u)).on(o+g,x).on(s+g,b),v=bt(u),y=a(h,d);function x(){var t,e,r=a(h,d);r&&(t=r[0]-y[0],e=r[1]-y[1],p|=t|e,y=r,f({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))}function b(){a(h,d)&&(m.on(o+g,null).on(s+g,null),v(p),f({type:\"dragend\"}))}l=r?[(l=r.apply(c,arguments)).x-y[0],l.y-y[1]]:[0,0],f({type:\"dragstart\"})}}return i.origin=function(t){return arguments.length?(r=t,i):r},t.rebind(i,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=B().touches),e?n(e).map((function(e){var r=wt(t,e);return r.identifier=e.identifier,r})):[]};var kt=1e-6,Mt=1e-12,At=Math.PI,St=2*At,Et=St-kt,Ct=At/2,Lt=At/180,Pt=180/At;function It(t){return t>0?1:t<0?-1:0}function zt(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function Ot(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Ct:t<-1?-Ct:Math.asin(t)}function Rt(t){return((t=Math.exp(t))+1/t)/2}function Ft(t){return(t=Math.sin(t/2))*t}var Bt=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,a=t[0],i=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-a,h=l-i,f=u*u+h*h;if(f<Mt)n=Math.log(c/o)/Bt,r=function(t){return[a+t*u,i+t*h,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/Bt,r=function(t){var e,r=t*n,s=Rt(m),l=o/(2*p)*(s*(e=Bt*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[a+l*u,i+l*h,o*s/Rt(Bt*r+m)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,i,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=Ut,g=250,m=0,v=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=N(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(v,P).on(jt+\".zoom\",z).on(\"dblclick.zoom\",O).on(b,I)}function T(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function k(t){f.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function A(e,n,a,i){e.__chart__={x:f.x,y:f.y,k:f.k},k(Math.pow(2,i)),M(r=n,a),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map((function(t){return(t-f.x)/f.k})).map(l.invert)),h&&h.domain(u.range().map((function(t){return(t-f.y)/f.k})).map(u.invert))}function E(t){m++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--m||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,a=t.select(o(e)).on(y,l).on(x,c),i=T(t.mouse(e)),s=bt(e);function l(){n=1,M(t.mouse(e),i),C(r)}function c(){a.on(y,null).on(x,null),s(n),L(r)}vs.call(e),E(r)}function I(){var e,r=this,n=_.of(r,arguments),a={},i=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=bt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach((function(t){t.identifier in a&&(a[t.identifier]=T(t))})),n}function g(){var e=t.event.target;t.select(e).on(l,m).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)a[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var v=p[0];A(r,v,a[v.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),F()}s=g}else if(p.length>1){v=p[0];var x=p[1],b=v[0]-x[0],_=v[1]-x[1];i=b*b+_*_}}function m(){var o,l,c,u,h=t.touches(r);vs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=a[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=i&&Math.sqrt(d/i);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(g*e)}s=null,M(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,i=e.length;r<i;++r)delete a[e[r].identifier];for(var s in a)return void d()}t.selectAll(u).on(o,null),h.on(v,P).on(b,I),p(),L(n)}g(),E(n),h.on(v,null).on(b,g)}function z(){var a=_.of(this,arguments);i?clearTimeout(i):(vs.call(this),e=T(r=n||t.mouse(this)),E(a)),i=setTimeout((function(){i=null,L(a)}),50),F(),k(Math.pow(2,.002*Nt())*f.k),M(r,e),C(a)}function O(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;A(this,e,T(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return jt||(jt=\"onwheel\"in a?(Nt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in a?(Nt=function(){return t.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each((function(){var e=_.of(this,arguments),n=f;bs?t.select(this).transition().each(\"start.zoom\",(function(){f=this.__chart__||{x:0,y:0,k:1},E(e)})).tween(\"zoom:zoom\",(function(){var a=p[0],i=p[1],o=r?r[0]:a/2,s=r?r[1]:i/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,a/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,a/n.k]);return function(t){var r=l(t),n=a/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}})).each(\"interrupt.zoom\",(function(){L(e)})).each(\"end.zoom\",(function(){L(e)})):(this.__chart__=f,E(e),C(e),L(e))}))},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},k(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):le(\"\"+t,ce,qt):new qt(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,a;function i(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(a-n)*t/60:t<180?a:t<240?n+(a-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(a=r<=.5?r*(1+e):r+e-r*e),new ne(i(t+120),i(t),i(t-120))}function Yt(e,r,n){return this instanceof Yt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Yt?new Yt(e.h,e.c,e.l):$t(e instanceof Xt?e.l:(e=ue((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Yt(e,r,n)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},t.hcl=Yt;var Wt=Yt.prototype=new Vt;function Zt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Yt?Zt(t.h,t.c,t.l):ue((t=ne(t)).r,t.g,t.b):new Xt(t,e,r)}Wt.brighter=function(t){return new Yt(this.h,this.c,Math.min(100,this.l+Jt*(arguments.length?t:1)))},Wt.darker=function(t){return new Yt(this.h,this.c,Math.max(0,this.l-Jt*(arguments.length?t:1)))},Wt.rgb=function(){return Zt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Jt=18,Kt=Xt.prototype=new Vt;function Qt(t,e,r){var n=(t+16)/116,a=n+e/500,i=n-r/200;return new ne(re(3.2404542*(a=.95047*te(a))-1.5371385*(n=1*te(n))-.4985314*(i=1.08883*te(i))),re(-.969266*a+1.8760108*n+.041556*i),re(.0556434*a-.2040259*n+1.0572252*i))}function $t(t,e,r){return t>0?new Yt(Math.atan2(r,e)*Pt,Math.sqrt(e*e+r*r),t):new Yt(NaN,NaN,t)}function te(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ee(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function re(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ne(t,e,r){return this instanceof ne?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ne?new ne(t.r,t.g,t.b):le(\"\"+t,ne,Gt):new ne(t,e,r)}function ae(t){return new ne(t>>16,t>>8&255,255&t)}function ie(t){return ae(t)+\"\"}Kt.brighter=function(t){return new Xt(Math.min(100,this.l+Jt*(arguments.length?t:1)),this.a,this.b)},Kt.darker=function(t){return new Xt(Math.max(0,this.l-Jt*(arguments.length?t:1)),this.a,this.b)},Kt.rgb=function(){return Qt(this.l,this.a,this.b)},t.rgb=ne;var oe=ne.prototype=new Vt;function se(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function le(t,e,r){var n,a,i,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(a=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(a[0]),parseFloat(a[1])/100,parseFloat(a[2])/100);case\"rgb\":return e(fe(a[0]),fe(a[1]),fe(a[2]))}return(i=pe.get(t))?e(i.r,i.g,i.b):(null==t||\"#\"!==t.charAt(0)||isNaN(i=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&i)>>4,o|=o>>4,s=240&i,s|=s>>4,l=15&i,l|=l<<4):7===t.length&&(o=(16711680&i)>>16,s=(65280&i)>>8,l=255&i)),e(o,s,l))}function ce(t,e,r){var n,a,i=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-i,l=(o+i)/2;return s?(a=l<.5?s/(o+i):s/(2-o-i),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,a=l>0&&l<1?0:n),new qt(n,a,l)}function ue(t,e,r){var n=ee((.4124564*(t=he(t))+.3575761*(e=he(e))+.1804375*(r=he(r)))/.95047),a=ee((.2126729*t+.7151522*e+.072175*r)/1);return Xt(116*a-16,500*(n-a),200*(a-ee((.0193339*t+.119192*e+.9503041*r)/1.08883)))}function he(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function fe(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}oe.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,a=30;return e||r||n?(e&&e<a&&(e=a),r&&r<a&&(r=a),n&&n<a&&(n=a),new ne(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ne(a,a,a)},oe.darker=function(t){return new ne((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},oe.hsl=function(){return ce(this.r,this.g,this.b)},oe.toString=function(){return\"#\"+se(this.r)+se(this.g)+se(this.b)};var pe=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function de(t){return\"function\"==typeof t?t:function(){return t}}function ge(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),me(e,r,t,n)}}function me(e,r,a,i){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=a.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return this.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(e)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return a=t,o},[\"get\",\"post\"].forEach((function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}})),o.send=function(t,n,a){if(2===arguments.length&&\"function\"==typeof n&&(a=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var i in l)c.setRequestHeader(i,l[i]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=a&&o.on(\"error\",a).on(\"load\",(function(t){a(null,t)})),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==i?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(i))}pe.forEach((function(t,e){pe.set(t,ae(e))})),t.functor=de,t.xhr=ge(L),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function a(t,r,n){arguments.length<3&&(n=r,r=null);var a=me(t,e,null==r?i:o(r),n);return a.row=function(t){return arguments.length?a.response(null==(r=t)?i:o(t)):r},a}function i(t){return a.parse(t.responseText)}function o(t){return function(e){return a.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return a.parse=function(t,e){var r;return a.parseRows(t,(function(t,n){if(r)return r(t,n-1);var a=new Function(\"d\",\"return {\"+t.map((function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"})).join(\",\")+\"}\");r=e?function(t,r){return e(a(t),r)}:a}))},a.parseRows=function(t,e){var r,a,i={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(a)return a=!1,i;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(a=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(a=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))a=!0;else if(13===s)a=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==i&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},a.format=function(e){if(Array.isArray(e[0]))return a.formatRows(e);var r=new C,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},a.formatRows=function(t){return t.map(s).join(\"\\n\")},a},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var ve,ye,xe,be,_e=this[I(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function we(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var a=r+e,i={c:t,t:a,n:null};return ye?ye.n=i:ve=i,ye=i,xe||(be=clearTimeout(be),xe=1,_e(Te)),i}function Te(){var t=ke(),e=Me()-t;e>24?(isFinite(e)&&(clearTimeout(be),be=setTimeout(Te,e)),xe=0):(xe=1,_e(Te))}function ke(){for(var t=Date.now(),e=ve;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Me(){for(var t,e=ve,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:ve=e.n;return ye=t,r}function Ae(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){we.apply(this,arguments)},t.timer.flush=function(){ke(),Me()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Se=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map((function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}}));function Ee(e){var r=e.decimal,n=e.thousands,a=e.grouping,i=e.currency,o=a&&n?function(t,e){for(var r=t.length,i=[],o=0,s=a[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),i.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=a[o=(o+1)%a.length];return i.reverse().join(n)}:L;return function(e){var n=Ce.exec(e),a=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,m=\"\",v=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===a&&\"=\"===s)&&(u=a=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,v=\"%\",d=\"f\";break;case\"p\":g=100,v=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(m=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(m=i[0],v=i[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Le.get(d)||Pe;var b=u&&f;return function(e){var n=v;if(y&&e%1)return\"\";var i=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+v}else e*=g;var _,w,T=(e=d(e,p)).lastIndexOf(\".\");if(T<0){var k=x?e.lastIndexOf(\"e\"):-1;k<0?(_=e,w=\"\"):(_=e.substring(0,k),w=e.substring(k))}else _=e.substring(0,T),w=r+e.substring(T+1);!u&&f&&(_=o(_,1/0));var M=m.length+_.length+w.length+(b?0:i.length),A=M<h?new Array(M=h-M+1).join(a):\"\";return b&&(_=o(A+_,A.length?h-w.length:1/0)),i+=m,e=_+w,(\"<\"===s?i+e+A:\">\"===s?A+i+e:\"^\"===s?A.substring(0,M>>=1)+i+e+A.substring(M):i+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ae(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Se[8+n/3]};var Ce=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Le=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ae(e,r))).toFixed(Math.max(0,Math.min(20,Ae(e*(1+1e-15),r))))}});function Pe(t){return t+\"\"}var Ie=t.time={},ze=Date;function Oe(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Oe.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){De.setUTCDate.apply(this._,arguments)},setDay:function(){De.setUTCDay.apply(this._,arguments)},setFullYear:function(){De.setUTCFullYear.apply(this._,arguments)},setHours:function(){De.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){De.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){De.setUTCMinutes.apply(this._,arguments)},setMonth:function(){De.setUTCMonth.apply(this._,arguments)},setSeconds:function(){De.setUTCSeconds.apply(this._,arguments)},setTime:function(){De.setTime.apply(this._,arguments)}};var De=Date.prototype;function Re(t,e,r){function n(e){var r=t(e),n=i(r,1);return e-r<n-e?r:n}function a(r){return e(r=t(new ze(r-1)),1),r}function i(t,r){return e(t=new ze(+t),r),t}function o(t,n,i){var o=a(t),s=[];if(i>1)for(;o<n;)r(o)%i||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=a,t.offset=i,t.range=o;var s=t.utc=Fe(t);return s.floor=s,s.round=Fe(n),s.ceil=Fe(a),s.offset=Fe(i),s.range=function(t,e,r){try{ze=Oe;var n=new Oe;return n._=t,o(n,e,r)}finally{ze=Date}},t}function Fe(t){return function(e,r){try{ze=Oe;var n=new Oe;return n._=e,t(n,r)._}finally{ze=Date}}}function Be(e){var r=e.dateTime,n=e.date,a=e.time,i=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,a,i,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(a=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(i=_[n])&&(n=i(r,null==a?\"e\"===n?\" \":\"0\":a)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&ze!==Oe,a=new(n?Oe:ze);return\"j\"in r?a.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),a.setFullYear(r.y,0,1),a.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(a.getDay()+5)%7:r.w+7*r.U-(a.getDay()+6)%7)):a.setFullYear(r.y,r.m,r.d),a.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?a._:a},r.toString=function(){return t},r}function h(t,e,r,n){for(var a,i,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(a=e.charCodeAt(s++))){if(o=e.charAt(s++),!(i=w[o in Ne?e.charAt(s++):o])||(n=i(t,r,n))<0)return-1}else if(a!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(ze=Oe);return r._=t,e(r)}finally{ze=Date}}return r.parse=function(t){try{ze=Oe;var r=e.parse(t);return r&&r._}finally{ze=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),m=He(s),v=qe(l),y=He(l),x=qe(c),b=He(c);i.forEach((function(t,e){f.set(t.toLowerCase(),e)}));var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+Ie.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return i[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(Ie.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(Ie.mondayOfYear(t),e,2)},x:u(n),X:u(a),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ar,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=m.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){v.lastIndex=0;var n=v.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Xe,Y:Ze,Z:Je,\"%\":ir};return u}Ie.year=Re((function(t){return(t=Ie.day(t)).setMonth(0,1),t}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t){return t.getFullYear()})),Ie.years=Ie.year.range,Ie.years.utc=Ie.year.utc.range,Ie.day=Re((function(t){var e=new ze(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t){return t.getDate()-1})),Ie.days=Ie.day.range,Ie.days.utc=Ie.day.utc.range,Ie.dayOfYear=function(t){var e=Ie.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach((function(t,e){e=7-e;var r=Ie[t]=Re((function(t){return(t=Ie.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t}),(function(t,e){t.setDate(t.getDate()+7*Math.floor(e))}),(function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)-(r!==e)}));Ie[t+\"s\"]=r.range,Ie[t+\"s\"].utc=r.utc.range,Ie[t+\"OfYear\"]=function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)}})),Ie.week=Ie.sunday,Ie.weeks=Ie.sunday.range,Ie.weeks.utc=Ie.sunday.utc.range,Ie.weekOfYear=Ie.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",a=(n?-t:t)+\"\",i=a.length;return n+(i<r?new Array(r-i+1).join(e)+a:a)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new _,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n,a=je.exec(e.slice(r,r+2));return a?(t.y=(n=+a[0])+(n>68?1900:2e3),r+a[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ar(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,a=y(e)%60;return r+Ve(n,\"0\",2)+Ve(a,\"0\",2)}function ir(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ee(t),timeFormat:Be(t)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,a=n-t,i=n-a;r.t=t-i+(e-a)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,a=r.length;++n<a;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,a=r.length;++n<a;)hr(r[n],e)}};function dr(t,e,r){var n,a=-1,i=t.length-r;for(e.lineStart();++a<i;)n=t[a],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return mr=0,t.geo.stream(e,Cr),mr};var mr,vr,yr,xr,br,_r,wr,Tr,kr,Mr,Ar,Sr,Er=new lr,Cr={sphere:function(){mr+=4*At},point:O,lineStart:O,lineEnd:O,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;mr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=O}};function Lr(){var t,e,r,n,a;function i(t,e){e=e*Lt/2+At/4;var i=(t*=Lt)-r,o=i>=0?1:-1,s=o*i,l=Math.cos(e),c=Math.sin(e),u=a*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,a=c}Cr.point=function(o,s){Cr.point=i,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+At/4),a=Math.sin(s)},Cr.lineEnd=function(){i(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Ir(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Or(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,a,i,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:m,polygonStart:function(){f.point=v,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=m,Er<0?(e=-(n=180),r=-(a=90)):c>kt?a=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,i){u.push(h=[e=t,n=t]),i<r&&(r=i),i>a&&(a=i)}function d(t,o){var s=Pr([t*Lt,o*Lt]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-i,f=h>0?1:-1,d=u[0]*Pt*f,g=y(h)>180;if(g^(f*i<d&&d<f*t))(m=u[1]*Pt)>a&&(a=m);else if(g^(f*i<(d=(d+360)%360-180)&&d<f*t)){var m;(m=-u[1]*Pt)<r&&(r=m)}else o<r&&(r=o),o>a&&(a=o);g?t<i?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>i?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,i=t}function g(){f.point=d}function m(){h[0]=e,h[1]=n,f.point=p,l=null}function v(t,e){if(l){var r=t-i;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){v(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function T(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(i){if(a=n=-(e=r=1/0),u=[],t.geo.stream(i,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)T((p=u[o])[0],g)||T(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,a]]}}(),t.geo.centroid=function(e){vr=yr=xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,Nr);var r=Mr,n=Ar,a=Sr,i=r*r+n*n+a*a;return i<Mt&&(r=wr,n=Tr,a=kr,yr<kt&&(r=xr,n=br,a=_r),(i=r*r+n*n+a*a)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*Pt,Dt(a/Math.sqrt(i))*Pt]};var Nr={sphere:O,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Lt;var r=Math.cos(e*=Lt);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){++vr,xr+=(t-xr)/vr,br+=(e-br)/vr,_r+=(r-_r)/vr}function Vr(){var t,e,r;function n(n,a){n*=Lt;var i=Math.cos(a*=Lt),o=i*Math.cos(n),s=i*Math.sin(n),l=Math.sin(a),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),Tr+=c*(e+(e=s)),kr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(a,i){a*=Lt;var o=Math.cos(i*=Lt);t=o*Math.cos(a),e=o*Math.sin(a),r=Math.sin(i),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,a;function i(t,e){t*=Lt;var i=Math.cos(e*=Lt),o=i*Math.cos(t),s=i*Math.sin(t),l=Math.sin(e),c=n*l-a*s,u=a*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+a*l,d=f&&-Ot(p)/f,g=Math.atan2(f,p);Mr+=d*c,Ar+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),Tr+=g*(n+(n=s)),kr+=g*(a+(a=l)),Ur(r,n,a)}Nr.point=function(o,s){t=o,e=s,Nr.point=i,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),a=Math.sin(s),Ur(r,n,a)},Nr.lineEnd=function(){i(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,a){var i=[],o=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){a.lineStart();for(var s=0;s<e;++s)a.point((r=t[s])[0],r[1]);a.lineEnd()}else{var l=new Xr(r,t,null,!0),c=new Xr(r,null,l,!1);l.o=c,i.push(l),o.push(c),l=new Xr(n,t,null,!1),c=new Xr(n,null,l,!0),l.o=c,i.push(l),o.push(c)}}})),o.sort(e),Zr(i),Zr(o),i.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=i[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,a.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)a.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,a);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)a.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,a);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);a.lineEnd()}}}function Zr(t){if(e=t.length){for(var e,r,n=0,a=t[0];++n<e;)a.n=r=t[n],r.p=a,a=r;a.n=r=t[0],r.p=a}}function Xr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,a){return function(i,o){var s,l=r(o),c=i.invert(a[0],a[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],a=[Math.sin(r),-Math.cos(r),0],i=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),m=1;;){m===u&&(m=0);var v=(t=c[m])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=v-f,w=_>=0?1:-1,T=w*_,k=T>At,M=d*x;if(Er.add(Math.atan2(M*w*Math.sin(T),g*b+M*Math.cos(T))),i+=k?_+w*St:_,k^f>=r^v>=r){var A=zr(Pr(h),Pr(t));Rr(A);var S=zr(a,A);Rr(S);var E=(k^_>=0?-1:1)*Dt(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=k^_>=0?1:-1)}if(!m++)break;f=v,d=x,g=b,h=t}}return(i<-kt||i<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=i(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=i(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,m,v=Qr(),y=r(v),x=!1;function b(t,e){m.push([t,e]);var r=i(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),m=[]}function w(){b(m[0][0],m[0][1]),y.lineEnd();var t,e=y.clean(),r=v.buffer(),n=r.length;if(m.pop(),g.push(m),m=null,n)if(1&e){var a,i=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++i<n;)o.point((a=t[i])[0],a[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:O,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Ct-kt:Ct-t[1])-((e=e.x)[0]<0?e[1]-Ct-kt:Ct-e[1])}var tn=Jr(Yr,(function(t){var e,r=NaN,n=NaN,a=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(i,o){var s=i>0?At:-At,l=y(i-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Ct:-Ct),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(i,n),e=0):a!==s&&l>=At&&(y(r-a)<kt&&(r-=a*kt),y(i-s)<kt&&(i-=s*kt),n=function(t,e,r,n){var a,i,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(i=Math.cos(n))*Math.sin(r)-Math.sin(n)*(a=Math.cos(e))*Math.sin(t))/(a*i*o)):(e+n)/2}(r,n,i,o),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=i,n=o),a=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var a;if(null==t)a=r*Ct,n.point(-At,a),n.point(0,a),n.point(At,a),n.point(At,0),n.point(At,-a),n.point(0,-a),n.point(-At,-a),n.point(-At,0),n.point(-At,a);else if(y(t[0]-e[0])>kt){var i=t[0]<e[0]?At:-At;a=r*i/2,n.point(-i,a),n.point(0,a),n.point(i,a)}else n.point(e[0],e[1])}),[-At,-At/2]);function en(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(a,(function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=a(h,f),m=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=i(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=a(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=i(d,e),t.point(p[0],p[1])):(p=i(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var v;m&s||!(v=i(d,e,!0))||(u=0,r?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=m},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}}),Bn(t,6*Lt),r?[0,-t]:[-At,t-At]);function a(t,r){return Math.cos(t)*Math.cos(r)>e}function i(t,r,n){var a=[1,0,0],i=zr(Pr(t),Pr(r)),o=Ir(i,i),s=i[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(a,i),f=Dr(a,c);Or(f,Dr(i,u));var p=h,d=Ir(f,p),g=Ir(p,p),m=d*d-g*(Ir(f,f)-1);if(!(m<0)){var v=Math.sqrt(m),x=Dr(p,(-d-v)/g);if(Or(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],T=t[1],k=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-At)<kt;if(!A&&k<T&&(b=T,T=k,k=b),A||M<kt?A?T+k>0^x[1]<(y(x[0]-_)<kt?T:k):T<=x[1]&&x[1]<=k:M>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+v)/g);return Or(S,f),[x,Fr(S)]}}}function o(e,n){var a=r?t:At-t,i=0;return e<-a?i|=1:e>a&&(i|=2),n<-a?i|=4:n>a&&(i|=8),i}}function rn(t,e,r,n){return function(a){var i,o=a.a,s=a.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(i=t-l,f||!(i>0)){if(i/=f,f<0){if(i<u)return;i<h&&(h=i)}else if(f>0){if(i>h)return;i>u&&(u=i)}if(i=r-l,f||!(i<0)){if(i/=f,f<0){if(i>h)return;i>u&&(u=i)}else if(f>0){if(i<u)return;i<h&&(h=i)}if(i=e-c,p||!(i>0)){if(i/=p,p<0){if(i<u)return;i<h&&(h=i)}else if(p>0){if(i>h)return;i>u&&(u=i)}if(i=n-c,p||!(i<0)){if(i/=p,p<0){if(i>h)return;i>u&&(u=i)}else if(p>0){if(i<u)return;i<h&&(h=i)}return u>0&&(a.a={x:l+u*f,y:c+u*p}),h<1&&(a.b={x:l+h*f,y:c+h*p}),a}}}}}}function nn(e,r,n,a){return function(l){var c,u,h,f,p,d,g,m,v,y,x,b=l,_=Qr(),w=rn(e,r,n,a),T={point:A,lineStart:function(){T.point=S,u&&u.push(h=[]);y=!0,v=!1,g=m=NaN},lineEnd:function(){c&&(S(f,p),d&&v&&_.rejoin(),c.push(_.buffer()));T.point=A,v&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],a=0;a<r;++a)for(var i,o=1,s=u[a],l=s.length,c=s[0];o<l;++o)i=s[o],c[1]<=n?i[1]>n&&zt(c,i,t)>0&&++e:i[1]<=n&&zt(c,i,t)<0&&--e,c=i;return 0!==e}([e,a]),n=x&&r,i=c.length;(n||i)&&(l.polygonStart(),n&&(l.lineStart(),k(null,null,1,l),l.lineEnd()),i&&Wr(c,o,r,k,l),l.polygonEnd()),c=u=h=null}};function k(t,o,l,c){var u=0,h=0;if(null==t||(u=i(t,l))!==(h=i(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?a:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function M(t,i){return e<=t&&t<=n&&r<=i&&i<=a}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-1e9,Math.min(1e9,t)),e=Math.max(-1e9,Math.min(1e9,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&v)l.point(t,e);else{var n={a:{x:g,y:m},b:{x:t,y:e}};w(n)?(v||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,m=e,v=r}return T};function i(t,a){return y(t[0]-e)<kt?a>0?0:3:y(t[0]-n)<kt?a>0?2:1:y(t[1]-r)<kt?a>0?1:0:a>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=i(t,1),n=i(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Ln(t),a=n(e,r);return a.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},a}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,a=1+r*(2*n-r),i=Math.sqrt(a)/n;function o(t,e){var r=Math.sqrt(a-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),i-r*Math.cos(t)]}return o.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,Dt((a-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,a,i,o={stream:function(t){return a&&(a.valid=!1),(a=i(t)).valid=!0,a},extent:function(s){return arguments.length?(i=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),a&&(a.valid=!1,a=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,a,i=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var i=t[0],o=t[1];return e=null,r(i,o),e||(n(i,o),e)||a(i,o),e}return c.invert=function(t){var e=i.scale(),r=i.translate(),n=(t[0]-r[0])/e,a=(t[1]-r[1])/e;return(a>=.12&&a<.234&&n>=-.425&&n<-.214?o:a>=.166&&a<.234&&n>=-.214&&n<-.115?s:i).invert(t)},c.stream=function(t){var e=i.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,a){e.point(t,a),r.point(t,a),n.point(t,a)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(i.precision(t),o.precision(t),s.precision(t),c):i.precision()},c.scale=function(t){return arguments.length?(i.scale(t),o.scale(.35*t),s.scale(t),c.translate(i.translate())):i.scale()},c.translate=function(t){if(!arguments.length)return i.translate();var e=i.scale(),u=+t[0],h=+t[1];return r=i.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,a=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:O,lineStart:O,lineEnd:O,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=O,sn+=y(ln/2)}};function dn(){var t,e,r,n;function a(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(i,o){pn.point=a,t=r=i,e=n=o},pn.lineEnd=function(){a(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:O,lineEnd:O,polygonStart:O,polygonEnd:O};function mn(){var t=vn(4.5),e=[],r={point:n,lineStart:function(){r.point=a},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=vn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function a(t,n){e.push(\"M\",t,\",\",n),r.point=i}function i(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function vn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=Tn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var a=r-t,i=n-e,o=Math.sqrt(a*a+i*i);wr+=o*(t+r)/2,Tr+=o*(e+n)/2,kr+=o,bn(t=r,e=n)}xn.point=function(n,a){xn.point=r,bn(t=n,e=a)}}function wn(){xn.point=bn}function Tn(){var t,e,r,n;function a(t,e){var a=t-r,i=e-n,o=Math.sqrt(a*a+i*i);wr+=o*(r+t)/2,Tr+=o*(n+e)/2,kr+=o,Mr+=(o=n*t-r*e)*(r+t),Ar+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(i,o){xn.point=a,bn(t=r=i,e=n=o)},xn.lineEnd=function(){a(t,e)}}function kn(t){var e=4.5,r={point:n,lineStart:function(){r.point=a},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:O};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,St)}function a(e,n){t.moveTo(e,n),r.point=i}function i(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Mn(t){var e=.5,r=Math.cos(30*Lt),n=16;function a(t){return(n?o:i)(t)}function i(e){return En(e,(function(r,n){r=t(r,n),e.point(r[0],r[1])}))}function o(e){var r,a,i,o,l,c,u,h,f,p,d,g,m={point:v,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),m.lineStart=_},polygonEnd:function(){e.polygonEnd(),m.lineStart=y}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,m.point=x,e.lineStart()}function x(r,a){var i=Pr([r,a]),o=t(r,a);s(h,f,u,p,d,g,h=o[0],f=o[1],u=r,p=i[0],d=i[1],g=i[2],n,e),e.point(h,f)}function b(){m.point=v,e.lineEnd()}function _(){y(),m.point=w,m.lineEnd=T}function w(t,e){x(r=t,e),a=h,i=f,o=p,l=d,c=g,m.point=x}function T(){s(h,f,u,p,d,g,a,i,r,o,l,c,n,e),m.lineEnd=b,b()}return m}function s(n,a,i,o,l,c,u,h,f,p,d,g,m,v){var x=u-n,b=h-a,_=x*x+b*b;if(_>4*e&&m--){var w=o+p,T=l+d,k=c+g,M=Math.sqrt(w*w+T*T+k*k),A=Math.asin(k/=M),S=y(y(k)-1)<kt||y(i-f)<kt?(i+f)/2:Math.atan2(T,w),E=t(S,A),C=E[0],L=E[1],P=C-n,I=L-a,z=b*P-x*I;(z*z/_>e||y((x*P+b*I)/_-.5)>.3||o*p+l*d+c*g<r)&&(s(n,a,i,o,l,c,C,L,S,w/=M,T/=M,k,m,v),v.point(C,L),s(C,L,S,w,T,k,u,h,f,p,d,g,m,v))}}return a.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,a):Math.sqrt(e)},a}function An(t){var e=Mn((function(e,r){return t([e*Pt,r*Pt])}));return function(t){return Pn(e(t))}}function Sn(t){this.stream=t}function En(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return Ln((function(){return t}))()}function Ln(e){var r,n,a,i,o,s,l=Mn((function(t,e){return[(t=r(t,e))[0]*c+i,o-t[1]*c]})),c=150,u=480,h=250,f=0,p=0,d=0,g=0,m=0,v=tn,y=L,x=null,b=null;function _(t){return[(t=a(t[0]*Lt,t[1]*Lt))[0]*c+i,o-t[1]*c]}function w(t){return(t=a.invert((t[0]-i)/c,(o-t[1])/c))&&[t[0]*Pt,t[1]*Pt]}function T(){a=Gr(n=On(d,g,m),r);var t=r(f,p);return i=u-t[0]*c,o=h+t[1]*c,k()}function k(){return s&&(s.valid=!1,s=null),_}return _.stream=function(t){return s&&(s.valid=!1),(s=Pn(v(n,l(y(t))))).valid=!0,s},_.clipAngle=function(t){return arguments.length?(v=null==t?(x=t,tn):en((x=+t)*Lt),k()):x},_.clipExtent=function(t){return arguments.length?(b=t,y=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):L,k()):b},_.scale=function(t){return arguments.length?(c=+t,T()):c},_.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},_.center=function(t){return arguments.length?(f=t[0]%360*Lt,p=t[1]%360*Lt,T()):[f*Pt,p*Pt]},_.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,m=t.length>2?t[2]%360*Lt:0,T()):[d*Pt,g*Pt,m*Pt]},t.rebind(_,l,\"precision\"),function(){return r=e.apply(this,arguments),_.invert=r.invert&&w,T()}}function Pn(t){return En(t,(function(e,r){t.point(e*Lt,r*Lt)}))}function In(t,e){return[t,e]}function zn(t,e){return[t>At?t-St:t<-At?t+St:t,e]}function On(t,e,r){return t?e||r?Gr(Rn(t),Fn(e,r)):Rn(t):e||r?Fn(e,r):zn}function Dn(t){return function(e,r){return[(e+=t)>At?e-St:e<-At?e+St:e,r]}}function Rn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t),a=Math.cos(e),i=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*a-u*i,s*r-c*n),Dt(u*a+l*i)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*a-l*i;return[Math.atan2(l*a+c*i,s*r+u*n),Dt(u*r-s*n)]},o}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(a,i,o,s){var l=o*e;null!=a?(a=Nn(r,a),i=Nn(r,i),(o>0?a<i:a>i)&&(a+=o*St)):(a=t+o*St,i=t-.5*l);for(var c,u=a;o>0?u>i:u<i;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Nn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=Ot(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function jn(e,r,n){var a=t.range(e,r-kt,n).concat(r);return function(t){return a.map((function(e){return[t,e]}))}}function Un(e,r,n){var a=t.range(e,r-kt,n).concat(r);return function(t){return a.map((function(e){return[e,t]}))}}function Vn(t){return t.source}function qn(t){return t.target}t.geo.path=function(){var e,r,n,a,i,o=4.5;function s(e){return e&&(\"function\"==typeof o&&a.pointRadius(+o.apply(this,arguments)),i&&i.valid||(i=n(a)),t.geo.stream(e,i)),a.result()}function l(){return i=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,n(xn)),Sr?[Mr/Sr,Ar/Sr]:kr?[wr/kr,Tr/kr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||An(t):L,l()):e},s.context=function(t){return arguments.length?(a=null==(r=t)?new mn:new kn(t),\"function\"!=typeof o&&a.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(a.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Sn(e);for(var n in t)r[n]=t[n];return r}}},Sn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=Ln,(t.geo.equirectangular=function(){return Cn(In)}).raw=In.invert=In,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=Pt,e[1]*=Pt,e}return t=On(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=Pt,e[1]*=Pt,e},e},zn.invert=In,t.geo.circle=function(){var t,e,r=[0,0],n=6;function a(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=On(-t[0]*Lt,-t[1]*Lt,0).invert,a=[];return e(null,null,1,{point:function(t,e){a.push(t=n(t,e)),t[0]*=Pt,t[1]*=Pt}}),{type:\"Polygon\",coordinates:[a]}}return a.origin=function(t){return arguments.length?(r=t,a):r},a.angle=function(r){return arguments.length?(e=Bn((t=+r)*Lt,n*Lt),a):t},a.precision=function(r){return arguments.length?(e=Bn(t*Lt,(n=+r)*Lt),a):n},a.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,a=t[1]*Lt,i=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(a),c=Math.cos(a),u=Math.sin(i),h=Math.cos(i);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,a,i,o,s,l,c,u,h,f,p=10,d=p,g=90,m=360,v=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(a/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/m)*m,s,m).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter((function(t){return y(t%g)>kt})).map(c)).concat(t.range(Math.ceil(o/d)*d,i,d).filter((function(t){return y(t%m)>kt})).map(u))}return x.lines=function(){return b().map((function(t){return{type:\"LineString\",coordinates:t}}))},x.outline=function(){return{type:\"Polygon\",coordinates:[h(a).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(a=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],a>n&&(t=a,a=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(v)):[[a,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],i=+t[1][1],r>e&&(t=r,r=e,e=t),o>i&&(t=o,o=i,i=t),x.precision(v)):[[r,o],[e,i]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],m=+t[1],x):[g,m]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(v=+t,c=jn(o,i,90),u=Un(r,e,v),h=jn(l,s,90),f=Un(a,n,v),x):v},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,a=qn;function i(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||a.apply(this,arguments)]}}return i.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||a.apply(this,arguments))},i.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,i):n},i.target=function(t){return arguments.length?(a=t,r=\"function\"==typeof t?null:t,i):a},i.precision=function(){return arguments.length?i:0},i},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,a=e[0]*Lt,i=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(i),c=Math.sin(i),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(a),p=l*Math.sin(a),d=2*Math.asin(Math.sqrt(Ft(i-n)+o*l*Ft(a-r))),g=1/Math.sin(d),(m=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,a=r*h+e*p,i=r*s+e*c;return[Math.atan2(a,n)*Pt,Math.atan2(i,Math.sqrt(n*n+a*a))*Pt]}:function(){return[r*Pt,n*Pt]}).distance=d,m;var r,n,a,i,o,s,l,c,u,h,f,p,d,g,m},t.geo.length=function(e){return yn=0,t.geo.stream(e,Hn),yn};var Hn={sphere:O,point:O,lineStart:function(){var t,e,r;function n(n,a){var i=Math.sin(a*=Lt),o=Math.cos(a),s=y((n*=Lt)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*i-e*o*l)*s),e*i+r*o*l),t=n,e=i,r=o}Hn.point=function(a,i){t=a*Lt,e=Math.sin(i*=Lt),r=Math.cos(i),Hn.point=n},Hn.lineEnd=function(){Hn.point=Hn.lineEnd=O}},lineEnd:O,polygonStart:O,polygonEnd:O};function Gn(t,e){function r(e,r){var n=Math.cos(e),a=Math.cos(r),i=t(n*a);return[i*a*Math.sin(e),i*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),a=e(n),i=Math.sin(a),o=Math.cos(a);return[Math.atan2(t*i,n*o),Math.asin(n&&r*i/n)]},r}var Yn=Gn((function(t){return Math.sqrt(2/(1+t))}),(function(t){return 2*Math.asin(t/2)}));(t.geo.azimuthalEqualArea=function(){return Cn(Yn)}).raw=Yn;var Wn=Gn((function(t){var e=Math.acos(t);return e&&e/Math.sin(e)}),L);function Zn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},a=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),i=r*Math.pow(n(t),a)/a;if(!a)return Kn;function o(t,e){i>0?e<-Ct+kt&&(e=-Ct+kt):e>Ct-kt&&(e=Ct-kt);var r=i/Math.pow(n(e),a);return[r*Math.sin(a*t),i-r*Math.cos(a*t)]}return o.invert=function(t,e){var r=i-e,n=It(a)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/a,2*Math.atan(Math.pow(i/n,1/a))-Ct]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),a=r/n+t;if(y(n)<kt)return In;function i(t,e){var r=a-e;return[r*Math.sin(n*t),a-r*Math.cos(n*t)]}return i.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,a-It(n)*Math.sqrt(t*t+r*r)]},i}(t.geo.azimuthalEquidistant=function(){return Cn(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Zn)}).raw=Zn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Jn=Gn((function(t){return 1/t}),Math.atan);function Kn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Qn(t){var e,r=Cn(t),n=r.scale,a=r.translate,i=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=a.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=i.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=a();i([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Jn)}).raw=Jn,Kn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ct]},(t.geo.mercator=function(){return Qn(Kn)}).raw=Kn;var $n=Gn((function(){return 1}),Math.asin);(t.geo.orthographic=function(){return Cn($n)}).raw=$n;var ta=Gn((function(t){return 1/(1+t)}),(function(t){return 2*Math.atan(t)}));function ea(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ra(t){return t[0]}function na(t){return t[1]}function aa(t){for(var e=t.length,r=[0,1],n=2,a=2;a<e;a++){for(;n>1&&zt(t[r[n-2]],t[r[n-1]],t[a])<=0;)--n;r[n++]=a}return r.slice(0,n)}function ia(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(ta)}).raw=ta,ea.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ct]},(t.geo.transverseMercator=function(){var t=Qn(ea),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ea,t.geom={},t.geom.hull=function(t){var e=ra,r=na;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,a=de(e),i=de(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+a.call(this,t[n],n),+i.call(this,t[n],n),n]);for(s.sort(ia),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=aa(s),u=aa(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,oa),t};var oa=t.geom.polygon.prototype=[];function sa(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function la(t,e,r,n){var a=t[0],i=r[0],o=e[0]-a,s=n[0]-i,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(a-i))/(h*o-s*u);return[a+f*o,l+f*u]}function ca(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}oa.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],a=0;++e<r;)t=n,n=this[e],a+=t[1]*n[0]-t[0]*n[1];return.5*a},oa.centroid=function(t){var e,r,n=-1,a=this.length,i=0,o=0,s=this[a-1];for(arguments.length||(t=-1/(6*this.area()));++n<a;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],i+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[i*t,o*t]},oa.clip=function(t){for(var e,r,n,a,i,o,s=ca(t),l=-1,c=this.length-ca(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,a=this[l],i=e[(n=e.length-s)-1],r=-1;++r<n;)sa(o=e[r],u,a)?(sa(i,u,a)||t.push(la(i,o,u,a)),t.push(o)):sa(i,u,a)&&t.push(la(i,o,u,a)),i=o;s&&t.push(t[0]),u=a}return t};var ua,ha,fa,pa,da,ga=[],ma=[];function va(){Ra(this),this.edge=this.site=this.circle=null}function ya(t){var e=ga.pop()||new va;return e.site=t,e}function xa(t){Ea(t),fa.remove(t),ga.push(t),Ra(t)}function ba(t){var e=t.circle,r=e.x,n=e.cy,a={x:r,y:n},i=t.P,o=t.N,s=[t];xa(t);for(var l=i;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)i=l.P,s.unshift(l),xa(l),l=i;s.unshift(l),Ea(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),xa(c),c=o;s.push(c),Ea(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],za(c.edge,l.site,c.site,a);l=s[0],(c=s[h-1]).edge=Pa(l.site,c.site,null,a),Sa(l),Sa(c)}function _a(t){for(var e,r,n,a,i=t.x,o=t.y,s=fa._;s;)if((n=wa(s,o)-i)>kt)s=s.L;else{if(!((a=i-Ta(s,o))>kt)){n>-kt?(e=s.P,r=s):a>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=ya(t);if(fa.insert(e,l),e||r){if(e===r)return Ea(e),r=ya(e.site),fa.insert(l,r),l.edge=r.edge=Pa(e.site,l.site),Sa(e),void Sa(r);if(r){Ea(e),Ea(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,m=d.y-h,v=2*(f*m-p*g),y=f*f+p*p,x=g*g+m*m,b={x:(m*y-p*x)/v+u,y:(f*x-g*y)/v+h};za(r.edge,c,d,b),l.edge=Pa(c,t,null,b),r.edge=Pa(t,d,null,b),Sa(e),Sa(r)}else l.edge=Pa(e.site,l.site)}}function wa(t,e){var r=t.site,n=r.x,a=r.y,i=a-e;if(!i)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/i-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+a-i/2)))/h+n:(n+s)/2}function Ta(t,e){var r=t.N;if(r)return wa(r,e);var n=t.site;return n.y===e?n.x:1/0}function ka(t){this.site=t,this.edges=[]}function Ma(t,e){return e.angle-t.angle}function Aa(){Ra(this),this.x=this.y=this.arc=this.site=this.cy=null}function Sa(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,a=t.site,i=r.site;if(n!==i){var o=a.x,s=a.y,l=n.x-o,c=n.y-s,u=i.x-o,h=2*(l*(m=i.y-s)-c*u);if(!(h>=-Mt)){var f=l*l+c*c,p=u*u+m*m,d=(m*f-c*p)/h,g=(l*p-u*f)/h,m=g+s,v=ma.pop()||new Aa;v.arc=t,v.site=a,v.x=d+o,v.y=m+Math.sqrt(d*d+g*g),v.cy=m,t.circle=v;for(var y=null,x=da._;x;)if(v.y<x.y||v.y===x.y&&v.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}da.insert(y,v),y||(pa=v)}}}}function Ea(t){var e=t.circle;e&&(e.P||(pa=e.N),da.remove(e),ma.push(e),Ra(e),t.circle=null)}function Ca(t,e){var r=t.b;if(r)return!0;var n,a,i=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,m=(f+d)/2,v=(p+g)/2;if(g===p){if(m<o||m>=s)return;if(f>d){if(i){if(i.y>=c)return}else i={x:m,y:l};r={x:m,y:c}}else{if(i){if(i.y<l)return}else i={x:m,y:c};r={x:m,y:l}}}else if(a=v-(n=(f-d)/(g-p))*m,n<-1||n>1)if(f>d){if(i){if(i.y>=c)return}else i={x:(l-a)/n,y:l};r={x:(c-a)/n,y:c}}else{if(i){if(i.y<l)return}else i={x:(c-a)/n,y:c};r={x:(l-a)/n,y:l}}else if(p<g){if(i){if(i.x>=s)return}else i={x:o,y:n*o+a};r={x:s,y:n*s+a}}else{if(i){if(i.x<o)return}else i={x:s,y:n*s+a};r={x:o,y:n*o+a}}return t.a=i,t.b=r,!0}function La(t,e){this.l=t,this.r=e,this.a=this.b=null}function Pa(t,e,r,n){var a=new La(t,e);return ua.push(a),r&&za(a,t,e,r),n&&za(a,e,t,n),ha[t.i].edges.push(new Oa(a,t,e)),ha[e.i].edges.push(new Oa(a,e,t)),a}function Ia(t,e,r){var n=new La(t,null);return n.a=e,n.b=r,ua.push(n),n}function za(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oa(t,e,r){var n=t.a,a=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(a.x-n.x,n.y-a.y):Math.atan2(n.x-a.x,a.y-n.y)}function Da(){this._=null}function Ra(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fa(t,e){var r=e,n=e.R,a=r.U;a?a.L===r?a.L=n:a.R=n:t._=n,n.U=a,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ba(t,e){var r=e,n=e.L,a=r.U;a?a.L===r?a.L=n:a.R=n:t._=n,n.U=a,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Na(t){for(;t.L;)t=t.L;return t}function ja(t,e){var r,n,a,i=t.sort(Ua).pop();for(ua=[],ha=new Array(t.length),fa=new Da,da=new Da;;)if(a=pa,i&&(!a||i.y<a.y||i.y===a.y&&i.x<a.x))i.x===r&&i.y===n||(ha[i.i]=new ka(i),_a(i),r=i.x,n=i.y),i=t.pop();else{if(!a)break;ba(a.arc)}e&&(function(t){for(var e,r=ua,n=rn(t[0][0],t[0][1],t[1][0],t[1][1]),a=r.length;a--;)(!Ca(e=r[a],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(a,1))}(e),function(t){for(var e,r,n,a,i,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ha,m=g.length;m--;)if((i=g[m])&&i.prepare())for(l=(s=i.edges).length,o=0;o<l;)n=(u=s[o].end()).x,a=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(a-r)>kt)&&(s.splice(o,0,new Oa(Ia(i.site,u,y(n-h)<kt&&d-a>kt?{x:h,y:y(e-h)<kt?r:d}:y(a-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&a-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(a-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null),i.site,null)),++l)}(e));var o={cells:ha,edges:ua};return fa=da=ua=ha=null,o}function Ua(t,e){return e.y-t.y||e.x-t.x}ka.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ma),e.length},Oa.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Da.prototype={insert:function(t,e){var r,n,a;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Na(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(a=n.R)&&a.C?(r.C=a.C=!1,n.C=!0,t=n):(t===r.R&&(Fa(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ba(this,n)):(a=n.L)&&a.C?(r.C=a.C=!1,n.C=!0,t=n):(t===r.L&&(Ba(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fa(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,a=t.U,i=t.L,o=t.R;if(r=i?o?Na(o):i:o,a?a.L===t?a.L=r:a.R=r:this._=r,i&&o?(n=r.C,r.C=t.C,r.L=i,i.U=r,r!==o?(a=r.U,r.U=t.U,t=r.R,a.L=t,r.R=o,o.U=r):(r.U=a,a=r,t=r.R)):(n=t.C,t=r),t&&(t.U=a),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===a.L){if((e=a.R).C&&(e.C=!1,a.C=!0,Fa(this,a),e=a.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ba(this,e),e=a.R),e.C=a.C,a.C=e.R.C=!1,Fa(this,a),t=this._;break}}else if((e=a.L).C&&(e.C=!1,a.C=!0,Ba(this,a),e=a.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fa(this,e),e=a.L),e.C=a.C,a.C=e.L.C=!1,Ba(this,a),t=this._;break}e.C=!0,t=a,a=a.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ra,r=na,n=e,a=r,i=Va;if(t)return o(t);function o(t){var e=new Array(t.length),r=i[0][0],n=i[0][1],a=i[1][0],o=i[1][1];return ja(s(t),i).cells.forEach((function(i,s){var l=i.edges,c=i.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=a&&c.y>=n&&c.y<=o?[[r,o],[a,o],[a,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(a(t,e)/kt)*kt,i:e}}))}return o.links=function(t){return ja(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return ja(s(t)).cells.forEach((function(r,n){for(var a,i,o,s,l=r.site,c=r.edges.sort(Ma),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,a=p,p=(f=c[u].edge).l===l?f.r:f.l,n<a.i&&n<p.i&&(o=a,s=p,((i=l).x-s.x)*(o.y-i.y)-(i.x-o.x)*(s.y-i.y)<0)&&e.push([t[n],t[a.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=de(e=t),o):e},o.y=function(t){return arguments.length?(a=de(r=t),o):r},o.clipExtent=function(t){return arguments.length?(i=null==t?Va:t,o):i===Va?null:i},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):i===Va?null:i&&i[1]},o};var Va=[[-1e6,-1e6],[1e6,1e6]];function qa(t){return t.x}function Ha(t){return t.y}function Ga(t,e,r,n,a,i){if(!t(e,r,n,a,i)){var o=.5*(r+a),s=.5*(n+i),l=e.nodes;l[0]&&Ga(t,l[0],r,n,o,s),l[1]&&Ga(t,l[1],o,n,a,s),l[2]&&Ga(t,l[2],r,s,o,i),l[3]&&Ga(t,l[3],o,s,a,i)}}function Ya(t,e,r,n,a,i,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>i||h>o||f<n||p<a)){if(d=c.point){var d,g=e-c.x,m=r-c.y,v=g*g+m*m;if(v<l){var y=Math.sqrt(l=v);n=e-y,a=r-y,i=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,a,i,o),s}function Wa(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,a=e.g,i=e.b,o=r.r-n,s=r.g-a,l=r.b-i;return function(t){return\"#\"+se(Math.round(n+o*t))+se(Math.round(a+s*t))+se(Math.round(i+l*t))}}function Za(t,e){var r,n={},a={};for(r in t)r in e?n[r]=$a(t[r],e[r]):a[r]=t[r];for(r in e)r in t||(a[r]=e[r]);return function(t){for(r in n)a[r]=n[r](t);return a}}function Xa(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ja(t,e){var r,n,a,i=Ka.lastIndex=Qa.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Ka.exec(t))&&(n=Qa.exec(e));)(a=n.index)>i&&(a=e.slice(i,a),s[o]?s[o]+=a:s[++o]=a),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Xa(r,n)})),i=Qa.lastIndex;return i<e.length&&(a=e.slice(i),s[o]?s[o]+=a:s[++o]=a),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,a){var i,o=ra,s=na;if(i=arguments.length)return o=qa,s=Ha,3===i&&(a=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,m,v=de(o),x=de(s);if(null!=e)p=e,d=r,g=n,m=a;else if(g=m=-(p=d=1/0),c=[],u=[],f=t.length,i)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>m&&(m=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+v(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>m&&(m=_),c.push(b),u.push(_)}var w=g-p,T=m-d;function k(t,e,r,n,a,i,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,a,i,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,a,i,o,s),M(t,e,r,n,a,i,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,a,i,o,s)}function M(t,e,r,n,a,i,o,s){var l=.5*(a+o),c=.5*(i+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?a=l:o=l,h?i=c:s=c,k(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,a,i,o,s)}w>T?m=d+w:g=p+T;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(A,t,+v(t,++h),+x(t,h),p,d,g,m)},visit:function(t){Ga(t,A,p,d,g,m)},find:function(t){return Ya(A,t[0],t[1],p,d,g,m)}};if(h=-1,null==e){for(;++h<f;)k(A,t[h],c[h],u[h],p,d,g,m);--h}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=a=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],a=+t[1][1]),l):null==e?null:[[e,r],[n,a]]},l.size=function(t){return arguments.length?(null==t?e=r=n=a=null:(e=r=0,n=+t[0],a=+t[1]),l):null==e?null:[n-e,a-r]},l},t.interpolateRgb=Wa,t.interpolateObject=Za,t.interpolateNumber=Xa,t.interpolateString=Ja;var Ka=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Qa=new RegExp(Ka.source,\"g\");function $a(e,r){for(var n,a=t.interpolators.length;--a>=0&&!(n=t.interpolators[a](e,r)););return n}function ti(t,e){var r,n=[],a=[],i=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push($a(t[r],e[r]));for(;r<i;++r)a[r]=t[r];for(;r<o;++r)a[r]=e[r];return function(t){for(r=0;r<s;++r)a[r]=n[r](t);return a}}t.interpolate=$a,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?pe.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?Wa:Ja:e instanceof Vt?Wa:Array.isArray(e)?ti:\"object\"===r&&isNaN(e)?Za:Xa)(t,e)}],t.interpolateArray=ti;var ei=function(){return L},ri=t.map({linear:ei,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return si},cubic:function(){return li},sin:function(){return ui},exp:function(){return hi},circle:function(){return fi},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/St*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*St/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return pi}}),ni=t.map({in:L,out:ii,\"in-out\":oi,\"out-in\":function(t){return oi(ii(t))}});function ai(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function ii(t){return function(e){return 1-t(1-e)}}function oi(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function si(t){return t*t}function li(t){return t*t*t}function ci(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ui(t){return 1-Math.cos(t*Ct)}function hi(t){return Math.pow(2,10*(t-1))}function fi(t){return 1-Math.sqrt(1-t*t)}function pi(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function di(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function gi(t){var e,r,n,a=[t.a,t.b],i=[t.c,t.d],o=vi(a),s=mi(a,i),l=vi(((e=i)[0]+=(n=-s)*(r=a)[0],e[1]+=n*r[1],e))||0;a[0]*i[1]<i[0]*a[1]&&(a[0]*=-1,a[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(a[1],a[0]):Math.atan2(-i[0],i[1]))*Pt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Pt:0}function mi(t,e){return t[0]*e[0]+t[1]*e[1]}function vi(t){var e=Math.sqrt(mi(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e=t.indexOf(\"-\"),n=e>=0?t.slice(0,e):t,a=e>=0?t.slice(e+1):\"in\";return n=ri.get(n)||ei,ai((a=ni.get(a)||L)(n.apply(null,r.call(arguments,1))))},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,a=e.c,i=e.l,o=r.h-n,s=r.c-a,l=r.l-i;isNaN(s)&&(s=0,a=isNaN(a)?r.c:a);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Zt(n+o*t,a+s*t,i+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,a=e.s,i=e.l,o=r.h-n,s=r.s-a,l=r.l-i;isNaN(s)&&(s=0,a=isNaN(a)?r.s:a);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Gt(n+o*t,a+s*t,i+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,a=e.a,i=e.b,o=r.l-n,s=r.a-a,l=r.b-i;return function(t){return Qt(n+o*t,a+s*t,i+l*t)+\"\"}},t.interpolateRound=di,t.transform=function(e){var r=a.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new gi(e?e.matrix:yi)})(e)},gi.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var yi={a:1,b:0,c:0,d:1,e:0,f:0};function xi(t){return t.length?t.pop()+\",\":\"\"}function bi(e,r){var n=[],a=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var a=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:a-4,x:Xa(t[0],e[0])},{i:a-2,x:Xa(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,a),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(xi(r)+\"rotate(\",null,\")\")-2,x:Xa(t,e)})):e&&r.push(xi(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,a),function(t,e,r,n){t!==e?n.push({i:r.push(xi(r)+\"skewX(\",null,\")\")-2,x:Xa(t,e)}):e&&r.push(xi(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,a),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var a=r.push(xi(r)+\"scale(\",null,\",\",null,\")\");n.push({i:a-4,x:Xa(t[0],e[0])},{i:a-2,x:Xa(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(xi(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,a),e=r=null,function(t){for(var e,r=-1,i=a.length;++r<i;)n[(e=a[r]).i]=e.x(t);return n.join(\"\")}}function _i(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function wi(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Ti(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=ki(t),n=ki(e),a=r.pop(),i=n.pop(),o=null;for(;a===i;)o=a,a=r.pop(),i=n.pop();return o}(e,r),a=[e];e!==n;)e=e.parent,a.push(e);for(var i=a.length;r!==n;)a.splice(i,0,r),r=r.parent;return a}function ki(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Mi(t){t.fixed|=2}function Ai(t){t.fixed&=-7}function Si(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Ei(t){t.fixed&=-5}t.interpolateTransform=bi,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Ti(t[r]));return e}},t.layout.chord=function(){var e,r,n,a,i,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},m=[],v=t.range(a),y=[];for(e=[],r=[],l=0,p=-1;++p<a;){for(u=0,d=-1;++d<a;)u+=n[p][d];m.push(u),y.push(t.range(a)),l+=u}for(i&&v.sort((function(t,e){return i(m[t],m[e])})),o&&y.forEach((function(t,e){t.sort((function(t,r){return o(n[e][t],n[e][r])}))})),l=(St-c*a)/l,u=0,p=-1;++p<a;){for(f=u,d=-1;++d<a;){var x=v[p],b=y[x][d],_=n[x][b],w=u,T=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:T,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:m[x]},u+=c}for(p=-1;++p<a;)for(d=p-1;++d<a;){var k=g[p+\"-\"+d],M=g[d+\"-\"+p];(k.value||M.value)&&e.push(k.value<M.value?{source:M,target:k}:{source:k,target:M})}s&&h()}function h(){e.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(t){return arguments.length?(a=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(i=t,e=r=null,l):i},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,a,i,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ci,f=Li,p=-30,d=Pi,g=.1,m=.64,v=[],y=[];function x(t){return function(e,r,n,a){if(e.point!==t){var i=e.cx-t.x,o=e.cy-t.y,s=a-r,l=i*i+o*o;if(s*s/m<l){if(l<d){var c=e.charge/l;t.px-=i*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=i*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,m,b,_,w,T=v.length,k=y.length;for(s=0;s<k;++s)f=(h=y[s]).source,(m=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=m=n*i[s]*((m=Math.sqrt(m))-a[s])/m,w*=m,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<T;)(h=v[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var a=0,i=0;if(e.charge=0,!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,a+=o.charge*o.cx,i+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,a+=u*e.point.x,i+=u*e.point.y}e.cx=a/e.charge,e.cy=i/e.charge}(r=t.geom.quadtree(v),n,o),s=-1;++s<T;)(h=v[s]).fixed||r.visit(x(h));for(s=-1;++s<T;)(h=v[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(v=t,s):v},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(m=t*t,s):Math.sqrt(m)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=we(s.tick)),s):n},s.start=function(){var t,e,r,n=v.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=v[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=v[r.source]),\"number\"==typeof r.target&&(r.target=v[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=v[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,v[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,a){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var i=y[c];e[i.source.index].push(i.target),e[i.target.index].push(i.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*a}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(L).on(\"dragstart.force\",Mi).on(\"drag.force\",b).on(\"dragend.force\",Ai)),!arguments.length)return r;this.on(\"mouseover.force\",Si).on(\"mouseout.force\",Ei).call(r)},t.rebind(s,l,\"on\")};var Ci=20,Li=1,Pi=1/0;function Ii(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Bi,e}function zi(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(a=t.children)&&(n=a.length))for(var n,a;--n>=0;)r.push(a[n])}function Oi(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(i=t.children)&&(a=i.length))for(var a,i,o=-1;++o<a;)r.push(i[o]);for(;null!=(t=n.pop());)e(t)}function Di(t){return t.children}function Ri(t){return t.value}function Fi(t,e){return e.value-t.value}function Bi(e){return t.merge(e.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}t.layout.hierarchy=function(){var t=Fi,e=Di,r=Ri;function n(a){var i,o=[a],s=[];for(a.depth=0;null!=(i=o.pop());)if(s.push(i),(c=e.call(n,i,i.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=i,u.depth=i.depth+1;r&&(i.value=0),i.children=c}else r&&(i.value=+r.call(n,i,i.depth)||0),delete i.children;return Oi(a,(function(e){var n,a;t&&(n=e.children)&&n.sort(t),r&&(a=e.parent)&&(a.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(zi(t,(function(t){t.children&&(t.value=0)})),Oi(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var a=e.call(this,t,n);return function t(e,r,n,a){var i=e.children;if(e.x=r,e.y=e.depth*a,e.dx=n,e.dy=a,i&&(o=i.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=i[c],r,l=s.value*n,a),r+=l}}(a[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(a=r.length))for(var a,i=-1;++i<a;)n=Math.max(n,t(r[i]));return 1+n}(a[0])),a}return n.size=function(t){return arguments.length?(r=t,n):r},Ii(n,e)},t.layout.pie=function(){var e=Number,r=Ni,n=0,a=St,i=0;function o(s){var l,c=s.length,u=s.map((function(t,r){return+e.call(o,t,r)})),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof a?a.apply(this,arguments):a)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof i?i.apply(this,arguments):i)),d=p*(f<0?-1:1),g=t.sum(u),m=g?(f-c*d)/g:0,v=t.range(c),y=[];return null!=r&&v.sort(r===Ni?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),v.forEach((function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*m+d,padAngle:p}})),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(a=t,o):a},o.padAngle=function(t){return arguments.length?(i=t,o):i},o};var Ni={};function ji(t){return t.x}function Ui(t){return t.y}function Vi(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=L,r=Gi,n=Yi,a=Vi,i=ji,o=Ui;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(t,r){return e.call(s,t,r)})),h=u.map((function(t){return t.map((function(t,e){return[i.call(s,t,e),o.call(s,t,e)]}))})),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,m,v=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(a.call(s,u[0][g],m=v[g],h[0][g][1]),d=1;d<p;++d)a.call(s,u[d][g],m+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:qi.get(t)||Gi,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Hi.get(t)||Yi,s):n},s.x=function(t){return arguments.length?(i=t,s):i},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(a=t,s):a},s};var qi=t.map({\"inside-out\":function(e){var r,n,a=e.length,i=e.map(Wi),o=e.map(Zi),s=t.range(a).sort((function(t,e){return i[t]-i[e]})),l=0,c=0,u=[],h=[];for(r=0;r<a;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Gi}),Hi=t.map({silhouette:function(t){var e,r,n,a=t.length,i=t[0].length,o=[],s=0,l=[];for(r=0;r<i;++r){for(e=0,n=0;e<a;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<i;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,a,i,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,a=0;e<u;++e)a+=t[e][r][1];for(e=0,i=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;i+=o*t[e][r][1]}p[r]=l-=a?i/a*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,a=t.length,i=t[0].length,o=1/a,s=[];for(r=0;r<i;++r){for(e=0,n=0;e<a;e++)n+=t[e][r][1];if(n)for(e=0;e<a;e++)t[e][r][1]/=n;else for(e=0;e<a;e++)t[e][r][1]=o}for(r=0;r<i;++r)s[r]=0;return s},zero:Yi});function Gi(e){return t.range(e.length)}function Yi(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Wi(t){for(var e,r=1,n=0,a=t[0][1],i=t.length;r<i;++r)(e=t[r][1])>a&&(n=r,a=e);return n}function Zi(t){return t.reduce(Xi,0)}function Xi(t,e){return t+e[1]}function Ji(t,e){return Ki(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ki(t,e){for(var r=-1,n=+t[0],a=(t[1]-n)/e,i=[];++r<=e;)i[r]=a*r+n;return i}function Qi(e){return[t.min(e),t.max(e)]}function $i(t,e){return t.value-e.value}function to(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function eo(t,e){t._pack_next=e,e._pack_prev=t}function ro(t,e){var r=e.x-t.x,n=e.y-t.y,a=t.r+e.r;return.999*a*a>r*r+n*n}function no(t){if((e=t.children)&&(l=e.length)){var e,r,n,a,i,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(ao),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(oo(r,n,a=e[2]),x(a),to(r,a),r._pack_prev=a,to(a,n),n=r._pack_next,i=3;i<l;i++){oo(r,n,a=e[i]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(ro(o,a)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!ro(s,a);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?eo(r,n=o):eo(r=s,n),i--):(to(r,a),n=a,x(a))}var m=(c+u)/2,v=(h+f)/2,y=0;for(i=0;i<l;i++)(a=e[i]).x-=m,a.y-=v,y=Math.max(y,a.r+Math.sqrt(a.x*a.x+a.y*a.y));t.r=y,e.forEach(io)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function ao(t){t._pack_next=t._pack_prev=t}function io(t){delete t._pack_next,delete t._pack_prev}function oo(t,e,r){var n=t.r+r.r,a=e.x-t.x,i=e.y-t.y;if(n&&(a||i)){var o=e.r+r.r,s=a*a+i*i,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*a+c*i,r.y=t.y+l*i-c*a}else r.x=t.x+n,r.y=t.y}function so(t,e){return t.parent==e.parent?1:2}function lo(t){var e=t.children;return e.length?e[0]:t.t}function co(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function uo(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function ho(t,e,r){return t.a.parent===e.parent?t.a:r}function fo(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function po(t,e){var r=t.x+e[3],n=t.y+e[0],a=t.dx-e[1]-e[3],i=t.dy-e[0]-e[2];return a<0&&(r+=a/2,a=0),i<0&&(n+=i/2,i=0),{x:r,y:n,dx:a,dy:i}}function go(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function mo(t){return t.rangeExtent?t.rangeExtent():go(t.range())}function vo(t,e,r,n){var a=r(t[0],t[1]),i=n(e[0],e[1]);return function(t){return i(a(t))}}function yo(t,e){var r,n=0,a=t.length-1,i=t[n],o=t[a];return o<i&&(r=n,n=a,a=r,r=i,i=o,o=r),t[n]=e.floor(i),t[a]=e.ceil(o),t}function xo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:bo}t.layout.histogram=function(){var e=!0,r=Number,n=Qi,a=Ji;function i(i,o){for(var s,l,c=[],u=i.map(r,this),h=n.call(this,u,o),f=a.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(i[o]));return c}return i.value=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=de(t),i):n},i.bins=function(t){return arguments.length?(a=\"number\"==typeof t?function(e){return Ki(e,t)}:de(t),i):a},i.frequency=function(t){return arguments.length?(e=!!t,i):e},i},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort($i),n=0,a=[1,1];function i(t,i){var o=r.call(this,t,i),s=o[0],l=a[0],c=a[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Oi(s,(function(t){t.r=+u(t.value)})),Oi(s,no),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Oi(s,(function(t){t.r+=h})),Oi(s,no),Oi(s,(function(t){t.r-=h}))}return function t(e,r,n,a){var i=e.children;if(e.x=r+=a*e.x,e.y=n+=a*e.y,e.r*=a,i)for(var o=-1,s=i.length;++o<s;)t(i[o],r,n,a)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return i.size=function(t){return arguments.length?(a=t,i):a},i.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,i):e},i.padding=function(t){return arguments.length?(n=+t,i):n},Ii(i,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],a=null;function i(t,i){var c=e.call(this,t,i),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var a,i=e.children,o=0,s=i.length;o<s;++o)n.push((i[o]=a={_:i[o],parent:e,children:(a=i[o].children)&&a.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=a);return r.children[0]}(u);if(Oi(h,o),h.parent.m=-h.z,zi(h,s),a)zi(u,l);else{var f=u,p=u,d=u;zi(u,(function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var g=r(f,p)/2-f.x,m=n[0]/(p.x+r(p,f)/2+g),v=n[1]/(d.depth||1);zi(u,(function(t){t.x=(t.x+g)*m,t.y=t.depth*v}))}return c}function o(t){var e=t.children,n=t.parent.children,a=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,a=t.children,i=a.length;for(;--i>=0;)(e=a[i]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var i=(e[0].z+e[e.length-1].z)/2;a?(t.z=a.z+r(t._,a._),t.m=t.z-i):t.z=i}else a&&(t.z=a.z+r(t._,a._));t.parent.A=function(t,e,n){if(e){for(var a,i=t,o=t,s=e,l=i.parent.children[0],c=i.m,u=o.m,h=s.m,f=l.m;s=co(s),i=lo(i),s&&i;)l=lo(l),(o=co(o)).a=t,(a=s.z+h-i.z-c+r(s._,i._))>0&&(uo(ho(s,t,n),t,a),c+=a,u+=a),h+=s.m,c+=i.m,f+=l.m,u+=o.m;s&&!co(o)&&(o.t=s,o.m+=h-u),i&&!lo(l)&&(l.t=i,l.m+=c-f,n=t)}return n}(t,a,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return i.separation=function(t){return arguments.length?(r=t,i):r},i.size=function(t){return arguments.length?(a=null==(n=t)?l:null,i):a?null:n},i.nodeSize=function(t){return arguments.length?(a=null==(n=t)?null:l,i):a?n:null},Ii(i,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],a=!1;function i(i,o){var s,l=e.call(this,i,o),c=l[0],u=0;Oi(c,(function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(n),e.y=function(e){return 1+t.max(e,(function(t){return t.y}))}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)}));var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Oi(c,a?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return i.separation=function(t){return arguments.length?(r=t,i):r},i.size=function(t){return arguments.length?(a=null==(n=t),i):a?null:n},i.nodeSize=function(t){return arguments.length?(a=null!=(n=t),i):a?n:null},Ii(i,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,a=[1,1],i=null,o=fo,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,a=-1,i=t.length;++a<i;)n=(r=t[a]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,a,i=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?i.dx:\"dice\"===l?i.dy:\"slice-dice\"===l?1&t.depth?i.dy:i.dx:Math.min(i.dx,i.dy);for(u(c,i.dx*i.dy/t.value),s.area=0;(a=c.length)>0;)s.push(r=c[a-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,i,!1),g=Math.min(i.dx,i.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,i,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),a=e.slice(),i=[];for(u(a,n.dx*n.dy/t.value),i.area=0;r=a.pop();)i.push(r),i.area+=r.area,null!=r.z&&(d(i,r.z?n.dx:n.dy,n,!a.length),i.length=i.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,a=0,i=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<i&&(i=r),r>a&&(a=r));return e*=e,(n*=n)?Math.max(e*a*c/n,n/(e*i*c)):1/0}function d(t,e,r,a){var i,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((a||u>r.dy)&&(u=r.dy);++o<s;)(i=t[o]).x=l,i.y=c,i.dy=u,l+=i.dx=Math.min(r.x+r.dx-l,u?n(i.area/u):0);i.z=!0,i.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((a||u>r.dx)&&(u=r.dx);++o<s;)(i=t[o]).x=l,i.y=c,i.dx=u,c+=i.dy=Math.min(r.y+r.dy-c,u?n(i.area/u):0);i.z=!1,i.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),i=n[0];return i.x=i.y=0,i.value?(i.dx=a[0],i.dy=a[1]):i.dx=i.dy=0,e&&r.revalue(i),u([i],i.dx*i.dy/i.value),(e?f:h)(i),s&&(e=n),n}return g.size=function(t){return arguments.length?(a=t,g):a},g.padding=function(t){if(!arguments.length)return i;function e(e){var r=t.call(g,e,e.depth);return null==r?fo(e):po(e,\"number\"==typeof r?[r,r,r,r]:r)}function r(e){return po(e,t)}var n;return o=null==(i=t)?fo:\"function\"==(n=typeof t)?e:\"number\"===n?(t=[t,t,t,t],r):r,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Ii(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,a;do{a=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!a||a>1);return t+e*r*Math.sqrt(-2*Math.log(a)/a)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var bo={floor:L,ceil:L};function _o(e,r,n,a){var i=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)i.push(n(e[s-1],e[s])),o.push(a(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](i[n](r))}}function wo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function To(t,e){return yo(t,xo(ko(t,e)[2])),yo(t,xo(ko(t,e)[2])),t}function ko(t,e){null==e&&(e=10);var r=go(t),n=r[1]-r[0],a=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),i=e/n*a;return i<=.15?a*=10:i<=.35?a*=5:i<=.75&&(a*=2),r[0]=Math.ceil(r[0]/a)*a,r[1]=Math.floor(r[1]/a)*a+.5*a,r[2]=a,r}function Mo(e,r){return t.range.apply(t,ko(e,r))}function Ao(e,r,n){var a=ko(e,r);if(n){var i=Ce.exec(n);if(i.shift(),\"s\"===i[8]){var o=t.formatPrefix(Math.max(y(a[0]),y(a[1])));return i[7]||(i[7]=\".\"+Eo(o.scale(a[2]))),i[8]=\"f\",n=t.format(i.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}i[7]||(i[7]=\".\"+function(t,e){var r=Eo(e[2]);return t in So?Math.abs(r-Eo(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(i[8],a)),n=i.join(\"\")}else n=\",.\"+Eo(a[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,a){var i,o;function s(){var t=Math.min(e.length,r.length)>2?_o:vo,s=a?wi:_i;return i=t(e,r,s,n),o=t(r,e,s,$a),l}function l(t){return i(t)}return l.invert=function(t){return o(t)},l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e},l.range=function(t){return arguments.length?(r=t,s()):r},l.rangeRound=function(t){return l.range(t).interpolate(di)},l.clamp=function(t){return arguments.length?(a=t,s()):a},l.interpolate=function(t){return arguments.length?(n=t,s()):n},l.ticks=function(t){return Mo(e,t)},l.tickFormat=function(t,r){return Ao(e,t,r)},l.nice=function(t){return To(e,t),s()},l.copy=function(){return t(e,r,n,a)},s()}([0,1],[0,1],$a,!1)};var So={s:1,g:1,p:1,r:1,e:1};function Eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,a,i){function o(t){return(a?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return a?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}return l.invert=function(t){return s(r.invert(t))},l.domain=function(t){return arguments.length?(a=t[0]>=0,r.domain((i=t.map(Number)).map(o)),l):i},l.base=function(t){return arguments.length?(n=+t,r.domain(i.map(o)),l):n},l.nice=function(){var t=yo(i.map(o),a?Math:Lo);return r.domain(t),i=t.map(s),l},l.ticks=function(){var t=go(i),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(a){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e},l.tickFormat=function(e,r){if(!arguments.length)return Co;arguments.length<2?r=Co:\"function\"!=typeof r&&(r=t.format(r));var a=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=a?r(t):\"\"}},l.copy=function(){return e(r.copy(),n,a,i)},wo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Co=t.format(\".0e\"),Lo={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Po(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var a=Po(r),i=Po(1/r);function o(t){return e(a(t))}return o.invert=function(t){return i(e.invert(t))},o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(a)),o):n},o.ticks=function(t){return Mo(n,t)},o.tickFormat=function(t,e){return Ao(n,t,e)},o.nice=function(t){return o.domain(To(n,t))},o.exponent=function(t){return arguments.length?(a=Po(r=t),i=Po(1/r),e.domain(n.map(a)),o):r},o.copy=function(){return t(e.copy(),r,n)},wo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var a,i,o;function s(t){return i[((a.get(t)||(\"range\"===n.t?a.set(t,r.push(t)):NaN))-1)%i.length]}function l(e,n){return t.range(r.length).map((function(t){return e+n*t}))}return s.domain=function(t){if(!arguments.length)return r;r=[],a=new _;for(var e,i=-1,o=t.length;++i<o;)a.has(e=t[i])||a.set(e,r.push(e));return s[n.t].apply(s,n.a)},s.range=function(t){return arguments.length?(i=t,o=0,n={t:\"range\",a:arguments},s):i},s.rangePoints=function(t,e){arguments.length<2&&(e=0);var a=t[0],c=t[1],u=r.length<2?(a=(a+c)/2,0):(c-a)/(r.length-1+e);return i=l(a+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s},s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var a=t[0],c=t[1],u=r.length<2?(a=c=Math.round((a+c)/2),0):(c-a)/(r.length-1+e)|0;return i=l(a+Math.round(u*e/2+(c-a-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s},s.rangeBands=function(t,e,a){arguments.length<2&&(e=0),arguments.length<3&&(a=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*a);return i=l(u+f*a,f),c&&i.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s},s.rangeRoundBands=function(t,e,a){arguments.length<2&&(e=0),arguments.length<3&&(a=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*a));return i=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&i.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s},s.rangeBand=function(){return o},s.rangeExtent=function(){return go(n.a[0])},s.copy=function(){return e(r,n)},s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Io)},t.scale.category20=function(){return t.scale.ordinal().range(zo)},t.scale.category20b=function(){return t.scale.ordinal().range(Oo)},t.scale.category20c=function(){return t.scale.ordinal().range(Do)};var Io=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(ie),zo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(ie),Oo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(ie),Do=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(ie);function Ro(){return 0}t.scale.quantile=function(){return function e(r,n){var a;function i(){var e=0,i=n.length;for(a=[];++e<i;)a[e-1]=t.quantile(r,e/i);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(a,e)]}return o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),i()):r},o.range=function(t){return arguments.length?(n=t,i()):n},o.quantiles=function(){return a},o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?a[t-1]:r[0],t<a.length?a[t]:r[r.length-1]]},o.copy=function(){return e(r,n)},i()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var a,i;function o(t){return n[Math.max(0,Math.min(i,Math.floor(a*(t-e))))]}function s(){return a=n.length/(r-e),i=n.length-1,o}return o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]},o.range=function(t){return arguments.length?(n=t,s()):n},o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/a+e,t+1/a]},o.copy=function(){return t(e,r,n)},s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function a(e){if(e<=e)return n[t.bisect(r,e)]}return a.domain=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=t,a):n},a.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]},a.copy=function(){return e(r,n)},a}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}return r.invert=r,r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e},r.ticks=function(t){return Mo(e,t)},r.tickFormat=function(t,r){return Ao(e,t,r)},r.copy=function(){return t(e)},r}([0,1])},t.svg={},t.svg.arc=function(){var t=Bo,e=No,r=Ro,n=Fo,a=jo,i=Uo,o=Vo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=a.apply(this,arguments)-Ct,h=i.apply(this,arguments)-Ct,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=Et)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,m,v,y,x,b,_,w,T,k,M,A=0,S=0,E=[];if((v=(+o.apply(this,arguments)||0)/2)&&(m=n===Fo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(m/c*Math.sin(v))),s&&(A=Dt(m/s*Math.sin(v)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&qo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-A),T=s*Math.sin(h-A),k=s*Math.cos(u+A),M=s*Math.sin(u+A);var P=Math.abs(u-h+2*A)<=At?0:1;if(A&&qo(w,T,k,M)===1-p^P){var I=(u+h)/2;w=s*Math.cos(I),T=s*Math.sin(I),k=M=null}}else w=T=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,O=d;if(f<At){var D=null==k?[w,T]:null==b?[y,x]:la([y,x],[k,M],[b,_],[w,T]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);O=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=Ho(null==k?[w,T]:[k,M],[y,x],c,z,p),q=Ho([b,_],[w,T],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^qo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=k){var H=Ho([y,x],[k,M],s,-O,p),G=Ho([w,T],null==b?[y,x]:[b,_],s,-O,p);d===O?E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^qo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",k,\",\",M);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=de(e),s):t},s.outerRadius=function(t){return arguments.length?(e=de(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=de(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Fo?Fo:de(t),s):n},s.startAngle=function(t){return arguments.length?(a=de(t),s):a},s.endAngle=function(t){return arguments.length?(i=de(t),s):i},s.padAngle=function(t){return arguments.length?(o=de(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+a.apply(this,arguments)+ +i.apply(this,arguments))/2-Ct;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Fo=\"auto\";function Bo(t){return t.innerRadius}function No(t){return t.outerRadius}function jo(t){return t.startAngle}function Uo(t){return t.endAngle}function Vo(t){return t&&t.padAngle}function qo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Ho(t,e,r,n,a){var i=t[0]-e[0],o=t[1]-e[1],s=(a?n:-n)/Math.sqrt(i*i+o*o),l=s*o,c=-s*i,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,m=f-u,v=p-h,y=m*m+v*v,x=r-n,b=u*p-f*h,_=(v<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*v-m*_)/y,T=(-b*m-v*_)/y,k=(b*v+m*_)/y,M=(-b*m+v*_)/y,A=w-d,S=T-g,E=k-d,C=M-g;return A*A+S*S>E*E+C*C&&(w=k,T=M),[[w-l,T-c],[w*r/x,T*r/x]]}function Go(t){var e=ra,r=na,n=Yr,a=Wo,i=a.key,o=.7;function s(i){var s,l=[],c=[],u=-1,h=i.length,f=de(e),p=de(r);function d(){l.push(\"M\",a(t(c),o))}for(;++u<h;)n.call(this,s=i[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(i=\"function\"==typeof t?a=t:(a=Yo.get(t)||Wo).key,s):i},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Go(L)};var Yo=t.map({linear:Wo,\"linear-closed\":Zo,step:function(t){var e=0,r=t.length,n=t[0],a=[n[0],\",\",n[1]];for(;++e<r;)a.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&a.push(\"H\",n[0]);return a.join(\"\")},\"step-before\":Xo,\"step-after\":Jo,basis:$o,\"basis-open\":function(t){if(t.length<4)return Wo(t);var e,r=[],n=-1,a=t.length,i=[0],o=[0];for(;++n<3;)e=t[n],i.push(e[0]),o.push(e[1]);r.push(ts(ns,i)+\",\"+ts(ns,o)),--n;for(;++n<a;)e=t[n],i.shift(),i.push(e[0]),o.shift(),o.push(e[1]),as(r,i,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,a=t.length,i=a+4,o=[],s=[];for(;++n<4;)r=t[n%a],o.push(r[0]),s.push(r[1]);e=[ts(ns,o),\",\",ts(ns,s)],--n;for(;++n<i;)r=t[n%a],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),as(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,a,i=t[0][0],o=t[0][1],s=t[r][0]-i,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],a=c/r,n[0]=e*n[0]+(1-e)*(i+a*s),n[1]=e*n[1]+(1-e)*(o+a*l);return $o(t)},cardinal:function(t,e){return t.length<3?Wo(t):t[0]+Ko(t,Qo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Wo(t):t[1]+Ko(t.slice(1,-1),Qo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Zo(t):t[0]+Ko((t.push(t[0]),t),Qo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Wo(t):t[0]+Ko(t,function(t){var e,r,n,a,i=[],o=function(t){var e=0,r=t.length-1,n=[],a=t[0],i=t[1],o=n[0]=is(a,i);for(;++e<r;)n[e]=(o+(o=is(a=i,i=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=is(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(a=r*r+n*n)>9&&(a=3*e/Math.sqrt(a),o[s]=a*r,o[s+1]=a*n));s=-1;for(;++s<=l;)a=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),i.push([a||0,o[s]*a||0]);return i}(t))}});function Wo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Zo(t){return t.join(\"L\")+\"Z\"}function Xo(t){for(var e=0,r=t.length,n=t[0],a=[n[0],\",\",n[1]];++e<r;)a.push(\"V\",(n=t[e])[1],\"H\",n[0]);return a.join(\"\")}function Jo(t){for(var e=0,r=t.length,n=t[0],a=[n[0],\",\",n[1]];++e<r;)a.push(\"H\",(n=t[e])[0],\"V\",n[1]);return a.join(\"\")}function Ko(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Wo(t);var r=t.length!=e.length,n=\"\",a=t[0],i=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(i[0]-2*o[0]/3)+\",\"+(i[1]-2*o[1]/3)+\",\"+i[0]+\",\"+i[1],a=t[1],l=2),e.length>1){s=e[1],i=t[l],l++,n+=\"C\"+(a[0]+o[0])+\",\"+(a[1]+o[1])+\",\"+(i[0]-s[0])+\",\"+(i[1]-s[1])+\",\"+i[0]+\",\"+i[1];for(var c=2;c<e.length;c++,l++)i=t[l],s=e[c],n+=\"S\"+(i[0]-s[0])+\",\"+(i[1]-s[1])+\",\"+i[0]+\",\"+i[1]}if(r){var u=t[l];n+=\"Q\"+(i[0]+2*s[0]/3)+\",\"+(i[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Qo(t,e){for(var r,n=[],a=(1-e)/2,i=t[0],o=t[1],s=1,l=t.length;++s<l;)r=i,i=o,o=t[s],n.push([a*(o[0]-r[0]),a*(o[1]-r[1])]);return n}function $o(t){if(t.length<3)return Wo(t);var e=1,r=t.length,n=t[0],a=n[0],i=n[1],o=[a,a,a,(n=t[1])[0]],s=[i,i,i,n[1]],l=[a,\",\",i,\"L\",ts(ns,o),\",\",ts(ns,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),as(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function ts(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Yo.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var es=[0,2/3,1/3,0],rs=[0,1/3,2/3,0],ns=[0,1/6,2/3,1/6];function as(t,e,r){t.push(\"C\",ts(es,e),\",\",ts(es,r),\",\",ts(rs,e),\",\",ts(rs,r),\",\",ts(ns,e),\",\",ts(ns,r))}function is(t,e){return(e[1]-t[1])/(e[0]-t[0])}function os(t){for(var e,r,n,a=-1,i=t.length;++a<i;)r=(e=t[a])[0],n=e[1]-Ct,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function ss(t){var e=ra,r=ra,n=0,a=na,i=Yr,o=Wo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],m=[],v=-1,y=s.length,x=de(e),b=de(n),_=e===r?function(){return f}:de(r),w=n===a?function(){return p}:de(a);function T(){d.push(\"M\",o(t(m),u),c,l(t(g.reverse()),u),\"Z\")}for(;++v<y;)i.call(this,h=s[v],v)?(g.push([f=+x.call(this,h,v),p=+b.call(this,h,v)]),m.push([+_.call(this,h,v),+w.call(this,h,v)])):g.length&&(T(),g=[],m=[]);return g.length&&T(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=a=t,h):a},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(a=t,h):a},h.defined=function(t){return arguments.length?(i=t,h):i},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Yo.get(t)||Wo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ls(t){return t.radius}function cs(t){return[t.x,t.y]}function us(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Ct;return[r*Math.cos(n),r*Math.sin(n)]}}function hs(){return 64}function fs(){return\"circle\"}function ps(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=Go(os);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Xo.reverse=Jo,Jo.reverse=Xo,t.svg.area=function(){return ss(L)},t.svg.area.radial=function(){var t=ss(os);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=qn,r=ls,n=jo,a=Uo;function i(r,n){var a,i,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(i=u,((a=c).a0==i.a0&&a.a1==i.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,i,o){var s=e.call(t,i,o),l=r.call(t,s,o),c=n.call(t,s,o)-Ct,u=a.call(t,s,o)-Ct;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return i.radius=function(t){return arguments.length?(r=de(t),i):r},i.source=function(e){return arguments.length?(t=de(e),i):t},i.target=function(t){return arguments.length?(e=de(t),i):e},i.startAngle=function(t){return arguments.length?(n=de(t),i):n},i.endAngle=function(t){return arguments.length?(a=de(t),i):a},i},t.svg.diagonal=function(){var t=Vn,e=qn,r=cs;function n(n,a){var i=t.call(this,n,a),o=e.call(this,n,a),s=(i.y+o.y)/2,l=[i,{x:i.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=de(e),n):t},n.target=function(t){return arguments.length?(e=de(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=cs,n=e.projection;return e.projection=function(t){return arguments.length?n(us(r=t)):r},e},t.svg.symbol=function(){var t=fs,e=hs;function r(r,n){return(ds.get(t.call(this,r,n))||ps)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=de(e),r):t},r.size=function(t){return arguments.length?(e=de(t),r):e},r};var ds=t.map({circle:ps,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*ms)),r=e*ms;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ds.keys();var gs=Math.sqrt(3),ms=Math.tan(30*Lt);Y.transition=function(t){for(var e,r,n=bs||++Ts,a=As(t),i=[],o=_s||{time:Date.now(),ease:ci,delay:0,duration:250},s=-1,l=this.length;++s<l;){i.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&Ss(r,u,a,n,o),e.push(r)}return xs(i,a,n)},Y.interrupt=function(t){return this.each(null==t?vs:ys(As(t)))};var vs=ys(As());function ys(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function xs(t,e,r){return U(t,ws),t.namespace=e,t.id=r,t}var bs,_s,ws=[],Ts=0;function ks(t,e,r,n){var a=t.id,i=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[i][a].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[i][a].tween.set(e,r)}))}function Ms(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function As(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function Ss(t,e,r,n,a){var i,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var a=u.active,f=u[a];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[a],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,we((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,i),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=h.ease,s=h.duration}function p(a){for(var i=a/s,o=l(i),f=c.length;f>0;)c[--f].call(t,o);if(i>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(i=a.time,o=we((function(t){var e=h.delay;if(o.t=e+i,e<=t)return f(t-e);o.c=f}),0,i),h=u[n]={tween:new _,time:i,timer:o,delay:a.delay,duration:a.duration,ease:a.ease,index:e},a=null,++u.count)}ws.call=Y.call,ws.empty=Y.empty,ws.node=Y.node,ws.size=Y.size,t.transition=function(e,r){return e&&e.transition?bs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ws,ws.select=function(t){var e,r,n,a=this.id,i=this.namespace,o=[];t=W(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),Ss(r,u,i,a,n[i][a]),e.push(r)):e.push(null)}return xs(o,i,a)},ws.selectAll=function(t){var e,r,n,a,i,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){i=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(a=r[d])&&Ss(a,d,s,o,i),e.push(a)}return xs(l,s,o)},ws.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=lt(t));for(var a=0,i=this.length;a<i;a++){n.push(e=[]);for(var o,s=0,l=(o=this[a]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,a)&&e.push(r)}return xs(n,this.namespace,this.id)},ws.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(a){a[n][r].tween.set(t,e)})},ws.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?bi:$a,a=t.ns.qualify(e);function i(){this.removeAttribute(a)}function o(){this.removeAttributeNS(a.space,a.local)}function s(t){return null==t?i:(t+=\"\",function(){var e,r=this.getAttribute(a);return r!==t&&(e=n(r,t),function(t){this.setAttribute(a,e(t))})})}function l(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(a.space,a.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(a.space,a.local,e(t))})})}return ks(this,\"attr.\"+e,r,a.local?l:s)},ws.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var a=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return a&&function(t){this.setAttributeNS(n.space,n.local,a(t))}}:function(t,e){var a=r.call(this,t,e,this.getAttribute(n));return a&&function(t){this.setAttribute(n,a(t))}})},ws.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function a(){this.style.removeProperty(t)}function i(e){return null==e?a:(e+=\"\",function(){var n,a=o(this).getComputedStyle(this,null).getPropertyValue(t);return a!==e&&(n=$a(a,e),function(e){this.style.setProperty(t,n(e),r)})})}return ks(this,\"style.\"+t,e,i)},ws.styleTween=function(t,e,r){function n(n,a){var i=e.call(this,n,a,o(this).getComputedStyle(this,null).getPropertyValue(t));return i&&function(e){this.style.setProperty(t,i(e),r)}}return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,n)},ws.text=function(t){return ks(this,\"text\",t,Ms)},ws.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ws.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,(function(t){t[n][r].ease=e})))},ws.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,a,i){n[r][e].delay=+t.call(n,n.__data__,a,i)}:(t=+t,function(n){n[r][e].delay=t}))},ws.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,a,i){n[r][e].duration=Math.max(1,t.call(n,n.__data__,a,i))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ws.each=function(e,r){var n=this.id,a=this.namespace;if(arguments.length<2){var i=_s,o=bs;try{bs=n,ut(this,(function(t,r,i){_s=t[a][n],e.call(t,t.__data__,r,i)}))}finally{_s=i,bs=o}}else ut(this,(function(i){var o=i[a][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)}));return this},ws.transition=function(){for(var t,e,r,n=this.id,a=++Ts,i=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&Ss(e,u,i,a,{time:(r=e[i][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return xs(o,i,a)},t.svg.axis=function(){var e,r=t.scale.linear(),a=Es,i=6,o=6,s=3,l=[10],c=null;function u(n){n.each((function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):L:e,g=u.selectAll(\".tick\").data(p,f),m=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),v=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(i,0)+s,b=mo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));m.append(\"line\"),m.append(\"text\");var T,k,M,A,S=m.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),P=m.select(\"text\"),I=y.select(\"text\"),z=\"top\"===a||\"left\"===a?-1:1;if(\"bottom\"===a||\"top\"===a?(n=Ls,T=\"x\",M=\"y\",k=\"x2\",A=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=Ps,T=\"y\",M=\"x\",k=\"y2\",A=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(A,z*i),P.attr(M,z*x),E.attr(k,0).attr(A,z*i),I.attr(T,0).attr(M,z*x),f.rangeBand){var O=f,D=O.rangeBand()/2;h=f=function(t){return O(t)+D}}else h.rangeBand?h=f:v.call(n,f,h);m.call(n,h,f),y.call(n,f,f)}))}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(a=t in Cs?t+\"\":Es,u):a},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(i=+t,o=+arguments[e-1],u):i},u.innerTickSize=function(t){return arguments.length?(i=+t,u):i},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Es=\"bottom\",Cs={top:1,right:1,bottom:1,left:1};function Ls(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function Ps(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}t.svg.brush=function(){var e,r,n=N(f,\"brushstart\",\"brush\",\"brushend\"),a=null,i=null,s=[0,0],l=[0,0],c=!0,u=!0,h=zs[0];function f(e){e.each((function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",m).on(\"touchstart.brush\",m),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,L);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return Is[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);a&&(o=mo(a),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),i&&(o=mo(i),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function m(){var h,m,v=this,y=t.select(t.event.target),x=n.of(v,arguments),b=t.select(v),_=y.datum(),w=!/^(n|s)$/.test(_)&&a,T=!/^(e|w)$/.test(_)&&i,k=y.classed(\"extent\"),M=bt(v),A=t.mouse(v),S=t.select(o(v)).on(\"keydown.brush\",L).on(\"keyup.brush\",P);if(t.event.changedTouches?S.on(\"touchmove.brush\",I).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",I).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),k)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);m=[s[1-E]-A[0],l[1-C]-A[1]],A[0]=s[E],A[1]=l[C]}else t.event.altKey&&(h=A.slice());function L(){32==t.event.keyCode&&(k||(h=null,A[0]-=s[1],A[1]-=l[1],k=2),F())}function P(){32==t.event.keyCode&&2==k&&(A[0]+=s[1],A[1]+=l[1],k=0,F())}function I(){var e=t.mouse(v),r=!1;m&&(e[0]+=m[0],e[1]+=m[1]),k||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<h[0])],A[1]=l[+(e[1]<h[1])]):h=null),w&&z(e,a,0)&&(d(b),r=!0),T&&z(e,i,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function z(t,n,a){var i,o,f=mo(n),p=f[0],d=f[1],g=A[a],m=a?l:s,v=m[1]-m[0];if(k&&(p-=g,d-=v+g),i=(a?u:c)?Math.max(p,Math.min(d,t[a])):t[a],k?o=(i+=g)+v:(h&&(g=Math.max(p,Math.min(d,2*h[a]-i))),g<i?(o=i,i=g):o=g),m[0]!=i||m[1]!=o)return a?r=null:e=null,m[0]=i,m[1]=o,!0}function O(){I(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),M(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),I()}return f.event=function(a){a.each((function(){var a=n.of(this,arguments),i={x:s,y:l,i:e,j:r},o=this.__chart__||i;this.__chart__=i,bs?t.select(this).transition().each(\"start.brush\",(function(){e=o.i,r=o.j,s=o.x,l=o.y,a({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var t=ti(s,i.x),n=ti(l,i.y);return e=r=null,function(e){s=i.x=t(e),l=i.y=n(e),a({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){e=i.i,r=i.j,a({type:\"brush\",mode:\"resize\"}),a({type:\"brushend\"})})):(a({type:\"brushstart\"}),a({type:\"brush\",mode:\"resize\"}),a({type:\"brushend\"}))}))},f.x=function(t){return arguments.length?(h=zs[!(a=t)<<1|!i],f):a},f.y=function(t){return arguments.length?(h=zs[!a<<1|!(i=t)],f):i},f.clamp=function(t){return arguments.length?(a&&i?(c=!!t[0],u=!!t[1]):a?c=!!t:i&&(u=!!t),f):a&&i?[c,u]:a?c:i?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(a&&(n=t[0],o=t[1],i&&(n=n[0],o=o[0]),e=[n,o],a.invert&&(n=a(n),o=a(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),i&&(c=t[0],u=t[1],a&&(c=c[1],u=u[1]),r=[c,u],i.invert&&(c=i(c),u=i(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(a&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],a.invert&&(n=a.invert(n),o=a.invert(o)),o<n&&(h=n,n=o,o=h))),i&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],i.invert&&(c=i.invert(c),u=i.invert(u)),u<c&&(h=c,c=u,u=h))),a&&i?[[n,c],[o,u]]:a?[n,o]:i&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!a&&s[0]==s[1]||!!i&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Is={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},zs=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Os=Ie.format=sr.timeFormat,Ds=Os.utc,Rs=Ds(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Fs(t){return t.toISOString()}function Bs(e,r,n){function a(t){return e(t)}function i(e,n){var a=(e[1]-e[0])/n,i=t.bisect(js,a);return i==js.length?[r.year,ko(e.map((function(t){return t/31536e6})),n)[2]]:i?r[a/js[i-1]<js[i]/a?i-1:i]:[qs,ko(e,n)[2]]}return a.invert=function(t){return Ns(e.invert(t))},a.domain=function(t){return arguments.length?(e.domain(t),a):e.domain().map(Ns)},a.nice=function(t,e){var r=a.domain(),n=go(r),o=null==t?i(n,10):\"number\"==typeof t&&i(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ns(+r+1),e).length}return o&&(t=o[0],e=o[1]),a.domain(yo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ns(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ns(+e+1);return e}}:t))},a.ticks=function(t,e){var r=go(a.domain()),n=null==t?i(r,10):\"number\"==typeof t?i(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ns(+r[1]+1),e<1?1:e)},a.tickFormat=function(){return n},a.copy=function(){return Bs(e.copy(),r,n)},wo(a,e)}function Ns(t){return new Date(t)}Os.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Fs:Rs,Fs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Fs.toString=Rs.toString,Ie.second=Re((function(t){return new ze(1e3*Math.floor(t/1e3))}),(function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))}),(function(t){return t.getSeconds()})),Ie.seconds=Ie.second.range,Ie.seconds.utc=Ie.second.utc.range,Ie.minute=Re((function(t){return new ze(6e4*Math.floor(t/6e4))}),(function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))}),(function(t){return t.getMinutes()})),Ie.minutes=Ie.minute.range,Ie.minutes.utc=Ie.minute.utc.range,Ie.hour=Re((function(t){var e=t.getTimezoneOffset()/60;return new ze(36e5*(Math.floor(t/36e5-e)+e))}),(function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))}),(function(t){return t.getHours()})),Ie.hours=Ie.hour.range,Ie.hours.utc=Ie.hour.utc.range,Ie.month=Re((function(t){return(t=Ie.day(t)).setDate(1),t}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t){return t.getMonth()})),Ie.months=Ie.month.range,Ie.months.utc=Ie.month.utc.range;var js=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Us=[[Ie.second,1],[Ie.second,5],[Ie.second,15],[Ie.second,30],[Ie.minute,1],[Ie.minute,5],[Ie.minute,15],[Ie.minute,30],[Ie.hour,1],[Ie.hour,3],[Ie.hour,6],[Ie.hour,12],[Ie.day,1],[Ie.day,2],[Ie.week,1],[Ie.month,1],[Ie.month,3],[Ie.year,1]],Vs=Os.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),qs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ns)},floor:L,ceil:L};Us.year=Ie.year,Ie.scale=function(){return Bs(t.scale.linear(),Us,Vs)};var Hs=Us.map((function(t){return[t[0].utc,t[1]]})),Gs=Ds.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function Ys(t){return JSON.parse(t.responseText)}function Ws(t){var e=a.createRange();return e.selectNode(a.body),e.createContextualFragment(t.responseText)}Hs.year=Ie.year.utc,Ie.scale.utc=function(){return Bs(t.scale.linear(),Hs,Gs)},t.text=ge((function(t){return t.responseText})),t.json=function(t,e){return me(t,\"application/json\",Ys,e)},t.html=function(t,e){return me(t,\"text/html\",Ws,e)},t.xml=ge((function(t){return t.responseXML})),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],170:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],171:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),a=t(\"uniq\");function i(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,a=r.length,i=0;i<a;++i){var o=n[i]-r[i];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var a=new Array(t-1),i=1;i<t;++i){var o=n[i-1],s=n[i];a[i-1]=[o[1],s[1]]}r&&a.push([-1,a[0][1]],[a[t-1][1],-1]);return a}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new i(f,u),c=Math.max(p,c)}a(l,o),r=l.length;var m=new Array(r+s+1),v=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;x[s]=y,m[0]=x.slice(),v[0]=-1;for(u=0;u<=s;++u){(f=x.slice())[u]=1,m[u+1]=f,v[u+1]=-1}for(u=0;u<r;++u){var b=l[u];m[u+s+1]=b.point,v[u+s+1]=b.index}var _=n(m,!1);_=e?_.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=v[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):_.filter((function(t){for(var e=0;e<=s;++e){var r=v[t[e]];if(r<0)return!1;t[e]=r}return!0}));if(1&s)for(u=0;u<_.length;++u){f=(b=_[u])[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":433,uniq:569}],172:[function(t,e,r){\"use strict\";e.exports=i;var n=(i.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),a=o([32,126]);function i(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,i={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=a),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;i[u]=1e3*p}}return i}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),a=t[0];a<t[1];a++){var i=n+String.fromCharCode(a);e.push(i)}return e}i.createPairs=o,i.ascii=a},{}],173:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),a=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===a[1]){e.exports=function(t){return n[0]=t,[a[0],a[1]]},e.exports.pack=function(t,e){return a[0]=t,a[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,a[0]},e.exports.hi=function(t){return n[0]=t,a[1]}}else if(1072693248===a[0]){e.exports=function(t){return n[0]=t,[a[1],a[0]]},e.exports.pack=function(t,e){return a[1]=t,a[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,a[1]},e.exports.hi=function(t){return n[0]=t,a[0]}}else r=!1}if(!r){var i=new t(8);e.exports=function(t){return i.writeDoubleLE(t,0,!0),[i.readUInt32LE(0,!0),i.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return i.writeUInt32LE(t,0,!0),i.writeUInt32LE(e,4,!0),i.readDoubleLE(0,!0)},e.exports.lo=function(t){return i.writeDoubleLE(t,0,!0),i.readUInt32LE(0,!0)},e.exports.hi=function(t){return i.writeDoubleLE(t,0,!0),i.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),a=1048575&n;return 2146435072&n&&(a+=1<<20),[r,a]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:111}],174:[function(t,e,r){var n=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),i={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),a(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[i[r]].apply(t,n)})),t.closePath()}},{\"abs-svg-path\":65,\"normalize-svg-path\":471}],175:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],176:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var a=0|e[n];if(a<=0)return[];var i,o=new Array(a);if(n===e.length-1)for(i=0;i<a;++i)o[i]=r;else for(i=0;i<a;++i)o[i]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],177:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,m=e&&e.length,v=m?e[0]*r:t.length,y=a(t,0,v,r,!0),x=[];if(!y||y.next===y.prev)return x;if(m&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=a(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=i(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<v;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function a(t,e,r,n,a){var i,o;if(a===E(t,e,r,n)>0)for(i=e;i<r;i+=n)o=M(i,t[i],t[i+1],o);else for(i=r-n;i>=e;i-=n)o=M(i,t[i],t[i+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function i(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,a,h,f){if(t){!f&&h&&function(t,e,r,n){var a=t;do{null===a.z&&(a.z=d(a.x,a.y,e,r,n)),a.prevZ=a.prev,a.nextZ=a.next,a=a.next}while(a!==t);a.prevZ.nextZ=null,a.prevZ=null,function(t){var e,r,n,a,i,o,s,l,c=1;do{for(r=t,t=null,i=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(a=r,r=r.nextZ,s--):(a=n,n=n.nextZ,l--),i?i.nextZ=a:t=a,a.prevZ=i,i=a;r=n}i.nextZ=null,c*=2}while(o>1)}(a)}(t,n,a,h);for(var p,g,m=t;t.prev!==t.next;)if(p=t.prev,g=t.next,h?l(t,n,a,h):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),A(t),t=g.next,m=g.next;else if((t=g)===m){f?1===f?o(t=c(i(t),e,r),e,r,n,a,h,2):2===f&&u(t,e,r,n,a,h):o(i(t),e,r,n,a,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var a=t.next.next;a!==t.prev;){if(m(e.x,e.y,r.x,r.y,n.x,n.y,a.x,a.y)&&y(a.prev,a,a.next)>=0)return!1;a=a.next}return!0}function l(t,e,r,n){var a=t.prev,i=t,o=t.next;if(y(a,i,o)>=0)return!1;for(var s=a.x<i.x?a.x<o.x?a.x:o.x:i.x<o.x?i.x:o.x,l=a.y<i.y?a.y<o.y?a.y:o.y:i.y<o.y?i.y:o.y,c=a.x>i.x?a.x>o.x?a.x:o.x:i.x>o.x?i.x:o.x,u=a.y>i.y?a.y>o.y?a.y:o.y:i.y>o.y?i.y:o.y,h=d(s,l,e,r,n),f=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=h&&g&&g.z<=f;){if(p!==t.prev&&p!==t.next&&m(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&m(a.x,a.y,i.x,i.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&m(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=f;){if(g!==t.prev&&g!==t.next&&m(a.x,a.y,i.x,i.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var a=n.prev,o=n.next.next;!x(a,o)&&b(a,n,n.next,o)&&T(a,o)&&T(o,a)&&(e.push(a.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return i(n)}function u(t,e,r,n,a,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=k(l,c);return l=i(l,l.next),u=i(u,u.next),o(l,e,r,n,a,s),void o(u,e,r,n,a,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,a=t.x,i=t.y,o=-1/0;do{if(i<=n.y&&i>=n.next.y&&n.next.y!==n.y){var s=n.x+(i-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=a&&s>o){if(o=s,s===a){if(i===n.y)return n;if(i===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(a===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{a>=n.x&&n.x>=u&&a!==n.x&&m(i<h?a:o,i,u,h,i<h?o:a,i,n.x,n.y)&&(l=Math.abs(i-n.y)/(a-n.x),T(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=k(e,t);i(e,e.next),i(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,a){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*a)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*a)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function m(t,e,r,n,a,i,o,s){return(a-o)*(e-s)-(t-o)*(i-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(i-s)-(a-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(T(t,e)&&T(e,t)&&function(t,e){var r=t,n=!1,a=(t.x+e.x)/2,i=(t.y+e.y)/2;do{r.y>i!=r.next.y>i&&r.next.y!==r.y&&a<(r.next.x-r.x)*(i-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var a=w(y(t,e,r)),i=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return a!==i&&o!==s||(!(0!==a||!_(t,r,e))||(!(0!==i||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function T(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function k(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),a=t.next,i=e.prev;return t.next=e,e.prev=t,r.next=a,a.prev=r,n.next=r,r.prev=n,i.next=n,n.prev=i,n}function M(t,e,r,n){var a=new S(t,e,r);return n?(a.next=n.next,a.prev=n,n.next.prev=a,n.next=a):(a.prev=a,a.next=a),a}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var a=0,i=e,o=r-n;i<r;i+=n)a+=(t[o]-t[i])*(t[i+1]+t[o+1]),o=i;return a}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var a=e&&e.length,i=a?e[0]*r:t.length,o=Math.abs(E(t,0,i,r));if(a)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,a=0;a<t.length;a++){for(var i=0;i<t[a].length;i++)for(var o=0;o<e;o++)r.vertices.push(t[a][i][o]);a>0&&(n+=t[a-1].length,r.holes.push(n))}return r}},{}],178:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var a=0;a<r;++a){var i=t[a];e=Math.max(e,i[0],i[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(a=0;a<e;++a)o[a]=[];for(a=0;a<r;++a){i=t[a];o[i[0]].push(i[1]),o[i[1]].push(i[0])}for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=t(\"uniq\")},{uniq:569}],179:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t,e){var r,a=[],i=[],o=[],s={},l=[];function c(t){var e,n,a=!1;for(i.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(u(r,i),a=!0):o[n]||(a=c(n));if(a)!function t(e){o[e]=!1,s.hasOwnProperty(e)&&Object.keys(s[e]).forEach((function(r){delete s[e][r],o[r]&&t(r)}))}(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var h=s[n];h||(h={},s[n]=h),h[n]=!0}return i.pop(),a}function u(t,r){var n=[].concat(r).concat(t);e?e(c):a.push(n)}function h(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,a=n(t).components.filter((function(t){return t.length>1})),i=1/0,o=0;o<a.length;o++)for(var s=0;s<a[o].length;s++)a[o][s]<i&&(i=a[o][s],r=o);var l=a[r];return!!l&&{leastVertex:i,adjList:t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}))}}r=0;for(var f=t.length;r<f;){var p=h(r);if(r=p.leastVertex,l=p.adjList){for(var d=0;d<l.length;d++)for(var g=0;g<l[d].length;g++){var m=l[d][g];o[+m]=!1,s[m]={}}c(r),r+=1}else r=f}return e?void 0:a}},{\"strongly-connected-components\":541}],180:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":211}],181:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":182,\"./shim\":183}],182:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,a=t(\"../../function/is-arguments\"),i=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,m,v,y,x,b,_,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&i(this))e=this;else{if(!T){if(a(t))return 1!==(v=t.length)?Array.apply(null,t):((m=new Array(1))[0]=t[0],m);if(h(t)){for(m=new Array(v=t.length),r=0;r<v;++r)m[r]=t[r];return m}}m=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(m=new e),b=x.next(),r=0;!b.done;)w=T?f.call(T,k,b.value,r):b.value,e?(p.value=w,d(m,r,p)):m[r]=w,b=x.next(),++r;v=r}else if(u(t)){for(v=t.length,e&&(m=new e),r=0,g=0;r<v;++r)w=t[r],r+1<v&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=T?f.call(T,k,w,g):w,e?(p.value=w,d(m,g,p)):m[g]=w,++g;v=g}if(void 0===v)for(v=o(t.length),e&&(m=new e(v)),r=0;r<v;++r)w=T?f.call(T,k,t[r],r):t[r],e?(p.value=w,d(m,r,p)):m[r]=w;return e&&(p.value=null,m.length=v),m}},{\"../../function/is-arguments\":184,\"../../function/is-function\":185,\"../../number/to-pos-integer\":191,\"../../object/is-value\":200,\"../../object/valid-callable\":209,\"../../object/valid-value\":211,\"../../string/is-string\":215,\"es6-symbol\":225}],184:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,a=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===a}},{}],185:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,a=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);e.exports=function(t){return\"function\"==typeof t&&a(n.call(t))}},{}],186:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],187:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":188,\"./shim\":189}],188:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],189:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],190:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),a=Math.abs,i=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*i(a(t)):t}},{\"../math/sign\":187}],191:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),a=Math.max;e.exports=function(t){return a(0,n(t))}},{\"./to-integer\":190}],192:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),a=t(\"./valid-value\"),i=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(a(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?i.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e}))}}},{\"./valid-callable\":209,\"./valid-value\":211}],193:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":194,\"./shim\":195}],194:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],195:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),a=t(\"../valid-value\"),i=Math.max;e.exports=function(t,e){var r,o,s,l=i(arguments.length,2);for(t=Object(a(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":201,\"../valid-value\":211}],196:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),a=t(\"./assign\"),i=t(\"./valid-value\");e.exports=function(t){var e=Object(i(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):a(s,t),s}},{\"../array/from\":181,\"./assign\":193,\"./valid-value\":211}],197:[function(t,e,r){\"use strict\";var n,a,i,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(a={},i={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){i[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(a,i),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:a}),function(t,e){return s(null===t?a:t,e)}):s},{\"./set-prototype-of/is-implemented\":207,\"./set-prototype-of/shim\":208}],198:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":192}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),a={function:!0,object:!0};e.exports=function(t){return n(t)&&a[typeof t]||!1}},{\"./is-value\":200}],200:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":186}],201:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":202,\"./shim\":203}],202:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],203:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),a=Object.keys;e.exports=function(t){return a(n(t)?Object(t):t)}},{\"../is-value\":200}],204:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),a=t(\"./for-each\"),i=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),a(t,(function(t,n,a,s){r[n]=i.call(e,o,t,n,a,s)})),r}},{\"./for-each\":198,\"./valid-callable\":209}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),a=Array.prototype.forEach,i=Object.create,o=function(t,e){var r;for(r in t)e[r]=t[r]};e.exports=function(t){var e=i(null);return a.call(arguments,(function(t){n(t)&&o(Object(t),e)})),e}},{\"./is-value\":200}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=Object.create,a=Object.getPrototypeOf,i={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&a(t(e(null),i))===i}},{}],208:[function(t,e,r){\"use strict\";var n,a=t(\"../is-object\"),i=t(\"../valid-value\"),o=Object.prototype.isPrototypeOf,s=Object.defineProperty,l={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(i(t),null===e||a(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=function(t){var e,r;return t?(2===t.level?t.set?(r=t.set,e=function(t,e){return r.call(n(t,e),e),t}):e=function(t,e){return n(t,e).__proto__=e,t}:e=function t(e,r){var a;return n(e,r),(a=o.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,a&&s(t.nullPolyfill,\"__proto__\",l),e},Object.defineProperty(e,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:t.level})):null}(function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}()),t(\"../create\")},{\"../create\":197,\"../is-object\":199,\"../valid-value\":211}],209:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],210:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":199}],211:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":200}],212:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":213,\"./shim\":214}],213:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],214:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],215:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,a=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===a)||!1}},{}],216:[function(t,e,r){\"use strict\";var n=Object.create(null),a=Math.random;e.exports=function(){var t;do{t=a().toString(36).slice(2)}while(n[t]);return t}},{}],217:[function(t,e,r){\"use strict\";var n,a=t(\"es5-ext/object/set-prototype-of\"),i=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?i.call(e,\"key+value\")?\"key+value\":i.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},a&&a(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/string/#/contains\":212,\"es6-symbol\":225}],218:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),a=t(\"es5-ext/object/valid-callable\"),i=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,m,v=arguments[2];if(s(t)||n(t)?r=\"array\":i(t)?r=\"string\":t=o(t),a(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,v,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(m=g.charCodeAt(0))>=55296&&m<=56319&&(g+=t[++p]),l.call(e,v,g,h),!f);++p);else c.call(t,(function(t){return l.call(e,v,t,h),f}))}},{\"./get\":219,\"es5-ext/function/is-arguments\":184,\"es5-ext/object/valid-callable\":209,\"es5-ext/string/is-string\":215}],219:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),a=t(\"es5-ext/string/is-string\"),i=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new i(t):a(t)?new o(t):new i(t)}},{\"./array\":217,\"./string\":222,\"./valid-iterable\":223,\"es5-ext/function/is-arguments\":184,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],220:[function(t,e,r){\"use strict\";var n,a=t(\"es5-ext/array/#/clear\"),i=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,i({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&a.call(this.__redo__),this.__nextIndex__=0}))}))),h(n.prototype,u.iterator,l((function(){return this})))},{d:155,\"d/auto-bind\":154,\"es5-ext/array/#/clear\":180,\"es5-ext/object/assign\":193,\"es5-ext/object/valid-callable\":209,\"es5-ext/object/valid-value\":211,\"es6-symbol\":225}],221:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),a=t(\"es5-ext/object/is-value\"),i=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!a(t)&&(!!s(t)||(!!i(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":184,\"es5-ext/object/is-value\":200,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],222:[function(t,e,r){\"use strict\";var n,a=t(\"es5-ext/object/set-prototype-of\"),i=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",i(\"\",t.length))},a&&a(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:i((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:i((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,i(\"c\",\"String Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es6-symbol\":225}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":221}],224:[function(t,e,r){(function(n,a){\n",
       "/*!\n",
       " * @overview es6-promise - a tiny implementation of Promises/A+.\n",
       " * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)\n",
       " * @license   Licensed under MIT license\n",
       " *            See https://raw.githubusercontent.com/stefanpenner/es6-promise/master/LICENSE\n",
       " * @version   v4.2.8+1e68dce6\n",
       " */\n",
       "!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,(function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},i=0,o=void 0,s=void 0,l=function(t,e){g[i]=t,g[i+1]=e,2===(i+=2)&&(s?s(m):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(m,1)}}var g=new Array(1e3);function m(){for(var t=0;t<i;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}i=0}var v,y,x,b,_=void 0;function w(t,e){var r=this,n=new this.constructor(M);void 0===n[k]&&D(n);var a=r._state;if(a){var i=arguments[a-1];l((function(){return z(a,n,i,r._result)}))}else P(r,n,t,e);return n}function T(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(M);return S(e,t),e}f?_=function(){return n.nextTick(m)}:h?(y=0,x=new h(m),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((v=new MessageChannel).port1.onmessage=m,_=function(){return v.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var t=Function(\"return this\")().require(\"vertx\");return\"undefined\"!=typeof(o=t.runOnLoop||t.runOnContext)?function(){o(m)}:d()}catch(t){return d()}}():d();var k=Math.random().toString(36).substring(2);function M(){}function A(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===T?function(t,e){1===e._state?C(t,e._result):2===e._state?L(t,e._result):P(e,void 0,(function(e){return S(t,e)}),(function(e){return L(t,e)}))}(t,r):void 0===n?C(t,r):e(n)?function(t,e,r){l((function(t){var n=!1,a=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,(function(r){n||(n=!0,e!==r?S(t,r):C(t,r))}),(function(e){n||(n=!0,L(t,e))}),t._label);!n&&a&&(n=!0,L(t,a))}),t)}(t,r,n):C(t,r)}function S(t,e){if(t===e)L(t,new TypeError(\"You cannot resolve a promise with itself\"));else if(a=typeof(n=e),null===n||\"object\"!==a&&\"function\"!==a)C(t,e);else{var r=void 0;try{r=e.then}catch(e){return void L(t,e)}A(t,e,r)}var n,a}function E(t){t._onerror&&t._onerror(t._result),I(t)}function C(t,e){void 0===t._state&&(t._result=e,t._state=1,0!==t._subscribers.length&&l(I,t))}function L(t,e){void 0===t._state&&(t._state=2,t._result=e,l(E,t))}function P(t,e,r,n){var a=t._subscribers,i=a.length;t._onerror=null,a[i]=e,a[i+1]=r,a[i+2]=n,0===i&&t._state&&l(I,t)}function I(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,a=void 0,i=t._result,o=0;o<e.length;o+=3)n=e[o],a=e[o+r],n?z(r,n,a,i):a(i);t._subscribers.length=0}}function z(t,r,n,a){var i=e(n),o=void 0,s=void 0,l=!0;if(i){try{o=n(a)}catch(t){l=!1,s=t}if(r===o)return void L(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=a;void 0!==r._state||(i&&l?S(r,o):!1===l?L(r,s):1===t?C(r,o):2===t&&L(r,o))}var O=0;function D(t){t[k]=O++,t._state=void 0,t._result=void 0,t._subscribers=[]}var R=function(){function t(t,e){this._instanceConstructor=t,this.promise=new t(M),this.promise[k]||D(this.promise),r(e)?(this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?C(this.promise,this._result):(this.length=this.length||0,this._enumerate(e),0===this._remaining&&C(this.promise,this._result))):L(this.promise,new Error(\"Array Methods must be provided an Array\"))}return t.prototype._enumerate=function(t){for(var e=0;void 0===this._state&&e<t.length;e++)this._eachEntry(t[e],e)},t.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===T){var a=void 0,i=void 0,o=!1;try{a=t.then}catch(t){o=!0,i=t}if(a===w&&void 0!==t._state)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof a)this._remaining--,this._result[e]=t;else if(r===F){var s=new r(M);o?L(s,i):A(s,t,a),this._willSettleAt(s,e)}else this._willSettleAt(new r((function(e){return e(t)})),e)}else this._willSettleAt(n(t),e)},t.prototype._settledAt=function(t,e,r){var n=this.promise;void 0===n._state&&(this._remaining--,2===t?L(n,r):this._result[e]=r),0===this._remaining&&C(n,this._result)},t.prototype._willSettleAt=function(t,e){var r=this;P(t,void 0,(function(t){return r._settledAt(1,e,t)}),(function(t){return r._settledAt(2,e,t)}))},t}();var F=function(){function t(e){this[k]=O++,this._result=this._state=void 0,this._subscribers=[],M!==e&&(\"function\"!=typeof e&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof t?function(t,e){try{e((function(e){S(t,e)}),(function(e){L(t,e)}))}catch(e){L(t,e)}}(this,e):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}return t.prototype.catch=function(t){return this.then(null,t)},t.prototype.finally=function(t){var r=this.constructor;return e(t)?this.then((function(e){return r.resolve(t()).then((function(){return e}))}),(function(e){return r.resolve(t()).then((function(){throw e}))})):this.then(t,t)},t}();return F.prototype.then=w,F.all=function(t){return new R(this,t).promise},F.race=function(t){var e=this;return r(t)?new e((function(r,n){for(var a=t.length,i=0;i<a;i++)e.resolve(t[i]).then(r,n)})):new e((function(t,e){return e(new TypeError(\"You must pass an array to race.\"))}))},F.resolve=T,F.reject=function(t){var e=new this(M);return L(e,t),e},F._setScheduler=function(t){s=t},F._setAsap=function(t){l=t},F._asap=l,F.polyfill=function(){var t=void 0;if(\"undefined\"!=typeof a)t=a;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=F},F.Promise=F,F}))}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:500}],225:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?t(\"ext/global-this\").Symbol:t(\"./polyfill\")},{\"./is-implemented\":226,\"./polyfill\":231,\"ext/global-this\":238}],226:[function(t,e,r){\"use strict\";var n=t(\"ext/global-this\"),a={object:!0,symbol:!0};e.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!a[typeof e.iterator]&&(!!a[typeof e.toPrimitive]&&!!a[typeof e.toStringTag])}},{\"ext/global-this\":238}],227:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],228:[function(t,e,r){\"use strict\";var n=t(\"d\"),a=Object.create,i=Object.defineProperty,o=Object.prototype,s=a(null);e.exports=function(t){for(var e,r,a=0;s[t+(a||\"\")];)++a;return s[t+=a||\"\"]=!0,i(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,i(this,e,n(t)),r=!1)}))),e}},{d:155}],229:[function(t,e,r){\"use strict\";var n=t(\"d\"),a=t(\"ext/global-this\").Symbol;e.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",a&&a.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",a&&a.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",a&&a.iterator||t(\"iterator\")),match:n(\"\",a&&a.match||t(\"match\")),replace:n(\"\",a&&a.replace||t(\"replace\")),search:n(\"\",a&&a.search||t(\"search\")),species:n(\"\",a&&a.species||t(\"species\")),split:n(\"\",a&&a.split||t(\"split\")),toPrimitive:n(\"\",a&&a.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",a&&a.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",a&&a.unscopables||t(\"unscopables\"))})}},{d:155,\"ext/global-this\":238}],230:[function(t,e,r){\"use strict\";var n=t(\"d\"),a=t(\"../../../validate-symbol\"),i=Object.create(null);e.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return i[e]?i[e]:i[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in a(t),i)if(i[e]===t)return e}))})}},{\"../../../validate-symbol\":232,d:155}],231:[function(t,e,r){\"use strict\";var n,a,i,o=t(\"d\"),s=t(\"./validate-symbol\"),l=t(\"ext/global-this\").Symbol,c=t(\"./lib/private/generate-name\"),u=t(\"./lib/private/setup/standard-symbols\"),h=t(\"./lib/private/setup/symbol-registry\"),f=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),i=!0}catch(t){}else l=null;a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return n(t)},e.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return i?l(e):(r=f(a.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),h(n),p(a.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(a.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(a.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},{\"./lib/private/generate-name\":228,\"./lib/private/setup/standard-symbols\":229,\"./lib/private/setup/symbol-registry\":230,\"./validate-symbol\":232,d:155,\"ext/global-this\":238}],232:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":227}],233:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":234,\"./polyfill\":236}],234:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],235:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],236:[function(t,e,r){\"use strict\";var n,a=t(\"es5-ext/object/is-value\"),i=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,m=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&i&&WeakMap!==n?i(new WeakMap,v(this)):this,a(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(i&&i(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!m.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(m.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return m.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":235,d:155,\"es5-ext/object/is-value\":200,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/object/valid-object\":210,\"es5-ext/object/valid-value\":211,\"es5-ext/string/random-uniq\":216,\"es6-iterator/for-of\":218,\"es6-iterator/get\":219,\"es6-symbol\":225}],237:[function(t,e,r){var n=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};e.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return n()}try{return __global__||n()}finally{delete Object.prototype.__global__}}()},{}],238:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?globalThis:t(\"./implementation\")},{\"./implementation\":237,\"./is-implemented\":239}],239:[function(t,e,r){\"use strict\";e.exports=function(){return\"object\"==typeof globalThis&&(!!globalThis&&globalThis.Array===Array)}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,a=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[a*t[12]-t[8],a*t[13]-t[9],a*t[14]-t[10],a*t[15]-t[11]]]}},{}],241:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":444}],242:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),a=t(\"binary-search-bounds\");function i(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=a.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=a.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],m=e[o+1]-g||1,v=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)v[p]=l[f],x[p]=c[f]*m,y[p]=l[f+u],b[p]=c[f+u]*m,_=_&&v[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=v[p];else n(v,x,y,b,(t-g)/m,s)}var w=h[0],T=h[1];for(p=0;p<u;++p)s[p]=i(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,i=a.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(i>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(i+1)-1;var f=e[i],p=e[i+1]-f||1,d=this._scratch[1],g=this._scratch[2],m=this._scratch[3],v=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],m[h]=l[u]*p,g[h]=s[u+c],v[h]=l[u+c]*p,y=y&&d[h]===g[h]&&m[h]===v[h]&&0===m[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,m,g,v,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),a.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(i(l[h-1],c[h-1],arguments[h])),a.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=i(c[f-1],u[f-1],arguments[f]);n.push(p),a.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,a=this.bounds,o=a[0],s=a[1];this._time.push(t);for(var l=e;l>0;--l)r.push(i(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(i(l[f-1],c[f-1],n[o++]+p)),a.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,a=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(i(l[h],c[h],n[o]+u*a[o])),a.push(0),o+=1}}},{\"binary-search-bounds\":243,\"cubic-hermite\":150}],243:[function(t,e,r){\"use strict\";function n(t,e,r,n,a,i){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",a?\".get(m)\":\"[m]\"];return i?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),i?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function a(t,e,r,a){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,a),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,a),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,a),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,a),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:a(\">=\",!1,\"GE\"),gt:a(\">\",!1,\"GT\"),lt:a(\"<\",!0,\"LT\"),le:a(\"<=\",!0,\"LE\"),eq:a(\"-\",!0,\"EQ\",!0)}},{}],244:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var a,i,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(a=0,o=r;a<t.length;a++)for(i=0;i<l;i++)e[o++]=null===t[a][i]?NaN:t[a][i]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),a=0,o=r,s=e.length;o<s;o++,a++)e[o]=null===t[a]?NaN:t[a];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:175}],245:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),a=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),i=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||a;i&&\"string\"!=typeof i&&(i=n(i));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=i,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";var f=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":147}],246:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return a(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=i(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var m=i(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-m+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var v=p-i(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=v,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=i(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=i(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=i(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=i(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=i(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=i(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=i(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-v}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,a(d,c)}function a(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function i(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],247:[function(t,e,r){\"use strict\";e.exports=function(t){return new s(t||g,null)};function n(t,e,r,n,a,i){this._color=t,this.key=e,this.value=r,this.left=n,this.right=a,this._count=i}function a(t){return new n(t._color,t.key,t.value,t.left,t.right,t._count)}function i(t,e){return new n(t,e.key,e.value,e.left,e.right,e._count)}function o(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function s(t,e){this._compare=t,this.root=e}var l=s.prototype;function c(t,e){var r;if(e.left&&(r=c(t,e.left)))return r;return(r=t(e.key,e.value))||(e.right?c(t,e.right):void 0)}function u(t,e,r,n){if(e(t,n.key)<=0){var a;if(n.left)if(a=u(t,e,r,n.left))return a;if(a=r(n.key,n.value))return a}if(n.right)return u(t,e,r,n.right)}function h(t,e,r,n,a){var i,o=r(t,a.key),s=r(e,a.key);if(o<=0){if(a.left&&(i=h(t,e,r,n,a.left)))return i;if(s>0&&(i=n(a.key,a.value)))return i}if(s>0&&a.right)return h(t,e,r,n,a.right)}function f(t,e){this.tree=t,this._stack=e}Object.defineProperty(l,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(l,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(l,\"length\",{get:function(){return this.root?this.root._count:0}}),l.insert=function(t,e){for(var r=this._compare,a=this.root,l=[],c=[];a;){var u=r(t,a.key);l.push(a),c.push(u),a=u<=0?a.left:a.right}l.push(new n(0,t,e,null,null,1));for(var h=l.length-2;h>=0;--h){a=l[h];c[h]<=0?l[h]=new n(a._color,a.key,a.value,l[h+1],a.right,a._count+1):l[h]=new n(a._color,a.key,a.value,a.left,l[h+1],a._count+1)}for(h=l.length-1;h>1;--h){var f=l[h-1];a=l[h];if(1===f._color||1===a._color)break;var p=l[h-2];if(p.left===f)if(f.left===a){if(!(d=p.right)||0!==d._color){if(p._color=0,p.left=f.right,f._color=1,f.right=p,l[h-2]=f,l[h-1]=a,o(p),o(f),h>=3)(g=l[h-3]).left===p?g.left=f:g.right=f;break}f._color=1,p.right=i(1,d),p._color=0,h-=1}else{if(!(d=p.right)||0!==d._color){if(f.right=a.left,p._color=0,p.left=a.right,a._color=1,a.left=f,a.right=p,l[h-2]=a,l[h-1]=f,o(p),o(f),o(a),h>=3)(g=l[h-3]).left===p?g.left=a:g.right=a;break}f._color=1,p.right=i(1,d),p._color=0,h-=1}else if(f.right===a){if(!(d=p.left)||0!==d._color){if(p._color=0,p.right=f.left,f._color=1,f.left=p,l[h-2]=f,l[h-1]=a,o(p),o(f),h>=3)(g=l[h-3]).right===p?g.right=f:g.left=f;break}f._color=1,p.left=i(1,d),p._color=0,h-=1}else{var d;if(!(d=p.left)||0!==d._color){var g;if(f.left=a.right,p._color=0,p.right=a.left,a._color=1,a.right=f,a.left=p,l[h-2]=a,l[h-1]=f,o(p),o(f),o(a),h>=3)(g=l[h-3]).right===p?g.right=a:g.left=a;break}f._color=1,p.left=i(1,d),p._color=0,h-=1}}return l[0]._color=1,new s(r,l[0])},l.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return c(t,this.root);case 2:return u(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return h(e,r,this._compare,t,this.root)}},Object.defineProperty(l,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new f(this,t)}}),Object.defineProperty(l,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new f(this,t)}}),l.at=function(t){if(t<0)return new f(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new f(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new f(this,[])},l.ge=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i<=0&&(a=n.length),r=i<=0?r.left:r.right}return n.length=a,new f(this,n)},l.gt=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i<0&&(a=n.length),r=i<0?r.left:r.right}return n.length=a,new f(this,n)},l.lt=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i>0&&(a=n.length),r=i<=0?r.left:r.right}return n.length=a,new f(this,n)},l.le=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i>=0&&(a=n.length),r=i<0?r.left:r.right}return n.length=a,new f(this,n)},l.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var a=e(t,r.key);if(n.push(r),0===a)return new f(this,n);r=a<=0?r.left:r.right}return new f(this,[])},l.remove=function(t){var e=this.find(t);return e?e.remove():this},l.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var p=f.prototype;function d(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function g(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(p,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(p,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),p.clone=function(){return new f(this.tree,this._stack.slice())},p.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new n(r._color,r.key,r.value,r.left,r.right,r._count);for(var l=t.length-2;l>=0;--l){(r=t[l]).left===t[l+1]?e[l]=new n(r._color,r.key,r.value,e[l+1],r.right,r._count):e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count)}if((r=e[e.length-1]).left&&r.right){var c=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var u=e[c-1];e.push(new n(r._color,u.key,u.value,r.left,r.right,r._count)),e[c-1].key=r.key,e[c-1].value=r.value;for(l=e.length-2;l>=c;--l)r=e[l],e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count);e[c-1].left=e[c]}if(0===(r=e[e.length-1])._color){var h=e[e.length-2];h.left===r?h.left=null:h.right===r&&(h.right=null),e.pop();for(l=0;l<e.length;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(r.left||r.right){r.left?d(r,r.left):r.right&&d(r,r.right),r._color=1;for(l=0;l<e.length-1;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(1===e.length)return new s(this.tree._compare,null);for(l=0;l<e.length;++l)e[l]._count--;var f=e[e.length-2];return function(t){for(var e,r,n,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((r=t[l-1]).left===e){if((n=r.right).right&&0===n.right._color){if(s=(n=r.right=a(n)).right=a(n.right),r.right=n.left,n.left=r,n.right=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).left===r?c.left=n:c.right=n;return void(t[l-1]=n)}if(n.left&&0===n.left._color){if(s=(n=r.right=a(n)).left=a(n.left),r.right=s.left,n.left=s.right,s.left=r,s.right=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).left===r?c.left=s:c.right=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.right=i(0,n));r.right=i(0,n);continue}n=a(n),r.right=n.left,n.left=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).left===r?c.left=n:c.right=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((n=r.left).left&&0===n.left._color){if(s=(n=r.left=a(n)).left=a(n.left),r.left=n.right,n.right=r,n.left=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).right===r?c.right=n:c.left=n;return void(t[l-1]=n)}if(n.right&&0===n.right._color){if(s=(n=r.left=a(n)).right=a(n.right),r.left=s.right,n.right=s.left,s.right=r,s.left=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).right===r?c.right=s:c.left=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.left=i(0,n));r.left=i(0,n);continue}var c;n=a(n),r.left=n.right,n.right=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).right===r?c.right=n:c.left=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(e),f.left===r?f.left=null:f.right=null,new s(this.tree._compare,e[0])},Object.defineProperty(p,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(p,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(p,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),p.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),p.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),a=e[e.length-1];r[r.length-1]=new n(a._color,a.key,t,a.left,a.right,a._count);for(var i=e.length-2;i>=0;--i)(a=e[i]).left===e[i+1]?r[i]=new n(a._color,a.key,a.value,r[i+1],a.right,a._count):r[i]=new n(a._color,a.key,a.value,a.left,r[i+1],a._count);return new s(this.tree._compare,r[0])},p.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],248:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function i(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+607/128+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(i(e));e-=1;for(var r=n[0],a=1;a<9;a++)r+=n[a]/(e+a);var o=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(o,e+.5)*Math.exp(-o)*r},e.exports.log=i},{}],249:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,a=e;try{var i=[t];0===t.indexOf(\"webgl\")&&i.push(\"experimental-\"+t);for(var o=0;o<i.length;o++)if(n=r.getContext(i[o],a))return n}catch(t){n=null}return n||null}},{}],250:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),a=t(\"./lib/lines.js\"),i=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=i(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var a,i=t[n],o=this[n];(e?Array.isArray(i)&&Array.isArray(i[0]):Array.isArray(i))?this[n]=a=[r(i[0]),r(i[1]),r(i[2])]:this[n]=a=[r(i),r(i),r(i)];for(var s=0;s<3;++s)if(a[s]!==o[s])return!0}return!1}t=t||{};var r,i=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else i(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),i(\"tickSize\"),i(\"tickAngle\"),i(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),i(\"labelSize\"),i(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),i(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),i(\"lineTickLength\"),i(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),i(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),i(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=a(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,a){for(var i=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=i,f=s,p=o,d=l;c&1<<u&&(h=s,f=i,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],a[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],m={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var v=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||m;for(var e=this.gl,r=t.model||l,n=t.view||l,a=t.projection||l,i=this.bounds,s=t._ortho||!1,u=o(r,n,a,i,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(a[3]*b+a[7]*_+a[11]*w+a[15]*T)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=h[M],this.lastCubeProps.axis[M]=f[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,h,f);e=this.gl;var S,E=g;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=f[M]:E[M]=0;this._background.draw(r,n,a,i,E,this.backgroundColor),this._lines.bind(r,n,a,this);for(M=0;M<3;++M){var C=[0,0,0];f[M]>0?C[M]=i[1][M]:C[M]=i[0][M];for(var L=0;L<2;++L){var P=(M+1+L)%3,I=(M+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,I,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(M+1+L)%3,I=(M+1+(1^L))%3;this.zeroEnable[I]&&Math.min(i[0][I],i[1][I])<=0&&Math.max(i[0][I],i[1][I])>=0&&this._lines.drawZero(P,I,this.bounds,C,this.zeroLineColor[I],this.zeroLineWidth[I]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var z=c(v,A[M].primalMinor),O=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=k/r[5*L];z[L]*=D[L]*R,O[L]*=D[L]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,a,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,a=(t+2)%3,i=e[n],o=e[a],s=r[n],l=r[a];i>0&&l>0||i>0&&l<0||i<0&&l>0||i<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(a)}for(M=0;M<3;++M){var U=A[M].primalMinor,V=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[M]&&(q[L]+=k*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]=\"auto\"):this.tickAlign[M]=-1,F=1,\"auto\"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(M,U,V);for(L=0;L<3;++L)q[L]+=k*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),\"auto\"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=k*U[L]*this.labelPad[L]/r[5*L];q[M]+=.5*(i[0][M]+i[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":251,\"./lib/cube.js\":252,\"./lib/lines.js\":253,\"./lib/text.js\":255,\"./lib/ticks.js\":256}],251:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var m=c;c=u,u=m}var v=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=a(t,[{buffer:v,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:v,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=i(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,v,x,b)};var n=t(\"gl-buffer\"),a=t(\"gl-vao\"),i=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,a,i){for(var o=!1,s=0;s<3;++s)o=o||a[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:a,colors:i},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":258,\"gl-vao\":332}],252:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i,p){a(s,e,t),a(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=i[x][2];for(var b=0;b<2;++b){u[1]=i[b][1];for(var _=0;_<2;++_)u[0]=i[_][0],f(l[y],u,s),y+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=(z=L<<M)+(L<<A)+(1-L<<S),I=z+(1-L<<A)+(L<<S);o(c[z],c[P],c[I],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<M);else{for(L=0;L<2;++L){P=(z=L<<M)+(L<<A)+(1-L<<S),I=z+(1-L<<A)+(L<<S);var z,O=d([l[z],l[P],l[I],l[z+(1<<A)+(1<<S)]]);L?E=O:C=O}C>E&&(w|=1<<M)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x){if((N=R^1<<x)!==w&&N!==D)F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N)}var B=-1;for(x=0;x<3;++x){var N;if((N=R^1<<x)!==w&&N!==D&&N!==F)B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N)}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=m,q=w;for(M=0;M<3;++M)V[M]=q&1<<M?-1:1;return v};var n=t(\"bit-twiddle\"),a=t(\"gl-mat4/multiply\"),i=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var a=0;a<3;++a)t[n]+=e[a]*r[4*a+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=i.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],a=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-a,h=l[0]/l[3]-n,f=l[1]/l[3]-a;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],m=[0,0,0],v={cubeEdges:g,axis:m}},{\"bit-twiddle\":97,\"gl-mat4/multiply\":280,\"robust-orientation\":520,\"split-polygon\":538}],253:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var m=o.length/3|0;s[h]=f,l[h]=m-f;f=o.length/3|0;for(var v=0;v<r[h].length;++v){g=+r[h][v].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}m=o.length/3|0;c[h]=f,u[h]=m-f}var y=n(t,new Float32Array(o)),x=a(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=i(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),a=t(\"gl-vao\"),i=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,a,i,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=a,this.tickOffset=i,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,a){var i=h(s);this.shader.uniforms.majorAxis=s,i[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=i;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,a){if(this.tickCount[t]){var i=h(o);i[t]=1,this.shader.uniforms.majorAxis=i,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=a;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,a,i){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=a,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,a,i){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=a,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":258,\"gl-vao\":332}],254:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),a=t(\"gl-shader\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return a(t,i,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return a(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return a(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":312,glslify:413}],255:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,i,s,l){var u=n(t),h=a(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,i,s,l),p};var n=t(\"gl-buffer\"),a=t(\"gl-vao\"),i=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var a=this.shader.uniforms;a.model=t,a.view=e,a.projection=r,a.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,a){var o=[];function s(t,e,r,n,a,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return i(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:a,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var m=p[d],v=2;v>=0;--v){var y=f[m[v]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||a,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,a,i,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=i,this.shader.uniforms.color=a,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,a,i,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=i,this.shader.uniforms.color=a,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":254,_process:500,\"gl-buffer\":258,\"gl-vao\":332,\"vectorize-text\":572}],256:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),a=0;n>=0&&(a=r.length-n-1);var i=Math.pow(10,a),o=Math.round(t*e*i),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/i,c=o%i;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),a){for(var h=\"\"+c;h.length<a;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],a=0;a<3;++a){for(var i=[],o=(t[0][a],t[1][a],0);o*e[a]<=t[1][a];++o)i.push({x:o*e[a],text:n(e[a],o)});for(o=-1;o*e[a]>=t[0][a];--o)i.push({x:o*e[a],text:n(e[a],o)});r.push(i)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var a=t[r][n],i=e[r][n];if(a.x!==i.x||a.text!==i.text||a.font!==i.font||a.fontColor!==i.fontColor||a.fontSize!==i.fontSize||a.dx!==i.dx||a.dy!==i.dy)return!1}}return!0}},{}],257:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,v=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||i(f,p,v,x,y)).axis;o(u,p,f),o(u,v,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,S=m;t:for(w=0;w<2;++w){var E=[];if(b[k]<0!=!!w){S[k]=x[w][k];for(var C=0;C<2;++C){S[M]=x[C^w][M];for(var L=0;L<2;++L)S[A]=x[L^C^w][A],E.push(S.slice())}var P=y?5:4;for(C=P;C===P;++C){if(0===E.length)continue t;E=a.positive(E,T[C])}for(C=0;C<E.length;++C){A=E[C];var I=d(m,u,A,r,l);for(L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,A[L]),_[L].hi=Math.max(_[L].hi,A[L]),L!==k&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(I[L])))}}}}return _};var n=t(\"extract-frustum-planes\"),a=t(\"split-polygon\"),i=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,a){for(var i=0;i<3;++i){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[i]+=1,l(s,s,e),s[3]<0&&(t[i]=1/0),o[i]-=1,l(o,o,e),o[3]<0&&(t[i]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*a;t[i]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],m=[0,0,0]},{\"./lib/cube.js\":252,\"extract-frustum-planes\":240,\"gl-mat4/multiply\":280,\"gl-mat4/transpose\":289,\"gl-vec4/transformMat4\":403,\"split-polygon\":538}],258:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),a=t(\"ndarray-ops\"),i=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,a){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=a}var l=s.prototype;function c(t,e,r,n,a,i){var o=a.length*a.BYTES_PER_ELEMENT;if(i<0)return t.bufferData(e,a,n),o;if(o+i>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,i,a),r}function u(t,e){for(var r=n.malloc(t.length,e),a=t.length,i=0;i<a;++i)r[i]=t[i];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=i(s,t.shape);a.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var a=t.createBuffer(),i=new s(t,r,a,0,n);return i.update(e),i}},{ndarray:469,\"ndarray-ops\":464,\"typedarray-pool\":567}],259:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\");e.exports=function(t,e){var r=t.positions,a=t.vectors,i={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),i;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=null,d=null,g=[],m=1/0,v=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),h=Math.min(x[2],h),f=Math.max(x[2],f);var b=a[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(m=Math.min(m,_),v=!1):v=!0}v||(p=x,d=b),g.push(b)}var w=[s,c,h],T=[l,u,f];e&&(e[0]=w,e[1]=T),0===o&&(o=1);var k=1/o;isFinite(m)||(m=1),i.vectorScale=m;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*k),i.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],C=x[2],L=g[y],P=n.length(L)*k,I=0;I<8;I++){i.positions.push([S,E,C,A++]),i.positions.push([S,E,C,A++]),i.positions.push([S,E,C,A++]),i.positions.push([S,E,C,A++]),i.positions.push([S,E,C,A++]),i.positions.push([S,E,C,A++]),i.vectors.push(L),i.vectors.push(L),i.vectors.push(L),i.vectors.push(L),i.vectors.push(L),i.vectors.push(L),i.vertexIntensity.push(P,P,P),i.vertexIntensity.push(P,P,P);var z=i.positions.length;i.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return i};var a=t(\"./lib/shaders\");e.exports.createMesh=t(\"./create_mesh\"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:a,traceType:\"cone\"})}},{\"./create_mesh\":260,\"./lib/shaders\":261,\"gl-vec3\":351}],260:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),a=t(\"gl-buffer\"),i=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"gl-mat4/multiply\"),l=t(\"gl-mat4/invert\"),c=t(\"ndarray\"),u=t(\"colormap\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e,r,n,a,i,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=a,this.triangleVectors=i,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=h,this._view=h,this._projection=h,this._resolution=[1,1]}var p=f.prototype;function d(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}function g(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var a=e[n],i=0;i<3;++i)r[4*n+i]=a[i];r[4*n+3]=255*a[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,a=t.vectors;if(n&&r&&a){var i=[],o=[],s=[],l=[],h=[];this.cells=r,this.positions=n,this.vectors=a;var f=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var m=0;m<p.length;++m){var v=p[m];d=Math.min(d,v),g=Math.max(g,v)}else for(m=0;m<n.length;++m){v=n[m][2];d=Math.min(d,v),g=Math.max(g,v)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(m=0;m<n.length;++m)for(var y=n[m],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(m=0;m<r.length;++m){var _=r[m];switch(_.length){case 3:for(x=0;x<3;++x){y=n[T=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var T;y=n[T=_[2-x]];i.push(y[0],y[1],y[2],y[3]);var k=a[T];o.push(k[0],k[1],k[2],k[3]||0);var M,A=f;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[T]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(M[0],M[1]),h.push(m)}b+=1}}this.triangleCount=b,this.trianglePositions.update(i),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(h))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,a=t.projection||h,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:a,inverseModel:h.slice(),clipBounds:i,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/f}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,a=t.projection||h,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(a),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:a,clipBounds:i,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),a={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?a.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(a.intensity=this.intensity[r[1]],a.velocity=this.vectors[r[1]].slice(0,3),a.divergence=this.vectors[r[1]][3],a.index=e),a},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var n=r.shaders;1===arguments.length&&(t=(e=t).gl);var s=d(t,n),l=g(t,n),u=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));u.generateMipmap(),u.minFilter=t.LINEAR_MIPMAP_LINEAR,u.magFilter=t.LINEAR;var h=a(t),p=a(t),m=a(t),v=a(t),y=a(t),x=i(t,[{buffer:h,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:p,type:t.FLOAT,size:4}]),b=new f(t,u,s,l,h,p,y,m,v,x,r.traceType||\"cone\");return b.update(e),b}},{colormap:131,\"gl-buffer\":258,\"gl-mat4/invert\":278,\"gl-mat4/multiply\":280,\"gl-shader\":312,\"gl-texture2d\":327,\"gl-vao\":332,ndarray:469}],261:[function(t,e,r){var n=t(\"glslify\"),a=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),i=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:413}],262:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],263:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":262}],264:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=a(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=i(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),a=t(\"gl-vao\"),i=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,a=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var i=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(a[3]*i+a[7]*s+a[11]*l+a[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var a=-1;a<=1;a+=2){var i=[0,0,0];i[(n+e)%3]=a,r.push(i)}t[e]=r}return t}();function h(t,e,r,n){for(var a=u[n],i=0;i<a.length;++i){var o=a[i];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return a.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var a=[],i=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<i;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],a.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(a,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],a.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(a,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(a)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":265,\"gl-buffer\":258,\"gl-vao\":332}],265:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),a=t(\"gl-shader\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return a(t,i,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":312,glslify:413}],266:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){a||(a=t.FRAMEBUFFER_UNSUPPORTED,i=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var a=new Array(r),i=0;i<n;++i)a[i]=t.COLOR_ATTACHMENT0+i;for(i=n;i<r;++i)a[i]=t.NONE;l[n]=a}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var m=!1;\"stencil\"in n&&(m=!!n.stencil);return new d(t,e,r,f,h,g,m,c)};var a,i,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case a:throw new Error(\"gl-fbo: Framebuffer unsupported\");case i:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,a,i,o){if(!a)return null;var s=n(t,e,r,i,a);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,a){var i=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,i),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,a,t.RENDERBUFFER,i),i}function d(t,e,r,n,a,i,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(a);for(var d=0;d<a;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=i,this._useStencil=o;var g=this,m=[0|e,0|r];Object.defineProperties(m,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=m,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),a=t._shape[0],i=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,m=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var v=0;v<o;++v)t.color[v]=f(r,a,i,m,r.RGBA,r.COLOR_ATTACHMENT0+v);0===o?(t._color_rb=p(r,a,i,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,a,i,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,a,i,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,a,i,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,a,i,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,a,i,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null);for(v=0;v<t.color.length;++v)t.color[v].dispose(),t.color[v]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function m(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,a=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var i=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,i),h(s)),u(n,i)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return m(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return m(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,m(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":327}],267:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,a=t(\"gl-constants/lookup\"),i=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=i(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===a.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}var m=o(e).split(\"\\n\");for(p=0;p<m.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var v=m[p];if(c+=v+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":66,\"gl-constants/lookup\":263,\"glsl-shader-name\":405,\"sprintf-js\":539}],268:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),a=o(r,l.pickVertex,l.pickFragment),i=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,a,i,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),a=t(\"iota-array\"),i=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,a,i,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=a,this.colorBuffer=i,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var a=t.gl,i=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=i[2]-i[0],c=i[3]-i[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-i[0])/l-1,u[7]=2*(r[1]-i[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(a.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(a.UNSIGNED_BYTE,!0),a.drawArrays(a.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,a=this.pickShader,i=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=i[2]-i[0],u=i[3]-i[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(i[0]-l[0])/h-1,t[7]=2*(i[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,a.bind();var d=a.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=a.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,a=this.shape[0]*this.shape[1];if(r<n||r>=n+a)return null;var i=r-n,o=this.xData,s=this.yData;return{object:this,pointId:i,dataCoord:[o[i%this.shape[0]],s[i/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||a(e[0]),o=t.y||a(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,h,p,d=t.colorLevels||[0],g=t.colorValues||[0,0,0,1],m=d.length,v=this.bounds;l?(c=v[0]=r[0],u=v[1]=o[0],h=v[2]=r[r.length-1],p=v[3]=o[o.length-1]):(c=v[0]=r[0]+(r[1]-r[0])/2,u=v[1]=o[0]+(o[1]-o[0])/2,h=v[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=v[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var y=1/(h-c),x=1/(p-u),b=e[0],_=e[1];this.shape=[b,_];var w=(l?(b-1)*(_-1):b*_)*(f.length>>>1);this.numVertices=w;for(var T=i.mallocUint8(4*w),k=i.mallocFloat32(2*w),M=i.mallocUint8(2*w),A=i.mallocUint32(w),S=0,E=l?b-1:b,C=l?_-1:_,L=0;L<C;++L){var P,I;l?(P=x*(o[L]-u),I=x*(o[L+1]-u)):(P=L<_-1?x*(o[L]-(o[L+1]-o[L])/2-u):x*(o[L]-(o[L]-o[L-1])/2-u),I=L<_-1?x*(o[L]+(o[L+1]-o[L])/2-u):x*(o[L]+(o[L]-o[L-1])/2-u));for(var z=0;z<E;++z){var O,D;l?(O=y*(r[z]-c),D=y*(r[z+1]-c)):(O=z<b-1?y*(r[z]-(r[z+1]-r[z])/2-c):y*(r[z]-(r[z]-r[z-1])/2-c),D=z<b-1?y*(r[z]+(r[z+1]-r[z])/2-c):y*(r[z]+(r[z]-r[z-1])/2-c));for(var R=0;R<f.length;R+=2){var F,B,N,j,U=f[R],V=f[R+1],q=s[l?(L+V)*b+(z+U):L*b+z],H=n.le(d,q);if(H<0)F=g[0],B=g[1],N=g[2],j=g[3];else if(H===m-1)F=g[4*m-4],B=g[4*m-3],N=g[4*m-2],j=g[4*m-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Y=1-G,W=4*H,Z=4*(H+1);F=Y*g[W]+G*g[Z],B=Y*g[W+1]+G*g[Z+1],N=Y*g[W+2]+G*g[Z+2],j=Y*g[W+3]+G*g[Z+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*O+.5*D,k[2*S+1]=.5*P+.5*I,M[2*S]=U,M[2*S+1]=V,A[S]=L*b+z,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(M),this.colorBuffer.update(T),this.idBuffer.update(A),i.free(k),i.free(T),i.free(M),i.free(A)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":269,\"binary-search-bounds\":96,\"gl-buffer\":258,\"gl-shader\":312,\"iota-array\":437,\"typedarray-pool\":567}],269:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:413}],270:[function(t,e,r){var n=t(\"glslify\"),a=t(\"gl-shader\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return a(t,i,o,null,l)},r.createPickShader=function(t){return a(t,i,s,null,l)}},{\"gl-shader\":312,glslify:413}],271:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=h(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=f(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=a(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=i(e,u);d.wrap=e.REPEAT;var g=new v(e,r,o,s,l,d);return g.update(t),g};var n=t(\"gl-buffer\"),a=t(\"gl-vao\"),i=t(\"gl-texture2d\"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t(\"binary-search-bounds\"),c=t(\"ndarray\"),u=t(\"./lib/shaders\"),h=u.createShader,f=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var a=t[n]-e[n];r+=a*a}return Math.sqrt(r)}function g(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function m(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,a,i){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=a,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=i,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=v.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:g(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:g(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var a=[],i=[],o=[],s=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var p=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,m=!1;t:for(e=1;e<f.length;++e){var v,y,x,b=f[e-1],_=f[e];for(i.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&a.length>0){for(var w=0;w<24;++w)a.push(a[a.length-12]);u+=2,m=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(p[0])?(v=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):v=y=p,3===v.length&&(v=[v[0],v[1],v[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&v[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var T=s;if(s+=d(b,_),m){for(r=0;r<2;++r)a.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3]);u+=2,m=!1}a.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],T,-x,v[0],v[1],v[2],v[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(a),i.push(s),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=i,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new m(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],a=this.points[Math.min(r+1,this.points.length-1)],i=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-i,u=[0,0,0],h=0;h<3;++h)u[h]=c*n[h]+i*a[h];var f=Math.min(i<.5?r:r+1,this.points.length-1);return new m(e,u,f,this.points[f])}},{\"./lib/shaders\":270,\"binary-search-bounds\":96,\"gl-buffer\":258,\"gl-texture2d\":327,\"gl-vao\":332,ndarray:469}],272:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],273:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],274:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3],i=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],m=t[15];return(e*o-r*i)*(h*m-f*g)-(e*s-n*i)*(u*m-f*d)+(e*l-a*i)*(u*g-h*d)+(r*s-n*o)*(c*m-f*p)-(r*l-a*o)*(c*g-h*p)+(n*l-a*s)*(c*d-u*p)}},{}],275:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r+r,s=n+n,l=a+a,c=r*o,u=n*o,h=n*s,f=a*o,p=a*s,d=a*l,g=i*o,m=i*s,v=i*l;return t[0]=1-h-d,t[1]=u+v,t[2]=f-m,t[3]=0,t[4]=u-v,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+m,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],276:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=n+n,l=a+a,c=i+i,u=n*s,h=n*l,f=n*c,p=a*l,d=a*c,g=i*c,m=o*s,v=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-v,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+m,t[7]=0,t[8]=f+v,t[9]=d-m,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],277:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],278:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-a*o,b=r*c-i*o,_=n*l-a*s,w=n*c-i*s,T=a*c-i*l,k=u*g-h*d,M=u*m-f*d,A=u*v-p*d,S=h*m-f*g,E=h*v-p*g,C=f*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(a*E-n*C-i*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(f*w-h*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-a*A+i*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-f*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-i*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+a*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],279:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,a){var i,o,s,l,c,u,h,f,p,d,g=e[0],m=e[1],v=e[2],y=a[0],x=a[1],b=a[2],_=r[0],w=r[1],T=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(m-w)<1e-6&&Math.abs(v-T)<1e-6)return n(t);h=g-_,f=m-w,p=v-T,d=1/Math.sqrt(h*h+f*f+p*p),i=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(i*i+o*o+s*s))?(i*=d=1/d,o*=d,s*=d):(i=0,o=0,s=0);l=f*s-p*o,c=p*i-h*s,u=h*o-f*i,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=i,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(i*g+o*m+s*v),t[13]=-(l*g+c*m+u*v),t[14]=-(h*g+f*m+p*v),t[15]=1,t}},{\"./identity\":277}],280:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*a+b*l+_*f+w*m,t[2]=x*i+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*a+b*l+_*f+w*m,t[6]=x*i+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*a+b*l+_*f+w*m,t[10]=x*i+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*a+b*l+_*f+w*m,t[14]=x*i+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}},{}],281:[function(t,e,r){e.exports=function(t,e,r,n,a,i,o){var s=1/(e-r),l=1/(n-a),c=1/(i-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(a+n)*l,t[14]=(o+i)*c,t[15]=1,t}},{}],282:[function(t,e,r){e.exports=function(t,e,r,n,a){var i=1/Math.tan(e/2),o=1/(n-a);return t[0]=i/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=i,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(a+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*a*n*o,t[15]=0,t}},{}],283:[function(t,e,r){e.exports=function(t,e,r,n){var a,i,o,s,l,c,u,h,f,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,a=Math.sin(r),i=Math.cos(r),o=1-i,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],m=e[9],v=e[10],y=e[11],x=E*E*o+i,b=C*E*o+L*a,_=L*E*o-C*a,w=E*C*o-L*a,T=C*C*o+i,k=L*C*o+E*a,M=E*L*o+C*a,A=C*L*o-E*a,S=L*L*o+i,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+m*_,t[2]=c*x+p*b+v*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*T+g*k,t[5]=l*w+f*T+m*k,t[6]=c*w+p*T+v*k,t[7]=u*w+d*T+y*k,t[8]=s*M+h*A+g*S,t[9]=l*M+f*A+m*S,t[10]=c*M+p*A+v*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],284:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=i*a+c*n,t[5]=o*a+u*n,t[6]=s*a+h*n,t[7]=l*a+f*n,t[8]=c*a-i*n,t[9]=u*a-o*n,t[10]=h*a-s*n,t[11]=f*a-l*n,t}},{}],285:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=i*a-c*n,t[1]=o*a-u*n,t[2]=s*a-h*n,t[3]=l*a-f*n,t[8]=i*n+c*a,t[9]=o*n+u*a,t[10]=s*n+h*a,t[11]=l*n+f*a,t}},{}],286:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=i*a+c*n,t[1]=o*a+u*n,t[2]=s*a+h*n,t[3]=l*a+f*n,t[4]=c*a-i*n,t[5]=u*a-o*n,t[6]=h*a-s*n,t[7]=f*a-l*n,t}},{}],287:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],a=r[1],i=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*a,t[5]=e[5]*a,t[6]=e[6]*a,t[7]=e[7]*a,t[8]=e[8]*i,t[9]=e[9]*i,t[10]=e[10]*i,t[11]=e[11]*i,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],288:[function(t,e,r){e.exports=function(t,e,r){var n,a,i,o,s,l,c,u,h,f,p,d,g=r[0],m=r[1],v=r[2];e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=a,t[2]=i,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*m+h*v+e[12],t[13]=a*g+l*m+f*v+e[13],t[14]=i*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]);return t}},{}],289:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],a=e[3],i=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=i,t[11]=e[14],t[12]=a,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],290:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),a=t(\"polytope-closest-point/lib/closest_point_2d.js\");function i(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var a=0;a<4;++a)r[a]+=t[4*n+a]*e[n];return r}function o(t,e,r,n,a){for(var o=i(n,i(r,i(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*a[0]*(1+o[0]),.5*a[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var a=t[n],i=e[n],o=0;o<3;++o)r[o]+=i*a[o];return r}e.exports=function(t,e,r,i,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),h=0;h<t.length;++h)u[h]=o(t[h],r,i,l,c);var f=0,p=1/0;for(h=0;h<u.length;++h){for(var d=0,g=0;g<2;++g)d+=Math.pow(u[h][g]-e[g],2);d<p&&(p=d,f=h)}var m=function(t,e){if(2===t.length){for(var r=0,i=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),i+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),i=Math.sqrt(i),r+i<1e-6?[1,0]:[i/(r+i),r/(i+r)]}if(3===t.length){var s=[0,0];return a(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),v=0;for(h=0;h<3;++h){if(m[h]<-.001||m[h]>1.0001)return null;v+=m[h]}if(Math.abs(v-1)>.001)return null;return[f,s(t,m),m]}},{barycentric:78,\"polytope-closest-point/lib/closest_point_2d.js\":499}],291:[function(t,e,r){var n=t(\"glslify\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),i=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:413}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),a=t(\"gl-buffer\"),i=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),m=d.meshShader,v=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m,v,y,x,b,_,T,k,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=a,this.pickShader=i,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=m,this.edgeUVs=v,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=T,this.pointSizes=k,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}function S(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}function E(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function L(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function P(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,a=e.vertexWeights,i=r.length,o=p.mallocFloat32(6*i),s=0,l=0;l<i;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],m=a[h],v=1-m,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=m*y[b]+v*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),a=0;a<256;++a){for(var i=r[a],o=0;o<3;++o)n[4*a+o]=i[o];n[4*a+3]=e?255*M(a/255,e):255*i[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var a=[],i=[],l=[],c=[],f=[],p=[],d=[],g=[],m=[],v=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,A)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,I=t.cellUVs,z=t.cellIntensity,O=1/0,D=-1/0;if(!L&&!I)if(P)if(t.vertexIntensityBounds)O=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];O=Math.min(O,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)O=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R){F=z[R];O=Math.min(O,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];O=Math.min(O,F),D=Math.max(D,F)}this.intensity=P||(z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;v.push(j[0],j[1],j[2]),Z=S?S[W]:E?E[R]:C,this.opacityscale&&P?i.push(Z[0],Z[1],Z[2],this.opacity*M((P[W]-O)/(D-O),this.opacityscale)):3===Z.length?y.push(Z[0],Z[1],Z[2],this.opacity):(y.push(Z[0],Z[1],Z[2],Z[3]*this.opacity),Z[3]<1&&(this.hasAlpha=!0)),X=L?L[W]:P?[(P[W]-O)/(D-O),0]:I?I[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],x.push(X[0],X[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),Z=S?S[W]:E?E[R]:C,this.opacityscale&&P?i.push(Z[0],Z[1],Z[2],this.opacity*M((P[W]-O)/(D-O),this.opacityscale)):3===Z.length?d.push(Z[0],Z[1],Z[2],this.opacity):(d.push(Z[0],Z[1],Z[2],Z[3]*this.opacity),Z[3]<1&&(this.hasAlpha=!0)),X=L?L[W]:P?[(P[W]-O)/(D-O),0]:I?I[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],g.push(X[0],X[1]),m.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,Z,X,J;j=n[W=G[2-U]];a.push(j[0],j[1],j[2]),(Z=S?S[W]:E?E[R]:C)?this.opacityscale&&P?i.push(Z[0],Z[1],Z[2],this.opacity*M((P[W]-O)/(D-O),this.opacityscale)):3===Z.length?i.push(Z[0],Z[1],Z[2],this.opacity):(i.push(Z[0],Z[1],Z[2],Z[3]*this.opacity),Z[3]<1&&(this.hasAlpha=!0)):i.push(.5,.5,.5,1),X=L?L[W]:P?[(P[W]-O)/(D-O),0]:I?I[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],c.push(X[0],X[1]),J=w?w[W]:T[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(v),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(m)),this.trianglePositions.update(a),this.triangleColors.update(i),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,a=t.projection||w,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:a,inverseModel:w.slice(),clipBounds:i,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,a=t.projection||w,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(a),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:a,clipBounds:i,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,a=new Array(r.length),i=0;i<r.length;++i)a[i]=n[r[i]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],h=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:h}}var f=g(a,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!f)return null;var p=f[2],d=0;for(i=0;i<r.length;++i)d+=p[i]*this.intensity[r[i]];return{position:f[1],index:r[f[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[f[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\");if(!r)throw new Error(\"derivatives not supported\");var n=A(t),s=S(t),l=E(t),c=C(t),h=L(t),f=P(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=a(t),g=a(t),m=a(t),v=a(t),y=a(t),x=i(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:m,type:t.FLOAT,size:2},{buffer:v,type:t.FLOAT,size:3}]),b=a(t),_=a(t),w=a(t),k=a(t),M=i(t,[{buffer:b,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),I=a(t),z=a(t),O=a(t),D=a(t),R=a(t),F=i(t,[{buffer:I,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:O,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=a(t),N=i(t,[{buffer:B,type:t.FLOAT,size:3}]),j=new T(t,p,n,s,l,c,h,f,d,y,g,m,v,x,b,k,_,w,M,I,R,z,O,D,F,B,N);return j.update(e),j}},{\"./lib/closest-point\":290,\"./lib/shaders\":291,colormap:131,\"gl-buffer\":258,\"gl-mat4/invert\":278,\"gl-mat4/multiply\":280,\"gl-shader\":312,\"gl-texture2d\":327,\"gl-vao\":332,ndarray:469,normals:472,\"simplicial-complex-contour\":528,\"typedarray-pool\":567}],293:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=a(e,i.boxVert,i.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),a=t(\"gl-shader\"),i=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,a){var i=this.plot,o=this.shader,c=i.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=a,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":296,\"gl-buffer\":258,\"gl-shader\":312}],294:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),i=a(e,o.gridVert,o.gridFrag),l=a(e,o.tickVert,o.gridFrag);return new s(t,r,i,l)};var n=t(\"gl-buffer\"),a=t(\"gl-shader\"),i=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,a=t.gl,i=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var m=i[g],v=i[g+2]-m,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*v/x,c[g]=2*(m-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&a.drawArrays(a.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],a=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,m=s.pixelRatio,v=s.screenBox,y=v[2]-v[0],x=v[3]-v[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*k/A,t[w]=2*(T-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,I=Math.min(i.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(i.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),O=0+6*I,D=6*Math.max(0,z-I),R=Math.min(i.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(i.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);a[0]=2*(g[0]-E[1])/y-1,a[1]=(g[3]+g[1])/x-1,o[0]=E[1]*m/y,o[1]=C[1]*m/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=a,f.drawArrays(f.TRIANGLES,B,N)),a[0]=(g[2]+g[0])/y-1,a[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*m/y,o[1]=E[0]*m/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=a,f.drawArrays(f.TRIANGLES,O,D)),a[0]=2*(g[2]+E[3])/y-1,a[1]=(g[3]+g[1])/x-1,o[0]=E[3]*m/y,o[1]=C[3]*m/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=a,f.drawArrays(f.TRIANGLES,B,N)),a[0]=(g[2]+g[0])/y-1,a[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*m/y,o[1]=E[2]*m/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=a,f.drawArrays(f.TRIANGLES,O,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),a=(this.plot.zeroLineEnable,0),i=[[],[]],o=0;o<2;++o)for(var s=i[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[a++]=d,n[a++]=f[g],n[a++]=p[g]}this.ticks=i,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":296,\"binary-search-bounds\":96,\"gl-buffer\":258,\"gl-shader\":312}],295:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=a(e,i.lineVert,i.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),a=t(\"gl-shader\"),i=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,a,i){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=a*o.pixelRatio,c.uniforms.color=i,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":296,\"gl-buffer\":258,\"gl-shader\":312}],296:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),a=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:a,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:a,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:a,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:413}],297:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),i=a(e,s.textVert,s.textFrag);return new l(t,r,i)};var n=t(\"gl-buffer\"),a=t(\"gl-shader\"),i=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],a=this.tickOffset[t],i=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,m=e.tickColor,v=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var A=2/f[2+(1^t)]-f[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*g[t],k<M&&a[M]>a[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t],r.uniforms.angle=v[t],i.drawArrays(i.TRIANGLES,a[k],a[M]-a[k]))),y[t]&&T&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],i.drawArrays(i.TRIANGLES,w,T)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*g[t+2],k<M&&a[M]>a[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t+2],r.uniforms.angle=v[t+2],i.drawArrays(i.TRIANGLES,a[k],a[M]-a[k]))),y[t+2]&&T&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],i.drawArrays(i.TRIANGLES,w,T))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,a=r.gl,i=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-i[u])/(i[2+u]-i[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,a.drawArrays(a.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,a=t.screenBox,i=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=i[o],g=i[o+2]-h,m=a[o],v=a[o+2]-m;p[o]=2*l/u*g/v,f[o]=2*(s-c)/u*g/v}d[1]=2*t.pixelRatio/(a[3]-a[1]),d[0]=d[1]*(a[3]-a[1])/(a[2]-a[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,a,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,m=p.font||\"sans-serif\";a=p.fontSize||12;for(var v=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=i(m,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*a,-n[r+1]*a-b*a*1.2,(d-y)*v);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=i(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,a=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*a,-n[e+1]*a,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=i(t.titleFont,t.title).data,a=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*a,-n[e+1]*a,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":296,\"binary-search-bounds\":96,\"gl-buffer\":258,\"gl-shader\":312,\"text-cache\":547}],298:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=a(c),c.text=i(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),a=t(\"./lib/grid\"),i=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,a=this.pixelRatio,i=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),i.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var m=this.borderLineEnable,v=this.borderLineWidth,y=this.borderLineColor;for(m[1]&&o.drawLine(r[0],r[1]-.5*v[1]*a,r[0],r[3]+.5*v[3]*a,v[1],y[1]),m[0]&&o.drawLine(r[0]-.5*v[0]*a,r[1],r[2]+.5*v[2]*a,r[1],v[0],y[0]),m[3]&&o.drawLine(r[2],r[1]-.5*v[1]*a,r[2],r[3]+.5*v[3]*a,v[3],y[3]),m[2]&&o.drawLine(r[0]-.5*v[0]*a,r[3],r[2]+.5*v[2]*a,r[3],v[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,a=this.viewBox,i=0|Math.round((t-a[0]/r)*n),o=0|Math.round((e-a[1]/r)*n),s=this.pickBuffer.query(i,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(i,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,a=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/a,10,10/a]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var i=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=i[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:i}),this.text.update({bounds:o,ticks:i,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":293,\"./lib/grid\":294,\"./lib/line\":295,\"./lib/text\":297,\"gl-select-static\":311}],299:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=a({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,a=e-2*r;c.idle(e-r),c.recalcMatrix(a),c.flush(e-(100+2*r));for(var i=!0,o=c.computedMatrix,s=0;s<16;++s)i=i&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,i?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),a=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var i=n();c._active.lookAt(i,r,a,e),c._active.lookAt(i+500,r,a,[0,0,1]),c._active.flush(i)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,a,i){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!i.control,p=!!i.alt,g=!!i.shift,m=!!(1&e),v=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(a-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&m&&!f&&!p&&!g||m&&!f&&!p&&g)&&c.rotate(M,w*k*b,-T*k*_,0),(l&&m&&!f&&!p&&!g||v||m&&f&&!p&&!g)&&c.pan(M,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&m&&!f&&!p&&!g||y||m&&!f&&p&&!g)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,h*(Math.exp(A)-1))}return d._lastX=r,d._lastY=a,d._lastMods=i,!0}}d.mouseListener=i(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()}),!!l&&{passive:!1}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,a=d.flipY?1:-1,i=n();if(Math.abs(t)>Math.abs(e))c.rotate(i,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*a*e/window.innerHeight*(i-c.lastT())/20;c.pan(i,0,0,h*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),a=t(\"3d-view\"),i=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":54,\"has-passive-events\":415,\"mouse-change\":457,\"mouse-event-offset\":458,\"mouse-wheel\":460,\"right-now\":514}],300:[function(t,e,r){var n=t(\"glslify\"),a=t(\"gl-shader\"),i=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return a(t,i,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":312,glslify:413}],301:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),a=t(\"gl-axes3d\"),i=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"gl-mat4/perspective\"),f=t(\"gl-mat4/ortho\"),p=t(\"./lib/shader\"),d=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e){if(e=document.createElement(\"canvas\"),t.container)t.container.appendChild(e);else document.body.appendChild(e)}var r=t.gl;r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!r)throw new Error(\"webgl not supported\");var y=t.bounds||[[-10,-10,-10],[10,10,10]],x=new g,b=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),_=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},M=a(r,k);M.enable=!k.disable;var A=t.spikes||{},S=o(r,A),E=[],C=[],L=[],P=[],I=!0,z=!0,O=new Array(16),D=new Array(16),R={view:null,projection:O,model:D,_ortho:!1},F=(z=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),B=t.cameraObject||n(e,T),N={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:B,axes:M,axesPixels:null,spikes:S,bounds:y,objects:E,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,z=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},j=[r.drawingBufferWidth/N.pixelRatio|0,r.drawingBufferHeight/N.pixelRatio|0];function U(){if(!N._stopped&&N.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var a=0|Math.ceil(r*N.pixelRatio),i=0|Math.ceil(n*N.pixelRatio);if(a!==e.width||i!==e.height){e.width=a,e.height=i;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}N.autoResize&&U();function V(){for(var t=E.length,e=P.length,n=0;n<e;++n)L[n]=0;t:for(n=0;n<t;++n){var a=E[n],i=a.pickSlots;if(i){for(var o=0;o<e;++o)if(L[o]+i<255){C[n]=o,a.setPickBase(L[o]+1),L[o]+=i;continue t}var l=s(r,F);C[n]=e,P.push(l),L.push(i),a.setPickBase(1),e+=1}else C[n]=-1}for(;e>0&&0===L[e-1];)L.pop(),P.pop().dispose()}function q(){if(N.contextLost)return!0;r.isContextLost()&&(N.contextLost=!0,N.mouseListener.enabled=!1,N.selection.object=null,N.oncontextloss&&N.oncontextloss())}window.addEventListener(\"resize\",U),N.update=function(t){N._stopped||(t=t||{},I=!0,z=!0)},N.add=function(t){N._stopped||(t.axes=M,E.push(t),C.push(-1),I=!0,z=!0,V())},N.remove=function(t){if(!N._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),C.pop(),I=!0,z=!0,V())}},N.dispose=function(){if(!N._stopped&&(N._stopped=!0,window.removeEventListener(\"resize\",U),e.removeEventListener(\"webglcontextlost\",q),N.mouseListener.enabled=!1,!N.contextLost)){M.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();b.dispose();for(t=0;t<P.length;++t)P[t].dispose();_.dispose(),r=null,M=null,S=null,E=[]}},N._mouseRotating=!1,N._prevButtons=0,N.enableMouseListeners=function(){N.mouseListener=u(e,(function(t,e,r){if(!N._stopped){var n=P.length,a=E.length,i=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&N._prevButtons)N._mouseRotating=!0;else{N._mouseRotating&&(z=!0),N._mouseRotating=!1;for(var s=0;s<n;++s){var l=P[s].query(e,j[1]-r-1,N.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<a;++c){var u=E[c];if(C[c]===s){var h=u.pick(l);h&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=h.distance,x.dataPosition=h.position,x.dataCoordinate=h.dataCoordinate,x.data=h,o=!0)}}}}}i&&i!==x.object&&(i.highlight&&i.highlight(null),I=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),I=!0),(o=o||x.object!==i)&&N.onselect&&N.onselect(x),1&t&&!(1&N._prevButtons)&&N.onclick&&N.onclick(x),N._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",q);var H=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],G=[H[0].slice(),H[1].slice()];function Y(){if(!q()){U();var t=N.camera.tick();R.view=N.camera.matrix,I=I||t,z=z||t,M.pixelRatio=N.pixelRatio,S.pixelRatio=N.pixelRatio;var e=E.length,n=H[0],a=H[1];n[0]=n[1]=n[2]=1/0,a[0]=a[1]=a[2]=-1/0;for(var o=0;o<e;++o){(L=E[o]).pixelRatio=N.pixelRatio,L.axes=N.axes,I=I||!!L.dirty,z=z||!!L.dirty;var s=L.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),a[p]=Math.max(a[p],u[p])}var d=N.bounds;if(N.autoBounds)for(p=0;p<3;++p){if(a[p]<n[p])n[p]=-1,a[p]=1;else{n[p]===a[p]&&(n[p]-=1,a[p]+=1);var g=.05*(a[p]-n[p]);n[p]=n[p]-g,a[p]=a[p]+g}d[0][p]=n[p],d[1][p]=a[p]}var v=!1;for(p=0;p<3;++p)v=v||G[0][p]!==d[0][p]||G[1][p]!==d[1][p],G[0][p]=d[0][p],G[1][p]=d[1][p];if(z=z||v,I=I||v){if(v){var y=[0,0,0];for(o=0;o<3;++o)y[o]=m((d[1][o]-d[0][o])/10);M.autoTicks?M.update({bounds:d,tickSpacing:y}):M.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;F[0]=T,F[1]=k,j[0]=0|Math.max(T/N.pixelRatio,1),j[1]=0|Math.max(k/N.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,a=n.projection,i=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(f(a,-p,p,-1,1,l,c),n._ortho=!0):(h(a,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)i[d]=0;i[15]=1;var g=0;for(d=0;d<3;++d)g=Math.max(g,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?i[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):i[5*d]=1/g,t.autoCenter&&(i[12+d]=.5*-i[5*d]*(r[0][d]+r[1][d]))}(N,w);for(o=0;o<e;++o){(L=E[o]).axesBounds=d,N.clipToBounds&&(L.clipBounds=d)}x.object&&(N.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),z&&(z=!1,function(){if(!q()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=P.length,n=0;n<e;++n){var a=P[n];a.shape=j,a.begin();for(var i=0;i<t;++i)if(C[i]===n){var o=E[i];o.drawPick&&(o.pixelRatio=1,o.drawPick(R))}a.end()}}}()),N.axesPixels=i(N.axes,R,T,k),N.onrender&&N.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),N.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var A=!1;M.enable&&(A=A||M.isTransparent(),M.draw(R)),S.axes=M,x.object&&S.draw(R),r.disable(r.CULL_FACE);for(o=0;o<e;++o){(L=E[o]).axes=M,L.pixelRatio=N.pixelRatio,L.isOpaque&&L.isOpaque()&&L.draw(R),L.isTransparent&&L.isTransparent()&&(A=!0)}if(A){b.shape=F,b.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){(L=E[o]).isOpaque&&L.isOpaque()&&L.draw(R)}r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){var L;(L=E[o]).isTransparent&&L.isTransparent()&&L.drawTransparent(R)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),_.bind(),b.color[0].bind(0),_.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}I=!1;for(o=0;o<e;++o)E[o].dirty=!1}}}return N.enableMouseListeners(),function t(){if(N._stopped||N.contextLost)return;Y(),requestAnimationFrame(t)}(),N.redraw=function(){N._stopped||(I=!0,Y())},N},createCamera:n}},{\"./camera.js\":299,\"./lib/shader\":300,\"a-big-triangle\":64,\"gl-axes3d\":250,\"gl-axes3d/properties\":257,\"gl-fbo\":266,\"gl-mat4/ortho\":281,\"gl-mat4/perspective\":282,\"gl-select-static\":311,\"gl-spikes3d\":321,\"is-mobile\":441,\"mouse-change\":457}],302:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:413}],303:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),a=t(\"gl-buffer\"),i=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,a){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=a,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,i=a(r),l=a(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,i,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,a=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=a?s:i.mallocFloat32(s.length),c=o?t.idToIndex:i.mallocInt32(n);if(a||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),a||i.free(l),o||i.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,a=this.plot.dataBox;if(0===this.pointCount)return t;var i=a[2]-a[0],o=a[3]-a[1],s=function(t,e){var r,n=0,a=t.length>>>1;for(r=0;r<a;r++){var i=t[2*r],o=t[2*r+1];i>=e[0]&&i<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,a),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/i,l[4]=2/o,l[6]=-2*a[0]/i-1,l[7]=-2*a[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,a=this.pointCount;if(r<n||r>=n+a)return null;var i=r-n,o=this.points;return{object:this,pointId:i,dataCoord:[o[2*i],o[2*i+1]]}}},{\"./lib/shader\":302,\"gl-buffer\":258,\"gl-shader\":312,\"typedarray-pool\":567}],304:[function(t,e,r){e.exports=function(t,e,r,n){var a,i,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],m=r[3];(i=c*p+u*d+h*g+f*m)<0&&(i=-i,p=-p,d=-d,g=-g,m=-m);1-i>1e-6?(a=Math.acos(i),o=Math.sin(a),s=Math.sin((1-n)*a)/o,l=Math.sin(n*a)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*m,t}},{}],305:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],306:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var i=a[e];i||(i=a[e]={});if(t in i)return i[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return i[t]=[s,u,h]};var a={}},{\"vectorize-text\":572}],307:[function(t,e,r){var n=t(\"gl-shader\"),a=t(\"glslify\"),i=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:i,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:i,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},m={vertex:s,fragment:c,attributes:u};function v(t,e){var r=n(t,e),a=r.attributes;return a.position.location=0,a.color.location=1,a.glyph.location=2,a.id.location=3,r}r.createPerspective=function(t){return v(t,h)},r.createOrtho=function(t){return v(t,f)},r.createProject=function(t){return v(t,p)},r.createPickPerspective=function(t){return v(t,d)},r.createPickOrtho=function(t){return v(t,g)},r.createPickProject=function(t){return v(t,m)}},{\"gl-shader\":312,glslify:413}],308:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),a=t(\"gl-buffer\"),i=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],a=t[2],i=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*a+e[12]*i,t[1]=e[1]*r+e[5]*n+e[9]*a+e[13]*i,t[2]=e[2]*r+e[6]*n+e[10]*a+e[14]*i,t[3]=e[3]*r+e[7]*n+e[11]*a+e[15]*i,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t||t>1?1:t}function m(t,e,r,n,a,i,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=a,this.colorBuffer=i,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=a(e),f=a(e),p=a(e),d=a(e),g=i(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new m(e,r,n,o,h,f,p,d,g,s,c,u);return v.update(t),v};var v=m.prototype;v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},v.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],T=h.slice(),k=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var a,i=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);a=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var m=0;m<3;++m)if(i[m]){l.scale=e.projectScale[m],l.opacity=e.projectOpacity[m];for(var v=T,C=0;C<16;++C)v[C]=0;for(C=0;C<4;++C)v[5*C]=1;v[5*m]=0,a[m]<0?v[12+m]=d[0][m]:v[12+m]=d[1][m],s(v,c,v),l.model=v;var L=(m+1)%3,P=(m+2)%3,I=A(x),z=A(b);I[L]=1,z[P]=1;var O=p(0,0,0,S(_,I)),D=p(0,0,0,S(w,z));if(Math.abs(O[1])>Math.abs(D[1])){var R=O;O=D,D=R,R=I,I=z,z=R;var F=L;L=P,P=F}O[0]<0&&(I[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);I[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=I,l.axes[1]=z,l.fragClipBounds[0]=E(k,g[0],m,-1e8),l.fragClipBounds[1]=E(k,g[1],m,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,a,i,o){var s=r.gl;if((i===r.projectHasAlpha||o)&&C(e,r,n,a),i===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=a,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*a),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function I(t,e,r,a){var i;i=Array.isArray(t)?e<t.length?t[e]:void 0:t,i=u(i);var o=!0;n(i)&&(i=\"\\u25bc\",o=!1);var s=c(i,r,a);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}v.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},v.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},v.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var a=0;a<3;++a)n.position[a]=n.dataCoordinate[a]=r[a];return n},v.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,a=e>>16&255;this.highlightId=[r/255,n/255,a/255,0]}else this.highlightId=[1,1,1,1]},v.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var a,i,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)a=c[0],i=c[1];else{a=[],i=[];for(n=0;n<c.length;++n)a[n]=c[n][0],i[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,m=t.angle,v=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],T=0;T<3;++T)if(isNaN(w[T])||!isFinite(w[T]))continue t;var k=(N=I(f,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*k.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,O=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(v)&&Array.isArray(v[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],T=0;T<3;++T){if(isNaN(w[T])||!isFinite(w[T]))continue t;h[T]=Math.max(h[T],w[T]),u[T]=Math.min(u[T],w[T])}k=(N=I(f,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(T=0;T<3;++T)D[T]=U[T];D[3]=1}else if(4===U.length){for(T=0;T<4;++T)D[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(v)){var U;if(3===(U=B?n<v.length?v[n]:[0,0,0,0]:v).length){for(T=0;T<3;++T)R[T]=U[T];R[T]=1}else if(4===U.length){for(T=0;T<4;++T)R[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(m)?q=n<m.length?+m[n]:0:m&&(q=+m);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],T=0;T<3;++T)h[T]=Math.max(h[T],w[T]),u[T]=Math.min(u[T],w[T]);var Y=a,W=i;Y=0;Array.isArray(a)?Y=n<a.length?a[n]:0:a&&(Y=a);W=0;Array.isArray(i)?W=n<i.length?i[n]:0:i&&(W=i);var Z=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],X=k.cells||[],J=k.positions||[];for(T=0;T<X.length;++T)for(var K=X[T],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)C[4*z+$]=D[$];P[z]=y;var tt=J[K[Q]];L[2*z]=V*(H*tt[0]-G*tt[1]+Z[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+Z[1]),z+=1}for(X=M.edges,J=M.positions,T=0;T<X.length;++T)for(K=X[T],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*O+$]=w[$];for($=0;$<4;++$)C[4*O+$]=R[$];P[O]=y;tt=J[K[Q]];L[2*O]=V*(H*tt[0]-G*tt[1]+Z[0]),L[2*O+1]=V*(G*tt[0]+H*tt[1]+Z[1]),O+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},v.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":305,\"./lib/glyphs\":306,\"./lib/shaders\":307,\"gl-buffer\":258,\"gl-mat4/multiply\":280,\"gl-vao\":332,\"is-string-blank\":444,\"typedarray-pool\":567}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:413}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),a=t(\"gl-buffer\"),i=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=a(r,[0,0,0,1,1,0,1,1]),l=n(r,i.boxVertex,i.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),a=(this.outerFill,this.outerColor),i=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],m=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,a),o.drawBox(0,f,h,d,a),o.drawBox(0,d,g,m,a),o.drawBox(p,f,g,d,a)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var v=r*u;o.drawBox(h-v,f-v,p+v,f+v,i),o.drawBox(h-v,d-v,p+v,d+v,i),o.drawBox(h-v,f-v,h+v,d+v,i),o.drawBox(p-v,f-v,p+v,d+v,i)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":309,\"gl-buffer\":258,\"gl-shader\":312}],311:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=e[0],i=e[1],o=n(t,r,i,{}),s=a.mallocUint8(r*i*4);return new l(t,o,s)};var n=t(\"gl-fbo\"),a=t(\"typedarray-pool\"),i=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2;function s(t,e,r,n,a){this.coord=[t,e],this.id=r,this.value=n,this.distance=a}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){a.free(this.buffer);for(var n=this.buffer=a.mallocUint8(o(r*e*4)),i=0;i<r*e*4;++i)n[i]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var a=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=a||c<=l)return null;var u=[o-a,c-l],h=i(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(a+n[0]*l)),f=function(t,e,r){for(var n=1e8,a=-1,i=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),h=t.get(l,c,1),f=t.get(l,c,2),p=t.get(l,c,3);if(u<255||h<255||f<255||p<255){var d=e-l,g=r-c,m=d*d+g*g;m<n&&(n=m,a=l,i=c)}}return[a,i,n]}(h.hi(u[0],u[1],1),r,r),p=f[0],d=f[1];return p<0||Math.pow(this.radius,2)<f[2]?null:new s(p+a|0,d+l|0,h.get(p,d,0),[h.get(p,d,1),h.get(p,d,2),h.get(p,d,3)],Math.sqrt(f[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),a.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":97,\"gl-fbo\":266,ndarray:469,\"typedarray-pool\":567}],312:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),a=t(\"./lib/create-attributes\"),i=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var m=p.createProgram();if(p.attachShader(m,f.fragShader),p.attachShader(m,f.vertShader),p.linkProgram(m),!p.getProgramParameter(m,p.LINK_STATUS)){var v=p.getProgramInfoLog(m);throw new l(v,\"Error linking program:\"+v)}r=r||s.uniforms(p,m),c=c||s.attributes(p,m),p.deleteProgram(m)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),M=0;M<T;++M)k[M]=_.length,b.push(w.name+\"[\"+M+\"]\"),\"number\"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:i(r),attributes:i(c)},f.attributes=a(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,a){var i=new c(t);return i.update(e,r,n,a),i}},{\"./lib/GLError\":313,\"./lib/create-attributes\":314,\"./lib/create-uniforms\":315,\"./lib/reflect\":316,\"./lib/runtime-reflect\":317,\"./lib/shader-cache\":318}],313:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],314:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){for(var i={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],a,1,i,h);break;default:if(f.indexOf(\"vec\")>=0){if((d=f.charCodeAt(f.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],a,d,i,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d;if((d=f.charCodeAt(f.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,a,d,i,h)}}}return i};var n=t(\"./GLError\");function a(t,e,r,n,a,i){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=a,this._constFunc=i}var i=a.prototype;function o(t,e,r,n,i,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<i;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+i+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+i+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new a(t,e,r,n,i,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,a,i,s){for(var l=new Array(a),c=new Array(a),u=0;u<a;++u)o(t,e,r[u],n,a,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<a;++e)c[e].location=t[e];else for(e=0;e<a;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(a),e=0;e<a;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,i,o,s){e=e||t.FLOAT,i=!!i,o=o||a*a,s=s||0;for(var l=0;l<a;++l){var c=n[r[l]];t.vertexAttribPointer(c,a,e,i,o,s+l*a),t.enableVertexAttribArray(c)}};var h=new Array(a),f=t[\"vertexAttrib\"+a+\"fv\"];Object.defineProperty(i,s,{set:function(e){for(var i=0;i<a;++i){var o=n[r[i]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[i]);else{for(var s=0;s<a;++s)h[s]=e[a*i+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}i.pointer=function(t,e,r,n){var a=this._gl,i=this._locations[this._index];a.vertexAttribPointer(i,this._dimension,t||a.FLOAT,!!e,r||0,n||0),a.enableVertexAttribArray(i)},i.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(i,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":313}],315:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),a=t(\"./GLError\");function i(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var i;if((i=r.charCodeAt(r.length-1)-48)<2||i>4)throw new a(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+i+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new a(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}if((i=r.charCodeAt(r.length-1)-48)<2||i>4)throw new a(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+i+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+i+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new a(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],a=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var a in r){var i=r[a],o=e;parseInt(a)+\"\"===a?o+=\"[\"+a+\"]\":o+=\".\"+a,\"object\"==typeof i?n.push.apply(n,t(o,i)):n.push([o,i])}return n}(\"\",e),i=0;i<a.length;++i){var o=a[i],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}return n.push(\"return obj}\"),new Function(\"gl\",\"locations\",n.join(\"\\n\"))(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:i(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new a(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new a(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new a(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:i(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":313,\"./reflect\":316}],316:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var a=t[n].name.split(\".\"),i=r,o=0;o<a.length;++o){var s=a[o].split(\"[\");if(s.length>1){s[0]in i||(i[s[0]]=[]),i=i[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<a.length-1?(c in i||(l<s.length-1?i[c]=[]:i[c]={}),i=i[c]):i[c]=e?n:t[n].type}}else o<a.length-1?(s[0]in i||(i[s[0]]={}),i=i[s[0]]):i[s[0]]=e?n:t[n].type}return r}},{}],317:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],a=0;a<r;++a){var o=t.getActiveUniform(e,a);if(o){var s=i(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],a=0;a<r;++a){var o=t.getActiveAttrib(e,a);o&&n.push({name:o.name,type:i(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},a=null;function i(t,e){if(!a){var r=Object.keys(n);a={};for(var i=0;i<r.length;++i){var o=r[i];a[t[o]]=n[o]}}return a[e]}},{}],318:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,a){return u(t).getProgram(e,r,n,a)};var n=t(\"./GLError\"),a=t(\"gl-format-compiler-error\"),i=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,a,i,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=i,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,a=r.length;n<a;++n){var i=t.programs[r[n]];i&&(delete t.programs[n],e.deleteProgram(i))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=i.get(t);return e||(e=new l(t),i.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,i=this.shaders[t===r.FRAGMENT_SHADER|0],l=i[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var i=t.createShader(e);if(t.shaderSource(i,r),t.compileShader(i),!t.getShaderParameter(i,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(i);try{var s=a(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return i}(r,t,e);l=i[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,a){var i=[t.id,e.id,r.join(\":\"),a.join(\":\")].join(\"@\"),o=this.programs[i];return o&&this.gl.isProgram(o)||(this.programs[i]=o=function(t,e,r,a,i){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<a.length;++s)t.bindAttribLocation(o,i[s],a[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,a),t.programs.push(i),e.programs.push(i)),o}},{\"./GLError\":313,\"gl-format-compiler-error\":267,\"weakmap-shim\":577}],319:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var a=n.prototype;a.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},a.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,a=this.plot,i=a.line,o=a.dataBox,s=a.viewBox;if(i.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&i.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&i.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&i.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&i.drawLine(l,c,l,s[3],e[3],r[3])}},a.dispose=function(){this.plot.removeOverlay(this)}},{}],320:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),a=t(\"gl-shader\"),i=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return a(t,i,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":312,glslify:413}],321:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),a=t(\"gl-vao\"),i=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,a,i,o){var s=[t,e,n,0,0,0,1];s[a+3]=1,s[a]=i,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[a]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[a]=i,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=a(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=i(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var a,i=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(a=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)a&&a[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=i,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":320,\"gl-buffer\":258,\"gl-vao\":332}],322:[function(t,e,r){var n=t(\"glslify\"),a=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),i=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:413}],323:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),a=t(\"gl-vec4\"),i=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e,r,i){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,i){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],h=[],f=[],p=[],d=[],g=0,m=0,v=a.create(),y=a.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),m=n.length(_)/i,v=a.create(),n.copy(v,_),v[3]=w;for(var T=0;T<8;T++)p[T]=[b[0],b[1],b[2],T];if(f.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(f[T],p[T],p[k],p[k],f[k],f[T]),h.push(y,v,v,v,y,y),d.push(g,m,m,m,g,g);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=f;f=p,p=A;var S=y;y=v,v=S;var E=g;g=m,m=E}return{positions:c,cells:u,vectors:h,vertexIntensity:d}}(t,r,i,o)})),h=[],f=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],m=h.length;h=h.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var v=g.cells[c],y=[];f.push(y);for(var x=0;x<v.length;x++)y.push(v[x]+m)}}return{positions:h,cells:f,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var a=t[r];if(a===e)return r;if(a>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var a=Math.abs(t[n]-t[n-1]);a<e&&(e=a)}return e};e.exports=function(t,e){var r=t.startingPositions,a=t.maxLength||1e3,u=t.tubeSize||1,h=t.absoluteTubeSize,f=t.gridFill||\"+x+y+z\",p={};-1!==f.indexOf(\"-x\")&&(p.reversedX=!0),-1!==f.indexOf(\"-y\")&&(p.reversedY=!0),-1!==f.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=i.indexOf(f.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var a=e.vectors,i=e.meshgrid,o=t[0],c=t[1],u=t[2],h=i[0].length,f=i[1].length,p=i[2].length,d=s(i[0],o),g=s(i[1],c),m=s(i[2],u),v=d+1,y=g+1,x=m+1;if(d=l(d,0,h-1),v=l(v,0,h-1),g=l(g,0,f-1),y=l(y,0,f-1),m=l(m,0,p-1),x=l(x,0,p-1),d<0||g<0||m<0||v>h-1||y>f-1||x>p-1)return n.create();var b,_,w,T,k,M,A=i[0][d],S=i[0][v],E=i[1][g],C=i[1][y],L=i[2][m],P=(o-A)/(S-A),I=(c-E)/(C-E),z=(u-L)/(i[2][x]-L);switch(isFinite(P)||(P=.5),isFinite(I)||(I=.5),isFinite(z)||(z=.5),r.reversedX&&(d=h-1-d,v=h-1-v),r.reversedY&&(g=f-1-g,y=f-1-y),r.reversedZ&&(m=p-1-m,x=p-1-x),r.filled){case 5:k=m,M=x,w=g*p,T=y*p,b=d*p*f,_=v*p*f;break;case 4:k=m,M=x,b=d*p,_=v*p,w=g*p*h,T=y*p*h;break;case 3:w=g,T=y,k=m*f,M=x*f,b=d*f*p,_=v*f*p;break;case 2:w=g,T=y,b=d*f,_=v*f,k=m*f*h,M=x*f*h;break;case 1:b=d,_=v,k=m*h,M=x*h,w=g*h*p,T=y*h*p;break;default:b=d,_=v,w=g*h,T=y*h,k=m*h*f,M=x*h*f}var O=a[b+w+k],D=a[b+w+M],R=a[b+T+k],F=a[b+T+M],B=a[_+w+k],N=a[_+w+M],j=a[_+T+k],U=a[_+T+M],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,O,B,P),n.lerp(q,D,N,P),n.lerp(H,R,j,P),n.lerp(G,F,U,P);var Y=n.create(),W=n.create();n.lerp(Y,V,H,I),n.lerp(W,q,G,I);var Z=n.create();return n.lerp(Z,Y,W,z),Z}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),a=1e-4;n.add(r,t,[a,0,0]);var i=d(r);n.subtract(i,i,e),n.scale(i,i,1/a),n.add(r,t,[0,a,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/a),n.add(r,t,[0,0,a]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/a),n.add(r,i,o),n.add(r,r,s),r},m=[],v=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<v||e>b||r<y||r>_||n<x||n>w)},k=10*n.distance(e[0],e[1])/a,M=k*k,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],a={},i={},o={},s=t.length,l=0;l<s;l++){var u=t[l],h=u[0],f=u[1],p=u[2];a[h]||(e.push(h),a[h]=!0),i[f]||(r.push(f),i[f]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),m=c(n),v=Math.min(d,g,m);return isFinite(v)?v:1}(r));for(var C=0;C<E;C++){var L=n.create();n.copy(L,r[C]);var P=[L],I=[],z=d(L),O=L;I.push(z);var D=[],R=g(L,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),m.push({points:P,velocities:I,divergences:D});for(var B=0;B<100*a&&P.length<a&&T(L);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,L),z=d(N),n.squaredDistance(O,N)-M>-1e-4*M){P.push(N),O=N,I.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}L=N}}var U=o(m,t.colormap,S,A);return h?U.tubeScale=h:(0===S&&(S=1),U.tubeScale=.5*u*A/S),U};var u=t(\"./lib/shaders\"),h=t(\"gl-cone3d\").createMesh;e.exports.createTubeMesh=function(t,e){return h(t,e,{shaders:u,traceType:\"streamtube\"})}},{\"./lib/shaders\":322,\"gl-cone3d\":259,\"gl-vec3\":351,\"gl-vec4\":387}],324:[function(t,e,r){var n=t(\"gl-shader\"),a=t(\"glslify\"),i=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=a([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,i,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,i,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":312,glslify:413}],325:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=a(e),u=i(e,[{buffer:c,size:4,stride:40,offset:0},{buffer:c,size:3,stride:40,offset:16},{buffer:c,size:3,stride:40,offset:28}]),h=a(e),f=i(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=a(e),d=i(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,256,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var m=new A(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),v={levels:[[],[],[]]};for(var w in t)v[w]=t[w];return v.colormap=v.colormap||\"jet\",m.update(v),m};var n=t(\"bit-twiddle\"),a=t(\"gl-buffer\"),i=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),m=t(\"ndarray-gradient\"),v=t(\"./lib/shaders\"),y=v.createShader,x=v.createContourShader,b=v.createPickShader,_=v.createPickContourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],k=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,a){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=a}!function(){for(var t=0;t<3;++t){var e=k[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();function A(t,e,r,n,a,i,o,l,c,u,f,p,d,g,m){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=m,this.intensityBounds=[],this._shader=n,this._pickShader=a,this._coordinateBuffer=i,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var S=A.prototype;S.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:256,format:\"rgba\"}).map((function(t,n){var a=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return a<1&&(r=!0),[t[0],t[1],t[2],255*a]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},S.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},S.isOpaque=function(){return!this.isTransparent()},S.pickSlots=1,S.setPickBase=function(t){this.pickId=t};var E=[0,0,0],C={showSurface:!1,showContour:!1,projections:[w.slice(),w.slice(),w.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function L(t,e){var r,n,a,i=e.axes&&e.axes.lastCubeProps.axis||E,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=C.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(i[r]>0)][r],p(l,t.model,l);var c=C.clipBounds[r];for(a=0;a<2;++a)for(n=0;n<3;++n)c[a][n]=t.clipBounds[a][n];c[0][r]=-1e8,c[1][r]=1e8}return C.showSurface=o,C.showContour=s,C}var P={model:w,view:w,projection:w,inverseModel:w.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=w.slice(),z=[1,0,0,0,1,0,0,0,1];function O(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=P;n.model=t.model||w,n.view=t.view||w,n.projection=t.projection||w,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var a=0;a<2;++a)for(var i=n.clipBounds[a],o=0;o<3;++o)i[o]=Math.min(Math.max(this.clipBounds[a][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=z,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),a=0;a<3;++a)n.eyePosition[a]=s[12+a]/s[15];var l=s[15];for(a=0;a<3;++a)l+=this.lightPosition[a]*s[4*a+3];for(a=0;a<3;++a){var c=s[12+a];for(o=0;o<3;++o)c+=s[4*o+a]*this.lightPosition[o];n.lightPosition[a]=c/l}var u=L(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),a=0;a<3;++a)this.surfaceProject[a]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[a],this._shader.uniforms.clipBounds=u.clipBounds[a],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),a=0;a<3;++a)for(h.uniforms.permutation=k[a],r.lineWidth(this.contourWidth[a]*this.pixelRatio),o=0;o<this.contourLevels[a].length;++o)o===this.highlightLevel[a]?(h.uniforms.contourColor=this.highlightColor[a],h.uniforms.contourTint=this.highlightTint[a]):0!==o&&o-1!==this.highlightLevel[a]||(h.uniforms.contourColor=this.contourColor[a],h.uniforms.contourTint=this.contourTint[a]),this._contourCounts[a][o]&&(h.uniforms.height=this.contourLevels[a][o],f.draw(r.LINES,this._contourCounts[a][o],this._contourOffsets[a][o]));for(a=0;a<3;++a)for(h.uniforms.model=u.projections[a],h.uniforms.clipBounds=u.clipBounds[a],o=0;o<3;++o)if(this.contourProject[a][o]){h.uniforms.permutation=k[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),a=0;a<3;++a)if(0!==this._dynamicCounts[a])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=k[a],r.lineWidth(this.dynamicWidth[a]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[a],h.uniforms.contourTint=this.dynamicTint[a],h.uniforms.height=this.dynamicLevel[a],f.draw(r.LINES,this._dynamicCounts[a],this._dynamicOffsets[a]),o=0;o<3;++o)this.contourProject[o][a]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[a],this._dynamicOffsets[a]));f.unbind()}}S.draw=function(t){return O.call(this,t,!1)},S.drawTransparent=function(t){return O.call(this,t,!0)};var D={model:w,view:w,projection:w,inverseModel:w,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function R(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function F(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function B(t){if(Array.isArray(t)){if(Array.isArray(t))return[F(t[0]),F(t[1]),F(t[2])];var e=F(t);return[e.slice(),e.slice(),e.slice()]}}S.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=D;r.model=t.model||w,r.view=t.view||w,r.projection=t.projection||w,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=z;for(var n=0;n<2;++n)for(var a=r.clipBounds[n],i=0;i<3;++i)a[i]=Math.min(Math.max(this.clipBounds[n][i],-1e8),1e8);var o=L(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),i=0;i<3;++i)for(e.lineWidth(this.contourWidth[i]*this.pixelRatio),s.uniforms.permutation=k[i],n=0;n<this.contourLevels[i].length;++n)this._contourCounts[i][n]&&(s.uniforms.height=this.contourLevels[i][n],l.draw(e.LINES,this._contourCounts[i][n],this._contourOffsets[i][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],i=0;i<3;++i)if(this.contourProject[n][i]){s.uniforms.permutation=k[i],e.lineWidth(this.contourWidth[i]*this.pixelRatio);for(var c=0;c<this.contourLevels[i].length;++c)this._contourCounts[i][c]&&(s.uniforms.height=this.contourLevels[i][c],l.draw(e.LINES,this._contourCounts[i][c],this._contourOffsets[i][c]))}l.unbind()}},S.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,a=Math.floor(n),i=n-a,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;a+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?i:1-i,f=0;f<2;++f)for(var p=a+u,d=s+f,m=h*(f?l:1-l),v=0;v<3;++v)c[v]+=this._field[v].get(p,d)*m;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=i<.5?a:a+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],v=0;v<3;++v)r.dataCoordinate[v]=this._field[v].get(r.index[0],r.index[1]);return r},S.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},S.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=R(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=R(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=R(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=B(t.contourColor)),\"contourProject\"in t&&(this.contourProject=R(t.contourProject,(function(t){return R(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=B(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=R(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=R(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var a=(e.shape[0]+2)*(e.shape[1]+2);a>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(a))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var i=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[i[0]+2,i[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(v=0;v<2;++v)if(c.shape[v]!==i[v])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=h(p)),p.shape[0]!==i[o])throw new Error(\"gl-surface: invalid tick length\");var d=h(p.data,i);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var g=[0,0];g[o]=1,this._field[o]=h(this._field[o].data,[i[0]+2,i[1]+2],g,0)}this._field[0].set(0,0,0);for(var v=0;v<i[0];++v)this._field[0].set(v+1,0,v);for(this._field[0].set(i[0]+1,0,i[0]-1),this._field[1].set(0,0,0),v=0;v<i[1];++v)this._field[1].set(0,v+1,v);this._field[1].set(0,i[1]+1,i[1]-1)}var y=this._field,x=h(s.mallocFloat(3*y[2].size*2),[3,i[0]+2,i[1]+2,2]);for(o=0;o<3;++o)m(x.pick(o),y[o],\"mirror\");var b=h(s.mallocFloat(3*y[2].size),[i[0]+2,i[1]+2,3]);for(o=0;o<i[0]+2;++o)for(v=0;v<i[1]+2;++v){var _=x.get(0,o,v,0),w=x.get(0,o,v,1),k=x.get(1,o,v,0),M=x.get(1,o,v,1),A=x.get(2,o,v,0),S=x.get(2,o,v,1),E=k*S-M*A,C=A*w-S*_,L=_*M-w*k,P=Math.sqrt(E*E+C*C+L*L);P<1e-8?(P=Math.max(Math.abs(E),Math.abs(C),Math.abs(L)))<1e-8?(L=1,C=E=0,P=1):P=1/P:P=1/Math.sqrt(P),b.set(o,v,0,E*P),b.set(o,v,1,C*P),b.set(o,v,2,L*P)}s.free(x.data);var I=[1/0,1/0,1/0],z=[-1/0,-1/0,-1/0],O=1/0,D=-1/0,F=(i[0]-1)*(i[1]-1)*6,N=s.mallocFloat(n.nextPow2(10*F)),j=0,U=0;for(o=0;o<i[0]-1;++o)t:for(v=0;v<i[1]-1;++v){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+v+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Y=o+T[H][0],W=v+T[H][1],Z=this._field[0].get(Y+1,W+1),X=this._field[1].get(Y+1,W+1);G=this._field[2].get(Y+1,W+1),E=b.get(Y+1,W+1,0),C=b.get(Y+1,W+1,1),L=b.get(Y+1,W+1,2),t.intensity&&(J=t.intensity.get(Y,W));var J=t.intensity?t.intensity.get(Y,W):G+this.objectOffset[2];N[j++]=Y,N[j++]=W,N[j++]=Z,N[j++]=X,N[j++]=G,N[j++]=0,N[j++]=J,N[j++]=E,N[j++]=C,N[j++]=L,I[0]=Math.min(I[0],Z+this.objectOffset[0]),I[1]=Math.min(I[1],X+this.objectOffset[1]),I[2]=Math.min(I[2],G+this.objectOffset[2]),O=Math.min(O,J),z[0]=Math.max(z[0],Z+this.objectOffset[0]),z[1]=Math.max(z[1],X+this.objectOffset[1]),z[2]=Math.max(z[2],G+this.objectOffset[2]),D=Math.max(D,J),U+=1}}for(t.intensityBounds&&(O=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<j;o+=10)N[o]=(N[o]-O)/(D-O);this._vertexCount=U,this._coordinateBuffer.update(N.subarray(0,j)),s.freeFloat(N),s.free(b.data),this.bounds=[I,z],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===O&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[O,D]}if(\"levels\"in t){var K=t.levels;for(K=Array.isArray(K[0])?K.slice():[[],[],K],o=0;o<3;++o)K[o]=K[o].slice(),K[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(v=0;v<K[o].length;++v)K[o][v]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(K[o].length!==this.contourLevels[o].length){r=!0;break}for(v=0;v<K[o].length;++v)if(K[o][v]!==this.contourLevels[o][v]){r=!0;break t}}this.contourLevels=K}if(r){y=this._field,i=this.shape;for(var Q=[],$=0;$<3;++$){var tt=this.contourLevels[$],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var at=f(this._field[$],tt[o]);et.push(Q.length/5|0),U=0;t:for(v=0;v<at.cells.length;++v){var it=at.cells[v];for(H=0;H<2;++H){var ot=at.positions[it[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ht=0|Math.floor(ut),ft=ut-ht,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var gt=($+dt+1)%3;for(V=0;V<2;++V){var mt=V?ct:1-ct;for(Y=0|Math.min(Math.max(lt+V,0),i[0]),q=0;q<2;++q){var vt=q?ft:1-ft;if(W=0|Math.min(Math.max(ht+q,0),i[1]),G=dt<2?this._field[gt].get(Y,W):(this.intensity.get(Y,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var yt=mt*vt;nt[dt]+=yt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)Q.pop();U-=1}continue t}Q.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[$]=et,this._contourCounts[$]=rt}var bt=s.mallocFloat(Q.length);for(o=0;o<Q.length;++o)bt[o]=Q[o];this._contourBuffer.update(bt),s.freeFloat(bt)}},S.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},S.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,a=this.shape,i=s.mallocFloat(12*a[0]*a[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,m=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var v=g[e],y=0;y<2;++y){var x=m[v[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,a[0]),T=b-_,k=1-T,M=+x[1],A=0|M,S=0|Math.min(A+1,a[1]),E=M-A,C=1-E,L=k*C,P=k*E,I=T*C,z=T*E,O=L*h.get(_,A)+P*h.get(_,S)+I*h.get(w,A)+z*h.get(w,S),D=L*p.get(_,A)+P*p.get(_,S)+I*p.get(w,A)+z*p.get(w,S);if(isNaN(O)||isNaN(D)){y&&(n-=1);break}i[2*n+0]=O,i[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(i.subarray(0,2*n)),s.freeFloat(i)}}},{\"./lib/shaders\":324,\"binary-search-bounds\":96,\"bit-twiddle\":97,colormap:131,\"gl-buffer\":258,\"gl-mat4/invert\":278,\"gl-mat4/multiply\":280,\"gl-texture2d\":327,\"gl-vao\":332,ndarray:469,\"ndarray-gradient\":462,\"ndarray-ops\":464,\"ndarray-pack\":465,\"surface-nets\":542,\"typedarray-pool\":567}],326:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),a=t(\"pick-by-alias\"),i=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),m=t(\"object-assign\"),v=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||i({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(T.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(T.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=a(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),T.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,i=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var a=n.stringify({size:T.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&a==e.font[r].baseString||(i=!0,e.font[r]=T.fonts[a],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:a,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:v(c,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:u.join(\" \")})},T.fonts[a]=e.font[r]}})),(i||o)&&this.font.forEach((function(r,a){var i=n.stringify({size:e.fontSize[a],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[a]=e.shader.atlas[i],!e.fontAtlas[a]){var o=r.metrics;e.shader.atlas[i]=e.fontAtlas[a]={fontString:i,step:2*Math.ceil(e.fontSize[a]*o.bottom*.5),em:e.fontSize[a],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||i){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var a=e.fontAtlas[n],i=0;i<e.text.length;i++){var o=e.text.charAt(i);if(null==a.ids[o]&&(a.ids[o]=a.chars.length,a.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);m(t.kerning,g(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)k[A++]=t.position[2*M],k[A++]=t.position[2*M+1];else for(var C=0;C<S;C++)k[A++]=t.position[M][0],k[A++]=t.position[M][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||i){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var I=0,z=0;I<this.counts.length;I++){for(var O=this.counts[I],D=this.font[I]||this.font[0],R=this.fontAtlas[I]||this.fontAtlas[0],F=0;F<O;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],a=n.step,i=Math.floor(T.maxAtlasSize/a),o=Math.min(i,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*a),u=x(s*a);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[a,a]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,a=0;return a+=.5*n.bottom,a+=\"number\"==typeof t?t-n.baseline:-n[t],T.normalViewport||(a*=-1),a}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var Z=t.color.length;H=u.mallocUint8(4*Z);for(var X=0;X<Z;X++)H.set(l(t.color[X]||0,\"uint8\"),4*X)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.normalViewport=!1,T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},e.exports=T},{\"bit-twiddle\":97,\"color-normalize\":125,\"css-font\":144,\"detect-kerning\":172,\"es6-weak-map\":233,\"flatten-vertex-data\":244,\"font-atlas\":245,\"font-measure\":246,\"gl-util/context\":328,\"is-plain-obj\":443,\"object-assign\":473,\"parse-rect\":478,\"parse-unit\":480,\"pick-by-alias\":485,regl:512,\"to-px\":550,\"typedarray-pool\":567}],327:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),a=t(\"ndarray-ops\"),i=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||c(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=u(e)?e:e.raw;if(r)return y(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return x(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}function u(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var h=function(t,e){a.muls(t,e,255)};function f(t,e,r){var n=t.gl,a=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function p(t,e,r,n,a,i){this.gl=t,this.handle=e,this.format=a,this.type=i,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var d=p.prototype;function g(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function m(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,a){var i=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture shape\");if(a===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,a,null),new p(t,o,e,r,n,a)}function y(t,e,r,n,a,i){var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,a,a,i,e),new p(t,o,r,n,a,i)}function x(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=g(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var u,f,d=0;if(2===o.length)d=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])d=t.ALPHA;else if(2===o[2])d=t.LUMINANCE_ALPHA;else if(3===o[2])d=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");d=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var v=e.size;if(l)u=0===e.offset&&e.data.length===v?e.data:e.data.subarray(e.offset,e.offset+v);else{var y=[o[2],o[2]*o[0],1];f=i.malloc(v,r);var x=n(f,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?a.assign(x,e):h(x,e),u=f.subarray(0,v)}var b=m(t);return t.texImage2D(t.TEXTURE_2D,0,d,o[0],o[1],0,d,c,u),l||i.free(f),new p(t,b,o[0],o[1],d,c)}Object.defineProperties(d,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return f(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return f(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,f(this,this._shape[0],t),t}}}),d.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},d.dispose=function(){this.gl.deleteTexture(this.handle)},d.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},d.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=u(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,u){var f=u.dtype,p=u.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var d=0,m=0,v=g(p,u.stride.slice());\"float32\"===f?d=t.FLOAT:\"float64\"===f?(d=t.FLOAT,v=!1,f=\"float32\"):\"uint8\"===f?d=t.UNSIGNED_BYTE:(d=t.UNSIGNED_BYTE,v=!1,f=\"uint8\");if(2===p.length)m=t.LUMINANCE,p=[p[0],p[1],1],u=n(u.data,p,[u.stride[0],u.stride[1],1],u.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])m=t.ALPHA;else if(2===p[2])m=t.LUMINANCE_ALPHA;else if(3===p[2])m=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");m=t.RGBA}p[2]}m!==t.LUMINANCE&&m!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(m=s);if(m!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=u.size,x=c.indexOf(o)<0;x&&c.push(o);if(d===l&&v)0===u.offset&&u.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data.subarray(u.offset,u.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data.subarray(u.offset,u.offset+y));else{var b;b=l===t.FLOAT?i.mallocFloat32(y):i.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);d===t.FLOAT&&l===t.UNSIGNED_BYTE?h(_,u):a.assign(_,u),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?i.freeFloat32(b):i.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:469,\"ndarray-ops\":464,\"typedarray-pool\":567}],328:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function a(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function i(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},i(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}i(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),a(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),a(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":485}],329:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var a=0;a<r.length;++a){var i=r[a];if(i.buffer){var o=i.buffer,s=i.size||4,l=i.type||t.FLOAT,c=!!i.normalized,u=i.stride||0,h=i.offset||0;o.bind(),t.enableVertexAttribArray(a),t.vertexAttribPointer(a,s,l,c,u,h)}else{if(\"number\"==typeof i)t.vertexAttrib1f(a,i);else if(1===i.length)t.vertexAttrib1f(a,i[0]);else if(2===i.length)t.vertexAttrib2f(a,i[0],i[1]);else if(3===i.length)t.vertexAttrib3f(a,i[0],i[1],i[2]);else{if(4!==i.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(a,i[0],i[1],i[2],i[3])}t.disableVertexAttribArray(a)}}for(;a<n;++a)t.disableVertexAttribArray(a)}else{t.bindBuffer(t.ARRAY_BUFFER,null);for(a=0;a<n;++a)t.disableVertexAttribArray(a)}}},{}],330:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function a(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}a.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},a.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.dispose=function(){},a.prototype.unbind=function(){},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new a(t)}},{\"./do-bind.js\":329}],331:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function a(t,e,r,n,a,i){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=a,this.d=i}function i(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}a.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},i.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},i.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},i.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},i.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var i=0;i<t.length;++i){var o=t[i];\"number\"==typeof o?this._attribs.push(new a(i,1,o)):Array.isArray(o)&&this._attribs.push(new a(i,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new i(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":329}],332:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),a=t(\"./lib/vao-emulated.js\");function i(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new i(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):a(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":330,\"./lib/vao-native.js\":331}],333:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],334:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);a(r,r),a(o,o);var s=i(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),a=t(\"./normalize\"),i=t(\"./dot\")},{\"./dot\":344,\"./fromValues\":350,\"./normalize\":361}],335:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],336:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],337:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],338:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],339:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2];return t[0]=a*l-i*s,t[1]=i*o-n*l,t[2]=n*s-a*o,t}},{}],340:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":341}],341:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2];return Math.sqrt(r*r+n*n+a*a)}},{}],342:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":343}],343:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],344:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],345:[function(t,e,r){e.exports=1e-6},{}],346:[function(t,e,r){e.exports=function(t,e){var r=t[0],a=t[1],i=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(a-s)<=n*Math.max(1,Math.abs(a),Math.abs(s))&&Math.abs(i-l)<=n*Math.max(1,Math.abs(i),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":345}],347:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],348:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],349:[function(t,e,r){e.exports=function(t,e,r,a,i,o){var s,l;e||(e=3);r||(r=0);l=a?Math.min(a*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],i(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":338}],350:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],351:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":333,\"./angle\":334,\"./ceil\":335,\"./clone\":336,\"./copy\":337,\"./create\":338,\"./cross\":339,\"./dist\":340,\"./distance\":341,\"./div\":342,\"./divide\":343,\"./dot\":344,\"./epsilon\":345,\"./equals\":346,\"./exactEquals\":347,\"./floor\":348,\"./forEach\":349,\"./fromValues\":350,\"./inverse\":352,\"./len\":353,\"./length\":354,\"./lerp\":355,\"./max\":356,\"./min\":357,\"./mul\":358,\"./multiply\":359,\"./negate\":360,\"./normalize\":361,\"./random\":362,\"./rotateX\":363,\"./rotateY\":364,\"./rotateZ\":365,\"./round\":366,\"./scale\":367,\"./scaleAndAdd\":368,\"./set\":369,\"./sqrDist\":370,\"./sqrLen\":371,\"./squaredDistance\":372,\"./squaredLength\":373,\"./sub\":374,\"./subtract\":375,\"./transformMat3\":376,\"./transformMat4\":377,\"./transformQuat\":378}],352:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],353:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":354}],354:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],355:[function(t,e,r){e.exports=function(t,e,r,n){var a=e[0],i=e[1],o=e[2];return t[0]=a+n*(r[0]-a),t[1]=i+n*(r[1]-i),t[2]=o+n*(r[2]-o),t}},{}],356:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],357:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],358:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":359}],359:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],360:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=r*r+n*n+a*a;i>0&&(i=1/Math.sqrt(i),t[0]=e[0]*i,t[1]=e[1]*i,t[2]=e[2]*i);return t}},{}],362:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,a=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*a,t[1]=Math.sin(r)*a,t[2]=n*e,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[1],i=r[2],o=e[1]-a,s=e[2]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=a+o*c-s*l,t[2]=i+o*l+s*c,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[0],i=r[2],o=e[0]-a,s=e[2]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=a+s*l+o*c,t[1]=e[1],t[2]=i+s*c-o*l,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[0],i=r[1],o=e[0]-a,s=e[1]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=a+o*c-s*l,t[1]=i+o*l+s*c,t[2]=e[2],t}},{}],366:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],367:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],368:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],369:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],370:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":372}],371:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":373}],372:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2];return r*r+n*n+a*a}},{}],373:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],374:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":375}],375:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],376:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2];return t[0]=n*r[0]+a*r[3]+i*r[6],t[1]=n*r[1]+a*r[4]+i*r[7],t[2]=n*r[2]+a*r[5]+i*r[8],t}},{}],377:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[3]*n+r[7]*a+r[11]*i+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*a+r[8]*i+r[12])/o,t[1]=(r[1]*n+r[5]*a+r[9]*i+r[13])/o,t[2]=(r[2]*n+r[6]*a+r[10]*i+r[14])/o,t}},{}],378:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*i-l*a,h=c*a+l*n-o*i,f=c*i+o*a-s*n,p=-o*n-s*a-l*i;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],380:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],381:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],382:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],383:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2],i=e[3]-t[3];return Math.sqrt(r*r+n*n+a*a+i*i)}},{}],384:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],385:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],386:[function(t,e,r){e.exports=function(t,e,r,n){var a=new Float32Array(4);return a[0]=t,a[1]=e,a[2]=r,a[3]=n,a}},{}],387:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":379,\"./clone\":380,\"./copy\":381,\"./create\":382,\"./distance\":383,\"./divide\":384,\"./dot\":385,\"./fromValues\":386,\"./inverse\":388,\"./length\":389,\"./lerp\":390,\"./max\":391,\"./min\":392,\"./multiply\":393,\"./negate\":394,\"./normalize\":395,\"./random\":396,\"./scale\":397,\"./scaleAndAdd\":398,\"./set\":399,\"./squaredDistance\":400,\"./squaredLength\":401,\"./subtract\":402,\"./transformMat4\":403,\"./transformQuat\":404}],388:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],389:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3];return Math.sqrt(e*e+r*r+n*n+a*a)}},{}],390:[function(t,e,r){e.exports=function(t,e,r,n){var a=e[0],i=e[1],o=e[2],s=e[3];return t[0]=a+n*(r[0]-a),t[1]=i+n*(r[1]-i),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],391:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],393:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],394:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r*r+n*n+a*a+i*i;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=a*o,t[3]=i*o);return t}},{}],396:[function(t,e,r){var n=t(\"./normalize\"),a=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),a(t,t,e),t}},{\"./normalize\":395,\"./scale\":397}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],398:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r,n,a){return t[0]=e,t[1]=r,t[2]=n,t[3]=a,t}},{}],400:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2],i=e[3]-t[3];return r*r+n*n+a*a+i*i}},{}],401:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3];return e*e+r*r+n*n+a*a}},{}],402:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],403:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3];return t[0]=r[0]*n+r[4]*a+r[8]*i+r[12]*o,t[1]=r[1]*n+r[5]*a+r[9]*i+r[13]*o,t[2]=r[2]*n+r[6]*a+r[10]*i+r[14]*o,t[3]=r[3]*n+r[7]*a+r[11]*i+r[15]*o,t}},{}],404:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*i-l*a,h=c*a+l*n-o*i,f=c*i+o*a-s*n,p=-o*n-s*a-l*i;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],405:[function(t,e,r){var n=t(\"glsl-tokenizer\"),a=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var i=e[r];if(\"preprocessor\"===i.type){var o=i.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?a(l):l).trim()}}}}},{\"atob-lite\":77,\"glsl-tokenizer\":412}],406:[function(t,e,r){e.exports=function(t){var e,r,c,u=0,h=0,f=999,p=[],d=[],g=1,m=0,v=0,y=!1,x=!1,b=\"\",_=i,w=n;\"300 es\"===(t=t||{}).version&&(_=s,w=o);var T={},k={};for(u=0;u<_.length;u++)T[_[u]]=!0;for(u=0;u<w.length;u++)k[w[u]]=!0;return function(t){return d=[],null!==t?function(t){u=0,t.toString&&(t=t.toString());var r;b+=t.replace(/\\r\\n/g,\"\\n\"),c=b.length;for(;e=b[u],u<c;){switch(r=u,f){case 0:u=C();break;case 1:case 2:u=E();break;case 3:u=L();break;case 4:u=z();break;case 11:u=I();break;case 5:u=O();break;case 9999:u=D();break;case 9:u=S();break;case 999:u=A()}if(r!==u)switch(b[r]){case\"\\n\":m=0,++g;break;default:++m}}return h+=u,b=b.slice(u),d}(t):function(t){p.length&&M(p.join(\"\"));return f=10,M(\"(eof)\"),d}()};function M(t){t.length&&d.push({type:l[f],data:t,position:v,line:g,column:m})}function A(){return p=p.length?[]:p,\"/\"===r&&\"*\"===e?(v=h+u-1,f=0,r=e,u+1):\"/\"===r&&\"/\"===e?(v=h+u-1,f=1,r=e,u+1):\"#\"===e?(f=2,v=h+u,u):/\\s/.test(e)?(f=9,v=h+u,u):(y=/\\d/.test(e),x=/[^\\w_]/.test(e),v=h+u,f=y?4:x?3:9999,u)}function S(){return/[^\\s]/g.test(e)?(M(p.join(\"\")),f=999,u):(p.push(e),r=e,u+1)}function E(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(p.push(e),r=e,u+1):(M(p.join(\"\")),f=999,u)}function C(){return\"/\"===e&&\"*\"===r?(p.push(e),M(p.join(\"\")),f=999,u+1):(p.push(e),r=e,u+1)}function L(){if(\".\"===r&&/\\d/.test(e))return f=5,u;if(\"/\"===r&&\"*\"===e)return f=0,u;if(\"/\"===r&&\"/\"===e)return f=1,u;if(\".\"===e&&p.length){for(;P(p););return f=5,u}if(\";\"===e||\")\"===e||\"(\"===e){if(p.length)for(;P(p););return M(e),f=999,u+1}var t=2===p.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;P(p););return f=999,u}return p.push(e),r=e,u+1}function P(t){for(var e,r,n=0;;){if(e=a.indexOf(t.slice(0,t.length+n).join(\"\")),r=a[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return M(r),v+=r.length,(p=p.slice(r.length)).length}}function I(){return/[^a-fA-F0-9]/.test(e)?(M(p.join(\"\")),f=999,u):(p.push(e),r=e,u+1)}function z(){return\".\"===e||/[eE]/.test(e)?(p.push(e),f=5,r=e,u+1):\"x\"===e&&1===p.length&&\"0\"===p[0]?(f=11,p.push(e),r=e,u+1):/[^\\d]/.test(e)?(M(p.join(\"\")),f=999,u):(p.push(e),r=e,u+1)}function O(){return\"f\"===e&&(p.push(e),r=e,u+=1),/[eE]/.test(e)?(p.push(e),r=e,u+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(M(p.join(\"\")),f=999,u):(p.push(e),r=e,u+1)}function D(){if(/[^\\d\\w_]/.test(e)){var t=p.join(\"\");return f=k[t]?8:T[t]?7:6,M(p.join(\"\")),f=999,u}return p.push(e),r=e,u+1}};var n=t(\"./lib/literals\"),a=t(\"./lib/operators\"),i=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":408,\"./lib/builtins-300es\":407,\"./lib/literals\":410,\"./lib/literals-300es\":409,\"./lib/operators\":411}],407:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":408}],408:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],409:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":410}],410:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],411:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],412:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),a=[];return a=(a=a.concat(r(t))).concat(r(null))}},{\"./index\":406}],413:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],414:[function(t,e,r){(function(r){\"use strict\";var n,a=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:a,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":438}],415:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":438}],416:[function(t,e,r){r.read=function(t,e,r,n,a){var i,o,s=8*a-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?a-1:0,f=r?-1:1,p=t[e+h];for(h+=f,i=p&(1<<-u)-1,p>>=-u,u+=s;u>0;i=256*i+t[e+h],h+=f,u-=8);for(o=i&(1<<-u)-1,i>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===i)i=1-c;else{if(i===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),i-=c}return(p?-1:1)*o*Math.pow(2,i-n)},r.write=function(t,e,r,n,a,i){var o,s,l,c=8*i-a-1,u=(1<<c)-1,h=u>>1,f=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,a),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,a),o=0));a>=8;t[r+p]=255&s,p+=d,s/=256,a-=8);for(o=o<<a|s,c+=a;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],417:[function(t,e,r){\"use strict\";var n=t(\"./types\");e.exports=function(t,e){var r;for(r in n)if(n[r].detect(t,e))return r}},{\"./types\":420}],418:[function(t,e,r){(function(r){\"use strict\";var n=t(\"fs\"),a=t(\"path\"),i=t(\"./types\"),o=t(\"./detector\");function s(t,e){var r=o(t,e);if(r in i){var n=i[r].calculate(t,e);if(!1!==n)return n.type=r,n}throw new TypeError(\"unsupported file type: \"+r+\" (file: \"+e+\")\")}e.exports=function(t,e){if(r.isBuffer(t))return s(t);if(\"string\"!=typeof t)throw new TypeError(\"invalid invocation\");var i=a.resolve(t);if(\"function\"!=typeof e)return s(function(t){var e=n.openSync(t,\"r\"),a=n.fstatSync(e).size,i=Math.min(a,524288),o=r.alloc(i);return n.readSync(e,o,0,i,0),n.closeSync(e),o}(i),i);!function(t,e){n.open(t,\"r\",(function(a,i){if(a)return e(a);n.fstat(i,(function(a,o){if(a)return e(a);var s=o.size;if(s<=0)return e(new Error(\"File size is not greater than 0 \\u2014\\u2014 \"+t));var l=Math.min(s,524288),c=r.alloc(l);n.read(i,c,0,l,0,(function(t){if(t)return e(t);n.close(i,(function(t){e(t,c)}))}))}))}))}(i,(function(t,r){if(t)return e(t);var n;try{n=s(r,i)}catch(e){t=e}e(t,n)}))},e.exports.types=Object.keys(i)}).call(this,t(\"buffer\").Buffer)},{\"./detector\":417,\"./types\":420,buffer:111,fs:109,path:481}],419:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){return r=r||0,t[\"readUInt\"+e+(n?\"BE\":\"LE\")].call(t,r)}},{}],420:[function(t,e,r){\"use strict\";var n={bmp:t(\"./types/bmp\"),cur:t(\"./types/cur\"),dds:t(\"./types/dds\"),gif:t(\"./types/gif\"),icns:t(\"./types/icns\"),ico:t(\"./types/ico\"),jpg:t(\"./types/jpg\"),png:t(\"./types/png\"),psd:t(\"./types/psd\"),svg:t(\"./types/svg\"),tiff:t(\"./types/tiff\"),webp:t(\"./types/webp\")};e.exports=n},{\"./types/bmp\":421,\"./types/cur\":422,\"./types/dds\":423,\"./types/gif\":424,\"./types/icns\":425,\"./types/ico\":426,\"./types/jpg\":427,\"./types/png\":428,\"./types/psd\":429,\"./types/svg\":430,\"./types/tiff\":431,\"./types/webp\":432}],421:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"BM\"===t.toString(\"ascii\",0,2)},calculate:function(t){return{width:t.readUInt32LE(18),height:Math.abs(t.readInt32LE(22))}}}},{}],422:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&2===t.readUInt16LE(2)},calculate:t(\"./ico\").calculate}},{\"./ico\":426}],423:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 542327876===t.readUInt32LE(0)},calculate:function(t){return{height:t.readUInt32LE(12),width:t.readUInt32LE(16)}}}},{}],424:[function(t,e,r){\"use strict\";var n=/^GIF8[79]a/;e.exports={detect:function(t){var e=t.toString(\"ascii\",0,6);return n.test(e)},calculate:function(t){return{width:t.readUInt16LE(6),height:t.readUInt16LE(8)}}}},{}],425:[function(t,e,r){\"use strict\";var n={ICON:32,\"ICN#\":32,\"icm#\":16,icm4:16,icm8:16,\"ics#\":16,ics4:16,ics8:16,is32:16,s8mk:16,icp4:16,icl4:32,icl8:32,il32:32,l8mk:32,icp5:32,ic11:32,ich4:48,ich8:48,ih32:48,h8mk:48,icp6:64,ic12:32,it32:128,t8mk:128,ic07:128,ic08:256,ic13:256,ic09:512,ic14:512,ic10:1024};function a(t,e){var r=e+4;return[t.toString(\"ascii\",e,r),t.readUInt32BE(r)]}function i(t){var e=n[t];return{width:e,height:e,type:t}}e.exports={detect:function(t){return\"icns\"===t.toString(\"ascii\",0,4)},calculate:function(t){var e,r,n,o=t.length,s=8,l=t.readUInt32BE(4);if(r=i((e=a(t,s))[0]),(s+=e[1])===l)return r;for(n={width:r.width,height:r.height,images:[r]};s<l&&s<o;)r=i((e=a(t,s))[0]),s+=e[1],n.images.push(r);return n}}},{}],426:[function(t,e,r){\"use strict\";function n(t,e){var r=t.readUInt8(e);return 0===r?256:r}function a(t,e){var r=6+16*e;return{width:n(t,r),height:n(t,r+1)}}e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&1===t.readUInt16LE(2)},calculate:function(t){var e,r=t.readUInt16LE(4),n=a(t,0);if(1===r)return n;for(n.images=[{width:n.width,height:n.height}],e=1;e<r;e+=1)n.images.push(a(t,e));return n}}},{}],427:[function(t,e,r){\"use strict\";var n=t(\"../readUInt\");function a(t){return\"45786966\"===t.toString(\"hex\",2,6)}function i(t,e){return{height:t.readUInt16BE(e),width:t.readUInt16BE(e+2)}}function o(t,e){var r=t.slice(2,e),a=r.toString(\"hex\",6,8),i=\"4d4d\"===a;if(i||\"4949\"===a)return function(t,e){for(var r,a,i=n(t,16,14,e),o=0;o<i;o++){if(a=(r=16+12*o)+12,r>t.length)return;var s=t.slice(r,a);if(274===n(s,16,0,e)){if(3!==n(s,16,2,e))return;if(1!==n(s,32,4,e))return;return n(s,16,8,e)}}}(r,i)}function s(t,e){if(e>t.length)throw new TypeError(\"Corrupt JPG, exceeded buffer limits\");if(255!==t[e])throw new TypeError(\"Invalid JPG, marker table corrupted\")}e.exports={detect:function(t){return\"ffd8\"===t.toString(\"hex\",0,2)},calculate:function(t){var e,r,n;for(t=t.slice(4);t.length;){if(r=t.readUInt16BE(0),a(t)&&(e=o(t,r)),s(t,r),192===(n=t[r+1])||193===n||194===n){var l=i(t,r+5);return e?{width:l.width,height:l.height,orientation:e}:l}t=t.slice(r+2)}throw new TypeError(\"Invalid JPG, no size found\")}}},{\"../readUInt\":419}],428:[function(t,e,r){\"use strict\";e.exports={detect:function(t){if(\"PNG\\r\\n\\x1a\\n\"===t.toString(\"ascii\",1,8)){var e=t.toString(\"ascii\",12,16);if(\"CgBI\"===e&&(e=t.toString(\"ascii\",28,32)),\"IHDR\"!==e)throw new TypeError(\"invalid png\");return!0}},calculate:function(t){return\"CgBI\"===t.toString(\"ascii\",12,16)?{width:t.readUInt32BE(32),height:t.readUInt32BE(36)}:{width:t.readUInt32BE(16),height:t.readUInt32BE(20)}}}},{}],429:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"8BPS\"===t.toString(\"ascii\",0,4)},calculate:function(t){return{width:t.readUInt32BE(18),height:t.readUInt32BE(14)}}}},{}],430:[function(t,e,r){\"use strict\";var n=/<svg\\s([^>\"']|\"[^\"]*\"|'[^']*')*>/;var a={root:n,width:/\\swidth=(['\"])([^%]+?)\\1/,height:/\\sheight=(['\"])([^%]+?)\\1/,viewbox:/\\sviewBox=(['\"])(.+?)\\1/},i={cm:96/2.54,mm:96/2.54/10,m:96/2.54*100,pt:96/72,pc:96/72/12,em:16,ex:8};function o(t){var e=/([0-9.]+)([a-z]*)/.exec(t);if(e)return Math.round(parseFloat(e[1])*(i[e[2]]||1))}function s(t){var e=t.split(\" \");return{width:o(e[2]),height:o(e[3])}}e.exports={detect:function(t){return n.test(t)},calculate:function(t){var e=t.toString(\"utf8\").match(a.root);if(e){var r=function(t){var e=t.match(a.width),r=t.match(a.height),n=t.match(a.viewbox);return{width:e&&o(e[2]),height:r&&o(r[2]),viewbox:n&&s(n[2])}}(e[0]);if(r.width&&r.height)return function(t){return{width:t.width,height:t.height}}(r);if(r.viewbox)return function(t){var e=t.viewbox.width/t.viewbox.height;return t.width?{width:t.width,height:Math.floor(t.width/e)}:t.height?{width:Math.floor(t.height*e),height:t.height}:{width:t.viewbox.width,height:t.viewbox.height}}(r)}throw new TypeError(\"invalid svg\")}}},{}],431:[function(t,e,r){(function(r){\"use strict\";var n=t(\"fs\"),a=t(\"../readUInt\");function i(t,e){var r=a(t,16,8,e);return(a(t,16,10,e)<<16)+r}function o(t){if(t.length>24)return t.slice(12)}e.exports={detect:function(t){var e=t.toString(\"hex\",0,4);return\"49492a00\"===e||\"4d4d002a\"===e},calculate:function(t,e){if(!e)throw new TypeError(\"Tiff doesn't support buffer\");var s=\"BE\"===function(t){var e=t.toString(\"ascii\",0,2);return\"II\"===e?\"LE\":\"MM\"===e?\"BE\":void 0}(t),l=function(t,e){for(var r,n,s,l={};t&&t.length&&(r=a(t,16,0,e),n=a(t,16,2,e),s=a(t,32,4,e),0!==r);)1!==s||3!==n&&4!==n||(l[r]=i(t,e)),t=o(t);return l}(function(t,e,i){var o=a(t,32,4,i),s=1024,l=n.statSync(e).size;o+s>l&&(s=l-o-10);var c=r.alloc(s),u=n.openSync(e,\"r\");return n.readSync(u,c,0,s,o),c.slice(2)}(t,e,s),s),c=l[256],u=l[257];if(!c||!u)throw new TypeError(\"Invalid Tiff, missing tags\");return{width:c,height:u}}}}).call(this,t(\"buffer\").Buffer)},{\"../readUInt\":419,buffer:111,fs:109}],432:[function(t,e,r){\"use strict\";e.exports={detect:function(t){var e=\"RIFF\"===t.toString(\"ascii\",0,4),r=\"WEBP\"===t.toString(\"ascii\",8,12),n=\"VP8\"===t.toString(\"ascii\",12,15);return e&&r&&n},calculate:function(t){var e=t.toString(\"ascii\",12,16);if(t=t.slice(20,30),\"VP8X\"===e){var r=t[0];return!(!(0==(192&r))||!(0==(1&r)))&&function(t){return{width:1+t.readUIntLE(4,3),height:1+t.readUIntLE(7,3)}}(t)}if(\"VP8 \"===e&&47!==t[0])return function(t){return{width:16383&t.readInt16LE(6),height:16383&t.readInt16LE(8)}}(t);var n=t.toString(\"hex\",3,6);return\"VP8L\"===e&&\"9d012a\"!==n&&function(t){return{width:1+((63&t[2])<<8|t[1]),height:1+((15&t[4])<<10|t[3]<<2|(192&t[2])>>6)}}(t)}}},{}],433:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var a=t[0].length;if(r<=a)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,a+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(a+1),u=0;u<=a;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var h=new i(l,new Array(a+1),!1),f=h.adjacent,p=new Array(a+2);for(u=0;u<=a;++u){for(var d=l.slice(),g=0;g<=a;++g)g===u&&(d[g]=-1);var m=d[0];d[0]=d[1],d[1]=m;var v=new i(d,new Array(a+1),!0);f[u]=v,p[u]=v}p[a+1]=h;for(u=0;u<=a;++u){d=f[u].vertices;var y=f[u].adjacent;for(g=0;g<=a;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=a;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}}var _=new c(a,o,p),w=!!e;for(u=a+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),a=t(\"simplicial-complex\").compareCells;function i(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return a(t.vertices,e.vertices)}i.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var a=0;a<=t;++a)this.tuple[a]=this.vertices[a];var i=l[t];i||(i=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var a=new Function(\"test\",e.join(\"\")),i=n[t+1];return i||(i=n),a(i)}(t)),this.orient=i}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,a=this.tuple,i=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];a[h]=f<0?e:i[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,a=this.vertices,i=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)i[u]=a[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=i[u];i[u]=t;var p=this.orient();if(i[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,a=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var m=0;m<=n;++m)if(m!==g){var v=d[m];if(v.boundary&&!(v.lastVisited>=r)){var y=v.vertices;if(v.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=a[y[b]];if(this.orient()>0){y[x]=r,v.boundary=!1,c.push(v),h.push(v),v.lastVisited=r;continue}v.lastVisited=-r}var _=v.adjacent,w=p.slice(),T=d.slice(),k=new i(w,T,!0);u.push(k);var M=_.indexOf(e);if(!(M<0)){_[M]=k,T[g]=v,w[m]=-1,T[m]=e,d[m]=k,k.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,k,b))}}}}}}f.sort(s);for(m=0;m+1<f.length;m+=2){var P=f[m],I=f[m+1],z=P.index,O=I.index;z<0||O<0||(P.cell.adjacent[P.index]=I.cell,I.cell.adjacent[I.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var a=this.dimension,i=this.tuple,o=0;o<=a;++o){var s=n.vertices[o];i[o]=s<0?t:r[s]}var l=this.orient(i);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,a=0;a<n;++a){var i=r[a];if(i.boundary){for(var o=new Array(t),s=i.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":520,\"simplicial-complex\":530}],434:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function a(t,e,r,n,a){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=a,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new v(null);return new v(m(t))};var i=a.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=m(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var a=r(t[n]);if(a)return a}}function h(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var a=r(t[n]);if(a)return a}}function f(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function g(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function m(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],i=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(g),new a(n,m(i),m(o),c,u)}function v(t){this.root=t}i.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},i.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=m([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=m([t]);else{var r=n.ge(this.leftPoints,t,d),a=n.ge(this.rightPoints,t,g);this.leftPoints.splice(r,0,t),this.rightPoints.splice(a,0,t)}},i.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,a=this.left;a.right;)r=a,a=a.right;if(r===this)a.right=this.right;else{var i=this.left,s=this.right;r.count-=a.count,r.right=a.left,a.left=i,a.right=s}o(this,a),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(i=n.ge(this.leftPoints,t,d);i<this.leftPoints.length&&this.leftPoints[i][0]===t[0];++i)if(this.leftPoints[i]===t){this.count-=1,this.leftPoints.splice(i,1);for(s=n.ge(this.rightPoints,t,g);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1}return 0},i.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return u(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return h(this.rightPoints,t,e)}return f(this.leftPoints,e)},i.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?u(this.leftPoints,e,r):t>this.mid?h(this.rightPoints,t,r):f(this.leftPoints,r)};var y=v.prototype;y.insert=function(t){this.root?this.root.insert(t):this.root=new a(t[0],null,null,[t],[t])},y.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},y.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},y.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(y,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(y,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":435}],435:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],436:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],437:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],438:[function(t,e,r){e.exports=!0},{}],439:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}\n",
       "/*!\n",
       " * Determine if an object is a Buffer\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],440:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],441:[function(t,e,r){\"use strict\";e.exports=i,e.exports.isMobile=i,e.exports.default=i;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,a=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function i(t){t||(t={});var e=t.ua;if(e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"!=typeof e)return!1;var r=t.tablet?a.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf(\"Macintosh\")&&-1!==e.indexOf(\"Safari\")&&(r=!0),r}},{}],442:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],443:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],444:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],445:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],446:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],447:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():(t=t||self).mapboxgl=n()}(this,(function(){\"use strict\";var t,e,r;function n(n,a){if(t)if(e){var i=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=a(o)).workerUrl=window.URL.createObjectURL(new Blob([i],{type:\"text/javascript\"}))}else e=a;else t=a}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,a,i,o;for(void 0===e&&(e=1e-6),a=t,o=0;o<8;o++){if(i=this.sampleCurveX(a)-t,Math.abs(i)<e)return a;var s=this.sampleCurveDerivativeX(a);if(Math.abs(s)<1e-6)break;a-=i/s}if((a=t)<(r=0))return r;if(a>(n=1))return n;for(;r<n;){if(i=this.sampleCurveX(a),Math.abs(i-t)<e)return a;t>i?r=a:n=a,a=.5*(n-r)+r}return a},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var a=i;function i(t,e){this.x=t,this.y=e}function o(t,e,n,a){var i=new r(t,e,n,a);return function(t){return i.solve(t)}}i.prototype={clone:function(){return new i(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[2]*this.x+t[3]*this.y;return this.x=t[0]*this.x+t[1]*this.y,this.y=e,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=r*this.x+e*this.y;return this.x=e*this.x-r*this.y,this.y=n,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=e.x+r*(this.x-e.x)-n*(this.y-e.y),this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},i.convert=function(t){return t instanceof i?t:Array.isArray(t)?new i(t[0],t[1]):t};var s=o(.25,.1,.25,1);function l(t,e,r){return Math.min(r,Math.max(e,t))}function c(t,e,r){var n=r-e,a=((t-e)%n+n)%n+e;return a===e?r:a}function u(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,a=e;n<a.length;n+=1){var i=a[n];for(var o in i)t[o]=i[o]}return t}var h=1;function f(){return h++}function p(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function d(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function g(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function v(t,e,r){var n={};for(var a in t)n[a]=e.call(r||this,t[a],a,t);return n}function y(t,e,r){var n={};for(var a in t)e.call(r||this,t[a],a,t)&&(n[a]=t[a]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?v(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,a=n-1,i=void 0,o=void 0;r<n;a=r++)e+=((o=t[a]).x-(i=t[r]).x)*(i.y+o.y);return e}function k(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function M(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,a){var i=n||a;return e[r]=!i||i.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var A=null;function S(t){if(null==A){var e=t.navigator?t.navigator.userAgent:null;A=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return A}function E(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var C,L,P,I,z=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,D=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,R={now:z,frame:function(t){var e=O(t);return{cancel:function(){return D(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=self.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return C||(C=self.document.createElement(\"a\")),C.href=t,C.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==L&&(L=self.matchMedia(\"(prefers-reduced-motion: reduce)\")),L.matches)}},F={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},B={supported:!1,testSupport:function(t){!N&&I&&(j?U(t):P=t)}},N=!1,j=!1;function U(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,I),t.isContextLost())return;B.supported=!0}catch(t){}t.deleteTexture(e),N=!0}self.document&&((I=self.document.createElement(\"img\")).onload=function(){P&&U(P),P=null,j=!0},I.onerror=function(){N=!0,P=null},I.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var V=\"01\",q=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function H(t){return 0===t.indexOf(\"mapbox:\")}q.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",V,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},q.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},q.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},q.prototype.normalizeStyleURL=function(t,e){if(!H(t))return t;var r=Z(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeGlyphsURL=function(t,e){if(!H(t))return t;var r=Z(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSourceURL=function(t,e){if(!H(t))return t;var r=Z(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSpriteURL=function(t,e,r,n){var a=Z(t);return H(t)?(a.path=\"/styles/v1\"+a.path+\"/sprite\"+e+r,this._makeAPIURL(a,this._customAccessToken||n)):(a.path+=\"\"+e+r,X(a))},q.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!H(t))return t;var r=Z(t);r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,(R.devicePixelRatio>=2||512===e?\"@2x\":\"\")+(B.supported?\".webp\":\"$1\")),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var n=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||F.ACCESS_TOKEN;return F.REQUIRE_ACCESS_TOKEN&&n&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,n)},q.prototype.canonicalizeTileURL=function(t,e){var r=Z(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var a=r.params;return e&&(a=a.filter((function(t){return!t.match(/^access_token=/)}))),a.length&&(n+=\"?\"+a.join(\"&\")),n},q.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&H(e),n=[],a=0,i=t.tiles||[];a<i.length;a+=1){var o=i[a];Y(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},q.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=Z(F.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!F.REQUIRE_ACCESS_TOKEN)return X(t);if(!(e=e||F.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),X(t)};var G=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function Y(t){return G.test(t)}var W=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function Z(t){var e=t.match(W);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function X(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function J(t){if(!t)return null;var e=t.split(\".\");if(!e||3!==e.length)return null;try{return JSON.parse(decodeURIComponent(self.atob(e[1]).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\")))}catch(t){return null}}var K=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};K.prototype.getStorageKey=function(t){var e,r=J(F.ACCESS_TOKEN);return e=r&&r.u?self.btoa(encodeURIComponent(r.u).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):F.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+e:\"mapbox.eventData:\"+e},K.prototype.fetchEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var a=self.localStorage.getItem(r);a&&(this.anonId=a)}catch(t){_(\"Unable to read from LocalStorage\")}},K.prototype.saveEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){_(\"Unable to write to LocalStorage\")}},K.prototype.processRequests=function(t){},K.prototype.postEvent=function(t,e,r,n){var a=this;if(F.EVENTS_URL){var i=Z(F.EVENTS_URL);i.params.push(\"access_token=\"+(n||F.ACCESS_TOKEN||\"\"));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.10.1\",skuId:V,userId:this.anonId},s=e?u(o,e):o,l={url:X(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([s])};this.pendingRequest=xt(l,(function(t){a.pendingRequest=null,r(t),a.saveEventData(),a.processRequests(n)}))}},K.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var Q,$,tt=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(F.EVENTS_URL&&n||F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,a=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),d(this.anonId)||(this.anonId=p()),this.postEvent(a,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(K),et=new(function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postTurnstileEvent=function(t,e){F.EVENTS_URL&&F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=J(F.ACCESS_TOKEN),n=r?r.u:F.ACCESS_TOKEN,a=n!==this.eventData.tokenU;d(this.anonId)||(this.anonId=p(),a=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(i),l=(i-this.eventData.lastSuccess)/864e5;a=a||l>=1||l<-1||o.getDate()!==s.getDate()}else a=!0;if(!a)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=i,e.eventData.tokenU=n)}),t)}},e}(K)),rt=et.postTurnstileEvent.bind(et),nt=new tt,at=nt.postMapLoadEvent.bind(nt),it=500,ot=50;function st(){self.caches&&!Q&&(Q=self.caches.open(\"mapbox-tiles\"))}function lt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var ct,ut=1/0;function ht(){return null==ct&&(ct=self.OffscreenCanvas&&new self.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof self.createImageBitmap),ct}var ft={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(ft);var pt,dt,gt=function(t){function e(e,r,n){401===r&&Y(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),mt=k()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===self.location.protocol?self.parent:self).location.href},vt=function(t,e){if(!(/^file:/.test(r=t.url)||/^file:/.test(mt())&&!/^\\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return function(t,e){var r,n=new self.AbortController,a=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:mt(),signal:n.signal}),i=!1,o=!1,s=(r=a.url).indexOf(\"sku=\")>0&&Y(r);\"json\"===t.type&&a.headers.set(\"Accept\",\"application/json\");var l=function(r,n,i){if(!o){if(r&&\"SecurityError\"!==r.message&&_(r),n&&i)return c(n);var l=Date.now();self.fetch(a).then((function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new gt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&function(t,e,r){if(st(),Q){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var a=M(e.headers.get(\"Cache-Control\")||\"\");a[\"no-store\"]||(a[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*a[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<42e4||function(t,e){if(void 0===$)try{new Response(new ReadableStream),$=!0}catch(t){$=!1}$?e(t.body):t.blob().then(e)}(e,(function(e){var r=new self.Response(e,n);st(),Q&&Q.then((function(e){return e.put(lt(t.url),r)})).catch((function(t){return _(t.message)}))})))}}(a,n,s),i=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return s?function(t,e){if(st(),!Q)return e(null);var r=lt(t.url);Q.then((function(t){t.match(r).then((function(n){var a=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=M(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),a&&t.put(r,n.clone()),e(null,n,a)})).catch(e)})).catch(e)}(a,l):l(null,null),{cancel:function(){o=!0,i||n.abort()}}}(t,e);if(k()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new gt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},yt=function(t,e){return vt(u(t,{type:\"arrayBuffer\"}),e)},xt=function(t,e){return vt(u(t,{method:\"POST\"}),e)};pt=[],dt=0;var bt=function(t,e){if(B.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),dt>=F.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,a=function(){if(!n)for(n=!0,dt--;pt.length&&dt<F.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift();t.cancelled||(t.cancel=bt(t.requestParameters,t.callback).cancel)}},i=yt(t,(function(t,r,n,i){a(),t?e(t):r&&(ht()?function(t,e){var r=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});self.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var a=new self.Image,i=self.URL;a.onload=function(){e(null,a),i.revokeObjectURL(a.src)},a.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});a.cacheControl=r,a.expires=n,a.src=t.byteLength?i.createObjectURL(o):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}(r,e,n,i))}));return{cancel:function(){i.cancel(),a()}}};function _t(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function wt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Tt=function(t,e){void 0===e&&(e={}),u(this,e),this.type=t},kt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",u({error:e},r))}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Tt),Mt=function(){};Mt.prototype.on=function(t,e){return this._listeners=this._listeners||{},_t(t,e,this._listeners),this},Mt.prototype.off=function(t,e){return wt(t,e,this._listeners),wt(t,e,this._oneTimeListeners),this},Mt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},_t(t,e,this._oneTimeListeners),this},Mt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Tt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,a=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<a.length;n+=1)a[n].call(this,t);for(var i=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];i<o.length;i+=1){var s=o[i];wt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(u(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof kt&&console.error(t.error);return this},Mt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Mt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var At={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},in:{group:\"Lookup\"},\"index-of\":{group:\"Lookup\"},slice:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},image:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},distance:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},within:{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},St=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Et(t){var e=t.value;return e?[new St(t.key,e,\"constants have been deprecated as of v8\")]:[]}function Ct(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,a=e;n<a.length;n+=1){var i=a[n];for(var o in i)t[o]=i[o]}return t}function Lt(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function Pt(t){if(Array.isArray(t))return t.map(Pt);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=Pt(t[r]);return e}return Lt(t)}var It=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Error),zt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var a=n[r];this.bindings[a[0]]=a[1]}};zt.prototype.concat=function(t){return new zt(this,t)},zt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},zt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Ot={kind:\"null\"},Dt={kind:\"number\"},Rt={kind:\"string\"},Ft={kind:\"boolean\"},Bt={kind:\"color\"},Nt={kind:\"object\"},jt={kind:\"value\"},Ut={kind:\"collator\"},Vt={kind:\"formatted\"},qt={kind:\"resolvedImage\"};function Ht(t,e){return{kind:\"array\",itemType:t,N:e}}function Gt(t){if(\"array\"===t.kind){var e=Gt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var Yt=[Ot,Dt,Rt,Ft,Bt,Vt,Nt,Ht(jt),qt];function Wt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Wt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=Yt;r<n.length;r+=1)if(!Wt(n[r],e))return null}return\"Expected \"+Gt(t)+\" but found \"+Gt(e)+\" instead.\"}function Zt(t,e){return e.some((function(e){return e.kind===t.kind}))}function Xt(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var Jt=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function a(t){return n(\"%\"===t[t.length-1]?parseFloat(t)/100*255:parseInt(t))}function i(t){return(e=\"%\"===t[t.length-1]?parseFloat(t)/100:parseFloat(t))<0?0:e>1?1:e;var e}function o(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,s=t.replace(/ /g,\"\").toLowerCase();if(s in r)return r[s].slice();if(\"#\"===s[0])return 4===s.length?(e=parseInt(s.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===s.length&&(e=parseInt(s.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=s.indexOf(\"(\"),c=s.indexOf(\")\");if(-1!==l&&c+1===s.length){var u=s.substr(0,l),h=s.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=i(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=i(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=i(h[1]),g=i(h[2]),m=g<=.5?g*(d+1):g+d-g*d,v=2*g-m;return[n(255*o(v,m,p+1/3)),n(255*o(v,m,p)),n(255*o(v,m,p-1/3)),f];default:return null}}return null}}catch(t){}})).parseCSSColor,Kt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Kt.parse=function(t){if(t){if(t instanceof Kt)return t;if(\"string\"==typeof t){var e=Jt(t);if(e)return new Kt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Kt.prototype.toString=function(){var t=this.toArray(),e=t[1],r=t[2],n=t[3];return\"rgba(\"+Math.round(t[0])+\",\"+Math.round(e)+\",\"+Math.round(r)+\",\"+n+\")\"},Kt.prototype.toArray=function(){var t=this.a;return 0===t?[0,0,0,0]:[255*this.r/t,255*this.g/t,255*this.b/t,t]},Kt.black=new Kt(0,0,0,1),Kt.white=new Kt(1,1,1,1),Kt.transparent=new Kt(0,0,0,0),Kt.red=new Kt(1,0,0,1);var Qt=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};Qt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Qt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var $t=function(t,e,r,n,a){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=a},te=function(t){this.sections=t};te.fromString=function(t){return new te([new $t(t,null,null,null,null)])},te.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},te.factory=function(t){return t instanceof te?t:te.fromString(t)},te.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},te.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var a={};n.fontStack&&(a[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(a[\"font-scale\"]=n.scale),n.textColor&&(a[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(a)}}return t};var ee=function(t){this.name=t.name,this.available=t.available};function re(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function ne(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof Kt)return!0;if(t instanceof Qt)return!0;if(t instanceof te)return!0;if(t instanceof ee)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1)if(!ne(r[e]))return!1;return!0}if(\"object\"==typeof t){for(var n in t)if(!ne(t[n]))return!1;return!0}return!1}function ae(t){if(null===t)return Ot;if(\"string\"==typeof t)return Rt;if(\"boolean\"==typeof t)return Ft;if(\"number\"==typeof t)return Dt;if(t instanceof Kt)return Bt;if(t instanceof Qt)return Ut;if(t instanceof te)return Vt;if(t instanceof ee)return qt;if(Array.isArray(t)){for(var e,r=t.length,n=0,a=t;n<a.length;n+=1){var i=ae(a[n]);if(e){if(e===i)continue;e=jt;break}e=i}return Ht(e||jt,r)}return Nt}function ie(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof Kt||t instanceof te||t instanceof ee?t.toString():JSON.stringify(t)}ee.prototype.toString=function(){return this.name},ee.fromString=function(t){return t?new ee({name:t,available:!1}):null},ee.prototype.serialize=function(){return[\"image\",this.name]};var oe=function(t,e){this.type=t,this.value=e};oe.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!ne(t[1]))return e.error(\"invalid value\");var r=t[1],n=ae(r),a=e.expectedType;return\"array\"!==n.kind||0!==n.N||!a||\"array\"!==a.kind||\"number\"==typeof a.N&&0!==a.N||(n=a),new oe(n,r)},oe.prototype.evaluate=function(){return this.value},oe.prototype.eachChild=function(){},oe.prototype.outputDefined=function(){return!0},oe.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof Kt?[\"rgba\"].concat(this.value.toArray()):this.value instanceof te?this.value.serialize():this.value};var se=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};se.prototype.toJSON=function(){return this.message};var le={string:Rt,number:Dt,boolean:Ft,object:Nt},ce=function(t,e){this.type=t,this.args=e};ce.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,a=t[0];if(\"array\"===a){var i,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in le)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);i=le[s],n++}else i=jt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=Ht(i,o)}else r=le[a];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,jt);if(!c)return null;l.push(c)}return new ce(r,l)},ce.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Wt(this.type,ae(r)))return r;if(e===this.args.length-1)throw new se(\"Expected value to be of type \"+Gt(this.type)+\", but found \"+Gt(ae(r))+\" instead.\")}return null},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ce.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var ue=function(t){this.type=Vt,this.sections=t};ue.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],a=!1,i=1;i<=t.length-1;++i){var o=t[i];if(a&&\"object\"==typeof o&&!Array.isArray(o)){a=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Dt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,Ht(Rt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Bt)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var h=e.parse(t[i],1,jt);if(!h)return null;var f=h.type.kind;if(\"string\"!==f&&\"value\"!==f&&\"null\"!==f&&\"resolvedImage\"!==f)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");a=!0,n.push({content:h,scale:null,font:null,textColor:null})}}return new ue(n)},ue.prototype.evaluate=function(t){return new te(this.sections.map((function(e){var r=e.content.evaluate(t);return ae(r)===qt?new $t(\"\",r,null,null,null):new $t(ie(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},ue.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ue.prototype.outputDefined=function(){return!1},ue.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var a={};n.scale&&(a[\"font-scale\"]=n.scale.serialize()),n.font&&(a[\"text-font\"]=n.font.serialize()),n.textColor&&(a[\"text-color\"]=n.textColor.serialize()),t.push(a)}return t};var he=function(t){this.type=qt,this.input=t};he.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Rt);return r?new he(r):e.error(\"No image name provided.\")},he.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=ee.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},he.prototype.eachChild=function(t){t(this.input)},he.prototype.outputDefined=function(){return!1},he.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var fe={\"to-boolean\":Ft,\"to-color\":Bt,\"to-number\":Dt,\"to-string\":Rt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=fe[r],a=[],i=1;i<t.length;i++){var o=e.parse(t[i],i,jt);if(!o)return null;a.push(o)}return new pe(n,a)},pe.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,a=this.args;n<a.length;n+=1){if(r=null,(e=a[n].evaluate(t))instanceof Kt)return e;if(\"string\"==typeof e){var i=t.parseColor(e);if(i)return i}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":re(e[0],e[1],e[2],e[3])))return new Kt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new se(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new se(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?te.fromString(ie(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?ee.fromString(ie(this.args[0].evaluate(t))):ie(this.args[0].evaluate(t))},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},pe.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new ue([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new he(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var de=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ge=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};ge.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ge.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?de[this.feature.type]:this.feature.type:null},ge.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},ge.prototype.canonicalID=function(){return this.canonical},ge.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ge.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Kt.parse(t)),e};var me=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};me.prototype.evaluate=function(t){return this._evaluate(t,this.args)},me.prototype.eachChild=function(t){this.args.forEach(t)},me.prototype.outputDefined=function(){return!1},me.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},me.parse=function(t,e){var r,n=t[0],a=me.definitions[n];if(!a)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var i=Array.isArray(a)?a[0]:a.type,o=Array.isArray(a)?[[a[1],a[2]]]:a.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Be(e.registry,e.path,null,e.scope);for(var d=[],g=!1,m=1;m<t.length;m++){var v=t[m],y=Array.isArray(f)?f[m-1]:f.type,x=l.parse(v,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new me(n,i,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Gt).join(\", \")+\")\":\"(\"+Gt(e.type)+\"...)\"})).join(\" | \"),k=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+k.length);if(!A)return null;k.push(Gt(A.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},me.register=function(t,e){for(var r in me.definitions=e,e)t[r]=me};var ve=function(t,e,r){this.type=Ut,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function ye(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function xe(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function be(t,e){var r=(180+t[0])/360,n=(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t[1]*Math.PI/360)))/360,a=Math.pow(2,e.z);return[Math.round(r*a*8192),Math.round(n*a*8192)]}function _e(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function we(t,e){for(var r,n,a,i,o,s,l,c=!1,u=0,h=e.length;u<h;u++)for(var f=e[u],p=0,d=f.length;p<d-1;p++){if((i=(r=t)[0]-(n=f[p])[0])*(l=r[1]-(a=f[p+1])[1])-(s=r[0]-a[0])*(o=r[1]-n[1])==0&&i*s<=0&&o*l<=0)return!1;_e(t,f[p],f[p+1])&&(c=!c)}return c}function Te(t,e){for(var r=0;r<e.length;r++)if(we(t,e[r]))return!0;return!1}function ke(t,e,r,n){var a=n[0]-r[0],i=n[1]-r[1],o=(t[0]-r[0])*i-a*(t[1]-r[1]),s=(e[0]-r[0])*i-a*(e[1]-r[1]);return o>0&&s<0||o<0&&s>0}function Me(t,e,r){for(var n=0,a=r;n<a.length;n+=1)for(var i=a[n],o=0;o<i.length-1;++o)if(0!=(h=[(u=i[o+1])[0]-(c=i[o])[0],u[1]-c[1]])[0]*(f=[(l=e)[0]-(s=t)[0],l[1]-s[1]])[1]-h[1]*f[0]&&ke(s,l,c,u)&&ke(c,u,s,l))return!0;var s,l,c,u,h,f;return!1}function Ae(t,e){for(var r=0;r<t.length;++r)if(!we(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Me(t[n],t[n+1],e))return!1;return!0}function Se(t,e){for(var r=0;r<e.length;r++)if(Ae(t,e[r]))return!0;return!1}function Ee(t,e,r){for(var n=[],a=0;a<t.length;a++){for(var i=[],o=0;o<t[a].length;o++){var s=be(t[a][o],r);ye(e,s),i.push(s)}n.push(i)}return n}function Ce(t,e,r){for(var n=[],a=0;a<t.length;a++){var i=Ee(t[a],e,r);n.push(i)}return n}function Le(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var a=.5*n,i=t[0]-r[0]>a?-n:r[0]-t[0]>a?n:0;0===i&&(i=t[0]-r[2]>a?-n:r[2]-t[0]>a?n:0),t[0]+=i}ye(e,t)}function Pe(t,e,r,n){for(var a=8192*Math.pow(2,n.z),i=[8192*n.x,8192*n.y],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var h=u[c],f=[h.x+i[0],h.y+i[1]];Le(f,e,r,a),o.push(f)}return o}function Ie(t,e,r,n){for(var a,i=8192*Math.pow(2,n.z),o=[8192*n.x,8192*n.y],s=[],l=0,c=t;l<c.length;l+=1){for(var u=[],h=0,f=c[l];h<f.length;h+=1){var p=f[h],d=[p.x+o[0],p.y+o[1]];ye(e,d),u.push(d)}s.push(u)}if(e[2]-e[0]<=i/2){(a=e)[0]=a[1]=1/0,a[2]=a[3]=-1/0;for(var g=0,m=s;g<m.length;g+=1)for(var v=0,y=m[g];v<y.length;v+=1)Le(y[v],e,r,i)}return s}ve.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Ft);if(!n)return null;var a=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Ft);if(!a)return null;var i=null;return r.locale&&!(i=e.parse(r.locale,1,Rt))?null:new ve(n,a,i)},ve.prototype.evaluate=function(t){return new Qt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ve.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ve.prototype.outputDefined=function(){return!1},ve.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var ze=function(t,e){this.type=Ft,this.geojson=t,this.geometries=e};function Oe(t){if(t instanceof me){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof ze)return!1;var e=!0;return t.eachChild((function(t){e&&!Oe(t)&&(e=!1)})),e}function De(t){if(t instanceof me&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!De(t)&&(e=!1)})),e}function Re(t,e){if(t instanceof me&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Re(t,e)&&(r=!1)})),r}ze.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(ne(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var a=r.features[n].geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new ze(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var i=r.geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new ze(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new ze(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},ze.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],a=t.canonicalID();if(\"Polygon\"===e.type){var i=Ee(e.coordinates,n,a),o=Pe(t.geometry(),r,n,a);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!we(l[s],i))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,a),u=Pe(t.geometry(),r,n,a);if(!xe(r,n))return!1;for(var h=0,f=u;h<f.length;h+=1)if(!Te(f[h],c))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],a=t.canonicalID();if(\"Polygon\"===e.type){var i=Ee(e.coordinates,n,a),o=Ie(t.geometry(),r,n,a);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!Ae(l[s],i))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,a),u=Ie(t.geometry(),r,n,a);if(!xe(r,n))return!1;for(var h=0,f=u;h<f.length;h+=1)if(!Se(f[h],c))return!1}return!0}(t,this.geometries)}return!1},ze.prototype.eachChild=function(){},ze.prototype.outputDefined=function(){return!0},ze.prototype.serialize=function(){return[\"within\",this.geojson]};var Fe=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Fe.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Fe(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Fe.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Fe.prototype.eachChild=function(){},Fe.prototype.outputDefined=function(){return!1},Fe.prototype.serialize=function(){return[\"var\",this.name]};var Be=function(t,e,r,n,a){void 0===e&&(e=[]),void 0===n&&(n=new zt),void 0===a&&(a=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=a,this.expectedType=r};function Ne(t,e){for(var r,n=t.length-1,a=0,i=n,o=0;a<=i;)if((r=t[o=Math.floor((a+i)/2)])<=e){if(o===n||e<t[o+1])return o;a=o+1}else{if(!(r>e))throw new se(\"Input is not a number.\");i=o-1}return 0}Be.prototype.parse=function(t,e,r,n,a){return void 0===a&&(a={}),e?this.concat(e,r,n)._parse(t,a):this._parse(t,a)},Be.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new ce(e,[t]):\"coerce\"===r?new pe(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var a=this.registry[n];if(a){var i=a.parse(t,this);if(!i)return null;if(this.expectedType){var o=this.expectedType,s=i.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else i=r(i,o,e.typeAnnotation||\"coerce\");else i=r(i,o,e.typeAnnotation||\"assert\")}if(!(i instanceof oe)&&\"resolvedImage\"!==i.type.kind&&function t(e){if(e instanceof Fe)return t(e.boundExpression);if(e instanceof me&&\"error\"===e.name)return!1;if(e instanceof ve)return!1;if(e instanceof ze)return!1;var r=e instanceof pe||e instanceof ce,n=!0;return e.eachChild((function(e){n=r?n&&t(e):n&&e instanceof oe})),!!n&&Oe(e)&&Re(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}(i)){var l=new ge;try{i=new oe(i.type,i.evaluate(l))}catch(t){return this.error(t.message),null}}return i}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return this.error(void 0===t?\"'undefined' value invalid. Use null instead.\":\"object\"==typeof t?'Bare objects invalid. Use [\"literal\", {...}] instead.':\"Expected an array, but found \"+typeof t+\" instead.\")},Be.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,a=r?this.scope.concat(r):this.scope;return new Be(this.registry,n,e||null,a,this.errors)},Be.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new It(n,t))},Be.prototype.checkSubtype=function(t,e){var r=Wt(t,e);return r&&this.error(r),r};var je=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,a=r;n<a.length;n+=1){var i=a[n],o=i[1];this.labels.push(i[0]),this.outputs.push(o)}};function Ue(t,e,r){return t*(1-r)+e*r}je.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=[],a=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(a=e.expectedType);for(var i=1;i<t.length;i+=2){var o=1===i?-1/0:t[i],s=t[i+1],l=i,c=i+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,a);if(!u)return null;a=a||u.type,n.push([o,u])}return new je(a,r,n)},je.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var a=e.length;return n>=e[a-1]?r[a-1].evaluate(t):r[Ne(e,n)].evaluate(t)},je.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},je.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},je.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ve=Object.freeze({__proto__:null,number:Ue,color:function(t,e,r){return new Kt(Ue(t.r,e.r,r),Ue(t.g,e.g,r),Ue(t.b,e.b,r),Ue(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return Ue(t,e[n],r)}))}}),qe=6/29*3*(6/29),He=Math.PI/180,Ge=180/Math.PI;function Ye(t){return t>.008856451679035631?Math.pow(t,1/3):t/qe+4/29}function We(t){return t>6/29?t*t*t:qe*(t-4/29)}function Ze(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Xe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Je(t){var e=Xe(t.r),r=Xe(t.g),n=Xe(t.b),a=Ye((.4124564*e+.3575761*r+.1804375*n)/.95047),i=Ye((.2126729*e+.7151522*r+.072175*n)/1);return{l:116*i-16,a:500*(a-i),b:200*(i-Ye((.0193339*e+.119192*r+.9503041*n)/1.08883)),alpha:t.a}}function Ke(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=1*We(e),r=.95047*We(r),n=1.08883*We(n),new Kt(Ze(3.2404542*r-1.5371385*e-.4985314*n),Ze(-.969266*r+1.8760108*e+.041556*n),Ze(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function Qe(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var $e={forward:Je,reverse:Ke,interpolate:function(t,e,r){return{l:Ue(t.l,e.l,r),a:Ue(t.a,e.a,r),b:Ue(t.b,e.b,r),alpha:Ue(t.alpha,e.alpha,r)}}},tr={forward:function(t){var e=Je(t),r=e.l,n=e.a,a=e.b,i=Math.atan2(a,n)*Ge;return{h:i<0?i+360:i,c:Math.sqrt(n*n+a*a),l:r,alpha:t.a}},reverse:function(t){var e=t.h*He,r=t.c;return Ke({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:Qe(t.h,e.h,r),c:Ue(t.c,e.c,r),l:Ue(t.l,e.l,r),alpha:Ue(t.alpha,e.alpha,r)}}},er=Object.freeze({__proto__:null,lab:$e,hcl:tr}),rr=function(t,e,r,n,a){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var i=0,o=a;i<o.length;i+=1){var s=o[i],l=s[1];this.labels.push(s[0]),this.outputs.push(l)}};function nr(t,e,r,n){var a=n-r,i=t-r;return 0===a?0:1===e?i/a:(Math.pow(e,i)-1)/(Math.pow(e,a)-1)}rr.interpolationFactor=function(t,e,n,a){var i=0;if(\"exponential\"===t.name)i=nr(e,t.base,n,a);else if(\"linear\"===t.name)i=nr(e,1,n,a);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;i=new r(o[0],o[1],o[2],o[3]).solve(nr(e,1,n,a))}return i},rr.parse=function(t,e){var r=t[0],n=t[1],a=t[2],i=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(a=e.parse(a,2,Dt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Bt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<i.length;u+=2){var h=i[u],f=i[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new rr(c,r,n,a,l):e.error(\"Type \"+Gt(c)+\" is not interpolatable.\")},rr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var a=e.length;if(n>=e[a-1])return r[a-1].evaluate(t);var i=Ne(e,n),o=rr.interpolationFactor(this.interpolation,n,e[i],e[i+1]),s=r[i].evaluate(t),l=r[i+1].evaluate(t);return\"interpolate\"===this.operator?Ve[this.type.kind.toLowerCase()](s,l,o):\"interpolate-hcl\"===this.operator?tr.reverse(tr.interpolate(tr.forward(s),tr.forward(l),o)):$e.reverse($e.interpolate($e.forward(s),$e.forward(l),o))},rr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},rr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},rr.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var ar=function(t,e){this.type=t,this.args=e};ar.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var a=[],i=0,o=t.slice(1);i<o.length;i+=1){var s=e.parse(o[i],1+a.length,r,void 0,{typeAnnotation:\"omit\"});if(!s)return null;r=r||s.type,a.push(s)}var l=n&&a.some((function(t){return Wt(n,t.type)}));return new ar(l?jt:r,a)},ar.prototype.evaluate=function(t){for(var e,r=null,n=0,a=0,i=this.args;a<i.length&&(n++,(r=i[a].evaluate(t))&&r instanceof ee&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null===r);a+=1);return r},ar.prototype.eachChild=function(t){this.args.forEach(t)},ar.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ar.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var ir=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};ir.prototype.evaluate=function(t){return this.result.evaluate(t)},ir.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},ir.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var a=t[n];if(\"string\"!=typeof a)return e.error(\"Expected string, but found \"+typeof a+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(a))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var i=e.parse(t[n+1],n+1);if(!i)return null;r.push([a,i])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new ir(r,o):null},ir.prototype.outputDefined=function(){return this.result.outputDefined()},ir.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e];t.push(n[0],n[1].serialize())}return t.push(this.result.serialize()),t};var or=function(t,e,r){this.type=t,this.index=e,this.input=r};or.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Dt),n=e.parse(t[2],2,Ht(e.expectedType||jt));return r&&n?new or(n.type.itemType,r,n):null},or.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new se(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new se(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new se(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},or.prototype.eachChild=function(t){t(this.index),t(this.input)},or.prototype.outputDefined=function(){return!1},or.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var sr=function(t,e){this.type=Ft,this.needle=t,this.haystack=e};sr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);return r&&n?Zt(r.type,[Ft,Rt,Dt,Ot,jt])?new sr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\"):null},sr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!Xt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ae(e))+\" instead.\");if(!Xt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ae(r))+\" instead.\");return r.indexOf(e)>=0},sr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},sr.prototype.outputDefined=function(){return!0},sr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var lr=function(t,e,r){this.type=Dt,this.needle=t,this.haystack=e,this.fromIndex=r};lr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);if(!r||!n)return null;if(!Zt(r.type,[Ft,Rt,Dt,Ot,jt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var a=e.parse(t[3],3,Dt);return a?new lr(r,n,a):null}return new lr(r,n)},lr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!Xt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ae(e))+\" instead.\");if(!Xt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ae(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},lr.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},lr.prototype.outputDefined=function(){return!1},lr.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var cr=function(t,e,r,n,a,i){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=a,this.otherwise=i};cr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var a={},i=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ae(f)))return null}else r=ae(f);if(void 0!==a[String(f)])return c.error(\"Branch labels must be unique.\");a[String(f)]=i.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,i.push(p)}var d=e.parse(t[1],1,jt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new cr(r,n,d,a,i,g):null},cr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(ae(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},cr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},cr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},cr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},a=0,i=Object.keys(this.cases).sort();a<i.length;a+=1){var o=i[a];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];e.push(1===f.length?s(f[0]):f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var ur=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};ur.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],a=1;a<t.length-1;a+=2){var i=e.parse(t[a],a,Ft);if(!i)return null;var o=e.parse(t[a+1],a+1,r);if(!o)return null;n.push([i,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new ur(r,n,s):null},ur.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],a=n[1];if(n[0].evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},ur.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],a=n[1];t(n[0]),t(a)}t(this.otherwise)},ur.prototype.outputDefined=function(){return this.branches.every((function(t){return t[1].outputDefined()}))&&this.otherwise.outputDefined()},ur.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var hr=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function fr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function pr(t,e,r,n){return 0===n.compare(e,r)}function dr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function a(t,e,r){this.type=Ft,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return a.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],i=e.parse(t[1],1,jt);if(!i)return null;if(!fr(r,i.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(i.type)+\"'.\");var o=e.parse(t[2],2,jt);if(!o)return null;if(!fr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(o.type)+\"'.\");if(i.type.kind!==o.type.kind&&\"value\"!==i.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Gt(i.type)+\"' and '\"+Gt(o.type)+\"'.\");n&&(\"value\"===i.type.kind&&\"value\"!==o.type.kind?i=new ce(o.type,[i]):\"value\"!==i.type.kind&&\"value\"===o.type.kind&&(o=new ce(i.type,[o])));var s=null;if(4===t.length){if(\"string\"!==i.type.kind&&\"string\"!==o.type.kind&&\"value\"!==i.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Ut)))return null}return new a(i,o,s)},a.prototype.evaluate=function(a){var i=this.lhs.evaluate(a),o=this.rhs.evaluate(a);if(n&&this.hasUntypedArgument){var s=ae(i),l=ae(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new se('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=ae(i),u=ae(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(a,i,o)}return this.collator?r(a,i,o,this.collator.evaluate(a)):e(a,i,o)},a.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},a.prototype.outputDefined=function(){return!0},a.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},a}()}hr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,Dt);if(!r||!n)return null;if(!Zt(r.type,[Ht(jt),Rt,jt]))return e.error(\"Expected first argument to be of type array or string, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var a=e.parse(t[3],3,Dt);return a?new hr(r.type,r,n,a):null}return new hr(r.type,r,n)},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!Xt(e,[\"string\",\"array\"]))throw new se(\"Expected first argument to be of type array or string, but found \"+Gt(ae(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},hr.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},hr.prototype.outputDefined=function(){return!1},hr.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var gr=dr(\"==\",(function(t,e,r){return e===r}),pr),mr=dr(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!pr(0,e,r,n)})),vr=dr(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),yr=dr(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),xr=dr(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),br=dr(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),_r=function(t,e,r,n,a){this.type=Rt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=a};_r.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var a=null;if(n.locale&&!(a=e.parse(n.locale,1,Rt)))return null;var i=null;if(n.currency&&!(i=e.parse(n.currency,1,Rt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Dt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Dt))?null:new _r(r,a,i,o,s)},_r.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},_r.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},_r.prototype.outputDefined=function(){return!1},_r.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var wr=function(t){this.type=Dt,this.input=t};wr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Gt(r.type)+\" instead.\"):new wr(r):null},wr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new se(\"Expected value to be of type string or array, but found \"+Gt(ae(e))+\" instead.\")},wr.prototype.eachChild=function(t){t(this.input)},wr.prototype.outputDefined=function(){return!1},wr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Tr={\"==\":gr,\"!=\":mr,\">\":yr,\"<\":vr,\">=\":br,\"<=\":xr,array:ce,at:or,boolean:ce,case:ur,coalesce:ar,collator:ve,format:ue,image:he,in:sr,\"index-of\":lr,interpolate:rr,\"interpolate-hcl\":rr,\"interpolate-lab\":rr,length:wr,let:ir,literal:oe,match:cr,number:ce,\"number-format\":_r,object:ce,slice:hr,step:je,string:ce,\"to-boolean\":pe,\"to-color\":pe,\"to-number\":pe,\"to-string\":pe,var:Fe,within:ze};function kr(t,e){var r=e[0],n=e[1],a=e[2],i=e[3];r=r.evaluate(t),n=n.evaluate(t),a=a.evaluate(t);var o=i?i.evaluate(t):1,s=re(r,n,a,o);if(s)throw new se(s);return new Kt(r/255*o,n/255*o,a/255*o,o)}function Mr(t,e){return t in e}function Ar(t,e){var r=e[t];return void 0===r?null:r}function Sr(t){return{type:t}}function Er(t){return{result:\"success\",value:t}}function Cr(t){return{result:\"error\",value:t}}function Lr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Pr(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Ir(t){return!!t.expression&&t.expression.interpolated}function zr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function Or(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Dr(t){return t}function Rr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Fr(t,e,r,n,a){return Rr(typeof r===a?n[r]:void 0,t.default,e.default)}function Br(t,e,r){if(\"number\"!==zr(r))return Rr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var a=Ne(t.stops.map((function(t){return t[0]})),r);return t.stops[a][1]}function Nr(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==zr(r))return Rr(t.default,e.default);var a=t.stops.length;if(1===a)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[a-1][0])return t.stops[a-1][1];var i=Ne(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var a=n-r,i=t-r;return 0===a?0:1===e?i/a:(Math.pow(e,i)-1)/(Math.pow(e,a)-1)}(r,n,t.stops[i][0],t.stops[i+1][0]),s=t.stops[i][1],l=t.stops[i+1][1],c=Ve[e.type]||Dr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=er[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function jr(t,e,r){return\"color\"===e.type?r=Kt.parse(r):\"formatted\"===e.type?r=te.fromString(r.toString()):\"resolvedImage\"===e.type?r=ee.fromString(r.toString()):zr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Rr(r,t.default,e.default)}me.register(Tr,{error:[{kind:\"error\"},[Rt],function(t,e){throw new se(e[0].evaluate(t))}],typeof:[Rt,[jt],function(t,e){return Gt(ae(e[0].evaluate(t)))}],\"to-rgba\":[Ht(Dt,4),[Bt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Bt,[Dt,Dt,Dt],kr],rgba:[Bt,[Dt,Dt,Dt,Dt],kr],has:{type:Ft,overloads:[[[Rt],function(t,e){return Mr(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Mr(e[0].evaluate(t),r.evaluate(t))}]]},get:{type:jt,overloads:[[[Rt],function(t,e){return Ar(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Ar(e[0].evaluate(t),r.evaluate(t))}]]},\"feature-state\":[jt,[Rt],function(t,e){return Ar(e[0].evaluate(t),t.featureState||{})}],properties:[Nt,[],function(t){return t.properties()}],\"geometry-type\":[Rt,[],function(t){return t.geometryType()}],id:[jt,[],function(t){return t.id()}],zoom:[Dt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Dt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Dt,[],function(t){return t.globals.lineProgress||0}],accumulated:[jt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Dt,Sr(Dt),function(t,e){for(var r=0,n=0,a=e;n<a.length;n+=1)r+=a[n].evaluate(t);return r}],\"*\":[Dt,Sr(Dt),function(t,e){for(var r=1,n=0,a=e;n<a.length;n+=1)r*=a[n].evaluate(t);return r}],\"-\":{type:Dt,overloads:[[[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)-r.evaluate(t)}],[[Dt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)/r.evaluate(t)}],\"%\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)%r.evaluate(t)}],ln2:[Dt,[],function(){return Math.LN2}],pi:[Dt,[],function(){return Math.PI}],e:[Dt,[],function(){return Math.E}],\"^\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return Math.pow(e[0].evaluate(t),r.evaluate(t))}],sqrt:[Dt,[Dt],function(t,e){return Math.sqrt(e[0].evaluate(t))}],log10:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN10}],ln:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))}],log2:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN2}],sin:[Dt,[Dt],function(t,e){return Math.sin(e[0].evaluate(t))}],cos:[Dt,[Dt],function(t,e){return Math.cos(e[0].evaluate(t))}],tan:[Dt,[Dt],function(t,e){return Math.tan(e[0].evaluate(t))}],asin:[Dt,[Dt],function(t,e){return Math.asin(e[0].evaluate(t))}],acos:[Dt,[Dt],function(t,e){return Math.acos(e[0].evaluate(t))}],atan:[Dt,[Dt],function(t,e){return Math.atan(e[0].evaluate(t))}],min:[Dt,Sr(Dt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Dt,Sr(Dt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Dt,[Dt],function(t,e){return Math.abs(e[0].evaluate(t))}],round:[Dt,[Dt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Dt,[Dt],function(t,e){return Math.floor(e[0].evaluate(t))}],ceil:[Dt,[Dt],function(t,e){return Math.ceil(e[0].evaluate(t))}],\"filter-==\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Ft,[jt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Ft,[Rt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a<i}],\"filter-id-<\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n<a}],\"filter->\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a>i}],\"filter-id->\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n>a}],\"filter-<=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a<=i}],\"filter-id-<=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n<=a}],\"filter->=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a>=i}],\"filter-id->=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n>=a}],\"filter-has\":[Ft,[jt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Ft,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[Ft,[Ht(Rt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Ft,[Ht(jt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var a=r+n>>1;if(e[a]===t)return!0;e[a]>t?n=a-1:r=a+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)&&r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)||r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Ft,[Ft],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Ft,[Rt],function(t,e){var r=t.globals&&t.globals.isSupportedScript;return!r||r(e[0].evaluate(t))}],upcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Rt,Sr(jt),function(t,e){return e.map((function(e){return ie(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Rt,[Ut],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Ur=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new ge,this._defaultValue=e?function(t){return\"color\"===t.type&&Or(t.default)?new Kt(0,0,0,0):\"color\"===t.type?Kt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Vr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Tr}function qr(t,e){var r=new Be(Tr,[],e?function(t){var e={color:Bt,string:Rt,number:Dt,enum:Rt,boolean:Ft,formatted:Vt,resolvedImage:qt};return\"array\"===t.type?Ht(e[t.value]||jt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Er(new Ur(n,e)):Cr(r.errors)}Ur.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,a,i){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=a||null,this._evaluator.formattedSection=i,this.expression.evaluate(this._evaluator)},Ur.prototype.evaluate=function(t,e,r,n,a,i){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=a||null,this._evaluator.formattedSection=i||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new se(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Hr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!De(e.expression)};Hr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,a,i){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,a,i)},Hr.prototype.evaluate=function(t,e,r,n,a,i){return this._styleExpression.evaluate(t,e,r,n,a,i)};var Gr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!De(e.expression),this.interpolationType=n};function Yr(t,e){if(\"error\"===(t=qr(t,e)).result)return t;var r=t.value.expression,n=Oe(r);if(!n&&!Lr(e))return Cr([new It(\"\",\"data expressions not supported\")]);var a=Re(r,[\"zoom\"]);if(!a&&!Pr(e))return Cr([new It(\"\",\"zoom expressions not supported\")]);var i=function t(e){var r=null;if(e instanceof ir)r=t(e.result);else if(e instanceof ar)for(var n=0,a=e.args;n<a.length&&!(r=t(a[n]));n+=1);else(e instanceof je||e instanceof rr)&&e.input instanceof me&&\"zoom\"===e.input.name&&(r=e);return r instanceof It||e.eachChild((function(e){var n=t(e);n instanceof It?r=n:!r&&n?r=new It(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new It(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),r}(r);return i||a?i instanceof It?Cr([i]):i instanceof rr&&!Ir(e)?Cr([new It(\"\",'\"interpolate\" expressions cannot be used with this property')]):Er(i?new Gr(n?\"camera\":\"composite\",t.value,i.labels,i instanceof rr?i.interpolation:void 0):new Hr(n?\"constant\":\"source\",t.value)):Cr([new It(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Gr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,a,i){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,a,i)},Gr.prototype.evaluate=function(t,e,r,n,a,i){return this._styleExpression.evaluate(t,e,r,n,a,i)},Gr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?rr.interpolationFactor(this.interpolationType,t,e,r):0};var Wr=function(t,e){this._parameters=t,this._specification=e,Ct(this,function t(e,r){var n,a,i,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||!(s||void 0!==e.property),c=e.type||(Ir(r)?\"exponential\":\"interval\");if(o&&((e=Ct({},e)).stops&&(e.stops=e.stops.map((function(t){return[t[0],Kt.parse(t[1])]}))),e.default=Kt.parse(e.default?e.default:r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!er[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===c)n=Nr;else if(\"interval\"===c)n=Br;else if(\"categorical\"===c){n=Fr,a=Object.create(null);for(var u=0,h=e.stops;u<h.length;u+=1){var f=h[u];a[f[0]]=f[1]}i=typeof e.stops[0][0]}else{if(\"identity\"!==c)throw new Error('Unknown function type \"'+c+'\"');n=jr}if(s){for(var p={},d=[],g=0;g<e.stops.length;g++){var m=e.stops[g],v=m[0].zoom;void 0===p[v]&&(p[v]={zoom:v,type:e.type,property:e.property,default:e.default,stops:[]},d.push(v)),p[v].stops.push([m[0].value,m[1]])}for(var y=[],x=0,b=d;x<b.length;x+=1){var _=b[x];y.push([p[_].zoom,t(p[_],r)])}var w={name:\"linear\"};return{kind:\"composite\",interpolationType:w,interpolationFactor:rr.interpolationFactor.bind(void 0,w),zoomStops:y.map((function(t){return t[0]})),evaluate:function(t,n){var a=t.zoom;return Nr({stops:y,base:e.base},r,a).evaluate(a,n)}}}if(l){var T=\"exponential\"===c?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:rr.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map((function(t){return t[0]})),evaluate:function(t){return n(e,r,t.zoom,a,i)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Rr(e.default,r.default):n(e,r,s,a,i)}}}(this._parameters,this._specification))};function Zr(t){var e=t.key,r=t.value,n=t.valueSpec||{},a=t.objectElementValidators||{},i=t.style,o=t.styleSpec,s=[],l=zr(r);if(\"object\"!==l)return[new St(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(a[u])f=a[u];else if(n[u])f=bn;else if(a[\"*\"])f=a[\"*\"];else{if(!n[\"*\"]){s.push(new St(e,r[c],'unknown property \"'+c+'\"'));continue}f=bn}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:i,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)a[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new St(e,r,'missing required property \"'+p+'\"'));return s}function Xr(t){var e=t.value,r=t.valueSpec,n=t.style,a=t.styleSpec,i=t.key,o=t.arrayElementValidator||bn;if(\"array\"!==zr(e))return[new St(i,e,\"array expected, \"+zr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new St(i,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new St(i,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};a.$version<7&&(s.function=r.function),\"object\"===zr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:a,key:i+\"[\"+c+\"]\"}));return l}function Jr(t){var e=t.key,r=t.value,n=t.valueSpec,a=zr(r);return\"number\"===a&&r!=r&&(a=\"NaN\"),\"number\"!==a?[new St(e,r,\"number expected, \"+a+\" found\")]:\"minimum\"in n&&r<n.minimum?[new St(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new St(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function Kr(t){var e,r,n,a=t.valueSpec,i=Lt(t.value.type),o={},s=\"categorical\"!==i&&void 0===t.value.property,l=!s,c=\"array\"===zr(t.value.stops)&&\"array\"===zr(t.value.stops[0])&&\"object\"===zr(t.value.stops[0][0]),u=Zr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===i)return[new St(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Xr({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===zr(r)&&0===r.length&&e.push(new St(t.key,r,\"array must have at least one stop\")),e},default:function(t){return bn({key:t.key,value:t.value,valueSpec:a,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===i&&s&&u.push(new St(t.key,t.value,'missing required property \"property\"')),\"identity\"===i||t.value.stops||u.push(new St(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===i&&t.valueSpec.expression&&!Ir(t.valueSpec)&&u.push(new St(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!Lr(t.valueSpec)?u.push(new St(t.key,t.value,\"property functions not supported\")):s&&!Pr(t.valueSpec)&&u.push(new St(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==i&&!c||void 0!==t.value.property||u.push(new St(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],i=t.value,s=t.key;if(\"array\"!==zr(i))return[new St(s,i,\"array expected, \"+zr(i)+\" found\")];if(2!==i.length)return[new St(s,i,\"array length 2 expected, length \"+i.length+\" found\")];if(c){if(\"object\"!==zr(i[0]))return[new St(s,i,\"object expected, \"+zr(i[0])+\" found\")];if(void 0===i[0].zoom)return[new St(s,i,\"object stop key must have zoom\")];if(void 0===i[0].value)return[new St(s,i,\"object stop key must have value\")];if(n&&n>Lt(i[0].zoom))return[new St(s,i[0].zoom,\"stop zoom values must appear in ascending order\")];Lt(i[0].zoom)!==n&&(n=Lt(i[0].zoom),r=void 0,o={}),e=e.concat(Zr({key:s+\"[0]\",value:i[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Jr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:i[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},i));return Vr(Pt(i[1]))?e.concat([new St(s+\"[1]\",i[1],\"expressions are not allowed in function stops.\")]):e.concat(bn({key:s+\"[1]\",value:i[1],valueSpec:a,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=zr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new St(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new St(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==i){var u=\"number expected, \"+s+\" found\";return Lr(a)&&void 0===i&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new St(t.key,c,u)]}return\"categorical\"!==i||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==i&&\"number\"===s&&void 0!==r&&l<r?[new St(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===i&&l in o?[new St(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new St(t.key,c,\"integer expected, found \"+l)]}}function Qr(t){var e=(\"property\"===t.expressionContext?Yr:qr)(Pt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new St(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new St(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Re(r,[\"zoom\",\"feature-state\"]))return[new St(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!Oe(r))return[new St(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function $r(t){var e=t.key,r=t.value,n=t.valueSpec,a=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&a.push(new St(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Lt(r))&&a.push(new St(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),a}function tn(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!tn(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Wr.deserialize=function(t){return new Wr(t._parameters,t._specification)},Wr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var en={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function rn(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};tn(t)||(t=an(t));var e=qr(t,en);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:function t(e){if(!Array.isArray(e))return!1;if(\"within\"===e[0])return!0;for(var r=1;r<e.length;r++)if(t(e[r]))return!0;return!1}(t)}}function nn(t,e){return t<e?-1:t>e?1:0}function an(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?on(t[1],t[2],\"==\"):\"!=\"===r?cn(on(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?on(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(an))):\"all\"===r?[\"all\"].concat(t.slice(1).map(an)):\"none\"===r?[\"all\"].concat(t.slice(1).map(an).map(cn)):\"in\"===r?sn(t[1],t.slice(2)):\"!in\"===r?cn(sn(t[1],t.slice(2))):\"has\"===r?ln(t[1]):\"!has\"===r?cn(ln(t[1])):\"within\"!==r||t}function on(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function sn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(nn)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function ln(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function cn(t){return[\"!\",t]}function un(t){return tn(Pt(t.value))?Qr(Ct({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==zr(r))return[new St(n,r,\"array expected, \"+zr(r)+\" found\")];var a,i=e.styleSpec,o=[];if(r.length<1)return[new St(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat($r({key:n+\"[0]\",value:r[0],valueSpec:i.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Lt(r[1])&&o.push(new St(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new St(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(a=zr(r[1]))&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+a+\" found\"));for(var s=2;s<r.length;s++)a=zr(r[s]),\"$type\"===Lt(r[1])?o=o.concat($r({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:i.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==a&&\"number\"!==a&&\"boolean\"!==a&&o.push(new St(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+a+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":a=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==a&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+a+\" found\"));break;case\"within\":a=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"object\"!==a&&o.push(new St(n+\"[1]\",r[1],\"object expected, \"+a+\" found\"))}return o}(t)}function hn(t,e){var r=t.key,n=t.style,a=t.styleSpec,i=t.value,o=t.objectKey,s=a[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return bn({key:r,value:i,valueSpec:a.transition,style:n,styleSpec:a});var c,u=t.valueSpec||s[o];if(!u)return[new St(r,i,'unknown property \"'+o+'\"')];if(\"string\"===zr(i)&&Lr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(i)))return[new St(r,i,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new St(r,i,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&Or(Pt(i))&&\"identity\"===Lt(i.type)&&h.push(new St(r,i,'\"text-font\" does not support identity functions'))),h.concat(bn({key:t.key,value:i,valueSpec:u,style:n,styleSpec:a,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function fn(t){return hn(t,\"paint\")}function pn(t){return hn(t,\"layout\")}function dn(t){var e=[],r=t.value,n=t.key,a=t.style,i=t.styleSpec;r.type||r.ref||e.push(new St(n,r,'either \"type\" or \"ref\" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var h=a.layers[u];Lt(h.id)===c&&e.push(new St(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new St(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),a.layers.forEach((function(t){Lt(t.id)===l&&(o=t)})),o?o.ref?e.push(new St(n,r.ref,\"ref cannot reference another ref layer\")):s=Lt(o.type):e.push(new St(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=a.sources&&a.sources[r.source],p=f&&Lt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new St(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new St(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new St(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new St(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new St(n,r,'missing required property \"source\"'));return e=e.concat(Zr({key:n,value:r,valueSpec:i.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return bn({key:n+\".type\",value:r.type,valueSpec:i.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:un,layout:function(t){return Zr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return pn(Ct({layerType:s},t))}}})},paint:function(t){return Zr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return fn(Ct({layerType:s},t))}}})}}}))}function gn(t){var e=t.value,r=t.key,n=zr(e);return\"string\"!==n?[new St(r,e,\"string expected, \"+n+\" found\")]:[]}var mn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===zr(r))return gn({key:e,value:r});var n=[];for(var a in r)n.push.apply(n,gn({key:e+\".\"+a,value:r[a]}));return n}};function vn(t){var e=t.value,r=t.key,n=t.styleSpec,a=t.style;if(!e.type)return[new St(r,e,'\"type\" is required')];var i,o=Lt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return Zr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:mn});case\"geojson\":if(i=Zr({key:r,value:e,valueSpec:n.source_geojson,style:a,styleSpec:n,objectElementValidators:mn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;i.push.apply(i,Qr({key:r+\".\"+s+\".map\",value:l[1],expressionContext:\"cluster-map\"})),i.push.apply(i,Qr({key:r+\".\"+s+\".reduce\",value:u,expressionContext:\"cluster-reduce\"}))}return i;case\"video\":return Zr({key:r,value:e,valueSpec:n.source_video,style:a,styleSpec:n});case\"image\":return Zr({key:r,value:e,valueSpec:n.source_image,style:a,styleSpec:n});case\"canvas\":return[new St(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return $r({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:a,styleSpec:n})}}function yn(t){var e=t.value,r=t.styleSpec,n=r.light,a=t.style,i=[],o=zr(e);if(void 0===e)return i;if(\"object\"!==o)return i.concat([new St(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);i=i.concat(l&&n[l[1]]&&n[l[1]].transition?bn({key:s,value:e[s],valueSpec:r.transition,style:a,styleSpec:r}):n[s]?bn({key:s,value:e[s],valueSpec:n[s],style:a,styleSpec:r}):[new St(s,e[s],'unknown property \"'+s+'\"')])}return i}var xn={\"*\":function(){return[]},array:Xr,boolean:function(t){var e=t.value,r=t.key,n=zr(e);return\"boolean\"!==n?[new St(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Jr,color:function(t){var e=t.key,r=t.value,n=zr(r);return\"string\"!==n?[new St(e,r,\"color expected, \"+n+\" found\")]:null===Jt(r)?[new St(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Et,enum:$r,filter:un,function:Kr,layer:dn,object:Zr,source:vn,light:yn,string:gn,formatted:function(t){return 0===gn(t).length?[]:Qr(t)},resolvedImage:function(t){return 0===gn(t).length?[]:Qr(t)}};function bn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&Or(Lt(e))?Kr(t):r.expression&&Vr(Pt(e))?Qr(t):r.type&&xn[r.type]?xn[r.type](t):Zr(Ct({},t,{valueSpec:r.type?n[r.type]:r}))}function _n(t){var e=t.value,r=t.key,n=gn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function wn(t,e){void 0===e&&(e=At);var r=[];return r=r.concat(bn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:_n,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Et({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Tn(r)}function Tn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function kn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Tn(t.apply(this,e))}}wn.source=kn(vn),wn.light=kn(yn),wn.layer=kn(dn),wn.filter=kn(un),wn.paintProperty=kn(fn),wn.layoutProperty=kn(pn);var Mn=wn,An=Mn.light,Sn=Mn.paintProperty,En=Mn.layoutProperty;function Cn(t,e){var r=!1;if(e&&e.length)for(var n=0,a=e;n<a.length;n+=1)t.fire(new kt(new Error(a[n].message))),r=!0;return r}var Ln=Pn;function Pn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var a=new Int32Array(this.arrayBuffer);t=a[0],this.d=(e=a[1])+2*(r=a[2]);for(var i=0;i<this.d*this.d;i++){var o=a[3+i],s=a[3+i+1];n.push(o===s?null:a.subarray(o,s))}var l=a[3+n.length+1];this.keys=a.subarray(a[3+n.length],l),this.bboxes=a.subarray(l),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var c=0;c<this.d*this.d;c++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var u=r/e*t;this.min=-u,this.max=t+u}Pn.prototype.insert=function(t,e,r,n,a){this._forEachCell(e,r,n,a,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(a)},Pn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},Pn.prototype._insertCell=function(t,e,r,n,a,i){this.cells[a].push(i)},Pn.prototype.query=function(t,e,r,n,a){var i=this.min,o=this.max;if(t<=i&&e<=i&&o<=r&&o<=n&&!a)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},a),s},Pn.prototype._queryCell=function(t,e,r,n,a,i,o,s){var l=this.cells[a];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,i.push(c[f])):o[f]=!1}}},Pn.prototype._forEachCell=function(t,e,r,n,a,i,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&a.call(this,t,e,r,n,d,i,o,s))return}},Pn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},Pn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},Pn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=3+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var a=new Int32Array(e+r+this.keys.length+this.bboxes.length);a[0]=this.extent,a[1]=this.n,a[2]=this.padding;for(var i=e,o=0;o<t.length;o++){var s=t[o];a[3+o]=i,a.set(s,i),i+=s.length}return a[3+t.length]=i,a.set(this.keys,i),a[3+t.length+1]=i+=this.keys.length,a.set(this.bboxes,i),i+=this.bboxes.length,a.buffer};var In=self.ImageData,zn=self.ImageBitmap,On={};function Dn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),On[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Rn in Dn(\"Object\",Object),Ln.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},Ln.deserialize=function(t){return new Ln(t.buffer)},Dn(\"Grid\",Ln),Dn(\"Color\",Kt),Dn(\"Error\",Error),Dn(\"ResolvedImage\",ee),Dn(\"StylePropertyFunction\",Wr),Dn(\"StyleExpression\",Ur,{omit:[\"_evaluator\"]}),Dn(\"ZoomDependentExpression\",Gr),Dn(\"ZoomConstantExpression\",Hr),Dn(\"CompoundExpression\",me,{omit:[\"_evaluate\"]}),Tr)Tr[Rn]._classRegistryKey||Dn(\"Expression_\"+Rn,Tr[Rn]);function Fn(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Bn(t){return zn&&t instanceof zn}function Nn(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(Fn(t)||Bn(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof In)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],a=0,i=t;a<i.length;a+=1)n.push(Nn(i[a],e));return n}if(\"object\"==typeof t){var o=t.constructor,s=o._classRegistryKey;if(!s)throw new Error(\"can't serialize object of unregistered class\");var l=o.serialize?o.serialize(t,e):{};if(!o.serialize){for(var c in t)if(t.hasOwnProperty(c)&&!(On[s].omit.indexOf(c)>=0)){var u=t[c];l[c]=On[s].shallow.indexOf(c)>=0?u:Nn(u,e)}t instanceof Error&&(l.message=t.message)}if(l.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==s&&(l.$name=s),l}throw new Error(\"can't serialize object of type \"+typeof t)}function jn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||Fn(t)||Bn(t)||ArrayBuffer.isView(t)||t instanceof In)return t;if(Array.isArray(t))return t.map(jn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=On[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),a=0,i=Object.keys(t);a<i.length;a+=1){var o=i[a];if(\"$name\"!==o){var s=t[o];n[o]=On[e].shallow.indexOf(o)>=0?s:jn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Un=function(){this.first=!0};Un.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var Vn={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function qn(t){for(var e=0,r=t;e<r.length;e+=1)if(Hn(r[e].charCodeAt(0)))return!0;return!1}function Hn(t){return!(746!==t&&747!==t&&(t<4352||!(Vn[\"Bopomofo Extended\"](t)||Vn.Bopomofo(t)||Vn[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||Vn[\"CJK Compatibility Ideographs\"](t)||Vn[\"CJK Compatibility\"](t)||Vn[\"CJK Radicals Supplement\"](t)||Vn[\"CJK Strokes\"](t)||!(!Vn[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||Vn[\"CJK Unified Ideographs Extension A\"](t)||Vn[\"CJK Unified Ideographs\"](t)||Vn[\"Enclosed CJK Letters and Months\"](t)||Vn[\"Hangul Compatibility Jamo\"](t)||Vn[\"Hangul Jamo Extended-A\"](t)||Vn[\"Hangul Jamo Extended-B\"](t)||Vn[\"Hangul Jamo\"](t)||Vn[\"Hangul Syllables\"](t)||Vn.Hiragana(t)||Vn[\"Ideographic Description Characters\"](t)||Vn.Kanbun(t)||Vn[\"Kangxi Radicals\"](t)||Vn[\"Katakana Phonetic Extensions\"](t)||Vn.Katakana(t)&&12540!==t||!(!Vn[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!Vn[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||Vn[\"Unified Canadian Aboriginal Syllabics\"](t)||Vn[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||Vn[\"Vertical Forms\"](t)||Vn[\"Yijing Hexagram Symbols\"](t)||Vn[\"Yi Syllables\"](t)||Vn[\"Yi Radicals\"](t))))}function Gn(t){return!(Hn(t)||function(t){return!!(Vn[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||Vn[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||Vn[\"Letterlike Symbols\"](t)||Vn[\"Number Forms\"](t)||Vn[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||Vn[\"Control Pictures\"](t)&&9251!==t||Vn[\"Optical Character Recognition\"](t)||Vn[\"Enclosed Alphanumerics\"](t)||Vn[\"Geometric Shapes\"](t)||Vn[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||Vn[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||Vn[\"CJK Symbols and Punctuation\"](t)||Vn.Katakana(t)||Vn[\"Private Use Area\"](t)||Vn[\"CJK Compatibility Forms\"](t)||Vn[\"Small Form Variants\"](t)||Vn[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Yn(t){return t>=1424&&t<=2303||Vn[\"Arabic Presentation Forms-A\"](t)||Vn[\"Arabic Presentation Forms-B\"](t)}function Wn(t,e){return!(!e&&Yn(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||Vn.Khmer(t))}function Zn(t){for(var e=0,r=t;e<r.length;e+=1)if(Yn(r[e].charCodeAt(0)))return!0;return!1}var Xn=null,Jn=\"unavailable\",Kn=null,Qn=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(Jn=\"error\"),Xn&&Xn(t)};function $n(){ta.fire(new Tt(\"pluginStateChange\",{pluginStatus:Jn,pluginURL:Kn}))}var ta=new Mt,ea=function(){return Jn},ra=function(){if(\"deferred\"!==Jn||!Kn)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");Jn=\"loading\",$n(),Kn&&yt({url:Kn},(function(t){t?Qn(t):(Jn=\"loaded\",$n())}))},na={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return\"loaded\"===Jn||null!=na.applyArabicShaping},isLoading:function(){return\"loading\"===Jn},setState:function(t){Jn=t.pluginStatus,Kn=t.pluginURL},isParsed:function(){return null!=na.applyArabicShaping&&null!=na.processBidirectionalText&&null!=na.processStyledBidirectionalText},getPluginURL:function(){return Kn}},aa=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Un,this.transition={})};aa.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!Wn(n[r].charCodeAt(0),e))return!1;return!0}(t,na.isLoaded())},aa.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},aa.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var ia=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(Or(t))return new Wr(t,e);if(Vr(t)){var r=Yr(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=Kt.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};ia.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},ia.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var oa=function(t){this.property=t,this.value=new ia(t,void 0)};oa.prototype.transitioned=function(t,e){return new la(this.property,this.value,e,u({},t.transition,this.transition),t.now)},oa.prototype.untransitioned=function(){return new la(this.property,this.value,null,{},0)};var sa=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};sa.prototype.getValue=function(t){return x(this._values[t].value.value)},sa.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oa(this._values[t].property)),this._values[t].value=new ia(this._values[t].property,null===e?void 0:x(e))},sa.prototype.getTransition=function(t){return x(this._values[t].transition)},sa.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oa(this._values[t].property)),this._values[t].transition=x(e)||void 0},sa.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],a=this.getValue(n);void 0!==a&&(t[n]=a);var i=this.getTransition(n);void 0!==i&&(t[n+\"-transition\"]=i)}return t},sa.prototype.transitioned=function(t,e){for(var r=new ca(this._properties),n=0,a=Object.keys(this._values);n<a.length;n+=1){var i=a[n];r._values[i]=this._values[i].transitioned(t,e._values[i])}return r},sa.prototype.untransitioned=function(){for(var t=new ca(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var la=function(t,e,r,n,a){this.property=t,this.value=e,this.begin=a+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};la.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,a=this.value.possiblyEvaluate(t,e,r),i=this.prior;if(i){if(n>this.end)return this.prior=null,a;if(this.value.isDataDriven())return this.prior=null,a;if(n<this.begin)return i.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(i.possiblyEvaluate(t,e,r),a,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return a};var ca=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};ca.prototype.possiblyEvaluate=function(t,e,r){for(var n=new fa(this._properties),a=0,i=Object.keys(this._values);a<i.length;a+=1){var o=i[a];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},ca.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1)if(this._values[e[t]].prior)return!0;return!1};var ua=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};ua.prototype.getValue=function(t){return x(this._values[t].value)},ua.prototype.setValue=function(t,e){this._values[t]=new ia(this._values[t].property,null===e?void 0:x(e))},ua.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],a=this.getValue(n);void 0!==a&&(t[n]=a)}return t},ua.prototype.possiblyEvaluate=function(t,e,r){for(var n=new fa(this._properties),a=0,i=Object.keys(this._values);a<i.length;a+=1){var o=i[a];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var ha=function(t,e,r){this.property=t,this.value=e,this.parameters=r};ha.prototype.isConstant=function(){return\"constant\"===this.value.kind},ha.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},ha.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var fa=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};fa.prototype.get=function(t){return this._values[t]};var pa=function(t){this.specification=t};pa.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},pa.prototype.interpolate=function(t,e,r){var n=Ve[this.specification.type];return n?n(t,e,r):t};var da=function(t,e){this.specification=t,this.overrides=e};da.prototype.possiblyEvaluate=function(t,e,r,n){return new ha(this,\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)}:t.expression,e)},da.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new ha(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ve[this.specification.type];return n?new ha(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},da.prototype.evaluate=function(t,e,r,n,a,i){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,a,i)};var ga=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new ha(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var a=t.expression.evaluate(e,null,{},r,n),i=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof a?a.name:a,o=this._calculate(i,i,i,e);return new ha(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new ha(this,{kind:\"constant\",value:s},e)}return new ha(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,a,i){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,a,i);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(da),ma=function(t){this.specification=t};ma.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var a=t.expression.evaluate(e,null,{},r,n);return this._calculate(a,a,a,e)}return this._calculate(t.expression.evaluate(new aa(Math.floor(e.zoom-1),e)),t.expression.evaluate(new aa(Math.floor(e.zoom),e)),t.expression.evaluate(new aa(Math.floor(e.zoom+1),e)),e)}},ma.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},ma.prototype.interpolate=function(t){return t};var va=function(t){this.specification=t};va.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},va.prototype.interpolate=function(){return!1};var ya=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new ia(r,void 0),a=this.defaultTransitionablePropertyValues[e]=new oa(r);this.defaultTransitioningPropertyValues[e]=a.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};Dn(\"DataDrivenProperty\",da),Dn(\"DataConstantProperty\",pa),Dn(\"CrossFadedDataDrivenProperty\",ga),Dn(\"CrossFadedProperty\",ma),Dn(\"ColorRampProperty\",va);var xa=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(this.metadata=(e=e).metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new ua(r.layout)),r.paint)){for(var n in this._transitionablePaint=new sa(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var a in e.layout)this.setLayoutProperty(a,e.layout[a],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new fa(r.paint)}}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){void 0===r&&(r={}),null!=e&&this._validate(En,\"layers.\"+this.id+\".layout.\"+t,t,e,r)||(\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e)},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e&&this._validate(Sn,\"layers.\"+this.id+\".paint.\"+t,t,e,r))return!1;if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var n=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===n.property.specification[\"property-type\"],i=n.value.isDataDriven(),o=n.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var s=this._transitionablePaint._values[t].value;return s.isDataDriven()||i||a||this._handleOverridablePaintPropertyUpdate(t,o,s)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),y(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Cn(this,t.call(Mn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:At,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof ha&&Lr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(Mt),ba={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},_a=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},wa=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Ta(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var a=ba[t.type].BYTES_PER_ELEMENT,i=r=ka(r,Math.max(e,a)),o=t.components||1;return n=Math.max(n,a),r+=a*o,{name:t.name,type:t.type,components:o,offset:i}})),size:ka(r,Math.max(n,e)),alignment:e}}function ka(t,e){return Math.ceil(t/e)*e}wa.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},wa.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},wa.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},wa.prototype.clear=function(){this.length=0},wa.prototype.resize=function(t){this.reserve(t),this.length=t},wa.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},wa.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var Ma=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(wa);Ma.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2i4\",Ma);var Aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=4*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,this.int16[i+3]=a,t},e}(wa);Aa.prototype.bytesPerElement=8,Dn(\"StructArrayLayout4i8\",Aa);var Sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=a,this.int16[s+4]=i,this.int16[s+5]=o,t},e}(wa);Sa.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i4i12\",Sa);var Ea=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=a,this.uint8[l+6]=i,this.uint8[l+7]=o,t},e}(wa);Ea.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2i4ub8\",Ea);var Ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,a,i,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u){var h=9*t,f=18*t;return this.uint16[h+0]=e,this.uint16[h+1]=r,this.uint16[h+2]=n,this.uint16[h+3]=a,this.uint16[h+4]=i,this.uint16[h+5]=o,this.uint16[h+6]=s,this.uint16[h+7]=l,this.uint8[f+16]=c,this.uint8[f+17]=u,t},e}(wa);Ca.prototype.bytesPerElement=18,Dn(\"StructArrayLayout8ui2ub18\",Ca);var La=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h){var f=this.length;return this.resize(f+1),this.emplace(f,t,e,r,n,a,i,o,s,l,c,u,h)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=a,this.uint16[p+4]=i,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=h,this.int16[p+11]=f,t},e}(wa);La.prototype.bytesPerElement=24,Dn(\"StructArrayLayout4i4ui4i24\",La);var Pa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,t},e}(wa);Pa.prototype.bytesPerElement=12,Dn(\"StructArrayLayout3f12\",Pa);var Ia=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint32[1*t+0]=e,t},e}(wa);Ia.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1ul4\",Ia);var za=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,a,i,o,s,l)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c){var u=10*t,h=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=a,this.int16[u+4]=i,this.int16[u+5]=o,this.uint32[h+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(wa);za.prototype.bytesPerElement=20,Dn(\"StructArrayLayout6i1ul2ui20\",za);var Oa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=a,this.int16[s+4]=i,this.int16[s+5]=o,t},e}(wa);Oa.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i2i2i12\",Oa);var Da=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n,a)},e.prototype.emplace=function(t,e,r,n,a,i){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=a,this.int16[s+7]=i,t},e}(wa);Da.prototype.bytesPerElement=16,Dn(\"StructArrayLayout2f1f2i16\",Da);var Ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=12*t,o=3*t;return this.uint8[i+0]=e,this.uint8[i+1]=r,this.float32[o+1]=n,this.float32[o+2]=a,t},e}(wa);Ra.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2ub2f12\",Ra);var Fa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.uint16[a+0]=e,this.uint16[a+1]=r,this.uint16[a+2]=n,t},e}(wa);Fa.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3ui6\",Fa);var Ba=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m,v){var y=24*t,x=12*t,b=48*t;return this.int16[y+0]=e,this.int16[y+1]=r,this.uint16[y+2]=n,this.uint16[y+3]=a,this.uint32[x+2]=i,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[y+10]=l,this.uint16[y+11]=c,this.uint16[y+12]=u,this.float32[x+7]=h,this.float32[x+8]=f,this.uint8[b+36]=p,this.uint8[b+37]=d,this.uint8[b+38]=g,this.uint32[x+10]=m,this.int16[y+22]=v,t},e}(wa);Ba.prototype.bytesPerElement=48,Dn(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Ba);var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E){var C=34*t,L=17*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=a,this.int16[C+4]=i,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=h,this.uint16[C+11]=f,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=g,this.uint16[C+15]=m,this.uint16[C+16]=v,this.uint16[C+17]=y,this.uint16[C+18]=x,this.uint16[C+19]=b,this.uint16[C+20]=_,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=M,this.float32[L+14]=A,this.float32[L+15]=S,this.float32[L+16]=E,t},e}(wa);Na.prototype.bytesPerElement=68,Dn(\"StructArrayLayout8i15ui1ul4f68\",Na);var ja=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.float32[1*t+0]=e,t},e}(wa);ja.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1f4\",ja);var Ua=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,t},e}(wa);Ua.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3i6\",Ua);var Va=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=4*t;return this.uint32[2*t+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(wa);Va.prototype.bytesPerElement=8,Dn(\"StructArrayLayout1ul2ui8\",Va);var qa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(wa);qa.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2ui4\",qa);var Ha=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint16[1*t+0]=e,t},e}(wa);Ha.prototype.bytesPerElement=2,Dn(\"StructArrayLayout1ui2\",Ha);var Ga=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(wa);Ga.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2f8\",Ga);var Ya=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=4*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,this.float32[i+3]=a,t},e}(wa);Ya.prototype.bytesPerElement=16,Dn(\"StructArrayLayout4f16\",Ya);var Wa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new a(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(_a);Wa.prototype.size=20;var Za=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Wa(this,t)},e}(za);Dn(\"CollisionBoxArray\",Za);var Xa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(_a);Xa.prototype.size=48;var Ja=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Xa(this,t)},e}(Ba);Dn(\"PlacedSymbolArray\",Ja);var Ka=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(_a);Ka.prototype.size=68;var Qa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Ka(this,t)},e}(Na);Dn(\"SymbolInstanceArray\",Qa);var $a=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(ja);Dn(\"GlyphOffsetArray\",$a);var ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(Ua);Dn(\"SymbolLineVertexArray\",ti);var ei=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(_a);ei.prototype.size=8;var ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new ei(this,t)},e}(Va);Dn(\"FeatureIndexArray\",ri);var ni=Ta([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,ai=function(t){void 0===t&&(t=[]),this.segments=t};function ii(t,e){return 256*(t=l(Math.floor(t),0,255))+l(Math.floor(e),0,255)}ai.prototype.prepareSegment=function(t,e,r,n){var a=this.segments[this.segments.length-1];return t>ai.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+ai.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!a||a.vertexLength+t>ai.MAX_VERTEX_ARRAY_LENGTH||a.sortKey!==n)&&(a={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(a.sortKey=n),this.segments.push(a)),a},ai.prototype.get=function(){return this.segments},ai.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},ai.simpleSegment=function(t,e,r,n){return new ai([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},ai.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Dn(\"SegmentVector\",ai);var oi=Ta([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint8\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint8\"}]),si=e((function(t){t.exports=function(t,e){var r,n,a,i,o,s,l,c;for(n=t.length-(r=3&t.length),a=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,a=27492+(65535&(i=5*(65535&(a=(a^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|a>>>19))+((5*(a>>>16)&65535)<<16)&4294967295))+((58964+(i>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:a^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return a^=t.length,a=2246822507*(65535&(a^=a>>>16))+((2246822507*(a>>>16)&65535)<<16)&4294967295,a=3266489909*(65535&(a^=a>>>13))+((3266489909*(a>>>16)&65535)<<16)&4294967295,(a^=a>>>16)>>>0}})),li=e((function(t){t.exports=function(t,e){for(var r,n=t.length,a=e^n,i=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(i)|(255&t.charCodeAt(++i))<<8|(255&t.charCodeAt(++i))<<16|(255&t.charCodeAt(++i))<<24))+((1540483477*(r>>>16)&65535)<<16),a=1540483477*(65535&a)+((1540483477*(a>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++i;switch(n){case 3:a^=(255&t.charCodeAt(i+2))<<16;case 2:a^=(255&t.charCodeAt(i+1))<<8;case 1:a=1540483477*(65535&(a^=255&t.charCodeAt(i)))+((1540483477*(a>>>16)&65535)<<16)}return a=1540483477*(65535&(a^=a>>>13))+((1540483477*(a>>>16)&65535)<<16),(a^=a>>>15)>>>0}})),ci=si,ui=li;ci.murmur3=si,ci.murmur2=ui;var hi=function(){this.ids=[],this.positions=[],this.indexed=!1};hi.prototype.add=function(t,e,r,n){this.ids.push(pi(t)),this.positions.push(e,r,n)},hi.prototype.getPositions=function(t){for(var e=pi(t),r=0,n=this.ids.length-1;r<n;){var a=r+n>>1;this.ids[a]>=e?n=a:r=a+1}for(var i=[];this.ids[r]===e;)i.push({index:this.positions[3*r],start:this.positions[3*r+1],end:this.positions[3*r+2]}),r++;return i},hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,a){for(;n<a;){for(var i=e[n+a>>1],o=n-1,s=a+1;;){do{o++}while(e[o]<i);do{s--}while(e[s]>i);if(o>=s)break;di(e,o,s),di(r,3*o,3*s),di(r,3*o+1,3*s+1),di(r,3*o+2,3*s+2)}s-n<a-s?(t(e,r,n,s),n=s+1):(t(e,r,s+1,a),a=s)}}(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},hi.deserialize=function(t){var e=new hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var fi=Math.pow(2,53)-1;function pi(t){var e=+t;return!isNaN(e)&&e<=fi?e:ci(String(t))}function di(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Dn(\"FeaturePositionMap\",hi);var gi=function(t,e){this.gl=t.gl,this.location=e},mi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(gi),vi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(gi),yi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(gi),xi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(gi),bi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(gi),_i=function(t){function e(e,r){t.call(this,e,r),this.current=Kt.transparent}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(gi),wi=new Float32Array(16),Ti=function(t){function e(e,r){t.call(this,e,r),this.current=wi}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(gi);function ki(t){return[ii(255*t.r,255*t.g),ii(255*t.b,255*t.a)]}var Mi=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};Mi.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},Mi.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new _i(t,e):new vi(t,e)};var Ai=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};Ai.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},Ai.prototype.setUniform=function(t,e,r,n){var a=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;a&&t.set(a)},Ai.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new bi(t,e):new vi(t,e)};var Si=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};Si.prototype.populatePaintArray=function(t,e,r,n,a){var i=this.paintVertexArray.length,o=this.expression.evaluate(new aa(0),e,{},n,[],a);this.paintVertexArray.resize(t),this._setPaintValue(i,t,o)},Si.prototype.updatePaintArray=function(t,e,r,n){var a=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,a)},Si.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=ki(r),a=t;a<e;a++)this.paintVertexArray.emplace(a,n[0],n[1]);else{for(var i=t;i<e;i++)this.paintVertexArray.emplace(i,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},Si.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Si.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var Ei=function(t,e,r,n,a,i){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=a,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new i};Ei.prototype.populatePaintArray=function(t,e,r,n,a){var i=this.expression.evaluate(new aa(this.zoom),e,{},n,[],a),o=this.expression.evaluate(new aa(this.zoom+1),e,{},n,[],a),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,i,o)},Ei.prototype.updatePaintArray=function(t,e,r,n){var a=this.expression.evaluate({zoom:this.zoom},r,n),i=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,a,i)},Ei.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var a=ki(r),i=ki(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,a[0],a[1],i[0],i[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},Ei.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ei.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ei.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=l(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},Ei.prototype.getBinding=function(t,e,r){return new vi(t,e)};var Ci=function(t,e,r,n,a,i){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=i,this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};Ci.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},Ci.prototype.updatePaintArray=function(t,e,r,n,a){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],a)},Ci.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var a=n[r.min],i=n[r.mid],o=n[r.max];if(a&&i&&o)for(var s=t;s<e;s++)this.zoomInPaintVertexArray.emplace(s,i.tl[0],i.tl[1],i.br[0],i.br[1],a.tl[0],a.tl[1],a.br[0],a.br[1],i.pixelRatio,a.pixelRatio),this.zoomOutPaintVertexArray.emplace(s,i.tl[0],i.tl[1],i.br[0],i.br[1],o.tl[0],o.tl[1],o.br[0],o.br[1],i.pixelRatio,o.pixelRatio)}},Ci.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,oi.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,oi.members,this.expression.isStateDependent))},Ci.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var Li=function(t,e,r,n){this.binders={},this.layoutAttributes=n,this._buffers=[];var a=[];for(var i in t.paint._values)if(r(i)){var o=t.paint.get(i);if(o instanceof ha&&Lr(o.property.specification)){var s=Ii(i,t.type),l=o.value,c=o.property.specification.type,u=o.property.useIntegerZoom,h=o.property.specification[\"property-type\"],f=\"cross-faded\"===h||\"cross-faded-data-driven\"===h;if(\"constant\"===l.kind)this.binders[i]=f?new Ai(l.value,s):new Mi(l.value,s,c),a.push(\"/u_\"+i);else if(\"source\"===l.kind||f){var p=zi(i,c,\"source\");this.binders[i]=f?new Ci(l,c,u,e,p,t.id):new Si(l,s,c,p),a.push(\"/a_\"+i)}else{var d=zi(i,c,\"composite\");this.binders[i]=new Ei(l,s,c,u,e,d),a.push(\"/z_\"+i)}}}this.cacheKey=a.sort().join(\"\")};Li.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof Si||e instanceof Ei?e.maxValue:0},Li.prototype.populatePaintArrays=function(t,e,r,n,a){for(var i in this.binders){var o=this.binders[i];(o instanceof Si||o instanceof Ei||o instanceof Ci)&&o.populatePaintArray(t,e,r,n,a)}},Li.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof Ai&&n.setConstantPatternPositions(t,e)}},Li.prototype.updatePaintArrays=function(t,e,r,n,a){var i=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var h in this.binders){var f=this.binders[h];if((f instanceof Si||f instanceof Ei||f instanceof Ci)&&!0===f.expression.isStateDependent){var p=n.paint.get(h);f.expression=p.value,f.updatePaintArray(c.start,c.end,u,t[o],a),i=!0}}}return i},Li.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof Mi||r instanceof Ai)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},Li.prototype.getPaintVertexBuffers=function(){return this._buffers},Li.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var a=this.binders[n];if(a instanceof Mi||a instanceof Ai||a instanceof Ei)for(var i=0,o=a.uniformNames;i<o.length;i+=1){var s=o[i];if(e[s]){var l=a.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},Li.prototype.setUniforms=function(t,e,r,n){for(var a=0,i=e;a<i.length;a+=1){var o=i[a],s=o.name,l=o.property;this.binders[l].setUniform(o.binding,n,r.get(l),s)}},Li.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof Ci){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof Si||r instanceof Ei)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},Li.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof Si||r instanceof Ei||r instanceof Ci)&&r.upload(t)}this.updatePaintBuffers()},Li.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof Si||e instanceof Ei||e instanceof Ci)&&e.destroy()}};var Pi=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var a=0,i=e;a<i.length;a+=1){var o=i[a];this.programConfigurations[o.id]=new Li(o,r,n,t)}this.needsUpload=!1,this._featureMap=new hi,this._bufferOffset=0};function Ii(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function zi(t,e,r){var n={color:{source:Ga,composite:Ya},number:{source:ja,composite:Ga}},a=function(t){return{\"line-pattern\":{source:Ca,composite:Ca},\"fill-pattern\":{source:Ca,composite:Ca},\"fill-extrusion-pattern\":{source:Ca,composite:Ca}}[t]}(t);return a&&a[r]||n[e][r]}Pi.prototype.populatePaintArrays=function(t,e,r,n,a,i){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,a,i);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},Pi.prototype.updatePaintArrays=function(t,e,r,n){for(var a=0,i=r;a<i.length;a+=1){var o=i[a];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},Pi.prototype.get=function(t){return this.programConfigurations[t]},Pi.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Pi.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},Dn(\"ConstantBinder\",Mi),Dn(\"CrossFadedConstantBinder\",Ai),Dn(\"SourceExpressionBinder\",Si),Dn(\"CrossFadedCompositeBinder\",Ci),Dn(\"CompositeExpressionBinder\",Ei),Dn(\"ProgramConfiguration\",Li,{omit:[\"_buffers\"]}),Dn(\"ProgramConfigurationSet\",Pi);var Oi={min:-1*Math.pow(2,14),max:Math.pow(2,14)-1};function Di(t){for(var e=8192/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var a=r[n],i=0;i<a.length;i++){var o=a[i];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Oi.min||o.x>Oi.max||o.y<Oi.min||o.y>Oi.max)&&(_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\"),o.x=l(o.x,Oi.min,Oi.max),o.y=l(o.y,Oi.min,Oi.max))}return r}function Ri(t,e,r,n,a){t.emplaceBack(2*e+(n+1)/2,2*r+(a+1)/2)}var Fi=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Ma,this.indexArray=new Fa,this.segments=new ai,this.programConfigurations=new Pi(ni,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function Bi(t,e){for(var r=0;r<t.length;r++)if(Wi(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Wi(t,e[n]))return!0;return!!Vi(t,e)}function Ni(t,e,r){return!!Wi(t,e)||!!Hi(e,t,r)}function ji(t,e){if(1===t.length)return Yi(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],a=0;a<n.length;a++)if(Wi(t,n[a]))return!0;for(var i=0;i<t.length;i++)if(Yi(e,t[i]))return!0;for(var o=0;o<e.length;o++)if(Vi(t,e[o]))return!0;return!1}function Ui(t,e,r){if(t.length>1){if(Vi(t,e))return!0;for(var n=0;n<e.length;n++)if(Hi(e[n],t,r))return!0}for(var a=0;a<t.length;a++)if(Hi(t[a],e,r))return!0;return!1}function Vi(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],a=t[r+1],i=0;i<e.length-1;i++)if(qi(n,a,e[i],e[i+1]))return!0;return!1}function qi(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function Hi(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var a=1;a<e.length;a++)if(Gi(t,e[a-1],e[a])<n)return!0;return!1}function Gi(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var a=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return t.distSqr(a<0?e:a>1?r:r.sub(e)._mult(a)._add(e))}function Yi(t,e){for(var r,n,a,i=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)(n=r[s]).y>e.y!=(a=r[l]).y>e.y&&e.x<(a.x-n.x)*(e.y-n.y)/(a.y-n.y)+n.x&&(i=!i);return i}function Wi(t,e){for(var r=!1,n=0,a=t.length-1;n<t.length;a=n++){var i=t[n],o=t[a];i.y>e.y!=o.y>e.y&&e.x<(o.x-i.x)*(e.y-i.y)/(o.y-i.y)+i.x&&(r=!r)}return r}function Zi(t,e,r){var n=r[0],a=r[2];if(t.x<n.x&&e.x<n.x||t.x>a.x&&e.x>a.x||t.y<n.y&&e.y<n.y||t.y>a.y&&e.y>a.y)return!1;var i=w(t,e,r[0]);return i!==w(t,e,r[1])||i!==w(t,e,r[2])||i!==w(t,e,r[3])}function Xi(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function Ji(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ki(t,e,r,n,i){if(!e[0]&&!e[1])return t;var o=a.convert(e)._mult(i);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++)s.push(t[l].sub(o));return s}Fi.prototype.populate=function(t,e,r){var n=this.layers[0],a=[],i=null;\"circle\"===n.type&&(i=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,h=l.index,f=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d={type:c.type,id:u,properties:c.properties,geometry:p?Di(c):[]};if(this.layers[0]._featureFilter.filter(new aa(this.zoom),d,r)){p||(d.geometry=Di(c));var g=i?i.evaluate(d,{},r):void 0;a.push({id:u,properties:c.properties,type:c.type,sourceLayerIndex:f,index:h,geometry:d.geometry,patterns:{},sortKey:g})}}i&&a.sort((function(t,e){return t.sortKey-e.sortKey}));for(var m=0,v=a;m<v.length;m+=1){var y=v[m],x=y.geometry,b=y.index,_=y.sourceLayerIndex,w=t[b].feature;this.addFeature(y,x,b,r),e.featureIndex.insert(w,x,b,_,this.index)}},Fi.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Fi.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Fi.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Fi.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ni),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Fi.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Fi.prototype.addFeature=function(t,e,r,n){for(var a=0,i=e;a<i.length;a+=1)for(var o=0,s=i[a];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=8192||u<0||u>=8192)){var h=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),f=h.vertexLength;Ri(this.layoutVertexArray,c,u,-1,-1),Ri(this.layoutVertexArray,c,u,1,-1),Ri(this.layoutVertexArray,c,u,1,1),Ri(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(f,f+1,f+2),this.indexArray.emplaceBack(f,f+3,f+2),h.vertexLength+=4,h.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},Dn(\"CircleBucket\",Fi,{omit:[\"layers\"]});var Qi=new ya({\"circle-sort-key\":new da(At.layout_circle[\"circle-sort-key\"])}),$i={paint:new ya({\"circle-radius\":new da(At.paint_circle[\"circle-radius\"]),\"circle-color\":new da(At.paint_circle[\"circle-color\"]),\"circle-blur\":new da(At.paint_circle[\"circle-blur\"]),\"circle-opacity\":new da(At.paint_circle[\"circle-opacity\"]),\"circle-translate\":new pa(At.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new pa(At.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new pa(At.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new pa(At.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new da(At.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new da(At.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new da(At.paint_circle[\"circle-stroke-opacity\"])}),layout:Qi},to=\"undefined\"!=typeof Float32Array?Float32Array:Array;function eo(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function ro(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*a+b*l+_*f+w*m,t[2]=x*i+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,t[4]=(x=r[4])*n+(b=r[5])*s+(_=r[6])*h+(w=r[7])*g,t[5]=x*a+b*l+_*f+w*m,t[6]=x*i+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,t[8]=(x=r[8])*n+(b=r[9])*s+(_=r[10])*h+(w=r[11])*g,t[9]=x*a+b*l+_*f+w*m,t[10]=x*i+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,t[12]=(x=r[12])*n+(b=r[13])*s+(_=r[14])*h+(w=r[15])*g,t[13]=x*a+b*l+_*f+w*m,t[14]=x*i+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var no,ao=ro;function io(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3];return t[0]=r[0]*n+r[4]*a+r[8]*i+r[12]*o,t[1]=r[1]*n+r[5]*a+r[9]*i+r[13]*o,t[2]=r[2]*n+r[6]*a+r[10]*i+r[14]*o,t[3]=r[3]*n+r[7]*a+r[11]*i+r[15]*o,t}no=new to(3),to!=Float32Array&&(no[0]=0,no[1]=0,no[2]=0),function(){var t=new to(4);to!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var oo=(function(){var t=new to(2);to!=Float32Array&&(t[0]=0,t[1]=0)}(),function(t){function e(e){t.call(this,e,$i)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new Fi(t)},e.prototype.queryRadius=function(t){var e=t;return Xi(\"circle-radius\",this,e)+Xi(\"circle-stroke-width\",this,e)+Ji(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,i,o,s){for(var l=Ki(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),i.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return t.map((function(t){return so(t,e)}))}(l,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,m=d[p];g<m.length;g+=1){var v=m[g],y=u?v:so(v,s),x=f,b=io([],[v.x,v.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/i.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=i.cameraToCenterDistance/b[3]),Ni(h,y,x))return!0}return!1},e}(xa));function so(t,e){var r=io([],[t.x,t.y,0,1],e);return new a(r[0]/r[3],r[1]/r[3])}var lo=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Fi);function co(t,e,r,n){var a=e.width,i=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==a*i*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(a*i*r);return t.width=a,t.height=i,t.data=n,t}function uo(t,e,r){var n=e.width,a=e.height;if(n!==t.width||a!==t.height){var i=co({},{width:n,height:a},r);ho(t,i,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,a)},r),t.width=n,t.height=a,t.data=i.data}}function ho(t,e,r,n,a,i){if(0===a.width||0===a.height)return e;if(a.width>t.width||a.height>t.height||r.x>t.width-a.width||r.y>t.height-a.height)throw new RangeError(\"out of range source coordinates for image copy\");if(a.width>e.width||a.height>e.height||n.x>e.width-a.width||n.y>e.height-a.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<a.height;l++)for(var c=((r.y+l)*t.width+r.x)*i,u=((n.y+l)*e.width+n.x)*i,h=0;h<a.width*i;h++)s[u+h]=o[c+h];return e}Dn(\"HeatmapBucket\",lo,{omit:[\"layers\"]});var fo=function(t,e){co(this,t,1,e)};fo.prototype.resize=function(t){uo(this,t,1)},fo.prototype.clone=function(){return new fo({width:this.width,height:this.height},new Uint8Array(this.data))},fo.copy=function(t,e,r,n,a){ho(t,e,r,n,a,1)};var po=function(t,e){co(this,t,4,e)};po.prototype.resize=function(t){uo(this,t,4)},po.prototype.replace=function(t,e){e?this.data.set(t):this.data=t instanceof Uint8ClampedArray?new Uint8Array(t.buffer):t},po.prototype.clone=function(){return new po({width:this.width,height:this.height},new Uint8Array(this.data))},po.copy=function(t,e,r,n,a){ho(t,e,r,n,a,4)},Dn(\"AlphaImage\",fo),Dn(\"RGBAImage\",po);var go={paint:new ya({\"heatmap-radius\":new da(At.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new da(At.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new pa(At.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new va(At.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new pa(At.paint_heatmap[\"heatmap-opacity\"])})};function mo(t,e){for(var r=new Uint8Array(1024),n={},a=0,i=0;a<256;a++,i+=4){n[e]=a/255;var o=t.evaluate(n);r[i+0]=Math.floor(255*o.r/o.a),r[i+1]=Math.floor(255*o.g/o.a),r[i+2]=Math.floor(255*o.b/o.a),r[i+3]=Math.floor(255*o.a)}return new po({width:256,height:1},r)}var vo=function(t){function e(e){t.call(this,e,go),this._updateColorRamp()}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new lo(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){this.colorRamp=mo(this._transitionablePaint._values[\"heatmap-color\"].value.expression,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(xa),yo={paint:new ya({\"hillshade-illumination-direction\":new pa(At.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new pa(At.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new pa(At.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new pa(At.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new pa(At.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new pa(At.paint_hillshade[\"hillshade-accent-color\"])})},xo=function(t){function e(e){t.call(this,e,yo)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(xa),bo=Ta([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,_o=To,wo=To;function To(t,e,r){r=r||2;var n,a,i,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=ko(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var a,i,o,s=[];for(a=0,i=e.length;a<i;a++)(o=ko(t,e[a]*n,a<i-1?e[a+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Do(o));for(s.sort(Po),a=0;a<s.length;a++)Io(s[a],r),r=Mo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=i=t[0],a=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<a&&(a=l),s>i&&(i=s),l>o&&(o=l);c=0!==(c=Math.max(i-n,o-a))?1/c:0}return Ao(f,p,r,n,a,c),p}function ko(t,e,r,n,a){var i,o;if(a===Zo(t,e,r,n)>0)for(i=e;i<r;i+=n)o=Go(i,t[i],t[i+1],o);else for(i=r-n;i>=e;i-=n)o=Go(i,t[i],t[i+1],o);return o&&No(o,o.next)&&(Yo(o),o=o.next),o}function Mo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!No(n,n.next)&&0!==Bo(n.prev,n,n.next))n=n.next;else{if(Yo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function Ao(t,e,r,n,a,i,o){if(t){!o&&i&&function(t,e,r,n){var a=t;do{null===a.z&&(a.z=Oo(a.x,a.y,e,r,n)),a.prevZ=a.prev,a.nextZ=a.next,a=a.next}while(a!==t);a.prevZ.nextZ=null,a.prevZ=null,function(t){var e,r,n,a,i,o,s,l,c=1;do{for(r=t,t=null,i=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(a=r,r=r.nextZ,s--):(a=n,n=n.nextZ,l--),i?i.nextZ=a:t=a,a.prevZ=i,i=a;r=n}i.nextZ=null,c*=2}while(o>1)}(a)}(t,n,a,i);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,i?Eo(t,n,a,i):So(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Yo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?Ao(t=Co(Mo(t),e,r),e,r,n,a,i,2):2===o&&Lo(t,e,r,n,a,i):Ao(Mo(t),e,r,n,a,i,1);break}}}function So(t){var e=t.prev,r=t,n=t.next;if(Bo(e,r,n)>=0)return!1;for(var a=t.next.next;a!==t.prev;){if(Ro(e.x,e.y,r.x,r.y,n.x,n.y,a.x,a.y)&&Bo(a.prev,a,a.next)>=0)return!1;a=a.next}return!0}function Eo(t,e,r,n){var a=t.prev,i=t,o=t.next;if(Bo(a,i,o)>=0)return!1;for(var s=a.x>i.x?a.x>o.x?a.x:o.x:i.x>o.x?i.x:o.x,l=a.y>i.y?a.y>o.y?a.y:o.y:i.y>o.y?i.y:o.y,c=Oo(a.x<i.x?a.x<o.x?a.x:o.x:i.x<o.x?i.x:o.x,a.y<i.y?a.y<o.y?a.y:o.y:i.y<o.y?i.y:o.y,e,r,n),u=Oo(s,l,e,r,n),h=t.prevZ,f=t.nextZ;h&&h.z>=c&&f&&f.z<=u;){if(h!==t.prev&&h!==t.next&&Ro(a.x,a.y,i.x,i.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;if(h=h.prevZ,f!==t.prev&&f!==t.next&&Ro(a.x,a.y,i.x,i.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;f=f.nextZ}for(;h&&h.z>=c;){if(h!==t.prev&&h!==t.next&&Ro(a.x,a.y,i.x,i.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.prevZ}for(;f&&f.z<=u;){if(f!==t.prev&&f!==t.next&&Ro(a.x,a.y,i.x,i.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;f=f.nextZ}return!0}function Co(t,e,r){var n=t;do{var a=n.prev,i=n.next.next;!No(a,i)&&jo(a,n,n.next,i)&&qo(a,i)&&qo(i,a)&&(e.push(a.i/r),e.push(n.i/r),e.push(i.i/r),Yo(n),Yo(n.next),n=t=i),n=n.next}while(n!==t);return Mo(n)}function Lo(t,e,r,n,a,i){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Fo(o,s)){var l=Ho(o,s);return o=Mo(o,o.next),l=Mo(l,l.next),Ao(o,e,r,n,a,i),void Ao(l,e,r,n,a,i)}s=s.next}o=o.next}while(o!==t)}function Po(t,e){return t.x-e.x}function Io(t,e){if(e=function(t,e){var r,n=e,a=t.x,i=t.y,o=-1/0;do{if(i<=n.y&&i>=n.next.y&&n.next.y!==n.y){var s=n.x+(i-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=a&&s>o){if(o=s,s===a){if(i===n.y)return n;if(i===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(a===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{a>=n.x&&n.x>=u&&a!==n.x&&Ro(i<h?a:o,i,u,h,i<h?o:a,i,n.x,n.y)&&(l=Math.abs(i-n.y)/(a-n.x),qo(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&zo(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=Ho(e,t);Mo(e,e.next),Mo(r,r.next)}}function zo(t,e){return Bo(t.prev,t,e.prev)<0&&Bo(e.next,t,t.next)<0}function Oo(t,e,r,n,a){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*a)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*a)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Do(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Ro(t,e,r,n,a,i,o,s){return(a-o)*(e-s)-(t-o)*(i-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(i-s)-(a-o)*(n-s)>=0}function Fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&jo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(qo(t,e)&&qo(e,t)&&function(t,e){var r=t,n=!1,a=(t.x+e.x)/2,i=(t.y+e.y)/2;do{r.y>i!=r.next.y>i&&r.next.y!==r.y&&a<(r.next.x-r.x)*(i-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(Bo(t.prev,t,e.prev)||Bo(t,e.prev,e))||No(t,e)&&Bo(t.prev,t,t.next)>0&&Bo(e.prev,e,e.next)>0)}function Bo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function No(t,e){return t.x===e.x&&t.y===e.y}function jo(t,e,r,n){var a=Vo(Bo(t,e,r)),i=Vo(Bo(t,e,n)),o=Vo(Bo(r,n,t)),s=Vo(Bo(r,n,e));return a!==i&&o!==s||!(0!==a||!Uo(t,r,e))||!(0!==i||!Uo(t,n,e))||!(0!==o||!Uo(r,t,n))||!(0!==s||!Uo(r,e,n))}function Uo(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function Vo(t){return t>0?1:t<0?-1:0}function qo(t,e){return Bo(t.prev,t,t.next)<0?Bo(t,e,t.next)>=0&&Bo(t,t.prev,e)>=0:Bo(t,e,t.prev)<0||Bo(t,t.next,e)<0}function Ho(t,e){var r=new Wo(t.i,t.x,t.y),n=new Wo(e.i,e.x,e.y),a=t.next,i=e.prev;return t.next=e,e.prev=t,r.next=a,a.prev=r,n.next=r,r.prev=n,i.next=n,n.prev=i,n}function Go(t,e,r,n){var a=new Wo(t,e,r);return n?(a.next=n.next,a.prev=n,n.next.prev=a,n.next=a):(a.prev=a,a.next=a),a}function Yo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function Wo(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Zo(t,e,r,n){for(var a=0,i=e,o=r-n;i<r;i+=n)a+=(t[o]-t[i])*(t[i+1]+t[o+1]),o=i;return a}function Xo(t,e,r,n,a){!function t(e,r,n,a,i){for(;a>n;){if(a-n>600){var o=a-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(a,Math.floor(r+(o-s)*c/o+u)),i)}var h=e[r],f=n,p=a;for(Jo(e,n,r),i(e[a],h)>0&&Jo(e,n,a);f<p;){for(Jo(e,f,p),f++,p--;i(e[f],h)<0;)f++;for(;i(e[p],h)>0;)p--}0===i(e[n],h)?Jo(e,n,p):Jo(e,++p,a),p<=r&&(n=p+1),r<=p&&(a=p-1)}}(t,e,r||0,n||t.length-1,a||Ko)}function Jo(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ko(t,e){return t<e?-1:t>e?1:0}function Qo(t,e){var r=t.length;if(r<=1)return[t];for(var n,a,i=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===a&&(a=s<0),a===s<0?(n&&i.push(n),n=[t[o]]):n.push(t[o]))}if(n&&i.push(n),e>1)for(var l=0;l<i.length;l++)i[l].length<=e||(Xo(i[l],e,1,i[l].length-1,$o),i[l]=i[l].slice(0,e));return i}function $o(t,e){return e.area-t.area}function ts(t,e,r){for(var n=r.patternDependencies,a=!1,i=0,o=e;i<o.length;i+=1){var s=o[i].paint.get(t+\"-pattern\");s.isConstant()||(a=!0);var l=s.constantOr(null);l&&(a=!0,n[l.to]=!0,n[l.from]=!0)}return a}function es(t,e,r,n,a){for(var i=a.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},a.availableImages),h=c.evaluate({zoom:n},r,{},a.availableImages),f=c.evaluate({zoom:n+1},r,{},a.availableImages);h=h&&h.name?h.name:h,f=f&&f.name?f.name:f,i[u=u&&u.name?u.name:u]=!0,i[h]=!0,i[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}To.deviation=function(t,e,r,n){var a=e&&e.length,i=Math.abs(Zo(t,0,a?e[0]*r:t.length,r));if(a)for(var o=0,s=e.length;o<s;o++)i-=Math.abs(Zo(t,e[o]*r,o<s-1?e[o+1]*r:t.length,r));var l=0;for(o=0;o<n.length;o+=3){var c=n[o]*r,u=n[o+1]*r,h=n[o+2]*r;l+=Math.abs((t[c]-t[h])*(t[u+1]-t[c+1])-(t[c]-t[u])*(t[h+1]-t[c+1]))}return 0===i&&0===l?0:Math.abs((l-i)/i)},To.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,a=0;a<t.length;a++){for(var i=0;i<t[a].length;i++)for(var o=0;o<e;o++)r.vertices.push(t[a][i][o]);a>0&&r.holes.push(n+=t[a-1].length)}return r},_o.default=wo;var rs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Ma,this.indexArray=new Fa,this.indexArray2=new qa,this.programConfigurations=new Pi(bo,t.layers,t.zoom),this.segments=new ai,this.segments2=new ai,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};rs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),a=[],i=0,o=t;i<o.length;i+=1){var s=o[i],l=s.feature,c=s.id,u=s.index,h=s.sourceLayerIndex,f=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:f?Di(l):[]};if(this.layers[0]._featureFilter.filter(new aa(this.zoom),p,r)){f||(p.geometry=Di(l));var d=n?n.evaluate(p,{},r,e.availableImages):void 0;a.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:h,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&a.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=a;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"fill\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},rs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},rs.prototype.addFeatures=function(t,e,r){for(var n=0,a=this.patternFeatures;n<a.length;n+=1){var i=a[n];this.addFeature(i,i.geometry,i.index,e,r)}},rs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},rs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},rs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,bo),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},rs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},rs.prototype.addFeature=function(t,e,r,n,a){for(var i=0,o=Qo(e,500);i<o.length;i+=1){for(var s=o[i],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var h=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),f=h.vertexLength,p=[],d=[],g=0,m=s;g<m.length;g+=1){var v=m[g];if(0!==v.length){v!==s[0]&&d.push(p.length/2);var y=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),x=y.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(x+v.length-1,x),p.push(v[0].x),p.push(v[0].y);for(var b=1;b<v.length;b++)this.layoutVertexArray.emplaceBack(v[b].x,v[b].y),this.indexArray2.emplaceBack(x+b-1,x+b),p.push(v[b].x),p.push(v[b].y);y.vertexLength+=v.length,y.primitiveLength+=v.length}}for(var _=_o(p,d),w=0;w<_.length;w+=3)this.indexArray.emplaceBack(f+_[w],f+_[w+1],f+_[w+2]);h.vertexLength+=l,h.primitiveLength+=_.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,a,n)},Dn(\"FillBucket\",rs,{omit:[\"layers\",\"patternFeatures\"]});var ns=new ya({\"fill-sort-key\":new da(At.layout_fill[\"fill-sort-key\"])}),as={paint:new ya({\"fill-antialias\":new pa(At.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new da(At.paint_fill[\"fill-opacity\"]),\"fill-color\":new da(At.paint_fill[\"fill-color\"]),\"fill-outline-color\":new da(At.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new pa(At.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new pa(At.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new ga(At.paint_fill[\"fill-pattern\"])}),layout:ns},is=function(t){function e(e){t.call(this,e,as)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new rs(t)},e.prototype.queryRadius=function(){return Ji(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,i,o){return ji(Ki(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),i.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(xa),os=Ta([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,ss=ls;function ls(t,e,r,n,a){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=a,t.readFields(cs,this,e)}function cs(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],a=e._values[t.readVarint()];e.properties[n]=a}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function us(t){for(var e,r,n=0,a=0,i=t.length,o=i-1;a<i;o=a++)n+=((r=t[o]).x-(e=t[a]).x)*(e.y+r.y);return n}ls.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ls.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,i=0,o=0,s=0,l=[];t.pos<r;){if(i<=0){var c=t.readVarint();n=7&c,i=c>>3}if(i--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new a(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},ls.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,a=0,i=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(a+=t.readSVarint())<o&&(o=a),a>s&&(s=a),(i+=t.readSVarint())<l&&(l=i),i>c&&(c=i);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},ls.prototype.toGeoJSON=function(t,e,r){var n,a,i=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=ls.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e];t[e]=[360*(r.x+o)/i-180,360/Math.PI*Math.atan(Math.exp((180-360*(r.y+s)/i)*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,a=[],i=0;i<e;i++){var o=us(t[i]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&a.push(r),r=[t[i]]):r.push(t[i]))}return r&&a.push(r),a}(l),n=0;n<l.length;n++)for(a=0;a<l[n].length;a++)u(l[n][a])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var hs=fs;function fs(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(ps,this,e),this.length=this._features.length}function ps(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function ds(t,e,r){if(3===t){var n=new hs(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}fs.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new ss(this._pbf,e,this.extent,this._keys,this._values)};var gs={VectorTile:function(t,e){this.layers=t.readFields(ds,{},e)},VectorTileFeature:ss,VectorTileLayer:hs},ms=gs.VectorTileFeature.types,vs=Math.pow(2,13);function ys(t,e,r,n,a,i,o,s){t.emplaceBack(e,r,2*Math.floor(n*vs)+o,a*vs*2,i*vs*2,Math.round(s))}var xs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Sa,this.indexArray=new Fa,this.programConfigurations=new Pi(os,t.layers,t.zoom),this.segments=new ai,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function bs(t,e){return t.x===e.x&&(t.x<0||t.x>8192)||t.y===e.y&&(t.y<0||t.y>8192)}xs.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=ts(\"fill-extrusion\",this.layers,e);for(var n=0,a=t;n<a.length;n+=1){var i=a[n],o=i.feature,s=i.id,l=i.index,c=i.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,h={type:o.type,id:s,properties:o.properties,geometry:u?Di(o):[]};if(this.layers[0]._featureFilter.filter(new aa(this.zoom),h,r)){var f={id:s,sourceLayerIndex:c,index:l,geometry:u?h.geometry:Di(o),properties:o.properties,type:o.type,patterns:{}};void 0!==o.id&&(f.id=o.id),this.hasPattern?this.features.push(es(\"fill-extrusion\",this.layers,f,this.zoom,e)):this.addFeature(f,f.geometry,l,r,{}),e.featureIndex.insert(o,f.geometry,l,c,this.index,!0)}}},xs.prototype.addFeatures=function(t,e,r){for(var n=0,a=this.features;n<a.length;n+=1){var i=a[n];this.addFeature(i,i.geometry,i.index,e,r)}},xs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},xs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},xs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},xs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,os),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},xs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},xs.prototype.addFeature=function(t,e,r,n,a){for(var i=0,o=Qo(e,500);i<o.length;i+=1){for(var s=o[i],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var h=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),f=0,p=s;f<p.length;f+=1){var d=p[f];if(0!==d.length&&!((I=d).every((function(t){return t.x<0}))||I.every((function(t){return t.x>8192}))||I.every((function(t){return t.y<0}))||I.every((function(t){return t.y>8192}))))for(var g=0,m=0;m<d.length;m++){var v=d[m];if(m>=1){var y=d[m-1];if(!bs(v,y)){h.vertexLength+4>ai.MAX_VERTEX_ARRAY_LENGTH&&(h=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=v.sub(y)._perp()._unit(),b=y.dist(v);g+b>32768&&(g=0),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,g),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,g),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,g+=b),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,g);var _=h.vertexLength;this.indexArray.emplaceBack(_,_+2,_+1),this.indexArray.emplaceBack(_+1,_+2,_+3),h.vertexLength+=4,h.primitiveLength+=2}}}}if(h.vertexLength+l>ai.MAX_VERTEX_ARRAY_LENGTH&&(h=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===ms[t.type]){for(var w=[],T=[],k=h.vertexLength,M=0,A=s;M<A.length;M+=1){var S=A[M];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var C=S[E];ys(this.layoutVertexArray,C.x,C.y,0,0,1,1,0),w.push(C.x),w.push(C.y)}}}for(var L=_o(w,T),P=0;P<L.length;P+=3)this.indexArray.emplaceBack(k+L[P],k+L[P+2],k+L[P+1]);h.primitiveLength+=L.length/3,h.vertexLength+=l}}var I;this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,a,n)},Dn(\"FillExtrusionBucket\",xs,{omit:[\"layers\",\"features\"]});var _s={paint:new ya({\"fill-extrusion-opacity\":new pa(At[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new da(At[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new pa(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new pa(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new ga(At[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new da(At[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new da(At[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new pa(At[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},ws=function(t){function e(e){t.call(this,e,_s)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new xs(t)},e.prototype.queryRadius=function(){return Ji(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s,l){var c=Ki(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var i=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];io(c,c,e),i.push(new a(c[0]/c[3],c[1]/c[3]))}return i}(c,l),p=function(t,e,r,n){for(var i=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,m=t;g<m.length;g+=1){for(var v=[],y=[],x=0,b=m[g];x<b.length;x+=1){var _=b[x],w=_.x,T=_.y,k=n[0]*w+n[4]*T+n[12],M=n[1]*w+n[5]*T+n[13],A=n[2]*w+n[6]*T+n[14],S=n[3]*w+n[7]*T+n[15],E=A+c,C=S+u,L=k+h,P=M+f,I=A+p,z=S+d,O=new a((k+s)/C,(M+l)/C);O.z=E/C,v.push(O);var D=new a(L/z,P/z);D.z=I/z,y.push(D)}i.push(v),o.push(y)}return[i,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ji(r,e)&&(n=ks(r,e[0]));for(var a=0;a<e.length;a++)for(var i=e[a],o=t[a],s=0;s<i.length-1;s++){var l=i[s],c=[l,i[s+1],o[s+1],o[s],l];Bi(r,c)&&(n=Math.min(n,ks(r,c)))}return n!==1/0&&n}(p[0],p[1],f)},e}(xa);function Ts(t,e){return t.x*e.x+t.y*e.y}function ks(t,e){if(1===t.length){for(var r,n=0,a=e[n++];!r||a.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var i=e[n],o=t[0],s=r.sub(a),l=i.sub(a),c=o.sub(a),u=Ts(s,s),h=Ts(s,l),f=Ts(l,l),p=Ts(c,s),d=Ts(c,l),g=u*f-h*h,m=(f*p-h*d)/g,v=(u*d-h*p)/g,y=a.z*(1-m-v)+r.z*m+i.z*v;if(isFinite(y))return y}return 1/0}for(var x=1/0,b=0,_=e;b<_.length;b+=1)x=Math.min(x,_[b].z);return x}var Ms=Ta([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,As=gs.VectorTileFeature.types,Ss=Math.cos(Math.PI/180*37.5),Es=Math.pow(2,14)/.5,Cs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Ea,this.indexArray=new Fa,this.programConfigurations=new Pi(Ms,t.layers,t.zoom),this.segments=new ai,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Cs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),a=[],i=0,o=t;i<o.length;i+=1){var s=o[i],l=s.feature,c=s.id,u=s.index,h=s.sourceLayerIndex,f=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:f?Di(l):[]};if(this.layers[0]._featureFilter.filter(new aa(this.zoom),p,r)){f||(p.geometry=Di(l));var d=n?n.evaluate(p,{},r):void 0;a.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:h,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&a.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=a;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"line\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},Cs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Cs.prototype.addFeatures=function(t,e,r){for(var n=0,a=this.patternFeatures;n<a.length;n+=1){var i=a[n];this.addFeature(i,i.geometry,i.index,e,r)}},Cs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Cs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Cs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ms),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Cs.prototype.addFeature=function(t,e,r,n,a){for(var i=this.layers[0].layout,o=i.get(\"line-join\").evaluate(t,{}),s=i.get(\"line-cap\"),l=i.get(\"line-miter-limit\"),c=i.get(\"line-round-limit\"),u=0,h=e;u<h.length;u+=1)this.addLine(h[u],t,o,s,l,c);this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,a,n)},Cs.prototype.addLine=function(t,e,r,n,a,i){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance()}for(var s=\"Polygon\"===As[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(a=1.05);var u,h=this.overscaling<=16?122880/(512*this.overscaling):0,f=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,g=void 0,m=void 0;this.e1=this.e2=-1,s&&(m=t[c].sub(u=t[l-2])._unit()._perp());for(var v=c;v<l;v++)if(!(d=v===l-1?s?t[c+1]:void 0:t[v+1])||!t[v].equals(d)){m&&(g=m),u&&(p=u),u=t[v],m=d?d.sub(u)._unit()._perp():g;var y=(g=g||m).add(m);0===y.x&&0===y.y||y._unit();var x=g.x*m.x+g.y*m.y,b=y.x*m.x+y.y*m.y,_=0!==b?1/b:1/0,w=2*Math.sqrt(2-2*b),T=b<Ss&&p&&d,k=g.x*m.y-g.y*m.x>0;if(T&&v>c){var M=u.dist(p);if(M>2*h){var A=u.sub(u.sub(p)._mult(h/M)._round());this.updateDistance(p,A),this.addCurrentVertex(A,g,0,0,f),p=A}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(_<i?E=\"miter\":_<=2&&(E=\"fakeround\")),\"miter\"===E&&_>a&&(E=\"bevel\"),\"bevel\"===E&&(_>2&&(E=\"flipbevel\"),_<a&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)y._mult(_),this.addCurrentVertex(u,y,0,0,f);else if(\"flipbevel\"===E){if(_>100)y=m.mult(-1);else{var C=_*g.add(m).mag()/g.sub(m).mag();y._perp()._mult(C*(k?-1:1))}this.addCurrentVertex(u,y,0,0,f),this.addCurrentVertex(u,y.mult(-1),0,0,f)}else if(\"bevel\"===E||\"fakeround\"===E){var L=-Math.sqrt(_*_-1),P=k?L:0,I=k?0:L;if(p&&this.addCurrentVertex(u,g,P,I,f),\"fakeround\"===E)for(var z=Math.round(180*w/Math.PI/20),O=1;O<z;O++){var D=O/z;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=m.sub(g)._mult(D)._add(g)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,f)}d&&this.addCurrentVertex(u,m,-P,-I,f)}else if(\"butt\"===E)this.addCurrentVertex(u,y,0,0,f);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,y,B,B,f)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,g,0,0,f),this.addCurrentVertex(u,g,1,1,f,!0)),d&&(this.addCurrentVertex(u,m,-1,-1,f,!0),this.addCurrentVertex(u,m,0,0,f)));if(T&&v<l-1){var N=u.dist(d);if(N>2*h){var j=u.add(d.sub(u)._mult(h/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,m,0,0,f),u=j}}}}},Cs.prototype.addCurrentVertex=function(t,e,r,n,a,i){void 0===i&&(i=!1);var o=e.y*n-e.x,s=-e.y-e.x*n;this.addHalfVertex(t,e.x+e.y*r,e.y-e.x*r,i,!1,r,a),this.addHalfVertex(t,o,s,i,!0,-n,a),this.distance>Es/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,a,i))},Cs.prototype.addHalfVertex=function(t,e,r,n,a,i,o){var s=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((t.x<<1)+(n?1:0),(t.y<<1)+(a?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===i?0:i<0?-1:1)|(63&s)<<2,s>>6);var l=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,l),o.primitiveLength++),a?this.e2=l:this.e1=l},Cs.prototype.updateScaledDistance=function(){this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Es-1):this.distance},Cs.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},Dn(\"LineBucket\",Cs,{omit:[\"layers\",\"patternFeatures\"]});var Ls=new ya({\"line-cap\":new pa(At.layout_line[\"line-cap\"]),\"line-join\":new da(At.layout_line[\"line-join\"]),\"line-miter-limit\":new pa(At.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new pa(At.layout_line[\"line-round-limit\"]),\"line-sort-key\":new da(At.layout_line[\"line-sort-key\"])}),Ps={paint:new ya({\"line-opacity\":new da(At.paint_line[\"line-opacity\"]),\"line-color\":new da(At.paint_line[\"line-color\"]),\"line-translate\":new pa(At.paint_line[\"line-translate\"]),\"line-translate-anchor\":new pa(At.paint_line[\"line-translate-anchor\"]),\"line-width\":new da(At.paint_line[\"line-width\"]),\"line-gap-width\":new da(At.paint_line[\"line-gap-width\"]),\"line-offset\":new da(At.paint_line[\"line-offset\"]),\"line-blur\":new da(At.paint_line[\"line-blur\"]),\"line-dasharray\":new ma(At.paint_line[\"line-dasharray\"]),\"line-pattern\":new ga(At.paint_line[\"line-pattern\"]),\"line-gradient\":new va(At.paint_line[\"line-gradient\"])}),layout:Ls},Is=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new aa(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,a){return r=u({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,a)},e}(da))(Ps.paint.properties[\"line-width\"].specification);Is.useIntegerZoom=!0;var zs=function(t){function e(e){t.call(this,e,Ps)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){this.gradient=mo(this._transitionablePaint._values[\"line-gradient\"].value.expression,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=Is.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new Cs(t)},e.prototype.queryRadius=function(t){var e=t,r=Os(Xi(\"line-width\",this,e),Xi(\"line-gap-width\",this,e)),n=Xi(\"line-offset\",this,e);return r/2+Math.abs(n)+Ji(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s){var l=Ki(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*Os(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new a(0,0),i=0;i<t.length;i++){for(var o=t[i],s=[],l=0;l<o.length;l++){var c=o[l],u=o[l+1],h=0===l?n:c.sub(o[l-1])._unit()._perp(),f=l===o.length-1?n:u.sub(c)._unit()._perp(),p=h._add(f)._unit();p._mult(1/(p.x*f.x+p.y*f.y)),s.push(p._mult(e)._add(c))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var a=e[n];if(t.length>=3)for(var i=0;i<a.length;i++)if(Wi(t,a[i]))return!0;if(Ui(t,a,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(xa);function Os(t,e){return e>0?e+2*t:t}var Ds=Ta([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Rs=Ta([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),Fs=(Ta([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Ta([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),Bs=(Ta([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),Ta([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ns=Ta([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function js(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),na.applyArabicShaping&&(t=na.applyArabicShaping(t)),t}(t.text,e,r)})),t}Ta([{name:\"triangle\",components:3,type:\"Uint16\"}]),Ta([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),Ta([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),Ta([{type:\"Float32\",name:\"offsetX\"}]),Ta([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var Us={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},Vs=function(t,e,r,n,a){var i,o,s=8*a-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?a-1:0,f=r?-1:1,p=t[e+h];for(h+=f,i=p&(1<<-u)-1,p>>=-u,u+=s;u>0;i=256*i+t[e+h],h+=f,u-=8);for(o=i&(1<<-u)-1,i>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===i)i=1-c;else{if(i===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),i-=c}return(p?-1:1)*o*Math.pow(2,i-n)},qs=function(t,e,r,n,a,i){var o,s,l,c=8*i-a-1,u=(1<<c)-1,h=u>>1,f=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,a),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,a),o=0));a>=8;t[r+p]=255&s,p+=d,s/=256,a-=8);for(o=o<<a|s,c+=a;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Hs=Gs;function Gs(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}Gs.Varint=0,Gs.Fixed64=1,Gs.Bytes=2,Gs.Fixed32=5;var Ys=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function Ws(t){return t.type===Gs.Bytes?t.readVarint()+t.pos:t.pos+1}function Zs(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Xs(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var a=r.pos-1;a>=t;a--)r.buf[a+n]=r.buf[a]}function Js(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Ks(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Qs(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function $s(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function tl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function el(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function rl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function nl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function il(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function ol(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function sl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}function ll(t,e,r){1===t&&r.readMessage(cl,e)}function cl(t,e,r){if(3===t){var n=r.readMessage(ul,{}),a=n.width,i=n.height,o=n.left,s=n.top,l=n.advance;e.push({id:n.id,bitmap:new fo({width:a+6,height:i+6},n.bitmap),metrics:{width:a,height:i,left:o,top:s,advance:l}})}}function ul(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}function hl(t){for(var e=0,r=0,n=0,a=t;n<a.length;n+=1){var i=a[n];e+=i.w*i.h,r=Math.max(r,i.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}Gs.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),a=n>>3,i=this.pos;this.type=7&n,t(a,e,this),this.pos===i&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=il(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=sl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=il(this.buf,this.pos)+4294967296*il(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=il(this.buf,this.pos)+4294967296*sl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Vs(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Vs(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,a,i=r.buf;if(n=(112&(a=i[r.pos++]))>>4,a<128)return Zs(t,n,e);if(n|=(127&(a=i[r.pos++]))<<3,a<128)return Zs(t,n,e);if(n|=(127&(a=i[r.pos++]))<<10,a<128)return Zs(t,n,e);if(n|=(127&(a=i[r.pos++]))<<17,a<128)return Zs(t,n,e);if(n|=(127&(a=i[r.pos++]))<<24,a<128)return Zs(t,n,e);if(n|=(1&(a=i[r.pos++]))<<31,a<128)return Zs(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Ys?function(t,e,r){return Ys.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",a=e;a<r;){var i,o,s,l=t[a],c=null,u=l>239?4:l>223?3:l>191?2:1;if(a+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(i=t[a+1]))&&(c=(31&l)<<6|63&i)<=127&&(c=null):3===u?(o=t[a+2],128==(192&(i=t[a+1]))&&128==(192&o)&&((c=(15&l)<<12|(63&i)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(o=t[a+2],s=t[a+3],128==(192&(i=t[a+1]))&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&i)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),a+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==Gs.Bytes)return t.push(this.readVarint(e));var r=Ws(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSVarint());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==Gs.Bytes)return t.push(this.readBoolean());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFloat());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==Gs.Bytes)return t.push(this.readDouble());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===Gs.Varint)for(;this.buf[this.pos++]>127;);else if(e===Gs.Bytes)this.pos=this.readVarint()+this.pos;else if(e===Gs.Fixed32)this.pos+=4;else{if(e!==Gs.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,r.buf[r.pos]=127&(t>>>=7)}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,a,i=0;i<e.length;i++){if((n=e.charCodeAt(i))>55295&&n<57344){if(!a){n>56319||i+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):a=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,a=n;continue}n=a-55296<<10|n-56320|65536,a=null}else a&&(t[r++]=239,t[r++]=191,t[r++]=189,a=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Xs(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),qs(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),qs(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Xs(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,Gs.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,Js,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Ks,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,tl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Qs,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,$s,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,el,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,rl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,nl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,al,e)},writeBytesField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var fl=function(t,e){var r=e.pixelRatio,n=e.version,a=e.stretchX,i=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=a,this.stretchY=i,this.content=o,this.version=n},pl={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};pl.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},pl.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},pl.tlbr.get=function(){return this.tl.concat(this.br)},pl.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(fl.prototype,pl);var dl=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var a=[];this.addImages(t,r,a),this.addImages(e,n,a);var i=hl(a),o=new po({width:i.w||1,height:i.h||1});for(var s in t){var l=t[s],c=r[s].paddedRect;po.copy(l.data,o,{x:0,y:0},{x:c.x+1,y:c.y+1},l.data)}for(var u in e){var h=e[u],f=n[u].paddedRect,p=f.x+1,d=f.y+1,g=h.data.width,m=h.data.height;po.copy(h.data,o,{x:0,y:0},{x:p,y:d},h.data),po.copy(h.data,o,{x:0,y:m-1},{x:p,y:d-1},{width:g,height:1}),po.copy(h.data,o,{x:0,y:0},{x:p,y:d+m},{width:g,height:1}),po.copy(h.data,o,{x:g-1,y:0},{x:p-1,y:d},{width:1,height:m}),po.copy(h.data,o,{x:0,y:0},{x:p+g,y:d},{width:1,height:m})}this.image=o,this.iconPositions=r,this.patternPositions=n};dl.prototype.addImages=function(t,e,r){for(var n in t){var a=t[n],i={x:0,y:0,w:a.data.width+2,h:a.data.height+2};r.push(i),e[n]=new fl(i,a),a.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},dl.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},dl.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl;r.update(e.data,void 0,{x:n[0],y:n[1]})}},Dn(\"ImagePosition\",fl),Dn(\"ImageAtlas\",dl);var gl={horizontal:1,vertical:2,horizontalOnly:3},ml=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};ml.forText=function(t,e){var r=new ml;return r.scale=t||1,r.fontStack=e,r},ml.forImage=function(t){var e=new ml;return e.imageName=t,e};var vl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function yl(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var m,v=vl.fromFeature(t,a);h===gl.vertical&&v.verticalizePunctuation();var y=na.processBidirectionalText,x=na.processStyledBidirectionalText;if(y&&1===v.sections.length){m=[];for(var b=0,_=y(v.toString(),Ml(v,c,i,e,n,p,d));b<_.length;b+=1){var w=_[b],T=new vl;T.text=w,T.sections=v.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);m.push(T)}}else if(x){m=[];for(var M=0,A=x(v.text,v.sectionIndex,Ml(v,c,i,e,n,p,d));M<A.length;M+=1){var S=A[M],E=new vl;E.text=S[0],E.sectionIndex=S[1],E.sections=v.sections,m.push(E)}}else m=function(t,e){for(var r=[],n=t.text,a=0,i=0,o=e;i<o.length;i+=1){var s=o[i];r.push(t.substring(a,s)),a=s}return a<n.length&&r.push(t.substring(a,n.length)),r}(v,Ml(v,c,i,e,n,p,d));var C=[],L={positionedLines:C,text:v.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:h,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,a,i,o,s,l,c,u,h){for(var f=0,p=-17,d=0,g=0,m=\"right\"===s?1:\"left\"===s?0:.5,v=0,y=0,x=a;y<x.length;y+=1){var b=x[y];b.trim();var _=b.getMaxScale(),w=24*(_-1),T={positionedGlyphs:[],lineOffset:0};t.positionedLines[v]=T;var k=T.positionedGlyphs,M=0;if(b.length()){for(var A=0;A<b.length();A++){var S=b.getSection(A),E=b.getSectionIndex(A),C=b.getCharCode(A),L=0,P=null,I=null,z=null,O=24,D=!(l===gl.horizontal||!u&&!Hn(C)||u&&(xl[C]||(H=C,Vn.Arabic(H)||Vn[\"Arabic Supplement\"](H)||Vn[\"Arabic Extended-A\"](H)||Vn[\"Arabic Presentation Forms-A\"](H)||Vn[\"Arabic Presentation Forms-B\"](H))));if(S.imageName){var R=n[S.imageName];if(!R)continue;z=S.imageName,t.iconsInText=t.iconsInText||!0,I=R.paddedRect;var F=R.displaySize;S.scale=24*S.scale/h,L=w+(24-F[1]*S.scale),O=(P={width:F[0],height:F[1],left:1,top:-3,advance:D?F[1]:F[0]}).advance;var B=D?F[0]*S.scale-24*_:F[1]*S.scale-24*_;B>0&&B>M&&(M=B)}else{var N=r[S.fontStack],j=N&&N[C];if(j&&j.rect)I=j.rect,P=j.metrics;else{var U=e[S.fontStack],V=U&&U[C];if(!V)continue;P=V.metrics}L=24*(_-S.scale)}D?(t.verticalizable=!0,k.push({glyph:C,imageName:z,x:f,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:P,rect:I}),f+=O*S.scale+c):(k.push({glyph:C,imageName:z,x:f,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:P,rect:I}),f+=P.advance*S.scale+c)}0!==k.length&&(d=Math.max(f-c,d),Sl(k,0,k.length-1,m,M)),f=0;var q=i*_+M;T.lineOffset=Math.max(M,w),p+=q,g=Math.max(q,g),++v}else p+=i,++v}var H,G=p- -17,Y=Al(o),W=Y.horizontalAlign,Z=Y.verticalAlign;(function(t,e,r,n,a,i,o,s,l){var c,u=(e-r)*a;c=i!==o?-s*n- -17:(-n*l+.5)*o;for(var h=0,f=t;h<f.length;h+=1)for(var p=0,d=f[h].positionedGlyphs;p<d.length;p+=1){var g=d[p];g.x+=u,g.y+=c}})(t.positionedLines,m,W,Z,d,g,i,G,a.length),t.top+=-Z*G,t.bottom=t.top+G,t.left+=-W*d,t.right=t.left+d}(L,e,r,n,m,o,s,l,h,c,f,g),!function(t){for(var e=0,r=t;e<r.length;e+=1)if(0!==r[e].positionedGlyphs.length)return!1;return!0}(C)&&L}vl.fromFeature=function(t,e){for(var r=new vl,n=0;n<t.sections.length;n++){var a=t.sections[n];a.image?r.addImageSection(a):r.addTextSection(a,e)}return r},vl.prototype.length=function(){return this.text.length},vl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},vl.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},vl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},vl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,a=t.charCodeAt(r-1)||null;e+=n&&Gn(n)&&!Us[t[r+1]]||a&&Gn(a)&&!Us[t[r-1]]||!Us[t[r]]?t[r]:Us[t[r]]}return e}(this.text)},vl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&xl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&xl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},vl.prototype.substring=function(t,e){var r=new vl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},vl.prototype.toString=function(){return this.text},vl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},vl.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(ml.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},vl.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(ml.forImage(e)),this.sectionIndex.push(this.sections.length-1)):_(\"Reached maximum number of images 6401\")}else _(\"Can't add FormattedSection with an empty image.\")},vl.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var xl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},bl={};function _l(t,e,r,n,a,i){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*24/i+a:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+a:0}function wl(t,e,r,n){var a=Math.pow(t-e,2);return n?t<e?a/2:2*a:a+Math.abs(r)*r}function Tl(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function kl(t,e,r,n,a,i){for(var o=null,s=wl(e,r,a,i),l=0,c=n;l<c.length;l+=1){var u=c[l],h=wl(e-u.x,r,a,i)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function Ml(t,e,r,n,a,i,o){if(\"point\"!==i)return[];if(!t)return[];for(var s,l=[],c=function(t,e,r,n,a,i){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=_l(t.getCharCode(s),l,n,a,e,i)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,a,o),u=t.text.indexOf(\"\\u200b\")>=0,h=0,f=0;f<t.length();f++){var p=t.getSection(f),d=t.getCharCode(f);if(xl[d]||(h+=_l(d,p,n,a,e,o)),f<t.length()-1){var g=!((s=d)<11904||!(Vn[\"Bopomofo Extended\"](s)||Vn.Bopomofo(s)||Vn[\"CJK Compatibility Forms\"](s)||Vn[\"CJK Compatibility Ideographs\"](s)||Vn[\"CJK Compatibility\"](s)||Vn[\"CJK Radicals Supplement\"](s)||Vn[\"CJK Strokes\"](s)||Vn[\"CJK Symbols and Punctuation\"](s)||Vn[\"CJK Unified Ideographs Extension A\"](s)||Vn[\"CJK Unified Ideographs\"](s)||Vn[\"Enclosed CJK Letters and Months\"](s)||Vn[\"Halfwidth and Fullwidth Forms\"](s)||Vn.Hiragana(s)||Vn[\"Ideographic Description Characters\"](s)||Vn[\"Kangxi Radicals\"](s)||Vn[\"Katakana Phonetic Extensions\"](s)||Vn.Katakana(s)||Vn[\"Vertical Forms\"](s)||Vn[\"Yi Radicals\"](s)||Vn[\"Yi Syllables\"](s)));(bl[d]||g||p.imageName)&&l.push(kl(f+1,h,c,l,Tl(d,t.getCharCode(f+1),g&&u),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(kl(t.length(),h,c,l,0,!0))}function Al(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Sl(t,e,r,n,a){if(n||a)for(var i=t[r],o=(t[r].x+i.metrics.advance*i.scale)*n,s=e;s<=r;s++)t[s].x-=o,t[s].y+=a}function El(t,e,r,n,a,i){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,h,f,p,d=e.left*i,g=e.right*i;\"width\"===r||\"both\"===r?(p=a[0]+d-n[3],h=a[0]+g+n[1]):h=(p=a[0]+(d+g-s.displaySize[0])/2)+s.displaySize[0];var m=e.top*i,v=e.bottom*i;return\"height\"===r||\"both\"===r?(u=a[1]+m-n[0],f=a[1]+v+n[2]):f=(u=a[1]+(m+v-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:h,bottom:f,left:p,collisionPadding:o}}bl[10]=!0,bl[32]=!0,bl[38]=!0,bl[40]=!0,bl[41]=!0,bl[43]=!0,bl[45]=!0,bl[47]=!0,bl[173]=!0,bl[183]=!0,bl[8203]=!0,bl[8208]=!0,bl[8211]=!0,bl[8231]=!0;var Cl=function(t){function e(e,r,n,a){t.call(this,e,r),this.angle=n,void 0!==a&&(this.segment=a)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(a);function Ll(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new aa(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,a=r.interpolationType,i=0;i<n.length&&n[i]<=t;)i++;for(var o=i=Math.max(0,i-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[i],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:a}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new aa(s)),maxSize:r.evaluate(new aa(l)),interpolationType:a}}function Pl(t,e,r){var n=e.uSize,a=r.lowerSize;return\"source\"===t.kind?a/128:\"composite\"===t.kind?Ue(a/128,r.upperSize/128,e.uSizeT):n}function Il(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var a=t.interpolationType,i=a?l(rr.interpolationFactor(a,e,t.minZoom,t.maxZoom),0,1):0;\"camera\"===t.kind?n=Ue(t.minSize,t.maxSize,i):r=i}return{uSizeT:r,uSize:n}}Dn(\"Anchor\",Cl);var zl=Object.freeze({__proto__:null,getSizeData:Ll,evaluateSizeForFeature:Pl,evaluateSizeForZoom:Il,SIZE_PACK_FACTOR:128});function Ol(t,e,r,n,a){if(void 0===e.segment)return!0;for(var i=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(i),i=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o],h=t[o+1];if(!h)return!1;var f=t[o-1].angleTo(u)-u.angleTo(h);for(f=Math.abs((f+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:f}),c+=f;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>a)return!1;o++,s+=u.dist(h)}return!0}function Dl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Rl(t,e,r){return t?.6*e*r:0}function Fl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Bl(t,e,r,n,a,i){for(var o=Rl(r,a,i),s=Fl(r,n)*i,l=0,c=Dl(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ue(h.x,f.x,d),m=Ue(h.y,f.y,d),v=new Cl(g,m,f.angleTo(h),u);return v._round(),!o||Ol(t,v,s,o,e)?v:void 0}l+=p}}function Nl(t,e,r,n,a,i,o,s,l){var c=Rl(n,i,o),u=Fl(n,a),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,a,i,o,s,l,c){for(var u=o/2,h=Dl(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var m=e[g],v=e[g+1],y=m.dist(v),x=v.angleTo(m);p+n<f+y;){var b=((p+=n)-f)/y,_=Ue(m.x,v.x,b),w=Ue(m.y,v.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var T=new Cl(_,w,x,g);T._round(),a&&!Ol(e,T,o,a,i)||d.push(T)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,a,i,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*i)*o*s%e,e,c,r,h,f,!1,l)}function jl(t,e,r,n,i){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<e&&f.x<e||(h.x<e?h=new a(e,h.y+(e-h.x)/(f.x-h.x)*(f.y-h.y))._round():f.x<e&&(f=new a(e,h.y+(e-h.x)/(f.x-h.x)*(f.y-h.y))._round()),h.y<r&&f.y<r||(h.y<r?h=new a(h.x+(r-h.y)/(f.y-h.y)*(f.x-h.x),r)._round():f.y<r&&(f=new a(h.x+(r-h.y)/(f.y-h.y)*(f.x-h.x),r)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new a(n,h.y+(n-h.x)/(f.x-h.x)*(f.y-h.y))._round():f.x>=n&&(f=new a(n,h.y+(n-h.x)/(f.x-h.x)*(f.y-h.y))._round()),h.y>=i&&f.y>=i||(h.y>=i?h=new a(h.x+(i-h.y)/(f.y-h.y)*(f.x-h.x),i)._round():f.y>=i&&(f=new a(h.x+(i-h.y)/(f.y-h.y)*(f.x-h.x),i)._round()),c&&h.equals(c[c.length-1])||o.push(c=[h]),c.push(f)))))}return o}function Ul(t,e,r,n){var i=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2,c=o.paddedRect.h-2,u=t.right-t.left,h=t.bottom-t.top,f=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},g=f.reduce(d,0),m=p.reduce(d,0),v=l-g,y=c-m,x=0,b=g,_=0,w=m,T=0,k=v,M=0,A=y;if(o.content&&n){var S=o.content;x=Vl(f,0,S[0]),_=Vl(p,0,S[1]),b=Vl(f,S[0],S[2]),w=Vl(p,S[1],S[3]),T=S[0]-x,M=S[1]-_,k=S[2]-S[0]-b,A=S[3]-S[1]-w}var E=function(n,i,l,c){var f=Hl(n.stretch-x,b,u,t.left),p=Gl(n.fixed-T,k,n.stretch,g),d=Hl(i.stretch-_,w,h,t.top),v=Gl(i.fixed-M,A,i.stretch,m),y=Hl(l.stretch-x,b,u,t.left),S=Gl(l.fixed-T,k,l.stretch,g),E=Hl(c.stretch-_,w,h,t.top),C=Gl(c.fixed-M,A,c.stretch,m),L=new a(f,d),P=new a(y,d),I=new a(y,E),z=new a(f,E),O=new a(p/s,v/s),D=new a(S/s,C/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];L._matMult(N),P._matMult(N),z._matMult(N),I._matMult(N)}var j=n.stretch+n.fixed,U=i.stretch+i.fixed;return{tl:L,tr:P,bl:z,br:I,tex:{x:o.paddedRect.x+1+j,y:o.paddedRect.y+1+U,w:l.stretch+l.fixed-j,h:c.stretch+c.fixed-U},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:O,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:A/s/h,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var C=ql(f,v,g),L=ql(p,y,m),P=0;P<C.length-1;P++)for(var I=C[P],z=C[P+1],O=0;O<L.length-1;O++)i.push(E(I,L[O],z,L[O+1]));else i.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return i}function Vl(t,e,r){for(var n=0,a=0,i=t;a<i.length;a+=1){var o=i[a];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function ql(t,e,r){for(var n=[{fixed:-1,stretch:0}],a=0,i=t;a<i.length;a+=1){var o=i[a],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+1,stretch:r}),n}function Hl(t,e,r,n){return t/e*r+n}function Gl(t,e,r,n){return t-e*r/n}var Yl=function(t,e,r,n,i,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var h=o.top,f=o.bottom,p=o.collisionPadding;p&&(h-=p[1],f+=p[3]);var d=f-h;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var g=o.top*s-l,m=o.bottom*s+l,v=o.left*s-l,y=o.right*s+l,x=o.collisionPadding;if(x&&(v-=x[0]*s,g-=x[1]*s,y+=x[2]*s,m+=x[3]*s),u){var b=new a(v,g),_=new a(y,g),w=new a(v,m),T=new a(y,m),k=u*Math.PI/180;b._rotate(k),_._rotate(k),w._rotate(k),T._rotate(k),v=Math.min(b.x,_.x,w.x,T.x),y=Math.max(b.x,_.x,w.x,T.x),g=Math.min(b.y,_.y,w.y,T.y),m=Math.max(b.y,_.y,w.y,T.y)}t.emplaceBack(e.x,e.y,v,g,y,m,r,n,i)}this.boxEndIndex=t.length},Wl=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=Zl),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function Zl(t,e){return t<e?-1:t>e?1:0}function Xl(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,i=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<i)&&(i=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=Math.min(o-n,s-i),f=h/2,p=new Wl([],Jl);if(0===h)return new a(n,i);for(var d=n;d<o;d+=h)for(var g=i;g<s;g+=h)p.push(new Kl(d+f,g+f,f,t));for(var m=function(t){for(var e=0,r=0,n=0,a=t[0],i=0,o=a.length,s=o-1;i<o;s=i++){var l=a[i],c=a[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new Kl(r/e,n/e,0,t)}(t),v=p.length;p.length;){var y=p.pop();(y.d>m.d||!m.d)&&(m=y,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*y.d)/1e4,v)),y.max-m.d<=e||(p.push(new Kl(y.p.x-(f=y.h/2),y.p.y-f,f,t)),p.push(new Kl(y.p.x+f,y.p.y-f,f,t)),p.push(new Kl(y.p.x-f,y.p.y+f,f,t)),p.push(new Kl(y.p.x+f,y.p.y+f,f,t)),v+=4)}return r&&(console.log(\"num probes: \"+v),console.log(\"best distance: \"+m.d)),m.p}function Jl(t,e){return e.max-t.max}function Kl(t,e,r,n){this.p=new a(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,a=0;a<e.length;a++)for(var i=e[a],o=0,s=i.length,l=s-1;o<s;l=o++){var c=i[o],u=i[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,Gi(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}Wl.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},Wl.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},Wl.prototype.peek=function(){return this.data[0]},Wl.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var a=t-1>>1,i=e[a];if(r(n,i)>=0)break;e[t]=i,t=a}e[t]=n},Wl.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,a=e[t];t<n;){var i=1+(t<<1),o=e[i],s=i+1;if(s<this.length&&r(e[s],o)<0&&(i=s,o=e[s]),r(o,a)>=0)break;e[t]=o,t=i}e[t]=a};var Ql=Number.POSITIVE_INFINITY;function $l(t,e){return e[1]!==Ql?function(t,e,r){var n=0,a=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":a=r-7;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":a=7-r}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,a]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var a=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=a-7;break;case\"bottom-right\":case\"bottom-left\":n=7-a;break;case\"bottom\":n=7-e;break;case\"top\":n=e-7}switch(t){case\"top-right\":case\"bottom-right\":r=-a;break;case\"top-left\":case\"bottom-left\":r=a;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function tc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function ec(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){var m=function(t,e,r,n,i,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],h=0,f=e.positionedLines;h<f.length;h+=1)for(var p=f[h],d=0,g=p.positionedGlyphs;d<g.length;d+=1){var m=g[d];if(m.rect){var v=m.rect||{},y=4,x=!0,b=1,_=0,w=(i||l)&&m.vertical,T=m.metrics.advance*m.scale/2;if(l&&e.verticalizable&&(_=p.lineOffset/2-(m.imageName?-(24-m.metrics.width*m.scale)/2:24*(m.scale-1))),m.imageName){var k=s[m.imageName];x=k.sdf,y=1/(b=k.pixelRatio)}var M=i?[m.x+T,m.y]:[0,0],A=i?[0,0]:[m.x+T+r[0],m.y+r[1]-_],S=[0,0];w&&(S=A,A=[0,0]);var E=(m.metrics.left-y)*m.scale-T+A[0],C=(-m.metrics.top-y)*m.scale+A[1],L=E+v.w*m.scale/b,P=C+v.h*m.scale/b,I=new a(E,C),z=new a(L,C),O=new a(E,P),D=new a(L,P);if(w){var R=new a(-T,T- -17),F=-Math.PI/2,B=12-T,N=new a(22-B,-(m.imageName?B:0)),j=new(Function.prototype.bind.apply(a,[null].concat(S)));I._rotateAround(F,R)._add(N)._add(j),z._rotateAround(F,R)._add(N)._add(j),O._rotateAround(F,R)._add(N)._add(j),D._rotateAround(F,R)._add(N)._add(j)}if(c){var U=Math.sin(c),V=Math.cos(c),q=[V,-U,U,V];I._matMult(q),z._matMult(q),O._matMult(q),D._matMult(q)}var H=new a(0,0),G=new a(0,0);u.push({tl:I,tr:z,bl:O,br:D,tex:v,writingMode:e.writingMode,glyphOffset:M,sectionIndex:m.sectionIndex,isSDF:x,pixelOffsetTL:H,pixelOffsetBR:G,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,i,o,s,n,t.allowVerticalPlacement),v=t.textSizeData,y=null;\"source\"===v.kind?(y=[128*i.layout.get(\"text-size\").evaluate(s,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'):\"composite\"===v.kind&&((y=[128*d.compositeTextSizes[0].evaluate(s,{},g),128*d.compositeTextSizes[1].evaluate(s,{},g)])[0]>32640||y[1]>32640)&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'),t.addSymbols(t.text,m,y,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,g);for(var x=0,b=h;x<b.length;x+=1)f[b[x]]=t.text.placedSymbolArray.length-1;return 4*m.length}function rc(t){for(var e in t)return t[e];return null}function nc(t,e,r,n){var a=t.compareText;if(e in a){for(var i=a[e],o=i.length-1;o>=0;o--)if(n.dist(i[o])<r)return!0}else a[e]=[];return a[e].push(n),!1}var ac=gs.VectorTileFeature.types,ic=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function oc(t,e,r,n,a,i,o,s,l,c,u,h,f){var p=s?Math.min(32640,Math.round(s[0])):0,d=s?Math.min(32640,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*a),i,o,(p<<1)+(l?1:0),d,16*c,16*u,256*h,256*f)}function sc(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function lc(t){for(var e=0,r=t.sections;e<r.length;e+=1)if(Zn(r[e].text))return!0;return!1}var cc=function(t){this.layoutVertexArray=new La,this.indexArray=new Fa,this.programConfigurations=t,this.segments=new ai,this.dynamicLayoutVertexArray=new Pa,this.opacityVertexArray=new Ia,this.placedSymbolArray=new Ja};cc.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},cc.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ds.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Rs.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,ic,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},cc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},Dn(\"SymbolBuffers\",cc);var uc=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new ai,this.collisionVertexArray=new Ra};uc.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,Fs.members,!0)},uc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},Dn(\"CollisionBuffers\",uc);var hc=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=eo([]),this.placementViewportMatrix=eo([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Ll(this.zoom,e[\"text-size\"]),this.iconSizeData=Ll(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),a=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==a&&void 0!==n.constantOr(1),this.sortFeaturesByY=(\"viewport-y\"===a||\"auto\"===a&&!this.sortFeaturesByKey)&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return gl[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};hc.prototype.createArrays=function(){this.text=new cc(new Pi(Ds.members,this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new cc(new Pi(Ds.members,this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new $a,this.lineVertexArray=new ti,this.symbolInstances=new Qa},hc.prototype.calculateGlyphDependencies=function(t,e,r,n,a){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,(r||n)&&a){var o=Us[t.charAt(i)];o&&(e[o.charCodeAt(0)]=!0)}},hc.prototype.populate=function(t,e,r){var n=this.layers[0],a=n.layout,i=a.get(\"text-font\"),o=a.get(\"text-field\"),s=a.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof te&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=a.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var h=e.iconDependencies,f=e.glyphDependencies,p=e.availableImages,d=new aa(this.zoom),g=0,m=t;g<m.length;g+=1){var v=m[g],y=v.feature,x=v.id,b=v.index,_=v.sourceLayerIndex,w=n._featureFilter.needGeometry,T={type:y.type,id:x,properties:y.properties,geometry:w?Di(y):[]};if(n._featureFilter.filter(d,T,r)){w||(T.geometry=Di(y));var k=void 0;if(l){var M=n.getValueAndResolveTokens(\"text-field\",T,r,p),A=te.factory(M);lc(A)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===ea()||this.hasRTLText&&na.isParsed())&&(k=js(A,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof ee?E:ee.fromString(E)}if(k||S){var C=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,L={id:x,text:k,icon:S,index:b,sourceLayerIndex:_,geometry:Di(y),properties:y.properties,type:ac[y.type],sortKey:C};if(this.features.push(L),S&&(h[S.name]=!0),k){var P=i.evaluate(T,{},r).join(\",\"),I=\"map\"===a.get(\"text-rotation-alignment\")&&\"point\"!==a.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(gl.vertical)>=0;for(var z=0,O=k.sections;z<O.length;z+=1){var D=O[z];if(D.image)h[D.image.name]=!0;else{var R=qn(k.toString()),F=D.fontStack||P,B=f[F]=f[F]||{};this.calculateGlyphDependencies(D.text,B,I,this.allowVerticalPlacement,R)}}}}}}\"line\"===a.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],a=0;function i(e){n.push(t[e]),a++}function o(t,e,a){var i=r[t];return delete r[t],r[e]=i,n[i].geometry[0].pop(),n[i].geometry[0]=n[i].geometry[0].concat(a[0]),i}function s(t,r,a){var i=e[r];return delete e[r],e[t]=i,n[i].geometry[0].shift(),n[i].geometry[0]=a[0].concat(n[i].geometry[0]),i}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),m=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[m].geometry,!0)]=m,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(i(c),e[p]=a-1,r[d]=a-1)}else i(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},hc.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},hc.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},hc.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},hc.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},hc.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},hc.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},hc.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),a=t.dist(e[t.segment]),i={},o=t.segment+1;o<e.length;o++)i[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)i[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:a},s>0&&(a+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=i[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},hc.prototype.addSymbols=function(t,e,r,n,a,i,o,s,l,c,u,h){for(var f=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,f,i.sortKey),g=this.glyphOffsetArray.length,m=d.vertexLength,v=this.allowVerticalPlacement&&o===gl.vertical?Math.PI/2:0,y=i.text&&i.text.sections,x=0;x<e.length;x++){var b=e[x],_=b.tl,w=b.tr,T=b.bl,k=b.br,M=b.tex,A=b.pixelOffsetTL,S=b.pixelOffsetBR,E=b.minFontScaleX,C=b.minFontScaleY,L=b.glyphOffset,P=b.isSDF,I=b.sectionIndex,z=d.vertexLength,O=L[1];oc(p,s.x,s.y,_.x,O+_.y,M.x,M.y,r,P,A.x,A.y,E,C),oc(p,s.x,s.y,w.x,O+w.y,M.x+M.w,M.y,r,P,S.x,A.y,E,C),oc(p,s.x,s.y,T.x,O+T.y,M.x,M.y+M.h,r,P,A.x,S.y,E,C),oc(p,s.x,s.y,k.x,O+k.y,M.x+M.w,M.y+M.h,r,P,S.x,S.y,E,C),sc(t.dynamicLayoutVertexArray,s,v),f.emplaceBack(z,z+1,z+2),f.emplaceBack(z+1,z+2,z+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(L[0]),x!==e.length-1&&I===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,i,i.index,{},h,y&&y[I])}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,m,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},hc.prototype._addCollisionDebugVertex=function(t,e,r,n,a,i){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,a,Math.round(i.x),Math.round(i.y))},hc.prototype.addCollisionDebugVertices=function(t,e,r,n,i,o,s){var l=i.segments.prepareSegment(4,i.layoutVertexArray,i.indexArray),c=l.vertexLength,u=i.layoutVertexArray,h=i.collisionVertexArray,f=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,h,o,f,p,new a(t,e)),this._addCollisionDebugVertex(u,h,o,f,p,new a(r,e)),this._addCollisionDebugVertex(u,h,o,f,p,new a(r,n)),this._addCollisionDebugVertex(u,h,o,f,p,new a(t,n)),l.vertexLength+=4;var d=i.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},hc.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var a=t;a<e;a++){var i=this.collisionBoxArray.get(a);this.addCollisionDebugVertices(i.x1,i.y1,i.x2,i.y2,n?this.textCollisionBox:this.iconCollisionBox,i.anchorPoint,r)}},hc.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new uc(Oa,Bs.members,qa),this.iconCollisionBox=new uc(Oa,Bs.members,qa);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},hc.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,a,i,o,s,l){for(var c={},u=e;u<r;u++){var h=t.get(u);c.textBox={x1:h.x1,y1:h.y1,x2:h.x2,y2:h.y2,anchorPointX:h.anchorPointX,anchorPointY:h.anchorPointY},c.textFeatureIndex=h.featureIndex;break}for(var f=n;f<a;f++){var p=t.get(f);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=i;d<o;d++){var g=t.get(d);c.iconBox={x1:g.x1,y1:g.y1,x2:g.x2,y2:g.y2,anchorPointX:g.anchorPointX,anchorPointY:g.anchorPointY},c.iconFeatureIndex=g.featureIndex;break}for(var m=s;m<l;m++){var v=t.get(m);c.verticalIconBox={x1:v.x1,y1:v.y1,x2:v.x2,y2:v.y2,anchorPointX:v.anchorPointX,anchorPointY:v.anchorPointY},c.verticalIconFeatureIndex=v.featureIndex;break}return c},hc.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},hc.prototype.hasTextData=function(){return this.text.segments.get().length>0},hc.prototype.hasIconData=function(){return this.icon.segments.get().length>0},hc.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},hc.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},hc.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},hc.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,a=r.vertexStartIndex;a<n;a+=4)t.indexArray.emplaceBack(a,a+1,a+2),t.indexArray.emplaceBack(a+1,a+2,a+3)},hc.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],a=[],i=[],o=0;o<this.symbolInstances.length;++o){i.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),a.push(s.featureIndex)}return i.sort((function(t,e){return n[t]-n[e]||a[e]-a[t]})),i},hc.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},hc.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var a=this.symbolInstances.get(n[r]);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,a.verticalPlacedTextSymbolIndex),a.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,a.placedIconSymbolIndex),a.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,a.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},Dn(\"SymbolBucket\",hc,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),hc.MAX_GLYPHS=65535,hc.addDynamicAttributes=sc;var fc=new ya({\"symbol-placement\":new pa(At.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new pa(At.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new pa(At.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new da(At.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new pa(At.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new pa(At.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new pa(At.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new pa(At.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new pa(At.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new da(At.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new pa(At.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new pa(At.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new da(At.layout_symbol[\"icon-image\"]),\"icon-rotate\":new da(At.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new pa(At.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new pa(At.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new da(At.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new da(At.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new pa(At.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new pa(At.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new pa(At.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new da(At.layout_symbol[\"text-field\"]),\"text-font\":new da(At.layout_symbol[\"text-font\"]),\"text-size\":new da(At.layout_symbol[\"text-size\"]),\"text-max-width\":new da(At.layout_symbol[\"text-max-width\"]),\"text-line-height\":new pa(At.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new da(At.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new da(At.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new da(At.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new pa(At.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new da(At.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new pa(At.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new pa(At.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new da(At.layout_symbol[\"text-rotate\"]),\"text-padding\":new pa(At.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new pa(At.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new da(At.layout_symbol[\"text-transform\"]),\"text-offset\":new da(At.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new pa(At.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new pa(At.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new pa(At.layout_symbol[\"text-optional\"])}),pc={paint:new ya({\"icon-opacity\":new da(At.paint_symbol[\"icon-opacity\"]),\"icon-color\":new da(At.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new da(At.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new da(At.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new da(At.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new pa(At.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new pa(At.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new da(At.paint_symbol[\"text-opacity\"]),\"text-color\":new da(At.paint_symbol[\"text-color\"],{runtimeType:Bt,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new da(At.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new da(At.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new da(At.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new pa(At.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new pa(At.paint_symbol[\"text-translate-anchor\"])}),layout:fc},dc=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Ot,this.defaultValue=t};dc.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},dc.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},dc.prototype.outputDefined=function(){return!1},dc.prototype.serialize=function(){return null},Dn(\"FormatSectionOverride\",dc,{omit:[\"defaultValue\"]});var gc=function(t){function e(e){t.call(this,e,pc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(this.layout._values[\"icon-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(this.layout._values[\"text-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var a=[],i=0,o=n;i<o.length;i+=1){var s=o[i];a.indexOf(s)<0&&a.push(s)}this.layout._values[\"text-writing-mode\"]=a}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var a=this.layout.get(t).evaluate(e,{},r,n),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Vr(i.value)||!a?a:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,a)},e.prototype.createBucket=function(t){return new hc(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=pc.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var a,i=this.paint.get(n),o=new dc(i),s=new Ur(o,i.property.specification);a=\"constant\"===i.value.kind||\"source\"===i.value.kind?new Hr(\"source\",s):new Gr(\"composite\",s,i.value.zoomStops,i.value._interpolationType),this.paint._values[n]=new ha(i.property,a,i.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=pc.paint.properties[e],a=!1,i=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n.overrides&&n.overrides.hasOverride(r[e]))return void(a=!0)};if(\"constant\"===r.value.kind&&r.value.value instanceof te)i(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){a||(t instanceof oe&&ae(t.value)===Vt?i(t.value.sections):t instanceof ue?i(t.sections):t.eachChild(o))},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return a},e}(xa),mc={paint:new ya({\"background-color\":new pa(At.paint_background[\"background-color\"]),\"background-pattern\":new ma(At.paint_background[\"background-pattern\"]),\"background-opacity\":new pa(At.paint_background[\"background-opacity\"])})},vc=function(t){function e(e){t.call(this,e,mc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xa),yc={paint:new ya({\"raster-opacity\":new pa(At.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new pa(At.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new pa(At.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new pa(At.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new pa(At.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new pa(At.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new pa(At.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new pa(At.paint_raster[\"raster-fade-duration\"])})},xc=function(t){function e(e){t.call(this,e,yc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xa),bc=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(xa),_c={circle:oo,heatmap:vo,hillshade:xo,fill:is,\"fill-extrusion\":ws,line:zs,symbol:gc,background:vc,raster:xc},wc=self.HTMLImageElement,Tc=self.HTMLCanvasElement,kc=self.HTMLVideoElement,Mc=self.ImageData,Ac=self.ImageBitmap,Sc=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Sc.prototype.update=function(t,e,r){var n=t.width,a=t.height,i=!(this.size&&this.size[0]===n&&this.size[1]===a||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),i)this.size=[n,a],t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,a,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,a,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Sc.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Sc.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Sc.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ec=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};Ec.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},Ec.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Cc=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},g([\"receive\",\"process\"],this),this.invoker=new Ec(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=k()?t:self};function Lc(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Cc.prototype.send=function(t,e,r,n,a){var i=this;void 0===a&&(a=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=S(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:a,sourceMapId:this.mapId,data:Nn(e,s)},s),{cancel:function(){r&&delete i.callbacks[o],i.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:i.mapId})}}},Cc.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else k()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Cc.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Cc.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(jn(e.error)):n(null,jn(e.data)))}else{var a=!1,i=S(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){a=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?Nn(e):null,data:Nn(n,i)},i)}:function(t){a=!0},s=null,l=jn(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!a&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Cc.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Pc=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Pc.prototype.setNorthEast=function(t){return this._ne=t instanceof Ic?new Ic(t.lng,t.lat):Ic.convert(t),this},Pc.prototype.setSouthWest=function(t){return this._sw=t instanceof Ic?new Ic(t.lng,t.lat):Ic.convert(t),this},Pc.prototype.extend=function(t){var e,r,n=this._sw,a=this._ne;if(t instanceof Ic)e=t,r=t;else{if(!(t instanceof Pc))return Array.isArray(t)?4===t.length||t.every(Array.isArray)?this.extend(Pc.convert(t)):this.extend(Ic.convert(t)):this;if(r=t._ne,!(e=t._sw)||!r)return this}return n||a?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),a.lng=Math.max(r.lng,a.lng),a.lat=Math.max(r.lat,a.lat)):(this._sw=new Ic(e.lng,e.lat),this._ne=new Ic(r.lng,r.lat)),this},Pc.prototype.getCenter=function(){return new Ic((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Pc.prototype.getSouthWest=function(){return this._sw},Pc.prototype.getNorthEast=function(){return this._ne},Pc.prototype.getNorthWest=function(){return new Ic(this.getWest(),this.getNorth())},Pc.prototype.getSouthEast=function(){return new Ic(this.getEast(),this.getSouth())},Pc.prototype.getWest=function(){return this._sw.lng},Pc.prototype.getSouth=function(){return this._sw.lat},Pc.prototype.getEast=function(){return this._ne.lng},Pc.prototype.getNorth=function(){return this._ne.lat},Pc.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Pc.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Pc.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Pc.prototype.contains=function(t){var e=Ic.convert(t),r=e.lng,n=e.lat,a=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(a=this._sw.lng>=r&&r>=this._ne.lng),this._sw.lat<=n&&n<=this._ne.lat&&a},Pc.convert=function(t){return!t||t instanceof Pc?t:new Pc(t)};var Ic=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Ic.prototype.wrap=function(){return new Ic(c(this.lng,-180,180),this.lat)},Ic.prototype.toArray=function(){return[this.lng,this.lat]},Ic.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Ic.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,a=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return 6371008.8*Math.acos(Math.min(a,1))},Ic.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Pc(new Ic(this.lng-r,this.lat-e),new Ic(this.lng+r,this.lat+e))},Ic.convert=function(t){if(t instanceof Ic)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Ic(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Ic(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var zc=2*Math.PI*6371008.8;function Oc(t){return zc*Math.cos(t*Math.PI/180)}function Dc(t){return(180+t)/360}function Rc(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Fc(t,e){return t/Oc(e)}function Bc(t){return 360/Math.PI*Math.atan(Math.exp((180-360*t)*Math.PI/180))-90}var Nc=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Nc.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Ic.convert(t);return new Nc(Dc(r.lng),Rc(r.lat),Fc(e,r.lat))},Nc.prototype.toLngLat=function(){return new Ic(360*this.x-180,Bc(this.y))},Nc.prototype.toAltitude=function(){return this.z*Oc(Bc(this.y))},Nc.prototype.meterInMercatorCoordinateUnits=function(){return 1/zc*(t=Bc(this.y),1/Math.cos(t*Math.PI/180));var t};var jc=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=qc(0,t,t,e,r)};jc.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},jc.prototype.url=function(t,e){var r,n,a,i,o,s=(n=this.y,a=this.z,i=Lc(256*(r=this.x),256*(n=Math.pow(2,a)-n-1),a),o=Lc(256*(r+1),256*(n+1),a),i[0]+\",\"+i[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,a=\"\",i=t;i>0;i--)a+=(e&(n=1<<i-1)?1:0)+(r&n?2:0);return a}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},jc.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new a(8192*(t.x*e-this.x),8192*(t.y*e-this.y))},jc.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var Uc=function(t,e){this.wrap=t,this.canonical=e,this.key=qc(t,e.z,e.z,e.x,e.y)},Vc=function(t,e,r,n,a){this.overscaledZ=t,this.wrap=e,this.canonical=new jc(r,+n,+a),this.key=qc(e,t,r,n,a)};function qc(t,e,r,n,a){(t*=2)<0&&(t=-1*t-1);var i=1<<r;return(i*i*t+i*a+n).toString(36)+r.toString(36)+e.toString(36)}Vc.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Vc.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Vc(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Vc(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Vc.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?qc(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):qc(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},Vc.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Vc.prototype.children=function(t){if(this.overscaledZ>=t)return[new Vc(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Vc(e,this.wrap,e,r,n),new Vc(e,this.wrap,e,r+1,n),new Vc(e,this.wrap,e,r,n+1),new Vc(e,this.wrap,e,r+1,n+1)]},Vc.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Vc.prototype.wrapped=function(){return new Vc(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.unwrapTo=function(t){return new Vc(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Vc.prototype.toUnwrapped=function(){return new Uc(this.wrap,this.canonical)},Vc.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},Vc.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Nc(t.x-this.wrap,t.y))},Dn(\"CanonicalTileID\",jc),Dn(\"OverscaledTileID\",Vc,{omit:[\"posMatrix\"]});var Hc=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return _('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var a=0;a<n;a++)this.data[this._idx(-1,a)]=this.data[this._idx(0,a)],this.data[this._idx(n,a)]=this.data[this._idx(n-1,a)],this.data[this._idx(a,-1)]=this.data[this._idx(a,0)],this.data[this._idx(a,n)]=this.data[this._idx(a,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};Hc.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},Hc.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},Hc.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Hc.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Hc.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Hc.prototype.getPixels=function(){return new po({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Hc.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,a=e*this.dim+this.dim,i=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=a-1;break;case 1:a=n+1}switch(r){case-1:i=o-1;break;case 1:o=i+1}for(var s=-e*this.dim,l=-r*this.dim,c=i;c<o;c++)for(var u=n;u<a;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},Dn(\"DEMData\",Hc);var Gc=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Gc.prototype.encode=function(t){return this._stringToNumber[t]},Gc.prototype.decode=function(t){return this._numberToString[t]};var Yc=function(t,e,r,n,a){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=a},Wc={geometry:{configurable:!0}};Wc.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Wc.geometry.set=function(t){this._geometry=t},Yc.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Yc.prototype,Wc);var Zc=function(){this.state={},this.stateChanges={},this.deletedStates={}};Zc.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},u(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var a in this.deletedStates[t]={},this.state[t])a!==n&&(this.deletedStates[t][a]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var i in this.deletedStates[t][n]={},this.state[t][n])r[i]||(this.deletedStates[t][n][i]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},Zc.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},Zc.prototype.getState=function(t,e){var r=String(e),n=u({},(this.state[t]||{})[r],(this.stateChanges[t]||{})[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var a=this.deletedStates[t][e];if(null===a)return{};for(var i in a)delete n[i]}return n},Zc.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},Zc.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var a={};for(var i in this.stateChanges[n])this.state[n][i]||(this.state[n][i]={}),u(this.state[n][i],this.stateChanges[n][i]),a[i]=this.state[n][i];r[n]=a}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var h=0,f=Object.keys(this.deletedStates[o][c]);h<f.length;h+=1)delete this.state[o][c][f[h]];s[c]=this.state[o][c]}r[o]=r[o]||{},u(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var p in t)t[p].setFeatureState(r,e)};var Xc=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new Ln(8192,16,0),this.grid3D=new Ln(8192,16,0),this.featureIndexArray=new ri,this.promoteId=e};function Jc(t,e,r,n,a){return v(t,(function(t,i){var o=e instanceof fa?e.get(i):null;return o&&o.evaluate?o.evaluate(r,n,a):o}))}function Kc(t){for(var e=1/0,r=1/0,n=-1/0,a=-1/0,i=0,o=t;i<o.length;i+=1){var s=o[i];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),a=Math.max(a,s.y)}return{minX:e,minY:r,maxX:n,maxY:a}}function Qc(t,e){return e-t}Xc.prototype.insert=function(t,e,r,n,a,i){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,a);for(var s=i?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<8192&&u[1]<8192&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Xc.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new gs.VectorTile(new Hs(this.rawTileData)).layers,this.sourceLayerCoder=new Gc(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Xc.prototype.query=function(t,e,r,n){var i=this;this.loadVTLayers();for(var o=t.params||{},s=8192/t.tileSize/t.scale,l=rn(o.filter),c=t.queryGeometry,u=t.queryPadding*s,h=Kc(c),f=this.grid.query(h.minX-u,h.minY-u,h.maxX+u,h.maxY+u),p=Kc(t.cameraQueryGeometry),d=0,g=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,i){return function(t,e,r,n,i){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&i>=l.y)return!0}var c=[new a(e,r),new a(e,i),new a(n,i),new a(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Wi(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Zi(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,i+u)}));d<g.length;d+=1)f.push(g[d]);f.sort(Qc);for(var m,v={},y=function(a){var u=f[a];if(u!==m){m=u;var h=i.featureIndexArray.get(u),p=null;i.loadMatchingFeature(v,h.bucketIndex,h.sourceLayerIndex,h.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=Di(e)),r.queryIntersectsFeature(c,e,n,p,i.z,t.transform,s,t.pixelPosMatrix)}))}},x=0;x<f.length;x++)y(x);return v},Xc.prototype.loadMatchingFeature=function(t,e,r,n,a,i,o,s,l,c,u){var h=this.bucketLayerIDs[e];if(!i||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(i,h)){var f=this.sourceLayerCoder.decode(r),p=this.vtLayers[f].feature(n);if(a.filter(new aa(this.tileID.overscaledZ),p))for(var d=this.getId(p,f),g=0;g<h.length;g++){var m=h[g];if(!(i&&i.indexOf(m)<0)){var v=s[m];if(v){var y={};void 0!==d&&c&&(y=c.getState(v.sourceLayer||\"_geojsonTileLayer\",d));var x=l[m];x.paint=Jc(x.paint,v.paint,p,y,o),x.layout=Jc(x.layout,v.layout,p,y,o);var b=!u||u(p,v,y);if(b){var _=new Yc(p,this.z,this.x,this.y,d);_.layer=x;var w=t[m];void 0===w&&(w=t[m]=[]),w.push({featureIndex:n,feature:_,intersectionZ:b})}}}}}},Xc.prototype.lookupSymbolFeatures=function(t,e,r,n,a,i,o,s){var l={};this.loadVTLayers();for(var c=rn(a),u=0,h=t;u<h.length;u+=1)this.loadMatchingFeature(l,r,n,h[u],c,i,o,s,e);return l},Xc.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,a=r[e];n<a.length;n+=1)if(t===a[n])return!0;return!1},Xc.prototype.getId=function(t,e){var r=t.id;return this.promoteId&&\"boolean\"==typeof(r=t.properties[\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e]])&&(r=Number(r)),r},Dn(\"FeatureIndex\",Xc,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var $c=function(t,e){this.tileID=t,this.uid=f(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};$c.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<R.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},$c.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},$c.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=i[a],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1)r[s[o].id]=t}},a=0,i=t;a<i.length;a+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var a=this.buckets[n];if(a instanceof hc){if(this.hasSymbolBuckets=!0,!r)break;a.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var i in this.buckets){var o=this.buckets[i];if(o instanceof hc&&o.hasRTLText){this.hasRTLText=!0,na.isLoading()||na.isLoaded()||\"deferred\"!==ea()||ra();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Za},$c.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},$c.prototype.getBucket=function(t){return this.buckets[t.id]},$c.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Sc(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Sc(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},$c.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},$c.prototype.queryRenderedFeatures=function(t,e,r,n,a,i,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:a,scale:i,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},$c.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),a=e?e.sourceLayer:\"\",i=n._geojsonTileLayer||n[a];if(i)for(var o=rn(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,h={z:l,x:c,y:u},f=0;f<i.length;f++){var p=i.feature(f);if(o.filter(new aa(this.tileID.overscaledZ),p)){var d=r.getId(p,a),g=new Yc(p,l,c,u,d);g.tile=h,t.push(g)}}}},$c.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},$c.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},$c.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),a=!1;if(this.expirationTime>n)a=!1;else if(e)if(this.expirationTime<e)a=!0;else{var i=this.expirationTime-e;i?this.expirationTime=n+Math.max(i,3e4):a=!0}else a=!0;a?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},$c.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},$c.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var a=this.buckets[n],i=a.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[i],s=t[i];if(o&&s&&0!==Object.keys(s).length){a.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(a)))}}}},$c.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},$c.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<R.now()},$c.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},$c.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=R.now()+t},$c.prototype.setDependencies=function(t,e){for(var r={},n=0,a=e;n<a.length;n+=1)r[a[n]]=!0;this.dependencies[t]=r},$c.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var a=this.dependencies[n[r]];if(a)for(var i=0,o=e;i<o.length;i+=1)if(a[o[i]])return!0}return!1};var tu=self.performance,eu=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},tu.mark(this._marks.start)};eu.prototype.finish=function(){tu.mark(this._marks.end);var t=tu.getEntriesByName(this._marks.measure);return 0===t.length&&(tu.measure(this._marks.measure,this._marks.start,this._marks.end),t=tu.getEntriesByName(this._marks.measure),tu.clearMarks(this._marks.start),tu.clearMarks(this._marks.end),tu.clearMeasures(this._marks.measure)),t},t.Actor=Cc,t.AlphaImage=fo,t.CanonicalTileID=jc,t.CollisionBoxArray=Za,t.Color=Kt,t.DEMData=Hc,t.DataConstantProperty=pa,t.DictionaryCoder=Gc,t.EXTENT=8192,t.ErrorEvent=kt,t.EvaluationParameters=aa,t.Event=Tt,t.Evented=Mt,t.FeatureIndex=Xc,t.FillBucket=rs,t.FillExtrusionBucket=xs,t.ImageAtlas=dl,t.ImagePosition=fl,t.LineBucket=Cs,t.LngLat=Ic,t.LngLatBounds=Pc,t.MercatorCoordinate=Nc,t.ONE_EM=24,t.OverscaledTileID=Vc,t.Point=a,t.Point$1=a,t.Properties=ya,t.Protobuf=Hs,t.RGBAImage=po,t.RequestManager=q,t.RequestPerformance=eu,t.ResourceType=ft,t.SegmentVector=ai,t.SourceFeatureState=Zc,t.StructArrayLayout1ui2=Ha,t.StructArrayLayout2f1f2i16=Da,t.StructArrayLayout2i4=Ma,t.StructArrayLayout3ui6=Fa,t.StructArrayLayout4i8=Aa,t.SymbolBucket=hc,t.Texture=Sc,t.Tile=$c,t.Transitionable=sa,t.Uniform1f=vi,t.Uniform1i=mi,t.Uniform2f=yi,t.Uniform3f=xi,t.Uniform4f=bi,t.UniformColor=_i,t.UniformMatrix4f=Ti,t.UnwrappedTileID=Uc,t.ValidationError=St,t.WritingMode=gl,t.ZoomHistory=Un,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=sc,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,a=new Array(t.length),i=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(i=t),a[o]=e,0==--n&&r(i,a)}))}))},t.bezier=o,t.bindAll=g,t.browser=R,t.cacheEntryPossiblyAdded=function(t){++ut>ot&&(t.getActor().send(\"enforceCacheSizeLimit\",it),ut=0)},t.clamp=l,t.clearTileCache=function(t){var e=self.caches.delete(\"mapbox-tiles\");t&&e.catch(t).then((function(){return t()}))},t.clipLine=jl,t.clone=function(t){var e=new to(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=x,t.clone$2=function(t){var e=new to(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=Ns,t.config=F,t.create=function(){var t=new to(16);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new to(9);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new to(4);return to!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=qr,t.createLayout=Ta,t.createStyleLayer=function(t){return\"custom\"===t.type?new bc(t):new _c[t.type](t)},t.cross=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2];return t[0]=a*l-i*s,t[1]=i*o-n*l,t[2]=n*s-a*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var a in e)if(!t(e[a],r[a]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=s,t.emitValidationErrors=Cn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){st(),Q&&Q.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Pl,t.evaluateSizeForZoom=Il,t.evaluateVariableOffset=$l,t.evented=ta,t.extend=u,t.featureFilter=rn,t.filterObject=y,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=Al,t.getAnchorJustification=tc,t.getArrayBuffer=yt,t.getImage=bt,t.getJSON=function(t,e){return vt(u(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=ea,t.getReferrer=mt,t.getVideo=function(t,e){var r,n,a=self.document.createElement(\"video\");a.muted=!0,a.onloadstart=function(){e(null,a)};for(var i=0;i<t.length;i++){var o=self.document.createElement(\"source\");r=t[i],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(a.crossOrigin=\"Anonymous\"),o.src=t[i],a.appendChild(o)}return{cancel:function(){}}},t.identity=eo,t.invert=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-a*o,b=r*c-i*o,_=n*l-a*s,w=n*c-i*s,T=a*c-i*l,k=u*g-h*d,M=u*m-f*d,A=u*v-p*d,S=h*m-f*g,E=h*v-p*g,C=f*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;return L?(t[0]=(s*C-l*E+c*S)*(L=1/L),t[1]=(a*E-n*C-i*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(f*w-h*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-a*A+i*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-f*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-i*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+a*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=Vn,t.isMapboxURL=H,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=vt,t.mapObject=v,t.mercatorXfromLng=Dc,t.mercatorYfromLat=Rc,t.mercatorZfromAltitude=Fc,t.mul=ao,t.multiply=ro,t.mvt=gs,t.normalize=function(t,e){var r=e[0],n=e[1],a=e[2],i=r*r+n*n+a*a;return i>0&&(i=1/Math.sqrt(i)),t[0]=e[0]*i,t[1]=e[1]*i,t[2]=e[2]*i,t},t.number=Ue,t.offscreenCanvasSupported=ht,t.ortho=function(t,e,r,n,a,i,o){var s=1/(e-r),l=1/(n-a),c=1/(i-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(a+n)*l,t[14]=(o+i)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Hs(t).readFields(ll,[])},t.pbf=Hs,t.performSymbolLayout=function(t,e,r,n,a,i,o){t.createArrays(),t.tilePixelRatio=8192/(512*t.overscaling),t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new aa(u.minZoom),o),l[\"text-size\"].possiblyEvaluate(new aa(h),o)]}if(\"composite\"===t.iconSizeData.kind){var f=t.iconSizeData,p=f.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new aa(f.minZoom),o),l[\"icon-size\"].possiblyEvaluate(new aa(p),o)]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new aa(t.zoom+1),o),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new aa(t.zoom+1),o),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new aa(18));for(var d=24*s.get(\"text-line-height\"),g=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),m=s.get(\"text-keep-upright\"),v=s.get(\"text-size\"),y=function(){var i=b[x],l=s.get(\"text-font\").evaluate(i,{},o).join(\",\"),u=v.evaluate(i,{},o),h=c.layoutTextSize.evaluate(i,{},o),f=c.layoutIconSize.evaluate(i,{},o),p={horizontal:{},vertical:void 0},y=i.text,w=[0,0];if(y){var T=y.toString(),k=24*s.get(\"text-letter-spacing\").evaluate(i,{},o),M=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n=r[e].charCodeAt(0),Vn.Arabic(n)||Vn[\"Arabic Supplement\"](n)||Vn[\"Arabic Extended-A\"](n)||Vn[\"Arabic Presentation Forms-A\"](n)||Vn[\"Arabic Presentation Forms-B\"](n))return!1;var n;return!0}(T)?k:0,A=s.get(\"text-anchor\").evaluate(i,{},o),S=s.get(\"text-variable-anchor\");if(!S){var E=s.get(\"text-radial-offset\").evaluate(i,{},o);w=E?$l(A,[24*E,Ql]):s.get(\"text-offset\").evaluate(i,{},o).map((function(t){return 24*t}))}var C=g?\"center\":s.get(\"text-justify\").evaluate(i,{},o),L=s.get(\"symbol-placement\"),P=\"point\"===L?24*s.get(\"text-max-width\").evaluate(i,{},o):0,I=function(){t.allowVerticalPlacement&&qn(T)&&(p.vertical=yl(y,e,r,a,l,P,d,A,\"left\",M,w,gl.vertical,!0,L,h,u))};if(!g&&S){for(var z=\"auto\"===C?S.map((function(t){return tc(t)})):[C],O=!1,D=0;D<z.length;D++){var R=z[D];if(!p.horizontal[R])if(O)p.horizontal[R]=p.horizontal[0];else{var F=yl(y,e,r,a,l,P,d,\"center\",R,M,w,gl.horizontal,!1,L,h,u);F&&(p.horizontal[R]=F,O=1===F.positionedLines.length)}}I()}else{\"auto\"===C&&(C=tc(A));var B=yl(y,e,r,a,l,P,d,A,C,M,w,gl.horizontal,!1,L,h,u);B&&(p.horizontal[C]=B),I(),qn(T)&&g&&m&&(p.vertical=yl(y,e,r,a,l,P,d,A,C,M,w,gl.vertical,!1,L,h,u))}}var N=void 0,j=!1;if(i.icon&&i.icon.name){var U=n[i.icon.name];U&&(N=function(t,e,r){var n=Al(r),a=e[0]-t.displaySize[0]*n.horizontalAlign,i=e[1]-t.displaySize[1]*n.verticalAlign;return{image:t,top:i,bottom:i+t.displaySize[1],left:a,right:a+t.displaySize[0]}}(a[i.icon.name],s.get(\"icon-offset\").evaluate(i,{},o),s.get(\"icon-anchor\").evaluate(i,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&_(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==s.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=rc(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,a,i,o,s,l,c,u){var h=i.textMaxSize.evaluate(e,{});void 0===h&&(h=o);var f,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),g=rc(r.horizontal),m=o/24,v=t.tilePixelRatio*m,y=t.tilePixelRatio*h/24,x=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,k=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),A=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=b/2,C=p.get(\"icon-text-fit\");n&&\"none\"!==C&&(t.allowVerticalPlacement&&r.vertical&&(f=El(n,r.vertical,C,p.get(\"icon-text-fit-padding\"),d,m)),g&&(n=El(n,g,C,p.get(\"icon-text-fit-padding\"),d,m)));var L=function(s,h){h.x<0||h.x>=8192||h.y<0||h.y>=8192||function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,m,v,y,x,b,w,T,k,M){var A,S,E,C,L,P=t.addToLineVertexArray(e,r),I=0,z=0,O=0,D=0,R=-1,F=-1,B={},N=ci(\"\"),j=0,U=0;if(void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(j=(A=s.layout.get(\"text-offset\").evaluate(b,{},k).map((function(t){return 24*t})))[0],U=A[1]):(j=24*s.layout.get(\"text-radial-offset\").evaluate(b,{},k),U=Ql),t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(b,{},k)+90;C=new Yl(l,e,c,u,h,n.vertical,f,p,d,V),o&&(L=new Yl(l,e,c,u,h,o,m,v,d,V))}if(a){var q=s.layout.get(\"icon-rotate\").evaluate(b,{}),H=\"none\"!==s.layout.get(\"icon-text-fit\"),G=Ul(a,q,T,H),Y=o?Ul(o,q,T,H):void 0;E=new Yl(l,e,c,u,h,a,m,v,!1,q),I=4*G.length;var W=t.iconSizeData,Z=null;\"source\"===W.kind?(Z=[128*s.layout.get(\"icon-size\").evaluate(b,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'):\"composite\"===W.kind&&((Z=[128*w.compositeIconSizes[0].evaluate(b,{},k),128*w.compositeIconSizes[1].evaluate(b,{},k)])[0]>32640||Z[1]>32640)&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'),t.addSymbols(t.icon,G,Z,x,y,b,!1,e,P.lineStartIndex,P.lineLength,-1,k),R=t.icon.placedSymbolArray.length-1,Y&&(z=4*Y.length,t.addSymbols(t.icon,Y,Z,x,y,b,gl.vertical,e,P.lineStartIndex,P.lineLength,-1,k),F=t.icon.placedSymbolArray.length-1)}for(var X in n.horizontal){var J=n.horizontal[X];if(!S){N=ci(J.text);var K=s.layout.get(\"text-rotate\").evaluate(b,{},k);S=new Yl(l,e,c,u,h,J,f,p,d,K)}var Q=1===J.positionedLines.length;if(O+=ec(t,e,J,i,s,d,b,g,P,n.vertical?gl.horizontal:gl.horizontalOnly,Q?Object.keys(n.horizontal):[X],B,R,w,k),Q)break}n.vertical&&(D+=ec(t,e,n.vertical,i,s,d,b,g,P,gl.vertical,[\"vertical\"],B,F,w,k));var $=S?S.boxStartIndex:t.collisionBoxArray.length,tt=S?S.boxEndIndex:t.collisionBoxArray.length,et=C?C.boxStartIndex:t.collisionBoxArray.length,rt=C?C.boxEndIndex:t.collisionBoxArray.length,nt=E?E.boxStartIndex:t.collisionBoxArray.length,at=E?E.boxEndIndex:t.collisionBoxArray.length,it=L?L.boxStartIndex:t.collisionBoxArray.length,ot=L?L.boxEndIndex:t.collisionBoxArray.length,st=-1,lt=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};st=lt(S,st),st=lt(C,st),st=lt(E,st);var ct=(st=lt(L,st))>-1?1:0;ct&&(st*=M/24),t.glyphOffsetArray.length>=hc.MAX_GLYPHS&&_(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==b.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,b.sortKey),t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,$,tt,et,rt,nt,at,it,ot,c,O,D,I,z,ct,0,f,j,U,st)}(t,h,s,r,n,a,f,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,x,T,A,d,e,i,c,u,o)};if(\"line\"===S)for(var P=0,I=jl(e.geometry,0,0,8192,8192);P<I.length;P+=1)for(var z=I[P],O=0,D=Nl(z,b,k,r.vertical||g,n,24,y,t.overscaling,8192);O<D.length;O+=1){var R=D[O];g&&nc(t,g.text,E,R)||L(z,R)}else if(\"line-center\"===S)for(var F=0,B=e.geometry;F<B.length;F+=1){var N=B[F];if(N.length>1){var j=Bl(N,k,r.vertical||g,n,24,y);j&&L(N,j)}}else if(\"Polygon\"===e.type)for(var U=0,V=Qo(e.geometry,0);U<V.length;U+=1){var q=V[U],H=Xl(q,16);L(q[0],new Cl(H.x,H.y,0))}else if(\"LineString\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1){var W=Y[G];L(W,new Cl(W[0].x,W[0].y,0))}else if(\"Point\"===e.type)for(var Z=0,X=e.geometry;Z<X.length;Z+=1)for(var J=0,K=X[Z];J<K.length;J+=1){var Q=K[J];L([Q],new Cl(Q.x,Q.y,0))}}(t,i,p,N,n,c,h,f,w,j,o)},x=0,b=t.features;x<b.length;x+=1)y();i&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,a){var i,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=a&&a!==1/0?(t[10]=(a+n)*(i=1/(n-a)),t[14]=2*a*n*i):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var a=e[n];a in t&&(r[a]=t[a])}return r},t.plugin=na,t.polygonIntersectsPolygon=Bi,t.postMapLoadEvent=at,t.postTurnstileEvent=rt,t.potpack=hl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=Dn,t.registerForPluginStateChange=function(t){return t({pluginStatus:Jn,pluginURL:Kn}),ta.on(\"pluginStateChange\",t),t},t.rotate=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+i*s,t[1]=a*l+o*s,t[2]=n*-s+i*l,t[3]=a*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=i*a+c*n,t[5]=o*a+u*n,t[6]=s*a+h*n,t[7]=l*a+f*n,t[8]=c*a-i*n,t[9]=u*a-o*n,t[10]=h*a-s*n,t[11]=f*a-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=i*a+c*n,t[1]=o*a+u*n,t[2]=s*a+h*n,t[3]=l*a+f*n,t[4]=c*a-i*n,t[5]=u*a-o*n,t[6]=h*a-s*n,t[7]=f*a-l*n,t},t.scale=function(t,e,r){var n=r[0],a=r[1],i=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*a,t[5]=e[5]*a,t[6]=e[6]*a,t[7]=e[7]*a,t[8]=e[8]*i,t[9]=e[9]*i,t[10]=e[10]*i,t[11]=e[11]*i,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){it=t,ot=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),\"deferred\"===Jn||\"loading\"===Jn||\"loaded\"===Jn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Kn=R.resolveURL(t),Jn=\"deferred\",Xn=e,$n(),r||ra()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=function(t){var e=t[0],r=t[1];return e*e+r*r},t.styleSpec=At,t.sub=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t},t.symbolSize=zl,t.transformMat3=function(t,e,r){var n=e[0],a=e[1],i=e[2];return t[0]=n*r[0]+a*r[3]+i*r[6],t[1]=n*r[1]+a*r[4]+i*r[7],t[2]=n*r[2]+a*r[5]+i*r[8],t},t.transformMat4=io,t.translate=function(t,e,r){var n,a,i,o,s,l,c,u,h,f,p,d,g=r[0],m=r[1],v=r[2];return e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n=e[0],t[1]=a,t[2]=i,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*m+h*v+e[12],t[13]=a*g+l*m+f*v+e[13],t[14]=i*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]),t},t.triggerPluginCompletionEvent=Qn,t.uniqueId=f,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=An,t.validateStyle=Mn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=gs,t.version=\"1.10.1\",t.warnOnce=_,t.webpSupported=B,t.window=self,t.wrap=c})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",a=0,i=t;a<i.length;a+=1)n+=e(i[a])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",a=0,i=t.refProperties;a<i.length;a+=1)n+=\"/\"+e(r[i[a]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var a=this,i=0,o=e;i<o.length;i+=1){var s=o[i];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},a=0;a<t.length;a++){var i=e&&e[t[a].id]||r(t[a]);e&&(e[t[a].id]=i);var o=n[i];o||(o=n[i]=[]),o.push(t[a])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map((function(t){return a._layers[t.id]})),g=d[0];if(\"none\"!==g.visibility){var m=g.source||\"\",v=this.familiesBySource[m];v||(v=this.familiesBySource[m]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=v[y];x||(x=v[y]=[]),x.push(d)}}};var a=function(e){var r={},n=[];for(var a in e){var i=e[a],o=r[a]={};for(var s in i){var l=i[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=new t.AlphaImage({width:u.w||1,height:u.h||1});for(var f in e){var p=e[f];for(var d in p){var g=p[+d];if(g&&0!==g.bitmap.width&&0!==g.bitmap.height){var m=r[f][d].rect;t.AlphaImage.copy(g.bitmap,h,{x:0,y:0},{x:m.x+1,y:m.y+1},g.bitmap)}}}this.image=h,this.positions=r};t.register(\"GlyphAtlas\",a);var i=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var a=new t.EvaluationParameters(r),i=0,o=e;i<o.length;i+=1)o[i].recalculate(a,n)}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,a,i){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:a,expires:i})}));return function(){n.cancel(),r()}}i.prototype.parse=function(e,r,n,i,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var h,f,p,d,g={},m={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},v=r.familiesBySource[this.source];for(var y in v){var x=e.layers[y];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+y+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var b=c.encode(y),_=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,y);_.push({feature:T,id:k,index:w,sourceLayerIndex:b})}for(var M=0,A=v[y];M<A.length;M+=1){var S=A[M],E=S[0];E.minzoom&&this.zoom<Math.floor(E.minzoom)||E.maxzoom&&this.zoom>=E.maxzoom||\"none\"!==E.visibility&&(o(S,this.zoom,n),(g[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:b,sourceID:this.source})).populate(_,m,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id}))))}}}var C=t.mapObject(m.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(C).length?i.send(\"getGlyphs\",{uid:this.uid,stacks:C},(function(t,e){h||(h=t,f=e,I.call(l))})):f={};var L=Object.keys(m.iconDependencies);L.length?i.send(\"getImages\",{icons:L,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){h||(h=t,p=e,I.call(l))})):p={};var P=Object.keys(m.patternDependencies);function I(){if(h)return s(h);if(f&&p&&d){var e=new a(f),r=new t.ImageAtlas(p,d);for(var i in g){var l=g[i];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,f,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(m,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(g).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?f:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}P.length?i.send(\"getImages\",{icons:P,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){h||(h=t,d=e,I.call(l))})):d={},I.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,a=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[a]=new i(e);s.abort=this.loadVectorData(e,(function(e,i){if(delete n.loading[a],e||!i)return s.status=\"done\",n.loaded[a]=s,r(e);var l=i.rawData,c={};i.expires&&(c.expires=i.expires),i.cacheControl&&(c.cacheControl=i.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=i.vectorTile,s.parse(i.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[a]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,a=t.uid,i=this;if(n&&n[a]){var o=n[a];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var a=o.reloadCallback;a&&(delete o.reloadCallback,o.parse(o.vectorTile,i.layerIndex,r.availableImages,i.actor,a)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};function h(t,e){if(0!==t.length){f(t[0],e);for(var r=1;r<t.length;r++)f(t[r],!e)}}function f(t,e){for(var r=0,n=0,a=t.length,i=a-1;n<a;i=n++)r+=(t[n][0]-t[i][0])*(t[i][1]+t[n][1]);r>=0!=!!e&&t.reverse()}u.prototype.loadTile=function(e,r){var n=e.uid,a=e.encoding,i=e.rawImageData,o=c&&i instanceof c?this.getImageData(i):i,s=new t.DEMData(n,o,a);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,d=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};d.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var a=n[r];e.push([new t.Point$1(a[0],a[1])])}return e}for(var i=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}i.push(l)}return i},d.prototype.toGeoJSON=function(t,e,r){return p.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new d(this._features[t])};var m=t.vectorTile.VectorTileFeature,v=y;function y(t,e){this.options=e||{},this.features=t,this.length=t.length}function x(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}y.prototype.feature=function(t){return new x(this.features[t],this.options.extent)},x.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],a=[],i=0;i<n.length;i++)a.push(new t.Point$1(n[i][0],n[i][1]));this.geometry.push(a)}return this.geometry},x.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,a=-1/0,i=0;i<t.length;i++)for(var o=t[i],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),a=Math.max(a,l.y)}return[e,n,r,a]},x.prototype.toGeoJSON=m.prototype.toGeoJSON;var b=w,_=v;function w(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,T,t.layers[r])}(e,r),r.finish()}function T(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,k,n);var a=n.keys;for(r=0;r<a.length;r++)e.writeStringField(3,a[r]);var i=n.values;for(r=0;r<i.length;r++)e.writeMessage(4,C,i[r])}function k(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,M,t),e.writeVarintField(3,r.type),e.writeMessage(4,E,r)}function M(t,e){var r=t.feature,n=t.keys,a=t.values,i=t.keycache,o=t.valuecache;for(var s in r.properties){var l=i[s];void 0===l&&(n.push(s),i[s]=l=n.length-1),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(a.push(c),o[h]=f=a.length-1),e.writeVarint(f)}}function A(t,e){return(e<<3)+(7&t)}function S(t){return t<<1^t>>31}function E(t,e){for(var r=t.loadGeometry(),n=t.type,a=0,i=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(A(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(A(2,u-1));var f=l[h].x-a,p=l[h].y-i;e.writeVarint(S(f)),e.writeVarint(S(p)),a+=f,i+=p}3===n&&e.writeVarint(A(7,1))}}function C(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function L(t,e,r,n){P(t,r,n),P(e,2*r,2*n),P(e,2*r+1,2*n+1)}function P(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function I(t,e,r,n){var a=t-r,i=e-n;return a*a+i*i}b.fromVectorTileJs=w,b.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new v(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return w({layers:r})},b.GeoJSONWrapper=_;var z=function(t){return t[0]},O=function(t){return t[1]},D=function(t,e,r,n,a){void 0===e&&(e=z),void 0===r&&(r=O),void 0===n&&(n=64),void 0===a&&(a=Float64Array),this.nodeSize=n,this.points=t;for(var i=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new i(t.length),s=this.coords=new a(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,a,i,o){if(!(i-a<=n)){var s=a+i>>1;!function t(e,r,n,a,i,o){for(;i>a;){if(i-a>600){var s=i-a+1,l=n-a+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(a,Math.floor(n-l*u/s+h)),Math.min(i,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=a,d=i;for(L(e,r,a,n),r[2*i+o]>f&&L(e,r,a,i);p<d;){for(L(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*a+o]===f?L(e,r,a,d):L(e,r,++d,i),d<=n&&(a=d+1),n<=d&&(i=d-1)}}(e,r,s,a,i,o%2),t(e,r,n,a,s-1,o+1),t(e,r,n,s+1,i,o+1)}}(o,s,n,0,o.length-1,0)};D.prototype.range=function(t,e,r,n){return function(t,e,r,n,a,i,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)l=e[2*d+1],(s=e[2*d])>=r&&s<=a&&l>=n&&l<=i&&u.push(t[d]);else{var g=Math.floor((p+f)/2);l=e[2*g+1],(s=e[2*g])>=r&&s<=a&&l>=n&&l<=i&&u.push(t[g]);var m=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(m)),(0===h?a>=s:i>=l)&&(c.push(g+1),c.push(f),c.push(m))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},D.prototype.within=function(t,e,r){return function(t,e,r,n,a,i){for(var o=[0,t.length-1,0],s=[],l=a*a;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=i)for(var f=h;f<=u;f++)I(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];I(d,g,r,n)<=l&&s.push(t[p]);var m=(c+1)%2;(0===c?r-a<=d:n-a<=g)&&(o.push(h),o.push(p-1),o.push(m)),(0===c?r+a>=d:n+a>=g)&&(o.push(p+1),o.push(u),o.push(m))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var R={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},F=function(t){this.options=H(Object.create(R),t),this.trees=new Array(this.options.maxZoom+1)};function B(t,e,r,n,a){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:a}}function N(t,e){var r=t.geometry.coordinates,n=r[1];return{x:V(r[0]),y:q(n),zoom:1/0,index:e,parentId:-1}}function j(t){return{type:\"Feature\",id:t.id,properties:U(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function U(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return H(H({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function V(t){return t/360+.5}function q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function H(t,e){for(var r in e)t[r]=e[r];return t}function G(t){return t.x}function Y(t){return t.y}function W(t,e,r,n,a,i){var o=a-r,s=i-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=a,n=i):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function Z(t,e,r,n){var a={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)X(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)X(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var a=0;a<e[n].length;a++)X(t,e[n][a])}(a),a}function X(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function J(t,e,r,n){if(e.geometry){var a=e.geometry.coordinates,i=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===i)K(a,s);else if(\"MultiPoint\"===i)for(var c=0;c<a.length;c++)K(a[c],s);else if(\"LineString\"===i)Q(a,s,o,!1);else if(\"MultiLineString\"===i){if(r.lineMetrics){for(c=0;c<a.length;c++)Q(a[c],s=[],o,!1),t.push(Z(l,\"LineString\",s,e.properties));return}$(a,s,o,!1)}else if(\"Polygon\"===i)$(a,s,o,!0);else{if(\"MultiPolygon\"!==i){if(\"GeometryCollection\"===i){for(c=0;c<e.geometry.geometries.length;c++)J(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<a.length;c++){var u=[];$(a[c],u,o,!0),s.push(u)}}t.push(Z(l,i,s,e.properties))}}function K(t,e){e.push(tt(t[0])),e.push(et(t[1])),e.push(0)}function Q(t,e,r,n){for(var a,i,o=0,s=0;s<t.length;s++){var l=tt(t[s][0]),c=et(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(a*c-l*i)/2:Math.sqrt(Math.pow(l-a,2)+Math.pow(c-i,2))),a=l,i=c}var u=e.length-3;e[2]=1,function t(e,r,n,a){for(var i,o=a,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=W(e[p],e[p+1],c,u,h,f);if(d>o)i=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(i=p,l=g)}}o>a&&(i-r>3&&t(e,r,i,a),e[i+2]=o,n-i>3&&t(e,i,n,a))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function $(t,e,r,n){for(var a=0;a<t.length;a++){var i=[];Q(t[a],i,r,n),e.push(i)}}function tt(t){return t/360+.5}function et(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function rt(t,e,r,n,a,i,o,s){if(n/=e,i>=(r/=e)&&o<n)return t;if(o<r||i>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===a?u.minX:u.minY,d=0===a?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)nt(h,g,r,n,a);else if(\"LineString\"===f)at(h,g,r,n,a,!1,s.lineMetrics);else if(\"MultiLineString\"===f)ot(h,g,r,n,a,!1);else if(\"Polygon\"===f)ot(h,g,r,n,a,!0);else if(\"MultiPolygon\"===f)for(var m=0;m<h.length;m++){var v=[];ot(h[m],v,r,n,a,!0),v.length&&g.push(v)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(m=0;m<g.length;m++)l.push(Z(u.id,f,g[m],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(Z(u.id,f,g,u.tags))}}}return l.length?l:null}function nt(t,e,r,n,a){for(var i=0;i<t.length;i+=3){var o=t[i+a];o>=r&&o<=n&&(e.push(t[i]),e.push(t[i+1]),e.push(t[i+2]))}}function at(t,e,r,n,a,i,o){for(var s,l,c=it(t),u=0===a?lt:ct,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],m=t[f+3],v=t[f+4],y=0===a?p:d,x=0===a?m:v,b=!1;o&&(s=Math.sqrt(Math.pow(p-m,2)+Math.pow(d-v,2))),y<r?x>r&&(l=u(c,p,d,m,v,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,m,v,n),o&&(c.start=h+s*l)):st(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,m,v,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,m,v,n),b=!0),!i&&b&&(o&&(c.end=h+s*l),e.push(c),c=it(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===a?p:d)>=r&&y<=n&&st(c,p,d,g),_=c.length-3,i&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&st(c,c[0],c[1],c[2]),c.length&&e.push(c)}function it(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ot(t,e,r,n,a,i){for(var o=0;o<t.length;o++)at(t[o],e,r,n,a,i,!1)}function st(t,e,r,n){t.push(e),t.push(r),t.push(n)}function lt(t,e,r,n,a,i){var o=(i-e)/(n-e);return t.push(i),t.push(r+(a-r)*o),t.push(1),o}function ct(t,e,r,n,a,i){var o=(i-r)/(a-r);return t.push(e+(n-e)*o),t.push(i),t.push(1),o}function ut(t,e){for(var r=[],n=0;n<t.length;n++){var a,i=t[n],o=i.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)a=ht(i.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){a=[];for(var s=0;s<i.geometry.length;s++)a.push(ht(i.geometry[s],e))}else if(\"MultiPolygon\"===o)for(a=[],s=0;s<i.geometry.length;s++){for(var l=[],c=0;c<i.geometry[s].length;c++)l.push(ht(i.geometry[s][c],e));a.push(l)}r.push(Z(i.id,o,a,i.tags))}return r}function ht(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function ft(t,e){if(t.transformed)return t;var r,n,a,i=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(pt(c[n],c[n+1],e,i,o,s));else for(n=0;n<c.length;n++){var h=[];for(a=0;a<c[n].length;a+=2)h.push(pt(c[n][a],c[n][a+1],e,i,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function pt(t,e,r,n,a,i){return[Math.round(r*(t*n-a)),Math.round(r*(e*n-i))]}function dt(t,e,r,n,a){for(var i=e===a.maxZoom?0:a.tolerance/((1<<e)*a.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,gt(o,t[s],i,a);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function gt(t,e,r,n){var a=e.geometry,i=e.type,o=[];if(\"Point\"===i||\"MultiPoint\"===i)for(var s=0;s<a.length;s+=3)o.push(a[s]),o.push(a[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===i)mt(o,a,t,r,!1,!1);else if(\"MultiLineString\"===i||\"Polygon\"===i)for(s=0;s<a.length;s++)mt(o,a[s],t,r,\"Polygon\"===i,0===s);else if(\"MultiPolygon\"===i)for(var l=0;l<a.length;l++){var c=a[l];for(s=0;s<c.length;s++)mt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===i&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=a.start/a.size,u.mapbox_clip_end=a.end/a.size}var f={geometry:o,type:\"Polygon\"===i||\"MultiPolygon\"===i?3:\"LineString\"===i||\"MultiLineString\"===i?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function mt(t,e,r,n,a,i){var o=n*n;if(n>0&&e.size<(a?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;a&&function(t,e){for(var r=0,n=0,a=t.length,i=a-2;n<a;i=n,n+=2)r+=(t[n]-t[i])*(t[n+1]+t[i+1]);if(r>0===e)for(n=0,a=t.length;n<a/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[a-2-n],t[n+1]=t[a-1-n],t[a-2-n]=o,t[a-1-n]=s}}(s,i),t.push(s)}}function vt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)J(r,t.features[n],e,n);else J(r,\"Feature\"===t.type?t:{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,a=rt(t,1,-1-r,r,0,-1,2,e),i=rt(t,1,1-r,2+r,0,-1,2,e);return(a||i)&&(n=rt(t,1,-r,1+r,0,-1,2,e)||[],a&&(n=ut(a,1).concat(n)),i&&(n=n.concat(ut(i,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function yt(t,e,r){return 32*((1<<t)*r+e)+t}function xt(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var a=new g(n.features),i=b(a);0===i.byteOffset&&i.byteLength===i.buffer.byteLength||(i=new Uint8Array(i)),e(null,{vectorTile:a,rawData:i.buffer})}F.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,a=e.maxZoom,i=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(N(t[l],l));this.trees[a+1]=new D(s,G,Y,i,Float32Array),r&&console.timeEnd(o);for(var c=a;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new D(s,G,Y,i,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},F.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),a=180===t[2]?180:((t[2]+180)%360+360)%360-180,i=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,a=180;else if(r>a){var o=this.getClusters([r,n,180,i],e),s=this.getClusters([-180,n,a,i],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(V(r),q(i),V(a),q(n));u<h.length;u+=1){var f=l.points[h[u]];c.push(f.numPoints?j(f):this.points[f.index])}return c},F.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",a=this.trees[r];if(!a)throw new Error(n);var i=a.points[e];if(!i)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=a.within(i.x,i.y,o);l<c.length;l+=1){var u=a.points[c[l]];u.parentId===t&&s.push(u.numPoints?j(u):this.points[u.index])}if(0===s.length)throw new Error(n);return s},F.prototype.getLeaves=function(t,e,r){var n=[];return this._appendLeaves(n,t,e=e||10,r=r||0,0),n},F.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],a=Math.pow(2,t),i=this.options,o=i.radius/i.extent,s=(r-o)/a,l=(r+1+o)/a,c={features:[]};return this._addTileFeatures(n.range((e-o)/a,s,(e+1+o)/a,l),n.points,e,r,a,c),0===e&&this._addTileFeatures(n.range(1-o/a,s,1,l),n.points,a,r,a,c),e===a-1&&this._addTileFeatures(n.range(0,s,o/a,l),n.points,-1,r,a,c),c.features.length?c:null},F.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},F.prototype._appendLeaves=function(t,e,r,n,a){for(var i=0,o=this.getChildren(e);i<o.length;i+=1){var s=o[i],l=s.properties;if(l&&l.cluster?a+l.point_count<=n?a+=l.point_count:a=this._appendLeaves(t,l.cluster_id,r,n,a):a<n?a++:t.push(s),t.length===r)break}return a},F.prototype._addTileFeatures=function(t,e,r,n,a,i){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*a-r)),Math.round(this.options.extent*(l.y*a-n))]],tags:c?U(l):this.points[l.index].properties},h=void 0;c?h=l.id:this.options.generateId?h=l.index:this.points[l.index].id&&(h=this.points[l.index].id),void 0!==h&&(u.id=h),i.features.push(u)}},F.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},F.prototype._cluster=function(t,e){for(var r=[],n=this.options,a=n.reduce,i=n.radius/(n.extent*Math.pow(2,e)),o=0;o<t.length;o++){var s=t[o];if(!(s.zoom<=e)){s.zoom=e;for(var l=this.trees[e+1],c=l.within(s.x,s.y,i),u=s.numPoints||1,h=s.x*u,f=s.y*u,p=a&&u>1?this._map(s,!0):null,d=(o<<5)+(e+1)+this.points.length,g=0,m=c;g<m.length;g+=1){var v=l.points[m[g]];if(!(v.zoom<=e)){v.zoom=e;var y=v.numPoints||1;h+=v.x*y,f+=v.y*y,u+=y,v.parentId=d,a&&(p||(p=this._map(s,!0)),a(p,this._map(v)))}}1===u?r.push(s):(s.parentId=d,r.push(B(h/u,f/u,d,u,p)))}}return r},F.prototype._getOriginId=function(t){return t-this.points.length>>5},F.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},F.prototype._map=function(t,e){if(t.numPoints)return e?H({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?H({},n):n},vt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},vt.prototype.splitTile=function(t,e,r,n,a,i,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=yt(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=dt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,a){if(e===l.maxZoom||e===a)continue;var d=1<<a-e;if(r!==Math.floor(i/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,m,v,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,T=.5+_,k=1+_;g=m=v=y=null,x=rt(t,u,r-_,r+T,0,f.minX,f.maxX,l),b=rt(t,u,r+w,r+k,0,f.minX,f.maxX,l),t=null,x&&(g=rt(x,u,n-_,n+T,1,f.minY,f.maxY,l),m=rt(x,u,n+w,n+k,1,f.minY,f.maxY,l),x=null),b&&(v=rt(b,u,n-_,n+T,1,f.minY,f.maxY,l),y=rt(b,u,n+w,n+k,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(m||[],e+1,2*r,2*n+1),s.push(v||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},vt.prototype.getTile=function(t,e,r){var n=this.options,a=n.extent,i=n.debug;if(t<0||t>24)return null;var o=1<<t,s=yt(t,e=(e%o+o)%o,r);if(this.tiles[s])return ft(this.tiles[s],a);i>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[yt(c,u,h)];return l&&l.source?(i>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),i>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),i>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?ft(this.tiles[s],a):null):null};var bt=function(e){function r(t,r,n,a){e.call(this,t,r,n,xt),a&&(this.loadGeoJSON=a)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var a=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(i,o){if(i||!o)return r(i);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){var n,a=e&&e.type;if(\"FeatureCollection\"===a)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===a)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===a)t(e.geometry,r);else if(\"Polygon\"===a)h(e.coordinates,r);else if(\"MultiPolygon\"===a)for(n=0;n<e.coordinates.length;n++)h(e.coordinates[n],r);return e}(o,!0);try{e._geoJSONIndex=n.cluster?new F(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var a={},i={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=t.createExpression(f[1]),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);a[h]=d.value,i[h]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var i=n[r];e[i]=a[i].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var a=n[r];o.accumulated=t[a],t[a]=i[a].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new vt(t,e)}(o,n.geojsonVtOptions)}catch(i){return r(i)}e.loaded={};var s={};if(a){var l=a.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded;return n&&n[t.uid]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l),_t=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:bt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return _t.prototype.setReferrer=function(t,e){this.referrer=e},_t.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var a=this.workerSources[t][n];for(var i in a)a[i].availableImages=e}r()},_t.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},_t.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},_t.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},_t.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},_t.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},_t.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},_t.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},_t.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},_t.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},_t.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},_t.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var a=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=a){this.self.importScripts(a);var i=t.plugin.isParsed();n(i?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+a),i)}}catch(t){n(t.toString())}},_t.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},_t.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},_t.prototype.getWorkerSource=function(t,e,r){var n=this;return this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),this.workerSources[t][e][r]||(this.workerSources[t][e][r]=new this.workerSourceTypes[e]({send:function(e,r,a){n.actor.send(e,r,a,t)}},this.getLayerIndex(t),this.getAvailableImages(t))),this.workerSources[t][e][r]},_t.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},_t.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new _t(t.window)),_t})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"==typeof window||\"undefined\"==typeof document?\"not a browser\":Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?(void 0===n[r=t&&t.failIfMajorPerformanceCaveat]&&(n[r]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);return!(!n||r.isContextLost())&&(r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS))}(r)),n[r]?void 0:\"insufficient WebGL support\"):\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\";var r}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var a=t.window.document.createElement(e);return void 0!==r&&(a.className=r),n&&n.appendChild(a),a},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function a(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var i,o=a([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(i=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=i)};var s=a([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),t.addEventListener(e,r,\"passive\"in n&&l?n:n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),t.removeEventListener(e,r,\"passive\"in n&&l?n:n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),a=[],i=0;i<r.length;i++)a.push(new t.Point(r[i].clientX-n.left-e.clientLeft,r[i].clientY-n.top-e.clientTop));return a},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e];this._notify(n.ids,n.callback)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,a=t;n<a.length;n+=1){var i=a[n];if(i[0]<r||i[1]<i[0]||e<i[1])return!1;r=i[1]}return!0},r.prototype._validateContent=function(t,e){return!(t&&(4!==t.length||t[0]<0||e.data.width<t[0]||t[1]<0||e.data.height<t[1]||t[2]<0||e.data.width<t[2]||t[3]<0||e.data.height<t[3]||t[2]<t[0]||t[3]<t[1]))},r.prototype.updateImage=function(t,e){e.version=this.images[t].version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,a=t;n<a.length;n+=1)this.images[a[n]]||(r=!1);this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},a=0,i=e;a<i.length;a+=1){var o=i[a];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var a={w:n.data.width+2,h:n.data.height+2,x:0,y:0},i=new t.ImagePosition(a,n);this.patterns[e]={bin:a,position:i}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),a=n.w,i=n.h,o=this.atlasImage;for(var s in o.resize({width:a||1,height:i||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var a=this.images[n];h(a)&&this.updateImage(n,a)}}},r}(t.Evented),p=m,d=m,g=1e20;function m(t,e,r,n,a,i){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=a||\"sans-serif\",this.fontWeight=i||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,a,i,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,a,i,o,r),l=0;l<r;l++)t[l*e+s]=a[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,a,i,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(a[s])}}function y(t,e,r,n,a){r[0]=0,n[0]=-g,n[1]=+g;for(var i=1,o=0;i<a;i++){for(var s=(t[i]+i*i-(t[r[o]]+r[o]*r[o]))/(2*i-2*r[o]);s<=n[o];)o--,s=(t[i]+i*i-(t[r[o]]+r[o]*r[o]))/(2*i-2*r[o]);r[++o]=i,n[o]=s,n[o+1]=+g}for(i=0,o=0;i<a;i++){for(;n[o+1]<i;)o++;e[i]=(i-r[o])*(i-r[o])+t[r[o]]}}m.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var a=e.data[4*n+3]/255;this.gridOuter[n]=1===a?0:0===a?g:Math.pow(Math.max(0,.5-a),2),this.gridInner[n]=1===a?g:0===a?0:Math.pow(Math.max(0,a-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++)r[n]=Math.max(0,Math.min(255,Math.round(255-255*((this.gridOuter[n]-this.gridInner[n])/this.radius+this.cutoff))));return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,a=[];for(var i in e)for(var o=0,s=e[i];o<s.length;o+=1)a.push({stack:i,id:s[o]});t.asyncAll(a,(function(t,e){var r=t.stack,a=t.id,i=n.entries[r];i||(i=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=i.glyphs[a];if(void 0===o){if(o=n._tinySDF(i,r,a))return i.glyphs[a]=o,void e(null,{stack:r,id:a,glyph:o});var s=Math.floor(a/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(i.ranges[s])e(null,{stack:r,id:a,glyph:o});else{var l=i.requests[s];l||(l=i.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(i.glyphs[+r]=e[+r]);i.ranges[s]=!0}for(var a=0,o=l;a<o.length;a+=1)(0,o[a])(t,e);delete i.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:a,glyph:n[a]||null})}))}}else e(null,{stack:r,id:a,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},a=0,i=e;a<i.length;a+=1){var o=i[a],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var a=this.localIdeographFontFamily;if(a&&this._doesCharSupportLocalGlyph(n)){var i=e.tinySDF;if(!i){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),i=e.tinySDF=new x.TinySDF(24,3,8,.25,a,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},i.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,a,i){var o=256*r,s=o+255,l=a.transformRequest(a.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)i(e);else if(r){for(var n={},a=0,o=t.parseGlyphPBF(r);a<o.length;a+=1){var s=o[a];n[s.id]=s}i(null,n)}}))},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var a=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),a):this._transitionable.setValue(n,a)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),T=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};T.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},T.prototype.getDashRanges=function(t,e,r){var n=[],a=t.length%2==1?-t[t.length-1]*r:0,i=t[0]*r,o=!0;n.push({left:a,right:i,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){var c=t[l];n.push({left:a=s*r,right:i=(s+=c)*r,isDash:o=!o,zeroLength:0===c})}return n},T.prototype.addRoundDash=function(t,e,r){for(var n=e/2,a=-r;a<=r;a++)for(var i=this.width*(this.nextRow+r+a),o=0,s=t[o],l=0;l<this.width;l++){l/s.right>1&&(s=t[++o]);var c=Math.abs(l-s.left),u=Math.abs(l-s.right),h=Math.min(c,u),f=void 0,p=a/r*(n+1);if(s.isDash){var d=n-Math.abs(p);f=Math.sqrt(h*h+d*d)}else f=n-Math.sqrt(h*h+p*p);this.data[i+l]=Math.max(0,Math.min(255,f+128))}},T.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var a=t[0],i=t[t.length-1];a.isDash===i.isDash&&(a.left=i.left-this.width,i.right=a.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),h=Math.abs(c-l.right),f=Math.min(u,h);this.data[o+c]=Math.max(0,Math.min(255,(l.isDash?f:-f)+128))}},T.prototype.addDash=function(e,r){var n=r?7:0,a=2*n+1;if(this.nextRow+a>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var i=0,o=0;o<e.length;o++)i+=e[o];if(0!==i){var s=this.width/i,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:i};return this.nextRow+=a,this.dirty=!0,c},T.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var a=this.workerPool.acquire(this.id),i=0;i<a.length;i++){var o=new e.Actor(a[i],n,this.id);o.name=\"Worker \"+i,this.actors.push(o)}};function M(e,r,n){var a=function(a,i){if(a)return n(a);if(i){var o=t.pick(t.extend(i,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);i.vector_layers&&(o.vectorLayers=i.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),a):t.browser.frame((function(){return a(null,e)}))}k.prototype.broadcast=function(e,r,n){t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n=n||function(){})},k.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},k.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),a=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),i=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<i&&e.y>=a&&e.y<o};var S=function(e){function r(r,n,a,i){if(e.call(this),this.id=r,this.dispatcher=a,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(i)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),a={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function i(n,a){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(a&&a.resourceTiming&&(e.resourceTiming=a.resourceTiming),this.map._refreshExpiredTiles&&a&&e.setExpiryData(a),e.loadVectorData(a,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}a.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",a,i.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",a,i.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,a,i){e.call(this),this.id=r,this.dispatcher=a,this.setEventedParent(i),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,a=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(a,t.ResourceType.Tile),(function(a,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(a)e.state=\"errored\",r(a);else if(i){n.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(i.width),e.texture?e.texture.update(i,{useMipmap:!0}):(e.texture=new t.Texture(o,i,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),C=function(e){function r(r,n,a,i){e.call(this,r,n,a,i),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function a(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var o=t.window.ImageBitmap&&i instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?i:t.browser.getImageData(i,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,a.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),a=(r.x-1+n)%n,i=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(E),L=function(e){function r(r,n,a,i){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=a.getActor(),this.setEventedParent(i),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),a=this._data;\"string\"==typeof a?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(a),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(a),this.actor.send(this.type+\".loadData\",n,(function(t,a){r._removed||a&&a.abandoned||(r._loaded=!0,a&&a.resourceTiming&&a.resourceTiming[r.id]&&(r._resourceTiming=a.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,a=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor,e.request=this.actor.send(a,{type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId},(function(t,i){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(i,n.map.painter,\"reloadTile\"===a),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),I=function(e){function r(t,r,n,a){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(a),this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(a,i){n._loaded=!0,a?n.fire(new t.ErrorEvent(a)):i&&(n.image=i,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,a=-1/0,i=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),a=Math.max(a,l.x),i=Math.max(i,l.y)}var c=Math.max(a-r,i-n),u=Math.max(0,Math.floor(-Math.log(c)/Math.LN2)),h=Math.pow(2,u);return new t.CanonicalTileID(u,Math.floor((r+a)/2*h),Math.floor((n+i)/2*h))}(n),this.minzoom=this.maxzoom=this.tileID.z;var a=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(a[0].x,a[0].y,0,0),this._boundsArray.emplaceBack(a[1].x,a[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(a[3].x,a[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(a[2].x,a[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var a=this.tiles[n];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),z=function(e){function r(t,r,n,a){e.call(this,t,r,n,a),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,a=r.urls;n<a.length;n+=1)this.urls.push(this.map._requestManager.transformRequest(a[n],t.ResourceType.Source).url);t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var a=this.tiles[n];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(I),O=function(e){function r(r,n,a,i){e.call(this,r,n,a,i),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var a in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var i=this.tiles[a];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(I),D={vector:S,raster:E,\"raster-dem\":C,geojson:L,video:z,image:I,canvas:O};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,a,i){var o=function(t,e,r){if(t)for(var n=0,a=t;n<a.length;n+=1){var i=e[a[n]];if(i&&i.source===r&&\"fill-extrusion\"===i.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(a&&a.layers,e,t.id),s=i.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(B);for(var c=[],u=0,h=l;u<h.length;u+=1){var f=h[u];c.push({wrappedTileID:f.tileID.wrapped().key,queryResults:f.tile.queryRenderedFeatures(e,r,t._state,f.queryGeometry,f.cameraQueryGeometry,f.scale,a,i,s,R(t.transform,f.tileID))})}var p=function(t){for(var e={},r={},n=0,a=t;n<a.length;n+=1){var i=a[n],o=i.queryResults,s=i.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,a=t.wrapped().key;void 0===this.data[a]&&(this.data[a]=[]);var i={value:e,timeout:void 0};if(void 0!==r&&(i.timeout=setTimeout((function(){n.remove(t,i)}),r)),this.data[a].push(i),this.order.push(a),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),a=this.data[r][n];return this.data[r].splice(n,1),a.timeout&&clearTimeout(a.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(a.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},N.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,a=this.data[r];n<a.length;n+=1){var i=a[n];t(i.value)||e.push(i)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var U={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},V=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var a=t.gl;this.buffer=a.createBuffer(),t.bindVertexBuffer.set(this.buffer),a.bufferData(a.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?a.DYNAMIC_DRAW:a.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};V.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},V.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},V.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=e.attributes[this.attributes[r].name];void 0!==n&&t.enableVertexAttribArray(n)}},V.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var a=this.attributes[n],i=e.attributes[a.name];void 0!==i&&t.vertexAttribPointer(i,a.components,t[U[a.type]],!1,this.itemSize,a.offset+this.itemSize*(r||0))}},V.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),at=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),kt=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var a=this.framebuffer=t.gl.createFramebuffer();this.colorAttachment=new wt(t,a),n&&(this.depthAttachment=new Tt(t,a))};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,a,i){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=a,this.pass=i};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Ct=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new Z(this),this.stencilMask=new X(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new at(this),this.blendEquation=new it(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ht(this),this.bindFramebuffer=new ft(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new mt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\")};Ct.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Ct.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Ct.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Ct.prototype.createVertexBuffer=function(t,e,r){return new V(this,t,e,r)},Ct.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,a=n.createRenderbuffer();return this.bindRenderbuffer.set(a),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),a},Ct.prototype.createFramebuffer=function(t,e,r){return new kt(this,t,e,r)},Ct.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,a=0;e&&(a|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(a|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(a)},Ct.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Ct.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Ct.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Ct.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Ct.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Lt=function(e){function r(r,n,a){var i=this;e.call(this),this.id=r,this.dispatcher=a,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(i._sourceLoaded=!0),i._sourceLoaded&&!i._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(i.reload(),i.transform&&i.update(i.transform))})),this.on(\"error\",(function(){i._sourceErrored=!0})),this._source=function(e,r,n,a){var i=new D[r.type](e,r,n,a);if(i.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+i.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],i),i}(r,n,a,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(Pt).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var a in this._tiles)this._isIdRenderable(a,e)&&n.push(this._tiles[a]);return e?n.sort((function(e,n){var a=e.tileID,i=n.tileID,o=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle),s=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle);return a.overscaledZ-i.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(Pt).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,a){if(a)return e.state=\"errored\",void(404!==a.status?this._source.fire(new t.ErrorEvent(a,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var a=this.getTileByID(n);i(t,a),i(a,t)}}function i(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,a=Math.pow(2,t.tileID.canonical.z),i=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+a)?r+=a:1===Math.abs(r-a)&&(r-=a)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[i]&&(t.neighboringTiles[i].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var a in this._tiles){var i=this._tiles[a];if(!(n[a]||!i.hasData()||i.tileID.overscaledZ<=e||i.tileID.overscaledZ>r)){for(var o=i.tileID;i&&i.tileID.overscaledZ>e+1;){var s=i.tileID.scaledTo(i.tileID.overscaledZ-1);(i=this._tiles[s.key])&&i.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var a=t.scaledTo(n),i=this._getLoadedTile(a);if(i)return i}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=Math.ceil(t.width/this._source.tileSize)+1,r=Math.ceil(t.height/this._source.tileSize)+1,n=Math.floor(e*r*5),a=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,n):n;this._cache.setMaxSize(a)},r.prototype.handleWrapJump=function(t){var e=Math.round((t-(void 0===this._prevLng?t:this._prevLng))/360);if(this._prevLng=t,e){var r={};for(var n in this._tiles){var a=this._tiles[n];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+e),r[a.tileID.key]=a}for(var i in this._tiles=r,this._timers)clearTimeout(this._timers[i]),delete this._timers[i];for(var o in this._tiles)this._setTileReloadTimer(o,this._tiles[o])}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var a;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?a=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(a=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(a=a.filter((function(t){return n._source.hasTile(t)})))):a=[];var i=e.coveringZoomLevel(this._source),o=Math.max(i-r.maxOverzooming,this._source.minzoom),s=Math.max(i+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(a,i);if(It(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var m=this.findLoadedParent(d,o);m&&(this._addTile(m.tileID),c[m.tileID.key]=m.tileID),u[p]=d}}for(var v in this._retainLoadedChildren(u,i,s,l),c)l[v]||(this._coveredTiles[v]=!0,l[v]=c[v])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},a={},i=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var m=d.children(this._source.maxzoom)[0],v=this.getTile(m);if(v&&v.hasData()){n[m.key]=m;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=i;--b){var _=d.scaledTo(b);if(a[_.key])break;if(a[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var a=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(a))break;n=a}for(var i=0,o=e;i<o.length;i+=1)this._loadedParentTiles[o[i]]=r}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var a=this,i=[],o=this.transform;if(!o)return i;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,m=c;g<m.length;g+=1){var v=m[g];h=Math.min(h,v.x),f=Math.min(f,v.y),p=Math.max(p,v.x),d=Math.max(d,v.y)}for(var y=function(e){var n=a._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),m=r*n.queryPadding*t.EXTENT/n.tileSize/g,v=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(v[0].x-m<t.EXTENT&&v[0].y-m<t.EXTENT&&v[1].x+m>=0&&v[1].y+m>=0){var y=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));i.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return i},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,a=r;n<a.length;n+=1){var i=a[n];i.posMatrix=this.transform.calculatePosMatrix(i.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(It(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){this._state.updateState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.removeFeatureState=function(t,e,r){this._state.removeFeatureState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.getFeatureState=function(t,e){return this._state.getState(t=t||\"_geojsonTileLayer\",e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function Pt(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function It(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function zt(){return new t.window.Worker(Ya.workerUrl)}Lt.maxOverzooming=10,Lt.maxUnderzooming=3;var Ot=\"mapboxgl_preloaded_worker_pool\",Dt=function(){this.active={}};Dt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Dt.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},Dt.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Dt.prototype.isPreloaded=function(){return!!this.active[Ot]},Dt.prototype.numActive=function(){return Object.keys(this.active).length};var Rt,Ft=Math.floor(t.browser.hardwareConcurrency/2);function Bt(){return Rt||(Rt=new Dt),Rt}function Nt(e,r){var n={};for(var a in e)\"ref\"!==a&&(n[a]=e[a]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function jt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Nt(t[n],e[t[n].ref]));return t}Dt.workerCount=Math.max(Math.min(Ft,6),1);var Ut={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Vt(t,e,r){r.push({command:Ut.addSource,args:[t,e[t]]})}function qt(t,e,r){e.push({command:Ut.removeSource,args:[t]}),r[t]=!0}function Ht(t,e,r,n){qt(t,r,n),Vt(t,e,r)}function Gt(e,r,n){var a;for(a in e[n])if(e[n].hasOwnProperty(a)&&\"data\"!==a&&!t.deepEqual(e[n][a],r[n][a]))return!1;for(a in r[n])if(r[n].hasOwnProperty(a)&&\"data\"!==a&&!t.deepEqual(e[n][a],r[n][a]))return!1;return!0}function Yt(e,r,n,a,i,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[a,s,r[s],i]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[a,s,r[s],i]}))}function Wt(t){return t.id}function Zt(t,e){return t[e.id]=e,t}var Xt=function(t,e){this.reset(t,e)};Xt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Xt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],a=e*this.paddedLength+this.padding;n<a&&r<this._distances.length;)n=this._distances[++r];var i=r-1,o=this._distances[i],s=n-o,l=s>0?(a-o)/s:0;return this.points[i].mult(1-l).add(this.points[r].mult(l))};var Jt=function(t,e,r){var n=this.boxCells=[],a=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var i=0;i<this.xCellCount*this.yCellCount;i++)n.push([]),a.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Kt(e,r,n,a,i){var o=t.create();return r?(t.scale(o,o,[1/i,1/i,1]),n||t.rotateZ(o,o,a.angle)):t.multiply(o,a.labelPlaneMatrix,e),o}function Qt(e,r,n,a,i){if(r){var o=t.clone(e);return t.scale(o,o,[i,i,1]),n||t.rotateZ(o,o,-a.angle),o}return a.glCoordMatrix}function $t(e,r){var n=[e.x,e.y,0,1];ue(n,n,r);var a=n[3];return{point:new t.Point(n[0]/a,n[1]/a),signedDistanceFromCamera:a}}function te(t,e){return.5+t/e*.5}function ee(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function re(e,r,n,a,i,o,s,l){var c=a?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=a?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=a?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,m=!1,v=0;v<d.length;v++){var y=d.get(v);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!m)ce(y.numGlyphs,f);else{m=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),ee(x,h)){var b=te(n.transform.cameraToCenterDistance,x[3]),_=t.evaluateSizeForFeature(c,u,y),w=s?_/b:_*b,T=new t.Point(y.anchorX,y.anchorY),k=$t(T,i).point,M={},A=ie(y,w,!1,l,r,i,o,e.glyphOffsetArray,p,f,k,T,M,g);m=A.useVertical,(A.notEnoughRoom||m||A.needsFlipping&&ie(y,w,!0,l,r,i,o,e.glyphOffsetArray,p,f,k,T,M,g).notEnoughRoom)&&ce(y.numGlyphs,f)}else ce(y.numGlyphs,f)}}a?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function ne(t,e,r,n,a,i,o,s,l,c,u){var h=s.glyphStartIndex+s.numGlyphs,f=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),g=e.getoffsetX(h-1),m=se(t*d,r,n,a,i,o,s.segment,f,p,l,c,u);if(!m)return null;var v=se(t*g,r,n,a,i,o,s.segment,f,p,l,c,u);return v?{first:m,last:v}:null}function ae(e,r,n,a){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*a?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ie(e,r,n,a,i,o,s,l,c,u,h,f,p,d){var g,m=r/24,v=e.lineOffsetX*m,y=e.lineOffsetY*m;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ne(m,l,v,y,n,h,f,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=$t(w.first.point,s).point,k=$t(w.last.point,s).point;if(a&&!n){var M=ae(e.writingMode,T,k,d);if(M)return M}g=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)g.push(se(m*l.getoffsetX(A),v,y,n,h,f,e.segment,b,_,c,o,p));g.push(w.last)}else{if(a&&!n){var S=$t(f,i).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=$t(C,i),P=L.signedDistanceFromCamera>0?L.point:oe(f,C,S,1,i),I=ae(e.writingMode,S,P,d);if(I)return I}var z=se(m*l.getoffsetX(e.glyphStartIndex),v,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!z)return{notEnoughRoom:!0};g=[z]}for(var O=0,D=g;O<D.length;O+=1){var R=D[O];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function oe(t,e,r,n,a){var i=$t(t.add(t.sub(e)._unit()),a).point,o=r.sub(i);return r.add(o._mult(n/o.mag()))}function se(e,r,n,a,i,o,s,l,c,u,h,f){var p=a?e-r:e+r,d=p>0?1:-1,g=0;a&&(d*=-1,g=Math.PI),d<0&&(g+=Math.PI);for(var m=d>0?l+s:l+s+1,v=i,y=i,x=0,b=0,_=Math.abs(p),w=[];x+b<=_;){if((m+=d)<l||m>=c)return null;if(y=v,w.push(v),void 0===(v=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),k=$t(T,h);if(k.signedDistanceFromCamera>0)v=f[m]=k.point;else{var M=m-d;v=oe(0===x?o:new t.Point(u.getx(M),u.gety(M)),T,y,_-x+1,h)}}x+=b,b=y.dist(v)}var A=(_-x)/b,S=v.sub(y),E=S.mult(A)._add(y);E._add(S._unit()._perp()._mult(n*d));var C=g+Math.atan2(v.y-y.y,v.x-y.x);return w.push(E),{point:E,angle:C,path:w}}Jt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Jt.prototype.insert=function(t,e,r,n,a){this._forEachCell(e,r,n,a,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(a)},Jt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Jt.prototype._insertBoxCell=function(t,e,r,n,a,i){this.boxCells[a].push(i)},Jt.prototype._insertCircleCell=function(t,e,r,n,a,i){this.circleCells[a].push(i)},Jt.prototype._query=function(t,e,r,n,a,i){if(r<0||t>this.width||n<0||e>this.height)return!a&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(a)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return i?o.filter(i):o}return this._forEachCell(t,e,r,n,this._queryCell,o,{hitTest:a,seenUids:{box:{},circle:{}}},i),a?o.length>0:o},Jt.prototype._queryCircle=function(t,e,r,n,a){var i=t-r,o=t+r,s=e-r,l=e+r;if(o<0||i>this.width||l<0||s>this.height)return!n&&[];var c=[];return this._forEachCell(i,s,o,l,this._queryCellCircle,c,{hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}},a),n?c.length>0:c},Jt.prototype.query=function(t,e,r,n,a){return this._query(t,e,r,n,!1,a)},Jt.prototype.hitTest=function(t,e,r,n,a){return this._query(t,e,r,n,!0,a)},Jt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Jt.prototype._queryCell=function(t,e,r,n,a,i,o,s){var l=o.seenUids,c=this.boxCells[a];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return i.push(!0),!0;i.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[a];if(null!==g)for(var m=this.circles,v=0,y=g;v<y.length;v+=1){var x=y[v];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(m[b],m[b+1],m[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return i.push(!0),!0;var _=m[b],w=m[b+1],T=m[b+2];i.push({key:this.circleKeys[x],x1:_-T,y1:w-T,x2:_+T,y2:w+T})}}}},Jt.prototype._queryCellCircle=function(t,e,r,n,a,i,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[a];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return i.push(!0),!0}}var m=this.circleCells[a];if(null!==m)for(var v=this.circles,y=0,x=m;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(v[_],v[_+1],v[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return i.push(!0),!0}}},Jt.prototype._forEachCell=function(t,e,r,n,a,i,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++)if(a.call(this,t,e,r,n,this.xCellCount*p+f,i,o,s))return},Jt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Jt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Jt.prototype._circlesCollide=function(t,e,r,n,a,i){var o=n-t,s=a-e,l=r+i;return l*l>o*o+s*s},Jt.prototype._circleAndRectCollide=function(t,e,r,n,a,i,o){var s=(i-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-a)/2,u=Math.abs(e-(a+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var le=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ce(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(le,3*n)}}function ue(t,e,r){var n=e[0],a=e[1];return t[0]=r[0]*n+r[4]*a+r[12],t[1]=r[1]*n+r[5]*a+r[13],t[3]=r[3]*n+r[7]*a+r[15],t}var he=function(t,e,r){void 0===e&&(e=new Jt(t.width+200,t.height+200,25)),void 0===r&&(r=new Jt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function fe(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}he.prototype.placeCollisionBox=function(t,e,r,n,a){var i=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*i.perspectiveRatio,s=t.x1*o+i.point.x,l=t.y1*o+i.point.y,c=t.x2*o+i.point.x,u=t.y2*o+i.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,a)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},he.prototype.placeCollisionCircles=function(e,r,n,a,i,o,s,l,c,u,h,f,p){var d=[],g=new t.Point(r.anchorX,r.anchorY),m=$t(g,o),v=te(this.transform.cameraToCenterDistance,m.signedDistanceFromCamera),y=(u?i/v:i*v)/t.ONE_EM,x=$t(g,s).point,b=ne(y,a,r.lineOffsetX*y,r.lineOffsetY*y,!1,x,g,r,n,s,{}),_=!1,w=!1,T=!0;if(b){for(var k=.5*f*v+p,M=new t.Point(-100,-100),A=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Xt,E=b.first,C=b.last,L=[],P=E.path.length-1;P>=1;P--)L.push(E.path[P]);for(var I=1;I<C.path.length;I++)L.push(C.path[I]);var z=2.5*k;if(l){var O=L.map((function(t){return $t(t,l)}));L=O.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:O.map((function(t){return t.point}))}var D=[];if(L.length>0){for(var R=L[0].clone(),F=L[0].clone(),B=1;B<L.length;B++)R.x=Math.min(R.x,L[B].x),R.y=Math.min(R.y,L[B].y),F.x=Math.max(F.x,L[B].x),F.y=Math.max(F.y,L[B].y);D=R.x>=M.x&&F.x<=A.x&&R.y>=M.y&&F.y<=A.y?[L]:F.x<M.x||R.x>A.x||F.y<M.y||R.y>A.y?[]:t.clipLine([L],M.x,M.y,A.x,A.y)}for(var N=0,j=D;N<j.length;N+=1){var U;S.reset(j[N],.25*k),U=S.length<=.5*k?1:Math.ceil(S.paddedLength/z)+1;for(var V=0;V<U;V++){var q=V/Math.max(U-1,1),H=S.lerp(q),G=H.x+100,Y=H.y+100;d.push(G,Y,k,0);var W=G-k,Z=Y-k,X=G+k,J=Y+k;if(T=T&&this.isOffscreen(W,Z,X,J),w=w||this.isInsideGrid(W,Z,X,J),!e&&this.grid.hitTestCircle(G,Y,k,h)&&(_=!0,!c))return{circles:[],offscreen:!1,collisionDetected:_}}}}return{circles:!c&&_||!w?[]:d,offscreen:T,collisionDetected:_}},he.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,a=1/0,i=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),a=Math.min(a,u.y),i=Math.max(i,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,a,i,o).concat(this.ignoredGrid.query(n,a,i,o));p<d.length;p+=1){var g=d[p],m=g.key;if(void 0===h[m.bucketInstanceId]&&(h[m.bucketInstanceId]={}),!h[m.bucketInstanceId][m.featureIndex]){var v=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,v)&&(h[m.bucketInstanceId][m.featureIndex]=!0,void 0===f[m.bucketInstanceId]&&(f[m.bucketInstanceId]=[]),f[m.bucketInstanceId].push(m.featureIndex))}}return f},he.prototype.insertCollisionBox=function(t,e,r,n,a){(e?this.ignoredGrid:this.grid).insert({bucketInstanceId:r,featureIndex:n,collisionGroupID:a},t[0],t[1],t[2],t[3])},he.prototype.insertCollisionCircles=function(t,e,r,n,a){for(var i=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:a},s=0;s<t.length;s+=4)i.insertCircle(o,t[s],t[s+1],t[s+2])},he.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var a=[r,n,0,1];return ue(a,a,e),{point:new t.Point((a[0]/a[3]+1)/2*this.transform.width+100,(-a[1]/a[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/a[3]*.5}},he.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},he.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},he.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var pe=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};pe.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var de=function(t,e,r,n,a){this.text=new pe(t?t.text:null,e,r,a),this.icon=new pe(t?t.icon:null,e,n,a)};de.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var ge=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},me=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},ve=function(t,e,r,n,a){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=a},ye=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function xe(e,r,n,a,i){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,a);return new t.Point(s+c[0]*i,l+c[1]*i)}function be(e,r,n,a,i,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return a&&p._rotate(i?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}ye.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var _e=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new he(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new ye(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function we(t,e,r,n,a){t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0)}_e.prototype.getBucketParts=function(e,r,n,a){var i=n.getBucket(r),o=n.latestFeatureIndex;if(i&&o&&r.id===i.layerIds[0]){var s=n.collisionBoxArray,l=i.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),f=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=fe(n,1,this.transform.zoom),g=Kt(h,f,p,this.transform,d),m=null;if(f){var v=Qt(h,f,p,this.transform,d);m=t.multiply([],this.transform.labelPlaneMatrix,v)}this.retainedQueryData[i.bucketInstanceId]=new ve(i.bucketInstanceId,o,i.sourceLayerIndex,i.index,n.tileID);var y={bucket:i,layout:l,posMatrix:h,textLabelPlaneMatrix:g,labelToScreenMatrix:m,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(i.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(i.sourceID)};if(a)for(var x=0,b=i.sortKeyRanges;x<b.length;x+=1){var _=b[x];e.push({sortKey:_.sortKey,symbolInstanceStart:_.symbolInstanceStart,symbolInstanceEnd:_.symbolInstanceEnd,parameters:y})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:i.symbolInstances.length,parameters:y})}},_e.prototype.attemptAnchorPlacement=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d){var g,m=[h.textOffset0,h.textOffset1],v=xe(t,r,n,m,a),y=this.collisionIndex.placeCollisionBox(be(e,v.x,v.y,i,o,this.transform.angle),u,s,l,c.predicate);if(!d||0!==this.collisionIndex.placeCollisionBox(be(d,v.x,v.y,i,o,this.transform.angle),u,s,l,c.predicate).box.length)return y.box.length>0?(this.prevPlacement&&this.prevPlacement.variableOffsets[h.crossTileID]&&this.prevPlacement.placements[h.crossTileID]&&this.prevPlacement.placements[h.crossTileID].text&&(g=this.prevPlacement.variableOffsets[h.crossTileID].anchor),this.variableOffsets[h.crossTileID]={textOffset:m,width:r,height:n,anchor:t,textBoxScale:a,prevAnchor:g},this.markUsedJustification(f,t,h,p),f.allowVerticalPlacement&&(this.markUsedOrientation(f,p,h),this.placedOrientations[h.crossTileID]=p),{shift:v,placedGlyphBoxes:y}):void 0},_e.prototype.placeLayerBucketPart=function(e,r,n){var a=this,i=e.parameters,o=i.bucket,s=i.layout,l=i.posMatrix,c=i.textLabelPlaneMatrix,u=i.labelToScreenMatrix,h=i.textPixelRatio,f=i.holdingForFade,p=i.collisionBoxArray,d=i.partiallyEvaluatedTextSize,g=i.collisionGroup,m=s.get(\"text-optional\"),v=s.get(\"icon-optional\"),y=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),b=\"map\"===s.get(\"text-rotation-alignment\"),_=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=y&&(x||!o.hasIconData()||v),M=x&&(y||!o.hasTextData()||m);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var A=function(e,i){if(!r[e.crossTileID])if(f)a.placements[e.crossTileID]=new ge(!1,!1,!1);else{var p,T=!1,A=!1,S=!0,E=null,C={box:null,offscreen:null},L={box:null,offscreen:null},P=null,I=null,z=0,O=0,D=0;i.textFeatureIndex?z=i.textFeatureIndex:e.useRuntimeCollisionCircles&&(z=e.featureIndex),i.verticalTextFeatureIndex&&(O=i.verticalTextFeatureIndex);var R=i.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&a.prevPlacement){var i=a.prevPlacement.placedOrientations[e.crossTileID];i&&(a.placedOrientations[e.crossTileID]=i,a.markUsedOrientation(o,n=i,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&i.verticalTextBox)for(var a=0,s=o.writingModes;a<s.length&&(s[a]===t.WritingMode.vertical?(C=n(),L=C):C=r(),!(C&&C.box&&C.box.length));a+=1);else C=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(a.prevPlacement&&a.prevPlacement.variableOffsets[e.crossTileID]){var j=a.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var i=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,f={box:[],offscreen:!1},p=y?2*N.length:N.length,d=0;d<p;++d){var m=a.attemptAnchorPlacement(N[d%N.length],t,i,s,c,b,_,h,l,g,d>=N.length,e,o,n,u);if(m&&(f=m.placedGlyphBoxes)&&f.box&&f.box.length){T=!0,E=m.shift;break}}return f};B((function(){return U(R,i.iconBox,t.WritingMode.horizontal)}),(function(){var r=i.verticalTextBox;return o.allowVerticalPlacement&&!(C&&C.box&&C.box.length)&&e.numVerticalGlyphVertices>0&&r?U(r,i.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),C&&(T=C.box,S=C.offscreen);var V=F(C&&C.box);if(!T&&a.prevPlacement){var q=a.prevPlacement.variableOffsets[e.crossTileID];q&&(a.variableOffsets[e.crossTileID]=q,a.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=a.collisionIndex.placeCollisionBox(t,y,h,l,g.predicate);return n&&n.box&&n.box.length&&(a.markUsedOrientation(o,r,e),a.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=i.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(C&&C.box&&C.box.length)}}if(T=(p=C)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Y=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\");P=a.collisionIndex.placeCollisionCircles(y,G,o.lineVertexArray,o.glyphOffsetArray,Y,l,c,u,n,_,g.predicate,e.collisionCircleDiameter,W),T=y||P.circles.length>0&&!P.collisionDetected,S=S&&P.offscreen}if(i.iconFeatureIndex&&(D=i.iconFeatureIndex),i.iconBox){var Z=function(t){var e=w&&E?be(t,E.x,E.y,b,_,a.transform.angle):t;return a.collisionIndex.placeCollisionBox(e,x,h,l,g.predicate)};A=L&&L.box&&L.box.length&&i.verticalIconBox?(I=Z(i.verticalIconBox)).box.length>0:(I=Z(i.iconBox)).box.length>0,S=S&&I.offscreen}var X=m||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,J=v||0===e.numIconVertices;if(X||J?J?X||(A=A&&T):T=A&&T:A=T=A&&T,T&&p&&p.box&&a.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,L&&L.box&&O?O:z,g.ID),A&&I&&a.collisionIndex.insertCollisionBox(I.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,g.ID),P&&(T&&a.collisionIndex.insertCollisionCircles(P.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,g.ID),n)){var K=o.bucketInstanceId,Q=a.collisionCircleArrays[K];void 0===Q&&(Q=a.collisionCircleArrays[K]=new me);for(var $=0;$<P.circles.length;$+=4)Q.circles.push(P.circles[$+0]),Q.circles.push(P.circles[$+1]),Q.circles.push(P.circles[$+2]),Q.circles.push(P.collisionDetected?1:0)}a.placements[e.crossTileID]=new ge(T||k,A||M,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var C=S[E];A(o.symbolInstances.get(C),o.collisionArrays[C])}else for(var L=e.symbolInstanceStart;L<e.symbolInstanceEnd;L++)A(o.symbolInstances.get(L),o.collisionArrays[L]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var P=this.collisionCircleArrays[o.bucketInstanceId];t.invert(P.invProjMatrix,l),P.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},_e.prototype.markUsedJustification=function(e,r,n,a){var i;i=a===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:{left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex}[t.getAnchorJustification(r)];for(var o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];o<s.length;o+=1){var l=s[o];l>=0&&(e.text.placedSymbolArray.get(l).crossTileID=i>=0&&l!==i?0:n.crossTileID)}},_e.prototype.markUsedOrientation=function(e,r,n){for(var a=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,i=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1)e.text.placedSymbolArray.get(s[o]).placedOrientation=a;n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=i)},_e.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,a=e?e.opacities:{},i=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=a[s];c?(this.opacities[s]=new de(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new de(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in a){var h=a[u];if(!this.opacities[u]){var f=new de(h,n,!1,!1);f.isHidden()||(this.opacities[u]=f,r=r||h.text.placed||h.icon.placed)}}for(var p in i)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=i[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},_e.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,a=e;n<a.length;n+=1){var i=a[n],o=i.getBucket(t);o&&i.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,i.collisionBoxArray)}},_e.prototype.updateBucketOpacities=function(e,r,n){var a=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var i=e.layers[0].layout,o=new de(null,0,!1,!1,!0),s=i.get(\"text-allow-overlap\"),l=i.get(\"icon-allow-overlap\"),c=i.get(\"text-variable-anchor\"),u=\"map\"===i.get(\"text-rotation-alignment\"),h=\"map\"===i.get(\"text-pitch-alignment\"),f=\"none\"!==i.get(\"icon-text-fit\"),p=new de(null,0,s&&(l||!e.hasIconData()||i.get(\"icon-optional\")),l&&(s||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},g=function(n){var i=e.symbolInstances.get(n),s=i.numHorizontalGlyphVertices,l=i.numVerticalGlyphVertices,g=i.crossTileID,m=a.opacities[g];r[g]?m=o:m||(a.opacities[g]=m=p),r[g]=!0;var v=i.numIconVertices>0,y=a.placedOrientations[i.crossTileID],x=y===t.WritingMode.vertical,b=y===t.WritingMode.horizontal||y===t.WritingMode.horizontalOnly;if(s>0||l>0){var _=Le(m.text);d(e.text,s,x?Pe:_),d(e.text,l,b?Pe:_);var w=m.text.isHidden();[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=w||x?1:0)})),i.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(i.verticalPlacedTextSymbolIndex).hidden=w||b?1:0);var T=a.variableOffsets[i.crossTileID];T&&a.markUsedJustification(e,T.anchor,i,y);var k=a.placedOrientations[i.crossTileID];k&&(a.markUsedJustification(e,\"left\",i,k),a.markUsedOrientation(e,k,i))}if(v){var M=Le(m.icon),A=!(f&&i.verticalPlacedIconSymbolIndex&&x);i.placedIconSymbolIndex>=0&&(d(e.icon,i.numIconVertices,A?M:Pe),e.icon.placedSymbolArray.get(i.placedIconSymbolIndex).hidden=m.icon.isHidden()),i.verticalPlacedIconSymbolIndex>=0&&(d(e.icon,i.numVerticalIconVertices,A?Pe:M),e.icon.placedSymbolArray.get(i.verticalPlacedIconSymbolIndex).hidden=m.icon.isHidden())}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var S=e.collisionArrays[n];if(S){var E=new t.Point(0,0);if(S.textBox||S.verticalTextBox){var C=!0;if(c){var L=a.variableOffsets[g];L?(E=xe(L.anchor,L.width,L.height,L.textOffset,L.textBoxScale),u&&E._rotate(h?a.transform.angle:-a.transform.angle)):C=!1}S.textBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||x,E.x,E.y),S.verticalTextBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||b,E.x,E.y)}var P=Boolean(!b&&S.verticalIconBox);S.iconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,P,f?E.x:0,f?E.y:0),S.verticalIconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,!P,f?E.x:0,f?E.y:0)}}},m=0;m<e.symbolInstances.length;m++)g(m);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var v=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=v.invProjMatrix,e.placementViewportMatrix=v.viewportMatrix,e.collisionCircleArray=v.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},_e.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},_e.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},_e.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},_e.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},_e.prototype.setStale=function(){this.stale=!0};var Te=Math.pow(2,25),ke=Math.pow(2,24),Me=Math.pow(2,17),Ae=Math.pow(2,16),Se=Math.pow(2,9),Ee=Math.pow(2,8),Ce=Math.pow(2,1);function Le(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Te+e*ke+r*Me+e*Ae+r*Se+e*Ee+r*Ce+e}var Pe=0,Ie=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Ie.prototype.continuePlacement=function(t,e,r,n,a){for(var i=this._bucketParts;this._currentTileIndex<t.length;)if(e.getBucketParts(i,n,t[this._currentTileIndex],this._sortAcrossTiles),this._currentTileIndex++,a())return!0;for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,i.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<i.length;)if(e.placeLayerBucketPart(i[this._currentPartIndex],this._seenCrossTileIDs,r),this._currentPartIndex++,a())return!0;return!1};var ze=function(t,e,r,n,a,i,o){this.placement=new _e(t,a,i,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};ze.prototype.isDone=function(){return this._done},ze.prototype.continuePlacement=function(e,r,n){for(var a=this,i=t.browser.now(),o=function(){var e=t.browser.now()-i;return!a._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ie(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},ze.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Oe=512/t.EXTENT/2,De=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var a=e.get(n),i=a.key;this.indexedSymbolInstances[i]||(this.indexedSymbolInstances[i]=[]),this.indexedSymbolInstances[i].push({crossTileID:a.crossTileID,coord:this.getScaledCoordinates(a,t)})}};De.prototype.getScaledCoordinates=function(e,r){var n=Oe/Math.pow(2,r.canonical.z-this.tileID.canonical.z);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*n),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*n)}},De.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),a=0;a<t.length;a++){var i=t.get(a);if(!i.crossTileID){var o=this.indexedSymbolInstances[i.key];if(o)for(var s=this.getScaledCoordinates(i,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,i.crossTileID=u.crossTileID;break}}}}};var Re=function(){this.maxCrossTileID=0};Re.prototype.generate=function(){return++this.maxCrossTileID};var Fe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Fe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],a={};for(var i in n){var o=n[i];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),a[o.tileID.key]=o}this.indexes[r]=a}this.lng=t},Fe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var a=this.usedCrossTileIDs[t.overscaledZ];for(var i in this.indexes){var o=this.indexes[i];if(Number(i)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,a)}else{var c=o[t.scaledTo(Number(i)).key];c&&c.findMatches(e.symbolInstances,t,a)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),a[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new De(t,e.symbolInstances,e.bucketInstanceId),!0},Fe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,a=e.indexedSymbolInstances[r];n<a.length;n+=1)delete this.usedCrossTileIDs[t][a[n].crossTileID]},Fe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var a in n)t[n[a].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[a]),delete n[a],e=!0)}return e};var Be=function(){this.layerIndexes={},this.crossTileIDs=new Re,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Be.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Fe);var a=!1,i={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(a=!0),i[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(i)&&(a=!0),a},Be.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Ne=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},je=t.pick(Ut,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ue=t.pick(Ut,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Ve=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var a,i=t.styleSpec.$root[n];i.required&&null!=(a=\"version\"===n?r:\"array\"===i.type?[]:{})&&(e[n]=a)}return e}(),qe=function(e){function r(n,a){var i=this;void 0===a&&(a={}),e.call(this),this.map=n,this.dispatcher=new k(Bt(),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,a.localIdeographFontFamily),this.lineAtlas=new T(256,512),this.crossTileSymbolIndex=new Be,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){o.dispatcher.broadcast(\"syncRTLPluginState\",{pluginStatus:e.pluginStatus,pluginURL:e.pluginURL},(function(e,r){if(t.triggerPluginCompletionEvent(e),r&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=i.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in i._layers){var a=i._layers[n];a.source===r.id&&i._validateLayer(a)}}}}))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var a=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var i=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(i,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,a)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(Ve,!1)},r.prototype._load=function(e,r){if(!r||!Ne(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=jt(this.stylesheet.layers);this._order=a.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var i=0,o=a;i<o.length;i+=1){var s=o[i];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var a,i,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,a=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,i=e,u())}));function u(){if(o)n(o);else if(a&&i){var e=t.browser.getImageData(i),r={};for(var s in a){var l=a[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=l.stretchX,m=l.stretchY,v=l.content,y=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,y,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:y,pixelRatio:d,sdf:p,stretchX:g,stretchY:m,content:v}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var a in n)r.imageManager.addImage(a,n[a]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var a=r.getSource();(\"geojson\"===a.type||a.vectorLayerIds&&-1===a.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+a.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var a=this._layers[n[r]];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),a=Object.keys(this._removedLayers);for(var i in(n.length||a.length)&&this._updateWorkerLayers(n,a),this._updatedSources){var o=this._updatedSources[i];\"reload\"===o?this._reloadSource(i):\"clear\"===o&&this._clearSource(i)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=this._layers[u[c]];h.recalculate(e,this._availableImages),!h.isHidden(e.zoom)&&h.source&&(this.sourceCaches[h.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Ne(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=jt(e.layers);var n=function(e,r){if(!e)return[{command:Ut.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Ut.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Ut.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Ut.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Ut.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Ut.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Ut.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Ut.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Ut.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Ut.setLight,args:[r.light]});var a={},i=[];!function(e,r,n,a){var i;for(i in r=r||{},e=e||{})e.hasOwnProperty(i)&&(r.hasOwnProperty(i)||qt(i,n,a));for(i in r)r.hasOwnProperty(i)&&(e.hasOwnProperty(i)?t.deepEqual(e[i],r[i])||(\"geojson\"===e[i].type&&\"geojson\"===r[i].type&&Gt(e,r,i)?n.push({command:Ut.setGeoJSONSourceData,args:[i,r[i].data]}):Ht(i,r,n,a)):Vt(i,r,n))}(e.sources,r.sources,i,a);var o=[];e.layers&&e.layers.forEach((function(t){a[t.source]?n.push({command:Ut.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(i),function(e,r,n){r=r||[];var a,i,o,s,l,c,u,h=(e=e||[]).map(Wt),f=r.map(Wt),p=e.reduce(Zt,{}),d=r.reduce(Zt,{}),g=h.slice(),m=Object.create(null);for(a=0,i=0;a<h.length;a++)d.hasOwnProperty(o=h[a])?i++:(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.indexOf(o,i),1));for(a=0,i=0;a<f.length;a++)g[g.length-1-a]!==(o=f[f.length-1-a])&&(p.hasOwnProperty(o)?(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-i),1)):i++,n.push({command:Ut.addLayer,args:[d[o],c=g[g.length-a]]}),g.splice(g.length-a,0,o),m[o]=!0);for(a=0;a<f.length;a++)if(s=p[o=f[a]],l=d[o],!m[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,Ut.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,Ut.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Ut.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Ut.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Ut.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Ut.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Ut.setStyle,args:[r]}]}return n}(this.serialize(),e).filter((function(t){return!(t.command in Ue)}));if(0===n.length)return!1;var a=n.filter((function(t){return!(t.command in je)}));if(a.length>0)throw new Error(\"Unimplemented: \"+a.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var a=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var i=this.sourceCaches[e]=new Lt(e,r,this.dispatcher);i.style=this,i.setEventedParent(this,(function(){return{isSourceLoaded:a.loaded(),source:i.serialize(),sourceId:e}})),i.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var a=e.id;if(this.getLayer(a))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+a+'\" already exists on this map')));else{var i;if(\"custom\"===e.type){if(Ne(this,t.validateCustomStyleLayer(e)))return;i=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(a,e.source),e=t.clone$1(e),e=t.extend(e,{source:a})),this._validate(t.validateStyle.layer,\"layers.\"+a,e,{arrayIndex:-1},n))return;i=t.createStyleLayer(e),this._validateLayer(i),i.setEventedParent(this,{layer:{id:a}}),this._serializedLayers[i.id]=i.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,a),this._layerOrderChanged=!0,this._layers[a]=i,this._removedLayers[a]&&i.source&&\"custom\"!==i.type){var s=this._removedLayers[a];delete this._removedLayers[a],s.type!==i.type?this._updatedSources[i.source]=\"clear\":(this._updatedSources[i.source]=\"reload\",this.sourceCaches[i.source].pause())}this._updateLayer(i),i.onAdd&&i.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var a=r?this._order.indexOf(r):this._order.length;r&&-1===a?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(a,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var a=this.getLayer(e);a?a.minzoom===r&&a.maxzoom===n||(null!=r&&(a.minzoom=r),null!=n&&(a.maxzoom=n),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var a=this.getLayer(e);if(a){if(!t.deepEqual(a.filter,r))return null==r?(a.filter=void 0,void this._updateLayer(a)):void(this._validate(t.validateStyle.filter,\"layers.\"+a.id+\".filter\",r,null,n)||(a.filter=t.clone$1(r),this._updateLayer(a)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,a){void 0===a&&(a={}),this._checkLoaded();var i=this.getLayer(e);i?t.deepEqual(i.getLayoutProperty(r),n)||(i.setLayoutProperty(r,n,a),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,a){void 0===a&&(a={}),this._checkLoaded();var i=this.getLayer(e);i?t.deepEqual(i.getPaintProperty(r),n)||(i.setPaintProperty(r,n,a)&&this._updateLayer(i),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,a=e.sourceLayer,i=this.sourceCaches[n];if(void 0!==i){var o=i.getSource().type;\"geojson\"===o&&a?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||a?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.setFeatureState(a,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,a=this.sourceCaches[n];if(void 0!==a){var i=a.getSource().type,o=\"vector\"===i?e.sourceLayer:void 0;\"vector\"!==i||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):a.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,a=this.sourceCaches[r];if(void 0!==a){if(\"vector\"!==a.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},a=[],i=this._order.length-1;i>=0;i--){var o=this._order[i];if(r(o)){n[o]=i;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1)a.push(h[u])}}}a.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var f=[],p=this._order.length-1;p>=0;p--){var d=this._order[p];if(r(d))for(var g=a.length-1;g>=0;g--){var m=a[g].feature;if(n[m.layer.id]<p)break;f.push(m),a.pop()}else for(var v=0,y=t;v<y.length;v+=1){var x=y[v][d];if(x)for(var b=0,_=x;b<_.length;b+=1)f.push(_[b].feature)}}return f},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var a={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var i=0,o=r.layers;i<o.length;i+=1){var s=o[i],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];a[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!a[u]||c.push(F(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,a,i,o){for(var s={},l=i.queryRenderedSymbols(n),c=[],u=0,h=Object.keys(l).map(Number);u<h.length;u+=1)c.push(o[h[u]]);c.sort(B);for(var f=function(){var r=d[p],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,a.filter,a.layers,a.availableImages,t);for(var i in n){var o=s[i]=s[i]||[],c=n[i];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var a=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-a}return e.featureIndex-t.featureIndex}));for(var u=0,h=c;u<h.length;u+=1)o.push(h[u])}},p=0,d=c;p<d.length;p+=1)f();var g=function(e){s[e].forEach((function(n){var a=n.feature,i=r[t[e].source].getFeatureState(a.layer[\"source-layer\"],a.id);a.source=a.layer.source,a.layer[\"source-layer\"]&&(a.sourceLayer=a.layer[\"source-layer\"]),a.state=i}))};for(var m in s)g(m);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],a={},i=0;i<r.length;i++){var o=r[i],s=o.tileID.canonical.key;a[s]||(a[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),a=!1;for(var i in e)if(!t.deepEqual(e[i],n[i])){a=!0;break}if(a){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,a,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&Ne(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},a)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers)this._layers[e].setEventedParent(null);for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,a,i){void 0===i&&(i=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var h=this._layers[u[c]];if(\"symbol\"===h.type){if(!l[h.source]){var f=this.sourceCaches[h.source];l[h.source]=f.getRenderableIds(!0).map((function(t){return f.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var p=this.crossTileSymbolIndex.addLayer(h,l[h.source],e.center.lng);o=o||p}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((i=i||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new ze(e,this._order,i,r,n,a,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var d=0,g=this._order;d<g.length;d+=1){var m=this._layers[g[d]];\"symbol\"===m.type&&this.placement.updateLayerOpacities(m,l[m.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);qe.getSourceType=function(t){return D[t]},qe.setSourceType=function(t,e){D[t]=e},qe.registerForPluginStateChange=t.registerForPluginStateChange;var He=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Ge=vr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Ye=vr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=vr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Ze=vr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Xe=vr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Je=vr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),Ke=vr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),Qe=vr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),$e=vr(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),tr=vr(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),er=vr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),rr=vr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),nr=vr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ar=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),ir=vr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),or=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),sr=vr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),lr=vr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),cr=vr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),ur=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),hr=vr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),fr=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),pr=vr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),dr=vr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),gr=vr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),mr=vr(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function vr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,(function(t,e,r,a,i){return n[i]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\nvarying \"+r+\" \"+a+\" \"+i+\";\\n#else\\nuniform \"+r+\" \"+a+\" u_\"+i+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+i+\"\\n    \"+r+\" \"+a+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,a,i){var o=\"float\"===a?\"vec2\":\"vec4\",s=i.match(/color/)?\"color\":o;return n[i]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\nuniform lowp float u_\"+i+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+i+\";\\nvarying \"+r+\" \"+a+\" \"+i+\";\\n#else\\nuniform \"+r+\" \"+a+\" u_\"+i+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+i+\" = a_\"+i+\";\\n#else\\n    \"+r+\" \"+a+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+i+\" = unpack_mix_\"+s+\"(a_\"+i+\", u_\"+i+\"_t);\\n#else\\n    \"+r+\" \"+a+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\nuniform lowp float u_\"+i+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+i+\";\\n#else\\nuniform \"+r+\" \"+a+\" u_\"+i+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+r+\" \"+a+\" \"+i+\" = a_\"+i+\";\\n#else\\n    \"+r+\" \"+a+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+i+\"\\n    \"+r+\" \"+a+\" \"+i+\" = unpack_mix_\"+s+\"(a_\"+i+\", u_\"+i+\"_t);\\n#else\\n    \"+r+\" \"+a+\" \"+i+\" = u_\"+i+\";\\n#endif\\n\"}))}}var yr=Object.freeze({__proto__:null,prelude:Ge,background:Ye,backgroundPattern:We,circle:Ze,clippingMask:Xe,heatmap:Je,heatmapTexture:Ke,collisionBox:Qe,collisionCircle:$e,debug:tr,fill:er,fillOutline:rr,fillOutlinePattern:nr,fillPattern:ar,fillExtrusion:ir,fillExtrusionPattern:or,hillshadePrepare:sr,hillshade:lr,line:cr,lineGradient:ur,linePattern:hr,lineSDF:fr,raster:pr,symbolIcon:dr,symbolSDF:gr,symbolTextAndIcon:mr}),xr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};xr.prototype.bind=function(t,e,r,n,a,i,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);t.extVertexArrayObject&&this.vao&&this.boundProgram===e&&this.boundLayoutVertexBuffer===r&&!l&&this.boundIndexBuffer===a&&this.boundVertexOffset===i&&this.boundDynamicVertexBuffer===o&&this.boundDynamicVertexBuffer2===s?(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),a&&a.dynamicDraw&&a.bind(),s&&s.bind()):this.freshBind(e,r,n,a,i,o,s)},xr.prototype.freshBind=function(t,e,r,n,a,i,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=a,this.boundDynamicVertexBuffer=i,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);i&&i.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,a);for(var d=0,g=r;d<g.length;d+=1){var m=g[d];m.bind(),m.setVertexAttribPointers(u,t,a)}i&&(i.bind(),i.setVertexAttribPointers(u,t,a)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,a)),c.currentNumAttributes=l},xr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var br=function(t,e,r,n,a){var i=t.gl;this.program=i.createProgram();var o=r?r.defines():[];a&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Ge.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Ge.vertexSource,e.vertexSource).join(\"\\n\"),c=i.createShader(i.FRAGMENT_SHADER);if(i.isContextLost())this.failedToCreate=!0;else{i.shaderSource(c,s),i.compileShader(c),i.attachShader(this.program,c);var u=i.createShader(i.VERTEX_SHADER);if(i.isContextLost())this.failedToCreate=!0;else{i.shaderSource(u,l),i.compileShader(u),i.attachShader(this.program,u);for(var h=r?r.layoutAttributes:[],f=0;f<h.length;f++)i.bindAttribLocation(this.program,f,h[f].name);i.linkProgram(this.program),i.deleteShader(u),i.deleteShader(c),this.numAttributes=i.getProgramParameter(this.program,i.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=i.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=i.getAttribLocation(this.program,g.name))}for(var m=i.getProgramParameter(this.program,i.ACTIVE_UNIFORMS),v=0;v<m;v++){var y=i.getActiveUniform(this.program,v);y&&(p[y.name]=i.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r?r.getUniforms(t,p):[]}}};function _r(t,e,r){var n=1/fe(r,1,e.transform.tileZoom),a=Math.pow(2,r.tileID.overscaledZ),i=r.tileSize*Math.pow(2,e.transform.tileZoom)/a,o=i*(r.tileID.canonical.x+r.tileID.wrap*a),s=i*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}br.prototype.draw=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var m,v=t.gl;if(!this.failedToCreate){for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(a),t.setCullFace(i),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(m={},m[v.LINES]=2,m[v.TRIANGLES]=3,m[v.LINE_STRIP]=1,m)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new xr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),v.drawElements(e,w.primitiveLength*x,v.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var wr=function(e,r,n,a){var i=r.style.light,o=i.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===i.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=i.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:i.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:a}},Tr=function(e,r,n,a,i,o,s){return t.extend(wr(e,r,n,a),_r(o,r,s),{u_height_factor:-Math.pow(2,i.overscaledZ)/s.tileSize/8})},kr=function(t){return{u_matrix:t}},Mr=function(e,r,n,a){return t.extend(kr(e),_r(n,r,a))},Ar=function(t,e){return{u_matrix:t,u_world:e}},Sr=function(e,r,n,a,i){return t.extend(Mr(e,r,n,a),{u_world:i})},Er=function(e,r,n,a){var i,o,s=e.transform;if(\"map\"===a.paint.get(\"circle-pitch-alignment\")){var l=fe(n,1,s.zoom);i=!0,o=[l,l]}else i=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===a.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,a.paint.get(\"circle-translate\"),a.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+i,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Cr=function(t,e,r){var n=fe(r,1,e.zoom),a=Math.pow(2,e.zoom-r.tileID.overscaledZ),i=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*a),e.pixelsToGLUnits[1]/(n*a)],u_overscale_factor:i}},Lr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Pr=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Ir=function(t){return{u_matrix:t}},zr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:fe(e,1,r),u_intensity:n}},Or=function(e,r,n){var a=e.transform;return{u_matrix:Nr(e,r,n),u_ratio:1/fe(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Dr=function(e,r,n){return t.extend(Or(e,r,n),{u_image:0})},Rr=function(e,r,n,a){var i=e.transform,o=Br(r,i);return{u_matrix:Nr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/fe(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,a.fromScale,a.toScale],u_fade:a.t,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Fr=function(e,r,n,a,i){var o=e.lineAtlas,s=Br(r,e.transform),l=\"round\"===n.layout.get(\"line-cap\"),c=o.getDash(a.from,l),u=o.getDash(a.to,l),h=c.width*i.fromScale,f=u.width*i.toScale;return t.extend(Or(e,r,n),{u_patternscale_a:[s/h,-c.height/2],u_patternscale_b:[s/f,-u.height/2],u_sdfgamma:o.width/(256*Math.min(h,f)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:c.y,u_tex_y_b:u.y,u_mix:i.t})};function Br(t,e){return 1/fe(t,1,e.tileZoom)}function Nr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var jr=function(t,e,r,n,a){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*a.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:a.paint.get(\"raster-brightness-min\"),u_brightness_high:a.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=a.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(i=a.paint.get(\"raster-contrast\"),i>0?1/(1-i):1+i),u_spin_weights:Ur(a.paint.get(\"raster-hue-rotate\"))};var i,o};function Ur(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Vr,qr=function(t,e,r,n,a,i,o,s,l,c){var u=a.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:a.options.fadeDuration?a.symbolFadeChange:1,u_matrix:i,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Hr=function(e,r,n,a,i,o,s,l,c,u,h){var f=i.transform;return t.extend(qr(e,r,n,a,i,o,s,l,c,u),{u_gamma_scale:a?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Gr=function(e,r,n,a,i,o,s,l,c,u){return t.extend(Hr(e,r,n,a,i,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},Yr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Wr=function(e,r,n,a,i,o){return t.extend(function(t,e,r,n){var a=r.imageManager.getPattern(t.from.toString()),i=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:a.tl,u_pattern_br_a:a.br,u_pattern_tl_b:i.tl,u_pattern_br_b:i.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:a.displaySize,u_pattern_size_b:i.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/fe(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(a,o,n,i),{u_matrix:e,u_opacity:r})},Zr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Xr(e,r,n,a,i,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),h=[],f=0,p=0,d=0;d<a.length;d++){var g=a[d],m=r.getTile(g),v=m.getBucket(n);if(v){var y=g.posMatrix;0===i[0]&&0===i[1]||(y=e.translatePosMatrix(g.posMatrix,m,i,o));var x=s?v.textCollisionBox:v.iconCollisionBox,b=v.collisionCircleArray;if(b.length>0){var _=t.create(),w=y;t.mul(_,v.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(_,_,v.placementViewportMatrix),h.push({circleArray:b,circleOffset:p,transform:w,invTransform:_}),p=f+=b.length/4}x&&u.draw(l,c.LINES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,Cr(y,e.transform,m),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&h.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*f),k._trim();for(var M=0,A=0,S=h;A<S.length;A+=1)for(var E=S[A],C=0;C<E.circleArray.length/4;C++){var L=4*C,P=E.circleArray[L+0],I=E.circleArray[L+1],z=E.circleArray[L+2],O=E.circleArray[L+3];k.emplace(M++,P,I,z,O,0),k.emplace(M++,P,I,z,O,1),k.emplace(M++,P,I,z,O,2),k.emplace(M++,P,I,z,O,3)}(!Vr||Vr.length<2*f)&&(Vr=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var a=0;a<r;a++){var i=6*a;n.uint16[i+0]=4*a+0,n.uint16[i+1]=4*a+1,n.uint16[i+2]=4*a+2,n.uint16[i+3]=4*a+2,n.uint16[i+4]=4*a+3,n.uint16[i+5]=4*a+0}return n}(f));for(var D=l.createIndexBuffer(Vr,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=h;F<B.length;F+=1){var N=B[F],j=Lr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var Jr=t.identity(new Float32Array(16));function Kr(e,r,n,a,i,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,a);return new t.Point((l/i+u[0])*o,(c/i+u[1])*o)}function Qr(e,r,n,a,i,o,s,l,c,u,h){var f=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,g={};p.clear();for(var m=0;m<f.length;m++){var v=f.get(m),y=v.hidden||!v.crossTileID||e.allowVerticalPlacement&&!v.placedOrientation?null:a[v.crossTileID];if(y){var x=new t.Point(v.anchorX,v.anchorY),b=$t(x,n?l:s),_=te(o.cameraToCenterDistance,b.signedDistanceFromCamera),w=i.evaluateSizeForFeature(e.textSizeData,u,v)*_/t.ONE_EM;n&&(w*=e.tilePixelRatio/c);for(var T=Kr(y.anchor,y.width,y.height,y.textOffset,y.textBoxScale,w),k=n?$t(x.add(T),s).point:b.point.add(r?T.rotate(-o.angle):T),M=e.allowVerticalPlacement&&v.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,A=0;A<v.numGlyphs;A++)t.addDynamicAttributes(p,k,M);h&&v.associatedIconIndex>=0&&(g[v.associatedIconIndex]={shiftedAnchor:k,angle:M})}else ce(v.numGlyphs,p)}if(h){d.clear();for(var S=e.icon.placedSymbolArray,E=0;E<S.length;E++){var C=S.get(E);if(C.hidden)ce(C.numGlyphs,d);else{var L=g[E];if(L)for(var P=0;P<C.numGlyphs;P++)t.addDynamicAttributes(d,L.shiftedAnchor,L.angle);else ce(C.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function $r(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function tn(e,r,n,a,i,o,s,l,c,u,h,f){for(var p=e.context,d=p.gl,g=e.transform,m=\"map\"===l,v=\"map\"===c,y=m&&\"point\"!==n.layout.get(\"symbol-placement\"),x=m&&!v&&!y,b=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),_=e.depthModeForSublayer(0,Mt.ReadOnly),w=n.layout.get(\"text-variable-anchor\"),T=[],k=0,M=a;k<M.length;k+=1){var A=M[k],S=r.getTile(A),E=S.getBucket(n);if(E){var C=i?E.text:E.icon;if(C&&C.segments.get().length){var L=C.programConfigurations.get(n.id),P=i||E.sdfIcons,I=i?E.textSizeData:E.iconSizeData,z=v||0!==g.pitch,O=e.useProgram($r(P,i,E),L),D=t.evaluateSizeForZoom(I,g.zoom),R=void 0,F=[0,0],B=void 0,N=void 0,j=null,U=void 0;if(i)B=S.glyphAtlasTexture,N=d.LINEAR,R=S.glyphAtlasTexture.size,E.iconsInText&&(F=S.imageAtlasTexture.size,j=S.imageAtlasTexture,U=z||e.options.rotating||e.options.zooming||\"composite\"===I.kind||\"camera\"===I.kind?d.LINEAR:d.NEAREST);else{var V=1!==n.layout.get(\"icon-size\").constantOr(0)||E.iconsNeedLinear;B=S.imageAtlasTexture,N=P||e.options.rotating||e.options.zooming||V||z?d.LINEAR:d.NEAREST,R=S.imageAtlasTexture.size}var q=fe(S,1,e.transform.zoom),H=Kt(A.posMatrix,v,m,e.transform,q),G=Qt(A.posMatrix,v,m,e.transform,q),Y=w&&E.hasTextData(),W=\"none\"!==n.layout.get(\"icon-text-fit\")&&Y&&E.hasIconData();y&&re(E,A.posMatrix,e,i,H,G,v,u);var Z=e.translatePosMatrix(A.posMatrix,S,o,s),X=y||i&&w||W?Jr:H,J=e.translatePosMatrix(G,S,o,s,!0),K=P&&0!==n.paint.get(i?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Q={program:O,buffers:C,uniformValues:P?E.iconsInText?Gr(I.kind,D,x,v,e,Z,X,J,R,F):Hr(I.kind,D,x,v,e,Z,X,J,i,R,!0):qr(I.kind,D,x,v,e,Z,X,J,i,R),atlasTexture:B,atlasTextureIcon:j,atlasInterpolation:N,atlasInterpolationIcon:U,isSDF:P,hasHalo:K};if(b)for(var $=0,tt=C.segments.get();$<tt.length;$+=1){var et=tt[$];T.push({segments:new t.SegmentVector([et]),sortKey:et.sortKey,state:Q})}else T.push({segments:C.segments,sortKey:0,state:Q})}}}b&&T.sort((function(t,e){return t.sortKey-e.sortKey}));for(var rt=0,nt=T;rt<nt.length;rt+=1){var at=nt[rt],it=at.state;if(p.activeTexture.set(d.TEXTURE0),it.atlasTexture.bind(it.atlasInterpolation,d.CLAMP_TO_EDGE),it.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),it.atlasTextureIcon&&it.atlasTextureIcon.bind(it.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),it.isSDF){var ot=it.uniformValues;it.hasHalo&&(ot.u_is_halo=1,en(it.buffers,at.segments,n,e,it.program,_,h,f,ot)),ot.u_is_halo=0}en(it.buffers,at.segments,n,e,it.program,_,h,f,it.uniformValues)}}function en(t,e,r,n,a,i,o,s,l){var c=n.context;a.draw(c,c.gl.TRIANGLES,i,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function rn(t,e,r,n,a,i,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var m=0,v=n;m<v.length;m+=1){var y=v[m],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePaintBuffers(g));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,M=k.patternPositions[T.to.toString()],A=k.patternPositions[T.from.toString()];M&&A&&_.setConstantPatternPositions(M,A)}var S=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var E=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Sr(S,t,g,x,E):Ar(S,E)}else u=b.indexBuffer,h=b.segments,c=d?Mr(S,t,g,x):kr(S);w.draw(t.context,s,a,t.stencilModeForClipping(y),i,Et.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function nn(t,e,r,n,a,i,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],m=e.getTile(g),v=m.getBucket(r);if(v){var y=v.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),m.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(h));var b=c.constantOr(null);if(b&&m.imageAtlas){var _=m.imageAtlas,w=_.patternPositions[b.to.toString()],T=_.patternPositions[b.from.toString()];w&&T&&y.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(g.posMatrix,m,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),M=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?Tr(k,t,M,f,g,h,m):wr(k,t,M,f);x.draw(s,s.gl.TRIANGLES,a,i,o,Et.backCCW,A,r.id,v.layoutVertexBuffer,v.indexBuffer,v.segments,r.paint,t.transform.zoom,y)}}}function an(e,r,n,a,i,o){var s=e.context,l=s.gl,c=r.fbo;if(c){var u=e.useProgram(\"hillshade\");s.activeTexture.set(l.TEXTURE0),l.bindTexture(l.TEXTURE_2D,c.colorAttachment.get());var h=function(e,r,n){var a=n.paint.get(\"hillshade-shadow-color\"),i=n.paint.get(\"hillshade-highlight-color\"),o=n.paint.get(\"hillshade-accent-color\"),s=n.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===n.paint.get(\"hillshade-illumination-anchor\")&&(s-=e.transform.angle);var l,c,u,h=!e.options.moving;return{u_matrix:e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),h),u_image:0,u_latrange:(l=r.tileID,c=Math.pow(2,l.canonical.z),u=l.canonical.y,[new t.MercatorCoordinate(0,u/c).toLngLat().lat,new t.MercatorCoordinate(0,(u+1)/c).toLngLat().lat]),u_light:[n.paint.get(\"hillshade-exaggeration\"),s],u_shadow:a,u_highlight:i,u_accent:o}}(e,r,n);u.draw(s,l.TRIANGLES,a,i,o,Et.disabled,h,n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments)}}function on(e,r,n,a,i,o,s){var l=e.context,c=l.gl,u=r.dem;if(u&&u.data){var h=u.dim,f=u.stride,p=u.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(f),r.demTexture){var d=r.demTexture;d.update(p,{premultiply:!1}),d.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,p,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var g=r.fbo;if(!g){var m=new t.Texture(l,{width:h,height:h,data:null},c.RGBA);m.bind(c.LINEAR,c.CLAMP_TO_EDGE),(g=r.fbo=l.createFramebuffer(h,h,!0)).colorAttachment.set(m.texture)}l.bindFramebuffer.set(g.framebuffer),l.viewport.set([0,0,h,h]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,i,o,s,Et.disabled,function(e,r,n){var a=r.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[a,a],u_zoom:e.overscaledZ,u_maxzoom:n,u_unpack:r.getUnpackVector()}}(r.tileID,u,a),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function sn(e,r,n,a,i){var o=a.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=i.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var ln=new t.Color(1,0,0,1),cn=new t.Color(0,1,0,1),un=new t.Color(0,0,1,1),hn=new t.Color(1,0,1,1),fn=new t.Color(0,1,1,1);function pn(t,e,r,n){gn(t,0,e+r/2,t.transform.width,r,n)}function dn(t,e,r,n){gn(t,e-r/2,0,r,t.transform.height,n)}function gn(e,r,n,a,i,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function mn(e,r,n){var a=e.context,i=a.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass();a.activeTexture.set(i.TEXTURE0),e.emptyTexture.bind(i.LINEAR,i.CLAMP_TO_EDGE),s.draw(a,i.LINE_STRIP,l,c,u,Et.disabled,Pr(o,t.Color.red),\"$debug\",e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var h=r.getTileByID(n.key).latestRawTileData,f=Math.floor((h&&h.byteLength||0)/1024),p=r.getTile(n).tileSize,d=512/Math.min(p,512)*(n.overscaledZ/e.transform.zoom)*.5,g=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(g+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,a=t.debugOverlayCanvas.getContext(\"2d\");a.clearRect(0,0,r.width,r.height),a.shadowColor=\"white\",a.shadowBlur=2,a.lineWidth=1.5,a.strokeStyle=\"white\",a.textBaseline=\"top\",a.font=\"bold 36px Open Sans, sans-serif\",a.fillText(e,5,5),a.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,g+\" \"+f+\"kb\"),s.draw(a,i.TRIANGLES,l,c,St.alphaBlended,Et.disabled,Pr(o,t.Color.transparent,d),\"$debug\",e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var vn={symbol:function(e,r,n,a,i){if(\"translucent\"===e.renderPass){var o=At.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,a,i,o,s){for(var l=r.transform,c=\"map\"===i,u=\"map\"===o,h=0,f=e;h<f.length;h+=1){var p=f[h],d=a.getTile(p),g=d.getBucket(n);if(g&&g.text&&g.text.segments.get().length){var m=t.evaluateSizeForZoom(g.textSizeData,l.zoom),v=fe(d,1,r.transform.zoom),y=Kt(p.posMatrix,u,c,r.transform,v),x=\"none\"!==n.layout.get(\"icon-text-fit\")&&g.hasIconData();if(m){var b=Math.pow(2,l.zoom-d.tileID.overscaledZ);Qr(g,c,u,s,t.symbolSize,l,y,p.posMatrix,b,m,x)}}}}(a,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),i),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&tn(e,r,n,a,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&tn(e,r,n,a,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Xr(e,r,n,a,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),Xr(e,r,n,a,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,a){if(\"translucent\"===e.renderPass){var i=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==i.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,h=e.depthModeForSublayer(0,Mt.ReadOnly),f=At.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<a.length;g++){var m=a[g],v=r.getTile(m),y=v.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:Er(e,m,v,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var T=w[_];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,M=d;k<M.length;k+=1){var A=M[k],S=A.state;S.program.draw(c,u.TRIANGLES,h,f,p,Et.disabled,S.uniformValues,n.id,S.layoutVertexBuffer,S.indexBuffer,A.segments,n.paint,e.transform.zoom,S.programConfiguration)}}}},heatmap:function(e,r,n,a){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var i=e.context,o=i.gl,s=At.disabled,l=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var a=r.heatmapFbo;if(a)n.bindTexture(n.TEXTURE_2D,a.colorAttachment.get()),t.bindFramebuffer.set(a.framebuffer);else{var i=n.createTexture();n.bindTexture(n.TEXTURE_2D,i),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),a=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var a=t.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,e.width/4,e.height/4,0,a.RGBA,t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),n.colorAttachment.set(r)}(t,e,i,a)}}(i,e,n),i.clear({color:t.Color.transparent});for(var c=0;c<a.length;c++){var u=a[c];if(!r.hasRenderableParent(u)){var h=r.getTile(u),f=h.getBucket(n);if(f){var p=f.programConfigurations.get(n.id);e.useProgram(\"heatmap\",p).draw(i,o.TRIANGLES,Mt.disabled,s,l,Et.disabled,zr(u.posMatrix,h,e.transform.zoom,n.paint.get(\"heatmap-intensity\")),n.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,n.paint,e.transform.zoom,p)}}}i.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,a=n.gl,i=r.heatmapFbo;if(i){n.activeTexture.set(a.TEXTURE0),a.bindTexture(a.TEXTURE_2D,i.colorAttachment.get()),n.activeTexture.set(a.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,a.RGBA)),o.bind(a.LINEAR,a.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,a.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,a){var i=t.create();t.ortho(i,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:i,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:0,u_color_ramp:1,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,a){if(\"translucent\"===e.renderPass){var i=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==i.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=h?\"linePattern\":c?\"lineSDF\":f?\"lineGradient\":\"line\",g=e.context,m=g.gl,v=!0;if(f){g.activeTexture.set(m.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,m.RGBA)),y.bind(m.LINEAR,m.CLAMP_TO_EDGE)}for(var x=0,b=a;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var T=w.getBucket(n);if(T){var k=T.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,k),S=v||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas,L=C.patternPositions[E.to.toString()],P=C.patternPositions[E.from.toString()];L&&P&&k.setConstantPatternPositions(L,P)}var I=h?Rr(e,w,n,p):c?Fr(e,w,n,c,p):f?Dr(e,w,n):Or(e,w,n);h?(g.activeTexture.set(m.TEXTURE0),w.imageAtlasTexture.bind(m.LINEAR,m.CLAMP_TO_EDGE),k.updatePaintBuffers(p)):c&&(S||e.lineAtlas.dirty)&&(g.activeTexture.set(m.TEXTURE0),e.lineAtlas.bind(g)),A.draw(g,m.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,I,n.id,T.layoutVertexBuffer,T.indexBuffer,T.segments,n.paint,e.transform.zoom,k),v=!1}}}}}},fill:function(e,r,n,a){var i=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===i.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);rn(e,r,n,a,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);rn(e,r,n,a,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var a=r.paint.get(\"fill-extrusion-opacity\");if(0!==a&&\"translucent\"===t.renderPass){var i=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==a||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))nn(t,e,r,n,i,At.disabled,St.disabled),nn(t,e,r,n,i,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();nn(t,e,r,n,i,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var a=t.context,i=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=t.colorModeForRenderPass(),l=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],c=l[0],u=0,h=l[1];u<h.length;u+=1){var f=h[u],p=e.getTile(f);p.needsHillshadePrepare&&\"offscreen\"===t.renderPass?on(t,p,r,i,o,At.disabled,s):\"translucent\"===t.renderPass&&an(t,p,r,o,c[f.overscaledZ],s)}a.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var a=t.context,i=a.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof I?[{},n]:t.stencilConfigForOverlap(n),u=c[0],h=c[1],f=h[h.length-1].overscaledZ,p=!t.options.moving,d=0,g=h;d<g.length;d+=1){var m=g[d],v=t.depthModeForSublayer(m.overscaledZ-f,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,i.LESS),y=e.getTile(m),x=t.transform.calculatePosMatrix(m.toUnwrapped(),p);y.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var b=e.findLoadedParent(m,0),_=sn(y,b,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?i.NEAREST:i.LINEAR;a.activeTexture.set(i.TEXTURE0),y.texture.bind(k,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST),a.activeTexture.set(i.TEXTURE1),b?(b.texture.bind(k,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,b.tileID.overscaledZ-y.tileID.overscaledZ),T=[y.tileID.canonical.x*w%1,y.tileID.canonical.y*w%1]):y.texture.bind(k,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST);var M=jr(x,T||[0,0],w||1,_,r);o instanceof I?s.draw(a,i.TRIANGLES,v,At.disabled,l,Et.disabled,M,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(a,i.TRIANGLES,v,u[m.overscaledZ],l,Et.disabled,M,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),a=r.paint.get(\"background-opacity\");if(0!==a){var i=t.context,o=i.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===a&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(i.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var m=r.getCrossfadeParameters(),v=0,y=g;v<y.length;v+=1){var x=y[v],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Wr(b,a,t,c,{tileID:x,tileSize:l},m):Yr(b,a,n);d.draw(i,o.TRIANGLES,f,h,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)mn(t,e,r[n])},custom:function(t,e,r){var n=t.context,a=r.implementation;if(\"offscreen\"===t.renderPass){var i=a.prerender;i&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),i.call(a,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===a.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),a.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},yn=function(t,e){this.context=new Ct(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Lt.maxUnderzooming+Lt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Be,this.gpuTimers={}};yn.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,a=this.style._order;n<a.length;n+=1)this.style._layers[a[n]].resize()},yn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,He.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,He.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var a=new t.StructArrayLayout4i8;a.emplaceBack(0,0,0,0),a.emplaceBack(t.EXTENT,0,t.EXTENT,0),a.emplaceBack(0,t.EXTENT,0,t.EXTENT),a.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(a,P.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var i=new t.StructArrayLayout2i4;i.emplaceBack(0,0),i.emplaceBack(1,0),i.emplaceBack(0,1),i.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(i,He.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},yn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Ir(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},yn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var a=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var i=0,o=e;i<o.length;i+=1){var s=o[i],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;a.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Ir(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},yn.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),a=n[n.length-1].overscaledZ,i=n[0].overscaledZ-a+1;if(i>1){this.currentStencilSource=void 0,this.nextStencilID+i>256&&this.clearStencil();for(var o={},s=0;s<i;s++)o[s+a]=new At({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=i,[o,n]}return[(e={},e[a]=At.disabled,e),n]},yn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?St.unblended:St.alphaBlended},yn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},yn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},yn.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var a=this.style._order,i=this.style.sourceCaches;for(var o in i){var s=i[o];s.used&&s.prepare(this.context)}var l,c,u={},h={},f={};for(var p in i){var d=i[p];u[p]=d.getVisibleCoordinates(),h[p]=u[p].slice().reverse(),f[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var g=0;g<a.length;g++)if(this.style._layers[a[g]].is3D()){this.opaquePassCutoff=g;break}this.renderPass=\"offscreen\";for(var m=0,v=a;m<v.length;m+=1){var y=this.style._layers[v[m]];if(y.hasOffscreenPass()&&!y.isHidden(this.transform.zoom)){var x=h[y.source];(\"custom\"===y.type||x.length)&&this.renderLayer(this,i[y.source],y,x)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=a.length-1;this.currentLayer>=0;this.currentLayer--){var b=this.style._layers[a[this.currentLayer]],_=i[b.source],w=u[b.source];this._renderTileClippingMasks(b,w),this.renderLayer(this,_,b,w)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<a.length;this.currentLayer++){var T=this.style._layers[a[this.currentLayer]],k=i[T.source],M=(\"symbol\"===T.type?f:h)[T.source];this._renderTileClippingMasks(T,u[T.source]),this.renderLayer(this,k,T,M)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&vn.debug(this,l,l.getVisibleCoordinates())),this.options.showPadding&&function(t){var e=t.transform.padding;pn(t,t.transform.height-(e.top||0),3,ln),pn(t,e.bottom||0,3,cn),dn(t,e.left||0,3,un),dn(t,t.transform.width-(e.right||0),3,hn);var r=t.transform.centerPoint;!function(t,e,r,n){gn(t,e-1,r-10,2,20,n),gn(t,e-10,r-1,20,2,n)}(t,r.x,t.transform.height-r.y,fn)}(this),this.context.setDefault()},yn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),vn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},yn.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},yn.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},yn.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},yn.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],a=this.context.extTimerQuery,i=a.getQueryObjectEXT(n.query,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(n.query),e[r]=i}return e},yn.prototype.translatePosMatrix=function(e,r,n,a,i){if(!n[0]&&!n[1])return e;var o=i?\"map\"===a?this.transform.angle:0:\"viewport\"===a?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[i?n[0]:fe(r,n[0],this.transform.zoom),i?n[1]:fe(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},yn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},yn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},yn.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},yn.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new br(this.context,yr[t],e,Zr[t],this._showOverdrawInspector)),this.cache[r]},yn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},yn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},yn.prototype.initDebugOverlayCanvas=function(){null==this.debugOverlayCanvas&&(this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512,this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,this.context.gl.RGBA))},yn.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var xn=function(t,e){this.points=t,this.planes=e};xn.fromInvProjectionMatrix=function(e,r,n){var a=Math.pow(2,n),i=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*a)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],i[e[0]],i[e[1]]),n=t.sub([],i[e[2]],i[e[1]]),a=t.normalize([],t.cross([],r,n)),o=-t.dot(a,i[e[1]]);return a.concat(o)}));return new xn(i,o)};var bn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};bn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),a=t.clone$2(this.max),i=0;i<r.length;i++)n[i]=r[i]?this.min[i]:this.center[i],a[i]=r[i]?this.center[i]:this.max[i];return a[2]=this.max[2],new bn(n,a)},bn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},bn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},bn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,a=0;a<e.planes.length;a++){for(var i=e.planes[a],o=0,s=0;s<r.length;s++)o+=t.dot$1(i,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,h=0;h<e.points.length;h++){var f=e.points[h][l]-this.min[l];c=Math.min(c,f),u=Math.max(u,f)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var _n=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};_n.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},_n.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),a=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,a)},_n.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},_n.prototype.clone=function(){return new _n(this.top,this.bottom,this.left,this.right)},_n.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var wn=function(e,r,n,a,i){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===i||i,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==a?60:a,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new _n,this._posMatrixCache={},this._alignedPosMatrixCache={}},Tn={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};wn.prototype.clone=function(){var t=new wn(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},Tn.minZoom.get=function(){return this._minZoom},Tn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Tn.maxZoom.get=function(){return this._maxZoom},Tn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Tn.minPitch.get=function(){return this._minPitch},Tn.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},Tn.maxPitch.get=function(){return this._maxPitch},Tn.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},Tn.renderWorldCopies.get=function(){return this._renderWorldCopies},Tn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Tn.worldSize.get=function(){return this.tileSize*this.scale},Tn.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},Tn.size.get=function(){return new t.Point(this.width,this.height)},Tn.bearing.get=function(){return-this.angle/Math.PI*180},Tn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Tn.pitch.get=function(){return this._pitch/Math.PI*180},Tn.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Tn.fov.get=function(){return this._fov/Math.PI*180},Tn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Tn.zoom.get=function(){return this._zoom},Tn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Tn.center.get=function(){return this._center},Tn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Tn.padding.get=function(){return this._edgeInsets.toJSON()},Tn.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},Tn.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},wn.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},wn.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},wn.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},wn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),a=this.pointCoordinate(new t.Point(this.width,0)),i=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,a.x,i.x,o.x)),l=Math.floor(Math.max(n.x,a.x,i.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},wn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var a=t.MercatorCoordinate.fromLngLat(this.center),i=Math.pow(2,r),o=[i*a.x,i*a.y,0],s=xn.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new bn([t*i,0,0],[(t+1)*i,i,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],h=[],f=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var g=u.pop(),m=g.x,v=g.y,y=g.fullyVisible;if(!y){var x=g.aabb.intersects(s);if(0===x)continue;y=2===x}var b=g.aabb.distanceX(o),_=g.aabb.distanceY(o),w=Math.max(Math.abs(b),Math.abs(_));if(g.zoom===f||w>3+(1<<f-g.zoom)-2&&g.zoom>=l)h.push({tileID:new t.OverscaledTileID(g.zoom===f?p:g.zoom,g.wrap,g.zoom,m,v),distanceSq:t.sqrLen([o[0]-.5-m,o[1]-.5-v])});else for(var T=0;T<4;T++){var k=(m<<1)+T%2,M=(v<<1)+(T>>1);u.push({aabb:g.aabb.quadrant(T),zoom:g.zoom+1,x:k,y:M,wrap:g.wrap,fullyVisible:y})}}return h.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},wn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Tn.unmodified.get=function(){return this._unmodified},wn.prototype.zoomScale=function(t){return Math.pow(2,t)},wn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},wn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},wn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},Tn.point.get=function(){return this.project(this.center)},wn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),a=this.pointCoordinate(this.centerPoint),i=this.locationCoordinate(e),o=new t.MercatorCoordinate(i.x-(n.x-a.x),i.y-(n.y-a.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},wn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},wn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},wn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},wn.prototype.coordinateLocation=function(t){return t.toLngLat()},wn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var a=r[3],i=n[3],o=r[1]/a,s=n[1]/i,l=r[2]/a,c=n[2]/i,u=l===c?0:(0-l)/(c-l);return new t.MercatorCoordinate(t.number(r[0]/a,n[0]/i,u)/this.worldSize,t.number(o,s,u)/this.worldSize)},wn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},wn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},wn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},wn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},wn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,a=r?this._alignedPosMatrixCache:this._posMatrixCache;if(a[n])return a[n];var i=e.canonical,o=this.worldSize/this.zoomScale(i.z),s=i.x+Math.pow(2,i.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,i.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),a[n]=new Float32Array(l),a[n]},wn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},wn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,a,i=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;i=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-i<c.y?c.y/(o-i):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+i)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,m=c.y/2;g-m<i&&(a=i+m),g+m>o&&(a=o-m)}if(this.lngRange){var v=p.x,y=c.x/2;v-y<s&&(n=s+y),v+y>l&&(n=l-y)}void 0===n&&void 0===a||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==a?a:p.y))),this._unmodified=u,this._constraining=!1}},wn.prototype._calcMatrices=function(){if(this.height){var e=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var r=Math.PI/2+this._pitch,n=this._fov*(.5+e.y/this.height),a=Math.sin(n)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-r-n,.01,Math.PI-.01)),i=this.point,o=i.x,s=i.y,l=1.01*(Math.cos(Math.PI/2-this._pitch)*a+this.cameraToCenterDistance),c=this.height/50,u=new Float64Array(16);t.perspective(u,this._fov,this.width/this.height,c,l),u[8]=2*-e.x/this.width,u[9]=2*e.y/this.height,t.scale(u,u,[1,-1,1]),t.translate(u,u,[0,0,-this.cameraToCenterDistance]),t.rotateX(u,u,this._pitch),t.rotateZ(u,u,this.angle),t.translate(u,u,[-o,-s,0]),this.mercatorMatrix=t.scale([],u,[this.worldSize,this.worldSize,this.worldSize]),t.scale(u,u,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=u,this.invProjMatrix=t.invert([],this.projMatrix);var h=this.width%2/2,f=this.height%2/2,p=Math.cos(this.angle),d=Math.sin(this.angle),g=o-Math.round(o)+p*h+d*f,m=s-Math.round(s)+p*f+d*h,v=new Float64Array(u);if(t.translate(v,v,[g>.5?g-1:g,m>.5?m-1:m,0]),this.alignedProjMatrix=v,u=t.create(),t.scale(u,u,[this.width/2,-this.height/2,1]),t.translate(u,u,[1,-1,0]),this.labelPlaneMatrix=u,u=t.create(),t.scale(u,u,[1,-1,1]),t.translate(u,u,[-1,-1,0]),t.scale(u,u,[2/this.width,2/this.height,1]),this.glCoordMatrix=u,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(u=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=u,this._posMatrixCache={},this._alignedPosMatrixCache={}}},wn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},wn.prototype.getCameraPoint=function(){var e=Math.tan(this._pitch)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,e))},wn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,a=r.y,i=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),a=Math.min(a,c.y),i=Math.max(i,c.x),o=Math.max(o,c.y)}return[new t.Point(n,a),new t.Point(i,a),new t.Point(i,o),new t.Point(n,o),new t.Point(n,a)]},Object.defineProperties(wn.prototype,Tn);var kn=function(e){var r,n,a,i;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=!1,a=null,i=function(){a=null,n&&(r(),a=setTimeout(i,300),n=!1)},function(){return n=!0,a||i(),a})};kn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},kn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},kn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,a=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,a),o=Math.round(r.lng*i)/i,s=Math.round(r.lat*i)/i,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var h=this._hashName,f=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===h?(f=!0,e+\"=\"+u):t})).filter((function(t){return t}));return f||p.push(h+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},kn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},kn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},kn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var Mn={linearity:.3,easing:t.bezier(0,0,.3,1)},An=t.extend({deceleration:2500,maxSpeed:1400},Mn),Sn=t.extend({deceleration:20,maxSpeed:1400},Mn),En=t.extend({deceleration:1e3,maxSpeed:360},Mn),Cn=t.extend({deceleration:1e3,maxSpeed:90},Mn),Ln=function(t){this._map=t,this.clear()};function Pn(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function In(e,r,n){var a=n.maxSpeed,i=n.linearity,o=n.deceleration,s=t.clamp(e*i/(r/1e3),-a,a),l=Math.abs(s)/(o*i);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}Ln.prototype.clear=function(){this._inertiaBuffer=[]},Ln.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},Ln.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},Ln.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,a=this._inertiaBuffer;n<a.length;n+=1){var i=a[n].settings;r.zoom+=i.zoomDelta||0,r.bearing+=i.bearingDelta||0,r.pitch+=i.pitchDelta||0,i.panDelta&&r.pan._add(i.panDelta),i.around&&(r.around=i.around),i.pinchAround&&(r.pinchAround=i.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=In(r.pan.mag(),o,t.extend({},An,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,Pn(s,l)}if(r.zoom){var c=In(r.zoom,o,Sn);s.zoom=this._map.transform.zoom+c.amount,Pn(s,c)}if(r.bearing){var u=In(r.bearing,o,En);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),Pn(s,u)}if(r.pitch){var h=In(r.pitch,o,Cn);s.pitch=this._map.transform.pitch+h.amount,Pn(s,h)}if(s.zoom||s.bearing){var f=void 0===r.pinchAround?r.around:r.pinchAround;s.around=f?this._map.unproject(f):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var zn=function(e){function n(n,a,i,o){void 0===o&&(o={});var s=r.mousePos(a.getCanvasContainer(),i),l=a.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:i},o)),this._defaultPrevented=!1,this.target=a}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var a={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},a.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,a),n}(t.Event),On=function(e){function n(n,a,i){var o=\"touchend\"===n?i.changedTouches:i.touches,s=r.touchPos(a.getCanvasContainer(),o),l=s.map((function(t){return a.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=a.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:i}),this._defaultPrevented=!1}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var a={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},a.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,a),n}(t.Event),Dn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Rn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Rn.prototype.reset=function(){delete this._mousedownPos},Rn.prototype.wheel=function(t){return this._firePreventable(new Dn(t.type,this._map,t))},Rn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseup=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.dblclick=function(t){return this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseover=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.mouseout=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.touchstart=function(t){return this._firePreventable(new On(t.type,this._map,t))},Rn.prototype.touchmove=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchend=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchcancel=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Rn.prototype.isEnabled=function(){return!0},Rn.prototype.isActive=function(){return!1},Rn.prototype.enable=function(){},Rn.prototype.disable=function(){};var Fn=function(t){this._map=t};Fn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},Fn.prototype.mousemove=function(t){this._map.fire(new zn(t.type,this._map,t))},Fn.prototype.mousedown=function(){this._delayContextMenu=!0},Fn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new zn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},Fn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new zn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},Fn.prototype.isEnabled=function(){return!0},Fn.prototype.isActive=function(){return!1},Fn.prototype.enable=function(){},Fn.prototype.disable=function(){};var Bn=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Nn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Bn.prototype.isEnabled=function(){return!!this._enabled},Bn.prototype.isActive=function(){return!!this._active},Bn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Bn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Bn.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Bn.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var a=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(a.x,n.x),o=Math.max(a.x,n.x),s=Math.min(a.y,n.y),l=Math.max(a.y,n.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+s+\"px)\"),this._box.style.width=o-i+\"px\",this._box.style.height=l-s+\"px\"}}},Bn.prototype.mouseupWindow=function(e,n){var a=this;if(this._active&&0===e.button){var i=this._startPos,o=n;if(this.reset(),r.suppressClick(),i.x!==o.x||i.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(i,o,a._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Bn.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Bn.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Bn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var jn=function(t){this.reset(),this.numTouches=t.numTouches};jn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},jn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,a=e;n<a.length;n+=1)r._add(a[n]);return r.div(e.length)}(r),this.touches=Nn(n,r)))},jn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Nn(r,e);for(var a in this.touches){var i=n[a];(!i||i.dist(this.touches[a])>30)&&(this.aborted=!0)}}},jn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var Un=function(t){this.singleTap=new jn(t),this.numTaps=t.numTaps,this.reset()};Un.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},Un.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},Un.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},Un.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var a=t.timeStamp-this.lastTime<500,i=!this.lastTap||this.lastTap.dist(n)<30;if(a&&i||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Vn=function(){this._zoomIn=new Un({numTouches:1,numTaps:2}),this._zoomOut=new Un({numTouches:2,numTaps:1}),this.reset()};Vn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Vn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Vn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Vn.prototype.touchend=function(t,e,r){var n=this,a=this._zoomIn.touchend(t,e,r),i=this._zoomOut.touchend(t,e,r);return a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(a)},{originalEvent:t})}}):i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(i)},{originalEvent:t})}}):void 0},Vn.prototype.touchcancel=function(){this.reset()},Vn.prototype.enable=function(){this._enabled=!0},Vn.prototype.disable=function(){this._enabled=!1,this.reset()},Vn.prototype.isEnabled=function(){return this._enabled},Vn.prototype.isActive=function(){return this._active};var qn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};qn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},qn.prototype._correctButton=function(t,e){return!1},qn.prototype._move=function(t,e){return{}},qn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},qn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r&&(t.preventDefault(),this._moved||!(e.dist(r)<this._clickTolerance)))return this._moved=!0,this._lastPoint=e,this._move(r,e)},qn.prototype.mouseupWindow=function(t){r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},qn.prototype.enable=function(){this._enabled=!0},qn.prototype.disable=function(){this._enabled=!1,this.reset()},qn.prototype.isEnabled=function(){return this._enabled},qn.prototype.isActive=function(){return this._active};var Hn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(qn),Gn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Yn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Wn=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};Wn.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},Wn.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},Wn.prototype.touchmove=function(t,e,r){if(this._active)return t.preventDefault(),this._calculateTransform(t,e,r)},Wn.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},Wn.prototype.touchcancel=function(){this.reset()},Wn.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var a=Nn(n,r),i=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in a){var c=a[l],u=this._touches[l];u&&(i._add(c),o._add(c.sub(u)),s++,a[l]=c)}if(this._touches=a,!(s<this._minTouches)&&o.mag()){var h=o.div(s);if(this._sum._add(h),!(this._sum.mag()<this._clickTolerance))return{around:i.div(s),panDelta:h}}},Wn.prototype.enable=function(){this._enabled=!0},Wn.prototype.disable=function(){this._enabled=!1,this.reset()},Wn.prototype.isEnabled=function(){return this._enabled},Wn.prototype.isActive=function(){return this._active};var Zn=function(){this.reset()};function Xn(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}function Jn(t,e){return Math.log(t/e)/Math.LN2}Zn.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},Zn.prototype._start=function(t){},Zn.prototype._move=function(t,e,r){return{}},Zn.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},Zn.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,a=n[1],i=Xn(r,e,n[0]),o=Xn(r,e,a);if(i&&o){var s=this._aroundCenter?null:i.add(o).div(2);return this._move([i,o],s,t)}}},Zn.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var a=this._firstTwoTouches,i=a[1],o=Xn(n,e,a[0]),s=Xn(n,e,i);o&&s||(this._active&&r.suppressClick(),this.reset())}},Zn.prototype.touchcancel=function(){this.reset()},Zn.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},Zn.prototype.disable=function(){this._enabled=!1,this.reset()},Zn.prototype.isEnabled=function(){return this._enabled},Zn.prototype.isActive=function(){return this._active};var Kn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(Jn(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:Jn(this._distance,r),pinchAround:e}},e}(Zn);function Qn(t,e){return 180*t.angleWith(e)/Math.PI}var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:Qn(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=Qn(t,this._startVector);return Math.abs(r)<e},e}(Zn);function ta(t){return Math.abs(t.y)>Math.abs(t.x)}var ea=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ta(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),a=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,a,r.timeStamp),this._valid)return this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+a.y)/2*-.5}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,a=e.mag()>=2;if(n||a){if(!n||!a)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var i=t.y>0==e.y>0;return ta(t)&&ta(e)&&i}},e}(Zn),ra={panStep:100,bearingStep:15,pitchStep:10},na=function(){var t=ra;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep};function aa(t){return t*(2-t)}na.prototype.reset=function(){this._active=!1},na.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,a=0,i=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?a=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?a=-1:(t.preventDefault(),o=1);break;default:return}return{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:aa,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+a*e._pitchStep,offset:[-i*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},na.prototype.enable=function(){this._enabled=!0},na.prototype.disable=function(){this._enabled=!1,this.reset()},na.prototype.isEnabled=function(){return this._enabled},na.prototype.isActive=function(){return this._active};var ia=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};ia.prototype.setZoomRate=function(t){this._defaultZoomRate=t},ia.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},ia.prototype.isEnabled=function(){return!!this._enabled},ia.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},ia.prototype.isZooming=function(){return!!this._zooming},ia.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},ia.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},ia.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),a=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":a>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(a*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},ia.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},ia.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},ia.prototype.renderFrame=function(){return this._onScrollFrame()},ia.prototype._onScrollFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,a=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==a&&(a=1/a);var i=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(i*a))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var h=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),f=c(h);o=t.number(l,s,f),h<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},ia.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,a=(t.browser.now()-n.start)/n.duration,i=n.easing(a+.01)-n.easing(a),o=.27/Math.sqrt(i*i+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},ia.prototype.reset=function(){this._active=!1};var oa=function(t,e){this._clickZoom=t,this._tapZoom=e};oa.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},oa.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},oa.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},oa.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var sa=function(){this.reset()};sa.prototype.reset=function(){this._active=!1},sa.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},sa.prototype.enable=function(){this._enabled=!0},sa.prototype.disable=function(){this._enabled=!1,this.reset()},sa.prototype.isEnabled=function(){return this._enabled},sa.prototype.isActive=function(){return this._active};var la=function(){this._tap=new Un({numTouches:1,numTaps:1}),this.reset()};la.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},la.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},la.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],a=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:a/128}}}else this._tap.touchmove(t,e,r)},la.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},la.prototype.touchcancel=function(){this.reset()},la.prototype.enable=function(){this._enabled=!0},la.prototype.disable=function(){this._enabled=!1,this.reset()},la.prototype.isEnabled=function(){return this._enabled},la.prototype.isActive=function(){return this._active};var ca=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};ca.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},ca.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},ca.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},ca.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var ua=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};ua.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},ua.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},ua.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},ua.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var ha=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};ha.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},ha.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},ha.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},ha.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},ha.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},ha.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var fa=function(t){return t.zoom||t.drag||t.pitch||t.rotate},pa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(t.Event);function da(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var ga=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Ln(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var a=this._el;this._listeners=[[a,\"touchstart\",{passive:!1}],[a,\"touchmove\",{passive:!1}],[a,\"touchend\",void 0],[a,\"touchcancel\",void 0],[a,\"mousedown\",void 0],[a,\"mousemove\",void 0],[a,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[a,\"mouseover\",void 0],[a,\"mouseout\",void 0],[a,\"dblclick\",void 0],[a,\"click\",void 0],[a,\"keydown\",{capture:!1}],[a,\"keyup\",void 0],[a,\"wheel\",{passive:!1}],[a,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var i=0,o=this._listeners;i<o.length;i+=1){var s=o[i],l=s[0];r.addEventListener(l,s[1],l===t.window.document?this.handleWindowEvent:this.handleEvent,s[2])}};ga.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var a=n[e],i=a[0];r.removeEventListener(i,a[1],i===t.window.document?this.handleWindowEvent:this.handleEvent,a[2])}},ga.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Rn(e,t));var n=e.boxZoom=new Bn(e,t);this._add(\"boxZoom\",n);var a=new Vn,i=new sa;e.doubleClickZoom=new oa(i,a),this._add(\"tapZoom\",a),this._add(\"clickZoom\",i);var o=new la;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new ea;this._add(\"touchPitch\",s);var l=new Gn(t),c=new Yn(t);e.dragRotate=new ua(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new Hn(t),h=new Wn(t);e.dragPan=new ca(r,u,h),this._add(\"mousePan\",u),this._add(\"touchPan\",h,[\"touchZoom\",\"touchRotate\"]);var f=new $n,p=new Kn;e.touchZoomRotate=new ha(r,p,f,o),this._add(\"touchRotate\",f,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new ia(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var g=e.keyboard=new na;this._add(\"keyboard\",g),this._add(\"blockableMapEvent\",new Fn(e));for(var m=0,v=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];m<v.length;m+=1){var y=v[m];t.interactive&&t[y]&&e[y].enable(t[y])}},ga.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},ga.prototype.stop=function(){if(!this._updatingCamera){for(var t=0,e=this._handlers;t<e.length;t+=1)e[t].handler.reset();this._inertia.clear(),this._fireEvents({},{}),this._changes=[]}},ga.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1)if(e[t].handler.isActive())return!0;return!1},ga.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},ga.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},ga.prototype.isMoving=function(){return Boolean(fa(this._eventsInProgress))||this.isZooming()},ga.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},ga.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},ga.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var a=n[r];this._el.contains(a.target)&&e.push(a)}return e},ga.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,a={needsRenderFrame:!1},i={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var h=u[c],f=h.handlerName,p=h.handler,d=h.allowed;if(p.isEnabled()){var g=void 0;this._blockedByActive(o,d,f)?p.reset():p[e||t.type]&&(g=p[e||t.type](t,l,s),this.mergeHandlerResult(a,i,g,f,n),g&&g.needsRenderFrame&&this._triggerRenderFrame()),(g||p.isActive())&&(o[f]=p)}}var m={};for(var v in this._previousActiveHandlers)o[v]||(m[v]=n);this._previousActiveHandlers=o,(Object.keys(m).length||da(a))&&(this._changes.push([a,i,m]),this._triggerRenderFrame()),(Object.keys(o).length||da(a))&&this._map._stop(!0),this._updatingCamera=!1;var y=a.cameraAnimation;y&&(this._inertia.clear(),this._fireEvents({},{}),this._changes=[],y(this._map))}else this.stop()},ga.prototype.mergeHandlerResult=function(e,r,n,a,i){if(n){t.extend(e,n);var o={handlerName:a,originalEvent:n.originalEvent||i};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},ga.prototype._applyChanges=function(){for(var e={},r={},n={},a=0,i=this._changes;a<i.length;a+=1){var o=i[a],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},ga.prototype._updateMapTransform=function(t,e,r){var n=this._map,a=n.transform;if(!da(t))return this._fireEvents(e,r);var i=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var h=a.pointLocation(i?c.sub(i):c);s&&(a.bearing+=s),l&&(a.pitch+=l),o&&(a.zoom+=o),a.setLocationAtPoint(h,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r)},ga.prototype._fireEvents=function(e,r){var n=this,a=fa(this._eventsInProgress),i=fa(e),o={};for(var s in e)this._eventsInProgress[s]||(o[s+\"start\"]=e[s].originalEvent),this._eventsInProgress[s]=e[s];for(var l in!a&&i&&this._fireEvent(\"movestart\",i.originalEvent),o)this._fireEvent(l,o[l]);for(var c in e.rotate&&(this._bearingChanged=!0),i&&this._fireEvent(\"move\",i.originalEvent),e)this._fireEvent(c,e[c].originalEvent);var u,h={};for(var f in this._eventsInProgress){var p=this._eventsInProgress[f],d=p.handlerName,g=p.originalEvent;this._handlersById[d].isActive()||(delete this._eventsInProgress[f],h[f+\"end\"]=u=r[d]||g)}for(var m in h)this._fireEvent(m,h[m]);var v=fa(this._eventsInProgress);if((a||i)&&!v){this._updatingCamera=!0;var y=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),x=function(t){return 0!==t&&-n._bearingSnap<t&&t<n._bearingSnap};y?(x(y.bearing||this._map.getBearing())&&(y.bearing=0),this._map.easeTo(y,{originalEvent:u})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:u})),x(this._map.getBearing())&&this._map.resetNorth()),this._bearingChanged=!1,this._updatingCamera=!1}},ga.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},ga.prototype._triggerRenderFrame=function(){var t=this;void 0===this._frameId&&(this._frameId=this._map._requestRenderFrame((function(e){delete t._frameId,t.handleEvent(new pa(\"renderFrame\",{timeStamp:e})),t._applyChanges()})))};var ma=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,a){var i={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(a=t.extend({padding:i,offset:[0,0],maxZoom:this.transform.maxZoom},a)).padding){var o=a.padding;a.padding={top:o,bottom:o,right:o,left:o}}a.padding=t.extend(i,a.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),h=c.rotate(-n*Math.PI/180),f=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(h.x,f.x),Math.max(h.y,f.y)),d=new t.Point(Math.min(h.x,f.x),Math.min(h.y,f.y)),g=p.sub(d),m=(s.width-(l.left+l.right+a.padding.left+a.padding.right))/g.x,v=(s.height-(l.top+l.bottom+a.padding.top+a.padding.bottom))/g.y;if(!(v<0||m<0)){var y=Math.min(s.scaleZoom(s.scale*Math.min(m,v)),a.maxZoom),x=t.Point.convert(a.offset),b=new t.Point(x.x+(a.padding.left-a.padding.right)/2,x.y+(a.padding.top-a.padding.bottom)/2).mult(s.scale/s.zoomScale(y));return{center:s.unproject(c.add(u).div(2).sub(b)),zoom:y,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,a,i){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,a),a,i)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,a=!1,i=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(a=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(i=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),a&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),i&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var a=this.transform,i=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:i,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,h=\"pitch\"in e?+e.pitch:s,f=\"padding\"in e?e.padding:a.padding,p=t.Point.convert(e.offset),d=a.centerPoint.add(p),g=a.pointLocation(d),m=t.LngLat.convert(e.center||g);this._normalizeCenter(m);var v,y,x=a.project(g),b=a.project(m).sub(x),_=a.zoomScale(c-i);e.around&&(v=t.LngLat.convert(e.around),y=a.locationPoint(v));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==i,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||h!==s,this._padding=!a.isPaddingEqual(f),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),clearTimeout(this._easeEndTimeoutID),this._ease((function(e){if(n._zooming&&(a.zoom=t.number(i,c,e)),n._rotating&&(a.bearing=t.number(o,u,e)),n._pitching&&(a.pitch=t.number(s,h,e)),n._padding&&(a.interpolatePadding(l,f,e),d=a.centerPoint.add(p)),v)a.setLocationAtPoint(v,y);else{var g=a.zoomScale(a.zoom-i),m=c>i?Math.min(2,_):Math.max(.5,_),w=Math.pow(m,1-e),T=a.unproject(x.add(b.mult(e*w)).mult(g));a.setLocationAtPoint(a.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,a=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),a&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var a=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(a,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):o,h=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,f=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:i.padding,d=i.zoomScale(u-o),g=t.Point.convert(e.offset),m=i.centerPoint.add(g),v=i.pointLocation(m),y=t.LngLat.convert(e.center||v);this._normalizeCenter(y);var x=i.project(v),b=i.project(y).sub(x),_=e.curve,w=Math.max(i.width,i.height),T=w/d,k=b.mag();if(\"minZoom\"in e){var M=t.clamp(Math.min(e.minZoom,o,u),i.minZoom,i.maxZoom),A=w/i.zoomScale(M-o);_=Math.sqrt(A/k*2)}var S=_*_;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function C(t){return(Math.exp(t)-Math.exp(-t))/2}function L(t){return(Math.exp(t)+Math.exp(-t))/2}var P=E(0),I=function(t){return L(P)/L(P+_*t)},z=function(t){return w*((L(P)*(C(e=P+_*t)/L(e))-C(P))/S)/k;var e},O=(E(1)-P)/_;if(Math.abs(k)<1e-6||!isFinite(O)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;O=Math.abs(Math.log(T/w))/_,z=function(){return 0},I=function(t){return Math.exp(D*_*t)}}return e.duration=\"duration\"in e?+e.duration:1e3*O/(\"screenSpeed\"in e?+e.screenSpeed/_:+e.speed),e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==h,this._pitching=f!==l,this._padding=!i.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var a=e*O,d=1/I(a);i.zoom=1===e?u:o+i.scaleZoom(d),n._rotating&&(i.bearing=t.number(s,h,e)),n._pitching&&(i.pitch=t.number(l,f,e)),n._padding&&(i.interpolatePadding(c,p,e),m=i.centerPoint.add(g));var v=1===e?y:i.unproject(x.add(b.mult(z(a))).mult(d));i.setLocationAtPoint(i.renderWorldCopies?v.wrap():v,m),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop()}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),va=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};va.prototype.getDefaultPosition=function(){return\"bottom-right\"},va.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},va.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},va.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},va.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},va.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var a=r[n];if(a.used){var i=a.getSource();i.attribution&&t.indexOf(i.attribution)<0&&t.push(i.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},va.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var ya=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};ya.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},ya.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},ya.prototype.getDefaultPosition=function(){return\"bottom-left\"},ya.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},ya.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},ya.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var xa=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};xa.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},xa.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var a=n[r];if(a.id===t)return void(a.cancelled=!0)}},xa.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var a=n[r];if(!a.cancelled&&(a.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},xa.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var ba={\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},_a=t.window.HTMLImageElement,wa=t.window.HTMLElement,Ta=t.window.ImageBitmap,ka={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Ma=function(n){function a(e){var r=this;if(null!=(e=t.extend({},ka,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>60)throw new Error(\"maxPitch must be less than or equal to 60\");var a=new wn(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new xa,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},ba,e.locale),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof wa))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),this.handlers=new ga(this,e),this._hash=e.hash&&new kn(\"string\"==typeof e.hash&&e.hash||void 0).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new va({customAttribution:e.customAttribution})),this.addControl(new ya,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(a.__proto__=n),(a.prototype=Object.create(n&&n.prototype)).constructor=a;var i={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return a.prototype._getMapId=function(){return this._mapId},a.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var a=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?a.insertBefore(n,a.firstChild):a.appendChild(n),this},a.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},a.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],a=r[1];this._resizeCanvas(n,a),this.transform.resize(n,a),this.painter.resize(n,a);var i=!this._moving;return i&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),i&&this.fire(new t.Event(\"moveend\",e)),this},a.prototype.getBounds=function(){return this.transform.getBounds()},a.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},a.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},a.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},a.prototype.getMinZoom=function(){return this.transform.minZoom},a.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},a.prototype.getMaxZoom=function(){return this.transform.maxZoom},a.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},a.prototype.getMinPitch=function(){return this.transform.minPitch},a.prototype.setMaxPitch=function(t){if((t=null==t?60:t)>60)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},a.prototype.getMaxPitch=function(){return this.transform.maxPitch},a.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},a.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},a.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},a.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},a.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},a.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},a.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},a.prototype._createDelegatedListener=function(t,e,r){var n,a=this;if(\"mouseenter\"===t||\"mouseover\"===t){var i=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=a.getLayer(e)?a.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?i||(i=!0,r.call(a,new zn(t,a,n.originalEvent,{features:o}))):i=!1},mouseout:function(){i=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(a.getLayer(e)?a.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(a,new zn(t,a,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(a,new zn(t,a,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=a.getLayer(e)?a.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(a,t),delete t.features)},n)}},a.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var a=this._createDelegatedListener(t,e,r);for(var i in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(i,a.delegates[i]);return this},a.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var a=this._createDelegatedListener(t,e,r);for(var i in a.delegates)this.once(i,a.delegates[i]);return this},a.prototype.off=function(t,e,r){var a=this;return void 0===r?n.prototype.off.call(this,t,e):(this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var i=n[t],o=0;o<i.length;o++){var s=i[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)a.off(l,s.delegates[l]);return i.splice(o,1),a}}}(this._delegatedListeners),this)},a.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var a=t.Point.convert(e[0]),i=t.Point.convert(e[1]);n=[a,new t.Point(i.x,a.y),i,new t.Point(a.x,i.y),a]}return this.style.queryRenderedFeatures(n,r,this.transform)},a.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},a.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},a.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},a.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new qe(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},a.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new qe(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},a.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var a=this._requestManager.normalizeStyleURL(e),i=this._requestManager.transformRequest(a,t.ResourceType.Style);t.getJSON(i,(function(e,a){e?n.fire(new t.ErrorEvent(e)):a&&n._updateDiff(a,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},a.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},a.prototype.getStyle=function(){if(this.style)return this.style.serialize()},a.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},a.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},a.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},a.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var a=r[n];if(\"loaded\"!==a.state&&\"errored\"!==a.state)return!1}}return!0},a.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},a.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},a.prototype.getSource=function(t){return this.style.getSource(t)},a.prototype.addImage=function(e,r,n){void 0===n&&(n={});var a=n.pixelRatio;void 0===a&&(a=1);var i=n.sdf;void 0===i&&(i=!1);var o=n.stretchX,s=n.stretchY,l=n.content;if(this._lazyInitEmptyStyle(),r instanceof _a||Ta&&r instanceof Ta){var c=t.browser.getImageData(r);this.style.addImage(e,{data:new t.RGBAImage({width:c.width,height:c.height},c.data),pixelRatio:a,stretchX:o,stretchY:s,content:l,sdf:i,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r;this.style.addImage(e,{data:new t.RGBAImage({width:r.width,height:r.height},new Uint8Array(r.data)),pixelRatio:a,stretchX:o,stretchY:s,content:l,sdf:i,version:0,userImage:u}),u.onAdd&&u.onAdd(this,e)}},a.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var a=r instanceof _a||Ta&&r instanceof Ta?t.browser.getImageData(r):r,i=a.width,o=a.height,s=a.data;return void 0===i||void 0===o?this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\"))):i!==n.data.width||o!==n.data.height?this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\"))):(n.data.replace(s,!(r instanceof _a||Ta&&r instanceof Ta)),void this.style.updateImage(e,n))},a.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},a.prototype.removeImage=function(t){this.style.removeImage(t)},a.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},a.prototype.listImages=function(){return this.style.listImages()},a.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},a.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},a.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},a.prototype.getLayer=function(t){return this.style.getLayer(t)},a.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},a.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},a.prototype.getFilter=function(t){return this.style.getFilter(t)},a.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},a.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},a.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},a.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},a.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},a.prototype.getLight=function(){return this.style.getLight()},a.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},a.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},a.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},a.prototype.getContainer=function(){return this._container},a.prototype.getCanvasContainer=function(){return this._canvasContainer},a.prototype.getCanvas=function(){return this._canvas},a.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},a.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},a.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var a=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),i=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){i[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,a)}))},a.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},a.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new yn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},a.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},a.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},a.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},a.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},a.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},a.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},a.prototype._render=function(e){var r,n=this,a=0,i=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=i.createQueryEXT(),i.beginQueryEXT(i.TIME_ELAPSED_EXT,r),a=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var h=t.browser.now()-a;i.endQueryEXT(i.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=i.getQueryObjectEXT(r,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:h,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var f=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(f);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}return this._sourcesDirty||this._styleDirty||this._placementDirty||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&(this._fullyLoaded||(this._fullyLoaded=!0),this.fire(new t.Event(\"idle\"))),this}},a.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),Aa(this._canvasContainer),Aa(this._controlContainer),Aa(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},a.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},a.prototype._onWindowOnline=function(){this._update()},a.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},i.showTileBoundaries.get=function(){return!!this._showTileBoundaries},i.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},i.showPadding.get=function(){return!!this._showPadding},i.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},i.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},i.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},i.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},i.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},i.repaint.get=function(){return!!this._repaint},i.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},i.vertices.get=function(){return!!this._vertices},i.vertices.set=function(t){this._vertices=t,this._update()},a.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},i.version.get=function(){return t.version},Object.defineProperties(a.prototype,i),a}(ma);function Aa(t){t.parentNode&&t.parentNode.removeChild(t)}var Sa={showCompass:!0,showZoom:!0,visualizePitch:!1},Ea=function(e){var n=this;this.options=t.extend({},Sa,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};Ea.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.disabled=t===this._map.getMaxZoom(),this._zoomOutButton.disabled=t===this._map.getMinZoom()},Ea.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},Ea.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ca(this._map,this._compass,this.options.visualizePitch)),this._container},Ea.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},Ea.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},Ea.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ca=function(e,n,a){void 0===a&&(a=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new Gn({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,a&&(this.mousePitch=new Yn({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function La(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var a=new t.LngLat(e.lng-360,e.lat),i=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(a).distSqr(r)<o?e=a:n.locationPoint(i).distSqr(r)<o&&(e=i)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ca.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ca.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var a=this.mousePitch.mousemoveWindow(t,e);a&&a.pitchDelta&&r.setPitch(r.getPitch()+a.pitchDelta)}},Ca.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ca.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ca.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ca.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ca.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ca.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ca.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ca.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ca.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var Pa={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Ia(t,e,r){var n=t.classList;for(var a in Pa)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+a);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var za,Oa=function(e){function n(n,a){var i=this;if(e.call(this),(n instanceof t.window.HTMLElement||a)&&(n=t.extend({element:n},a)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");o.setAttributeNS(null,\"display\",\"block\"),o.setAttributeNS(null,\"height\",\"41px\"),o.setAttributeNS(null,\"width\",\"27px\"),o.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"stroke\",\"none\"),s.setAttributeNS(null,\"stroke-width\",\"1\"),s.setAttributeNS(null,\"fill\",\"none\"),s.setAttributeNS(null,\"fill-rule\",\"evenodd\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"fill-rule\",\"nonzero\");var c=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");c.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),c.setAttributeNS(null,\"fill\",\"#000000\");for(var u=0,h=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];u<h.length;u+=1){var f=h[u],p=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");p.setAttributeNS(null,\"opacity\",\"0.04\"),p.setAttributeNS(null,\"cx\",\"10.5\"),p.setAttributeNS(null,\"cy\",\"5.80029008\"),p.setAttributeNS(null,\"rx\",f.rx),p.setAttributeNS(null,\"ry\",f.ry),c.appendChild(p)}var d=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"fill\",this._color);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");g.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),d.appendChild(g);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),m.appendChild(v);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");x.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#000000\"),b.setAttributeNS(null,\"opacity\",\"0.25\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),x.appendChild(b),x.appendChild(_),l.appendChild(c),l.appendChild(d),l.appendChild(m),l.appendChild(y),l.appendChild(x),o.appendChild(l),this._element.appendChild(o),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),this._element.addEventListener(\"focus\",(function(){var t=i._map.getContainer();t.scrollTop=0,t.scrollLeft=0})),Ia(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=La(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Pa[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Da={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0},Ra=0,Fa=!1,Ba=function(e){function n(r){e.call(this),this.options=t.extend({},Da,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==za?n(za):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){n(za=\"denied\"!==t.state)})):n(za=!!t.window.navigator.geolocation),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ra=0,Fa=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,a=this._map.getBearing(),i=t.extend({bearing:a},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),i,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),a=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=a+\"px\",this._circleElement.style.height=a+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&Fa)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var a=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}else{var i=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Oa(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Oa({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||e.originalEvent&&\"resize\"===e.originalEvent.type||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ra--,Fa=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Ra>1?(e={maximumAge:6e5,timeout:0},Fa=!0):(e=this.options.positionOptions,Fa=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Na={maxWidth:100,unit:\"metric\"},ja=function(e){this.options=t.extend({},Na,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Ua(t,e,r){var n=r&&r.maxWidth||100,a=t._container.clientHeight/2,i=t.unproject([0,a]),o=t.unproject([n,a]),s=i.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;l>5280?Va(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\")):Va(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?Va(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?Va(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):Va(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function Va(t,e,r,n){var a,i,o,s=(a=r,(i=Math.pow(10,(\"\"+Math.floor(a)).length-1))*(o=(o=a/i)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o)));t.style.width=e*(s/r)+\"px\",t.innerHTML=s+\"&nbsp;\"+n}ja.prototype.getDefaultPosition=function(){return\"bottom-left\"},ja.prototype._onMove=function(){Ua(this._map,this._container,this.options)},ja.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},ja.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},ja.prototype.setUnit=function(t){this.options.unit=t,Ua(this._map,this._container,this.options)};var qa=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};qa.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},qa.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},qa.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},qa.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},qa.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},qa.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},qa.prototype._isFullscreen=function(){return this._fullscreen},qa.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},qa.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Ha={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Ga=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Ha),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),a=t.window.document.createElement(\"body\");for(a.innerHTML=e;r=a.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(e){var n=this;if(this._map&&(this._lngLat||this._trackPointer)&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return n._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=La(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),i=this.options.anchor,o=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var a=t.Point.convert(r);return{center:a,top:a,\"top-left\":a,\"top-right\":a,bottom:a,\"bottom-left\":a,\"bottom-right\":a,left:a,right:a}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!i){var s,l=this._container.offsetWidth,c=this._container.offsetHeight;s=a.y+o.bottom.y<c?[\"top\"]:a.y>this._map.transform.height-c?[\"bottom\"]:[],a.x<l/2?s.push(\"left\"):a.x>this._map.transform.width-l/2&&s.push(\"right\"),i=0===s.length?\"bottom\":s.join(\"-\")}var u=a.add(o[i]).round();r.setTransform(this._container,Pa[i]+\" translate(\"+u.x+\"px,\"+u.y+\"px)\"),Ia(this._container,i,\"popup\")}},n.prototype._onClose=function(){this.remove()},n}(t.Evented),Ya={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Ma,NavigationControl:Ea,GeolocateControl:Ba,AttributionControl:va,ScaleControl:ja,FullscreenControl:qa,Popup:Ga,Marker:Oa,Style:qe,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){Bt().acquire(Ot)},clearPrewarmedResources:function(){var t=Rt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(Ot),Rt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Dt.workerCount},set workerCount(t){Dt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Ya})),r}))},{}],448:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=i(t,n);return r};var n=t(\"convex-hull\");function a(t,e,r){for(var n=new Array(t),a=0;a<t;++a)n[a]=0,a===e&&(n[a]+=.5),a===r&&(n[a]+=.5);return n}function i(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],i=[],o=0;o<=t;++o)if(e&1<<o){r.push(a(t,o-1,o-1)),i.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(a(t,o-1,s-1)),i.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!i[u[s]])continue t;h.push(i[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":135}],449:[function(t,e,r){var n=t(\"./normalize\"),a=t(\"gl-mat4/create\"),i=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=a(),h=a(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,a){t[0]=e[0]*n+r[0]*a,t[1]=e[1]*n+r[1]*a,t[2]=e[2]*n+r[2]*a}e.exports=function(t,e,r,a,m,v){if(e||(e=[0,0,0]),r||(r=[0,0,0]),a||(a=[0,0,0]),m||(m=[0,0,0,1]),v||(v=[0,0,0,1]),!n(u,t))return!1;if(i(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,T,k,M=u[3],A=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==M||0!==A||0!==S){if(f[0]=M,f[1]=A,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=m,b=h,_=(x=f)[0],w=x[1],T=x[2],k=x[3],y[0]=b[0]*_+b[4]*w+b[8]*T+b[12]*k,y[1]=b[1]*_+b[5]*w+b[9]*T+b[13]*k,y[2]=b[2]*_+b[6]*w+b[10]*T+b[14]*k,y[3]=b[3]*_+b[7]*w+b[11]*T+b[15]*k}else m[0]=m[1]=m[2]=0,m[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),a[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-a[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),a[0]/=r[1],a[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-a[1]),a[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-a[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),a[1]/=r[2],a[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var I=0;I<3;I++)r[I]*=-1,p[I][0]*=-1,p[I][1]*=-1,p[I][2]*=-1;return v[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),v[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),v[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),v[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(v[0]=-v[0]),p[0][2]>p[2][0]&&(v[1]=-v[1]),p[1][0]>p[0][1]&&(v[2]=-v[2]),!0}},{\"./normalize\":450,\"gl-mat4/clone\":272,\"gl-mat4/create\":273,\"gl-mat4/determinant\":274,\"gl-mat4/invert\":278,\"gl-mat4/transpose\":289,\"gl-vec3/cross\":339,\"gl-vec3/dot\":344,\"gl-vec3/length\":354,\"gl-vec3/normalize\":361}],450:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,a=0;a<16;a++)t[a]=e[a]*n;return!0}},{}],451:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),a=t(\"mat4-recompose\"),i=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=i(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=i(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p)&&(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),a(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),!0)}},{\"gl-mat4/determinant\":274,\"gl-vec3/lerp\":355,\"mat4-decompose\":449,\"mat4-recompose\":452,\"quat-slerp\":501}],452:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},a=(n.create(),n.create());e.exports=function(t,e,r,i,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(a),0!==i[2]&&(a[9]=i[2],n.multiply(t,t,a)),0!==i[1]&&(a[9]=0,a[8]=i[1],n.multiply(t,t,a)),0!==i[0]&&(a[8]=0,a[4]=i[0],n.multiply(t,t,a)),n.scale(t,t,r),t}},{\"gl-mat4/create\":273,\"gl-mat4/fromRotationTranslation\":276,\"gl-mat4/identity\":277,\"gl-mat4/multiply\":280,\"gl-mat4/scale\":287,\"gl-mat4/translate\":288}],453:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],454:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),a=t(\"mat4-interpolate\"),i=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else a(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var m=this.computedInverse;i(m,o);var v=this.computedEye,y=m[15];v[0]=m[12]/y,v[1]=m[13]/y,v[2]=m[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=v[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var a=0,i=0;i<3;++i)a+=Math.pow(r[i]-e[i],2);a=Math.log(Math.sqrt(a)),this.computedRadius[0]=a},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var a=this.computedInverse;e&&s(a,a,e),r&&o(a,a,r),n&&l(a,a,n),this.setMatrix(t,i(this.computedMatrix,a))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var a=this.computedInverse;u(a,a,g),this.setMatrix(t,i(a,a))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var a=this.computedMatrix;u(a,a,g),this.setMatrix(t,a)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":455,\"gl-mat4/invert\":278,\"gl-mat4/lookAt\":279,\"gl-mat4/rotateX\":284,\"gl-mat4/rotateY\":285,\"gl-mat4/rotateZ\":286,\"gl-mat4/scale\":287,\"gl-mat4/translate\":288,\"gl-vec3/normalize\":361,\"mat4-interpolate\":451}],455:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),a=0;a<e;++a)r[a]=a;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var i=new Array(e);for(a=0;a<e;++a)i[a]=a;i.sort((function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]}));var o=[i[0],i[1]],s=[i[0],i[1]];for(a=2;a<e;++a){for(var l=i[a],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var h=0,f=(a=0,o.length);a<f;++a)r[h++]=o[a];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":520}],457:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,a=0,i=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==a||u!==i||l(s))&&(r=0|t,a=c||0,i=u||0,e&&e(r,a,i,o))}function u(t){c(0,t)}function h(){(r||a||i||o.shift||o.alt||o.meta||o.control)&&(a=i=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,a,i,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function m(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}m();var v={element:t};return Object.defineProperties(v,{enabled:{get:function(){return s},set:function(e){e?m():function(){if(!s)return;s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f))}()},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return a},enumerable:!0},y:{get:function(){return i},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),v};var n=t(\"mouse-event\")},{\"mouse-event\":459}],458:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var a=t.clientX||0,i=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=a-o.left,r[1]=i-o.top,r}},{}],459:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],460:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var a=n(\"ex\",t),i=function(t){r&&t.preventDefault();var n=t.deltaX||0,i=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=a;break;case 2:s=window.innerHeight}if(i*=s,o*=s,(n*=s)||i||o)return e(n,i,o,t)};return t.addEventListener(\"wheel\",i),i}},{\"to-px\":550}],461:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function a(t){return\"a\"+t}function i(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function m(t){return\"y\"+t}function v(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var b=t.arrayArguments||1;b<1&&e(\"Must have at least one array argument\");var _=t.scalarArguments||0;_<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var w=t.getters||[],T=new Array(b),k=0;k<b;++k)w.indexOf(k)>=0?T[k]=!0:T[k]=!1;return function(t,e,r,b,_,w){var T=w.length,k=_.length;if(k<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var M=\"extractContour\"+_.join(\"_\"),A=[],S=[],E=[],C=0;C<T;++C)E.push(a(C));for(C=0;C<b;++C)E.push(u(C));for(C=0;C<k;++C)S.push(s(C)+\"=\"+a(0)+\".shape[\"+C+\"]|0\");for(C=0;C<T;++C){S.push(i(C)+\"=\"+a(C)+\".data\",c(C)+\"=\"+a(C)+\".offset|0\");for(var L=0;L<k;++L)S.push(l(C,L)+\"=\"+a(C)+\".stride[\"+L+\"]|0\")}for(C=0;C<T;++C){S.push(h(C)+\"=\"+c(C)),S.push(o(C,0));for(L=1;L<1<<k;++L){for(var P=[],I=0;I<k;++I)L&1<<I&&P.push(\"-\"+l(C,I));S.push(f(C,L)+\"=(\"+P.join(\"\")+\")|0\"),S.push(o(C,L)+\"=0\")}}for(C=0;C<T;++C)for(L=0;L<k;++L){var z=[l(C,_[L])];L>0&&z.push(l(C,_[L-1])+\"*\"+s(_[L-1])),S.push(d(C,_[L])+\"=(\"+z.join(\"-\")+\")|0\")}for(C=0;C<k;++C)S.push(p(C)+\"=0\");S.push(\"N=0\");var O=[\"2\"];for(C=k-2;C>=0;--C)O.push(s(_[C]));S.push(\"Q=(\"+O.join(\"*\")+\")|0\",\"P=mallocUint32(Q)\",\"V=mallocUint32(Q)\",\"X=0\"),S.push(g(0)+\"=0\");for(L=1;L<1<<k;++L){var D=[],R=[];for(I=0;I<k;++I)L&1<<I&&(0===R.length?D.push(\"1\"):D.unshift(R.join(\"*\"))),R.push(s(_[I]));var F=\"\";D[0].indexOf(s(_[k-2]))<0&&(F=\"-\");var B=x(k,L,_);S.push(v(B)+\"=(-\"+D.join(\"-\")+\")|0\",m(B)+\"=(\"+F+D.join(\"-\")+\")|0\",g(B)+\"=0\")}function N(t,e){A.push(\"for(\",p(_[t]),\"=\",e,\";\",p(_[t]),\"<\",s(_[t]),\";\",\"++\",p(_[t]),\"){\")}function j(t){for(var e=0;e<T;++e)A.push(h(e),\"+=\",d(e,_[t]),\";\");A.push(\"}\")}function U(){for(var t=1;t<1<<k;++t)A.push(\"T\",\"=\",v(t),\";\",v(t),\"=\",m(t),\";\",m(t),\"=\",\"T\",\";\")}S.push(y(0)+\"=0\",\"T=0\"),function t(e,r){if(e<0)!function(t){for(var e=0;e<T;++e)w[e]?A.push(o(e,0),\"=\",i(e),\".get(\",h(e),\");\"):A.push(o(e,0),\"=\",i(e),\"[\",h(e),\"];\");var r=[];for(e=0;e<T;++e)r.push(o(e,0));for(e=0;e<b;++e)r.push(u(e));A.push(g(0),\"=\",\"P\",\"[\",\"X\",\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<k;++n)A.push(g(n),\"=\",\"P\",\"[\",\"X\",\"+\",v(n),\"];\");var a=[];for(n=1;n<1<<k;++n)a.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");A.push(\"if(\",a.join(\"||\"),\"){\");var s=[];for(e=0;e<k;++e)s.push(p(e));for(e=0;e<T;++e){s.push(o(e,0));for(n=1;n<1<<k;++n)w[e]?A.push(o(e,n),\"=\",i(e),\".get(\",h(e),\"+\",f(e,n),\");\"):A.push(o(e,n),\"=\",i(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(e=0;e<1<<k;++e)s.push(g(e));for(e=0;e<b;++e)s.push(u(e));A.push(\"vertex(\",s.join(),\");\",y(0),\"=\",\"V\",\"[\",\"X\",\"]=\",\"N\",\"++;\");var l=(1<<k)-1,c=g(l);for(n=0;n<k;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,m=g(d),x=[],_=d;_>0;_=_-1&d)x.push(\"V[X+\"+v(_)+\"]\");x.push(y(0));for(_=0;_<T;++_)1&n?x.push(o(_,l),o(_,d)):x.push(o(_,d),o(_,l));1&n?x.push(c,m):x.push(m,c);for(_=0;_<b;++_)x.push(u(_));A.push(\"if(\",c,\"!==\",m,\"){\",\"face(\",x.join(),\")}\")}A.push(\"}\",\"X\",\"+=1;\")}(r);else{!function(t){for(var e=t-1;e>=0;--e)N(e,0);var r=[];for(e=0;e<T;++e)w[e]?r.push(i(e)+\".get(\"+h(e)+\")\"):r.push(i(e)+\"[\"+h(e)+\"]\");for(e=0;e<b;++e)r.push(u(e));for(A.push(\"P\",\"[\",\"X\",\"++]=phase(\",r.join(),\");\"),e=0;e<t;++e)j(e);for(var n=0;n<T;++n)A.push(h(n),\"+=\",d(n,_[t]),\";\")}(e),A.push(\"if(\",s(_[e]),\">0){\",p(_[e]),\"=1;\"),t(e-1,r|1<<_[e]);for(var n=0;n<T;++n)A.push(h(n),\"+=\",d(n,_[e]),\";\");e===k-1&&(A.push(\"X\",\"=0;\"),U()),N(e,2),t(e-1,r),e===k-1&&(A.push(\"if(\",p(_[k-1]),\"&1){\",\"X\",\"=0;}\"),U()),j(e),A.push(\"}\")}}(k-1,0),A.push(\"freeUint32(\",\"V\",\");freeUint32(\",\"P\",\");\");var V=[\"'use strict';\",\"function \",M,\"(\",E.join(),\"){\",\"var \",S.join(),\";\",A.join(\"\"),\"}\",\"return \",M].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",V)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,_,r,T)};function x(t,e,r){for(var n=0,a=0;a<t;++a)e&1<<a&&(n|=1<<r[a]);return n}},{\"typedarray-pool\":567}],462:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var a=0;a<e.dimension;++a)if(t.shape[a]!==e.shape[a])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(v=o[e])return v;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function a(e){for(var a=r-e.length,i=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),i.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+i.join()+\").hi(\"+o.join()+\")\";if(0===i.length&&(c=\"\"),a>0){n.push(\"if(1\");for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",a,\"(src.pick(\",s.join(),\")\",c);for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===a?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===a?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===a?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}a>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){var d=h.slice();for(f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);a(d)}}n.push(\"return dst;};return gradient\");var g=[\"diff\",\"zero\"],m=[l,c];for(s=1;s<=r;++s)g.push(\"grad\"+s),m.push(u(s));g.push(n.join(\"\"));var v=Function.apply(void 0,g).apply(void 0,m);return i[e]=v,v}(r)(t,e)};var n=t(\"dup\"),a=t(\"cwise-compiler\"),i={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=a({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=a({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in i)return i[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return i[t]=a({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map((function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}})),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":151,dup:176}],463:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,a=0<=r&&r<t.shape[0],i=0<=r+1&&r+1<t.shape[0];return(1-n)*(a?+t.get(r):0)+n*(i?+t.get(r+1):0)}function a(t,e,r){var n=Math.floor(e),a=e-n,i=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=i&&c?t.get(n,s):0,f=i&&u?t.get(n,s+1):0;return(1-l)*((1-a)*h+a*(o&&c?t.get(n+1,s):0))+l*((1-a)*f+a*(o&&u?t.get(n+1,s+1):0))}function i(t,e,r,n){var a=Math.floor(e),i=e-a,o=0<=a&&a<t.shape[0],s=0<=a+1&&a+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],m=o&&u&&d?t.get(a,l,f):0,v=o&&h&&d?t.get(a,l+1,f):0,y=s&&u&&d?t.get(a+1,l,f):0,x=s&&h&&d?t.get(a+1,l+1,f):0,b=o&&u&&g?t.get(a,l,f+1):0,_=o&&h&&g?t.get(a,l+1,f+1):0;return(1-p)*((1-c)*((1-i)*m+i*y)+c*((1-i)*v+i*x))+p*((1-c)*((1-i)*b+i*(s&&u&&g?t.get(a+1,l,f+1):0))+c*((1-i)*_+i*(s&&h&&g?t.get(a+1,l+1,f+1):0)))}function o(t){var e,r,n=0|t.shape.length,a=new Array(n),i=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],a[e]=Math.floor(r),i[e]=r-a[e],o[e]=0<=a[e]&&a[e]<t.shape[e],s[e]=0<=a[e]+1&&a[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=i[l],u+=t.stride[l]*(a[l]+1)}else{if(!o[l])continue t;c*=1-i[l],u+=t.stride[l]*a[l]}h+=c*t.data[u]}return h}e.exports=function(t,e,r,s){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return a(t,e,r);case 3:return i(t,e,r,s);default:return o.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=a,e.exports.d3=i},{}],464:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),a={body:\"\",args:[],thisVars:[],localVars:[]};function i(t){if(!t)return a;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:i(t.pre),body:i(t.body),post:i(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:a,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:a,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:a,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":151}],465:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),a=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],i=t,o=1;Array.isArray(i);)r.push(i.length),o*=i.length,i=i[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),a(e,t),e)}},{\"./doConvert.js\":466,ndarray:469}],466:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":151}],467:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),a=32;function i(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l){0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p))}var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!==(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",a,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var m=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),v=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),a=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=i(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",a.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){r.push(\"dptr=0;sptr=ptr\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(\"scratch[dptr++]=\",h(\"sptr\"));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\")}r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\");for(u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\"));for(u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");r.push(\"dptr=cptr;sptr=cptr-s0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(f(\"dptr\",h(\"sptr\")));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\")}r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(f(\"dptr\",\"scratch[sptr++]\"));for(u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=i(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function m(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function v(e,r,a){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var i=0;i<e.length;++i)n.push([\"b_ptr\",i,\"=s0*\",e[i]].join(\"\"));r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\");for(i=t.length-1;i>=0;--i){0!==(o=t[i])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"))}if(e.length>1)for(i=0;i<e.length;++i)n.push([\"ptr\",i,\"=b_ptr\",i,\"+ptr_shift\"].join(\"\"));n.push(a),r&&n.push(\"++pivot_ptr\");for(i=0;i<t.length;++i){var o;0!==(o=t[i])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,a,i){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}a&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\");for(o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));n.push(i);for(o=t.length-1;o>=1;--o)a&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var a=\"el\"+e,i=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[a,i],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",a,\";\",a,\"=\",i,\";\",i,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(a)),\">\",g(d(i)),\"){tmp0=\",a,\";\",a,\"=\",i,\";\",i,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?v([e,r],!1,m(\"ptr0\",g(\"ptr1\"))):n.push(m(d(e),g(d(r))))}function w(e,r,a){if(t.length>1){var i=\"__l\"+ ++u;y(i,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",a,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",i,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",a].join(\"\"))}function T(e,r){t.length>1?v([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\"))}function k(e,r,a){t.length>1?(v([e,r,a],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+a)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(a),\"\\n\",\"++\",r,\"\\n\",\"--\",a,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\"))}function M(t,e){T(t,e),n.push(\"--\"+e)}function A(e,r,a){t.length>1?v([e,r],!0,[m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",[\"pivot\",a,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(m(d(e),g(d(r))),m(d(r),\"pivot\"+a))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",a,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,a){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),v([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(a,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",a,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?v([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",m(\"ptr5\",\"x\"),\"\\n\",m(\"ptr6\",\"y\"),\"\\n\",m(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",m(d(\"index1\"),\"x\"),\"\\n\",m(d(\"index3\"),\"y\"),\"\\n\",m(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),A(\"left\",\"(less-1)\",1),A(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,v);return m(v,y)}},{\"typedarray-pool\":567}],468:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),a={};e.exports=function(t){var e=t.order,r=t.dtype,i=[e,r].join(\":\"),o=a[i];return o||(a[i]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":467}],469:[function(t,e,r){var n=t(\"iota-array\"),a=t(\"is-buffer\"),i=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var a=\"generic\"===t;if(-1===e){var i=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(i)()}if(0===e){i=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(a?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(a?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",i)(c[t][0])}i=[\"'use strict'\"];var o=n(e),l=o.map((function(t){return\"i\"+t})),u=\"this.offset+\"+o.map((function(t){return\"this.stride[\"+t+\"]*i\"+t})).join(\"+\"),h=o.map((function(t){return\"b\"+t})).join(\",\"),f=o.map((function(t){return\"c\"+t})).join(\",\");i.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),i.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map((function(t){return\"this.shape[\"+t+\"]\"})).join(\"*\"),\"}})\"),1===e?i.push(\"proto.order=[0]\"):(i.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(i.push(\"function \"+r+\"_order(){\"),2===e?i.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&i.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):i.push(\"ORDER})\")),i.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),a?i.push(\"return this.data.set(\"+u+\",v)}\"):i.push(\"return this.data[\"+u+\"]=v}\"),i.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),a?i.push(\"return this.data.get(\"+u+\")}\"):i.push(\"return this.data[\"+u+\"]}\"),i.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),i.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map((function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")})).join(\",\")+\",\"+o.map((function(t){return\"this.stride[\"+t+\"]\"})).join(\",\")+\",this.offset)}\");var p=o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})),d=o.map((function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"}));i.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)i.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");i.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"c\"+t})).join(\",\")+\",b)}\"),i.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"})).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)i.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");i.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t})).join(\",\")+\",c)}\");var m=new Array(e),v=new Array(e);for(g=0;g<e;++g)m[g]=\"a[i\"+g+\"]\",v[g]=\"b[i\"+g+\"]\";i.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map((function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"})).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+m.join(\",\")+\",\"+v.join(\",\")+\",this.offset)}\"),i.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)i.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return i.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),i.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map((function(t){return\"shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"stride[\"+t+\"]\"})).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",i.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],bigint64:[],biguint64:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n){n=0;for(s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s])}for(var h=function(t){if(a(t))return\"buffer\";if(i)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":437,\"is-buffer\":439}],470:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),a=Math.pow(2,-1074);e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-a:a;var r=n.hi(t),i=n.lo(t);e>t==t>0?i===-1>>>0?(r+=1,i=0):i+=1:0===i?(i=-1>>>0,r-=1):i-=1;return n.pack(i,r)}},{\"double-bits\":173}],471:[function(t,e,r){var n=Math.PI,a=c(120);function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,a,i){return[\"C\",t/3+2/3*r,e/3+2/3*n,a/3+2/3*r,i/3+2/3*n,a,i]}function s(t,e,r,i,o,c,u,h,f,p){if(p)T=p[0],k=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,m=(e-(f=d.y))/2,v=g*g/(r*r)+m*m/(i*i);v>1&&(r*=v=Math.sqrt(v),i*=v);var y=r*r,x=i*i,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*m*m-x*g*g)/(y*m*m+x*g*g)));b==1/0&&(b=1);var _=b*r*m/i+(t+h)/2,w=b*-i*g/r+(e+f)/2,T=Math.asin(((e-w)/i).toFixed(9)),k=Math.asin(((f-w)/i).toFixed(9));(T=t<_?n-T:T)<0&&(T=2*n+T),(k=h<_?n-k:k)<0&&(k=2*n+k),u&&T>k&&(T-=2*n),!u&&k>T&&(k-=2*n)}if(Math.abs(k-T)>a){var M=k,A=h,S=f;k=T+a*(u&&k>T?1:-1);var E=s(h=_+r*Math.cos(k),f=w+i*Math.sin(k),r,i,o,0,u,A,S,[k,M,_,w])}var C=Math.tan((k-T)/4),L=4/3*r*C,P=4/3*i*C,I=[2*t-(t+L*Math.sin(T)),2*e-(e-P*Math.cos(T)),h+L*Math.sin(k),f-P*Math.cos(k),h,f];if(p)return I;E&&(I=I.concat(E));for(var z=0;z<I.length;){var O=l(I[z],I[z+1],o);I[z++]=O.x,I[z++]=O.y}return I}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,a=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,m=t.length;g<m;g++){var v=t[g],y=v[0];switch(y){case\"M\":l=v[1],u=v[2];break;case\"A\":(v=s(p,d,v[1],v[2],c(v[3]),v[4],v[5],v[6],v[7])).unshift(\"C\"),v.length>7&&(r.push(v.splice(0,7)),v.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-a),v=[\"C\",x,b,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),v=o(p,d,h,f,v[1],v[2]);break;case\"Q\":h=v[1],f=v[2],v=o(p,d,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(p,d,v[1],v[2]);break;case\"H\":v=i(p,d,v[1],d);break;case\"V\":v=i(p,d,p,v[1]);break;case\"Z\":v=i(p,d,l,u)}e=y,p=v[v.length-2],d=v[v.length-1],v.length>4?(n=v[v.length-4],a=v[v.length-3]):(n=p,a=d),r.push(v)}return r}},{}],472:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,a=new Array(n),i=void 0===r?1e-6:r,o=0;o<n;++o)a[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),m=0,v=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],m+=g[x]*g[x],v[x]=d[x]-p[x],y+=v[x]*v[x];if(m*y>i){var b=a[c],_=1/Math.sqrt(m*y);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;b[x]+=_*(v[w]*g[T]-v[T]*g[w])}}}for(o=0;o<n;++o){b=a[o];var k=0;for(x=0;x<3;++x)k+=b[x]*b[x];if(k>i)for(_=1/Math.sqrt(k),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return a},r.faceNormals=function(t,e,r){for(var n=t.length,a=new Array(n),i=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>i?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;a[o]=f}return a}},{}],473:[function(t,e,r){\n",
       "/*\n",
       "object-assign\n",
       "(c) Sindre Sorhus\n",
       "@license MIT\n",
       "*/\n",
       "\"use strict\";var n=Object.getOwnPropertySymbols,a=Object.prototype.hasOwnProperty,i=Object.prototype.propertyIsEnumerable;function o(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,s,l=o(t),c=1;c<arguments.length;c++){for(var u in r=Object(arguments[c]))a.call(r,u)&&(l[u]=r[u]);if(n){s=n(r);for(var h=0;h<s.length;h++)i.call(r,s[h])&&(l[s[h]]=r[s[h]])}}return l}},{}],474:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a,i,o,s,l,c){var u=e+i+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-i)/h,t[3]=.5*h}else{var f=Math.max(e,i,c);h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(a+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):i>=f?(t[0]=.5*(r+a)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-a)/h)}return t}},{}],475:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var a=new h(r,e,Math.log(n));a.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&a.lookAt(0,t.eye,t.center,t.up);return a};var n=t(\"filtered-vector\"),a=t(\"gl-mat4/lookAt\"),i=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=c(r,n,a,i);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=a/o,t[3]=i/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;i(r,e);var n=this.computedCenter,a=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);a[0]=n[0]+s*r[2],a[1]=n[1]+s*r[6],a[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*a[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var a=this.computedMatrix,i=a[1],o=a[5],s=a[9],c=l(i,o,s);i/=c,o/=c,s/=c;var u=a[0],h=a[4],f=a[8],p=u*i+h*o+f*s,d=l(u-=i*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=a[2],m=a[6],v=a[10],y=g*i+m*o+v*s,x=g*u+m*h+v*f,b=l(g-=y*i+x*u,m-=y*o+x*h,v-=y*s+x*f);g/=b,m/=b,v/=b;var _=u*e+i*r,w=h*e+o*r,T=f*e+s*r;this.center.move(t,_,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var a=this.computedMatrix,i=a[0],o=a[4],s=a[8],u=a[1],h=a[5],f=a[9],p=a[2],d=a[6],g=a[10],m=e*i+r*u,v=e*o+r*h,y=e*s+r*f,x=-(d*y-g*v),b=-(g*m-p*y),_=-(p*v-d*m),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),T=c(x,b,_,w);T>1e-6?(x/=T,b/=T,_/=T,w/=T):(x=b=_=0,w=1);var k=this.computedRotation,M=k[0],A=k[1],S=k[2],E=k[3],C=M*w+E*x+A*_-S*b,L=A*w+E*b+S*x-M*_,P=S*w+E*_+M*b-A*x,I=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,I=I*(w=Math.cos(e))-(C=C*w+I*x+L*_-P*b)*x-(L=L*w+I*b+P*x-C*_)*b-(P=P*w+I*_+C*b-L*x)*_}var O=c(C,L,P,I);O>1e-6?(C/=O,L/=O,P/=O,I/=O):(C=L=P=0,I=1),this.rotation.set(t,C,L,P,I)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var i=this.computedMatrix;a(i,e,r,n);var o=this.computedRotation;s(o,i[0],i[1],i[2],i[4],i[5],i[6],i[8],i[9],i[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var a=n[15];if(Math.abs(a)>1e-6){var i=n[12]/a,l=n[13]/a,c=n[14]/a;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,i-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var a=t.distance;a&&a>0&&this.radius.set(e,Math.log(a)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":474,\"filtered-vector\":242,\"gl-mat4/fromQuat\":275,\"gl-mat4/invert\":278,\"gl-mat4/lookAt\":279}],476:[function(t,e,r){\n",
       "/*!\n",
       " * pad-left <https://github.com/jonschlinkert/pad-left>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT license.\n",
       " */\n",
       "\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":513}],477:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],a=e.escape||\"___\",i=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function i(e,i,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),a+s+a}r.forEach((function(t,n){for(var a,o=0;t!=a;)if(a=t,t=t.replace(e,i),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+a+r+\"\\\\\"+a+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+a+\"([0-9]+)\\\\\"+a);return i?r:function t(e,r,n){for(var a,i=[],s=0;a=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");i.push(e.slice(0,a.index)),i.push(t(r[a[1]],r)),e=e.slice(a.index+a[0].length)}return i.push(e),i}(r[0],r)}function a(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",a=t[0];if(!a)return\"\";for(var i=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;a!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=a,a=a.replace(i,s)}return a}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function i(t,e){return Array.isArray(t)?a(t,e):n(t,e)}i.parse=n,i.stringify=a,e.exports=i},{}],478:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":485}],479:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(a,(function(t,r,a){var o=r.toLowerCase();for(a=function(t){var e=t.match(i);return e?e.map(Number):[]}(a),\"m\"==o&&a.length>2&&(e.push([r].concat(a.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(a.length==n[o])return a.unshift(r),e.push(a);if(a.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(a.splice(0,n[o])))}})),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},a=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var i=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],480:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],481:[function(t,e,r){(function(t){function e(t,e){for(var r=0,n=t.length-1;n>=0;n--){var a=t[n];\".\"===a?t.splice(n,1):\"..\"===a?(t.splice(n,1),r++):r&&(t.splice(n,1),r--)}if(e)for(;r--;r)t.unshift(\"..\");return t}function n(t,e){if(t.filter)return t.filter(e);for(var r=[],n=0;n<t.length;n++)e(t[n],n,t)&&r.push(t[n]);return r}r.resolve=function(){for(var r=\"\",a=!1,i=arguments.length-1;i>=-1&&!a;i--){var o=i>=0?arguments[i]:t.cwd();if(\"string\"!=typeof o)throw new TypeError(\"Arguments to path.resolve must be strings\");o&&(r=o+\"/\"+r,a=\"/\"===o.charAt(0))}return(a?\"/\":\"\")+(r=e(n(r.split(\"/\"),(function(t){return!!t})),!a).join(\"/\"))||\".\"},r.normalize=function(t){var i=r.isAbsolute(t),o=\"/\"===a(t,-1);return(t=e(n(t.split(\"/\"),(function(t){return!!t})),!i).join(\"/\"))||i||(t=\".\"),t&&o&&(t+=\"/\"),(i?\"/\":\"\")+t},r.isAbsolute=function(t){return\"/\"===t.charAt(0)},r.join=function(){var t=Array.prototype.slice.call(arguments,0);return r.normalize(n(t,(function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"Arguments to path.join must be strings\");return t})).join(\"/\"))},r.relative=function(t,e){function n(t){for(var e=0;e<t.length&&\"\"===t[e];e++);for(var r=t.length-1;r>=0&&\"\"===t[r];r--);return e>r?[]:t.slice(e,r-e+1)}t=r.resolve(t).substr(1),e=r.resolve(e).substr(1);for(var a=n(t.split(\"/\")),i=n(e.split(\"/\")),o=Math.min(a.length,i.length),s=o,l=0;l<o;l++)if(a[l]!==i[l]){s=l;break}var c=[];for(l=s;l<a.length;l++)c.push(\"..\");return(c=c.concat(i.slice(s))).join(\"/\")},r.sep=\"/\",r.delimiter=\":\",r.dirname=function(t){if(\"string\"!=typeof t&&(t+=\"\"),0===t.length)return\".\";for(var e=t.charCodeAt(0),r=47===e,n=-1,a=!0,i=t.length-1;i>=1;--i)if(47===(e=t.charCodeAt(i))){if(!a){n=i;break}}else a=!1;return-1===n?r?\"/\":\".\":r&&1===n?\"/\":t.slice(0,n)},r.basename=function(t,e){var r=function(t){\"string\"!=typeof t&&(t+=\"\");var e,r=0,n=-1,a=!0;for(e=t.length-1;e>=0;--e)if(47===t.charCodeAt(e)){if(!a){r=e+1;break}}else-1===n&&(a=!1,n=e+1);return-1===n?\"\":t.slice(r,n)}(t);return e&&r.substr(-1*e.length)===e&&(r=r.substr(0,r.length-e.length)),r},r.extname=function(t){\"string\"!=typeof t&&(t+=\"\");for(var e=-1,r=0,n=-1,a=!0,i=0,o=t.length-1;o>=0;--o){var s=t.charCodeAt(o);if(47!==s)-1===n&&(a=!1,n=o+1),46===s?-1===e?e=o:1!==i&&(i=1):-1!==e&&(i=-1);else if(!a){r=o+1;break}}return-1===e||-1===n||0===i||1===i&&e===n-1&&e===r+1?\"\":t.slice(e,n)};var a=\"b\"===\"ab\".substr(-1)?function(t,e,r){return t.substr(e,r)}:function(t,e,r){return e<0&&(e=t.length+e),t.substr(e,r)}}).call(this,t(\"_process\"))},{_process:500}],482:[function(t,e,r){(function(t){(function(){var r,n,a,i,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,i=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=i-s):Date.now?(e.exports=function(){return Date.now()-a},a=Date.now()):(e.exports=function(){return(new Date).getTime()-a},a=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:500}],483:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<32){for(var r=1,a=0;a<e;++a)for(var i=0;i<a;++i)if(t[a]<t[i])r=-r;else if(t[a]===t[i])return 0;return r}var o=n.mallocUint8(e);for(a=0;a<e;++a)o[a]=0;for(r=1,a=0;a<e;++a)if(!o[a]){var s=1;o[a]=1;for(i=t[a];i!==a;i=t[i]){if(o[i])return n.freeUint8(o),0;s+=1,o[i]=1}1&s||(r=-r)}return n.freeUint8(o),r};var n=t(\"typedarray-pool\")},{\"typedarray-pool\":567}],484:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),a=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,i,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(a(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)i=l[o],r=s[o],s[o]=s[i],s[i]=r,l[o]=l[r],l[r]=i,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,a,i,o=1;for((r=r||new Array(t))[0]=0,i=1;i<t;++i)r[i]=i,o=o*i|0;for(i=t-1;i>0;--i)e=e-(n=e/o|0)*o|0,o=o/i|0,a=0|r[i],r[i]=0|r[n],r[n]=0|a;return r}},{\"invert-permutation\":436,\"typedarray-pool\":567}],485:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,i,o={};if(\"string\"==typeof e&&(e=a(e)),Array.isArray(e)){var s={};for(i=0;i<e.length;i++)s[e[i]]=!0;e=s}for(n in e)e[n]=a(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(i=0;i<c.length;i++){var u=c[i];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=i;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function a(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],486:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,a=t.length,i=[new Array(r),new Array(r)],o=0;o<r;++o)i[0][o]=[],i[1][o]=[];for(o=0;o<a;++o){var s=t[o];i[0][s[0]].push(s),i[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)i[0][o].length+i[1][o].length===0&&l.push([o]);function c(t,e){var r=i[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,a){for(var o,s,l,u=0;u<2;++u)if(i[u][r].length>0){o=i[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=i[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h];n(e[t],e[r],e[s],e[g])>0&&(o=d,s=g,l=h)}return a||o&&c(o,l),s}function h(t,r){var a=i[r][t][0],o=[t];c(a,r);for(var s=a[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(i[0][t].length+i[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];i[p][o].length>0;){i[0][o].length;var g=h(o,p);f(0,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":132}],487:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),a=new Array(e.length),i=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;i[s]=l,a[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();a[c]=!1;var u=r[c];for(s=0;s<u.length;++s){var h=u[s];0==--i[h]&&o.push(h)}}var f=new Array(e.length),p=[];for(s=0;s<e.length;++s)if(a[s]){c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;var d=[];for(s=0;s<t.length;++s){var g=t[s];a[g[0]]&&a[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":178}],488:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=a(t,e);var g=(d=d.filter((function(t){for(var r=t.length,n=[0],a=0;a<r;++a){var i=e[t[a]],l=e[t[(a+1)%r]],c=o(-i[0],i[1]),u=o(-i[0],l[1]),h=o(l[0],i[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0}))).length,m=new Array(g),v=new Array(g);for(p=0;p<g;++p){m[p]=p;var y=new Array(g),x=d[p].map((function(t){return e[t]})),b=i([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var M=b(e[q[k]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}v[p]=[_,p,y]}v.sort((function(t,e){return e[0]-t[0]}));for(p=0;p<g;++p){var A=(y=v[p])[1],S=y[2];for(w=0;w<g;++w)S[w]&&(m[w]=A)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g);for(p=0;p<g;++p)E[p].push(m[p]),E[m[p]].push(p);var C={},L=u(h,!1);for(p=0;p<g;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var P=q[w],I=q[(w+1)%T],z=Math.min(P,I)+\":\"+Math.max(P,I);if(z in C){var O=C[z];E[O].push(p),E[p].push(O),L[P]=L[I]=!0}else C[z]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!L[t[r]])return!1;return!0}var R=[],F=u(g,-1);for(p=0;p<g;++p)m[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);r=[];for(;R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];if(0===V){var q=d[B];j=[q]}for(p=0;p<U;++p){var H=N[p];if(!(F[H]>=0))if(F[H]=1^V,R.push(H),0===V)D(q=d[H])||(q.reverse(),j.push(q))}0===V&&r.push(j)}return r};var n=t(\"edges-to-adjacency-list\"),a=t(\"planar-dual\"),i=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":487,\"edges-to-adjacency-list\":178,\"planar-dual\":486,\"point-in-big-polygon\":490,\"robust-sum\":525,\"two-product\":554,uniq:569}],489:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],490:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],i=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?i.push([d,g]):r.push([d,g])}if(0===r.length)return 0===i.length?c:(m=l(i),function(t){return m(t[0],t[1])?0:1});var m;var v=a(r),y=function(t,e){return function(r){var a=o.le(e,r[0]);if(a<0)return 1;var i=t[a];if(!i){if(!(a>0&&e[a]===r[0]))return 1;i=t[a-1]}for(var s=1;i;){var l=i.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)i=i.left;else{if(!(c>0))return 0;s=-1,i=i.right}else if(c>0)i=i.left;else{if(!(c<0))return 0;s=1,i=i.right}}return s}}(v.slabs,v.coordinates);return 0===i.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(i),y)};var n=t(\"robust-orientation\")[3],a=t(\"slab-decomposition\"),i=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],a=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];a in e?e[a].push(c):e[a]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=i(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":489,\"interval-tree-1d\":434,\"robust-orientation\":520,\"slab-decomposition\":537}],491:[function(t,e,r){\n",
       "/*\n",
       " * @copyright 2016 Sean Connelly (@voidqk), http://syntheti.cc\n",
       " * @license MIT\n",
       " * @preserve Project Home: https://github.com/voidqk/polybooljs\n",
       " */\n",
       "var n,a=t(\"./lib/build-log\"),i=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=i();function f(t,e,r){var a=n.segments(t),i=n.segments(e),o=r(n.combine(a,i));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=a():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":492,\"./lib/epsilon\":493,\"./lib/geojson\":494,\"./lib/intersecter\":495,\"./lib/segment-chainer\":497,\"./lib/segment-selector\":498}],492:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],493:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var a=r[0],i=r[1],o=n[0],s=n[1],l=e[0];return(o-a)*(e[1]-i)-(s-i)*(l-a)>=-t},pointBetween:function(e,r,n){var a=e[1]-r[1],i=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*i+a*s;return!(l<t)&&!(l-(i*i+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var a=e[0]-r[0],i=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(a*s-o*i)<t},linesIntersect:function(e,r,n,a){var i=r[0]-e[0],o=r[1]-e[1],s=a[0]-n[0],l=a[1]-n[1],c=i*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(i*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*i,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],a=e[1],i=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-a>t!=o-a>t&&(i-c)*(a-u)/(o-u)+c-n>t&&(s=!s),i=c,o=u}return s}};return e}},{}],494:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),a=1;a<e.length;a++)n=t.selectDifference(t.combine(n,r(e[a])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),a=0;a<e.coordinates.length;a++)n=t.selectUnion(t.combine(n,r(e.coordinates[a])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function a(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var i=a(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var i=a(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(i.children.push(s),t.children.splice(r,1),r--)}t.children.push(i)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(i,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],a=t[t.length-1][1],i=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];i.push([s,l]),r+=l*n-s*a,n=s,a=l}return r<0!==e&&i.reverse(),i.push([i[0][0],i[0][1]]),i}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<i.children.length;s++)h(i.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],495:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function a(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var i=n.create();function o(t,r){i.insertBefore(t,(function(n){return function(t,r,n,a,i,o){var s=e.pointsCompare(r,i);return 0!==s?s:e.pointsSame(n,o)?0:t!==a?t?1:-1:e.pointAboveOrOnLine(n,a?i:o,a?o:i)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var a=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=a,o(a,t.pt)}(r,t,e),r}function l(t,e){var n=a(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(a,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,a,i,o,s,l;return(n=t,a=r.ev,i=n.seg.start,o=n.seg.end,s=a.seg.start,l=a.seg.end,e.pointsCollinear(i,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(i,s,l)?1:-1)>0}))}function u(t,n){var a=t.seg,i=n.seg,o=a.start,s=a.end,c=i.start,u=i.end;r&&r.checkIntersection(a,i);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!i.isEmpty();){var f=i.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function m(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var v,y=m();if(y){var x;if(t)(x=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(y.seg.myFill.above=!y.seg.myFill.above);else y.seg.otherFill=f.seg.myFill;r&&r.segmentUpdate(y.seg),f.other.remove(),f.remove()}if(i.getHead()!==f){r&&r.rewind(f.seg);continue}if(t)x=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:a,f.seg.myFill.above=x?!f.seg.myFill.below:f.seg.myFill.below;else if(null===f.seg.otherFill)v=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:a,f.seg.otherFill={above:v,below:v};r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}i.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,a,i,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((a=c<0?n:o,i=c<0?o:n,{id:r?r.segmentId():-1,start:a,end:i,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(a(t.start,t.end,t),!0)})),r.forEach((function(t){s(a(t.start,t.end,t),!1)})),c(e,n)}}}},{\"./linked-list\":496}],496:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,a=t.root.next;null!==a;){if(r(a))return e.prev=a.prev,e.next=a,a.prev.next=e,void(a.prev=e);n=a,a=a.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],497:[function(t,e,r){e.exports=function(t,e,r){var n=[],a=[];return t.forEach((function(t){var i=t.start,o=t.end;if(e.pointsSame(i,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(m=n[u])[0],f=(m[1],m[m.length-1]);m[m.length-2];if(e.pointsSame(h,i)){if(k(u,!0,!0))break}else if(e.pointsSame(h,o)){if(k(u,!0,!1))break}else if(e.pointsSame(f,i)){if(k(u,!1,!0))break}else if(e.pointsSame(f,o)&&k(u,!1,!1))break}if(c===s)return n.push([i,o]),void(r&&r.chainNew(i,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:i,g=s.matches_head,m=n[p],v=g?m[0]:m[m.length-1],y=g?m[1]:m[m.length-2],x=g?m[m.length-1]:m[0],b=g?m[m.length-2]:m[1];return e.pointsCollinear(y,v,d)&&(g?(r&&r.chainRemoveHead(s.index,d),m.shift()):(r&&r.chainRemoveTail(s.index,d),m.pop()),v=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,v)&&(g?(r&&r.chainRemoveTail(s.index,v),m.pop()):(r&&r.chainRemoveHead(s.index,v),m.shift())),r&&r.chainClose(s.index),void a.push(m)):void(g?(r&&r.chainAddHead(s.index,d),m.unshift(d)):(r&&r.chainAddTail(s.index,d),m.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var T=n[_].length<n[w].length;s.matches_head?l.matches_head?T?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):T?(M(_),A(w,_)):(M(w),A(_,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,a){var i=n[t],o=n[a],s=i[i.length-1],l=i[i.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),i.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(a,c),o.shift()),r&&r.chainJoin(t,a),n[t]=i.concat(o),n.splice(a,1)}})),a}},{}],498:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach((function(t){var a=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[a]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[a],below:2===e[a]},otherFill:null})})),r&&r.selected(n),n}var a={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=a},{}],499:[function(t,e,r){\"use strict\";var n=new Float64Array(4),a=new Float64Array(4),i=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),a=new Float64Array(o.length),i=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],a[l]=e[l]-t[l],i[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=a[l],m=i[l],v=n[l];c+=g*g,u+=g*m,h+=m*m,f+=v*g,p+=v*m,d+=v*v}var y,x,b,_,w,T=Math.abs(c*h-u*u),k=u*p-h*f,M=u*f-c*p;if(k+M<=T)if(k<0)M<0&&f<0?(M=0,-f>=c?(k=1,y=c+2*f+d):y=f*(k=-f/c)+d):(k=0,p>=0?(M=0,y=d):-p>=h?(M=1,y=h+2*p+d):y=p*(M=-p/h)+d);else if(M<0)M=0,f>=0?(k=0,y=d):-f>=c?(k=1,y=c+2*f+d):y=f*(k=-f/c)+d;else{var A=1/T;y=(k*=A)*(c*k+u*(M*=A)+2*f)+M*(u*k+h*M+2*p)+d}else k<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(k=1,M=0,y=c+2*f+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*f)+M*(u*k+h*M+2*p)+d:(k=0,b<=0?(M=1,y=h+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/h)+d):M<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(M=1,k=0,y=h+2*p+d):y=(k=1-(M=_/w))*(c*k+u*M+2*f)+M*(u*k+h*M+2*p)+d:(M=0,b<=0?(k=1,y=c+2*f+d):f>=0?(k=0,y=d):y=f*(k=-f/c)+d):(_=h+p-u-f)<=0?(k=0,M=1,y=h+2*p+d):_>=(w=c-2*u+h)?(k=1,M=0,y=c+2*f+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*f)+M*(u*k+h*M+2*p)+d;var S=1-k-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*e[l]+M*r[l];return y<0?0:y}},{}],500:[function(t,e,r){var n,a,i=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{a=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){a=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(a===clearTimeout)return clearTimeout(t);if((a===s||!a)&&clearTimeout)return a=clearTimeout,clearTimeout(t);try{a(t)}catch(e){try{return a.call(null,t)}catch(e){return a.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function m(){}i.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},i.title=\"browser\",i.browser=!0,i.env={},i.argv=[],i.version=\"\",i.versions={},i.on=m,i.addListener=m,i.once=m,i.off=m,i.removeListener=m,i.removeAllListeners=m,i.emit=m,i.prependListener=m,i.prependOnceListener=m,i.listeners=function(t){return[]},i.binding=function(t){throw new Error(\"process.binding is not supported\")},i.cwd=function(){return\"/\"},i.chdir=function(t){throw new Error(\"process.chdir is not supported\")},i.umask=function(){return 0}},{}],501:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":304}],502:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),a=\"undefined\"==typeof window?r:window,i=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=a[\"request\"+o],l=a[\"cancel\"+o]||a[\"cancelRequest\"+o],c=0;!s&&c<i.length;c++)s=a[i[c]+\"Request\"+o],l=a[i[c]+\"Cancel\"+o]||a[i[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout((function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(a,t)},e.exports.cancel=function(){l.apply(a,arguments)},e.exports.polyfill=function(t){t||(t=a),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":482}],503:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,a=new Array(r),i=0;i<r;++i)a[i]=n(t[i],e[i]);return a}},{\"big-rat/add\":80}],504:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":83}],505:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),a=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),i=t.length,o=new Array(i),s=0;s<i;++s)o[s]=a(t[s],r);return o}},{\"big-rat\":83,\"big-rat/mul\":92}],506:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,a=new Array(r),i=0;i<r;++i)a[i]=n(t[i],e[i]);return a}},{\"big-rat/sub\":94}],507:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),a=t(\"compare-oriented-cell\"),i=t(\"cell-orientation\");e.exports=function(t){t.sort(a);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=i(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&i(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":117,\"compare-cell\":133,\"compare-oriented-cell\":134}],508:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),a=t(\"color-normalize\"),i=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,m,v=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"static\",type:\"float\",data:f}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:m,stride:24,offset:0},lineOffset:{buffer:m,stride:24,offset:8},capOffset:{buffer:m,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:T,draw:_,destroy:k,regl:t,gl:v,canvas:v.canvas,groups:x}),b;function b(t){t?T(t):null===t&&k(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),i(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var i=0;i<r;i++)t[i]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=a(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:v.drawingBufferWidth,height:v.drawingBufferHeight},e}}]),u):u})),e||r){var f=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),m=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,a=t.offset,i=t.color,o=t.errors;n&&(_.set(i,4*a),w.set(o,4*a),m.set(r,2*a))}})),c(u(m)),p(h(m)),d(_),g(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),m.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":70,\"color-normalize\":125,\"flatten-vertex-data\":244,\"object-assign\":473,\"pick-by-alias\":485,\"to-float32\":549,\"update-diff\":571}],509:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),a=t(\"array-bounds\"),i=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function m(t,e){if(!(this instanceof m))return new m(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=m.shaders.has(t)?m.shaders.get(t):m.shaders.set(t,m.createShaders(t)).get(t),this.update(e)}e.exports=m,m.dashMult=2,m.maxPatternLength=256,m.precisionThreshold=3e6,m.maxPoints=1e4,m.maxLines=2048,m.shaders=new d,m.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},a=t(i({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(i({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=a}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:a,miter:e}},m.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},m.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},m.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>m.precisionThreshold||e.scale[1]*e.viewport.height>m.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=m.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},m.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach((function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=i({},m.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<m.maxLines&&(d.depth=2*(m.maxLines-1-h%m.maxLines)/m.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var v,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),v=new Float64Array(2*y);for(var _=0;_<y;_++)v[2*_]=x[_],v[2*_+1]=b[_]}else v=l(t.positions,\"float64\"),y=d.count=Math.floor(v.length/2);var w=d.bounds=a(v,2);if(d.fill){for(var T=[],k={},M=0,A=0,S=0,E=d.count;A<E;A++){var C=v[2*A],L=v[2*A+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=v[2*M],L=v[2*M+1],k[A]=M):M=A,T[S++]=C,T[S++]=L}for(var P=c(T,d.hole||[]),I=0,z=P.length;I<z;I++)null!=k[P[I]]&&(P[I]=k[P[I]]);d.triangles=P}var O=new Float64Array(v);u(O,2,w);var D=new Float64Array(2*y+6);d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[0]=O[2*y-4],D[1]=O[2*y-3]):(D[0]=O[2*y-2],D[1]=O[2*y-1]):(D[0]=O[0],D[1]=O[1]),D.set(O,2),d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[2*y+2]=O[2],D[2*y+3]=O[3],d.count-=1):(D[2*y+2]=O[0],D[2*y+3]=O[1],D[2*y+4]=O[2],D[2*y+5]=O[3]):(D[2*y+2]=O[2*y-2],D[2*y+3]=O[2*y-1],D[2*y+4]=O[2*y-2],D[2*y+5]=O[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*m.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var Z=0,X=t.dashes[W]*m.dashMult*.5;Z<X;++Z)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],\"uint8\");Q.set(tt,4*$)}Q.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:Q})}}else e.passes[h]=null})),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=this.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var v=[],y=0;y<this.passes.length;y++)null!==this.passes[y]&&v.push(this.passes[y]);return this.passes=v,this}},m.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},{\"array-bounds\":70,\"array-normalize\":71,\"color-normalize\":125,earcut:177,\"es6-weak-map\":233,\"flatten-vertex-data\":244,glslify:413,\"object-assign\":473,\"parse-rect\":478,\"pick-by-alias\":485,\"to-float32\":549}],510:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){if(\"undefined\"==typeof Symbol||!(Symbol.iterator in Object(t)))return;var r=[],n=!0,a=!1,i=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){a=!0,i=t}finally{try{n||null==s.return||s.return()}finally{if(a)throw i}}return r}(t,e)||i(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function a(t){return function(t){if(Array.isArray(t))return o(t)}(t)||function(t){if(\"undefined\"!=typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}(t)||i(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t,e){if(t){if(\"string\"==typeof t)return o(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?o(t,e):void 0}}function o(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var s=t(\"color-normalize\"),l=t(\"array-bounds\"),c=t(\"color-id\"),u=t(\"@plotly/point-cluster\"),h=t(\"object-assign\"),f=t(\"glslify\"),p=t(\"pick-by-alias\"),d=t(\"update-diff\"),g=t(\"flatten-vertex-data\"),m=t(\"is-iexplorer\"),v=t(\"to-float32\"),y=t(\"parse-rect\"),x=b;function b(t,e){var r=this;if(!(this instanceof b))return new b(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,a=(t=e.regl)._gl,i=[];this.tooManyColors=m,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),h(this,{regl:t,gl:a,groups:[],markerCache:[null],markerTextures:[null],palette:i,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:a.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?i.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?i.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=h({},o);s.frag=f([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=f([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=h({},o);l.frag=f([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=f([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),m&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}b.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},b.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},b.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var a=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var i=0;i<r.length;i++)this.drawItem(i,r[i]);else a.forEach((function(e,r){t.drawItem(r)}));return this},b.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var i=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&i.push.apply(i,a(this.getMarkerDrawOptions(o,n,e)));i.length&&this.drawMarker(i)}},b.prototype.getMarkerDrawOptions=function(t,e,r){var a=e.range,i=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;this.regl;if(!i)return r?[h({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[h({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var u=[],f=i.range(a,{lod:!0,px:[(a[2]-a[0])/o.width,(a[3]-a[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),g=0;g<r.length;g++){var m=r[g];d[m]=p?p[m]:1}l.subdata(d)}for(var v=f.length;v--;){var y=n(f[v],2),x=y[0],b=y[1];u.push(h({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return u},b.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var a=this.groups,i=this.gl,o=this.regl,s=this.maxSize,c=this.maxColors,f=this.palette;this.groups=a=r.map((function(e,r){var n=a[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=p(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(a[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=h({},b.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var m=0,x=0;if(d(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=b.defaults.size),m+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=b.defaults.borderSize),m+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=b.defaults.color),e=t.updateColor(e),x++,e},borderColor:function(e,r){return null==e&&(e=b.defaults.borderColor),e=t.updateColor(e),x++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,a=e.positionBuffer,i=e.positionFractBuffer,s=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=g(t,\"float64\");var c=e.count=Math.floor(t.length/2),h=e.bounds=c?l(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||c>n)?e.tree=u(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=o.elements(f)}return a({data:v.float(t),usage:\"dynamic\"}),i({data:v.fract(t),usage:\"dynamic\"}),s({data:new Uint8Array(c),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var a=r.activation;if(a.forEach((function(t){return t&&t.destroy&&t.destroy()})),a.length=0,e&&\"number\"!=typeof e[0]){for(var i=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);i[c]||(i[c]=new Uint8Array(r.count)),i[c][s]=1}for(var u=0;u<i.length;u++)if(i[u]){var h={data:i[u],type:\"uint8\",usage:\"static\"};a[u]?a[u](h):a[u]=o.buffer(h),a[u].data=i[u]}}else{a[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=v.fract(e.scale),e.translateFract=v.fract(e.translate),t},viewport:function(t){return y(t||[i.drawingBufferWidth,i.drawingBufferHeight])}}]),m){var _=n,w=_.count,T=_.size,k=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==T[S]?T:T[S])/s),A[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/s);M({data:A,usage:\"dynamic\"})}if(x){var E,C=n,L=C.count,P=C.color,I=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||I.length){E=new Uint8Array(8*L);for(var O=0;O<L;O++){var D=P[O];E[8*O]=f[4*D],E[8*O+1]=f[4*D+1],E[8*O+2]=f[4*D+2],E[8*O+3]=f[4*D+3];var R=I[O];E[8*O+4]=f[4*R],E[8*O+5]=f[4*R+1],E[8*O+6]=f[4*R+2],E[8*O+7]=f[4*R+3]}}}else if(P.length||I.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%c,E[4*F+1]=Math.floor(P[F]/c)),null!=I[F]&&(E[4*F+2]=I[F]%c,E[4*F+3]=Math.floor(I[F]/c))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},b.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,a=this.markerCache,i=null==t?0:a.indexOf(t);if(i>=0)return i;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return i=r.length,a.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),i},b.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var a=[];if(\"number\"==typeof t[0]){var i=[];if(Array.isArray(t))for(var o=0;o<t.length;o+=4)i.push(t.slice(o,o+4));else for(var l=0;l<t.length;l+=4)i.push(t.subarray(l,l+4));t=i}for(var u=0;u<t.length;u++){var h=t[u];h=s(h,\"uint8\");var f=c(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}a[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===a.length?a[0]:a},b.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var a=.25*(t=t.slice()).length%e;a<n*e;a++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},b.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=t(\"object-assign\");e.exports=function(t,e){var r=new x(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"@plotly/point-cluster\":57,\"array-bounds\":70,\"color-id\":123,\"color-normalize\":125,\"flatten-vertex-data\":244,glslify:413,\"is-iexplorer\":440,\"object-assign\":473,\"parse-rect\":478,\"pick-by-alias\":485,\"to-float32\":549,\"update-diff\":571}],511:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),a=t(\"pick-by-alias\"),i=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,a,i,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],a=s[3]):s.length?(n=s[0],a=s[1]):(s.x,n=s.y,s.x+s.width,a=s.y+s.height),l.length>2?(i=l[0],o=l[2],l[1],l[3]):l.length?(i=l[0],o=l[1]):(i=l.x,l.y,o=l.x+l.width,l.y+l.height),[i,n,o,a]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var a=[],i=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)a.push(this.passes[l[c]]);s.passOffset=i,i+=s.passes.length}return(t=this.scatter).update.apply(t,a),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=a(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=i(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,m=s.count,v=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=v/g,w=y/g;s.passes=[];for(var T=0;T<g;T++)for(var k=0;k<g;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var M=h(s.id,T,k),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:k,count:m,stride:g},y:{buffer:s.buffer,offset:T,count:m,stride:g}}:A.positions={x:{buffer:s.buffer,offset:k*m,count:m},y:{buffer:s.buffer,offset:T*m,count:m}},A.bounds=f(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?f(s.padding,T,k):s.padding;if(s.domain){var E=f(s.domain,T,k),C=E[0],L=E[1],P=E[2],I=E[3];A.viewport=[x+C*v+S[0],b+L*y+S[1],x+P*v-S[2],b+I*y-S[3]]}else A.viewport=[x+k*_+_*S[0],b+T*w+w*S[1],x+(k+1)*_-_*S[2],b+(T+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?f(s.range,T,k):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],a=0;a<e.length;a++)if(\"number\"==typeof e[a]){var i=this.traces[e[a]],o=i.passes,l=i.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[a].length){var c=e[a],u=this.traces[a],h=u.passes,f=u.passOffset;h=h.map((function(t,e){n[f+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":70,\"array-range\":72,\"flatten-vertex-data\":244,\"parse-rect\":478,\"pick-by-alias\":485,raf:502,\"regl-scatter2d\":510}],512:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.createREGL=n()}(this,(function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function a(t){var e,a,i,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?i=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?i=n(s.canvas):\"container\"in s&&(a=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?i=e:a=e),!o){if(!i){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,U(i.style,{width:e+\"px\",height:n+\"px\"})}var a,i=document.createElement(\"canvas\");return U(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",U(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(a=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){a?a.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(a||document.body,0,u)))return null;i=e.canvas,p=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(i,t)}return o?{gl:o,canvas:i,container:a,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function i(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=i(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||Z(t.data))}function c(t,e,r,n,a,i){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)a[i++]=c[u]}function u(t){return 0|K[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,a,i,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[a*l+i*c+o]}function p(t,e,r,n){function a(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function i(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,a,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){a=et(e);for(var s=n=1;s<a.length;++s)n*=a[s];t.dimension=n,i(t,e=tt(e,a,t.dtype),r),o?t.persistentData=e:Y.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=a,h(a=Y.allocType(t.dtype,e.length),e),i(t,a,r),o?t.persistentData=a:Y.freeType(a)):Z(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,i(t,e=tt(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:Y.freeType(e))}else if(Z(e))t.dtype=n||u(e),t.dimension=a,i(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){a=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,m=0;1===a.length?(p=a[0],d=1,g=c[0],m=0):2===a.length&&(p=a[0],d=a[1],g=c[0],m=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(a=Y.allocType(t.dtype,p*d),e.data,p,d,g,m,s),i(t,a,r),o?t.persistentData=a:Y.freeType(a)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=a,i(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};a.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},a.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach((function(e){t+=p[e].stats.size})),t}),{create:function(n,i,c,d){function g(e){var n=35044,a=null,i=0,s=0,c=1;return Array.isArray(e)||Z(e)||l(e)||e instanceof ArrayBuffer?a=e:\"number\"==typeof e?i=0|e:e&&(\"data\"in e&&(a=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=Q[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(i=0|e.length)),m.bind(),a?o(m,a,n,s,c,d):(i&&t.bufferData(m.type,i,n),m.dtype=s||5121,m.usage=n,m.dimension=c,m.byteLength=i),r.profile&&(m.stats.size=m.byteLength*rt[m.dtype]),g}e.bufferCount++;var m=new a(i);return p[m.id]=m,c||g(n),g._reglType=\"buffer\",g._buffer=m,g.subdata=function(e,r){var n,a=0|(r||0);if(m.bind(),Z(e)||e instanceof ArrayBuffer)t.bufferSubData(m.type,a,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var i=Y.allocType(m.dtype,e.length);h(i,e),t.bufferSubData(m.type,a,i),Y.freeType(i)}else(Array.isArray(e[0])||Z(e[0]))&&(n=et(e),i=tt(e,n,m.dtype),t.bufferSubData(m.type,a,i),Y.freeType(i))}else if(l(e)){n=e.shape;var o=e.stride,s=i=0,c=0,p=0;1===n.length?(i=n[0],s=1,c=o[0],p=0):2===n.length&&(i=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?m.dtype:u(e.data),f(n=Y.allocType(n,i*s),e.data,i,s,c,p,e.offset),t.bufferSubData(m.type,a,n),Y.freeType(n)}return g},r.profile&&(g.stats=m.stats),g.destroy=function(){s(m)},g},createStream:function(t,e){var r=d.pop();return r||(r=new a(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof a?t._buffer:null},restore:function(){X(p).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function d(t,e,r,n){function a(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function i(n,a,i,o,s,c,u){var h;if(n.buffer.bind(),a?((h=u)||Z(a)&&(!l(a)||Z(a.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,a,i,h,3)):(t.bufferData(34963,c,i),n.buffer.dtype=h||5121,n.buffer.usage=i,n.buffer.dimension=3,n.buffer.byteLength=c),h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(a=s)&&(a=n.buffer.byteLength,5123===h?a>>=1:5125===h&&(a>>=2)),n.vertCount=a,a=o,0>o&&(a=4,1===(o=n.buffer.dimension)&&(a=0),2===o&&(a=1),3===o&&(a=4)),n.primType=a}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),a.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,a=-1,o=0,f=0;Array.isArray(t)||Z(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=nt[t.primitive]),\"count\"in t&&(a=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=a,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),i(h,e,r,n,a,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new a(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new a(r.create(null,34963,!0,!1)._buffer)),i(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof a?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=Y.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{at[0]=t[r];var n=(i=it[0])>>>31<<15,a=(i<<1>>>24)-127,i=i>>13&1023;e[r]=-24>a?n:-14>a?n+(i+1024>>-14-a):15<a?n+31744:n+(a+15<<10)+i}return e}function m(t){return Array.isArray(t)||Z(t)}function v(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!m(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=gt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),Y.freeType(e)):t.data=e}function T(t,e,r,n,a,i){if(t=\"undefined\"!=typeof vt[t]?vt[t]:lt[t]*mt[e],i&&(t*=6),a){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function k(t,e,r,n,a,i,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,a=t.channels,i=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(a=e.shape[2],i=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(a=e.channels,i=!0)),t.width=0|r,t.height=0|n,t.channels=0|a,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=G[r],t.format=it[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in W&&(t.compressed=!0),r=!0),!i&&r?t.channels=lt[t.format]:i&&!r&&t.channels!==st[t.format]&&(t.format=t.internalformat=st[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=a.viewportWidth,i=a.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||i-t.yOffset,t.needsCopy=!0}else if(r){if(Z(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,i=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(i=Y.allocType(t.type,i)).set(n),t.data=i;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(n)]);i=r.shape;var o,s,c,h,f=r.stride;3===i.length?(c=i[2],h=f[2]):h=c=1,o=i[0],s=i[1],i=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=st[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=Y.allocType(36193===t.type?5126:t.type,c*h*s),d=0,v=0;v<h;++v)for(var T=0;T<c;++T)for(var k=0;k<s;++k)p[d++]=n[i*T+f*v+o*k+r];w(t,p)}else if(b(r)===ct||b(r)===ut||b(r)===ht)b(r)===ct||b(r)===ut?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===pt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===dt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,i=t.height||r.length,f=t.channels,f=m(r[0][0])?f||r[0][0].length:f||1,o=J.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=Y.allocType(36193===t.type?5126:t.type,c),J.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=i,t.channels=f,t.format=t.internalformat=st[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,a,i,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,a,i,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,a,i,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,a,i,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,a,i,p,d,u,f,l)}function v(){return gt.pop()||new f}function k(t){t.needsFree&&Y.freeType(t.data),f.call(t),gt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=v();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,a=0;a<n.length;++a)c(r=t.images[a]=v(),t),r.width>>=a,r.height>>=a,p(r,n[a]),t.mipmask|=1<<a;else c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var a=e.images,i=0;i<a.length&&a[i];++i){var o=a[i],s=r,l=i,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,m=o.height;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,m,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,m,0)):t.texImage2D(s,l,p,g,m,0,p,d,u||null)}}function C(){var t=mt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&k(e[r]),e[r]=null;mt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function I(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=ot.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var a=e.wrap;\"string\"==typeof a?r=n=N[a]:Array.isArray(a)&&(r=N[a[0]],n=N[a[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function O(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=bt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,a=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(a,null),bt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete yt[e.id],i.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},V=U({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},G={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},W={};e.ext_srgb&&(G.srgb=35904,G.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(U(G,{depth:6402,\"depth stencil\":34041}),U(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&U(W,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&U(W,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&U(W,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(W[\"rgb etc1\"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(W).forEach((function(t){var e=W[t];0<=Q.indexOf(e)&&(G[t]=e)}));var $=Object.keys(G);r.textureFormats=$;var tt=[];Object.keys(G).forEach((function(t){tt[G[t]]=t}));var et=[];Object.keys(H).forEach((function(t){et[H[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(V).forEach((function(t){nt[V[t]]=t}));var at=[];Object.keys(N).forEach((function(t){at[N[t]]=t}));var it=$.reduce((function(t,r){var n=G[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),gt=[],mt=[],vt=0,yt={},xt=r.maxTextureUnits,bt=Array(xt).map((function(){return null}));return U(O.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=bt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}bt[r]=this,e=r;break}o.profile&&i.maxTextureUnits<e+1&&(i.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(i.getTotalTextureSize=function(){var t=0;return Object.keys(yt).forEach((function(e){t+=yt[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=a.texInfo;P.call(r);var i=C();return\"number\"==typeof t?A(i,0|t,\"number\"==typeof e?0|e:0|t):t?(I(r,t),S(i,t)):A(i,1,1),r.genMipmaps&&(i.mipmask=(i.width<<1)-1),a.mipmask=i.mipmask,c(a,i),a.internalformat=i.internalformat,n.width=i.width,n.height=i.height,D(a),E(i,3553),z(r,3553),R(),L(i),o.profile&&(a.stats.size=T(a.internalformat,a.type,i.width,i.height,r.genMipmaps,!1)),n.format=tt[a.internalformat],n.type=et[a.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=at[r.wrapS],n.wrapT=at[r.wrapT],n}var a=new O(3553);return yt[a.id]=a,i.textureCount++,n(e,r),n.subimage=function(t,e,r,i){e|=0,r|=0,i|=0;var o=v();return c(o,a),o.width=0,o.height=0,p(o,t),o.width=o.width||(a.width>>i)-e,o.height=o.height||(a.height>>i)-r,D(a),d(o,3553,e,r,i),R(),k(o),n},n.resize=function(e,r){var i=0|e,s=0|r||i;if(i===a.width&&s===a.height)return n;n.width=a.width=i,n.height=a.height=s,D(a);for(var l=0;a.mipmask>>l;++l){var c=i>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,a.format,c,u,0,a.format,a.type,null)}return R(),o.profile&&(a.stats.size=T(a.internalformat,a.type,i,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=a,o.profile&&(n.stats=a.stats),n.destroy=function(){a.decRef()},n},createCube:function(e,r,n,a,s,l){function h(t,e,r,n,a,i){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],a),S(g[5],i);else if(I(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=T(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=at[l.wrapS],h.wrapT=at[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new O(34067);yt[f.id]=f,i.cubeCount++;var g=Array(6);return h(e,r,n,a,s,l),h.subimage=function(t,e,r,n,a){r|=0,n|=0,a|=0;var i=v();return c(i,f),i.width=0,i.height=0,p(i,e),i.width=i.width||(f.width>>a)-r,i.height=i.height||(f.height>>a)-n,D(f),d(i,34069+t,r,n,a),R(),k(i),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=T(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),bt[e]=null;X(yt).forEach(F),i.cubeCount=0,i.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=bt[e];r&&(r.bindCount=0,r.unit=-1,bt[e]=null)}X(yt).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)}))}}}function M(t,e,r,n,a,i){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,a=t;return\"object\"==typeof t&&(a=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=a._reglType)||\"textureCube\"===t?r=a:\"renderbuffer\"===t&&(n=a,e=36161),new o(e,r,n)}function h(t,e,r,i,s){return r?((t=n.create2D({width:t,height:e,format:i,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=a.create({width:t,height:e,format:i}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function m(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,i.framebufferCount--,delete k[e.id]}function v(e){var n;t.bindFramebuffer(36160,e.framebuffer);var a=e.colorAttachments;for(n=0;n<a.length;++n)c(36064+n,a[n]);for(n=a.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var a,i=0,o=0,s=!0,c=!0;a=null;var p=!0,d=\"rgba\",m=\"uint8\",y=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(i=0|t,o=0|e||i):t?(\"shape\"in t?(i=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(i=o=t.radius),\"width\"in t&&(i=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(a=t.color||t.colors,Array.isArray(a)),a||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(m=t.colorType,!p)&&(\"half float\"===m||\"float16\"===m?d=\"rgba16f\":\"float\"!==m&&\"float32\"!==m||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):i=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(a))M=a.map(u);else if(a)M=[u(a)];else for(M=Array(y),a=0;a<y;++a)M[a]=h(i,o,p,d,m);for(i=i||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=h(i,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(i,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=h(i,o,k,\"depth stencil\",\"depth stencil\")),s=null,a=0;a<M.length;++a)l(M[a]),M[a]&&M[a].texture&&(c=bt[M[a].texture._texture.format]*_t[M[a].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),g(n),n.width=i,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(f),r.depth=f(A),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,v(n),r}var n=new d;return i.framebufferCount++,r(t,e),U(r,{resize:function(t,e){var a=Math.max(0|t,1),i=Math.max(0|e||a,1);if(a===n.width&&i===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],a,i);return p(n.depthAttachment,a,i),p(n.stencilAttachment,a,i),p(n.depthStencilAttachment,a,i),n.width=r.width=a,n.height=r.height=i,v(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){m(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return U(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var a,i={color:null},o=0,s=null;a=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(a=t.colorFormat)),\"depth\"in t&&(i.depth=t.depth),\"stencil\"in t&&(i.stencil=t.stencil),\"depthStencil\"in t&&(i.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],a=0;a<s.length;++a)t[a]=s[a];else t=[s];else for(t=Array(c),s={radius:o,format:a,type:l},a=0;a<c;++a)t[a]=n.createCube(s);for(i.color=Array(t.length),a=0;a<t.length;++a)c=t[a],o=o||c.width,i.color[a]={target:34069,data:t[a]};for(a=0;6>a;++a){for(c=0;c<t.length;++c)i.color[c].target=34069+a;0<a&&(i.depth=r[0].depth,i.stencil=r[0].stencil,i.depthStencil=r[0].depthStencil),r[a]?r[a](i):r[a]=y(i)}return U(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),U(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var a=e.color;for(t=0;t<a.length;++t)a[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){X(k).forEach(m)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),v(e)}))}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n,a){function i(){this.id=++c,this.attributes=[];var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,u[this.id]=this,this.buffers=[]}var o=r.maxAttributes,s=Array(o);for(r=0;r<o;++r)s[r]=new A;var c=0,u={},h={Record:A,scope:{},state:s,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&X(u).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){for(var n=0;n<r.buffers.length;++n)r.buffers[n].destroy();r.buffers.length=0,(n=r.attributes).length=t.length;for(var i=0;i<t.length;++i){var o=t[i],s=n[i]=new A;Array.isArray(o)||Z(o)||l(o)?(o=a.create(o,34962,!1,!0),s.buffer=a.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1,r.buffers.push(o)):a.getBuffer(o)?(s.buffer=a.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1):a.getBuffer(o.buffer)?(s.buffer=a.getBuffer(o.buffer),s.size=0|(+o.size||s.buffer.dimension),s.normalized=!!o.normalized||!1,s.type=\"type\"in o?Q[o.type]:s.buffer.dtype,s.offset=0|(o.offset||0),s.stride=0|(o.stride||0),s.divisor=0|(o.divisor||0),s.state=1):\"x\"in o&&(s.x=+o.x||0,s.y=+o.y||0,s.z=+o.z||0,s.w=+o.w||0,s.state=2)}return r.refresh(),e}var r=new i;return n.vaoCount+=1,e.destroy=function(){r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<s.length;++r){var n=s[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==h.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),h.currentVAO=t}}:function(r){if(r!==h.currentVAO){if(r)r.bindAttrs();else for(var n=e.angle_instanced_arrays,a=0;a<s.length;++a){var i=s[a];i.buffer?(t.enableVertexAttribArray(a),t.vertexAttribPointer(a,i.size,i.type,i.normalized,i.stride,i.offfset),n&&n.vertexAttribDivisorANGLE(a,i.divisor)):(t.disableVertexAttribArray(a),t.vertexAttrib4f(a,i.x,i.y,i.z,i.w))}h.currentVAO=r}},clear:e.oes_vertex_array_object?function(){X(u).forEach((function(t){t.destroy()}))}:function(){}};return i.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,a=0;a<n.length;++a){var i=n[a];i.buffer?(t.enableVertexAttribArray(a),t.bindBuffer(34962,i.buffer.buffer),t.vertexAttribPointer(a,i.size,i.type,i.normalized,i.stride,i.offset),r&&r.vertexAttribDivisorANGLE(a,i.divisor)):(t.disableVertexAttribArray(a),t.vertexAttrib4f(a,i.x,i.y,i.z,i.w))}for(r=n.length;r<o;++r)t.disableVertexAttribArray(r)},i.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),h.currentVAO=this)},i.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===h.currentVAO&&(h.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}u[this.id]&&(delete u[this.id],--n.vaoCount)},h}function E(t,e,r,n){function a(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function i(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,a){if(!(o=(a=35632===r?c:u)[n])){var i=e.str(n),o=t.createShader(r);t.shaderSource(o,i),t.compileShader(o),a[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var h=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var f=0;f<l.size;++f){var p=l.name.replace(\"[0]\",\"[\"+f+\"]\");i(h,new a(p,e.id(p),t.getUniformLocation(s,p),l))}else i(h,new a(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&i(r,new a(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach((function(e){t.deleteProgram(e.program)})),f.length=0,h={},r.shaderCount=0},program:function(t,e,n,a){var i=h[e];i||(i=h[e]={});var o=i[t];return o&&!a?o:(e=new s(e,t),r.shaderCount++,l(e,n,a),o||(i[t]=e),f.push(e),e)},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t],null,f[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function C(t,e,r,n,a,i,o){function s(a){var i;i=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return Z(a)?u=a:a&&(o=0|a.x,s=0|a.y,l=0|(a.width||n.framebufferWidth-o),c=0|(a.height||n.framebufferHeight-s),u=a.data||null),r(),a=l*c*4,u||(5121===i?u=new Uint8Array(a):5126===i&&(u=u||new Float32Array(a))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,i,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function P(t){return L(t).join(\"\")}function I(){function t(){var t=[],e=[];return U((function(){t.push.apply(t,L(arguments))}),{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,L(arguments)),t.push(\";\")),n},toString:function(){return P([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",P(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),a=r.toString,i=n.toString;return U((function(){r.apply(r,L(arguments))}),{def:r.def,entry:r,exit:n,save:e,set:function(t,n,a){e(t,n),r(t,n,\"=\",a,\";\")},toString:function(){return a()+i()}})}var r=0,n=[],a=[],i=t(),o={};return{global:i,link:function(t){for(var e=0;e<a.length;++e)if(a[e]===t)return n[e];return e=\"g\"+r++,n.push(e),a.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+a.length;return a.push(t),t}var a=[];r=r||0;for(var i=0;i<r;++i)n();var s=(i=e()).toString;return o[t]=U(i,{arg:n,toString:function(){return P([\"function(\",a.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=P(arguments),r=e(),n=e(),a=r.toString,i=n.toString;return U(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=i();return e&&(e=\"else{\"+e+\"}\"),P([\"if(\",t,\"){\",a(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',i,\"return {\"];Object.keys(o).forEach((function(e){t.push('\"',e,'\":',o[e].toString(),\",\")})),t.push(\"}\");var e=P(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,a)}}}function z(t){return Array.isArray(t)||Z(t)||l(t)}function O(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function R(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function F(t){return new D(!1,!1,!1,t)}function B(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function N(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g){function v(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=v(t);rt.push(t),et[n]=tt[n]=!!r,at[n]=e}function x(t,e,r){var n=v(t);rt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,it[n]=e}function b(){var t=I(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var a=r(ot),i=t.shared={props:\"a0\"};Object.keys(ot).forEach((function(t){i[t]=n.def(a,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(it).forEach((function(t){Array.isArray(tt[t])&&(o[t]=n.def(i.next,\".\",t),s[t]=n.def(i.current,\".\",t))}));var l=t.constants={};Object.keys(st).forEach((function(t){l[t]=n.def(JSON.stringify(st[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var a=[\"this\",i.context,i.props,t.batchId];return e.def(r(n.data),\".call(\",a.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(i.props,n.data);case 2:return e.def(i.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new X),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var a=r.framebuffer;return a?(a=l.getFramebuffer(a),F((function(t,e){var r=t.link(a),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):F((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var i=n.framebuffer;return B(i,(function(t,e){var r=t.invoke(e,i),n=t.shared,a=n.framebuffer;r=e.def(a,\".getFramebuffer(\",r,\")\");return e.set(a,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function w(t,r,n){function a(t){if(t in i){var r=e.id(i[t]);return(t=F((function(){return r}))).id=r,t}if(t in o){var n=o[t];return B(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var i=t.static,o=t.dynamic,s=a(\"frag\"),l=a(\"vert\"),c=null;return R(s)&&R(l)?(c=h.program(l.id,s.id,null,n),t=F((function(t,e){return t.link(c)}))):t=new D(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,a=t.shared.shader;return r=s?s.append(t,e):e.def(a,\".\",\"frag\"),n=l?l.append(t,e):e.def(a,\".\",\"vert\"),e.def(a+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function T(t,e){function r(t,e){if(t in n){var r=0|n[t];return F((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in a){var o=a[t];return B(o,(function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n}))}return e&&i?F((function(t,e){return t.OFFSET=\"0\",0})):null}var n=t.static,a=t.dynamic,i=function(){if(\"elements\"in n){var t=n.elements;z(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=F((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null}));return e.value=t,e}if(\"elements\"in a){var r=a.elements;return B(r,(function(t,e){var n=(a=t.shared).isBufferArgs,a=a.elements,i=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",i,\")\"),i=t.cond(n).then(o,\"=\",a,\".createStream(\",i,\");\").else(o,\"=\",a,\".getElements(\",i,\");\");return e.entry(i),e.exit(t.cond(n).then(a,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return null}(),s=r(\"offset\",!0);return{elements:i,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return F((function(e,r){return nt[t]}))}if(\"primitive\"in a){var e=a.primitive;return B(e,(function(t,r){var n=t.constants.primTypes,a=t.invoke(r,e);return r.def(n,\"[\",a,\"]\")}))}return i?R(i)?i.value?F((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):F((function(){return 4})):new D(i.thisDep,i.contextDep,i.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return F((function(){return t}))}if(\"count\"in a){var e=a.count;return B(e,(function(t,r){return t.invoke(r,e)}))}return i?R(i)?i?s?new D(s.thisDep,s.contextDep,s.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):F((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):F((function(){return-1})):new D(i.thisDep||s.thisDep,i.contextDep||s.contextDep,i.propDep||s.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):null}(),instances:r(\"instances\",!1),offset:s}}function k(t,r){var n=t.static,i=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],i=e.id(t),s=new X;if(z(r))s.state=1,s.buffer=a.getBuffer(a.create(r,34962,!1,!0)),s.type=0;else if(c=a.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:wt.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=z(r.buffer)?a.getBuffer(a.create(r.buffer,34962,!1,!0)):a.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=Q[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=F((function(t,e){var r=t.attribCache;if(i in r)return r[i];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[i]=n}))})),Object.keys(i).forEach((function(t){var e=i[t];o[t]=B(e,(function(t,r){function n(t){r(l[t],\"=\",a,\".\",t,\"|0;\")}var a=t.invoke(r,e),i=t.shared,o=t.constants,s=i.isBufferArgs,l=(i=i.buffer,{isStream:r.def(!1)}),c=new X;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,h=l.type;return r(\"if(\",s,\"(\",a,\")){\",l.isStream,\"=true;\",u,\"=\",i,\".createStream(\",34962,\",\",a,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",i,\".getBuffer(\",a,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',a,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+a+'.constant === \"number\"){',l[wt[0]],\"=\",a,\".constant;\",wt.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",wt.map((function(t,e){return l[t]+\"=\"+a+\".constant.length>\"+e+\"?\"+a+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",a,\".buffer)){\",u,\"=\",i,\".createStream(\",34962,\",\",a,\".buffer);\",\"}else{\",u,\"=\",i,\".getBuffer(\",a,\".buffer);\",\"}\",h,'=\"type\" in ',a,\"?\",o.glTypes,\"[\",a,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",a,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",i,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,a,o){function s(t){var e=c[t];e&&(f[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var a=[],i=0;i<n.length;++i)a.push([0|r[n[i]],n[i]]);return a}}return null}(t,e),c=function(t,e,r){function n(t){if(t in a){var r=a[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var a=t.shared.context,i=n;\"width\"in r||(i=e.def(a,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(a,\".\",\"framebufferHeight\",\"-\",l)),[s,l,i,c]}))}if(t in i){var c=i[t];return t=B(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,a=e.def(r,\".x|0\"),i=e.def(r,\".y|0\");return[a,i,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",a,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",i,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var a=t.static,i=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=_(t)),h=T(t),f=function(t,e){var r=t.static,n=t.dynamic,a={};return rt.forEach((function(t){function e(e,i){if(t in r){var s=e(r[t]);a[o]=F((function(){return s}))}else if(t in n){var l=n[t];a[o]=B(l,(function(t,e){return i(t,e,t.invoke(e,l))}))}}var o=v(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Mt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[kt[\"srcRGB\"in t?t.srcRGB:t.src],kt[\"dstRGB\"in t?t.dstRGB:t.dst],kt[\"srcAlpha\"in t?t.srcAlpha:t.src],kt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var a=n(\"src\",\"RGB\"),i=n(\"dst\",\"RGB\"),o=(a=e.def(t,\"[\",a,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[a,i=e.def(t,\"[\",i,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,a=e.def(),i=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(a,\"=\",i,\"=\",n,\"[\",r,\"];\"),t.else(a,\"=\",n,\"[\",r,\".rgb];\",i,\"=\",n,\"[\",r,\".alpha];\"),e(t),[a,i]}));case\"blend.color\":return e((function(t){return i(4,(function(e){return+t[e]}))}),(function(t,e,r){return i(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Mt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,At[e.fail||\"keep\"],At[e.zfail||\"keep\"],At[e.zpass||\"keep\"]]}),(function(e,r,n){function a(t){return r.def('\"',t,'\" in ',n,\"?\",i,\"[\",n,\".\",t,\"]:\",7680)}var i=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,a(\"fail\"),a(\"zfail\"),a(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"frontFace\":return e((function(t){return St[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return i(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),a}(t),p=w(t,0,l);s(\"viewport\"),s(v(\"scissor.box\"));var d,g=0<Object.keys(f).length;if((d={framebuffer:d,draw:h,shader:p,state:f,dirty:g,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=F((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var a=t.profile;e=B(a,(function(t,e){return t.invoke(e,a)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,a={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=F((function(){return n}));else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=F((function(t){return t.link(n)})):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=F((function(t){return t.link(n.color[0])})))}else m(n)&&(e=F((function(t){return t.global.def(\"[\",i(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,a[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];a[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),a}(n),d.drawVAO=d.scopeVAO=function(t,e){var r=t.static,n=t.dynamic;if(\"vao\"in r){var a=r.vao;return null!==a&&null===u.getVAO(a)&&(a=u.createVAO(a)),F((function(t){return t.link(u.getVAO(a))}))}if(\"vao\"in n){var i=n.vao;return B(i,(function(t,e){var r=t.invoke(e,i);return e.def(t.shared.vao+\".getVAO(\"+r+\")\")}))}return null}(t),!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays){var y=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],y=y&&!!t,t})),y&&0<t.length){var x=u.getVAO(u.createVAO(t));d.drawVAO=new D(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=k(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=F((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),n}(a),d}function A(t,e,r){var n=t.shared.context,a=t.scope();Object.keys(r).forEach((function(i){e.save(n,\".\"+i),a(n,\".\",i,\"=\",r[i].append(t,e),\";\")})),e(a)}function S(t,e,r,n){var a,i=(s=t.shared).gl,o=s.framebuffer;$&&(a=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",i,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),$&&e(a,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",i,\".bindFramebuffer(\",36160,\",null);\"),$&&e(a,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,a=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");rt.forEach((function(e){var n,h;if(!((e=v(e))in r.state))if(e in s){n=s[e],h=o[e];var f=i(tt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(f.map((function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"})).join(\"||\")).then(a,\".\",it[e],\"(\",f,\");\",f.map((function(t,e){return h+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in at?f(t.cond(n).then(a,\".enable(\",at[e],\");\").else(a,\".disable(\",at[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(a,\".\",it[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var a=t.shared,i=t.current,o=a.current,s=a.gl;O(Object.keys(r)).forEach((function(a){var l=r[a];if(!n||n(l)){var c=l.append(t,e);if(at[a]){var u=at[a];R(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",a,\"=\",c,\";\")}else if(m(c)){var h=i[a];e(s,\".\",it[a],\"(\",c,\");\",c.map((function(t,e){return h+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else e(s,\".\",it[a],\"(\",c,\");\",o,\".\",a,\"=\",c,\";\")}}))}function L(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function P(t,e,r,n,a){function i(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",i(),\";\"),\"string\"==typeof a?t(f,\".count+=\",a,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",i(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(R(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,a){function i(r,n,a){function i(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,i=a.type;r=a.size?e.def(a.size,\"||\",n):n,e(\"if(\",u,\".type!==\",i,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+a[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,i,a.normalized,a.stride,a.offset],\");\",u,\".type=\",i,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+a[t]+\";\"})).join(\"\"),\"}\"),K&&(i=a.divisor,e(\"if(\",u,\".divisor!==\",i,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,i],\");\",u,\".divisor=\",i,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",wt.map((function(t,e){return u+\".\"+t+\"!==\"+f[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",wt.map((function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=a.state;var h=a.buffer,f=[a.x,a.y,a.z,a.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?i():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),i(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!a(l))return;o=l.append(t,e)}else{if(!a(Et))return;var c=t.scopeAttrib(s);o={},Object.keys(new X).forEach((function(t){o[t]=e.def(c,\".\",t)}))}i(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function j(t,r,n,a,o){for(var s,l=t.shared,c=l.gl,u=0;u<a.length;++u){var h,f=(g=a[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(R(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",m(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Et))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var v=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",i(g,(function(t){return v+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"})),\",\",v,\")\")}else r(1<f?i(f,(function(t){return h+\"[\"+t+\"]\"})):h);r(\");\")}}function U(t,e,r,n){function a(a){var i=f[a];return i?i.contextDep&&n.contextDynamic||i.propDep?i.append(t,r):i.append(t,e):e.def(h,\".\",a)}function i(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,m,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,m]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var a=f.elements,i=e;return a?((a.contextDep&&n.contextDynamic||a.propDep)&&(i=r),a=a.append(t,i)):a=i.def(h,\".\",\"elements\"),a&&i(\"if(\"+a+\")\"+u+\".bindBuffer(34963,\"+a+\".buffer.buffer);\"),a}(),d=a(\"primitive\"),g=a(\"offset\"),m=function(){var a=f.count,i=e;return a?((a.contextDep&&n.contextDynamic||a.propDep)&&(i=r),a=a.append(t,i)):a=i.def(h,\".\",\"count\"),a}();if(\"number\"==typeof m){if(0===m)return}else r(\"if(\",m,\"){\"),r.exit(\"}\");K&&(s=a(\"instances\"),l=t.instancing);var v=p+\".type\",y=f.elements&&R(f.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),i(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):i():o()}function V(t,e,r,n,a){return a=(e=b()).proc(\"body\",a),K&&(e.instancing=a.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,a,r,n),e.compile().body}function H(t,e,r,n){L(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),N(t,e,r,n.attributes,(function(){return!0}))),j(t,e,r,n.uniforms,(function(){return!0})),U(t,e,e,r)}function G(t,e,r,n){function a(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,a),j(t,e,r,n.uniforms,a),U(t,e,e,r)}function Y(t,e,r,n){function a(t){return t.contextDep&&o||t.propDep}function i(t){return!a(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,a),r.profile&&a(r.profile)&&P(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?a(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),N(t,c,r,n.attributes,i),N(t,u,r,n.attributes,a)),j(t,c,r,n.uniforms,i),j(t,u,r,n.uniforms,a),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return V(G,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&a.set(i.shader,\".\"+e,n.append(t,a))}var a=t.proc(\"scope\",3);t.batchId=\"a2\";var i=t.shared,o=i.current;A(t,a,r.context),r.framebuffer&&r.framebuffer.append(t,a),O(Object.keys(r.state)).forEach((function(e){var n=r.state[e].append(t,a);m(n)?n.forEach((function(r,n){a.set(t.next[e],\"[\"+n+\"]\",r)})):a.set(i.next,\".\"+e,n)})),P(t,a,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&a.set(i.draw,\".\"+e,\"\"+n.append(t,a))})),Object.keys(r.uniforms).forEach((function(n){a.set(i.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,a))})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,a),i=t.scopeAttrib(e);Object.keys(new X).forEach((function(t){a.set(i,\".\"+t,n[t])}))})),r.scopeVAO&&a.set(i.vao,\".targetVAO\",r.scopeVAO.append(t,a)),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(a(o,\".dirty=true;\"),a.exit(o,\".dirty=true;\")),a(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function Z(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!m(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(q.isDynamic(t[e[r]]))return!0;return!1}}(n)){var a=t.global,i=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");i.forEach((function(e){var r=n[e];if(q.isDynamic(r))\"function\"==typeof r&&(r=n[e]=q.unbox(r)),e=B(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(a(c,\".\",e,\"=\"),typeof r){case\"number\":a(r);break;case\"string\":a('\"',r,'\"');break;case\"object\":Array.isArray(r)&&a(\"[\",r.join(),\"]\");break;default:a(t.link(r))}a(\";\")}})),e.dynamic[r]=new q.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){i.forEach((function(r){var a=n[r];q.isDynamic(a)&&(a=t.invoke(e,a),e(c,\".\",r,\"=\",a,\";\"))}))}}),delete e.static[r]}}var X=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var K=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},rt=[],at={},it={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:a,shader:h,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:z},st={primTypes:nt,compareFuncs:Mt,blendFuncs:kt,blendEquations:J,stencilOps:At,glTypes:Q,orientationType:St};$&&(st.backBuffer=[1029],st.drawBuffer=i(n.maxDrawbuffers,(function(t){return 0===t?[0]:i(t,(function(t){return 36064+t}))})));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),a=t.proc(\"refresh\"),o=t.block();e(o),a(o);var s,l=t.shared,c=l.gl,u=l.next,h=l.current;o(h,\".dirty=false;\"),S(t,e),S(t,a,null,!0),K&&(s=t.link(K)),r.oes_vertex_array_object&&a(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");for(var f=0;f<n.maxAttributes;++f){var p=a.def(l.attributes,\"[\",f,\"]\"),d=t.cond(p,\".buffer\");d.then(c,\".enableVertexAttribArray(\",f,\");\",c,\".bindBuffer(\",34962,\",\",p,\".buffer.buffer);\",c,\".vertexAttribPointer(\",f,\",\",p,\".size,\",p,\".type,\",p,\".normalized,\",p,\".stride,\",p,\".offset);\").else(c,\".disableVertexAttribArray(\",f,\");\",c,\".vertexAttrib4f(\",f,\",\",p,\".x,\",p,\".y,\",p,\".z,\",p,\".w);\",p,\".buffer=null;\"),a(d),K&&a(s,\".vertexAttribDivisorANGLE(\",f,\",\",p,\".divisor);\")}return a(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(at).forEach((function(r){var n=at[r],i=o.def(u,\".\",r),s=t.block();s(\"if(\",i,\"){\",c,\".enable(\",n,\")}else{\",c,\".disable(\",n,\")}\",h,\".\",r,\"=\",i,\";\"),a(s),e(\"if(\",i,\"!==\",h,\".\",r,\"){\",s,\"}\")})),Object.keys(it).forEach((function(r){var n,s,l=it[r],f=tt[r],p=t.block();p(c,\".\",l,\"(\"),m(f)?(l=f.length,n=t.global.def(u,\".\",r),s=t.global.def(h,\".\",r),p(i(l,(function(t){return n+\"[\"+t+\"]\"})),\");\",i(l,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",i(l,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=o.def(u,\".\",r),s=o.def(h,\".\",r),p(n,\");\",h,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),a(p)})),t.compile()}(),compile:function(t,e,r,n,a){var i=b();return i.stats=i.link(a),Object.keys(e.static).forEach((function(t){Z(i,e,t)})),Tt.forEach((function(e){Z(i,t,e)})),r=M(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),P(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var a=t.global.def(\"{}\"),i=r.def(n,\".id\"),o=r.def(a,\"[\",i,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",a,\"[\",i,\"]=\",t.link((function(r){return V(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(i,r),W(i,r),function(t,e){function r(t){return t.contextDep&&a||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var a=!1,i=!0;Object.keys(e.context).forEach((function(t){a=a||e.context[t].propDep})),a||(A(t,n,e.context),i=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?a=o=!0:s.contextDep&&a&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(a=!0),E(t,n,e),C(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||P(t,n,e,!1,\"a1\"),e.contextDep=a,e.needsContext=i,e.needsFramebuffer=o,(i=e.shader.progVar).contextDep&&a||i.propDep)Y(t,n,e,null);else if(i=i.append(t,n),n(t.shared.gl,\".useProgram(\",i,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(i,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return V(Y,t,e,r,2)})),\"(\",i,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(i,r),i.compile()}}}function j(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var U=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,q={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},H={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},G=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},Y=s();Y.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,a=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),a=t.getParameter(36063));var i=!!e.oes_texture_float;if(i){i=t.createTexture(),t.bindTexture(3553,i),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,i,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))i=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=Y.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?i=!1:(t.deleteFramebuffer(o),t.deleteTexture(i),i=1===s[0]),Y.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=Y.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),Y.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:a,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:i,npotTextureCube:s}},Z=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map((function(e){return t[e]}))},J={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var a=1;if(e.length)for(var i=0;i<e.length;++i)a*=e[i];else a=0;switch(r=n||Y.allocType(r,a),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],i=a=0;i<n;++i)for(var o=t[i],s=0;s<e;++s)r[a++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,a,i){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,a,i),i+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,a,i),i+=o}(t,e,0,r,0)}return r}},K={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},Q={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},tt=J.flatten,et=J.shape,rt=[];rt[5120]=1,rt[5122]=2,rt[5124]=4,rt[5121]=1,rt[5123]=2,rt[5125]=4,rt[5126]=4;var nt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},at=new Float32Array(1),it=new Uint32Array(at.buffer),ot=[9984,9986,9985,9987],st=[0,6409,6410,6407,6408],lt={};lt[6409]=lt[6406]=lt[6402]=1,lt[34041]=lt[6410]=2,lt[6407]=lt[35904]=3,lt[6408]=lt[35906]=4;var ct=v(\"HTMLCanvasElement\"),ut=v(\"OffscreenCanvas\"),ht=v(\"CanvasRenderingContext2D\"),ft=v(\"ImageBitmap\"),pt=v(\"HTMLImageElement\"),dt=v(\"HTMLVideoElement\"),gt=Object.keys(K).concat([ct,ut,ht,ft,pt,dt]),mt=[];mt[5121]=1,mt[5126]=4,mt[36193]=2,mt[5123]=2,mt[5125]=4;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[34041]=4,vt[33776]=.5,vt[33777]=.5,vt[33778]=1,vt[33779]=1,vt[35986]=.5,vt[35987]=1,vt[34798]=1,vt[35840]=.5,vt[35841]=.25,vt[35842]=.5,vt[35843]=.25,vt[36196]=.5;var yt=[];yt[32854]=2,yt[32855]=2,yt[36194]=2,yt[33189]=2,yt[36168]=1,yt[34041]=4,yt[35907]=4,yt[34836]=16,yt[34842]=8,yt[34843]=6;var xt=function(t,e,r,n,a){function i(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,a.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return i.prototype.decRef=function(){0>=--this.refCount&&o(this)},a.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,i=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(i=e.shape)[0],i=0|i[1]):(\"radius\"in e&&(n=i=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(i=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,i=\"number\"==typeof r?0|r:n):e||(n=i=1),n!==c.width||i!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=i,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,i),a.profile&&(c.stats.size=yt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new i(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,i=0|r||n;return n===c.width&&i===c.height||(o.width=c.width=n,o.height=c.height=i,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,i),a.profile&&(c.stats.size=yt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,a.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},bt=[];bt[6408]=4,bt[6407]=3;var _t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2;var wt=[\"x\",\"y\",\"z\",\"w\"],Tt=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),kt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Mt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},At={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},St={cw:2304,ccw:2305},Et=new D(!1,!1,!1,(function(){}));return function(t){function e(){if(0===J.length)w&&w.update(),tt=null;else{tt=H.next(e),h();for(var t=J.length-1;0<=t;--t){var r=J[t];r&&r(P,null,0)}m.flush(),w&&w.update()}}function r(){!tt&&0<J.length&&(tt=H.next(e))}function n(){tt&&(H.cancel(e),tt=null)}function i(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){m.getError(),y.restore(),R.restore(),z.restore(),F.restore(),B.restore(),V.restore(),O.restore(),w&&w.restore(),Y.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach((function(n){var a=t[n];q.isDynamic(a)?r[n]=q.unbox(a,n):e[n]=a})),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),a=e(t.attributes||{}),i=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=U({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=Y.compile(i,a,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return U((function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}}),{stats:t})}function l(t,e){var r=0;Y.procs.poll();var n=e.color;n&&(m.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(m.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(m.clearStencil(0|e.stencil),r|=1024),m.clear(r)}function c(t){return J.push(t),r(),{cancel:function(){var e=j(J,t);J[e]=function t(){var e=j(J,t);J[e]=J[J.length-1],--J.length,0>=J.length&&n()}}}}function u(){var t=Z.viewport,e=Z.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=m.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=m.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),Y.procs.poll()}function f(){u(),Y.procs.refresh(),w&&w.update()}function g(){return(G()-T)/1e3}if(!(t=a(t)))return null;var m=t.gl,v=m.getContextAttributes();m.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},a=0;a<e.extensions.length;++a){var i=e.extensions[a];if(!r(i))return e.onDestroy(),e.onDone('\"'+i+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(m,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var a=o.pop()||new r;a.startQueryIndex=t,a.endQueryIndex=e,a.sum=0,a.stats=n,s.push(a)}if(!e.ext_disjoint_timer_query)return null;var a=[],i=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=a.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),i.push(r),n(i.length-1,i.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=i.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<i.length;++r){var u=i[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),a.push(u)):i[t++]=u,l[r+1]=n,c[r+1]=t}for(i.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex;n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return i.length},clear:function(){a.push.apply(a,i);for(var t=0;t<a.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(a[t]);i.length=0,a.length=0},restore:function(){i.length=0,a.length=0}}}(0,_),T=G(),A=m.drawingBufferWidth,L=m.drawingBufferHeight,P={tick:0,time:0,viewportWidth:A,viewportHeight:L,framebufferWidth:A,framebufferHeight:L,drawingBufferWidth:A,drawingBufferHeight:L,pixelRatio:t.pixelRatio},I=W(m,_),z=p(m,b,t,(function(t){return O.destroyBuffer(t)})),O=S(m,_,I,b,z),D=d(m,_,z,b),R=E(m,x,b,t),F=k(m,_,I,(function(){Y.procs.poll()}),P,b,t),B=xt(m,_,0,b,t),V=M(m,_,I,F,B,b),Y=N(m,x,_,I,z,D,0,V,{},O,R,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),Z=(x=C(m,V,Y.procs.poll,P),Y.next),X=m.canvas,J=[],K=[],Q=[],$=[t.onDestroy],tt=null;X&&(X.addEventListener(\"webglcontextlost\",i,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var et=V.setFBO=s({framebuffer:q.define.call(null,1,\"framebuffer\")});return f(),v=U(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)et(U({framebuffer:t.framebuffer.faces[e]},t),l);else et(t,l);else l(0,t)},prop:q.define.bind(null,1),context:q.define.bind(null,2),this:q.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:F.create2D,cube:F.createCube,renderbuffer:B.create,framebuffer:V.create,framebufferCube:V.createCube,vao:O.createVAO,attributes:v,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:I,hasExtension:function(t){return 0<=I.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){J.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",i),X.removeEventListener(\"webglcontextrestored\",o)),R.clear(),V.clear(),B.clear(),F.clear(),D.clear(),z.clear(),O.clear(),w&&w.clear(),$.forEach((function(t){t()}))},_gl:m,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,v),v}}))},{}],513:[function(t,e,r){\n",
       "/*!\n",
       " * repeat-string <https://github.com/jonschlinkert/repeat-string>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT License.\n",
       " */\n",
       "\"use strict\";var n,a=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,a=\"\";else if(a.length>=r)return a.substr(0,r);for(;r>a.length&&e>1;)1&e&&(a+=t),e>>=1,t+=t;return a=(a+=t).substr(0,r)}},{}],514:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,a=e-2;a>=0;--a){var i=r,o=t[a];(l=o-((r=i+o)-i))&&(t[--n]=r,r=l)}var s=0;for(a=n;a<e;++a){var l;i=t[a];(l=(o=r)-((r=i+o)-i))&&(t[s++]=l)}return t[s++]=r,t.length=s,t}},{}],516:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),a=t(\"robust-sum\"),i=t(\"robust-scale\"),o=t(\"robust-compress\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function l(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(s(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(l(t)),\")};return robustDeterminant\",t].join(\"\"))(a,i,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<6;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<6;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var a=Function.apply(void 0,t);for(e.exports=a.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":515,\"robust-scale\":522,\"robust-sum\":525,\"two-product\":554}],517:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),a=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),i=1;i<t.length;++i)r=a(r,n(t[i],e[i]));return r}},{\"robust-sum\":525,\"two-product\":554}],518:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),a=t(\"robust-sum\"),i=t(\"robust-subtract\"),o=t(\"robust-scale\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return c(e,t)}function u(t){if(2===t.length)return[[\"diff(\",c(t[0][0],t[1][1]),\",\",c(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(u(s(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return l(r)}function f(t){for(var e=[],r=[],c=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),f=0;f<t;++f)c[0][f]=\"1\",c[t-1][f]=\"w\"+f;for(f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(s(c,f))):r.push.apply(r,u(s(c,f)));var p=l(e),d=l(r),g=\"exactInSphere\"+t,m=[];for(f=0;f<t;++f)m.push(\"m\"+f);var v=[\"function \",g,\"(\",m.join(),\"){\"];for(f=0;f<t;++f){v.push(\"var w\",f,\"=\",h(f,t),\";\");for(var y=0;y<t;++y)y!==f&&v.push(\"var w\",f,\"m\",y,\"=scale(w\",f,\",m\",y,\"[0]);\")}return v.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",v.join(\"\"))(a,i,n,o)}var p=[function(){return 0},function(){return 0},function(){return 0}];function d(t){var e=p[t.length];return e||(e=p[t.length]=f(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=6;)p.push(f(p.length));for(var t=[],r=[\"slow\"],n=0;n<=6;++n)t.push(\"a\"+n),r.push(\"o\"+n);var a=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=6;++n)a.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");a.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(a.join(\"\"));var i=Function.apply(void 0,r);for(e.exports=i.apply(void 0,[d].concat(p)),n=0;n<=6;++n)e.exports[n]=p[n]}()},{\"robust-scale\":522,\"robust-subtract\":524,\"robust-sum\":525,\"two-product\":554}],519:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\");function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],a=0;a<t;++a){r.push(\"det([\");for(var i=0;i<t;++i){i>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===a?r.push(\"+b[\",i,\"]\"):r.push(\"+A[\",i,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var i=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;i.length<6;)i.push(a(i.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<6;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var o=Function.apply(void 0,t);for(e.exports=o.apply(void 0,i.concat([i,a])),n=0;n<6;++n)e.exports[n]=i[n]}()},{\"robust-determinant\":516}],520:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),a=t(\"robust-sum\"),i=t(\"robust-scale\"),o=t(\"robust-subtract\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(c(s(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function u(t){for(var e=[],r=[],u=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,c(s(u,f))):r.push.apply(r,c(s(u,f))),h.push(\"m\"+f);var p=l(e),d=l(r),g=\"orientation\"+t+\"Exact\",m=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",m)(a,n,i,o)}var h=u(3),f=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,a=(t[1]-r[1])*(e[0]-r[0]),i=(t[0]-r[0])*(e[1]-r[1]),o=a-i;if(a>0){if(i<=0)return o;n=a+i}else{if(!(a<0))return o;if(i>=0)return o;n=-(a+i)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:h(t,e,r)},function(t,e,r,n){var a=t[0]-n[0],i=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],p=r[2]-n[2],d=i*c,g=o*l,m=o*s,v=a*c,y=a*l,x=i*s,b=u*(d-g)+h*(m-v)+p*(y-x),_=7771561172376103e-31*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(m)+Math.abs(v))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(p));return b>_||-b>_?b:f(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=5;)p.push(u(p.length));for(var t=[],r=[\"slow\"],n=0;n<=5;++n)t.push(\"a\"+n),r.push(\"o\"+n);var a=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=5;++n)a.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");a.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(a.join(\"\"));var i=Function.apply(void 0,r);for(e.exports=i.apply(void 0,[d].concat(p)),n=0;n<=5;++n)e.exports[n]=p[n]}()},{\"robust-scale\":522,\"robust-subtract\":524,\"robust-sum\":525,\"two-product\":554}],521:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),a=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return a(e,t[0]);if(1===e.length)return a(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var i=0;i<t.length;++i)r=n(r,a(e,t[i]));else for(i=0;i<e.length;++i)r=n(r,a(t,e[i]));return r}},{\"robust-scale\":522,\"robust-sum\":525}],522:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),a=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var i=n(t[0],e);return i[0]?i:[i[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];a(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=p-(d-f);s[1]=d,g&&(o[c++]=g)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":554,\"two-sum\":555}],523:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var i=n(t,r,a),o=n(e,r,a);if(i>0&&o>0||i<0&&o<0)return!1;var s=n(r,t,e),l=n(a,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===i&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var a=0;a<2;++a){var i=t[a],o=e[a],s=Math.min(i,o),l=Math.max(i,o),c=r[a],u=n[a],h=Math.min(c,u);if(Math.max(c,u)<s||l<h)return!1}return!0}(t,e,r,a);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":520}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,a=t-(r-n)+(e-n);if(a)return[a,r];return[r]}(t[0],-e[0]);var a,i,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,m,v=a+i,y=v-a,x=i-y,b=x,_=v;for(;l<r&&c<n;)f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(i=b)-(y=(v=a+i)-a))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(i=b)-(y=(v=(a=h)+i)-a))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(i=b)-(y=(v=(a=p)+i)-a))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,a=t-(r-n)+(e-n);if(a)return[a,r];return[r]}(t[0],e[0]);var a,i,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,m,v=a+i,y=v-a,x=i-y,b=x,_=v;for(;l<r&&c<n;)f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(i=b)-(y=(v=a+i)-a))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(i=b)-(y=(v=(a=h)+i)-a))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(i=b)-(y=(v=(a=p)+i)-a))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],526:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],527:[function(t,e,r){\"use strict\";e.exports=function(t){return a(n(t))};var n=t(\"boundary-cells\"),a=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":100,\"reduce-simplicial-complex\":507}],528:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=a.mallocUint8(r),i=0;i<r;++i)n[i]=t[i]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=a.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],h=(e=u.length,0);h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}i(n(s,[l/2|0,2]));var g=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,i){for(var o=t.data,s=t.shape[0],l=a.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-i)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=a.mallocInt32(2*e),n=t.shape[0],i=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=i[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),a=0;a<e;++a)n[a]=[r[2*a],r[2*a+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return a.free(l),a.free(c.data),a.free(u.data),a.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),a=t(\"typedarray-pool\"),i=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":529,ndarray:469,\"ndarray-sort\":468,\"typedarray-pool\":567}],529:[function(t,e,r){\"use strict\";e.exports=function(t){var e=i[t];e||(e=i[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var i=1;i<=t;++i)for(var o=r[i]=a(i),s=0;s<o.length;++s)e=Math.max(e,o[i].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var a=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",a[0],\"],c[\",a[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(i=t+1;i>1;--i){i<t+1&&l.push(\"else \"),l.push(\"if(l===\",i,\"){\");var u=[];for(s=0;s<i;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<i)-1,\"){continue}switch(M){\");for(o=r[i-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),a=t(\"marching-simplex-table\"),i={}},{\"marching-simplex-table\":448,\"typedarray-pool\":567}],530:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),a=t(\"union-find\");function i(t,e){var r=t.length,n=t.length-e.length,a=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||a(t[0],t[1])-a(e[0],e[1]);case 3:var i=t[0]+t[1],o=e[0]+e[1];if(s=i+t[2]-(o+e[2]))return s;var s,l=a(t[0],t[1]),c=a(e[0],e[1]);return(s=a(l,t[2])-a(c,e[2]))||a(l+t[2],i)-a(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return i(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),a=0;a<r;++a)n[a]=[t[a],e[a]];n.sort(o);for(a=0;a<r;++a)t[a]=n[a][0],e[a]=n[a][1];return t}return t.sort(i),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var a=t[n];if(i(a,t[n-1])){if(n===e){e++;continue}t[e++]=a}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,a=-1;r<=n;){var o=r+n>>1,s=i(t[o],e);s<=0?(0===s&&(a=o),r=o+1):s>0&&(n=o-1)}return a}function u(t,e){for(var r=new Array(t.length),a=0,o=r.length;a<o;++a)r[a]=[];for(var s=[],l=(a=0,e.length);a<l;++a)for(var u=e[a],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var m=c(t,s);if(!(m<0))for(;r[m++].push(a),!(m>=t.length||0!==i(t[m],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],a=(1<<e+1)-1,i=0;i<t.length;++i)for(var o=t[i],l=a;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,a=t.length;n<a;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,a=t.length;n<a;++n)for(var i=t[n],o=0,s=i.length;o<s;++o)e=r(e,i[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=i,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var a=t.length;n<a;++n)for(var i=t[n],o=0,s=i.length;o<s;++o)r[i[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0|a.length,o=1,l=1<<i;o<l;++o){for(var c=[],u=0;u<i;++u)o>>>u&1&&c.push(a[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;++i){for(var l=new Array(a.length-1),c=0,u=0;c<o;++c)c!==i&&(l[u++]=a[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new a(e),n=0;n<t.length;++n)for(var i=t[n],o=0;o<i.length;++o)for(var s=o+1;s<i.length;++s)r.link(i[o],i[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new a(e.length),n=0;n<t.length;++n)for(var i=t[n],o=0;o<i.length;++o)for(var u=c(e,[i[o]]),f=o+1;f<i.length;++f)r.link(u,c(e,[i[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":97,\"union-find\":568}],531:[function(t,e,r){arguments[4][97][0].apply(r,arguments)},{dup:97}],532:[function(t,e,r){arguments[4][530][0].apply(r,arguments)},{\"bit-twiddle\":531,dup:530,\"union-find\":533}],533:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var a=this.ranks,i=this.roots,o=a[r],s=a[n];o<s?i[r]=n:s<o?i[n]=r:(i[n]=r,++a[r])}}},{}],534:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var i=e.length,o=t.length,s=new Array(i),l=new Array(i),c=new Array(i),u=new Array(i),h=0;h<i;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,a,i,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],a=e[h],i=e[f],o=Math.abs(n(r,a,i)),c=Math.sqrt(Math.pow(a[0]-i[0],2)+Math.pow(a[1]-i[1],2)),o/c)}function m(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,M[r]=e,M[n]=t}function v(t){return c[k[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=v(t);;){var r=e,n=2*t+1,a=2*(t+1),i=t;if(n<A){var o=v(n);o<r&&(i=n,r=o)}if(a<A)v(a)<r&&(i=a);if(i===t)return t;m(t,i),t=i}}function b(t){for(var e=v(t);t>0;){var r=y(t);if(r>=0)if(e<v(r)){m(t,r),t=r;continue}return t}}function _(){if(A>0){var t=k[0];return m(0,A-1),A-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((A+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],g(e)),M[r]>=0&&w(M[r],g(r))}}var k=[],M=new Array(i);for(h=0;h<i;++h){(c[h]=g(h))<1/0?(M[h]=k.length,k.push(h)):M[h]=-1}var A=k.length;for(h=A>>1;h>=0;--h)x(h);for(;;){var S=_();if(S<0||c[S]>r)break;T(S)}var E=[];for(h=0;h<i;++h)u[h]||(M[h]=E.length,E.push(e[h].slice()));E.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var a=t[n];if(!u[n]||a<0||a===n)break;if(a=t[n=a],!u[n]||a<0||a===n)break;n=a,r=t[r]}while(r!==n);for(var i=e;i!==n;i=t[i])t[i]=n;return n}var L=[];return t.forEach((function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],a=M[r];n!==a&&L.push([n,a])}})),a.unique(a.normalize(L)),{positions:E,edges:L}};var n=t(\"robust-orientation\"),a=t(\"simplicial-complex\")},{\"robust-orientation\":520,\"simplicial-complex\":532}],535:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,i,o,s;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0]))return a(e,t);r=e[1],i=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-a(t,e);o=t[1],s=t[0]}var l=n(r,i,s),c=n(r,i,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,i),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return i[0]-s[0]};var n=t(\"robust-orientation\");function a(t,e){var r,a,i,o;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],a=e[0]}t[0][1]<t[1][1]?(i=t[0],o=t[1]):(i=t[1],o=t[0]);var h=n(a,r,i);return h||((h=n(a,r,o))||o-a)}},{\"robust-orientation\":520}],536:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],537:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),i=0;i<e;++i){var l=t[i],c=l[0][0]<l[1][0];n[2*i]=new h(l[0][0],l,c,i),n[2*i+1]=new h(l[1][0],l,!c,i)}n.sort((function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))}));var f=a(o),p=[],d=[],g=[];for(i=0;i<r;){for(var m=n[i].x,v=[];i<r;){var y=n[i];if(y.x!==m)break;i+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(v.push(new u(y.segment[0][1],y.index,!0,!0)),v.push(new u(y.segment[1][1],y.index,!1,!1))):(v.push(new u(y.segment[1][1],y.index,!0,!1)),v.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(m),g.push(v)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),a=t(\"functional-red-black-tree\"),i=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,a,o=t.key;o[0][0]<o[1][0]?(n=o[0],a=o[1]):(n=o[1],a=o[0]);var s=i(n,a,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),a=-1;if(r&&(a=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,a=u.value):(a=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return a;p=h[f]}}if(p.start)if(s){var d=i(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(a=p.index)}else a=p.index;else p.y!==t[1]&&(a=p.index)}}}return a}},{\"./lib/order-segments\":535,\"binary-search-bounds\":536,\"functional-red-black-tree\":247,\"robust-orientation\":520}],538:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),a=t(\"robust-sum\");function i(t,e){var r=a(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var a=-e/(n-e);a<0?a=0:a>1&&(a=1);for(var i=1-a,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=a*t[l]+i*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],a=i(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=i(l=t[c],e);if(a<0&&u>0||a>0&&u<0){var h=o(s,u,l,a);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),a=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=i(t[t.length-1],e),a=t[t.length-1],s=t[0],l=0;l<t.length;++l,a=s){var c=i(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(a,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=i(t[t.length-1],e),a=t[t.length-1],s=t[0],l=0;l<t.length;++l,a=s){var c=i(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(a,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":517,\"robust-sum\":525}],539:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(t){return a(o(t),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}function a(r,n){var a,i,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(i=0;i<d;i++)if(\"string\"==typeof r[i])g+=r[i];else if(\"object\"==typeof r[i]){if((s=r[i]).keys)for(a=n[p],o=0;o<s.keys.length;o++){if(null==a)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));a=a[s.keys[o]]}else a=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&a instanceof Function&&(a=a()),t.numeric_arg.test(s.type)&&\"number\"!=typeof a&&isNaN(a))throw new TypeError(e(\"[sprintf] expecting number but found %T\",a));switch(t.number.test(s.type)&&(h=a>=0),s.type){case\"b\":a=parseInt(a,10).toString(2);break;case\"c\":a=String.fromCharCode(parseInt(a,10));break;case\"d\":case\"i\":a=parseInt(a,10);break;case\"j\":a=JSON.stringify(a,null,s.width?parseInt(s.width):0);break;case\"e\":a=s.precision?parseFloat(a).toExponential(s.precision):parseFloat(a).toExponential();break;case\"f\":a=s.precision?parseFloat(a).toFixed(s.precision):parseFloat(a);break;case\"g\":a=s.precision?String(Number(a.toPrecision(s.precision))):parseFloat(a);break;case\"o\":a=(parseInt(a,10)>>>0).toString(8);break;case\"s\":a=String(a),a=s.precision?a.substring(0,s.precision):a;break;case\"t\":a=String(!!a),a=s.precision?a.substring(0,s.precision):a;break;case\"T\":a=Object.prototype.toString.call(a).slice(8,-1).toLowerCase(),a=s.precision?a.substring(0,s.precision):a;break;case\"u\":a=parseInt(a,10)>>>0;break;case\"v\":a=a.valueOf(),a=s.precision?a.substring(0,s.precision):a;break;case\"x\":a=(parseInt(a,10)>>>0).toString(16);break;case\"X\":a=(parseInt(a,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=a:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",a=a.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+a).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+a+l:\"0\"===c?f+l+a:l+f+a)}return g}var i=Object.create(null);function o(e){if(i[e])return i[e];for(var r,n=e,a=[],o=0;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],540:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var a=n.parse(t,{flat:!0,brackets:r.ignore}),i=a[0].split(e);if(r.escape){for(var o=[],s=0;s<i.length;s++){var l=i[s],c=i[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}i=o}for(s=0;s<i.length;s++)a[0]=i[s],i[s]=n.stringify(a,{flat:!0});return i}},{parenthesis:477}],541:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),a=new Array(e),i=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,a[l]=!1,i[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,a[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(i[e]<p.length){for(var d=i[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,a[g]=!0,u+=1,l.push(g),c.push(g);break}a[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}i[e]=d}else{if(n[e]===r[e]){var m=[],v=[],y=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(a[x]=!1,m.push(x),v.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(m);var b=new Array(y);for(d=0;d<v.length;d++)for(var _=0;_<v[d].length;_++)b[--y]=v[d][_];f.push(b)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],542:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=i(t,e),n=r.length,a=new Array(n),o=new Array(n),s=0;s<n;++s)a[s]=[r[s]],o[s]=[s];return{positions:a,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,i=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;i.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&i.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),i.push(\"vertex:function vertexFunc(\",s.join(),\"){\");var u=[];for(c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");i.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(i.push(\"switch(m){\"),f=i):i.push(\"switch(m>>>7){\");for(c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;i.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),m=new Array(r),v=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],m[x]=0,v[x]=0;for(x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),m[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),m[b]-=2),y+=1;for(var T=0;T<r;++T)T!==b&&(_&1<<T?v[T]+=1:v[T]-=1)}}var k=[];for(b=0;b<r;++b)if(0===d[b].length)k.push(\"d\"+b+\"-0.5\");else{var M=\"\";m[b]<0?M=m[b]+\"*c\":m[b]>0&&(M=\"+\"+m[b]+\"*c\");var A=d[b].length/y*.5,S=.5+v[b]/y*.5;k.push(\"d\"+b+\"-\"+S+\"-\"+A+\"*(\"+d[b].join(\"+\")+M+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",k.join(),\"]);\",\"break;\")}i.push(\"}},\"),h.length>0&&f.push(\"}}\");var E=[];for(c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),i.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=a(r-1);i.push(\"if(p0){b.push(\",C.map((function(t){return\"[\"+t.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}else{b.push(\",C.map((function(t){var e=t.slice();return e.reverse(),\"[\"+e.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(c=0;c<h.length;++c)i.push(h[c].join(\"\"));return new Function(\"genContour\",i.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),a=t(\"triangulate-hypercube\"),i=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":461,\"triangulate-hypercube\":552,\"zero-crossings\":596}],543:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,a=!1,i=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){a=!0,i=t}finally{try{!n&&s.return&&s.return()}finally{if(a)throw i}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")},a=2*Math.PI,i=function(t,e,r,n,a,i,o){var s=t.x,l=t.y;return{x:n*(s*=e)-a*(l*=r)+i,y:a*s+n*l+o}},o=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),a=Math.sin(t),i=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-a*r,y:a+n*r},{x:i+o*r,y:o-i*r},{x:i,y:o}]},s=function(t,e,r,n){var a=t*r+e*n;return a>1&&(a=1),a<-1&&(a=-1),(t*n-e*r<0?-1:1)*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,m=t.sweepFlag,v=void 0===m?0:m,y=[];if(0===u||0===h)return[];var x=Math.sin(p*a/360),b=Math.cos(p*a/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var T=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);T>1&&(u*=Math.sqrt(T),h*=Math.sqrt(T));var k=function(t,e,r,n,i,o,l,c,u,h,f,p){var d=Math.pow(i,2),g=Math.pow(o,2),m=Math.pow(f,2),v=Math.pow(p,2),y=d*g-d*v-g*m;y<0&&(y=0),y/=d*v+g*m;var x=(y=Math.sqrt(y)*(l===c?-1:1))*i/o*p,b=y*-o/i*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,T=(f-x)/i,k=(p-b)/o,M=(-f-x)/i,A=(-p-b)/o,S=s(1,0,T,k),E=s(T,k,M,A);return 0===c&&E>0&&(E-=a),1===c&&E<0&&(E+=a),[_,w,S,E]}(e,r,l,c,u,h,g,v,x,b,_,w),M=n(k,4),A=M[0],S=M[1],E=M[2],C=M[3],L=Math.abs(C)/(a/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var I=0;I<P;I++)y.push(o(E,C)),E+=C;return y.map((function(t){var e=i(t[0],u,h,b,x,A,S),r=e.x,n=e.y,a=i(t[1],u,h,b,x,A,S),o=a.x,s=a.y,l=i(t[2],u,h,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))},e.exports=r.default},{}],544:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),a=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=a(t),!(t=i(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":65,assert:73,\"is-svg-path\":445,\"normalize-svg-path\":545,\"parse-svg-path\":479}],545:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var m=t[d],v=m[0];switch(v){case\"M\":l=m[1],c=m[2];break;case\"A\":var y=n({px:f,py:p,cx:m[6],cy:m[7],rx:m[1],ry:m[2],xAxisRotation:m[3],largeArcFlag:m[4],sweepFlag:m[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],m=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(m);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),m=[\"C\",_,w,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),m=i(f,p,u,h,m[1],m[2]);break;case\"Q\":u=m[1],h=m[2],m=i(f,p,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(f,p,m[1],m[2]);break;case\"H\":m=a(f,p,m[1],p);break;case\"V\":m=a(f,p,f,m[1]);break;case\"Z\":m=a(f,p,l,c)}e=v,f=m[m.length-2],p=m[m.length-1],m.length>4?(o=m[m.length-4],s=m[m.length-3]):(o=f,s=p),r.push(m)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function i(t,e,r,n,a,i){return[\"C\",t/3+2/3*r,e/3+2/3*n,a/3+2/3*r,i/3+2/3*n,a,i]}},{\"svg-arc-to-cubic-bezier\":543}],546:[function(t,e,r){\"use strict\";var n,a=t(\"svg-path-bounds\"),i=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||a(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],m=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(m,m),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var v=new Path2D(t);u.fill(v),p&&u.stroke(v)}else{var y=i(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":98,\"draw-svg-path\":174,\"is-svg-path\":445,\"parse-svg-path\":479,\"svg-path-bounds\":544}],547:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,a){a=a||{};var o=i[e];o||(o=i[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),a=0,i=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[a++]=c[0],n[a++]=c[1]+1.4,i=Math.max(c[0],i)}return{data:n,shape:i}}(n(r,{triangles:!0,font:e,textAlign:a.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);var p=new Float32Array(u),d=0,g=-.5*h;for(f=0;f<c.length;++f){for(var m=c[f].data,v=0;v<m.length;v+=2)p[d++]=m[v]+g,p[d++]=m[v+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),a=window||r.global||{},i=a.__TEXT_CACHE||{};a.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:500,\"vectorize-text\":572}],548:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,a=0,i=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var a={r:0,g:0,b:0},i=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,a=!1;if(S[t])t=S[t],a=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:I(e[1]),g:I(e[2]),b:I(e[3]),a:R(e[4]),format:a?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:I(e[1]),g:I(e[2]),b:I(e[3]),format:a?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:I(e[1]+\"\"+e[1]),g:I(e[2]+\"\"+e[2]),b:I(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:a?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:I(e[1]+\"\"+e[1]),g:I(e[2]+\"\"+e[2]),b:I(e[3]+\"\"+e[3]),format:a?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,a={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=O(e.s),c=O(e.v),a=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var a=t.floor(e),i=e-a,o=n*(1-r),s=n*(1-i*r),l=n*(1-(1-i)*r),c=a%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=O(e.s),u=O(e.l),a=function(t,e,r){var n,a,i;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=a=i=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),a=o(l,s,t),i=o(l,s,t-1/3)}return{r:255*n,g:255*a,b:255*i}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(i=e.a));var p,d,g;return i=C(i),{ok:h,format:e.format||f,r:o(255,s(a.r,0)),g:o(255,s(a.g,0)),b:o(255,s(a.b,0)),a:i}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=i(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=i(this._r)),this._g<1&&(this._g=i(this._g)),this._b<1&&(this._b=i(this._b)),this._ok=u.ok,this._tc_id=a++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,a,i=s(t,e,r),l=o(t,e,r),c=(i+l)/2;if(i==l)n=a=0;else{var u=i-l;switch(a=c>.5?u/(2-i-l):u/(i+l),i){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:a,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,a,i=s(t,e,r),l=o(t,e,r),c=i,u=i-l;if(a=0===i?0:u/i,i==l)n=0;else{switch(i){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:a,v:c}}function f(t,e,r,n){var a=[z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16))];return n&&a[0].charAt(0)==a[0].charAt(1)&&a[1].charAt(0)==a[1].charAt(1)&&a[2].charAt(0)==a[2].charAt(1)?a[0].charAt(0)+a[1].charAt(0)+a[2].charAt(0):a.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function m(t){return c(t).desaturate(100)}function v(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-i(-e/100*255))),r.g=s(0,o(255,r.g-i(-e/100*255))),r.b=s(0,o(255,r.b-i(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),a=360/r,i=[c(t)];for(n.h=(n.h-(a*e>>1)+720)%360;--e;)n.h=(n.h+a)%360,i.push(c(n));return i}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,a=r.s,i=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:a,v:i})),i=(i+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,a=this.toRgb();return e=a.r/255,r=a.g/255,n=a.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=i(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=i(360*t.h),r=i(100*t.s),n=i(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=i(360*t.h),r=i(100*t.s),n=i(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,a){var o=[z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16)),z(D(n))];if(a&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:i(this._r),g:i(this._g),b:i(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+i(this._r)+\", \"+i(this._g)+\", \"+i(this._b)+\")\":\"rgba(\"+i(this._r)+\", \"+i(this._g)+\", \"+i(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:i(100*L(this._r,255))+\"%\",g:i(100*L(this._g,255))+\"%\",b:i(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+i(100*L(this._r,255))+\"%, \"+i(100*L(this._g,255))+\"%, \"+i(100*L(this._b,255))+\"%)\":\"rgba(\"+i(100*L(this._r,255))+\"%, \"+i(100*L(this._g,255))+\"%, \"+i(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var a=c(t);r=\"#\"+p(a._r,a._g,a._b,a._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(v,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(m,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(k,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(T,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:O(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),a=c(e).toRgb(),i=r/100;return c({r:(a.r-n.r)*i+n.r,g:(a.g-n.g)*i+n.g,b:(a.b-n.b)*i+n.b,a:(a.a-n.a)*i+n.a})},c.readability=function(e,r){var n=c(e),a=c(r);return(t.max(n.getLuminance(),a.getLuminance())+.05)/(t.min(n.getLuminance(),a.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,a,i=c.readability(t,e);switch(a=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":a=i>=4.5;break;case\"AAlarge\":a=i>=3;break;case\"AAAsmall\":a=i>=7}return a},c.mostReadable=function(t,e,r){var n,a,i,o,s=null,l=0;a=(r=r||{}).includeFallbackColors,i=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:i,size:o})||!a?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function I(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function O(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return I(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],549:[function(t,e,r){\"use strict\";e.exports=a,e.exports.float32=e.exports.float=a,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=a(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return a(t-a(t))};var n=new Float32Array(1);function a(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],550:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=i;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*i(r[1],t)}function i(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return 96;case\"cm\":return 96/2.54;case\"mm\":return 96/25.4;case\"pt\":return 96/72;case\"pc\":return 16}return 1}},{\"parse-unit\":480}],551:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).topojson=t.topojson||{})}(this,(function(t){\"use strict\";function e(t){return t}function r(t){if(null==t)return e;var r,n,a=t.scale[0],i=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(r+=t[0])*a+o,u[1]=(n+=t[1])*i+s;l<c;)u[l]=t[l],++l;return u}}function n(t){var e,n=r(t.transform),a=1/0,i=a,o=-a,s=-a;function l(t){(t=n(t))[0]<a&&(a=t[0]),t[0]>o&&(o=t[0]),t[1]<i&&(i=t[1]),t[1]>s&&(s=t[1])}function c(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(c);break;case\"Point\":l(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(l)}}for(e in t.arcs.forEach((function(t){for(var e,r=-1,l=t.length;++r<l;)(e=n(t[r],r))[0]<a&&(a=e[0]),e[0]>o&&(o=e[0]),e[1]<i&&(i=e[1]),e[1]>s&&(s=e[1])})),t.objects)c(t.objects[e]);return[a,i,o,s]}function a(t,e){var r=e.id,n=e.bbox,a=null==e.properties?{}:e.properties,o=i(t,e);return null==r&&null==n?{type:\"Feature\",properties:a,geometry:o}:null==n?{type:\"Feature\",id:r,properties:a,geometry:o}:{type:\"Feature\",id:r,bbox:n,properties:a,geometry:o}}function i(t,e){var n=r(t.transform),a=t.arcs;function i(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],i=0,o=r.length;i<o;++i)e.push(n(r[i],i));t<0&&function(t,e){for(var r,n=t.length,a=n-e;a<--n;)r=t[a],t[a++]=t[n],t[n]=r}(e,o)}function o(t){return n(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)i(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}function o(t,e){var r={},n={},a={},i=[],o=-1;function s(t,e){for(var n in t){var a=t[n];delete e[a.start],delete a.start,delete a.end,a.forEach((function(t){r[t<0?~t:t]=1})),i.push(a)}}return e.forEach((function(r,n){var a,i=t.arcs[r<0?~r:r];i.length<3&&!i[1][0]&&!i[1][1]&&(a=e[++o],e[o]=r,e[n]=a)})),e.forEach((function(e){var r,i,o=function(e){var r,n=t.arcs[e<0?~e:e],a=n[0];t.transform?(r=[0,0],n.forEach((function(t){r[0]+=t[0],r[1]+=t[1]}))):r=n[n.length-1];return e<0?[r,a]:[a,r]}(e),s=o[0],l=o[1];if(r=a[s])if(delete a[r.end],r.push(e),r.end=l,i=n[l]){delete n[i.start];var c=i===r?r:r.concat(i);n[c.start=r.start]=a[c.end=i.end]=c}else n[r.start]=a[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,i=a[s]){delete a[i.end];var u=i===r?r:i.concat(r);n[u.start=i.start]=a[u.end=r.end]=u}else n[r.start]=a[r.end]=r;else n[(r=[e]).start=s]=a[r.end=l]=r})),s(a,n),s(n,a),e.forEach((function(t){r[t<0?~t:t]||i.push([t])})),i}function s(t,e,r){var n,a,i;if(arguments.length>1)n=l(t,e,r);else for(a=0,n=new Array(i=t.arcs.length);a<i;++a)n[a]=a;return{type:\"MultiLineString\",arcs:o(t,n)}}function l(t,e,r){var n,a=[],i=[];function o(t){var e=t<0?~t:t;(i[e]||(i[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":!function(t){t.forEach(l)}(e.arcs)}}(e),i.forEach(null==r?function(t){a.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&a.push(t[0].i)}),a}function c(t,e){var r={},n=[],a=[];function s(t){t.forEach((function(e){e.forEach((function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)}))})),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,a=t[n-1],i=0;++r<n;)e=a,a=t[r],i+=e[0]*a[1]-e[1]*a[0];return Math.abs(i)}(i(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach((function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":s(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(s)}})),n.forEach((function(t){if(!t._){var e=[],n=[t];for(t._=1,a.push(e);t=n.pop();)e.push(t),t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].forEach((function(t){t._||(t._=1,n.push(t))}))}))}))}})),n.forEach((function(t){delete t._})),{type:\"MultiPolygon\",arcs:a.map((function(e){var n,a=[];if(e.forEach((function(t){t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].length<2&&a.push(t)}))}))})),(n=(a=o(t,a)).length)>1)for(var i,s,c=1,u=l(a[0]);c<n;++c)(i=l(a[c]))>u&&(s=a[0],a[0]=a[c],a[c]=s,u=i);return a})).filter((function(t){return t.length>0}))}}function u(t,e){for(var r=0,n=t.length;r<n;){var a=r+n>>>1;t[a]<e?r=a+1:n=a}return r}function h(t){if(null==t)return e;var r,n,a=t.scale[0],i=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c),h=Math.round((t[0]-o)/a),f=Math.round((t[1]-s)/i);for(u[0]=h-r,r=h,u[1]=f-n,n=f;l<c;)u[l]=t[l],++l;return u}}t.bbox=n,t.feature=function(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return a(t,e)}))}:a(t,e)},t.merge=function(t){return i(t,c.apply(this,arguments))},t.mergeArcs=c,t.mesh=function(t){return i(t,s.apply(this,arguments))},t.meshArcs=s,t.neighbors=function(t){var e={},r=t.map((function(){return[]}));function n(t,r){t.forEach((function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]}))}function a(t,e){t.forEach((function(t){n(t,e)}))}var i={LineString:n,MultiLineString:a,Polygon:a,MultiPolygon:function(t,e){t.forEach((function(t){a(t,e)}))}};for(var o in t.forEach((function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach((function(e){t(e,r)})):e.type in i&&i[e.type](e.arcs,r)})),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(t.transform)throw new Error(\"already quantized\");if(e&&e.scale)l=t.bbox;else{if(!((r=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");var r,a=(l=t.bbox||n(t))[0],i=l[1],o=l[2],s=l[3];e={scale:[o-a?(o-a)/(r-1):1,s-i?(s-i)/(r-1):1],translate:[a,i]}}var l,c,u=h(e),f=t.objects,p={};function d(t){return u(t)}function g(t){var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(g)};break;case\"Point\":e={type:\"Point\",coordinates:d(t.coordinates)};break;case\"MultiPoint\":e={type:\"MultiPoint\",coordinates:t.coordinates.map(d)};break;default:return t}return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}for(c in f)p[c]=g(f[c]);return{type:\"Topology\",bbox:l,transform:e,objects:p,arcs:t.arcs.map((function(t){var e,r=0,n=1,a=t.length,i=new Array(a);for(i[0]=u(t[0],0);++r<a;)((e=u(t[r],r))[0]||e[1])&&(i[n++]=e);return 1===n&&(i[n++]=[0,0]),i.length=n,i}))}},t.transform=r,t.untransform=h,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],552:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(i(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);a(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),a=t(\"permutation-parity\"),i=t(\"gamma\")},{gamma:248,\"permutation-parity\":483,\"permutation-rank\":484}],553:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),a=t.radius||1,i=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),a=c(d[0],d[1],d[2]);var g=l(r,d)/a,m=l(n,d)/a;u=Math.acos(g),i=Math.acos(m)}return a=Math.log(a),new f(t.zoomMin,t.zoomMax,e,r,n,a,i,u)};var n=t(\"filtered-vector\"),a=t(\"gl-mat4/invert\"),i=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),a=[0,0,0];e>Math.max(r,n)?a[2]=1:r>Math.max(e,n)?a[0]=1:a[1]=1;for(var i=0,o=0,l=0;l<3;++l)i+=t[l]*t[l],o+=a[l]*t[l];for(l=0;l<3;++l)a[l]-=o/i*t[l];return s(a,a),a}function f(t,e,r,a,i,o,s,l){this.center=n(r),this.up=n(a),this.right=n(i),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,a=0,i=0;i<3;++i)a+=e[i]*r[i],n+=e[i]*e[i];var l=Math.sqrt(n),u=0;for(i=0;i<3;++i)r[i]-=e[i]*a/n,u+=r[i]*r[i],e[i]/=l;var h=Math.sqrt(u);for(i=0;i<3;++i)r[i]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],m=Math.cos(d),v=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=m*y,w=v*y,T=x,k=-m*x,M=-v*x,A=y,S=this.computedEye,E=this.computedMatrix;for(i=0;i<3;++i){var C=_*r[i]+w*f[i]+T*e[i];E[4*i+1]=k*r[i]+M*f[i]+A*e[i],E[4*i+2]=C,E[4*i+3]=0}var L=E[1],P=E[5],I=E[9],z=E[2],O=E[6],D=E[10],R=P*D-I*O,F=I*z-L*D,B=L*O-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(i=0;i<3;++i)S[i]=b[i]+E[2+4*i]*p;for(i=0;i<3;++i){u=0;for(var j=0;j<3;++j)u+=E[i+4*j]*S[j];E[12+i]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var a=this.computedMatrix;d[0]=a[2],d[1]=a[6],d[2]=a[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)a[4*c]=o[c],a[4*c+1]=s[c],a[4*c+2]=l[c];i(a,a,n,d);for(c=0;c<3;++c)o[c]=a[4*c],s[c]=a[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var a=this.computedMatrix,i=(Math.exp(this.computedRadius[0]),a[1]),o=a[5],s=a[9],l=c(i,o,s);i/=l,o/=l,s/=l;var u=a[0],h=a[4],f=a[8],p=u*i+h*o+f*s,d=c(u-=i*p,h-=o*p,f-=s*p),g=(u/=d)*e+i*r,m=(h/=d)*e+o*r,v=(f/=d)*e+s*r;this.center.move(t,g,m,v);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var i=1;\"number\"==typeof r&&(i=0|r),(i<0||i>3)&&(i=1);var o=(i+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[i],l=e[i+4],h=e[i+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var m=c(s,l,h);s/=m,l/=m,h/=m}var v,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,T=c(x-=s*w,b-=l*w,_-=h*w),k=l*(_/=T)-h*(b/=T),M=h*(x/=T)-s*_,A=s*b-l*x,S=c(k,M,A);if(k/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===i){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,I=E*k+C*M+L*A;v=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(I,P)}else{var z=e[2],O=e[6],D=e[10],R=z*s+O*l+D*h,F=z*x+O*b+D*_,B=z*k+O*M+D*A;v=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,v),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;a(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var a=(n=n||this.computedUp)[0],i=n[1],o=n[2],s=c(a,i,o);if(!(s<1e-6)){a/=s,i/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],m=d[1],v=d[2],y=a*g+i*m+o*v,x=c(g-=y*a,m-=y*i,v-=y*o);if(!(x<.01&&(x=c(g=i*f-o*h,m=o*l-a*f,v=a*h-i*l))<1e-6)){g/=x,m/=x,v/=x,this.up.set(t,a,i,o),this.right.set(t,g,m,v),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=i*v-o*m,_=o*g-a*v,w=a*m-i*g,T=c(b,_,w),k=a*l+i*h+o*f,M=g*l+m*h+v*f,A=(b/=T)*l+(_/=T)*h+(w/=T)*f,S=Math.asin(u(k)),E=Math.atan2(A,M),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var I=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),O=Math.abs(L-2*Math.PI-E);I<z&&(L+=2*Math.PI),O<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":242,\"gl-mat4/invert\":278,\"gl-mat4/rotate\":283,\"gl-vec3/cross\":339,\"gl-vec3/dot\":344,\"gl-vec3/normalize\":361}],554:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var a=t*e,i=n*t,o=i-(i-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(a-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=a,r;return[h,a]};var n=+(Math.pow(2,27)+1)},{}],555:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,a=n-t,i=e-a,o=t-(n-a);if(r)return r[0]=o+i,r[1]=n,r;return[o+i,n]}},{}],556:[function(t,e,r){\"use strict\";var n=t(\"../prototype/is\");e.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},{\"../prototype/is\":563}],557:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),a=t(\"../object/is\"),i=t(\"../string/coerce\"),o=t(\"./to-short-string\"),s=function(t,e){return t.replace(\"%v\",o(e))};e.exports=function(t,e,r){if(!a(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=i(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},{\"../object/is\":560,\"../string/coerce\":564,\"../value/is\":566,\"./to-short-string\":559}],558:[function(t,e,r){\"use strict\";e.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},{}],559:[function(t,e,r){\"use strict\";var n=t(\"./safe-to-string\"),a=/[\\n\\r\\u2028\\u2029]/g;e.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\\u2026\"),e=e.replace(a,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},{\"./safe-to-string\":558}],560:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),a={object:!0,function:!0,undefined:!0};e.exports=function(t){return!!n(t)&&hasOwnProperty.call(a,typeof t)}},{\"../value/is\":566}],561:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),a=t(\"./is\");e.exports=function(t){return a(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},{\"../lib/resolve-exception\":557,\"./is\":562}],562:[function(t,e,r){\"use strict\";var n=t(\"../function/is\"),a=/^\\s*class[\\s{/}]/,i=Function.prototype.toString;e.exports=function(t){return!!n(t)&&!a.test(i.call(t))}},{\"../function/is\":556}],563:[function(t,e,r){\"use strict\";var n=t(\"../object/is\");e.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},{\"../object/is\":560}],564:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),a=t(\"../object/is\"),i=Object.prototype.toString;e.exports=function(t){if(!n(t))return null;if(a(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===i)return null}try{return\"\"+t}catch(t){return null}}},{\"../object/is\":560,\"../value/is\":566}],565:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),a=t(\"./is\");e.exports=function(t){return a(t)?t:n(t,\"Cannot use %v\",arguments[1])}},{\"../lib/resolve-exception\":557,\"./is\":566}],566:[function(t,e,r){\"use strict\";e.exports=function(t){return null!=t}},{}],567:[function(t,e,r){(function(e){\"use strict\";var n=t(\"bit-twiddle\"),a=t(\"dup\"),i=t(\"buffer\").Buffer;e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),BIGUINT64:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),BIGINT64:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=e.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=a([32,0])),c.BIGUINT64||(c.BIGUINT64=a([32,0])),c.BIGINT64||(c.BIGINT64=a([32,0])),c.BUFFER||(c.BUFFER=a([32,0]));var u=c.DATA,h=c.BUFFER;function f(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function g(t){return new Uint16Array(p(2*t),0,t)}function m(t){return new Uint32Array(p(4*t),0,t)}function v(t){return new Int8Array(p(t),0,t)}function y(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function b(t){return new Float32Array(p(4*t),0,t)}function _(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function M(t){return new DataView(p(t),0,t)}function A(t){t=n.nextPow2(t);var e=n.log2(t),r=h[e];return r.length>0?r.pop():new i(t)}r.free=function(t){if(i.isBuffer(t))h[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeBigUint64=r.freeInt8=r.freeInt16=r.freeInt32=r.freeBigInt64=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){f(t.buffer)},r.freeArrayBuffer=f,r.freeBuffer=function(t){h[n.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return g(t);case\"uint32\":return m(t);case\"int8\":return v(t);case\"int16\":return y(t);case\"int32\":return x(t);case\"float\":case\"float32\":return b(t);case\"double\":case\"float64\":return _(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return A(t);case\"data\":case\"dataview\":return M(t);default:return null}return null},r.mallocArrayBuffer=p,r.mallocUint8=d,r.mallocUint16=g,r.mallocUint32=m,r.mallocInt8=v,r.mallocInt16=y,r.mallocInt32=x,r.mallocFloat32=r.mallocFloat=b,r.mallocFloat64=r.mallocDouble=_,r.mallocUint8Clamped=w,r.mallocBigUint64=T,r.mallocBigInt64=k,r.mallocDataView=M,r.mallocBuffer=A,r.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,h[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"bit-twiddle\":97,buffer:111,dup:176}],568:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var a=n.prototype;Object.defineProperty(a,\"length\",{get:function(){return this.roots.length}}),a.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},a.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},a.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var a=this.ranks,i=this.roots,o=a[r],s=a[n];o<s?i[r]=n:s<o?i[n]=r:(i[n]=r,++a[r])}}},{}],569:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,a=t[0],i=t[0],o=1;o<n;++o)if(i=a,e(a=t[o],i)){if(o===r){r++;continue}t[r++]=a}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],a=t[0],i=1;i<r;++i,a=n)if(a=n,(n=t[i])!==a){if(i===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],570:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],571:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,a=r.length;n<a;n++){var i=r[n];for(var o in i)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===i[o])s=e[o];else{if(!1===i[o])continue;if(\"function\"==typeof i[o]&&void 0===(s=i[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],572:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||a,e.context||i,e)};var n=t(\"./lib/vtext\"),a=null,i=null;\"undefined\"!=typeof document&&((a=document.createElement(\"canvas\")).width=8192,a.height=1024,i=a.getContext(\"2d\"))},{\"./lib/vtext\":573}],573:[function(t,e,r){e.exports=function(t,e,r,n){var i=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(i=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,i+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",f(function(t,e,r,n,i,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(p=0;p<r.length;++p)l[p]=s;!0===o.bolds&&(l=c(\"b\",\"b|\",r,l));!0===o.italics&&(l=c(\"i\",\"i|\",r,l));!0===o.superscripts&&(l=c(\"sup\",\"+1\",r,l));!0===o.subscripts&&(l=c(\"sub\",\"-1\",r,l));var u=[],h=\"\";for(p=0;p<r.length;++p)null!==l[p]&&(h+=r[p],u.push(l[p]));var f,p,d,g,m,v=h.split(\"\\n\"),y=v.length,x=Math.round(i*n),b=n,_=2*n,w=0,T=y*x+_;t.height<T&&(t.height=T);e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var k=0,M=\"\";function A(){if(\"\"!==M){var t=e.measureText(M).width;e.fillText(M,b+d,_+g),d+=t}}function S(){return Math.round(m)+\"px \"}function E(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var a=t.indexOf(\"-\"),i=r.indexOf(\"-\"),s=a>-1?parseInt(t[1+a]):0,l=i>-1?parseInt(r[1+i]):0;s!==l&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,l-s),n=n.replace(\"?px \",S())),g+=.25*x*(l-s)}if(!0===o.superscripts){var c=t.indexOf(\"+\"),u=r.indexOf(\"+\"),h=c>-1?parseInt(t[1+c]):0,f=u>-1?parseInt(r[1+u]):0;h!==f&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,f-h),n=n.replace(\"?px \",S())),g-=.25*x*(f-h)}if(!0===o.bolds){var p=t.indexOf(\"b|\")>-1,d=r.indexOf(\"b|\")>-1;!p&&d&&(n=v?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),p&&!d&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var v=t.indexOf(\"i|\")>-1,y=r.indexOf(\"i|\")>-1;!v&&y&&(n=\"italic \"+n),v&&!y&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(f=0;f<y;++f){var C=v[f]+\"\\n\";for(d=0,g=f*x,m=n,M=\"\",p=0;p<C.length;++p){var L=p+k<u.length?u[p+k]:u[u.length-1];s===L?M+=C[p]:(A(),M=C[p],void 0!==L&&(E(s,L),s=L))}A(),k+=C.length;var P=0|Math.round(d+2*b);w<P&&(w=P)}var I=w,z=_+x*y;return a(e.getImageData(0,0,I,z).data,[z,I,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,i,o,s),n,i)},e.exports.processPixels=f;var n=t(\"surface-nets\"),a=t(\"ndarray\"),i=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\");function c(t,e,r,n){for(var a=\"<\"+t+\">\",i=\"</\"+t+\">\",o=a.length,s=i.length,l=\"+\"===e[0]||\"-\"===e[0],c=0,u=-s;c>-1&&-1!==(c=r.indexOf(a,c))&&-1!==(u=r.indexOf(i,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,d=r.substr(p,u-p).indexOf(a);c=-1!==d?d:u+s}return n}function u(t,e){var r=n(t,128);return e?i(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function h(t,e,r,n){var a=u(t,n),i=function(t,e,r){for(var n=e.textAlign||\"start\",a=e.textBaseline||\"alphabetic\",i=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)i[u]=0|Math.min(i[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(i[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-i[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(a){case\"hanging\":case\"top\":f=-i[1];break;case\"middle\":f=-.5*(i[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+a+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-i[0]):\"height\"in e&&(p=e.height/(o[1]-i[1])),t.map((function(t){return[p*(t[0]+h),p*(t[1]+f)]}))}(a.positions,e,r),c=a.edges,h=\"ccw\"===e.orientation;if(o(i,c),e.polygons||e.polygon||e.polyline){for(var f=l(c,i),p=new Array(f.length),d=0;d<f.length;++d){for(var g=f[d],m=new Array(g.length),v=0;v<g.length;++v){for(var y=g[v],x=new Array(y.length),b=0;b<y.length;++b)x[b]=i[y[b]].slice();h&&x.reverse(),m[v]=x}p[d]=m}return p}return e.triangles||e.triangulate||e.triangle?{cells:s(i,c,{delaunay:!1,exterior:!1,interior:!0}),positions:i}:{edges:c,positions:i}}function f(t,e,r){try{return h(t,e,r,!0)}catch(t){}try{return h(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:112,\"clean-pslg\":121,ndarray:469,\"planar-graph-to-polyline\":488,\"simplify-planar-graph\":534,\"surface-nets\":542}],574:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=g);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,a=Object.freeze({});if(n.set(a,1),1===n.get(a))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var i=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var c=new ArrayBuffer(25),u=new Uint8Array(c);crypto.getRandomValues(u),l=\"weakmap:rand:\"+Array.prototype.map.call(u,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return i(t).filter(m)}}),\"getPropertyNames\"in Object){var h=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return h(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var f=!1,p=0,d=function(){this instanceof d||x();var t=[],e=[],r=p++;return Object.create(d.prototype,{get___:{value:y((function(n,a){var i,o=v(n);return o?r in o?o[r]:a:(i=t.indexOf(n))>=0?e[i]:a}))},has___:{value:y((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:y((function(n,a){var i,o=v(n);return o?o[r]=a:(i=t.indexOf(n))>=0?e[i]=a:(i=t.length,e[i]=a,t[i]=n),this}))},delete___:{value:y((function(n){var a,i,o=v(n);return o?r in o&&delete o[r]:!((a=t.indexOf(n))<0)&&(i=t.length-1,t[a]=void 0,e[a]=e[i],t[a]=t[i],t.length=i,e.length=i,!0)}))}})};d.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof d||x();var e,n=new r,a=void 0,i=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(a||(a=new d),a.set(t,e)),this}:function(t,e){if(i)try{n.set(t,e)}catch(r){a||(a=new d),a.set___(t,e)}else n.set(t,e);return this},Object.create(d.prototype,{get___:{value:y((function(t,e){return a?n.has(t)?n.get(t):a.get___(t,e):n.get(t,e)}))},has___:{value:y((function(t){return n.has(t)||!!a&&a.has___(t)}))},set___:{value:y(e)},delete___:{value:y((function(t){var e=!!n.delete(t);return a&&a.delete___(t)||e}))},permitHostObjects___:{value:y((function(t){if(t!==g)throw new Error(\"bogus call to permitHostObjects___\");i=!0}))}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=d.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=d)}function g(t){t.permitHostObjects___&&t.permitHostObjects___(g)}function m(t){return!(\"weakmap:\"==t.substr(0,\"weakmap:\".length)&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[l];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,l,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function y(t){return t.prototype=null,Object.freeze(t)}function x(){f||\"undefined\"==typeof console||(f=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],575:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":576}],576:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],577:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":575}],578:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":249}],579:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\"),i=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,a(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),a=t.month(),i=\"\"+this.toChineseMonth(n,a);return e&&i.length<2&&(i=\"0\"+i),this.isIntercalaryMonth(n,a)&&(i+=\"i\"),i},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),a=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(a=\"\\u95f0\"+a),a},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),a=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(a=\"\\u95f0\"+a),a},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var a=e[e.length-1];r=\"i\"===a||\"I\"===a}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var a=this.intercalaryMonth(t);if(r&&e!==a||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return a?!r&&e<=a?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var a,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(a=i.newDate(l,c,u)).add(4-(a.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-a.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(a.year()),e=a.month(),r=a.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,a){var i,o,s;if(\"object\"==typeof t)o=t,i=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,i=n):(l=!!n,i=a||{}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=h[o.year-h[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++){s+=u&1<<12-d?30:29}var g=f[o.year-f[0]],m=new Date(g>>9&4095,(g>>5&15)-1,(31&g)+s);return i.year=m.getFullYear(),i.month=1+m.getMonth(),i.day=m.getDate(),i}(t,s,r,o);return i.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=i.fromJD(t),r=function(t,e,r,n){var a,i;if(\"object\"==typeof t)a=t,i=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");a={year:t,month:e,day:r},i=n||{}}var o=f[a.year-f[0]],s=a.year<<9|a.month<<5|a.day;i.year=s>=o?a.year:a.year-1,o=f[i.year-f[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(a.year,a.month-1,a.day);l=Math.round((u-c)/864e5);var p,d=h[i.year-h[0]];for(p=0;p<13;p++){var g=d&1<<12-p?30:29;if(l<g)break;l-=g}var m=d>>13;!m||p<m?(i.isIntercalary=!1,i.month=1+p):p===m?(i.isIntercalary=!0,i.month=p):(i.isIntercalary=!1,i.month=p);return i.day=1+l,i}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],a=!!e[3],i=this.toMonthIndex(r,n,a),o=+e[4];return this.newDate(r,i,o)},add:function(t,e,r){var n=t.year(),a=t.month(),i=this.isIntercalaryMonth(n,a),s=this.toChineseMonth(n,a),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=i&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":593,\"object-assign\":473}],580:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return(t=a.year())<0&&t++,a.day()+30*(a.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,a=e-30*(n-1)+1;return this.newDate(r,n,a)}}),n.calendars.coptic=i},{\"../main\":593,\"object-assign\":473}],581:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((a.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year()+(a.year()<0?1:0),e=a.month(),(r=a.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=i},{\"../main\":593,\"object-assign\":473}],582:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return(t=a.year())<0&&t++,a.day()+30*(a.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,a=e-30*(n-1)+1;return this.newDate(r,n,a)}}),n.calendars.ethiopian=i},{\"../main\":593,\"object-assign\":473}],583:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(a)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(a)%10-3]}},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=t<=0?t+1:t,o=this.jdEpoch+this._delay1(i)+this._delay2(i)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=i},{\"../main\":593,\"object-assign\":473}],584:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year(),e=a.month(),t=t<=0?t+1:t,(r=a.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=i},{\"../main\":593,\"object-assign\":473}],585:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year(),e=a.month(),r=a.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),a=Math.floor((e-n)/30.6001),i=a-Math.floor(a<14?1:13),o=r-Math.floor(i>2?4716:4715),s=e-n-Math.floor(30.6001*a);return o<=0&&o--,this.newDate(o,i,s)}}),n.calendars.julian=i},{\"../main\":593,\"object-assign\":473}],586:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate).toJD(),i=this._toHaab(a),o=this._toTzolkin(a);return{haabMonthName:this.local.haabMonths[i[0]-1],haabMonth:i[0],haabDay:i[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return a.day()+20*a.month()+360*a.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=i},{\"../main\":593,\"object-assign\":473}],587:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");a(i.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidMonth);(t=a.year())<0&&t++;for(var i=a.day(),s=1;s<a.month();s++)i+=this.daysPerMonth[s-1];return i+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=i},{\"../main\":593,\"object-assign\":473}],588:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=i.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],i.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),a=e.dayOfYear(),i=r+56;this._createMissingCalendarData(i);for(var o=9,s=this.NEPALI_CALENDAR_DATA[i][0],l=this.NEPALI_CALENDAR_DATA[i][o]-s+1;a>l;)++o>12&&(o=1,i++),l+=this.NEPALI_CALENDAR_DATA[i][o];var c=this.NEPALI_CALENDAR_DATA[i][o]-(l-a);return this.newDate(i,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=i},{\"../main\":593,\"object-assign\":473}],589:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=t-(t>=0?474:473),s=474+o(i,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(i/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),a=2820;if(1029982!==n){var i=Math.floor(n/366),s=o(n,366);a=Math.floor((2134*i+2816*s+2815)/1028522)+i+1}var l=a+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=i,n.calendars.jalali=i},{\"../main\":593,\"object-assign\":473}],590:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\"),i=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,a(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return i.leapYear(t)},weekOfYear:function(t,e,r){var a=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(a.year());return i.weekOfYear(t,a.month(),a.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(a.year());return i.toJD(t,a.month(),a.day())},fromJD:function(t){var e=i.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":593,\"object-assign\":473}],591:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\"),i=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,a(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return i.leapYear(t)},weekOfYear:function(t,e,r){var a=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(a.year());return i.weekOfYear(t,a.month(),a.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(a.year());return i.toJD(t,a.month(),a.day())},fromJD:function(t){var e=i.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":593,\"object-assign\":473}],592:[function(t,e,r){var n=t(\"../main\"),a=t(\"object-assign\");function i(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}i.prototype=new n.baseCalendar,a(i.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,a=0,i=0;i<o.length;i++){if(o[i]>r)return o[a]-o[a-1];a++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate),i=12*(a.year()-1)+a.month()-15292;return a.day()+o[i-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var a=r+15292,i=Math.floor((a-1)/12),s=i+1,l=a-12*i,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var a=n.baseCalendar.prototype.isValid.apply(this,arguments);return a&&(a=(t=null!=t.year?t.year:t)>=1276&&t<=1500),a},_validate:function(t,e,r,a){var i=n.baseCalendar.prototype._validate.apply(this,arguments);if(i.year<1276||i.year>1500)throw a.replace(/\\{0\\}/,this.local.name);return i}}),n.calendars.ummalqura=i;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":593,\"object-assign\":473}],593:[function(t,e,r){var n=t(\"object-assign\");function a(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function i(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(a.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,a){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,a):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",a=0;r>0;){var i=r%10;n=(0===i?\"\":t[i]+e[a])+n,a++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(i.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new i(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),a=t.calendar().fromJD(n);return this._validateLevel--,[a.year(),a.month(),a.day()]}try{var i=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);a=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(i,o)&&(o=this.newDate(i,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(i)),a=Math.min(a,this.daysInMonth(i,this.fromMonthOfYear(i,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)i--,o+=t.monthsInYear(i);for(var e=t.monthsInYear(i);o>e-1+t.minMonth;)i++,o-=e,e=t.monthsInYear(i)}(this),a=Math.min(a,this.daysInMonth(i,this.fromMonthOfYear(i,o))));var s=[i,this.fromMonthOfYear(i,o),a];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var a={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],i=r<0?-1:1;e=this._add(t,r*a[0]+i*a[1],a[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),a=\"m\"===r?e:t.month(),i=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(i=Math.min(i,this.daysInMonth(n,a))),t.date(n,a,i)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var a=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(a)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(a)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var a=this.newDate(t,e,r);return this._validateLevel--,a}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var a=Math.floor(t/100),i=2-a+Math.floor(a/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+i-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,a=Math.floor((n-122.1)/365.25),i=Math.floor(365.25*a),o=Math.floor((n-i)/30.6001),s=n-i-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=a-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),a=new Date(n.year(),n.month()-1,n.day());return a.setHours(0),a.setMinutes(0),a.setSeconds(0),a.setMilliseconds(0),a.setHours(a.getHours()>12?a.getHours()+2:0),a},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new a;c.cdate=i,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":473}],594:[function(t,e,r){var n=t(\"object-assign\"),a=t(\"./main\");n(a.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),a.local=a.regionalOptions[\"\"],n(a.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(a.baseCalendar.prototype,{UNIX_EPOCH:a.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:a.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw a.local.invalidFormat||a.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,i,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var a=\"\"+e;if(p(t,n))for(;a.length<r;)a=\"0\"+a;return a},g=this,m=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},v=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",i=e.dayOfWeek(),o=l,s=c,p(n)?s[i]:o[i]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=m(e);break;case\"M\":b+=v(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw a.local.invalidArguments||a.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var i=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,m=!1,v=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),i=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+i+\"}\"),s=e.substring(M).match(o);if(!s)throw(a.local.missingNumberAt||a.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(M));return M+=t.length,t}return x(\"m\")},w=function(t,r,n,i){for(var o=y(t,i)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(a.local.unknownNameAt||a.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,M)},T=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(M)!==t.charAt(A))throw(a.local.unexpectedLiteralAt||a.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,M);M++},M=0,A=0;A<t.length;A++)if(v)\"'\"!==t.charAt(A)||y(\"'\")?k():v=!1;else switch(t.charAt(A)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",i,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=T();break;case\"y\":var S=A;m=!y(\"y\",2),A=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(M)&&(M++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":M=e.length;break;case\"'\":y(\"'\")?k():v=!0;break;default:k()}if(M<e.length)throw a.local.unexpectedText||a.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&m&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,a){r&&\"object\"!=typeof r&&(a=n,n=r,r=null),\"string\"!=typeof n&&(a=n,n=\"\");var i=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return i.parseDate(n,t,a)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||i.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:i.today().add(t,\"d\"):i.newDate(t)}})},{\"./main\":593,\"object-assign\":473}],595:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":151}],596:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":595}],597:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],598:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),a=t(\"../../plots/font_attributes\"),i=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:a({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",i.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",i.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",i.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",i.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:a({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":787,\"../../plots/cartesian/constants\":804,\"../../plots/font_attributes\":826,\"./arrow_paths\":597}],599:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=a.getFromId(t,e.xref),n=a.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)}))}function s(t,e){var r,n=e._id,i=n.charAt(0),o=t[i],s=t[\"a\"+i],l=t[i+\"ref\"],c=t[\"a\"+i+\"ref\"],u=t[\"_\"+i+\"padplus\"],h=t[\"_\"+i+\"padminus\"],f={x:1,y:-1}[i]*t[i+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,m=3*t.startarrowsize*t.arrowwidth||0,v=m+f,y=m-f;if(c===l){var x=a.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=a.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,v),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else v=s?v+s:v,y=s?y-s:y,r=a.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,v),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([i,o],t)}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"./draw\":604}],600:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\"),i=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,a,i,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(i=(a=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===a.xref&&c._id===a.yref&&l.d2r(o.x)===s(a._xclick,l)&&c.d2r(o.y)===s(a._yclick,c)){(a.visible?\"onout\"===i?f:p:h).push(r);break}n===d&&a.visible&&\"onout\"===i&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=i(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=i(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return a.call(\"update\",t,{},h)}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../registry\":881}],601:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../color\");e.exports=function(t,e,r,i){i(\"opacity\");var o=i(\"bgcolor\"),s=i(\"bordercolor\"),l=a.opacity(s);i(\"borderpad\");var c=i(\"borderwidth\"),u=i(\"showarrow\");if(i(\"text\",u?\" \":r._dfltTitle.annotation),i(\"textangle\"),n.coerceFont(i,\"font\",r.font),i(\"width\"),i(\"align\"),i(\"height\")&&i(\"valign\"),u){var h,f,p=i(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=i(\"arrowhead\"),f=i(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(i(\"startarrowhead\",h),i(\"startarrowsize\",f)),i(\"arrowcolor\",l?e.bordercolor:a.defaultLine),i(\"arrowwidth\",2*(l&&c||1)),i(\"standoff\"),i(\"startstandoff\")}var d=i(\"hovertext\"),g=r.hoverlabel||{};if(d){var m=i(\"hoverlabel.bgcolor\",g.bgcolor||(a.opacity(o)?a.rgb(o):a.defaultLine)),v=i(\"hoverlabel.bordercolor\",g.bordercolor||a.contrast(m));n.coerceFont(i,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||v})}i(\"captureevents\",!!d)}},{\"../../lib\":749,\"../color\":615}],602:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,i){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?a(r,e.range):Math.pow(10,r),n(s)||(s=null),i(c+t,s)}}},{\"../../lib/to_log_range\":775,\"fast-isnumeric\":241}],603:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function i(r,a){return n.coerce(t,e,s,r,a)}var l=i(\"visible\"),c=i(\"clicktoshow\");if(l||c){o(t,e,r,i);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],m=a.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==m)a.getFromId(p,m)._annIndices.push(e._index);if(a.coercePosition(e,p,i,m,g,.5),u){var v=\"a\"+g,y=a.coerceRef(t,e,p,v,\"pixel\");\"pixel\"!==y&&y!==m&&(y=e[v]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;a.coercePosition(e,p,i,y,v,x)}i(g+\"anchor\"),i(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=i(\"xclick\"),_=i(\"yclick\");e._xclick=void 0===b?e.x:a.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:a.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){i(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../../plots/cartesian/axes\":798,\"./attributes\":598,\"./common_defaults\":601}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function m(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),a=s.getFromId(t,r.yref);n&&n.setScale(),a&&a.setScale(),v(t,r,e,!1,n,a)}function v(t,e,r,i,s,m){var v,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;i?(v=\"annotation-\"+i,y=i+\".annotations\"):(v=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),T=w.modifyBase,k=w.modifyItem,M=w.getUpdateObj;x._infolayer.selectAll(\".\"+v+'[data-index=\"'+r+'\"]').remove();var A=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(v,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],I=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",I?\"all\":null).call(f,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))}));e.hovertext&&z.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,a=this.getBoundingClientRect(),i=t.getBoundingClientRect();u.loneHover({x0:a.left-i.left,x1:a.right-i.left,y:(a.top+a.bottom)/2-i.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})})).on(\"mouseout\",(function(){u.loneUnhover(x._hoverlayer.node())}));var O=e.borderwidth,D=e.borderpad,R=O+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",O+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+A).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",A).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",(function(r){e.text=r,this.call(H),k(\"text\",r),s&&s.autorange&&T(s._name+\".autorange\",!0),m&&m.autorange&&T(m._name+\".autorange\",!0),a.call(\"_guiRelayout\",t,M())})):V.call(H)}else n.selectAll(\"#\"+A).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return i&&(n.subplotId=i),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),v=d.width,y=d.height,w=e.width||v,I=e.height||y,D=Math.round(w+2*R),j=Math.round(I+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,Z,X,J,K,Q=G[Y],$=e[Q+\"ref\"]||Q,tt=e[\"a\"+Q+\"ref\"],et={x:s,y:m}[Q],rt=(E+(\"x\"===Q?0:-90))*Math.PI/180,nt=D*Math.cos(rt),at=j*Math.sin(rt),it=Math.abs(nt)+Math.abs(at),ot=e[Q+\"anchor\"],st=e[Q+\"shift\"]*(\"x\"===Q?1:-1),lt=S[Q];if(et){var ct=et.r2fraction(e[Q]);(ct<0||ct>1)&&(tt===$?((ct=et.r2fraction(e[\"a\"+Q]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[Q]),J=.5}else\"x\"===Q?(X=e[Q],W=b.l+b.w*X):(X=1-e[Q],W=b.t+b.h*X),J=e.showarrow?.5:X;if(e.showarrow){lt.head=W;var ut=e[\"a\"+Q];K=nt*U(.5,e.xanchor)-at*U(.5,e.yanchor),tt===$?(lt.tail=et._offset+et.r2p(ut),Z=K):(lt.tail=W+ut,Z=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===Q?\"width\":\"height\"];if(\"paper\"===$&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else Z=K=it*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,Z+=st,e[\"_\"+Q+\"padplus\"]=it/2+Z,e[\"_\"+Q+\"padminus\"]=it/2-Z,e[\"_\"+Q+\"size\"]=it,e[\"_\"+Q+\"shift\"]=K}if(H)z.remove();else{var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-v)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(I-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?A:null,t);else{var mt=R+gt-d.top,vt=R+dt-d.left;V.call(h.positionText,vt,mt).call(c.setClipUrl,B?A:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,I),F.call(c.setRect,O/2,O/2,D-O,j-O),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,v=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,v,y),w=o.apply2DTransform(x),A=o.apply2DTransform2(x),P=+F.attr(\"width\"),I=+F.attr(\"height\"),O=v-.5*P,D=O+P,R=y-.5*I,B=R+I,N=[[O,R,O,B],[O,B,D,B],[D,B,D,R],[D,R,O,R]].map(A);if(!N.reduce((function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])}),!1)){N.forEach((function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)}));var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!i){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var Z,X,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);Z=t.x,X=t.y,s&&s.autorange&&T(s._name+\".autorange\",!0),m&&m.autorange&&T(m._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(Z,X),a=n[0]+t,i=n[1]+r;z.call(c.setTranslate,a,i),k(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),k(\"y\",m?m.p2r(m.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&k(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&k(\"ay\",m.p2r(m.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+a+\",\"+i+\")\"})},doneFn:function(){a.call(\"_guiRelayout\",t,M());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?k(\"ax\",s.p2r(s.r2p(e.ax)+t)):k(\"ax\",e.ax+t),e.ayref===e.yref?k(\"ay\",m.p2r(m.r2p(e.ay)+r)):k(\"ay\",e.ay+r),xt(t,r);else{if(i)return;var a,o;if(s)a=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;a=p.align(c+t/b.w,l,0,1,e.xanchor)}if(m)o=m.p2r(m.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}k(\"x\",a),k(\"y\",o),s&&m||(n=p.getCursor(s?.5:a,m?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),a.call(\"_guiRelayout\",t,M());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&m(t,r);return i.previousPromises(t)},drawOne:m,drawRaw:v}},{\"../../lib\":749,\"../../lib/setcursor\":769,\"../../lib/svg_text_utils\":773,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/axes\":798,\"../../plots/plots\":861,\"../../registry\":881,\"../color\":615,\"../dragelement\":634,\"../drawing\":637,\"../fx\":655,\"./draw_arrow_head\":605,d3:169}],605:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../color\"),i=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=i[r.arrowhead||0],f=i[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,m=e.indexOf(\"end\")>=0,v=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,v&&y&&v+y>Math.sqrt(x*x+b*b))return void P();if(v){if(v*v>x*x+b*b)return void P();var _=v*Math.cos(l),w=v*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var T=y*Math.cos(l),k=y*Math.sin(l);o.x-=T,o.y-=k,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var M=u.getTotalLength(),A=\"\";if(M<v+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,M)),A=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(M),L=u.getPointAtLength(M-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,M-v)),A+=M-(A?y+v:v)+\"px,\"+M+\"px\",t.style(\"stroke-dasharray\",A)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function I(e,i,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+i.x+\",\"+i.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:a.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&I(f,o,l,d),m&&I(h,s,c,p)}},{\"../color\":615,\"./arrow_paths\":597,d3:169}],606:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),a=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:a.hasClickToShow,onClick:a.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":810,\"./attributes\":598,\"./calc_autorange\":599,\"./click\":600,\"./convert_coords\":602,\"./defaults\":603,\"./draw\":604}],607:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),a=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=a(i(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":780,\"../../plot_api/plot_template\":787,\"../annotations/attributes\":598}],608:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\");function i(t,e){var r=e.fullSceneLayout.domain,i=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),a.setConvert(t._xa),t._xa._offset=i.l+r.x[0]*i.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*i.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),a.setConvert(t._ya),t._ya._offset=i.t+(1-r.y[1])*i.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*i.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)i(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798}],609:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,i){function l(r,a){return n.coerce(t,e,s,r,a)}function c(t){var n=t+\"axis\",i={_fullLayout:{}};return i._fullLayout[n]=r[n],a.coercePosition(e,i,l,t,t,.5)}l(\"visible\")&&(o(t,e,i.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){i(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../../plots/cartesian/axes\":798,\"../annotations/common_defaults\":601,\"./attributes\":607}],610:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,a=t(\"../../plots/gl3d/project\"),i=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=i[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=a(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":849,\"../annotations/draw\":604}],611:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var i=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];i.test(l)&&(t[l].annotations||[]).length&&(a.pushUnique(e._basePlotModules,r),a.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":749,\"../../registry\":881,\"./attributes\":607,\"./convert\":608,\"./defaults\":609,\"./draw\":610}],612:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":579,\"world-calendars/dist/calendars/coptic\":580,\"world-calendars/dist/calendars/discworld\":581,\"world-calendars/dist/calendars/ethiopian\":582,\"world-calendars/dist/calendars/hebrew\":583,\"world-calendars/dist/calendars/islamic\":584,\"world-calendars/dist/calendars/julian\":585,\"world-calendars/dist/calendars/mayan\":586,\"world-calendars/dist/calendars/nanakshahi\":587,\"world-calendars/dist/calendars/nepali\":588,\"world-calendars/dist/calendars/persian\":589,\"world-calendars/dist/calendars/taiwan\":590,\"world-calendars/dist/calendars/thai\":591,\"world-calendars/dist/calendars/ummalqura\":592,\"world-calendars/dist/main\":593,\"world-calendars/dist/plus\":594}],613:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),a=t(\"../../lib\"),i=t(\"../../constants/numerical\"),o=i.EPOCHJD,s=i.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var i={};return i[r]=l,a.coerce(t,e,i,r,n)},u={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:\"##\",w:\"##\",c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var h={};function f(t){var e=h[t];return e||(e=h[t]=n.instance(t))}function p(t){return a.extendFlat({},l,{description:t})}function d(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var g={xcalendar:p(d(\"x\"))},m=a.extendFlat({},g,{ycalendar:p(d(\"y\"))}),v=a.extendFlat({},m,{zcalendar:p(d(\"z\"))}),y=p([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:v,surface:v,mesh3d:v,scattergl:m,ohlc:g,candlestick:g},layout:{calendar:p([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:y},yaxis:{calendar:y},scene:{xaxis:{calendar:y},yaxis:{calendar:y},zaxis:{calendar:y}},polar:{radialaxis:{calendar:y}}},transforms:{filter:{valuecalendar:p([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:p([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var a=0;a<r.length;a++)c(t,e,r[a]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:f,worldCalFmt:function(t,e,r){for(var n,a,i,l,c,h=Math.floor((e+.05)/s)+o,p=f(r).fromJD(h),d=0;-1!==(d=t.indexOf(\"%\",d));)\"0\"===(n=t.charAt(d+1))||\"-\"===n||\"_\"===n?(i=3,a=t.charAt(d+2),\"_\"===n&&(n=\"-\")):(a=n,n=\"0\",i=2),(l=u[a])?(c=\"##\"===l?\"##\":p.formatDate(l[n]),t=t.substr(0,d)+c+t.substr(d+i),d+=c.length):d+=i;return t}}},{\"../../constants/numerical\":724,\"../../lib\":749,\"./calendars\":612}],614:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],615:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),i=e.exports={},o=t(\"./attributes\");i.defaults=o.defaults;var s=i.defaultLine=o.defaultLine;i.lightLine=o.lightLine;var l=i.background=o.background;function c(t){if(a(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),i=\"a\"===e.charAt(3)&&4===n.length;if(!i&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return i?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}i.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},i.rgb=function(t){return i.tinyRGB(n(t))},i.opacity=function(t){return t?n(t).getAlpha():0},i.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},i.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var a=n(e||l).toRgb(),i=1===a.a?a:{r:255*(1-a.a)+a.r*a.a,g:255*(1-a.a)+a.g*a.a,b:255*(1-a.a)+a.b*a.a},o={r:i.r*(1-r.a)+r.r*r.a,g:i.g*(1-r.a)+r.g*r.a,b:i.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},i.contrast=function(t,e,r){var a=n(t);return 1!==a.getAlpha()&&(a=n(i.combine(t,l))),(a.isDark()?e?a.lighten(e):l:r?a.darken(r):s).toString()},i.stroke=function(t,e){var r=n(e);t.style({stroke:i.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},i.fill=function(t,e){var r=n(e);t.style({fill:i.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},i.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,a,o=Object.keys(t);for(e=0;e<o.length;e++)if(a=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(a))for(r=0;r<a.length;r++)a[r]=c(a[r]);else t[n]=c(a);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(a))for(r=0;r<a.length;r++)Array.isArray(a[r])&&(a[r][1]=c(a[r][1]));else if(Array.isArray(a)){var s=a[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<a.length;r++)i.clean(a[r])}else a&&\"object\"==typeof a&&i.clean(a)}}},{\"./attributes\":614,\"fast-isnumeric\":241,tinycolor2:548}],616:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),i=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:i({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:a({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:a({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:a({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/cartesian/layout_attributes\":812,\"../../plots/font_attributes\":826}],617:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],618:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),i=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=a.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),i(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/tick_label_defaults\":819,\"../../plots/cartesian/tick_mark_defaults\":820,\"../../plots/cartesian/tick_value_defaults\":821,\"./attributes\":616}],619:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"tinycolor2\"),i=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),m=t(\"../colorscale/helpers\").flipScale,v=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,T=b.FROM_BR,k=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+k.colorbar).data(function(t){var e,r,n,a,i=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof a.calc?a.calc(t,n,e):(e._fillgradient=r.reversescale?m(r.colorscale):r.colorscale,e._zrange=[r[a.min],r[a.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],v=0;v<g.length;v++){var y=(a=g[v]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in i._colorAxes)if((r=i[x]).showscale){var b=i._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=i._meta,a={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],a.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(k.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",k.cbbg),c.ensureSingle(r,\"g\",k.cbfills),c.ensureSingle(r,\"g\",k.cblines),c.ensureSingle(r,\"g\",k.cbaxis,(function(t){t.classed(k.crisp,!0)})),c.ensureSingle(r,\"g\",k.cbtitleunshift,(function(t){t.append(\"g\").classed(k.cbtitle,!0)})),c.ensureSingle(r,\"rect\",k.cboutline);var m=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,m=e._line,b=e.title,M=b.side,A=e._zrange||n.extent((\"function\"==typeof h?h:m.color).domain()),S=\"function\"==typeof m.color?m.color:function(){return m.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,a,i=e._levels,o=[],s=[],l=i.end+i.size/100,c=i.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(a=0;a<1e5&&(n=i.start+a*c,!(c>0?n>=l:n<=l));a++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,a=0;a<1e5&&(n=f.start+a*c,!(c>0?n>=l:n<=l));a++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-i.size/2}))).push(s[s.length-1]+i.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);i.size<0&&(o.reverse(),s.reverse());return{line:o,fill:s}}(0,e,A),P=L.fill,I=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),O=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-O*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=O,e._xLeftFrac=U,e._yBottomFrac=V;var G=e._axis=function(t,e,r){var n=t._fullLayout,a={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},i={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,noTicklabelmode:!0,calendar:n.calendar};function s(t,e){return c.coerce(a,i,x,t,e)}return v(a,i,s,o,n),y(a,i,s,o),i}(r,e,A);G.position=e.x+F+O,-1!==[\"top\",\"bottom\"].indexOf(M)&&(G.title.side=M,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N));if(m.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,Z=(A[1]-A[0])/((e.nticks||W)*Y);if(Z>1){var X=Math.pow(10,Math.floor(Math.log(Z)/Math.LN10));Y*=X*c.roundUp(Z/X,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+k.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),Q=t.select(\".\"+k.cbaxis),$=0;function tt(n,a){var i={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+k.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(i,a||{}))}return c.syncOrAsync([i.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(M)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===M?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(M)){var i=t.select(\".\"+k.cbtitle),o=i.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=i.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?($=f.bBox(h).height)>p&&(u[1]-=($-p)/2):o.node()&&!o.classed(k.jsPlaceholder)&&($=f.bBox(o.node()).height),$){if($+=5,\"top\"===M)G.domain[1]-=$/l.h,u[1]*=-1;else{G.domain[0]+=$/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}i.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+k.cbfills+\",.\"+k.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),Q.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var v=t.select(\".\"+k.cbfills).selectAll(\"rect.\"+k.cbfill).data(P);v.enter().append(\"rect\").classed(k.cbfill,!0).style(\"stroke\",\"none\"),v.exit().remove();var y=A.map(G.c2p).map(Math.round).sort((function(t,e){return t-e}));v.each((function(t,i){var o=[0===i?A[0]:(P[i]+P[i-1])/2,i===P.length-1?A[1]:(P[i]+P[i+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",a(l).toHexString())}}));var x=t.select(\".\"+k.cblines).selectAll(\"path.\"+k.cbline).data(m.color&&m.width?I:[]);x.enter().append(\"path\").classed(k.cbline,!0),x.exit().remove(),x.each((function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+m.width/2%1)+\"h\"+z).call(f.lineGroupStyle,m.width,S(t),m.dash)})),Q.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),T=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:Q,path:s.makeTickPath(G,b,C),transFn:T}),s.drawLabels(r,G,{vals:w,layer:Q,transFn:T,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(M)){var t=G.title.font.size,e=G._offset+G._length/2,a=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:M,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:a,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},i.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox(Q.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(k.jsPlaceholder)){var a,o=K.select(\".h\"+G._id+\"title-math-group\").node();a=o&&-1!==[\"top\",\"bottom\"].indexOf(M)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,a)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+k.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+k.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===M?$:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-$,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=T[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var m=w[e.xanchor],v=T[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*m,h.r=s*v;else{var y=s-z;h.l=y*m,h.r=y*v,h.xl=e.x-e.thickness*m,h.xr=e.x+e.thickness*v}i.autoMargin(r,e._id,h)}],r)}(r,e,t);m&&m.then&&(t._promises||[]).push(m),t._context.edits.colorbarPosition&&function(t,e,r){var n,a,i,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),a=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),i=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(a,i,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==a&&void 0!==i){var n={};n[e._propPrefix+\"x\"]=a,n[e._propPrefix+\"y\"]=i,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){i.autoMargin(t,e._id)})).remove(),e.order()}}},{\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/extend\":739,\"../../lib/setcursor\":769,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/axis_defaults\":800,\"../../plots/cartesian/layout_attributes\":812,\"../../plots/cartesian/position_defaults\":815,\"../../plots/plots\":861,\"../../registry\":881,\"../color\":615,\"../colorscale/helpers\":626,\"../dragelement\":634,\"../drawing\":637,\"../titles\":710,\"./constants\":617,d3:169,tinycolor2:548}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":749}],621:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":616,\"./defaults\":618,\"./draw\":619,\"./has_colorbar\":620}],622:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),a=t(\"../../lib/regex\").counter,i=t(\"./scales.js\").scales;Object.keys(i);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?i[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",m=s+\"mid\",v=(o(f+p),o(f+d),o(f+g),{});v[d]=v[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:v},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[m]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:v},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:a(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":765,\"../colorbar/attributes\":616,\"./scales.js\":630}],623:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?a.nestedProperty(e,c).get():e,h=i(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,m=function(){return a.aggNums(Math.min,null,l)},v=function(){return a.aggNums(Math.max,null,l)};(void 0===p?p=m():f&&(p=u._colorAx&&n(p)?Math.min(p,m()):m()),void 0===d?d=v():f&&(d=u._colorAx&&n(d)?Math.max(d,v()):v()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":749,\"./helpers\":626,\"fast-isnumeric\":241}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./helpers\").hasColorscale,i=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,a){var o=a.container?n.nestedProperty(t,a.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=i(o),l=s.auto;(l||void 0===s.min)&&r(o,a.min),(l||void 0===s.max)&&r(o,a.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);a(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":749,\"./helpers\":626}],625:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?a.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,m=c(e,p),v=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&a.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=b[_];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,a.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var k=m[d+\"min\"],M=m[d+\"max\"],A=n(k)&&n(M)&&k<M;h(p+d+\"auto\",!A)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=m.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=i(m)),h(p+\"showscale\",E)&&(p&&y&&(v._template=y),o(m,v,u)))}},{\"../../lib\":749,\"../../registry\":881,\"../colorbar/defaults\":618,\"../colorbar/has_colorbar\":620,\"./scales\":630,\"fast-isnumeric\":241}],626:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,a=t._colorAx,i=a||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=i[n];if(a)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=i[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in i||(s=\"z\"+n)in i)&&(o[n]=i[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;i[n]=i[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,a=e.reversescale?p(e.colorscale):e.colorscale,i=a.length,o=new Array(i),s=new Array(i),l=0;l<i;l++){var c=a[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,a=0;n>=0;n--,a++){var i=t[n];r[a]=[1-i[0],i[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=a(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,m=e.returnArray;return(f=d&&m?p:d?function(t){return g(p(t))}:m?function(t){return i(t)?p(t):a(t).isValid()?t:s.defaultLine}:function(t){return i(t)?g(p(t)):a(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return a(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,a=n[r||\"color\"],s=!1;if(o.isArrayOrTypedArray(a))for(var c=0;c<a.length;c++)if(i(a[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||i(n.cmin)&&i(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":749,\"../color\":615,\"./scales\":630,d3:169,\"fast-isnumeric\":241,tinycolor2:548}],627:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),a=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:a.hasColorscale,extractOpts:a.extractOpts,extractScale:a.extractScale,flipScale:a.flipScale,makeColorScaleFunc:a.makeColorScaleFunc,makeColorScaleFuncFromTrace:a.makeColorScaleFuncFromTrace}},{\"./attributes\":622,\"./calc\":623,\"./cross_trace_defaults\":624,\"./defaults\":625,\"./helpers\":626,\"./layout_attributes\":628,\"./layout_defaults\":629,\"./scales\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,a=t(\"./attributes\"),i=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:i.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:i.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:i.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},a(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":739,\"./attributes\":622,\"./scales\":630}],629:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),i=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,i.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=a.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"./defaults\":625,\"./layout_attributes\":628}],630:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),a={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},i=a.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var a=t[r];if(2!==a.length||+a[0]<e||!n(a[1]).isValid())return!1;e=+a[0]}return!0}e.exports={scales:a,defaultScale:i,get:function(t,e){if(e||(e=i),!t)return e;function r(){try{t=a[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==a[t]||o(t)}}},{tinycolor2:548}],631:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){var i=(t-r)/(n-r),o=i+e/(n-r),s=(i+o)/2;return\"left\"===a||\"bottom\"===a?i:\"center\"===a||\"middle\"===a?s:\"right\"===a||\"top\"===a?o:i<2/3-s?i:o>4/3-s?o:s}},{}],632:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,i){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===i?0:\"middle\"===i?1:\"top\"===i?2:n.constrain(Math.floor(3*e),0,2),a[e][t]}},{\"../../lib\":749}],633:[function(t,e,r){\"use strict\";r.selectMode=function(t){return\"lasso\"===t||\"select\"===t},r.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},r.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},r.selectingOrDrawing=function(t){return r.freeMode(t)||r.rectMode(t)}},{}],634:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),a=t(\"has-hover\"),i=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,m=t.gd,v=1,y=m._context.doubleClickDelay,x=t.element;m._mouseDownTime||(m._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,i?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(i){m._dragged=!1,m._dragging=!0;var o=h(i);e=o[0],r=o[1],d=i.target,p=i,g=2===i.buttons||i.ctrlKey,\"undefined\"==typeof i.clientX&&\"undefined\"==typeof i.clientY&&(i.clientX=e,i.clientY=r),(n=(new Date).getTime())-m._mouseDownTime<y?v+=1:(v=1,m._mouseDownTime=n),t.prepFn&&t.prepFn(i,e,r),a&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:a||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(i.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var a=h(n),i=t.minDrag||s.MINDRAG,o=b(a[0]-e,a[1]-r,i),c=o[0],u=o[1];(c||u)&&(m._dragged=!0,l.unhover(m)),m._dragged&&t.moveFn&&!g&&(m._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete m._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),a?o(f):c&&(f.documentElement.style.cursor=c,c=null),m._dragging){if(m._dragging=!1,(new Date).getTime()-m._mouseDownTime>y&&(v=Math.max(v-1,1)),m._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(v,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}m._dragging=!1,m._dragged=!1}else m._dragged=!1}},l.coverSlip=u},{\"../../lib\":749,\"../../plots/cartesian/constants\":804,\"./align\":631,\"./cursor\":632,\"./unhover\":635,\"has-hover\":414,\"has-passive-events\":415,\"mouse-event-offset\":458}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),a=t(\"../../lib/throttle\"),i=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=i(t))._fullLayout&&a.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,a=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&a&&t.emit(\"plotly_unhover\",{event:e,points:a}))}},{\"../../lib/dom\":737,\"../../lib/events\":738,\"../../lib/throttle\":774,\"../fx/constants\":649}],636:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],637:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),m=t(\"../../components/fx/helpers\").appendArrayPointValue,v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,a){t.call(v.setPosition,e,r).call(v.setSize,n,a)},v.translatePoint=function(t,e,r,n){var i=r.c2p(t.x),o=n.c2p(t.y);return!!(a(i)&&a(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",i).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+i+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each((function(t){var a=n.select(this);v.translatePoint(t,a,e,r)}))},v.hideOutsideRangePoint=function(t,e,r,n,a,i){e.attr(\"display\",r.isPtWithinRange(t,a)&&n.isPtWithinRange(t,i)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,a=e.yaxis;t.each((function(e){var i=e[0].trace,s=i.xcalendar,l=i.ycalendar,c=o.traceIs(i,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){v.hideOutsideRangePoint(t,n.select(this),r,a,s,l)}))}))}},v.crispRound=function(t,e,r){return e&&a(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,a){e.style(\"fill\",\"none\");var i=(((t||[])[0]||{}).trace||{}).line||{},o=r||i.width||0,l=a||i.dash||\"\";s.stroke(e,n||i.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,a){t.style(\"fill\",\"none\").each((function(t){var i=(((t||[])[0]||{}).trace||{}).line||{},o=e||i.width||0,l=a||i.dash||\"\";n.select(this).call(s.stroke,r||i.color).call(v.dashLine,l,o)}))},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each((function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)}))};var y=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(y).forEach((function(t){var e=y[t],r=e.n;v.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),v.symbolNames[r]=t,v.symbolFuncs[r]=e.f,e.needLine&&(v.symbolNeedLines[r]=!0),e.noDot?v.symbolNoDot[r]=!0:v.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(v.symbolNoFill[r]=!0)}));var x=v.symbolNames.length;function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}v.symbolNumber=function(t){if(a(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=x||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},T=n.format(\"~.1f\"),k={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,a,o,l){for(var u=o.length,h=k[a],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[T(100*(1-o[p][0])),o[p][1]]:f[p]=[T(100*o[p][0]),o[p][1]];var d=e._fullLayout,g=\"g\"+d._uid+\"-\"+r,m=d._defs.select(\".gradients\").selectAll(\"#\"+g).data([a+f.join(\";\")],c.identity);m.exit().remove(),m.enter().append(h.node).each((function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",g);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=i(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,z(g,e)).style(l+\"-opacity\",null);var v=function(t){return\".\"+t.attr(\"class\").replace(/\\s/g,\".\")},y=v(n.select(t.node().parentNode))+\">\"+v(t);d._gradientUrlQueryParts[y]=1},v.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),e._gradientUrlQueryParts={}},v.pointStyle=function(t,e,r){if(t.size()){var a=v.makePointStyleFns(e);t.each((function(t){v.singlePointStyle(t,n.select(this),e,a,r)}))}},v.singlePointStyle=function(t,e,r,n,a){var i=r.marker,o=i.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?i.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===i.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||i.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=i.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(i.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):i.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:p)+\"px\");var m=i.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],k[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,a,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.marker||{},i=r.marker||{},s=n.marker||{},l=a.opacity,u=i.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?a.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=a.color,m=i.color,v=s.color;(m||v)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?m||e:v||e});var y=a.size,x=i.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.textfont||{},i=r.textfont||{},o=n.textfont||{},l=a.color,c=i.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),a=e.marker||{},i=[];r.selectedOpacityFn&&i.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&i.push((function(t,e){s.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&i.push((function(t,e){var n=e.mx||a.symbol||0,i=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),i)),e.mrc2=i})),i.length&&t.each((function(t){for(var e=n.select(this),r=0;r<i.length;r++)i[r](e,t)}))}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var M={start:1,end:-1,middle:0,bottom:1,top:-1};function A(t,e,r,a){var i=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=a?a/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=M[s]*l,p=.75*r+M[o]*l+(M[o]-1)*c*r/2;t.attr(\"text-anchor\",s),i.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return a(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var a;if(e.selectedpoints){var i=v.makeSelectedTextStyleFns(e);a=i.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each((function(t){var i=n.select(this),l=o?c.extractOption(t,e,\"txt\",\"texttemplate\"):c.extractOption(t,e,\"tx\",\"text\");if(l||0===l){if(o){var h=e._module.formatLabels?e._module.formatLabels(t,e,s):{},f={};m(f,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,h,s._d3locale,f,t,p)}var d=t.tp||e.textposition,g=S(t,e),y=a?a(t):t.tc||e.textfont.color;i.call(v.font,t.tf||e.textfont.family,g,y).text(l).call(u.convertToTspans,r).call(A,d,g,t.mrc)}else i.remove()}))}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each((function(t){var a=n.select(this),i=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(a,i),A(a,o,l,t.mrc2||t.mrc)}))}};function E(t,e,r,a){var i=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(i*i+o*o,.25),u=Math.pow(s*s+l*l,.25),h=(u*u*i-c*c*s)*a,f=(u*u*o-c*c*l)*a,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],a=[];for(r=1;r<t.length-1;r++)a.push(E(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+a[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+a[r-2][1]+\" \"+a[r-1][0]+\" \"+t[r];return n+=\"Q\"+a[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],a=t.length-1,i=[E(t[a],t[0],t[1],e)];for(r=1;r<a;r++)i.push(E(t[r-1],t[r],t[r+1],e));for(i.push(E(t[a-1],t[a],t[0],e)),r=1;r<=a;r++)n+=\"C\"+i[r-1][1]+\" \"+i[r][0]+\" \"+t[r];return n+=\"C\"+i[a][1]+\" \"+i[0][0]+\" \"+t[0]+\"Z\"};var C={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},L=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=C[t]||L;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),a=1;a<t.length;a++)r+=e(t[a-1],t[a]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=c.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));v.tester=t,v.testref=e},v.savedBBoxes={};var P=0;function I(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function z(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var a,i,o;if(r||(r=I(t)),r){if(a=v.savedBBoxes[r])return c.extendFlat({},a)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=I(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,a=v.savedBBoxes[r])return c.extendFlat({},a)}}e?i=t:(o=v.tester.node(),i=t.cloneNode(!0),o.appendChild(i)),n.select(i).attr(\"transform\",null).call(u.positionText,0,0);var d=i.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(i);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return P>=1e4&&(v.savedBBoxes={},P=0),r&&(v.savedBBoxes[r]=m),P++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",z(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",a=t.attr?\"attr\":\"setAttribute\",i=t[n](\"transform\")||\"\";return e=e||0,r=r||0,i=i.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),i=(i+=\" translate(\"+e+\", \"+r+\")\").trim(),t[a](\"transform\",i),i},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",a=t.attr?\"attr\":\"setAttribute\",i=t[n](\"transform\")||\"\";return e=e||1,r=r||1,i=i.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),i=(i+=\" scale(\"+e+\", \"+r+\")\").trim(),t[a](\"transform\",i),i};var O=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(O,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var D=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,a=n.select(this),i=a.select(\"text\");if(i.node()){var o=parseFloat(i.attr(\"x\")||0),s=parseFloat(i.attr(\"y\")||0),l=(a.attr(\"transform\")||\"\").match(D);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),a.attr(\"transform\",t.join(\" \"))}}))}},{\"../../components/fx/helpers\":651,\"../../constants/alignment\":717,\"../../constants/interactions\":723,\"../../constants/xmlns_namespaces\":725,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../registry\":881,\"../../traces/scatter/make_bubble_size_func\":1173,\"../../traces/scatter/subtypes\":1181,\"../color\":615,\"../colorscale\":627,\"./symbol_defs\":638,d3:169,\"fast-isnumeric\":241,tinycolor2:548}],638:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,a=\"l\"+e+\",-\"+e,i=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+a+i+a+i+o+i+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),a=n.round(-t,2),i=n.round(-.309*t,2);return\"M\"+e+\",\"+i+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+i+\"L0,\"+a+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),a=n.round(t*Math.sqrt(3)/2,2);return\"M\"+a+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+a+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),a=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+a+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+a+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),a=n.round(.951*e,2),i=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+a+\"L\"+i+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+i+\",\"+c+\"L-\"+a+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),a=n.round(.76*t,2);return\"M-\"+a+\",0l-\"+r+\",-\"+e+\"h\"+a+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+a+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+a+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+a+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),a=n.round(1.6*t,2),i=n.round(4*t,2),o=\"A \"+i+\",\"+i+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+a+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),a=n.round(1.6*t,2),i=n.round(4*t,2),o=\"A \"+i+\",\"+i+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+a+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),a=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+a+\"-\"+e+\",\"+e+a+e+\",\"+e+a+e+\",-\"+e+a+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),a=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+a+\"0,\"+e+a+e+\",0\"+a+\"0,-\"+e+a+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return\"M-\"+e+\",\"+a+\"L0,0M\"+e+\",\"+a+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return\"M-\"+e+\",-\"+a+\"L0,0M\"+e+\",-\"+a+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return\"M\"+a+\",\"+e+\"L0,0M\"+a+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return\"M-\"+a+\",\"+e+\"L0,0M-\"+a+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-down\":{n:46,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-left\":{n:47,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-right\":{n:48,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0}}},{d3:169}],639:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],640:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,a){var l=e[\"error_\"+a]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[a];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var m=f[a+\"s\"]=d-g[0],v=f[a+\"h\"]=d+g[1];c.push(m,v)}}}var y=r._id,x=e._extremes[y],b=i.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&a.traceIs(o,\"errorBarsOK\")){var s=i.getFromId(t,o.xaxis),c=i.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"./compute_error\":641,\"fast-isnumeric\":241}],641:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var a=t.array||[];if(r)return function(t,e){var r=+a[e];return[r,r]};var i=t.arrayminus||[];return function(t,e){var r=+a[e],n=+i[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],642:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return i.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",a.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../registry\":881,\"./attributes\":639,\"fast-isnumeric\":241}],643:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./attributes\"),o={error_x:n.extendFlat({},i),error_y:n.extendFlat({},i)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},i),error_y:n.extendFlat({},i),error_z:n.extendFlat({},i)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:a(s,\"calc\",\"nested\"),scattergl:a(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":749,\"../../plot_api/edit_types\":780,\"./attributes\":639,\"./calc\":640,\"./compute_error\":641,\"./defaults\":642,\"./plot\":644,\"./style\":645}],644:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each((function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var m=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(m.exit().remove(),e.length){p.visible||m.selectAll(\"path.xerror\").remove(),d.visible||m.selectAll(\"path.yerror\").remove(),m.style(\"opacity\",1);var v=m.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),i.setClipUrl(m,r.layerClipId,t),m.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),a(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),a(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var i,o=e.select(\"path.yerror\");if(d.visible&&a(r.x)&&a(r.yh)&&a(r.ys)){var h=d.width;i=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(i+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",i)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&a(r.y)&&a(r.xh)&&a(r.xs)){var m=(p.copy_ystyle?d:p).width;i=\"M\"+r.xh+\",\"+(r.y-m)+\"v\"+2*m+\"m0,-\"+m+\"H\"+r.xs,r.noXS||(i+=\"m0,-\"+m+\"v\"+2*m),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",i)}else f.remove()}}))}}))}},{\"../../traces/scatter/subtypes\":1181,\"../drawing\":637,d3:169,\"fast-isnumeric\":241}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../color\");e.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},i=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(a.stroke,r.color),i.copy_ystyle&&(i=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",i.thickness+\"px\").call(a.stroke,i.color)}))}},{\"../color\":615,d3:169}],646:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"./layout_attributes\").hoverlabel,i=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:i({},a.bgcolor,{arrayOk:!0}),bordercolor:i({},a.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:i({},a.align,{arrayOk:!0}),namelength:i({},a.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":739,\"../../plots/font_attributes\":826,\"./layout_attributes\":656}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\");function i(t,e,r,a){a=a||n.identity,Array.isArray(t)&&(e[0][r]=a(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!a.traceIs(c,\"pie-like\")){var u=a.traceIs(c,\"2dMap\")?i:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":749,\"../../registry\":881}],648:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"./hover\").hover;e.exports=function(t,e,r){var i=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&a(t,e,r,!0),t._hoverdata&&e&&e.target&&(i&&i.then?i.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":881,\"./hover\":652}],649:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],650:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}),s)}},{\"../../lib\":749,\"./attributes\":646,\"./hoverlabel_defaults\":653}],651:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],a=t.yaxes||[],i=0;i<n.length;i++)for(var o=0;o<a.length;o++)if(-1!==e.indexOf(n[i]+a[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,a){return\"closest\"===t?a||r.quadrature(e,n):\"x\"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var a=e(t[n]);a<=r.distance&&(r.index=n,r.distance=a)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),a=e(r);return Math.sqrt(n*n+a*a)}},r.makeEventData=function(t,e,n){var a=\"index\"in t?t.index:t.pointNumber,i={data:e._input,fullData:e,curveNumber:e.index,pointNumber:a};if(e._indexToPoints){var o=e._indexToPoints[a];1===o.length?i.pointIndex=o[0]:i.pointIndices=o}else i.pointIndex=a;return e._module.eventData?i=e._module.eventData(i,t,e,n,a):(\"xVal\"in t?i.x=t.xVal:\"x\"in t&&(i.x=t.x),\"yVal\"in t?i.y=t.yVal:\"y\"in t&&(i.y=t.y),t.xa&&(i.xaxis=t.xa),t.ya&&(i.yaxis=t.ya),void 0!==t.zLabelVal&&(i.z=t.zLabelVal)),r.appendArrayPointValue(i,e,a),i},r.appendArrayPointValue=function(t,e,r){var a=e._arrayAttrs;if(a)for(var s=0;s<a.length;s++){var l=a[s],c=i(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var a=e._arrayAttrs;if(a)for(var s=0;s<a.length;s++){var l=a[s],c=i(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var a={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function i(t){return a[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};r.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},r.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},{\"../../lib\":749}],652:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),m=t(\"./constants\"),v=t(\"../legend/defaults\"),y=t(\"../legend/draw\"),x=m.YANGLE,b=Math.PI*x/180,_=1/Math.sin(b),w=Math.cos(b),T=Math.sin(b),k=m.HOVERARROWSIZE,M=m.HOVERTEXTPAD;function A(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")}r.hover=function(t,e,r,i){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+m.HOVERID,m.HOVERMINTIME,(function(){!function(t,e,r,i){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,p=u._plots||[],m=p[r],v=u._has(\"cartesian\");if(m){var y=m.overlays.map((function(t){return t.id}));l=l.concat(y)}for(var x=l.length,b=new Array(x),w=new Array(x),T=!1,k=0;k<x;k++){var M=l[k];if(p[M])T=!0,b[k]=p[M].xaxis,w[k]=p[M].yaxis;else{if(!u[M]||!u[M]._subplot)return void o.warn(\"Unrecognized subplot: \"+M);var S=u[M]._subplot;b[k]=S.xaxis,w[k]=S.yaxis}}var C=e.hovermode||u.hovermode;C&&!T&&(C=\"closest\");if(-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(C)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var O,D,R,F,B,N,j,U,V,q,H,G,Y,W=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,X=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(C=\"array\",R=0;R<e.length;R++)(B=t.calcdata[e[R].curveNumber||0])&&(N=B[0].trace,\"skip\"!==B[0].trace.hoverinfo&&(J.push(B),\"h\"===N.orientation&&(Q=!0)));else{for(F=0;F<t.calcdata.length;F++)B=t.calcdata[F],\"skip\"!==(N=B[0].trace).hoverinfo&&g.isTraceInSubplots(N,l)&&(J.push(B),\"h\"===N.orientation&&(Q=!0));var $,tt;if(!e.target)$=\"xpx\"in e?e.xpx:b[0]._length/2,tt=\"ypx\"in e?e.ypx:w[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var et=e.target.getBoundingClientRect();if($=e.clientX-et.left,tt=e.clientY-et.top,$<0||$>b[0]._length||tt<0||tt>w[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=$+b[0]._offset,e.pointerY=tt+w[0]._offset,O=\"xval\"in e?g.flat(l,e.xval):g.p2c(b,$),D=\"yval\"in e?g.flat(l,e.yval):g.p2c(w,tt),!a(O[0])||!a(D[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var rt=1/0;function nt(t,r){for(F=0;F<J.length;F++)if((B=J[F])&&B[0]&&B[0].trace&&!0===(N=B[0].trace).visible&&0!==N._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(N._module.name)){if(\"splom\"===N.type?j=l[U=0]:(j=g.getSubplot(N),U=l.indexOf(j)),V=C,g.isUnifiedHover(V)&&(V=V.charAt(0)),G={cd:B,trace:N,xa:b[U],ya:w[U],maxHoverDistance:W,maxSpikeDistance:Z,index:!1,distance:Math.min(rt,W),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:N.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[j]&&(G.subplot=u[j]._subplot),u._splomScenes&&u._splomScenes[N.uid]&&(G.scene=u._splomScenes[N.uid]),Y=X.length,\"array\"===V){var n=e[F];\"pointNumber\"in n?(G.index=n.pointNumber,V=\"closest\"):(V=\"\",\"xval\"in n&&(q=n.xval,V=\"x\"),\"yval\"in n&&(H=n.yval,V=V?\"closest\":\"y\"))}else void 0!==t&&void 0!==r?(q=t,H=r):(q=O[U],H=D[U]);if(0!==W)if(N._module&&N._module.hoverPoints){var i=N._module.hoverPoints(G,q,H,V,u._hoverlayer);if(i)for(var s,c=0;c<i.length;c++)s=i[c],a(s.x0)&&a(s.y0)&&X.push(P(s,C))}else o.log(\"Unrecognized trace type in hover:\",N);if(\"closest\"===C&&X.length>Y&&(X.splice(0,Y),rt=X[0].distance),v&&0!==Z&&0===X.length){G.distance=Z,G.index=!1;var f=N._module.hoverPoints(G,q,H,\"closest\",u._hoverlayer);if(f&&(f=f.filter((function(t){return t.spikeDistance<=Z}))),f&&f.length){var p,d=f.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(d.length){var m=d[0];a(m.x0)&&a(m.y0)&&(p=it(m),(!K.vLinePoint||K.vLinePoint.spikeDistance>p.spikeDistance)&&(K.vLinePoint=p))}var y=f.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(y.length){var x=y[0];a(x.x0)&&a(x.y0)&&(p=it(x),(!K.hLinePoint||K.hLinePoint.spikeDistance>p.spikeDistance)&&(K.hLinePoint=p))}}}}}function at(t,e){for(var r,n=null,a=1/0,i=0;i<t.length;i++)(r=t[i].spikeDistance)<=a&&r<=e&&(n=t[i],a=r);return n}function it(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}nt();var ot={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},st=t._spikepoints,lt={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=lt,v&&0!==Z&&0!==X.length){var ct=at(X.filter((function(t){return t.ya.showspikes})),Z);K.hLinePoint=it(ct);var ut=at(X.filter((function(t){return t.xa.showspikes})),Z);K.vLinePoint=it(ut)}if(0===X.length){var ht=f.unhoverRaw(t,e);return!v||null===K.hLinePoint&&null===K.vLinePoint||z(st)&&I(t,K,ot),ht}v&&z(st)&&I(t,K,ot);if(X.sort((function(t,e){return t.distance-e.distance})),g.isXYhover(V)&&0!==X[0].length&&\"splom\"!==X[0].trace.type){var ft=X[0],pt=ft.cd[ft.index],dt=\"group\"===u.boxmode||\"group\"===u.violinmode,gt=ft.xVal,mt=ft.xa;\"category\"===mt.type&&(gt=mt._categoriesMap[gt]),\"date\"===mt.type&&(gt=mt.d2c(gt)),pt&&pt.t&&pt.t.posLetter===mt._id&&dt&&(gt+=pt.t.dPos);var vt=ft.yVal;\"category\"===(mt=ft.ya).type&&(vt=mt._categoriesMap[vt]),\"date\"===mt.type&&(vt=mt.d2c(vt)),pt&&pt.t&&pt.t.posLetter===mt._id&&dt&&(vt+=pt.t.dPos),nt(gt,vt);var yt={};X=X.filter((function(t){var e=A(t);if(!yt[e])return yt[e]=!0,yt[e]}))}var xt=t._hoverdata,bt=[];for(R=0;R<X.length;R++){var _t=X[R],wt=g.makeEventData(_t,_t.trace,_t.cd);if(!1!==_t.hovertemplate){var Tt=!1;_t.cd[_t.index]&&_t.cd[_t.index].ht&&(Tt=_t.cd[_t.index].ht),_t.hovertemplate=Tt||_t.trace.hovertemplate||!1}_t.eventData=[wt],bt.push(wt)}t._hoverdata=bt;var kt=\"y\"===C&&(J.length>1||X.length>1)||\"closest\"===C&&Q&&X.length>1,Mt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),At={hovermode:C,rotateLabels:kt,bgColor:Mt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},St=E(X,At,t);g.isUnifiedHover(C)||(!function(t,e,r){var n,a,i,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(a=e.pmin-e.pos-e.dp+e.size,i=r.pos+r.dp+r.size-e.pmax,a>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=a;n=!1}if(!(i<.01)){if(a<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=i;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,i=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=i;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each((function(t){var n=t[e],a=\"x\"===n._id.charAt(0),i=n.range;0===d&&i&&i[0]>i[1]!==a&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(a?_:1)/2,pmin:0,pmax:a?r.width:r.height}]})),p.sort((function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)}));for(;!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var m=p[o],v=p[o+1],y=m[m.length-1],x=v[0];if((a=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=v.length-1;s>=0;s--)v[s].dp+=a;for(m.push.apply(m,v),p.splice(o+1,1),c=0,s=m.length-1;s>=0;s--)c+=m[s].dp;for(i=c/m.length,s=m.length-1;s>=0;s--)m[s].dp-=i;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var w=b[s],T=w.datum;T.offset=w.dp,T.del=w.del}}}(St,kt?\"xa\":\"ya\",u),L(St,kt));if(e.target&&e.target.tagName){var Et=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,bt);c(n.select(e.target),Et?\"pointer\":\"\")}if(!e.target||i||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var a=r[n],i=t._hoverdata[n];if(a.curveNumber!==i.curveNumber||String(a.pointNumber)!==String(i.pointNumber)||String(a.pointNumbers)!==String(i.pointNumbers))return!0}return!1}(t,0,xt))return;xt&&t.emit(\"plotly_unhover\",{event:e,points:xt});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:b,yaxes:w,xvals:O,yvals:D})}(t,e,r,i)}))},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var a=t.map((function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}})),i=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):i,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:i,outerContainer:o},l=E(a,s,e.gd),c=0,u=0;return l.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)})).each((function(t){t.offset-=u})),L(l,s.rotateLabels),r?l:l.node()};var S=/<extra>([\\s\\S]*)<\\/extra>/;function E(t,e,r){var a=r._fullLayout,i=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},b=e.fontFamily||m.HOVERFONT,_=e.fontSize||m.HOVERFONTSIZE,w=t[0],T=w.xa,S=w.ya,E=\"y\"===i.charAt(0)?\"yLabel\":\"xLabel\",L=w[E],P=(String(L)||\"\").split(\" \")[0],I=p.node().getBoundingClientRect(),z=I.top,O=I.width,D=I.height,R=void 0!==L&&w.distance<=e.hoverdistance&&(\"x\"===i||\"y\"===i);if(R){var F,B,N=!0;for(F=0;F<t.length;F++)if(N&&void 0===t[F].zLabel&&(N=!1),B=t[F].hoverinfo||t[F].trace.hoverinfo){var j=Array.isArray(B)?B:B.split(\"+\");if(-1===j.indexOf(\"all\")&&-1===j.indexOf(i)){R=!1;break}}N&&(R=!1)}var U=f.selectAll(\"g.axistext\").data(R?[0]:[]);function V(t){return t.filter((function(t){return void 0!==t.zLabelVal||(t[E]||\"\").split(\" \")[0]===P}))}if(U.enter().append(\"g\").classed(\"axistext\",!0),U.exit().remove(),U.each((function(){var e=n.select(this),s=o.ensureSingle(e,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),c=o.ensureSingle(e,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),f=d.bgcolor||h.defaultLine,p=d.bordercolor||h.contrast(f),g=h.contrast(f),m={family:d.font.family||b,size:d.font.size||_,color:d.font.color||g};s.style({fill:f,stroke:p}),c.text(L).call(u.font,m).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v,y,x=c.node().getBoundingClientRect();if(\"x\"===i){var A=\"top\"===T.side?\"-\":\"\";c.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===T.side?z-x.bottom-k-M:z-x.top+k+M),v=T._offset+(w.x0+w.x1)/2,y=S._offset+(\"top\"===T.side?0:S._length);var E=x.width/2+M;v<E?(v=E,s.attr(\"d\",\"M-\"+(E-k)+\",0L-\"+(E-2*k)+\",\"+A+k+\"H\"+(M+x.width/2)+\"v\"+A+(2*M+x.height)+\"H-\"+E+\"V\"+A+k+\"Z\")):v>a.width-E?(v=a.width-E,s.attr(\"d\",\"M\"+(E-k)+\",0L\"+E+\",\"+A+k+\"v\"+A+(2*M+x.height)+\"H-\"+E+\"V\"+A+k+\"H\"+(E-2*k)+\"Z\")):s.attr(\"d\",\"M0,0L\"+k+\",\"+A+k+\"H\"+(M+x.width/2)+\"v\"+A+(2*M+x.height)+\"H-\"+(M+x.width/2)+\"V\"+A+k+\"H-\"+k+\"Z\")}else{var C,P,I;\"right\"===S.side?(C=\"start\",P=1,I=\"\",v=T._offset+T._length):(C=\"end\",P=-1,I=\"-\",v=T._offset),y=S._offset+(w.y0+w.y1)/2,c.attr(\"text-anchor\",C),s.attr(\"d\",\"M0,0L\"+I+k+\",\"+k+\"V\"+(M+x.height/2)+\"h\"+I+(2*M+x.width)+\"V-\"+(M+x.height/2)+\"H\"+I+k+\"V-\"+k+\"Z\");var O,D=x.height/2,R=z-x.top-D,F=\"clip\"+a._uid+\"commonlabel\"+S._id;if(v<x.width+2*M+k){O=\"M-\"+(k+M)+\"-\"+D+\"h-\"+(x.width-M)+\"V\"+D+\"h\"+(x.width-M)+\"Z\";var B=x.width-v+M;l.positionText(c,B,R),\"end\"===C&&c.selectAll(\"tspan\").each((function(){var t=n.select(this),e=u.tester.append(\"text\").text(t.text()).call(u.font,m),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(x.width)&&t.attr(\"x\",B-r.width),e.remove()}))}else l.positionText(c,P*(M+k),R),O=null;var N=a._topclips.selectAll(\"#\"+F).data(O?[0]:[]);N.enter().append(\"clipPath\").attr(\"id\",F).append(\"path\"),N.exit().remove(),N.select(\"path\").attr(\"d\",O),u.setClipUrl(c,O?F:null,r)}e.attr(\"transform\",\"translate(\"+v+\",\"+y+\")\"),t=V(t)})),g.isUnifiedHover(i)){if(f.selectAll(\"g.hovertext\").remove(),void 0!==L&&w.distance<=e.hoverdistance&&(t=V(t)),0===t.length)return;var q={showlegend:!0,legend:{title:{text:L,font:a.hoverlabel.font},font:a.hoverlabel.font,bgcolor:a.hoverlabel.bgcolor,bordercolor:a.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:a.legend?a.legend.traceorder:void 0,orientation:\"v\"}},H={};v(q,H,r._fullData);var G=H.legend;G.entries=[];for(var Y=0;Y<t.length;Y++){var W=C(t[Y],!0,i,a,L),Z=W[0],X=W[1],J=t[Y];J.name=X,J.text=\"\"!==X?X+\" : \"+Z:Z;var K=J.cd[J.index];K&&(K.mc&&(J.mc=K.mc),K.mcc&&(J.mc=K.mcc),K.mlc&&(J.mlc=K.mlc),K.mlcc&&(J.mlc=K.mlcc),K.mlw&&(J.mlw=K.mlw),K.mrc&&(J.mrc=K.mrc),K.dir&&(J.dir=K.dir)),J._distinct=!0,G.entries.push([J])}G.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),G.layer=f,y(r,G);var Q=o.mean(t.map((function(t){return(t.y0+t.y1)/2}))),$=o.mean(t.map((function(t){return(t.x0+t.x1)/2}))),tt=f.select(\"g.legend\"),et=tt.node().getBoundingClientRect();$+=T._offset,Q+=S._offset-et.height/2;var rt=et.width+2*M;!($+rt<=O)&&$-rt>=0?$-=rt:$+=2*M;var nt=et.height+2*M,at=Q+nt>=D;return nt<=D&&(Q<=z?Q=S._offset+2*M:at&&(Q=D-nt)),tt.attr(\"transform\",\"translate(\"+$+\",\"+Q+\")\"),tt}var it=f.selectAll(\"g.hovertext\").data(t,(function(t){return A(t)}));return it.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,b,_)})),it.exit().remove(),it.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var f=t.bgcolor||o,p=h.combine(h.opacity(f)?f:h.defaultLine,c),d=h.combine(h.opacity(o)?o:h.defaultLine,c),g=t.borderColor||h.contrast(p),m=C(t,R,i,a,L,e),v=m[0],y=m[1],w=e.select(\"text.nums\").call(u.font,t.fontFamily||b,t.fontSize||_,t.fontColor||g).text(v).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),T=e.select(\"text.name\"),A=0,S=0;if(y&&y!==v){T.call(u.font,t.fontFamily||b,t.fontSize||_,d).text(y).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var E=T.node().getBoundingClientRect();A=E.width+2*M,S=E.height+2*M}else T.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:p,stroke:g});var P,I,F=w.node().getBoundingClientRect(),B=t.xa._offset+(t.x0+t.x1)/2,N=t.ya._offset+(t.y0+t.y1)/2,j=Math.abs(t.x1-t.x0),U=Math.abs(t.y1-t.y0),V=F.width+k+M+A;if(t.ty0=z-F.top,t.bx=F.width+2*M,t.by=Math.max(F.height+2*M,S),t.anchor=\"start\",t.txwidth=F.width,t.tx2width=A,t.offset=0,s)t.pos=B,P=N+U/2+V<=D,I=N-U/2-V>=0,\"top\"!==t.idealAlign&&P||!I?P?(N+=U/2,t.anchor=\"start\"):t.anchor=\"middle\":(N-=U/2,t.anchor=\"end\");else if(t.pos=N,P=B+j/2+V<=O,I=B-j/2-V>=0,\"left\"!==t.idealAlign&&P||!I)if(P)B+=j/2,t.anchor=\"start\";else{t.anchor=\"middle\";var q=V/2,H=B+q-O,G=B-q;H>0&&(B-=H),G<0&&(B+=-G)}else B-=j/2,t.anchor=\"end\";w.attr(\"text-anchor\",t.anchor),A&&T.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+B+\",\"+N+\")\"+(s?\"rotate(\"+x+\")\":\"\"))})),it}function C(t,e,r,n,a,i){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=O(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[r.charAt(0)+\"Label\"]===a?l=t[(\"x\"===r.charAt(0)?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),i&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&i.remove(),l=s);var c=n._d3locale,u=t.hovertemplate||!1,h=t.hovertemplateLabels||t,f=t.eventData[0]||{};return u&&(l=(l=o.hovertemplateString(u,h,c,f,t.trace._meta)).replace(S,(function(e,r){return s=O(r,t.nameLength),\"\"}))),[l,s]}function L(t,e){t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var a=r.select(\"text.nums\"),i=t.anchor,o=\"end\"===i?-1:1,s={start:1,end:-1,middle:0}[i],c=s*(k+M),h=c+s*(t.txwidth+M),f=0,p=t.offset;\"middle\"===i&&(c-=t.tx2width/2,h+=t.txwidth/2+M),e&&(p*=-T,f=t.offset*w),r.select(\"path\").attr(\"d\",\"middle\"===i?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*k+f)+\",\"+(k+p)+\"v\"+(t.by/2-k)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*k+f)+\"V\"+(p-k)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+M,m=t.textAlign||\"auto\";\"auto\"!==m&&(\"left\"===m&&\"start\"!==i?(a.attr(\"text-anchor\",\"start\"),d=\"middle\"===i?-t.bx/2-t.tx2width/2+M:-t.bx-M):\"right\"===m&&\"end\"!==i&&(a.attr(\"text-anchor\",\"end\"),d=\"middle\"===i?t.bx/2-t.tx2width/2-M:t.bx+M)),a.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*M+f,p+t.ty0-t.by/2+M),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))}))}function P(t,e){var r=t.index,n=t.trace||{},i=t.cd[0],s=t.cd[r]||{};function l(t){return t||a(t)&&0===t}var c=Array.isArray(r)?function(t,e){var a=o.castOption(i,r,t);return l(a)?a:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var a=c(r,n);l(a)&&(t[e]=a)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function I(t,e,r){var n,a,o=r.container,s=r.fullLayout,l=s._size,c=r.event,f=!!e.hLinePoint,d=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),d||f){var g=h.combine(s.plot_bgcolor,s.paper_bgcolor);if(f){var m,v,y=e.hLinePoint;n=y&&y.xa,\"cursor\"===(a=y&&y.ya).spikesnap?(m=c.pointerX,v=c.pointerY):(m=n._offset+y.x,v=a._offset+y.y);var x,b,_=i.readability(y.color,g)<1.5?h.contrast(g):y.color,w=a.spikemode,T=a.spikethickness,k=a.spikecolor||_,M=p.getPxPosition(t,a);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=M,b=m),-1!==w.indexOf(\"across\")){var A=a._counterDomainMin,S=a._counterDomainMax;\"free\"===a.anchor&&(A=Math.min(A,a.position),S=Math.max(S,a.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":u.dashStyle(a.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T+2,stroke:g}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:M+(\"right\"!==a.side?T:-T),cy:v,r:T,fill:k}).classed(\"spikeline\",!0)}if(d){var E,C,L=e.vLinePoint;n=L&&L.xa,a=L&&L.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,C=c.pointerY):(E=n._offset+L.x,C=a._offset+L.y);var P,I,z=i.readability(L.color,g)<1.5?h.contrast(g):L.color,O=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=p.getPxPosition(t,n);if(-1!==O.indexOf(\"toaxis\")||-1!==O.indexOf(\"across\")){if(-1!==O.indexOf(\"toaxis\")&&(P=F,I=C),-1!==O.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),P=l.t+(1-N)*l.h,I=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:P,y2:I,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":u.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:P,y2:I,\"stroke-width\":D+2,stroke:g}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==O.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function z(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function O(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":749,\"../../lib/events\":738,\"../../lib/override_cursor\":760,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"../color\":615,\"../dragelement\":634,\"../drawing\":637,\"../legend/defaults\":667,\"../legend/draw\":668,\"./constants\":649,\"./helpers\":651,d3:169,\"fast-isnumeric\":241,tinycolor2:548}],653:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../color\"),i=t(\"./helpers\").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&i(e.hovermode)&&(o.font||(o.font={}),s(\"size\"),s(\"family\"),s(\"color\"),e.legend?(o.bgcolor||(o.bgcolor=a.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},{\"../../lib\":749,\"../color\":615,\"./helpers\":651}],654:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e,r){function i(r,i){return void 0!==e[r]?e[r]:n.coerce(t,e,a,r,i)}var o,s=i(\"clickmode\");return e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var a=t[n],i=a.xaxis+a.yaxis,o=(r[i]||{})[a.stackgroup]||{};if(\"h\"!==a.orientation&&\"h\"!==o.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",i(\"hovermode\",o)}},{\"../../lib\":749,\"./layout_attributes\":656}],655:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return a.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return a.castOption(t,r,\"hoverinfo\",(function(r){return a.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:i.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=a.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":749,\"../dragelement\":634,\"./attributes\":646,\"./calc\":647,\"./click\":648,\"./constants\":649,\"./defaults\":650,\"./helpers\":651,\"./hover\":652,\"./layout_attributes\":656,\"./layout_defaults\":657,\"./layout_global_defaults\":658,d3:169}],656:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"../../plots/font_attributes\")({editType:\"none\"});a.family.dflt=n.HOVERFONT,a.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:a,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":826,\"./constants\":649}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./helpers\").isUnifiedHover,i=t(\"./layout_attributes\"),o=t(\"./hovermode_defaults\"),s=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r){function l(r,a){return n.coerce(t,e,i,r,a)}var c=o(t,e,r);c&&(l(\"hoverdistance\"),l(\"spikedistance\",a(c)?-1:void 0)),\"select\"===l(\"dragmode\")&&l(\"selectdirection\");var u=e._has(\"mapbox\"),h=e._has(\"geo\"),f=e._basePlotModules.length;\"zoom\"===e.dragmode&&((u||h)&&1===f||u&&h&&2===f)&&(e.dragmode=\"pan\"),s(t,e,l)}},{\"../../lib\":749,\"./helpers\":651,\"./hoverlabel_defaults\":653,\"./hovermode_defaults\":654,\"./layout_attributes\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./hoverlabel_defaults\"),i=t(\"./layout_attributes\");e.exports=function(t,e){a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}))}},{\"../../lib\":749,\"./hoverlabel_defaults\":653,\"./layout_attributes\":656}],659:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../lib/regex\").counter,i=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[a(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:i({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],a=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:a.length?a:void 0}function u(t,e,r,n,a,i){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(a),c=s[0],u=(s[1]-c)/(a-o),h=u*(1-o),f=0;f<a;f++){var p=c+u*f;l[i?a-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,a){var i,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(i=0;i<r;i++)s(i,t[i]);else for(s(0,a),i=1;i<r;i++)s(i,a+(i+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},a=c(e,r,\"x\"),i=c(e,r,\"y\");if(t.grid||a||i){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(a),d=Array.isArray(i),g=p&&a!==r.xaxes&&d&&i!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=i.length),p&&(h=a.length));var m=s.newContainer(e,\"grid\"),v=k(\"rows\",o),y=k(\"columns\",h);if(v*y>1){if(!f&&!p&&!d)\"independent\"===k(\"pattern\")&&(f=!0);m._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===k(\"roworder\"),w=f?.2:.1,T=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),m._domains={x:u(\"x\",k,w,x,y),y:u(\"y\",k,T,b,v,_)}}else delete e.grid}function k(t,e){return n.coerce(r,m,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,a,i,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,m=r.columns,v=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(m),w=x[n]||[];for(a=0;a<m;a++)if(v?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[a],_[a]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),i=s.slice(0,u),o=s.slice(u),void 0!==y[i]&&y[i]!==a||void 0!==y[o]&&y[o]!==n)continue;_[a]=s,y[i]=a,y[o]=n}}}else{var T=c(e,f,\"x\"),k=c(e,f,\"y\");r.xaxes=h(T,p.xaxis,m,y,\"x\"),r.yaxes=h(k,p.yaxis,g,y,\"y\")}var M=r._anchors={},A=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),I=r[P+\"side\"];if(I.length<8)M[S]=\"free\";else if(\"x\"===P){if(\"t\"===I.charAt(0)===A?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if(\"l\"===I.charAt(0)?(E=0,C=1,L=m):(E=m-1,C=-1,L=-1),d){var O=y[S];for(n=E;n!==L;n+=C)if((s=l[O][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(i=r.xaxes[n],-1!==p.cartesian.indexOf(i+S)){M[S]=i;break}}}}}},{\"../../lib\":749,\"../../lib/regex\":765,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/constants\":804,\"../../plots/domain\":825}],660:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=a(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":787,\"../../plots/cartesian/constants\":804}],661:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,i){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,m=null;if(o){g=a(p,e.range);var v=d/Math.pow(10,g)/2;m=2*Math.log(v+Math.sqrt(1+v*v))/Math.LN10}else m=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(m)||(m=null):(g=null,m=null),i(c+h,g),i(c+\"size\"+h,m)}}},{\"../../lib/to_log_range\":775,\"fast-isnumeric\":241}],662:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function i(r,a){return n.coerce(t,e,o,r,a)}var s=i(\"source\");if(!i(\"visible\",!!s))return e;i(\"layer\"),i(\"xanchor\"),i(\"yanchor\"),i(\"sizex\"),i(\"sizey\"),i(\"sizing\"),i(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=a.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)a.getFromId(l,f)._imgIndices.push(e._index);a.coercePosition(e,l,i,f,h,0)}return e}e.exports=function(t,e){i(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../../plots/cartesian/axes\":798,\"./attributes\":660}],663:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../drawing\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},d={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function g(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",o.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var a=new Promise(function(t){var n=new Image;function a(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=a,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",a),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(a)}}function m(e){var r=n.select(this),o=i.getFromId(t,e.xref),l=i.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p[e.xanchor].offset,g=h*d[e.yanchor].offset,m=p[e.xanchor].sizing+d[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,y=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+g;switch(e.sizing){case\"fill\":m+=\" slice\";break;case\"stretch\":m=\"none\"}r.attr({x:v,y:y,width:u,height:h,preserveAspectRatio:m,opacity:e.opacity});var x=(o?o._id:\"\")+(l?l._id:\"\");a.setClipUrl(r,x?\"clip\"+s._uid+x:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),y=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),y.enter().append(\"image\"),v.exit().remove(),y.exit().remove(),v.each((function(t){g.bind(this)(t),m.bind(this)(t)})),y.each((function(t){g.bind(this)(t),m.bind(this)(t)}));var x=Object.keys(s._plots);for(r=0;r<x.length;r++){e=x[r];var b=s._plots[e];if(b.imagelayer){var _=b.imagelayer.selectAll(\"image\").data(c[e]||[]);_.enter().append(\"image\"),_.exit().remove(),_.each((function(t){g.bind(this)(t),m.bind(this)(t)}))}}}},{\"../../constants/xmlns_namespaces\":725,\"../../plots/cartesian/axes\":798,\"../drawing\":637,d3:169}],664:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":810,\"./attributes\":660,\"./convert_coords\":661,\"./defaults\":662,\"./draw\":663}],665:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:a.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":826,\"../color/attributes\":614}],666:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,textGap:40,itemGap:5}},{}],667:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,h=!1,f=\"normal\",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(h=!0,(n.traceIs(d,\"pie-like\")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(d.fill))&&(f=l.isGrouped({traceorder:f})?\"grouped+reversed\":\"reversed\"),void 0!==d.legendgroup&&\"\"!==d.legendgroup&&(f=l.isReversed({traceorder:f})?\"reversed+grouped\":\"grouped\"))}var g=a.coerce(t,e,s,\"showlegend\",h&&u>1);if(!1!==g||c.uirevision){var m=i.newContainer(e,\"legend\");if(_(\"uirevision\",e.uirevision),!1!==g){_(\"bgcolor\",e.paper_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),a.coerceFont(_,\"font\",e.font);var v,y,x,b=_(\"orientation\");\"h\"===b?(v=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(t.xaxis)?(y=1.1,x=\"bottom\"):(y=-.1,x=\"top\")):(v=1.02,y=1,x=\"auto\"),_(\"traceorder\",f),l.isGrouped(e.legend)&&_(\"tracegroupgap\"),_(\"itemsizing\"),_(\"itemclick\"),_(\"itemdoubleclick\"),_(\"x\",v),_(\"xanchor\"),_(\"y\",y),_(\"yanchor\",x),_(\"valign\"),a.noneOrAll(c,m,[\"x\",\"y\"]),_(\"title.text\")&&(_(\"title.side\",\"h\"===b?\"left\":\"top\"),a.coerceFont(_,\"title.font\",e.font))}}function _(t,e){return a.coerce(c,m,o,t,e)}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../plots/layout_attributes\":852,\"../../registry\":881,\"./attributes\":665,\"./helpers\":671}],668:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,m=d.FROM_TL,v=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,a){var i=r.data()[0][0].trace,l={event:a,node:r.node(),curveNumber:i.index,expandedIndex:i._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(i._group&&(l.group=i._group),o.traceIs(i,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout((function(){f(r,t,n)}),t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n,i=t.data()[0][0],s=i.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=r._main&&e._context.edits.legendText&&!l,d=r._maxNameLength;r.entries?n=i.text:(n=l?i.label:s.name,s._meta&&(n=a.templateString(n,s._meta)));var g=a.ensureSingle(t,\"text\",\"legendtext\");g.attr(\"text-anchor\",\"start\").call(c.font,r.font).text(f?T(n,d):n),h.positionText(g,p.textGap,0),f?g.call(h.makeEditable,{gd:e,text:n}).call(M,t,e,r).on(\"edit\",(function(n){this.text(T(n,d)).call(M,t,e,r);var s=i.trace._fullInput||{},l={};if(o.hasTransform(s,\"groupby\")){var c=o.getTransformIndices(s,\"groupby\"),h=c[c.length-1],f=a.keyedContainer(s,\"transforms[\"+h+\"].styles\",\"target\",\"value.name\");f.set(i.trace._group,n),l=f.constructUpdate()}else l.name=n;return o.call(\"_guiRestyle\",e,l,u)})):M(g,t,e,r)}function T(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function k(t,e){var r,i=e._context.doubleClickDelay,o=1,s=a.ensureSingle(t,\"rect\",\"legendtoggle\",(function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")}));s.on(\"mousedown\",(function(){(r=(new Date).getTime())-e._legendMouseDownTime<i?o+=1:(o=1,e._legendMouseDownTime=r)})),s.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>i&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}}))}function M(t,e,r,n){n._main||t.attr(\"data-notex\",!0),h.convertToTspans(t,r,(function(){!function(t,e,r){var n=t.data()[0][0];if(r._main&&n&&!n.trace.showlegend)return void t.remove();var a=t.select(\"g[class*=math-group]\"),i=a.node();r||(r=e._fullLayout.legend);var o,s,l=r.borderwidth,u=(n?r:r.title).font.size*g;if(i){var f=c.bBox(i);o=f.height,s=f.width,n?c.setTranslate(a,0,.25*o):c.setTranslate(a,l,.75*o+l)}else{var d=t.select(n?\".legendtext\":\".legendtitletext\"),m=h.lineCount(d),v=d.node();o=u*m,s=v?c.bBox(v).width:0;var y=u*((m-1)/2-.3);n?h.positionText(d,p.textGap,-y):h.positionText(d,p.titlePad+l,u+l)}n?(n.lineHeight=u,n.height=Math.max(o,16)+3,n.width=s):(r._titleWidth=s,r._titleHeight=o)}(e,r,n)}))}function A(t){return a.isRightAnchor(t)?\"right\":a.isCenterAnchor(t)?\"center\":\"left\"}function S(t){return a.isBottomAnchor(t)?\"bottom\":a.isMiddleAnchor(t)?\"middle\":\"top\"}e.exports=function(t,e){var r,s=t._fullLayout,h=\"legend\"+s._uid;if(e?(r=e.layer,h+=\"-hover\"):((e=s.legend||{})._main=!0,r=s._infolayer),r){var f;if(t._legendMouseDownTime||(t._legendMouseDownTime=0),e._main){if(!t.calcdata)return;f=s.showlegend&&y(t.calcdata,e)}else{if(!e.entries)return;f=y(e.entries,e)}var d=s.hiddenlabels||[];if(e._main&&(!s.showlegend||!f.length))return r.selectAll(\".legend\").remove(),s._topdefs.select(\"#\"+h).remove(),i.autoMargin(t,\"legend\");var g=a.ensureSingle(r,\"g\",\"legend\",(function(t){e._main&&t.attr(\"pointer-events\",\"all\")})),T=a.ensureSingleById(s._topdefs,\"clipPath\",h,(function(t){t.append(\"rect\")})),E=a.ensureSingle(g,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));E.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\");var C=a.ensureSingle(g,\"g\",\"scrollbox\"),L=e.title;if(e._titleWidth=0,e._titleHeight=0,L.text){var P=a.ensureSingle(C,\"text\",\"legendtitletext\");P.attr(\"text-anchor\",\"start\").call(c.font,L.font).text(L.text),M(P,C,t,e)}else C.selectAll(\".legendtitletext\").remove();var I=a.ensureSingle(g,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),z=C.selectAll(\"g.groups\").data(f);z.enter().append(\"g\").attr(\"class\",\"groups\"),z.exit().remove();var O=z.selectAll(\"g.traces\").data(a.identity);O.enter().append(\"g\").attr(\"class\",\"traces\"),O.exit().remove(),O.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==d.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(w,t,e)})).call(x,t,e).each((function(){e._main&&n.select(this).call(k,t)})),a.syncOrAsync([i.previousPromises,function(){return function(t,e,r,a){var i=t._fullLayout;a||(a=i.legend);var o=i._size,s=b.isVertical(a),l=b.isGrouped(a),u=a.borderwidth,h=2*u,f=p.textGap,d=p.itemGap,g=2*(u+d),m=S(a),v=a.y<0||0===a.y&&\"top\"===m,y=a.y>1||1===a.y&&\"bottom\"===m;a._maxHeight=Math.max(v||y?i.height/2:o.h,30);var x=0;a._width=0,a._height=0;var _=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight));return[e,r]}(a);if(s)r.each((function(t){var e=t[0].height;c.setTranslate(this,u+_[0],u+_[1]+a._height+e/2+d),a._height+=e,a._width=Math.max(a._width,t[0].width)})),x=f+a._width,a._width+=d+f+h,a._height+=g,l&&(e.each((function(t,e){c.setTranslate(this,0,e*a.tracegroupgap)})),a._height+=(a._lgroupsLength-1)*a.tracegroupgap);else{var w=A(a),T=a.x<0||0===a.x&&\"right\"===w,k=a.x>1||1===a.x&&\"left\"===w,M=y||v,E=i.width/2;a._maxWidth=Math.max(T?M&&\"left\"===w?o.l+o.w:E:k?M&&\"right\"===w?o.r+o.w:E:o.w,2*f);var C=0,L=0;r.each((function(t){var e=t[0].width+f;C=Math.max(C,e),L+=e})),x=null;var P=0;if(l){var I=0,z=0,O=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=r[0].height;c.setTranslate(this,_[0],_[1]+u+d+n/2+e),e+=n,t=Math.max(t,f+r[0].width)})),I=Math.max(I,e);var r=t+d;r+u+z>a._maxWidth&&(P=Math.max(P,z),z=0,O+=I+a.tracegroupgap,I=e),c.setTranslate(this,z,O),z+=r})),a._width=Math.max(P,z)+u,a._height=O+I+g}else{var D=r.size(),R=L+h+(D-1)*d<a._maxWidth,F=0,B=0,N=0,j=0;r.each((function(t){var e=t[0].height,r=f+t[0].width,n=(R?r:C)+d;n+u+B-d>=a._maxWidth&&(P=Math.max(P,j),B=0,N+=F,a._height+=F,F=0),c.setTranslate(this,_[0]+u+B,_[1]+u+N+e/2+d),j=B+r+d,B+=n,F=Math.max(F,e)})),R?(a._width=B+h,a._height=F+g):(a._width=Math.max(P,j)+h,a._height+=F+g)}}a._width=Math.ceil(Math.max(a._width+_[0],a._titleWidth+2*(u+p.titlePad))),a._height=Math.ceil(Math.max(a._height+_[1],a._titleHeight+2*(u+p.itemGap))),a._effHeight=Math.min(a._height,a._maxHeight);var U=t._context.edits,V=U.legendText||U.legendPosition;r.each((function(t){var e=n.select(this).select(\".legendtoggle\"),r=t[0].height,a=V?f:x||f+t[0].width;s||(a+=d/2),c.setRect(e,0,-r/2,a,r)}))}(t,z,O,e)},function(){if(!e._main||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return i.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*m[r],r:e._width*v[r],b:e._effHeight*v[n],t:e._effHeight*m[n]})}(t)){var u,f,d,y,x=s._size,b=e.borderwidth,w=x.l+x.w*e.x-m[A(e)]*e._width,k=x.t+x.h*(1-e.y)-m[S(e)]*e._effHeight;if(e._main&&s.margin.autoexpand){var M=w,L=k;w=a.constrain(w,0,s.width-e._width),k=a.constrain(k,0,s.height-e._effHeight),w!==M&&a.log(\"Constrain legend.x to make legend fit inside graph\"),k!==L&&a.log(\"Constrain legend.y to make legend fit inside graph\")}if(e._main&&c.setTranslate(g,w,k),I.on(\".drag\",null),g.on(\"wheel\",null),!e._main||e._height<=e._maxHeight||t._context.staticPlot){var P=e._effHeight;e._main||(P=e._height),E.attr({width:e._width-b,height:P-b,x:b/2,y:b/2}),c.setTranslate(C,0,0),T.select(\"rect\").attr({width:e._width-2*b,height:P-2*b,x:b,y:b}),c.setClipUrl(C,h,t),c.setRect(I,0,0,0,0),delete e._scrollY}else{var z,O,D,R=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),F=e._effHeight-R-2*p.scrollBarMargin,B=e._height-e._effHeight,N=F/B,j=Math.min(e._scrollY||0,B);E.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),T.select(\"rect\").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+j}),c.setClipUrl(C,h,t),q(j,R,N),g.on(\"wheel\",(function(){q(j=a.constrain(e._scrollY+n.event.deltaY/F*B,0,B),R,N),0!==j&&j!==B&&n.event.preventDefault()}));var U=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;z=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,D=j})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(O=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,q(j=function(t,e,r){var n=(r-e)/N+t;return a.constrain(n,0,B)}(D,z,O),R,N))}));I.call(U);var V=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(z=t.changedTouches[0].clientY,D=j)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(O=t.changedTouches[0].clientY,q(j=function(t,e,r){var n=(e-r)/N+t;return a.constrain(n,0,B)}(D,z,O),R,N))}));C.call(V)}if(t._context.edits.legendPosition)g.classed(\"cursor-move\",!0),l.init({element:g.node(),gd:t,prepFn:function(){var t=c.getTranslate(g);d=t.x,y=t.y},moveFn:function(t,r){var n=d+t,a=y+r;c.setTranslate(g,n,a),u=l.align(n,0,x.l,x.l+x.w,e.xanchor),f=l.align(a,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==u&&void 0!==f&&o.call(\"_guiRelayout\",t,{\"legend.x\":u,\"legend.y\":f})},clickFn:function(e,n){var a=r.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom}));a.size()>0&&_(t,g,a,e,n)}})}function q(r,n,a){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(C,0,-r),c.setRect(I,e._width,p.scrollBarMargin+r*a,p.scrollBarWidth,n),T.select(\"rect\").attr(\"y\",b+r)}}],t)}}},{\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/events\":738,\"../../lib/svg_text_utils\":773,\"../../plots/plots\":861,\"../../registry\":881,\"../color\":615,\"../dragelement\":634,\"../drawing\":637,\"./constants\":666,\"./get_legend_data\":669,\"./handle_click\":670,\"./helpers\":671,\"./style\":673,d3:169}],669:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"./helpers\");e.exports=function(t,e){var r,i,o={},s=[],l=!1,c={},u=0,h=0,f=e._main;function p(t,r){if(\"\"!==t&&a.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var d=t[r],g=d[0],m=g.trace,v=m.legendgroup;if(!f||m.visible&&m.showlegend)if(n.traceIs(m,\"pie-like\"))for(c[v]||(c[v]={}),i=0;i<d.length;i++){var y=d[i].label;c[v][y]||(p(v,{label:y,color:d[i].color,i:d[i].i,trace:m,pts:d[i].pts}),c[v][y]=!0,h=Math.max(h,(y||\"\").length))}else p(v,g),h=Math.max(h,(m.name||\"\").length)}if(!s.length)return[];var x,b,_=s.length;if(l&&a.isGrouped(e))for(b=new Array(_),r=0;r<_;r++)x=o[s[r]],b[r]=a.isReversed(e)?x.reverse():x;else{for(b=[new Array(_)],r=0;r<_;r++)x=o[s[r]][0],b[0][a.isReversed(e)?_-r-1:r]=x;_=1}return e._lgroupsLength=_,e._maxNameLength=h,b}},{\"../../registry\":881,\"./helpers\":671}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\"),i=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&i&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),i=!1):i=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],m=t.data()[0][0],v=e._fullData,y=m.trace,x=y.legendgroup,b={},_=[],w=[],T=[];if(a.traceIs(y,\"pie-like\")){var k=m.label,M=g.indexOf(k);\"toggle\"===s?-1===M?g.push(k):g.splice(M,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach((function(t){k!==t.label&&g.push(t.label)})),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===M&&(g=[])),a.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var A,S=x&&x.length,E=[];if(S)for(u=0;u<v.length;u++)(A=v[u]).visible&&A.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<v.length;u++)!1!==v[u].visible&&v[u].legendgroup===x&&B(v[u],C);else B(y,C)}else if(\"toggleothers\"===s){var L,P,I,z,O=!0;for(u=0;u<v.length;u++)if(L=v[u]===y,I=!0!==v[u].showlegend,!(L||I||(P=S&&v[u].legendgroup===x)||!0!==v[u].visible||a.traceIs(v[u],\"notLegendIsolatable\"))){O=!1;break}for(u=0;u<v.length;u++)if(!1!==v[u].visible&&!a.traceIs(v[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":B(v[u],!0);break;case!0:z=!!O||\"legendonly\",L=v[u]===y,I=!0!==v[u].showlegend&&!v[u].legendgroup,P=L||S&&v[u].legendgroup===x,B(v[u],!(!P&&!I)||z)}}for(u=0;u<w.length;u++)if(f=w[u]){var D=f.constructUpdate(),R=Object.keys(D);for(h=0;h<R.length;h++)p=R[h],(b[p]=b[p]||[])[T[u]]=D[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);a.call(\"_guiRestyle\",e,b,_)}}}function F(t,e,r){var n=_.indexOf(t),a=b[e];return a||(a=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),a[n]=r,n}function B(t,e){var r=t._fullInput;if(a.hasTransform(r,\"groupby\")){var i=w[r.index];if(!i){var o=a.getTransformIndices(r,\"groupby\"),s=o[o.length-1];i=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=i}var l=i.get(t._group);void 0===l&&(l=!0),!1!==l&&i.set(t._group,e),T[r.index]=F(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,\"visible\",c)}}}},{\"../../lib\":749,\"../../registry\":881}],671:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],672:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":665,\"./defaults\":667,\"./draw\":668,\"./style\":673}],673:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../colorscale/helpers\").extractOpts,c=t(\"../../traces/scatter/subtypes\"),u=t(\"../../traces/pie/style_one\"),h=t(\"../../traces/pie/helpers\").castOption;function f(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}e.exports=function(t,e,r){var p=e._fullLayout;r||(r=p.legend);var d=\"constant\"===r.itemsizing,g=function(t,e,r,n){var a;if(t+1)a=t;else{if(!(e&&e.width>0))return 0;a=e.width}return d?n:Math.min(a,r)};function m(t,e,r){var i=t[0].trace,o=i.marker||{},l=o.line||{},c=r?i.visible&&i.type===r:a.traceIs(i,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each((function(t){var e=n.select(this),r=t[0],a=g(r.mlw,o.line,5,2);e.style(\"stroke-width\",a+\"px\").call(s.fill,r.mc||o.color),a&&s.stroke(e,r.mlc||l.color)}))}function v(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:a.traceIs(s,r),c=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(c.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),c.exit().remove(),c.size()){var f=(s.marker||{}).line,p=g(h(f.width,o.pts),f,5,2),d=i.minExtend(s,{marker:{line:{width:p}}});d.marker.line.color=f.color;var m=i.minExtend(o,{trace:d});u(c,m,d)}}t.each((function(t){var e=n.select(this),a=i.ensureSingle(e,\"g\",\"layers\");a.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));a.attr(\"transform\",\"translate(0,\"+c+\")\")}else a.attr(\"transform\",null);a.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),a.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=a.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,a=t[0].trace,c=[];if(a.visible)switch(a.type){case\"histogram2d\":case\"heatmap\":c=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":c=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":c=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":c=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":c=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":c=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":c=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":c=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":c=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(c);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,c){var u,h=n.select(this),p=l(a),d=p.colorscale,g=p.reversescale;if(d){if(!r){var m=d.length;u=0===c?d[g?m-1:0][1]:1===c?d[g?0:m-1][1]:d[Math.floor((m-1)/2)][1]}}else{var v=a.vertexcolor||a.facecolor||a.color;u=i.isArrayOrTypedArray(v)?v[c]||v[0]:v}h.attr(\"d\",t[0]),u?h.call(s.fill,u):h.call((function(t){if(t.size()){var n=\"legendfill-\"+a.uid;o.gradient(t,e,n,f(g,\"radial\"===r),d,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var a=t[0].trace[t[0].dir].marker;return t[0].mc=a.color,t[0].mlw=a.line.width,t[0].mlc=a.line.color,m(t,this,\"waterfall\")}var i=[];e.visible&&r&&(i=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(i);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),a=e[t[0]].marker,i=g(void 0,a.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",i+\"px\").call(s.fill,a.color),i&&r.call(s.stroke,a.line.color)}))})).each((function(t){m(t,this,\"funnel\")})).each((function(t){m(t,this)})).each((function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&a.traceIs(r,\"box-violin\")?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var a=g(void 0,r.line,5,2);t.style(\"stroke-width\",a+\"px\").call(s.fill,r.fillcolor),a&&s.stroke(t,r.line.color)}else{var c=i.minExtend(r,{marker:{size:d?12:i.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}}))})).each((function(t){v(t,this,\"funnelarea\")})).each((function(t){v(t,this,\"pie\")})).each((function(t){var r,a,s=t[0],u=s.trace,h=u.visible&&u.fill&&\"none\"!==u.fill,p=c.hasLines(u),d=u.contours,m=!1,v=!1,y=l(u),x=y.colorscale,b=y.reversescale;if(d){var _=d.coloring;\"lines\"===_?m=!0:p=\"none\"===_||\"heatmap\"===_||d.showlines,\"constraint\"===d.type?h=\"=\"!==d._operation:\"fill\"!==_&&\"heatmap\"!==_||(v=!0)}var w=c.hasMarkers(u)||c.hasText(u),T=h||v,k=p||m,M=w||!T?\"M5,0\":k?\"M5,-2\":\"M5,-3\",A=n.select(this),S=A.select(\".legendfill\").selectAll(\"path\").data(h||v?[t]:[]);if(S.enter().append(\"path\").classed(\"js-fill\",!0),S.exit().remove(),S.attr(\"d\",M+\"h30v6h-30z\").call(h?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+u.uid;o.gradient(t,e,r,f(b),x,\"fill\")}}),p||m){var E=g(void 0,u.line,10,5);a=i.minExtend(u,{line:{width:E}}),r=[i.minExtend(s,{trace:a})]}var C=A.select(\".legendlines\").selectAll(\"path\").data(p||m?[r]:[]);C.enter().append(\"path\").classed(\"js-line\",!0),C.exit().remove(),C.attr(\"d\",M+(m?\"l30,0.0001\":\"h30\")).call(p?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+u.uid;o.lineGroupStyle(t),o.gradient(t,e,r,f(b),x,\"stroke\")}})})).each((function(t){var r,a,s=t[0],l=s.trace,u=c.hasMarkers(l),h=c.hasText(l),f=c.hasLines(l);function p(t,e,r,n){var a=i.nestedProperty(l,t).get(),o=i.isArrayOrTypedArray(a)&&e?e(a):a;if(d&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function g(t){return s._distinct&&s.index&&t[s.index]?t[s.index]:t[0]}if(u||h||f){var m={},v={};if(u){m.mc=p(\"marker.color\",g),m.mx=p(\"marker.symbol\",g),m.mo=p(\"marker.opacity\",i.mean,[.2,1]),m.mlc=p(\"marker.line.color\",g),m.mlw=p(\"marker.line.width\",i.mean,[0,5],2),v.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var y=p(\"marker.size\",i.mean,[2,16],12);m.ms=y,v.marker.size=y}f&&(v.line={width:p(\"line.width\",g,[0,10],5)}),h&&(m.tx=\"Aa\",m.tp=p(\"textposition\",g),m.ts=10,m.tc=p(\"textfont.color\",g),m.tf=p(\"textfont.family\",g)),r=[i.minExtend(s,m)],(a=i.minExtend(l,v)).selectedpoints=null,a.texttemplate=null}var x=n.select(this).select(\"g.legendpoints\"),b=x.selectAll(\"path.scatterpts\").data(u?r:[]);b.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),b.exit().remove(),b.call(o.pointStyle,a,e),u&&(r[0].mrc=3);var _=x.selectAll(\"g.pointtext\").data(h?r:[]);_.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),_.exit().remove(),_.selectAll(\"text\").call(o.textPointStyle,a,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var a=n.select(this),i=e[r?\"increasing\":\"decreasing\"],o=g(void 0,i.line,5,2);a.style(\"stroke-width\",o+\"px\").call(s.fill,i.fillcolor),o&&s.stroke(a,i.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var a=n.select(this),i=e[r?\"increasing\":\"decreasing\"],l=g(void 0,i.line,5,2);a.style(\"fill\",\"none\").call(o.dashLine,i.line.dash,l),l&&s.stroke(a,i.line.color)}))}))}},{\"../../lib\":749,\"../../registry\":881,\"../../traces/pie/helpers\":1135,\"../../traces/pie/style_one\":1141,\"../../traces/scatter/subtypes\":1181,\"../color\":615,\"../colorscale/helpers\":626,\"../drawing\":637,d3:169}],674:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../plots/plots\"),i=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../fonts/ploticon\"),s=t(\"../shapes/draw\").eraseActiveShape,l=t(\"../../lib\"),c=l._,u=e.exports={};function h(t,e){var r,a,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=i.list(t,null,!0),f=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,m=(1-d)/2;for(a=0;a<h.length;a++)if(!(r=h[a]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var v=r._rangeInitial.slice();u[p+\".range[0]\"]=v[0],u[p+\".range[1]\"]=v[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+m*y[1],g*y[1]+m*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=f,n.call(\"_guiRelayout\",t,u)}function f(t,e){for(var r=e.currentTarget,a=r.getAttribute(\"data-attr\"),i=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=a.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=i;var u=\"pan\"===i?i:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),a=\"resetLastSave\"===r,i=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,h=s[c],f=h+\".camera\",p=h+\".aspectratio\",d=h+\".aspectmode\",g=o[h]._scene;a?(l[f+\".up\"]=g.viewInitial.up,l[f+\".eye\"]=g.viewInitial.eye,l[f+\".center\"]=g.viewInitial.center,u=!0):i&&(l[f+\".up\"]=null,l[f+\".eye\"]=null,l[f+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=g.viewInitial.aspectratio.x,l[p+\".y\"]=g.viewInitial.aspectratio.y,l[p+\".z\"]=g.viewInitial.aspectratio.z,l[d]=g.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,a=t._fullLayout,i=a._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<i.length;c++){var u=i[c],h=a[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function g(t,e){for(var r=e.currentTarget,a=r.getAttribute(\"data-attr\"),i=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===a){var h=u.projection.scale,f=\"in\"===i?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}}\"reset\"===a&&x(t,\"geo\")}function m(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=m(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function y(t,e){for(var r=e.currentTarget.getAttribute(\"data-val\"),a=t._fullLayout,i=a._subplots.mapbox||[],o={},s=0;s<i.length;s++){var l=i[s],c=a[l].zoom,u=\"in\"===r?1.05*c:c/1.05;o[l+\".zoom\"]=u}n.call(\"_guiRelayout\",t,o)}function x(t,e){for(var r=t._fullLayout,a=r._subplots[e]||[],i={},o=0;o<a.length;o++)for(var s=a[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];i[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,i)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){a.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){a.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan2d={name:\"pan2d\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:h},u.select2d={name:\"select2d\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:h},u.lasso2d={name:\"lasso2d\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:h},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:h},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:h},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:h},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:h},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:h},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:h},u.zoomOut2d={name:\"zoomOut2d\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:h},u.autoScale2d={name:\"autoScale2d\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:h},u.resetScale2d={name:\"resetScale2d\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:h},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:h},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:h},u.zoom3d={name:\"zoom3d\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan3d={name:\"pan3d\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:f},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:f},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:f},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:g},u.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:g},u.resetGeo={name:\"resetGeo\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:g},u.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:v},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var a=t._fullData[r]._viewInitial;e[\"node.groups\"].push(a.node.groups.slice()),e[\"node.x\"].push(a.node.x.slice()),e[\"node.y\"].push(a.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=m(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),h(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),x(t,\"geo\"),x(t,\"mapbox\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=i.list(t,null,!0),n={},a=0;a<r.length;a++){var o=r[a];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){x(t,\"mapbox\")}},u.zoomInMapbox={name:\"zoomInMapbox\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:y},u.zoomOutMapbox={name:\"zoomOutMapbox\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:y}},{\"../../fonts/ploticon\":728,\"../../lib\":749,\"../../plots/cartesian/axis_ids\":801,\"../../plots/plots\":861,\"../../registry\":881,\"../shapes/draw\":696}],675:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":676}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../traces/scatter/subtypes\"),i=t(\"../../registry\"),o=t(\"../fx/helpers\").isUnifiedHover,s=t(\"./modebar\"),l=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,u=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var h,f=r.modeBarButtons;h=Array.isArray(f)&&f.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var a=r[n];if(\"string\"==typeof a){if(void 0===l[a])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=l[a]}}return t}(f):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context,u=s.modeBarButtonsToRemove,h=s.modeBarButtonsToAdd,f=e._has(\"cartesian\"),p=e._has(\"gl3d\"),d=e._has(\"geo\"),g=e._has(\"pie\"),m=e._has(\"funnelarea\"),v=e._has(\"gl2d\"),y=e._has(\"ternary\"),x=e._has(\"mapbox\"),b=e._has(\"polar\"),_=e._has(\"sankey\"),w=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),T=o(e.hovermode),k=[];function M(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===u.indexOf(n)&&e.push(l[n])}k.push(e)}}var A=[\"toImage\"];s.showEditInChartStudio?A.push(\"editInChartStudio\"):s.showSendToCloud&&A.push(\"sendDataToCloud\");M(A);var S=[],E=[],C=[],L=[];(f||v||g||m||y)+d+p+x+b>1?(E=[\"toggleHover\"],C=[\"resetViews\"]):d?(S=[\"zoomInGeo\",\"zoomOutGeo\"],E=[\"hoverClosestGeo\"],C=[\"resetGeo\"]):p?(E=[\"hoverClosest3d\"],C=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):x?(S=[\"zoomInMapbox\",\"zoomOutMapbox\"],E=[\"toggleHover\"],C=[\"resetViewMapbox\"]):v?E=[\"hoverClosestGl2d\"]:g?E=[\"hoverClosestPie\"]:_?(E=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],C=[\"resetViewSankey\"]):E=[\"toggleHover\"];f&&(E=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!i.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||T)&&(E=[]);!f&&!v||w||(S=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==C[0]&&(C=[\"resetScale2d\"]));p?L=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(f||v)&&!w||y?L=[\"zoom2d\",\"pan2d\"]:x||d?L=[\"pan2d\"]:b&&(L=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(i.traceIs(n,\"scatter-like\")?(a.hasMarkers(n)||a.hasText(n))&&(e=!0):i.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&L.push(\"select2d\",\"lasso2d\");if(Array.isArray(h)){for(var P=[],I=0;I<h.length;I++){var z=h[I];\"string\"==typeof z?-1!==c.indexOf(z)&&(e._has(\"mapbox\")||e._has(\"cartesian\"))&&L.push(z):P.push(z)}h=P}return M(L),M(S.concat(C)),M(E),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(k,h)}(t),u?u.update(t,h):e._modeBar=s(t,h)}else u&&(u.destroy(),delete e._modeBar)};var c=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"]},{\"../../plots/cartesian/axis_ids\":801,\"../../registry\":881,\"../../traces/scatter/subtypes\":1181,\"../fx/helpers\":651,\"./buttons\":674,\"./modebar\":677}],677:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,a=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",a),this._uid=a,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";i.deleteRelatedStyleRule(a),i.addRelatedStyleRule(a,s+\"#\"+a+\" .modebar-group\",\"background-color: \"+o.bgcolor),i.addRelatedStyleRule(a,\"#\"+a+\" .modebar-btn .icon path\",\"fill: \"+o.color),i.addRelatedStyleRule(a,\"#\"+a+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),i.addRelatedStyleRule(a,\"#\"+a+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var a=e.createButton(t);e.buttonElements.push(a),r.appendChild(a)})),e.element.appendChild(r)}))},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var a=t.title;void 0===a?a=t.name:\"function\"==typeof a&&(a=a(this.graphInfo)),(a||0===a)&&r.setAttribute(\"data-title\",a),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var i=t.val;if(void 0!==i&&(\"function\"==typeof i&&(i=i(this.graphInfo)),r.setAttribute(\"data-val\",i)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=a(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var i=document.createElementNS(n,\"path\");i.setAttribute(\"d\",t.path),t.transform?i.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&i.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(i)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var a=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:i.nestedProperty(e,o).get();l.classed(\"active\",c===a)}}))},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",i._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){i.removeElement(this.container.querySelector(\".modebar\")),i.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,a=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(a.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),a}},{\"../../fonts/ploticon\":728,\"../../lib\":749,d3:169,\"fast-isnumeric\":241}],678:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"../color/attributes\"),i=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:i,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:a.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":787,\"../../plots/font_attributes\":826,\"../color/attributes\":614}],679:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],680:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../color\"),i=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,a){var i=a.calendar;function o(r,a){return n.coerce(t,e,s.buttons,r,a)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!i||\"gregorian\"===i||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=i.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),a=0,i=0;i<n.length;i++){var o=e[n[i]].domain;o&&(a=Math.max(o[1],a))}return[t.domain[0],a+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var m=d(\"bgcolor\");d(\"activecolor\",a.contrast(m,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../plots/array_container_defaults\":793,\"../color\":615,\"./attributes\":678,\"./constants\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),m=t(\"./get_update_object\");function v(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call((function(t){c.convertToTspans(t,n)}))}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var a=e[n];a.rangeselector&&a.rangeselector.visible&&r.push(a)}return r}(t),v);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each((function(e){var r=n.select(this),i=m(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,i),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",(function(){t._dragged||a.call(\"_guiRelayout\",t,i)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(y,u,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(y,u,e)}))})),function(t,e,r,a,o){var u=0,h=0,m=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*f,a=Math.max(e*c.lineCount(t),16)+3;h=Math.max(h,a)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),a=t.select(\".selector-text\"),i=a.node()&&s.bBox(a.node()).width,o=r.font.size*f,l=c.lineCount(a),p=Math.max(i+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(m+u)+\",\"+m+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(a,p/2,h/2-(l-1)*o/2+3),u+=p+5}));var v=t._fullLayout._size,y=v.l+v.w*r.x,x=v.t+v.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),i.autoMargin(t,a+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)}))}},{\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axis_ids\":801,\"../../plots/plots\":861,\"../../registry\":881,\"../color\":615,\"../drawing\":637,\"./constants\":679,\"./get_update_object\":682,d3:169}],682:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,a={};if(\"all\"===e.step)a[r+\".autorange\"]=!0;else{var i=function(t,e){var r,a=t.range,i=new Date(t.r2l(a[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(i,-s));break;case\"todate\":var l=n.time[o].utc.offset(i,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=a[1];return[r,c]}(t,e);a[r+\".range[0]\"]=i[0],a[r+\".range[1]\"]=i[1]}return a}},{d3:169}],683:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":678,\"./defaults\":680,\"./draw\":681}],684:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":614}],685:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,a=t(\"../../plots/cartesian/autorange\").getAutoRange,i=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[i.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=a(t,o))}}},{\"../../plots/cartesian/autorange\":797,\"../../plots/cartesian/axis_ids\":801,\"./constants\":686}],686:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],687:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),i=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=a.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===i.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),m=n.simpleMap(g,i.id2name),v=0;v<m.length;v++){var y=m[v];u=f[y]||{},h=a.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/axis_ids\":801,\"./attributes\":684,\"./oppaxis_attributes\":691}],688:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var a=o.ensureSingle(t,\"rect\",d.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),i=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);a.attr({width:n._width+i,height:n._height+i,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function m(t,e,r,n){var a=e._fullLayout;o.ensureSingleById(a._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function v(t,e,r,a){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",(function(t){return d.rangePlotClassName+\" \"+t})).call(s.setClipUrl,a._clipId,e),f.order(),f.exit().remove(),f.each((function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=a[d],m={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:a.range.slice(),calendar:r.calendar},width:a._width,height:a._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(m.layout.xaxis.rangebreaks=r.rangebreaks),m.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(m.layout[d].rangebreaks=p.rangebreaks),i.supplyDefaults(m);var v=m._fullLayout.xaxis,y=m._fullLayout[d];v.clearCalc(),v.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:v,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var a=t[n],i=a[0].trace;i.xaxis+i.yaxis===e&&r.push(a)}return r}(c,t))}))}function y(t,e,r,n,a){(o.ensureSingle(t,\"rect\",d.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==a.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,(function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var a=o.ensureSingle(t,\"g\",d.grabberMinClassName),i=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(a,\"rect\",d.handleMinClassName,(function(t){t.attr(s)})).attr(c),o.ensureSingle(i,\"rect\",d.handleMaxClassName,(function(t){t.attr(s)})).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(a,\"rect\",d.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(i,\"rect\",d.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,i=0;i<r.length;i++){var s=r[i][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,(function(t){return t._name}));l.exit().each((function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each((function(r){var i=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),T=o.simpleMap(r.range,r.r2l);_=T[0]<T[1]?[Math.min(w[0],T[0]),Math.max(w[1],T[1])]:[Math.max(w[0],T[0]),Math.min(w[1],T[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var k=e._size,M=r.domain;s._width=k.w*(M[1]-M[0]);var A=Math.round(k.l+k.w*M[0]),S=Math.round(k.t+k.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+s._offsetShift+d.extraPad);i.attr(\"transform\",\"translate(\"+A+\",\"+S+\")\"),s._rl=o.simpleMap(s.range,r.r2l);var E=s._rl[0],C=s._rl[1],L=C-E;if(s.p2d=function(t){return t/s._width*L+E},s.d2p=function(t){return(t-E)/L*s._width},r.rangebreaks){var P=r.locateBreaks(E,C);if(P.length){var I,z,O=0;for(I=0;I<P.length;I++)O+=(z=P[I]).max-z.min;var D=s._width/(C-E-O),R=[-D*E];for(I=0;I<P.length;I++)z=P[I],R.push(R[R.length-1]-D*(z.max-z.min));for(s.d2p=function(t){for(var e=R[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.max)e=R[r+1];else if(t<n.min)break}return e+D*t},I=0;I<P.length;I++)(z=P[I]).pmin=s.d2p(z.min),z.pmax=s.d2p(z.max);s.p2d=function(t){for(var e=R[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.pmax)e=R[r+1];else if(t<n.pmin)break}return(t-e)/D}}}if(\"match\"!==u.rangemode){var F=l.r2l(u.range[0]),B=l.r2l(u.range[1])-F;s.d2pOppAxis=function(t){return(t-F)/B*s._height}}i.call(g,t,r,s).call(m,t,r,s).call(v,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,i){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();function u(){var u=n.event,h=u.target,d=u.clientX||u.touches[0].clientX,g=d-t.node().getBoundingClientRect().left,m=i.d2p(r._rl[0]),v=i.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+(t.clientX||t.touches[0].clientX)-d;switch(h){case s:x=\"ew-resize\",u=m+b,f=v+b;break;case l:x=\"col-resize\",u=m+b,f=v;break;case c:x=\"col-resize\",u=m,f=v+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}i._pixelMin=u,i._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function i(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=i(n.p2d(n._pixelMin)),l=i(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){a.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,i)}function b(){y.removeEventListener(\"mousemove\",x),y.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",x),this.removeEventListener(\"touchend\",b),o.removeElement(y)}this.addEventListener(\"touchmove\",x),this.addEventListener(\"touchend\",b),y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",b)}t.on(\"mousedown\",u),t.on(\"touchstart\",u)}(i,t,r,s),function(t,e,r,n,a,i){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==i.rangemode){var p=n._height-c(n.d2pOppAxis(a._rl[1])),g=n._height-c(n.d2pOppAxis(a._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var m=Math.round(u(h-s))-.5,v=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\")}(i,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:S+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},{\"../../lib\":749,\"../../lib/setcursor\":769,\"../../plots/cartesian\":811,\"../../plots/cartesian/axis_ids\":801,\"../../plots/plots\":861,\"../../registry\":881,\"../color\":615,\"../dragelement\":634,\"../drawing\":637,\"../titles\":710,\"./constants\":686,d3:169}],689:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../lib/svg_text_utils\"),i=t(\"./constants\"),o=t(\"../../constants/alignment\").LINE_SPACING,s=i.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,a=[];if(!t._has(\"gl2d\"))for(var i=0;i<e.length;i++){var o=e[i];if(l(o)){a.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=a},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(a.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:i.extraPad+2*n._offsetShift}}},{\"../../constants/alignment\":717,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axis_ids\":801,\"./constants\":686}],690:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},a,{yaxis:i})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":749,\"./attributes\":684,\"./calc_autorange\":685,\"./defaults\":687,\"./draw\":688,\"./helpers\":689,\"./oppaxis_attributes\":691}],691:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],692:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),a=t(\"../../traces/scatter/attributes\").line,i=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},a.color,{editType:\"arraydraw\"}),width:o({},a.width,{editType:\"calc+arraydraw\"}),dash:o({},i,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":739,\"../../plot_api/plot_template\":787,\"../../traces/scatter/attributes\":1156,\"../annotations/attributes\":598,\"../drawing/attributes\":636}],693:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,a,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?i.paramIsY:i.paramIsX):[r,a],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,a){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(i.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=a[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(i.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=a.getFromId(t,f.xref),p,d,f.path,i.paramIsX))&&(f._extremes[c._id]=a.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,m=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=a.getFromId(t,f.yref),g,m,f.path,i.paramIsY))&&(f._extremes[c._id]=a.findExtremes(c,h,l(f)))}}}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"./constants\":694,\"./helpers\":703}],694:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],695:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function i(r,a){return n.coerce(t,e,o,r,a)}if(i(\"visible\")){var l=i(\"path\"),c=i(\"type\",l?\"path\":\"rect\");\"path\"!==e.type&&delete e.path,i(\"editable\"),i(\"layer\"),i(\"opacity\"),i(\"fillcolor\"),i(\"fillrule\"),i(\"line.width\")&&(i(\"line.color\"),i(\"line.dash\"));for(var u=i(\"xsizemode\"),h=i(\"ysizemode\"),f=[\"x\",\"y\"],p=0;p<2;p++){var d,g,m,v=f[p],y=v+\"anchor\",x=\"x\"===v?u:h,b={_fullLayout:r},_=a.coerceRef(t,e,b,v,\"\",\"paper\");if(\"paper\"!==_?((d=a.getFromId(b,_))._shapeIndices.push(e._index),m=s.rangeToShapePosition(d),g=s.shapePositionToRange(d)):g=m=n.identity,\"path\"!==c){var w=v+\"0\",T=v+\"1\",k=t[w],M=t[T];t[w]=g(t[w],!0),t[T]=g(t[T],!0),\"pixel\"===x?(i(w,0),i(T,10)):(a.coercePosition(e,b,i,_,w,.25),a.coercePosition(e,b,i,_,T,.75)),e[w]=m(e[w]),e[T]=m(e[T]),t[w]=k,t[T]=M}if(\"pixel\"===x){var A=t[y];t[y]=g(t[y],!0),a.coercePosition(e,b,i,_,y,.25),e[y]=m(e[y]),t[y]=A}}\"path\"===c?i(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){i(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../../plots/cartesian/axes\":798,\"./attributes\":692,\"./helpers\":703}],696:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"./draw_newshape/helpers\").readPaths,s=t(\"./draw_newshape/display_outlines\"),l=t(\"../../plots/cartesian/handle_outline\").clearOutlineControllers,c=t(\"../color\"),u=t(\"../drawing\"),h=t(\"../../plot_api/plot_template\").arrayEditor,f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\"),g=t(\"./helpers\");function m(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var a=0;a<e.shapes.length;a++)e.shapes[a].visible&&x(t,a)}function v(t){return!!t._fullLayout._drawing}function y(t){return!t._context.edits.shapePosition}function x(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=g.makeOptionsAndPlotinfo(t,e),l=r.options,x=r.plotinfo;if(l._input&&!1!==l.visible)if(\"below\"!==l.layer)k(t._fullLayout._shapeUpperLayer);else if(\"paper\"===l.xref||\"paper\"===l.yref)k(t._fullLayout._shapeLowerLayer);else{if(x._hadPlotinfo)k((x.mainplotinfo||x).shapelayer);else k(t._fullLayout._shapeLowerLayer)}function k(r){var k=_(t,l),M={\"data-index\":e,\"fill-rule\":l.fillrule,d:k},A=l.opacity,S=l.fillcolor,E=l.line.width?l.line.color:\"rgba(0,0,0,0)\",C=l.line.width,L=l.line.dash;C||!0!==l.editable||(C=5,L=\"solid\");var P=\"Z\"!==k[k.length-1],I=y(t)&&l.editable&&t._fullLayout._activeShapeIndex===e;I&&(S=P?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,A=t._fullLayout.activeshape.opacity);var z,O=r.append(\"path\").attr(M).style(\"opacity\",A).call(c.stroke,E).call(c.fill,S).call(u.dashLine,L,C);if(b(O,t,l),(I||t._context.edits.shapePosition)&&(z=h(t.layout,\"shapes\",l)),I){O.style({cursor:\"move\"});var D={element:O.node(),plotinfo:x,gd:t,editHelpers:z,isActiveShape:!0},R=o(k,t);s(R,O,D)}else t._context.edits.shapePosition?function(t,e,r,o,s,l){var c,h,m,y,x,T,k,M,A,S,E,C,L,P,I,z,O=\"pixel\"===r.xsizemode,D=\"pixel\"===r.ysizemode,R=\"line\"===r.type,F=\"path\"===r.type,B=l.modifyItem,N=i.getFromId(t,r.xref),j=i.getFromId(t,r.yref),U=g.getDataToPixel(t,N),V=g.getDataToPixel(t,j,!0),q=g.getPixelToData(t,N),H=g.getPixelToData(t,j,!0),G=R?function(){var t=Math.max(r.line.width,10),n=s.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var a={\"fill-opacity\":\"0\"},i=Math.max(t/2,10);return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:O?U(r.xanchor)+r.x0:U(r.x0),cy:D?V(r.yanchor)-r.y0:V(r.y0),r:i}).style(a).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:O?U(r.xanchor)+r.x1:U(r.x1),cy:D?V(r.yanchor)-r.y1:V(r.y1),r:i}).style(a).classed(\"cursor-grab\",!0),n}():e,Y={element:G.node(),gd:t,prepFn:function(n){if(v(t))return;O&&(x=U(r.xanchor));D&&(T=V(r.yanchor));\"path\"===r.type?I=r.path:(c=O?r.x0:U(r.x0),h=D?r.y0:V(r.y0),m=O?r.x1:U(r.x1),y=D?r.y1:V(r.y1));c<m?(A=c,L=\"x0\",S=m,P=\"x1\"):(A=m,L=\"x1\",S=c,P=\"x0\");!D&&h<y||D&&h>y?(k=h,E=\"y0\",M=y,C=\"y1\"):(k=y,E=\"y1\",M=h,C=\"y0\");W(n),J(s,r),function(t,e,r){var n=e.xref,a=e.yref,o=i.getFromId(r,n),s=i.getFromId(r,a),l=\"\";\"paper\"===n||o.autorange||(l+=n);\"paper\"===a||s.autorange||(l+=a);u.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),Y.moveFn=\"move\"===z?Z:X,Y.altKey=n.altKey},doneFn:function(){if(v(t))return;p(e),K(s),b(e,t,r),n.call(\"_guiRelayout\",t,l.getUpdateObj())},clickFn:function(){if(v(t))return;K(s)}};function W(r){if(v(t))z=null;else if(R)z=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=Y.element.getBoundingClientRect(),a=n.right-n.left,i=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!F&&a>10&&i>10&&!r.shiftKey?f.getCursor(o/a,1-s/i):\"move\";p(e,l),z=l.split(\"-\")[0]}}function Z(n,a){if(\"path\"===r.type){var i=function(t){return t},o=i,l=i;O?B(\"xanchor\",r.xanchor=q(x+n)):(o=function(t){return q(U(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=H(T+a)):(l=function(t){return H(V(t)+a)},j&&\"date\"===j.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(I,o,l))}else O?B(\"xanchor\",r.xanchor=q(x+n)):(B(\"x0\",r.x0=q(c+n)),B(\"x1\",r.x1=q(m+n))),D?B(\"yanchor\",r.yanchor=H(T+a)):(B(\"y0\",r.y0=H(h+a)),B(\"y1\",r.y1=H(y+a)));e.attr(\"d\",_(t,r)),J(s,r)}function X(n,a){if(F){var i=function(t){return t},o=i,l=i;O?B(\"xanchor\",r.xanchor=q(x+n)):(o=function(t){return q(U(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=H(T+a)):(l=function(t){return H(V(t)+a)},j&&\"date\"===j.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(I,o,l))}else if(R){if(\"resize-over-start-point\"===z){var u=c+n,f=D?h-a:h+a;B(\"x0\",r.x0=O?u:q(u)),B(\"y0\",r.y0=D?f:H(f))}else if(\"resize-over-end-point\"===z){var p=m+n,d=D?y-a:y+a;B(\"x1\",r.x1=O?p:q(p)),B(\"y1\",r.y1=D?d:H(d))}}else{var v=function(t){return-1!==z.indexOf(t)},b=v(\"n\"),G=v(\"s\"),Y=v(\"w\"),W=v(\"e\"),Z=b?k+a:k,X=G?M+a:M,K=Y?A+n:A,Q=W?S+n:S;D&&(b&&(Z=k-a),G&&(X=M-a)),(!D&&X-Z>10||D&&Z-X>10)&&(B(E,r[E]=D?Z:H(Z)),B(C,r[C]=D?X:H(X))),Q-K>10&&(B(L,r[L]=O?K:q(K)),B(P,r[P]=O?Q:q(Q)))}e.attr(\"d\",_(t,r)),J(s,r)}function J(t,e){(O||D)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var i=U(O?e.xanchor:a.midRange(r?[e.x0,e.x1]:g.extractPathCoords(e.path,d.paramIsX))),o=V(D?e.yanchor:a.midRange(r?[e.y0,e.y1]:g.extractPathCoords(e.path,d.paramIsY)));if(i=g.roundPositionForSharpStrokeRendering(i,1),o=g.roundPositionForSharpStrokeRendering(o,1),O&&D){var s=\"M\"+(i-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(O){var l=\"M\"+(i-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(i-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function K(t){t.selectAll(\".visual-cue\").remove()}f.init(Y),G.node().onmousemove=W}(t,O,l,e,r,z):!0===l.editable&&O.style(\"pointer-events\",P||c.opacity(S)*A<=.5?\"stroke\":\"all\");O.node().addEventListener(\"click\",(function(){return function(t,e){if(!y(t))return;var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void T(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=T,m(t)}}(t,O)}))}}function b(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");u.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function _(t,e){var r,n,o,s,l,c,u,h,f=e.type,p=i.getFromId(t,e.xref),m=i.getFromId(t,e.yref),v=t._fullLayout._size;if(p?(r=g.shapePositionToRange(p),n=function(t){return p._offset+p.r2p(r(t,!0))}):n=function(t){return v.l+v.w*t},m?(o=g.shapePositionToRange(m),s=function(t){return m._offset+m.r2p(o(t,!0))}):s=function(t){return v.t+v.h*(1-t)},\"path\"===f)return p&&\"date\"===p.type&&(n=g.decodeDate(n)),m&&\"date\"===m.type&&(s=g.decodeDate(s)),function(t,e,r){var n=t.path,i=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(d.segmentRE,(function(t){var n=0,c=t.charAt(0),u=d.paramIsX[c],h=d.paramIsY[c],f=d.numParams[c],p=t.substr(1).replace(d.paramRE,(function(t){return u[n]?t=\"pixel\"===i?e(s)+Number(t):e(t):h[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>f&&(t=\"X\"),t}));return n>f&&(p=p.replace(/[\\s,]*X.*/,\"\"),a.log(\"Ignoring extra params in segment \"+t)),c+p}))}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,h=x-e.y1}else u=s(e.y0),h=s(e.y1);if(\"line\"===f)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+h;if(\"rect\"===f)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+h+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+h)/2,w=Math.abs(b-l),T=Math.abs(_-u),k=\"A\"+w+\",\"+T,M=b+w+\",\"+_;return\"M\"+M+k+\" 0 1,1 \"+(b+\",\"+(_-T))+k+\" 0 0,1 \"+M+\"Z\"}function w(t,e,r){return t.replace(d.segmentRE,(function(t){var n=0,a=t.charAt(0),i=d.paramIsX[a],o=d.paramIsY[a],s=d.numParams[a];return a+t.substr(1).replace(d.paramRE,(function(t){return n>=s||(i[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function T(t){y(t)&&(t._fullLayout._activeShapeIndex>=0&&(l(t),delete t._fullLayout._activeShapeIndex,m(t)))}e.exports={draw:m,drawOne:x,eraseActiveShape:function(t){if(!y(t))return;l(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var a=[],i=0;i<r.length;i++)i!==e&&a.push(r[i]);delete t._fullLayout._activeShapeIndex,n.call(\"_guiRelayout\",t,{shapes:a})}}}},{\"../../lib\":749,\"../../lib/setcursor\":769,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/handle_outline\":808,\"../../registry\":881,\"../color\":615,\"../dragelement\":634,\"../drawing\":637,\"./constants\":694,\"./draw_newshape/display_outlines\":700,\"./draw_newshape/helpers\":701,\"./helpers\":703}],697:[function(t,e,r){\"use strict\";var n=t(\"../../drawing/attributes\").dash,a=t(\"../../../lib/extend\").extendFlat;e.exports={newshape:{line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:0,dflt:4,editType:\"none\"},dash:a({},n,{dflt:\"solid\",editType:\"none\"}),editType:\"none\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"none\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"none\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\",editType:\"none\"},editType:\"none\"},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},{\"../../../lib/extend\":739,\"../../drawing/attributes\":636}],698:[function(t,e,r){\"use strict\";e.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},{}],699:[function(t,e,r){\"use strict\";var n=t(\"../../color\");e.exports=function(t,e,r){if(r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var a=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(a)),r(\"newshape.line.dash\")}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},{\"../../color\":615}],700:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement\"),a=t(\"../../dragelement/helpers\").drawMode,i=t(\"../../../registry\"),o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,h=t(\"../../../plots/cartesian/handle_outline\").clearOutlineControllers,f=t(\"./helpers\"),p=f.pointsShapeRectangle,d=f.pointsShapeEllipse,g=f.writePaths,m=t(\"./newshapes\");e.exports=function t(e,r,o,f){f||(f=0);var v=o.gd;function y(){t(e,r,o,f++),d(e[0])&&x({redrawing:!0})}function x(t){o.isActiveShape=!1;var e=m(r,o);Object.keys(e).length&&i.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",v,e)}var b,_,w,T,k,M=o.isActiveShape,A=v._fullLayout._zoomlayer,S=o.dragmode;(a(S)?v._fullLayout._drawing=!0:v._fullLayout._activeShapeIndex>=0&&h(v),r.attr(\"d\",g(e)),M&&!f)&&(k=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var a=0;a<n.length;a++){t[r][a]=[];for(var i=0;i<n[a].length;i++)t[r][a][i]=n[a][i]}}return t}([],e),function(t){b=[];for(var r=0;r<e.length;r++){var a=e[r],i=!p(a)&&d(a);b[r]=[];for(var o=0;o<a.length;o++)if(\"Z\"!==a[o][0]&&(!i||o===s||o===l||o===c||o===u)){var h=a[o][1],f=a[o][2],g=t.append(\"circle\").classed(\"cursor-grab\",!0).attr(\"data-i\",r).attr(\"data-j\",o).attr(\"cx\",h).attr(\"cy\",f).attr(\"r\",4).style({\"mix-blend-mode\":\"luminosity\",fill:\"black\",stroke:\"white\",\"stroke-width\":1});b[r][o]={element:g.node(),gd:v,prepFn:E,doneFn:L,clickFn:P},n.init(b[r][o])}}}(A.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(_=[],!e.length)return;_[0]={element:r[0][0],gd:v,prepFn:z,doneFn:O},n.init(_[0])}());function E(t){w=+t.srcElement.getAttribute(\"data-i\"),T=+t.srcElement.getAttribute(\"data-j\"),b[w][T].moveFn=C}function C(t,r){if(e.length){var n=k[w][T][1],a=k[w][T][2],i=e[w],o=i.length;if(p(i)){for(var s=0;s<o;s++)if(s!==T){var l=i[s];l[1]===i[T][1]&&(l[1]=n+t),l[2]===i[T][2]&&(l[2]=a+r)}if(i[T][1]=n+t,i[T][2]=a+r,!p(i))for(var c=0;c<o;c++)for(var u=0;u<i[c].length;u++)i[c][u]=k[w][c][u]}else i[T][1]=n+t,i[T][2]=a+r;y()}}function L(){x()}function P(t,r){if(2===t){w=+r.srcElement.getAttribute(\"data-i\"),T=+r.srcElement.getAttribute(\"data-j\");var n=e[w];p(n)||d(n)||function(){if(e.length&&e[w]&&e[w].length){for(var t=[],r=0;r<e[w].length;r++)r!==T&&t.push(e[w][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===T&&(t[0][0]=\"M\"),e[w]=t,y(),x())}}()}}function I(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var a=0;a<e[n].length;a++)for(var i=0;i+2<e[n][a].length;i+=2)e[n][a][i+1]=k[n][a][i+1]+t,e[n][a][i+2]=k[n][a][i+2]+r}(t,r),y()}function z(t){(w=+t.srcElement.getAttribute(\"data-i\"))||(w=0),_[w].moveFn=I}function O(){x()}}},{\"../../../plots/cartesian/handle_outline\":808,\"../../../registry\":881,\"../../dragelement\":634,\"../../dragelement/helpers\":633,\"./constants\":698,\"./helpers\":701,\"./newshapes\":702}],701:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),a=t(\"./constants\"),i=a.CIRCLE_SIDES,o=a.SQRT2,s=t(\"../../../plots/cartesian/helpers\"),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],h=[0,3,4,1,2];function f(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}r.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var a=t[n].length,i=0;i<a;i++){var o=t[n][i][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][i].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=h[l]:\"C\"===o&&(c=u[l]),r+=t[n][i][c],l>0&&l<s-1&&(r+=\",\")}}return r},r.readPaths=function(t,e,r,a){var o,s,u,h=n(t),f=[],p=-1,d=0,g=0,m=function(){s=d,u=g};m();for(var v=0;v<h.length;v++){var y,x,b,_,w=[],T=h[v][0],k=T;switch(T){case\"M\":p++,f[p]=[],d=+h[v][1],g=+h[v][2],w.push([k,d,g]),m();break;case\"Q\":case\"S\":y=+h[v][1],b=+h[v][2],d=+h[v][3],g=+h[v][4],w.push([k,d,g,y,b]);break;case\"C\":y=+h[v][1],b=+h[v][2],x=+h[v][3],_=+h[v][4],d=+h[v][5],g=+h[v][6],w.push([k,d,g,y,b,x,_]);break;case\"T\":case\"L\":d=+h[v][1],g=+h[v][2],w.push([k,d,g]);break;case\"H\":k=\"L\",d=+h[v][1],w.push([k,d,g]);break;case\"V\":k=\"L\",g=+h[v][1],w.push([k,d,g]);break;case\"A\":k=\"L\";var M=+h[v][1],A=+h[v][2];+h[v][4]||(M=-M,A=-A);var S=d-M,E=g;for(o=1;o<=i/2;o++){var C=2*Math.PI*o/i;w.push([k,S+M*Math.cos(C),E+A*Math.sin(C)])}break;case\"Z\":d===s&&g===u||(d=s,g=u,w.push([k,d,g]))}for(var L=(r||{}).domain,P=e._fullLayout._size,I=r&&\"pixel\"===r.xsizemode,z=r&&\"pixel\"===r.ysizemode,O=!1===a,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,g=F,r&&(r.xaxis&&r.xaxis.p2r?(O&&(R-=r.xaxis._offset),R=I?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(O&&(R-=P.l),L?R=L.x[0]+R/P.w:R/=P.w),r.yaxis&&r.yaxis.p2r?(O&&(F-=r.yaxis._offset),F=z?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(O&&(F-=P.t),F=L?L.y[1]-F/P.h:1-F/P.h)),w[D][o+1]=R,w[D][o+2]=F)}f[p].push(w[D].slice())}}return f},r.pointsShapeRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!f(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!f(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!f(t[0][1],t[1][1])&&!f(t[0][1],t[3][1]))&&!!(p(t[0],t[1])*p(t[0],t[3]))},r.pointsShapeEllipse=function(t){var e=t.length;if(e!==i+1)return!1;e=i;for(var r=0;r<e;r++){var n=(2*e-r)%e,a=(e/2+n)%e,o=(e/2+r)%e;if(!f(p(t[r],t[o]),p(t[n],t[a])))return!1}return!0},r.handleEllipse=function(t,e,n){if(!t)return[e,n];var a=r.ellipseOver({x0:e[0],y0:e[1],x1:n[0],y1:n[1]}),s=(a.x1+a.x0)/2,l=(a.y1+a.y0)/2,c=(a.x1-a.x0)/2,u=(a.y1-a.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var h=[],f=0;f<i;f++){var p=2*f*Math.PI/i;h.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return h},r.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,a=t.y1,i=n-e,s=a-r,l=((e-=i)+n)/2,c=((r-=s)+a)/2;return{x0:l-(i*=o),y0:c-(s*=o),x1:l+i,y1:c+s}}},{\"../../../plots/cartesian/helpers\":809,\"./constants\":698,\"parse-svg-path\":479}],702:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement/helpers\"),a=n.drawMode,i=n.openMode,o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,h=o.cos45,f=o.sin45,p=t(\"../../../plots/cartesian/helpers\"),d=p.p2r,g=p.r2p,m=t(\"../../../plots/cartesian/handle_outline\").clearSelect,v=t(\"./helpers\"),y=v.readPaths,x=v.writePaths,b=v.ellipseOver;e.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var n=r.getAttribute(\"d\"),o=e.gd,p=o._fullLayout.newshape,v=e.plotinfo,_=v.xaxis,w=v.yaxis,T=!!v.domain||!v.xaxis,k=!!v.domain||!v.yaxis,M=e.isActiveShape,A=e.dragmode,S=(o.layout||{}).shapes||[];if(!a(A)&&void 0!==M){var E=o._fullLayout._activeShapeIndex;if(E<S.length)switch(o._fullLayout.shapes[E].type){case\"rect\":A=\"drawrect\";break;case\"circle\":A=\"drawcircle\";break;case\"line\":A=\"drawline\";break;case\"path\":var C=S[E].path||\"\";A=\"Z\"===C[C.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var L,P=i(A),I=y(n,o,v,M),z={editable:!0,xref:T?\"paper\":_._id,yref:k?\"paper\":w._id,layer:p.layer,opacity:p.opacity,line:{color:p.line.color,width:p.line.width,dash:p.line.dash}};if(P||(z.fillcolor=p.fillcolor,z.fillrule=p.fillrule),1===I.length&&(L=I[0]),L&&\"drawrect\"===A)z.type=\"rect\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[2][1],z.y1=L[2][2];else if(L&&\"drawline\"===A)z.type=\"line\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[1][1],z.y1=L[1][2];else if(L&&\"drawcircle\"===A){z.type=\"circle\";var O=L[s][1],D=L[l][1],R=L[c][1],F=L[u][1],B=L[s][2],N=L[l][2],j=L[c][2],U=L[u][2],V=v.xaxis&&(\"date\"===v.xaxis.type||\"log\"===v.xaxis.type),q=v.yaxis&&(\"date\"===v.yaxis.type||\"log\"===v.yaxis.type);V&&(O=g(v.xaxis,O),D=g(v.xaxis,D),R=g(v.xaxis,R),F=g(v.xaxis,F)),q&&(B=g(v.yaxis,B),N=g(v.yaxis,N),j=g(v.yaxis,j),U=g(v.yaxis,U));var H=(D+F)/2,G=(B+j)/2,Y=b({x0:H,y0:G,x1:H+(F-D+R-O)/2*h,y1:G+(U-N+j-B)/2*f});V&&(Y.x0=d(v.xaxis,Y.x0),Y.x1=d(v.xaxis,Y.x1)),q&&(Y.y0=d(v.yaxis,Y.y0),Y.y1=d(v.yaxis,Y.y1)),z.x0=Y.x0,z.y0=Y.y0,z.x1=Y.x1,z.y1=Y.y1}else z.type=\"path\",_&&w&&function(t,e,r){var n=\"date\"===e.type,a=\"date\"===r.type;if(!n&&!a)return t;for(var i=0;i<t.length;i++)for(var o=0;o<t[i].length;o++)for(var s=0;s+2<t[i][o].length;s+=2)n&&(t[i][o][s+1]=t[i][o][s+1].replace(\" \",\"_\")),a&&(t[i][o][s+2]=t[i][o][s+2].replace(\" \",\"_\"))}(I,_,w),z.path=x(I),L=null;m(o);for(var W=e.editHelpers,Z=(W||{}).modifyItem,X=[],J=0;J<S.length;J++){var K=o._fullLayout.shapes[J];if(X[J]=K._input,void 0!==M&&J===o._fullLayout._activeShapeIndex){var Q=z;switch(K.type){case\"line\":case\"rect\":case\"circle\":Z(\"x0\",Q.x0),Z(\"x1\",Q.x1),Z(\"y0\",Q.y0),Z(\"y1\",Q.y1);break;case\"path\":Z(\"path\",Q.path)}}}return void 0===M?(X.push(z),X):W?W.getUpdateObj():{}}}}},{\"../../../plots/cartesian/handle_outline\":808,\"../../../plots/cartesian/helpers\":809,\"../../dragelement/helpers\":633,\"./constants\":698,\"./helpers\":701}],703:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach((function(t){var i=e[t.charAt(0)].drawn;if(void 0!==i){var o=t.substr(1).match(n.paramRE);!o||o.length<i||r.push(a.cleanNumber(o[i]))}})),r},r.getDataToPixel=function(t,e,n){var a,i=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return i.t+i.h*(1-t)}:function(t){return i.l+i.w*t};return a},r.getPixelToData=function(t,e,n){var a,i=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);a=function(t){return o(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-i.t)/i.h}:function(t){return(t-i.l)/i.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},r.makeOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return!!n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}}},{\"../../lib\":749,\"./constants\":694}],704:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),supplyDrawNewShapeDefaults:t(\"./draw_newshape/defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":810,\"./attributes\":692,\"./calc_autorange\":693,\"./defaults\":695,\"./draw\":696,\"./draw_newshape/defaults\":699}],705:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"../../plots/pad_attributes\"),i=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:i(a({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plot_api/plot_template\":787,\"../../plots/animation_attributes\":792,\"../../plots/font_attributes\":826,\"../../plots/pad_attributes\":860,\"./constants\":706}],706:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],707:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/array_container_defaults\"),i=t(\"./attributes\"),o=t(\"./constants\").name,s=i.steps;function l(t,e,r){function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=a(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,a){return n.coerce(t,e,s,r,a)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var a=r(\"label\",\"step-\"+e._index);r(\"value\",a),r(\"execute\")}}e.exports=function(t,e){a(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"./attributes\":705,\"./constants\":706}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../plots/plots\"),i=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function m(t){return t._index}function v(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var i=0,c=0;r.each((function(t){var r=b(n.select(this),{step:t},e).node();if(r){var a=o.bBox(r);c=Math.max(c,a.height),i=Math.max(i,a.width)}})),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var m=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),v=i+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(v/m)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each((function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},a=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,a)})),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var T={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*p[_],T.r=0,T.xr=e.x+e.len*d[_]):(T.x=e.x,T.l=h.outerLength*p[_],T.r=h.outerLength*d[_]),a.autoMargin(t,g(e),T)}function y(t,e,r){if(e.currentvalue.visible){var n,a,i=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=i.inputAreaLength-u.currentValueInset-i.currentValueMaxWidth,a=\"left\";break;case\"center\":n=.5*i.inputAreaLength,a=\"middle\";break;default:n=u.currentValueInset,a=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,(function(t){t.attr({\"text-anchor\":a,\"data-notex\":1})})),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),m=(i.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,m),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,(function(n){n.call(k,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(i.stroke,r.bordercolor).call(i.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),a=e.step.label,i=r._gd._fullLayout._meta;return i&&(a=s.templateString(a,i)),n.call(o.font,r.font).text(a).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),a=e._dims,i=r.selectAll(\"g.\"+u.labelGroupClass).data(a.labelSteps);i.enter().append(\"g\").classed(u.labelGroupClass,!0),i.exit().remove(),i.each((function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+a.currentValueTotalHeight)}))}function w(t,e,r,n,a){var i=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[i]._index;o!==r.active&&T(t,e,r,o,!0,a)}function T(t,e,r,n,i,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(A,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:i,previousActive:s}),l&&l.method&&i&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=i,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:i,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&a.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function k(t,e,r){var a=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",(function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(i.fill,t.activebgcolor);var c=E(t,n.mouse(a)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",(function(){var t=s(),i=E(t,n.mouse(a)[0]);w(e,r,t,i,!1)})),o.on(\"mouseup\",(function(){var t=s();t._dragging=!1,l.call(i.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}))}))}function M(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),a=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%a.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(i.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+a.currentValueTotalHeight)}))}function A(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),a=0,i=0;i<e._stepCount;i++)if(e._visibleSteps[i]._index===e.active){a=i;break}var o=S(e,a/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,a=s.ensureSingle(t,\"rect\",u.railTouchRectClass,(function(n){n.call(k,e,t,r).style(\"pointer-events\",\"all\")}));a.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(i.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(a,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,a=s.ensureSingle(t,\"rect\",u.railRectClass);a.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(i.stroke,e.bordercolor).call(i.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(a,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],a=0;a<r.length;a++){var i=r[a];i.visible&&(i._gd=e,n.push(i))}return n}(e,t),i=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),a.autoMargin(t,g(e))}if(i.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),i.exit().each((function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)})).remove(),0!==r.length){var l=i.selectAll(\"g.\"+u.groupClassName).data(r,m);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];v(t,h)}l.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),a.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||T(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(M,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(A,r,!1),e.call(y,r)}(t,n.select(this),e)}))}}},{\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plot_api/plot_template\":787,\"../../plots/plots\":861,\"../color\":615,\"../drawing\":637,\"./constants\":706,d3:169}],709:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":705,\"./constants\":706,\"./defaults\":707,\"./draw\":708}],710:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\"),f=t(\"../../constants/alignment\").OPPOSITE_SIDE,p=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var d,g=r.propContainer,m=r.propName,v=r.placeholder,y=r.traceIndex,x=r.avoid||{},b=r.attributes,_=r.transform,w=r.containerGroup,T=t._fullLayout,k=1,M=!1,A=g.title,S=(A&&A.text?A.text:\"\").trim(),E=A&&A.font?A.font:{},C=E.family,L=E.size,P=E.color;\"title.text\"===m?d=\"titleText\":-1!==m.indexOf(\"axis\")?d=\"axisTitleText\":m.indexOf(!0)&&(d=\"colorbarTitleText\");var I=t._context.edits[d];\"\"===S?k=0:S.replace(p,\" % \")===v.replace(p,\" % \")&&(k=.2,M=!0,I||(S=\"\")),r._meta?S=s.templateString(S,r._meta):T._meta&&(S=s.templateString(S,T._meta));var z=S||I;w||(w=s.ensureSingle(T._infolayer,\"g\",\"g-\"+e));var O=w.selectAll(\"text\").data(z?[0]:[]);if(O.enter().append(\"text\"),O.text(S).attr(\"class\",e),O.exit().remove(),!z)return w;function D(t){s.syncOrAsync([R,F],t)}function R(e){var r;return _?(r=\"\",_.rotate&&(r+=\"rotate(\"+[_.rotate,b.x,b.y]+\")\"),_.offset&&(r+=\"translate(0, \"+_.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":C,\"font-size\":n.round(L,2)+\"px\",fill:c.rgb(P),opacity:k*c.opacity(P),\"font-weight\":i.fontWeight}).attr(b).call(u.convertToTspans,t),i.previousPromises(t)}function F(t){var e=n.select(t.node().parentNode);if(x&&x.selection&&x.side&&S){e.attr(\"transform\",null);var r=f[x.side],i=\"left\"===x.side||\"top\"===x.side?-1:1,o=a(x.pad)?x.pad:2,c=l.bBox(e.node()),u={left:0,top:0,right:T.width,bottom:T.height},h=x.maxShift||i*(u[x.side]-c[x.side]),p=0;if(h<0)p=h;else{var d=x.offsetLeft||0,g=x.offsetTop||0;c.left-=d,c.right-=d,c.top-=g,c.bottom-=g,x.selection.each((function(){var t=l.bBox(this);s.bBoxIntersect(c,t,o)&&(p=Math.max(p,i*(t[x.side]-c[r])+o))})),p=Math.min(h,p)}if(p>0||h<0){var m={left:[-p,0],right:[p,0],top:[0,-p],bottom:[0,p]}[x.side];e.attr(\"transform\",\"translate(\"+m+\")\")}}}return O.call(D),I&&(S?O.on(\".opacity\",null):(k=0,M=!0,O.text(v).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)}))),O.call(u.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==y?o.call(\"_guiRestyle\",t,m,e,y):o.call(\"_guiRelayout\",t,m,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(D)})).on(\"input\",(function(t){this.text(t||\" \").call(u.positionText,b.x,b.y)}))),O.classed(\"js-placeholder\",M),w}}},{\"../../constants/alignment\":717,\"../../constants/interactions\":723,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/plots\":861,\"../../registry\":881,\"../color\":615,\"../drawing\":637,d3:169,\"fast-isnumeric\":241}],711:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"../color/attributes\"),i=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:i(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:a.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plot_api/plot_template\":787,\"../../plots/font_attributes\":826,\"../../plots/pad_attributes\":860,\"../color/attributes\":614}],712:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/array_container_defaults\"),i=t(\"./attributes\"),o=t(\"./constants\").name,s=i.buttons;function l(t,e,r){function o(r,a){return n.coerce(t,e,i,r,a)}o(\"visible\",a(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,a){return n.coerce(t,e,s,r,a)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){a(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"./attributes\":711,\"./constants\":712}],714:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../plots/plots\"),i=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,a,i,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?v(t,n,null,null,e):\"dropdown\"===e.type&&(a.attr(h.menuIndexAttrName,\"-1\"),m(t,n,a,i,e),s||v(t,n,a,i,e))}function m(t,e,r,n,a){var i=s.ensureSingle(e,\"g\",h.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=a._dims,c=a.active,u=a.buttons[c]||h.blankHeaderOpts,f={y:a.pad.t,yPad:0,x:a.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};i.call(y,a,u,t).call(A,a,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,a.font).text(h.arrowSymbol[a.direction])})).attr({x:l.headerWidth-h.arrowOffsetX+a.pad.l,y:l.headerHeight/2+h.textOffsetY+a.pad.t}),i.on(\"click\",(function(){r.call(S,String(d(r,a)?-1:a._index)),v(t,e,r,n,a)})),i.on(\"mouseover\",(function(){i.call(w)})),i.on(\"mouseout\",(function(){i.call(T,a)})),o.setTranslate(e,l.lx,l.ly)}function v(t,e,r,i,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,m=0,v=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?m=v.headerHeight+h.gapButtonHeader:d=v.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(m=-h.gapButtonHeader+h.gapButton-v.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-v.openWidth);var b={x:v.lx+d+o.pad.l,y:v.ly+m+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},k={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,i,-1),a.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,i,l),a.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(_,o)}))})),u.call(_,o),x?(k.w=Math.max(v.openWidth,v.headerWidth),k.h=b.y-k.t):(k.w=b.x-k.l,k.h=Math.max(v.openHeight,v.headerHeight)),k.direction=o.direction,i&&(u.size()?function(t,e,r,n,a,i){var o,s,l,c=a.direction,u=\"up\"===c||\"down\"===c,f=a._dims,p=a.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(i,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,i,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()}));r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(i))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,(function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})})).call(i.stroke,e.bordercolor).call(i.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var a=s.ensureSingle(t,\"text\",h.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),i=r.label,c=n._fullLayout._meta;c&&(i=s.templateString(i,c)),a.call(o.font,e.font).text(i).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each((function(t,a){var o=n.select(this);a===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(i.fill,h.activeColor)}))}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(i.fill,h.hoverColor)}function T(t,e){t.select(\"rect.\"+h.itemRectClassName).call(i.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},i=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));i.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);i.each((function(a,i){var s=n.select(this);s.call(y,e,a,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,m=l.lineCount(f),v=Math.max(g*m,h.minHeight)+h.textOffsetY;v=Math.ceil(v),d=Math.ceil(d),r.widths[i]=d,r.heights[i]=v,r.height1=Math.max(r.height1,v),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=v+h.gapButton,r.openHeight+=v+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,v),r.openHeight=r.totalHeight)})),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),i.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var m=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,m=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,m=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),a.autoMargin(t,M(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[m]||0),t:p*({bottom:1,middle:.5}[m]||0)})}function M(t){return h.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var a=t.select(\".\"+h.itemRectClassName),i=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);a.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,m=(l.lineCount(i)-1)*g/2;l.positionText(i,h.textOffsetX,d/2-m+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function i(e){a.autoMargin(t,M(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(i)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var y=r[u];k(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),i(t)})).remove(),l.each((function(e){var r=n.select(this),i=\"dropdown\"===e.type?c:null;a.manageCommandObserver(t,e,e.buttons,(function(n){g(t,e,e.buttons[n.index],r,i,b,n.index,!0)})),\"dropdown\"===e.type?(m(t,r,c,b,e),d(c,e)&&v(t,r,c,b,e)):v(t,r,null,null,e)}))}}},{\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plot_api/plot_template\":787,\"../../plots/plots\":861,\"../color\":615,\"../drawing\":637,\"./constants\":712,\"./scrollbox\":716,d3:169}],715:[function(t,e,r){arguments[4][709][0].apply(r,arguments)},{\"./attributes\":711,\"./constants\":712,\"./defaults\":713,\"./draw\":714,dup:709}],716:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),a=t(\"../color\"),i=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,m=this.position.t,v=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,T=v;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=m,T=(p=Math.min(f+T,c))-f):T=(p=m+T)-(f=Math.max(p-T,0))):(p=(f=m)+T,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:T};var k=g>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=m+v;E+A>c&&(E=c-A);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(a.fill,s.barColor),k?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=v>T,P=s.barWidth+2*s.barPad,I=s.barLength+2*s.barPad,z=d+g,O=m;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(a.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:O,width:P,height:I}),this._vbarYMin=O+I/2,this._vbarTranslateMax=T-I):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=k?p+A+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(i.setClipUrl,R,this.gd),this.bg.attr({x:d,y:m,width:g,height:v})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(i.setClipUrl,null),delete this._clipRect),k||L){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(i.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,a=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,a)-r)/(a-r)*(this.position.w-this._box.w)}if(this.vbar){var i=e+this._vbarYMin,s=i+this._vbarTranslateMax;e=(o.constrain(n.event.y,i,s)-i)/(s-i)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(i.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var a=t/r;this.hbar.call(i.setTranslate,t+a*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(i.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":749,\"../color\":615,\"../drawing\":637,d3:169}],717:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],718:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],719:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format#locale_format\"}},{}],720:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],721:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],722:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],723:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],724:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],725:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],726:[function(t,e,r){\"use strict\";r.version=t(\"./version\").version,t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),a=r.register=n.register,i=t(\"./plot_api\"),o=Object.keys(i),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=i[l]),a({moduleType:\"apiMethod\",name:l,fn:i[l]})}a(t(\"./traces/scatter\")),a([t(\"./components/legend\"),t(\"./components/fx\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),a([t(\"./locale-en\"),t(\"./locale-en-us\")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(a(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":606,\"./components/annotations3d\":611,\"./components/colorbar\":621,\"./components/colorscale\":627,\"./components/errorbars\":643,\"./components/fx\":655,\"./components/grid\":659,\"./components/images\":664,\"./components/legend\":672,\"./components/rangeselector\":683,\"./components/rangeslider\":690,\"./components/shapes\":704,\"./components/sliders\":709,\"./components/updatemenus\":715,\"./fonts/mathjax_config\":727,\"./fonts/ploticon\":728,\"./lib/queue\":764,\"./locale-en\":778,\"./locale-en-us\":777,\"./plot_api\":782,\"./plot_api/plot_schema\":786,\"./plots/plots\":861,\"./registry\":881,\"./snapshot\":886,\"./traces/scatter\":1168,\"./version\":1339,d3:169,\"es6-promise\":224}],727:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],728:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],729:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],730:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),a=n.mod,i=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return i(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=a(r,s))>(n=a(n,s))&&(n+=s);var i=a(t,s),o=i+s;return i>=r&&i<=n||o>=r&&o<=n}function h(t,e,r,n,a,i,c){a=a||0,i=i||0;var u,h,f,p,d,g=l([r,n]);function m(t,e){return[t*Math.cos(e)+a,i-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var v,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+m(t,e)}return g?v=null===p?\"M\"+m(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+m(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+m(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(v=\"M\"+m(d,u)+x(d,f,0),c&&(v+=\"L0,0Z\")):v=\"M\"+m(p,u)+\"L\"+m(d,u)+x(d,f,0)+\"L\"+m(p,f)+x(p,u,1)+\"Z\",v}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(a=r[0],i=r[1]):(a=r[1],i=r[0]),t>=a&&t<=i);var a,i},pathArc:function(t,e,r,n,a){return h(null,t,e,r,n,a,0)},pathSector:function(t,e,r,n,a){return h(null,t,e,r,n,a,1)},pathAnnulus:function(t,e,r,n,a,i){return h(t,e,r,n,a,i,1)}}},{\"./mod\":756}],731:[function(t,e,r){\"use strict\";var n=Array.isArray,a=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},i=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return a.isView(t)&&!(t instanceof i)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,a=0;a<t.length;a++)n=e(n,t[a].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,a,i,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(a=arguments[r]).length)&&(e?c.push(a):(e=a,i=o),n(a)?t=!1:(u=!1,h?t!==a.constructor&&(t=!1):t=a.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)a=c[r],s.set(a,i),i+=a.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(a=c[r],l=0;l<a.length;l++)s[i+l]=a[l];i+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],732:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\").BADNUM,i=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(i,\"\")),n(t)?Number(t):a}},{\"../constants/numerical\":724,\"fast-isnumeric\":241}],733:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},{}],734:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],735:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),i=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var a={},i=a,o={set:function(t){i=t}};return n.coerceFunction(t,o,a,e),i!==a}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var a=String(r[n]);if(\"/\"===a.charAt(0)&&\"/\"===a.charAt(a.length-1)){if(new RegExp(a.substr(1,a.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,a){!n(t)||void 0!==a.min&&t<a.min||void 0!==a.max&&t>a.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,a){t%1||!n(t)||void 0!==a.min&&t<a.min||void 0!==a.max&&t>a.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var a=\"number\"==typeof t;!0!==n.strict&&a?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){a(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return a(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var a=n.regex||c(r);\"string\"==typeof t&&a.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var a=t.split(\"+\"),i=0;i<a.length;){var o=a[i];-1===n.flags.indexOf(o)||a.indexOf(o)<i?a.splice(i,1):i++}a.length?e.set(a.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,a){function i(t,e,n){var a,i={set:function(t){a=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,i,n,e),a}var o=2===a.dimensions||\"1-2\"===a.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=a.items,d=[],g=Array.isArray(p),m=g&&o&&Array.isArray(p[0]),v=o&&g&&!m,y=g&&!v?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=v?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=v?p[l]:g?p[s][l]:p,void 0!==(f=i(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=i(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),a=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var i=0;i<t.length;i++)if(a){if(!Array.isArray(t[i])||!e.freeLength&&t[i].length!==r[i].length)return!1;for(var o=0;o<t[i].length;o++)if(!f(t[i][o],n?r[i][o]:r))return!1}else if(!f(t[i],n?r[i]:r))return!1;return!0}}},r.coerce=function(t,e,n,a,i){var o=l(n,a).get(),s=l(t,a),c=l(e,a),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,a).get(),p=0),void 0===i&&(i=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,i,o);var g=c.get();return p&&g===i&&!f(u,o)&&(d(u=l(p,a).get(),c,i,o),g=c.get()),g},r.coerce2=function(t,e,n,a,i){var o=l(t,a),s=r.coerce(t,e,n,a,i),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var a,o=e._module.attributes,s=o.hoverinfo?o:i,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),a=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",a)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,a=t.marker.opacity;if(void 0!==a)h(a)||t.selected||t.unselected||(r=a,n=s*a),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":630,\"../constants/interactions\":723,\"../plots/attributes\":794,\"./array\":731,\"./mod\":756,\"./nested_property\":757,\"./regex\":765,\"fast-isnumeric\":241,tinycolor2:548}],736:[function(t,e,r){\"use strict\";var n,a,i=t(\"d3-time-format\").timeFormat,o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,m=t(\"../registry\"),v=t(\"d3-time-format\").utcFormat,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&m.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){var n=function(t,e){return _(t)?e?m.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:m.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!e);if(e<2)return n;var a=r.dateTime2ms(n,t);return a+=h*(e-1),r.ms2DateTime(a,0,t)},r.dfltRange=function(t){return _(t)?m.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var i=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;i=i-s/2+l(o-i+s/2,s)}return(t=Number(t)-i)>=n&&t<=a?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),v=t.charAt(0);!c||\"G\"!==v&&\"g\"!==v||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),T=t.match(w?x:y);if(!T)return u;var k=T[1],M=T[3]||\"1\",A=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),C=Number(T[11]||0);if(c){if(2===k.length)return u;var L;k=Number(k);try{var P=m.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var I=\"i\"===M.charAt(M.length-1);M=parseInt(M,10),L=P.newDate(k,P.toMonthIndex(k,M,I),A)}else L=P.newDate(k,Number(M),A)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}k=2===k.length?(Number(k)+2e3-b)%100+b:Number(k),M-=1;var z=new Date(Date.UTC(2e3,M,A,S,E));return z.setUTCFullYear(k),z.getUTCMonth()!==M||z.getUTCDate()!==A?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),a=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var T=90*h,k=3*f,M=5*p;function A(t,e,r,n,a){if((e||r||n||a)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||a)&&(t+=\":\"+w(n,2),a))){for(var i=4;a%10==0;)i-=1,a/=10;t+=\".\"+w(a,i)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=a))return u;e||(e=0);var i,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{i=m.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){i=v(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===i.charAt(0))for(;i.length<11;)i=\"-0\"+i.substr(1);else for(;i.length<10;)i=\"0\"+i;o=e<T?Math.floor(E/f):0,s=e<T?Math.floor(E%f/p):0,c=e<k?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),i=v(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(i,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=a-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(i(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var a=new Date(Math.floor(e+.05));if(_(n))try{t=m.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(a)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,a,i){if(a=_(a)&&a,!e)if(\"y\"===r)e=i.year;else if(\"m\"===r)e=i.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var a=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(a=a.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+a}return n}(t,r)+\"\\n\"+E(i.dayMonthYear,t,n,a);e=i.dayMonth+\"\\n\"+i.year}return E(e,t,n,a)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var a=Math.round(t/h)+g,i=m.getComponentMethod(\"calendars\",\"getCal\")(r),o=i.fromJD(a);return e%12?i.add(o,e,\"m\"):i.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,a=0,i=0,s=0,l=0,c=_(e)&&m.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?a++:i++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?a++:i++:s++}else l++;s+=i+=a;var f=t.length-l;return{exactYears:a/f,exactMonths:i/f,exactDays:s/f}}},{\"../constants/numerical\":724,\"../registry\":881,\"./loggers\":753,\"./mod\":756,\"d3-time-format\":166,\"fast-isnumeric\":241}],737:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"./loggers\");function i(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,i=document.getElementById(n);i||((i=document.createElement(\"style\")).setAttribute(\"id\",n),i.appendChild(document.createTextNode(\"\")),document.head.appendChild(i));var o=i.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):a.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:i,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&i(r)}}},{\"./loggers\":753,d3:169}],738:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,a={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,a){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,a),e.emit(n,a),r.emit(n,a)},t},triggerHandler:function(t,e,r){var n,a;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var i=t._ev;if(!i)return n;var o,s=i._events[e];if(!s)return n;function l(t){return t.listener?(i.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(i,[r]))):t.apply(i,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return a=l(s[o]),void 0!==n?n:a},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=a},{events:110}],739:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),a=Array.isArray;function i(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&a(p)&&a(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&a(u)?p[l]=u:e&&u&&(n(u)||(h=a(u)))?(h?(h=!1,f=c&&a(c)?c:[]):f=c&&n(c)?c:{},p[l]=i([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return i(arguments,!1,!1,!1)},r.extendDeep=function(){return i(arguments,!0,!1,!1)},r.extendDeepAll=function(){return i(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return i(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":750}],740:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,a=0;a<t.length;a++){var i=t[a];1!==e[i]&&(e[i]=1,r[n++]=i)}return r}},{}],741:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function a(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?a:n),i=[],o=0;o<t.length;o++){var s=t[o];r(s)&&i.push(s)}return i}},{}],742:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"country-regex\"),i=t(\"@turf/area\"),o=t(\"@turf/centroid\"),s=t(\"@turf/bbox\"),l=t(\"./identity\"),c=t(\"./loggers\"),u=t(\"./is_plain_object\"),h=t(\"./nested_property\"),f=t(\"./polygon\"),p=Object.keys(a),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(a[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function g(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,i,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],i=0;i<r.length;i++)(a=r[i]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(i=0;i<n.length;i++)if((a=n[i]).id===o)return a;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,a,i=t.geometry,o=i.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),a=0;a<t.length;a++)e[a]=[t[a][0]<0?t[a][0]+360:t[a][0],t[a][1]];l.push(f.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(f.tester(t));var r=new Array(t.length+1),n=0;for(a=0;a<t.length;a++)a>e?r[n++]=[t[a][0]+360,t[a][1]]:a===e?(r[n++]=t[a],r[n++]=[t[a][0],-90]):r[n++]=t[a];var i=f.tester(r);i.pts.pop(),l.push(i)}:function(t){l.push(f.tester(t))},i.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:g,extractTraceFeature:function(t){var e=t[0].trace,r=g(e);if(!r)return!1;var n,a={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(a[l.loc]=l)}function u(t){var r=h(t,e.featureidkey||\"id\").get(),n=a[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,a=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>a&&(a=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete a[r]}switch(r.type){case\"FeatureCollection\":var f=r.features;for(n=0;n<f.length;n++)u(f[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in a)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function a(t){return new Promise((function(r,a){n.json(t,(function(n,i){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return a(new Error(o))}return e[t]=i,r(i)}))}))}function i(t){return new Promise((function(r,n){var a=0,i=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(i),r(e[t])):a>100?(clearInterval(i),n(\"Unexpected error while fetching from \"+t)):void a++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(i(s)):(e[s]=\"pending\",r.push(a(s))))}return r},computeBbox:function(t){return s.default(t)}}},{\"./identity\":747,\"./is_plain_object\":750,\"./loggers\":753,\"./nested_property\":757,\"./polygon\":761,\"@turf/area\":59,\"@turf/bbox\":60,\"@turf/centroid\":61,\"country-regex\":139,d3:169}],743:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],a=[],i=0;i<t.length;i++){var o=t[i].lonlat;o[0]!==n?a.push(o):!e&&a.length>0&&(r.push(a),a=[])}return a.length>0&&r.push(a),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":724}],744:[function(t,e,r){\"use strict\";var n,a,i,o=t(\"./mod\").mod;function s(t,e,r,n,a,i,o,s){var l=r-t,c=a-t,u=o-a,h=n-e,f=i-e,p=s-i,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,m=(c*h-l*f)/d;return m<0||m>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,a){var i=n*t+a*e;if(i<0)return n*n+a*a;if(i>r){var o=n-t,s=a-e;return o*o+s*s}var l=n*e-a*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,a,i,o,c){if(s(t,e,r,n,a,i,o,c))return 0;var u=r-t,h=n-e,f=o-a,p=c-i,d=u*u+h*h,g=f*f+p*p,m=Math.min(l(u,h,d,a-t,i-e),l(u,h,d,o-t,c-e),l(f,p,g,t-a,e-i),l(f,p,g,r-a,n-i));return Math.sqrt(m)},r.getTextLocation=function(t,e,r,s){if(t===a&&s===i||(n={},a=t,i=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){a=null},r.getVisibleSegment=function(t,e,r){var n,a,i=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(a=r);var c=r.x<i?i-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-a.x)<.1&&Math.abs(n.y-a.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var a,i,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(a=(f+p)/2,o=(i=t.getPointAtLength(a))[r]-e,Math.abs(o)<l)return i;u*o>0?p=a:f=a,h++}return i}},{\"./mod\":756}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),i=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=i(s);function u(t,e){var r=t;return r[3]*=e,r}function h(t){if(n(t))return c;var e=i(t);return e.length?e:c}function f(t){return n(t)?t:1}e.exports={formatColor:function(t,e,r){var n,a,s,p,d,g=t.color,m=l(g),v=l(e),y=o.extractOpts(t),x=[];if(n=void 0!==y.colorscale?o.makeColorScaleFuncFromTrace(t):h,a=m?function(t,e){return void 0===t[e]?c:i(n(t[e]))}:h,s=v?function(t,e){return void 0===t[e]?1:f(t[e])}:f,m||v)for(var b=0;b<r;b++)p=a(g,b),d=s(e,b),x[b]=u(p,d);else x=u(i(g),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=a(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},{\"../components/color/attributes\":614,\"../components/colorscale\":627,\"./array\":731,\"color-normalize\":125,\"fast-isnumeric\":241,tinycolor2:548}],746:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function a(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:a,descend:n,wrap:a,unwrap:function(t){return t[0]}}},{\"./identity\":747}],747:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],748:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,a=String(n).length;if(a>16){var i=String(e).length;if(a>=String(t).length+i){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"d3-time-format\").utcFormat,i=t(\"fast-isnumeric\"),o=t(\"../constants/numerical\"),s=o.FP_SAFE,l=o.BADNUM,c=e.exports={};c.nestedProperty=t(\"./nested_property\"),c.keyedContainer=t(\"./keyed_container\"),c.relativeAttr=t(\"./relative_attr\"),c.isPlainObject=t(\"./is_plain_object\"),c.toLogRange=t(\"./to_log_range\"),c.relinkPrivateKeys=t(\"./relink_private\");var u=t(\"./array\");c.isTypedArray=u.isTypedArray,c.isArrayOrTypedArray=u.isArrayOrTypedArray,c.isArray1D=u.isArray1D,c.ensureArray=u.ensureArray,c.concat=u.concat,c.maxRowLength=u.maxRowLength,c.minRowLength=u.minRowLength;var h=t(\"./mod\");c.mod=h.mod,c.modHalf=h.modHalf;var f=t(\"./coerce\");c.valObjectMeta=f.valObjectMeta,c.coerce=f.coerce,c.coerce2=f.coerce2,c.coerceFont=f.coerceFont,c.coerceHoverinfo=f.coerceHoverinfo,c.coerceSelectionMarkerOpacity=f.coerceSelectionMarkerOpacity,c.validate=f.validate;var p=t(\"./dates\");c.dateTime2ms=p.dateTime2ms,c.isDateTime=p.isDateTime,c.ms2DateTime=p.ms2DateTime,c.ms2DateTimeLocal=p.ms2DateTimeLocal,c.cleanDate=p.cleanDate,c.isJSDate=p.isJSDate,c.formatDate=p.formatDate,c.incrementMonth=p.incrementMonth,c.dateTick0=p.dateTick0,c.dfltRange=p.dfltRange,c.findExactDates=p.findExactDates,c.MIN_MS=p.MIN_MS,c.MAX_MS=p.MAX_MS;var d=t(\"./search\");c.findBin=d.findBin,c.sorterAsc=d.sorterAsc,c.sorterDes=d.sorterDes,c.distinctVals=d.distinctVals,c.roundUp=d.roundUp,c.sort=d.sort,c.findIndexOfMin=d.findIndexOfMin;var g=t(\"./stats\");c.aggNums=g.aggNums,c.len=g.len,c.mean=g.mean,c.median=g.median,c.midRange=g.midRange,c.variance=g.variance,c.stdev=g.stdev,c.interp=g.interp;var m=t(\"./matrix\");c.init2dArray=m.init2dArray,c.transposeRagged=m.transposeRagged,c.dot=m.dot,c.translationMatrix=m.translationMatrix,c.rotationMatrix=m.rotationMatrix,c.rotationXYMatrix=m.rotationXYMatrix,c.apply2DTransform=m.apply2DTransform,c.apply2DTransform2=m.apply2DTransform2;var v=t(\"./angles\");c.deg2rad=v.deg2rad,c.rad2deg=v.rad2deg,c.angleDelta=v.angleDelta,c.angleDist=v.angleDist,c.isFullCircle=v.isFullCircle,c.isAngleInsideSector=v.isAngleInsideSector,c.isPtInsideSector=v.isPtInsideSector,c.pathArc=v.pathArc,c.pathSector=v.pathSector,c.pathAnnulus=v.pathAnnulus;var y=t(\"./anchor_utils\");c.isLeftAnchor=y.isLeftAnchor,c.isCenterAnchor=y.isCenterAnchor,c.isRightAnchor=y.isRightAnchor,c.isTopAnchor=y.isTopAnchor,c.isMiddleAnchor=y.isMiddleAnchor,c.isBottomAnchor=y.isBottomAnchor;var x=t(\"./geometry2d\");c.segmentsIntersect=x.segmentsIntersect,c.segmentDistance=x.segmentDistance,c.getTextLocation=x.getTextLocation,c.clearLocationCache=x.clearLocationCache,c.getVisibleSegment=x.getVisibleSegment,c.findPointOnPath=x.findPointOnPath;var b=t(\"./extend\");c.extendFlat=b.extendFlat,c.extendDeep=b.extendDeep,c.extendDeepAll=b.extendDeepAll,c.extendDeepNoArrays=b.extendDeepNoArrays;var _=t(\"./loggers\");c.log=_.log,c.warn=_.warn,c.error=_.error;var w=t(\"./regex\");c.counterRegex=w.counter;var T=t(\"./throttle\");c.throttle=T.throttle,c.throttleDone=T.done,c.clearThrottle=T.clear;var k=t(\"./dom\");function M(t){var e={};for(var r in t)for(var n=t[r],a=0;a<n.length;a++)e[n[a]]=+r;return e}c.getGraphDiv=k.getGraphDiv,c.isPlotDiv=k.isPlotDiv,c.removeElement=k.removeElement,c.addStyleRule=k.addStyleRule,c.addRelatedStyleRule=k.addRelatedStyleRule,c.deleteRelatedStyleRule=k.deleteRelatedStyleRule,c.clearResponsive=t(\"./clear_responsive\"),c.makeTraceGroups=t(\"./make_trace_groups\"),c._=t(\"./localize\"),c.notifier=t(\"./notifier\"),c.filterUnique=t(\"./filter_unique\"),c.filterVisible=t(\"./filter_visible\"),c.pushUnique=t(\"./push_unique\"),c.increment=t(\"./increment\"),c.cleanNumber=t(\"./clean_number\"),c.ensureNumber=function(t){return i(t)?(t=Number(t))<-s||t>s?l:i(t)?Number(t):l:l},c.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},c.noop=t(\"./noop\"),c.identity=t(\"./identity\"),c.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},c.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var a=0;a<e.length;a++){var i=e[a],o=c.nestedProperty(t,i.replace(\"?\",r)),s=c.nestedProperty(t,i.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},c.raiseToTop=function(t){t.parentNode.appendChild(t)},c.cancelTransition=function(t){return t.transition().duration(0)},c.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},c.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},c.simpleMap=function(t,e,r,n,a){for(var i=t.length,o=new Array(i),s=0;s<i;s++)o[s]=e(t[s],r,n,a);return o},c.randstr=function t(e,r,n,a){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var i,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(i=2;s===1/0;i*=2)s=Math.log(Math.pow(2,r/i))/Math.log(n)*i;var u=s-Math.floor(s);for(i=0;i<Math.floor(s);i++)l=Math.floor(Math.random()*n).toString(n)+l;u&&(o=Math.pow(n,u),l=Math.floor(Math.random()*o).toString(n)+l);var h=parseInt(l,n);return e&&e[l]||h!==1/0&&h>=Math.pow(2,r)?a>10?(c.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(a||0)+1):l},c.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},c.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,a,i,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(i=0,n=0;n<l;n++)(a=r+n+1-e)<-o?a-=s*Math.round(a/s):a>=s&&(a-=s*Math.floor(a/s)),a<0?a=-1-a:a>=o&&(a=s-1-a),i+=t[a]*c[n];u[r]=i}return u},c.syncOrAsync=function(t,e,r){var n;function a(){return c.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(a).then(void 0,c.promiseError);return r&&r(e)},c.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},c.noneOrAll=function(t,e,r){if(t){var n,a=!1,i=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?a=!0:i=!1;if(a&&!i)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},c.mergeArray=function(t,e,r,n){var a=\"function\"==typeof n;if(c.isArrayOrTypedArray(t))for(var i=Math.min(t.length,e.length),o=0;o<i;o++){var s=t[o];e[o][r]=a?n(s):s}},c.mergeArrayCastPositive=function(t,e,r){return c.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},c.fillArray=function(t,e,r,n){if(n=n||c.identity,c.isArrayOrTypedArray(t))for(var a=0;a<e.length;a++)e[a][r]=n(t[a])},c.castOption=function(t,e,r,n){n=n||c.identity;var a=c.nestedProperty(t,r).get();return c.isArrayOrTypedArray(a)?Array.isArray(e)&&c.isArrayOrTypedArray(a[e[0]])?n(a[e[0]][e[1]]):n(a[e]):a},c.extractOption=function(t,e,r,n){if(r in t)return t[r];var a=c.nestedProperty(e,n).get();return Array.isArray(a)?void 0:a},c.tagSelected=function(t,e,r){var n,a,i=e.selectedpoints,o=e._indexToPoints;o&&(n=M(o));for(var s=0;s<i.length;s++){var l=i[s];if(c.isIndex(l)||c.isArrayOrTypedArray(l)&&c.isIndex(l[0])&&c.isIndex(l[1])){var u=n?n[l]:l,h=r?r[u]:u;void 0!==(a=h)&&a<t.length&&(t[h].selected=1)}}},c.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=M(r),a=[],i=0;i<e.length;i++){var o=e[i];if(c.isIndex(o)){var s=n[o];c.isIndex(s)&&a.push(s)}}return a}return e},c.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=c.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},c.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,a,i,o=Object.keys(t);for(n=0;n<o.length;n++)i=t[a=o[n]],\"_\"!==a.charAt(0)&&\"function\"!=typeof i&&(\"module\"===a?r[a]=i:Array.isArray(i)?r[a]=\"colorscale\"===a?i.slice():i.slice(0,3):c.isTypedArray(i)?r[a]=i.subarray(0,3):r[a]=i&&\"object\"==typeof i?c.minExtend(t[a],e[a]):i);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(i=e[a=o[n]])&&a in r&&\"object\"==typeof r[a]||(r[a]=i);return r},c.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},c.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},c.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;c.isIE9orBelow=function(){return c.isIE()&&A.test(window.navigator.userAgent)};var S=/Version\\/[\\d\\.]+.*Safari/;c.isSafari=function(){return S.test(window.navigator.userAgent)};var E=/iPad|iPhone|iPod/;c.isIOS=function(){return E.test(window.navigator.userAgent)},c.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},c.ensureSingle=function(t,e,r,n){var a=t.select(e+(r?\".\"+r:\"\"));if(a.size())return a;var i=t.append(e);return r&&i.classed(r,!0),n&&i.call(n),i},c.ensureSingleById=function(t,e,r,n){var a=t.select(e+\"#\"+r);if(a.size())return a;var i=t.append(e).attr(\"id\",r);return n&&i.call(n),i},c.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),a=r={},i=0;i<n.length;i++){var o=n[i],s=null,l=n[i].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],i===n.length-1?r[s]=e:r[s]={},r=r[s]):(i===n.length-1?r[o]=e:r[o]={},r=r[o])}return a};var C=/^([^\\[\\.]+)\\.(.+)?/,L=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;c.expandObjectPaths=function(t){var e,r,n,a,i,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(C))?(a=t[r],n=e[1],delete t[r],t[n]=c.extendDeepNoArrays(t[n]||{},c.objectFromPath(r,c.expandObjectPaths(a))[n])):(e=r.match(L))?(a=t[r],n=e[1],i=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][i]=t[n][i]||{},c.extendDeepNoArrays(o,c.objectFromPath(s,c.expandObjectPaths(a)))):t[n][i]=c.expandObjectPaths(a)):t[r]=c.expandObjectPaths(t[r]));return t},c.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,a=e.charAt(0),i=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?a+o[1]:\"\";if(i&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+i+\"$2\");return s+l},c.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var P=/^\\w*$/;c.templateString=function(t,e){var r={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,n){var a;return P.test(n)?a=e[n]:(r[n]=r[n]||c.nestedProperty(e,n).get,a=r[n]()),c.isValidTextValue(a)?a:\"\"}))};var I={max:10,count:0,name:\"hovertemplate\"};c.hovertemplateString=function(){return D.apply(I,arguments)};var z={max:10,count:0,name:\"texttemplate\"};c.texttemplateString=function(){return D.apply(z,arguments)};var O=/^[:|\\|]/;function D(t,e,r){var i=this,o=arguments;e||(e={});var s={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,l,u){var h,f,p,d;for(p=3;p<o.length;p++)if(h=o[p]){if(h.hasOwnProperty(l)){f=h[l];break}if(P.test(l)||(f=s[l]||c.nestedProperty(h,l).get())&&(s[l]=f),void 0!==f)break}if(void 0===f&&i)return i.count<i.max&&(c.warn(\"Variable '\"+l+\"' in \"+i.name+\" could not be found!\"),f=t),i.count===i.max&&c.warn(\"Too many \"+i.name+\" warnings - additional warnings will be suppressed\"),i.count++,t;if(u){if(\":\"===u[0]&&(f=(d=r?r.numberFormat:n.format)(u.replace(O,\"\"))(f)),\"|\"===u[0]){d=r?r.timeFormat:a;var g=c.dateTime2ms(f);f=c.formatDate(g,u.replace(O,\"\"),!1,d)}}else e.hasOwnProperty(l+\"Label\")&&(f=e[l+\"Label\"]);return f}))}c.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,a=0,i=0;i<r;i++){var o=t.charCodeAt(i)||0,s=e.charCodeAt(i)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(a=10*a+s-48),!l||!c){if(n!==a)return n-a;if(o!==s)return o-s}}return a-n};var R=2e9;c.seedPseudoRandom=function(){R=2e9},c.pseudoRandom=function(){var t=R;return R=(69069*R+1)%4294967296,Math.abs(R-t)<429496729?c.pseudoRandom():R/4294967296},c.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},a=c.extractOption(t,e,\"htx\",\"hovertext\");if(c.isValidTextValue(a))return n(a);var i=c.extractOption(t,e,\"tx\",\"text\");return c.isValidTextValue(i)?n(i):void 0},c.isValidTextValue=function(t){return t||0===t},c.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},c.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},c.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,a=t.targetX,i=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,c=t.scale;return c?c>1&&(c=1):c=0,\"translate(\"+(a-c*(r+o))+\",\"+(i-c*(n+s))+\")\"+(c<1?\"scale(\"+c+\")\":\"\")+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},c.ensureUniformFontSize=function(t,e){var r=c.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r}},{\"../constants/numerical\":724,\"./anchor_utils\":729,\"./angles\":730,\"./array\":731,\"./clean_number\":732,\"./clear_responsive\":734,\"./coerce\":735,\"./dates\":736,\"./dom\":737,\"./extend\":739,\"./filter_unique\":740,\"./filter_visible\":741,\"./geometry2d\":744,\"./identity\":747,\"./increment\":748,\"./is_plain_object\":750,\"./keyed_container\":751,\"./localize\":752,\"./loggers\":753,\"./make_trace_groups\":754,\"./matrix\":755,\"./mod\":756,\"./nested_property\":757,\"./noop\":758,\"./notifier\":759,\"./push_unique\":763,\"./regex\":765,\"./relative_attr\":766,\"./relink_private\":767,\"./search\":768,\"./stats\":771,\"./throttle\":774,\"./to_log_range\":775,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],750:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],751:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),a=/^\\w*$/;e.exports=function(t,e,r,i){var o,s,l;r=r||\"name\",i=i||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=a.test(i),f={set:function(t,e){var a=null===e?4:0;if(!s){if(!l||4===a)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===a)return;a|=3,o=s.length,u[t]=o}else e!==(h?s[o][i]:n(s[o],i).get())&&(a|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[i]=e:n(p,i).set(e),null!==e&&(a&=-5),c[o]=c[o]|a,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][i]:n(s[e],i).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),f},remove:function(t){var e=u[t];if(void 0===e)return f;var a=s[e];if(Object.keys(a).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(a,i).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,a,o={},l=Object.keys(c),u=0;u<l.length;u++)a=l[u],t=e+\"[\"+a+\"]\",s[a]?(1&c[a]&&(o[t+\".\"+r]=s[a][r]),2&c[a]&&(o[t+\".\"+i]=h?4&c[a]?null:s[a][i]:4&c[a]?null:n(s[a],i).get())):o[t]=null;return o}};return f}},{\"./nested_property\":757}],752:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,a=0;a<2;a++){for(var i=t._context.locales,o=0;o<2;o++){var s=(i[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}i=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":881}],753:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,a=t(\"./notifier\"),i=e.exports={};function o(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);a(r.join(\"<br>\"),\"long\")}},i.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);a(r.join(\"<br>\"),\"stick\")}},i.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.error,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);a(r.join(\"<br>\"),\"stick\")}}},{\"../plot_api/plot_config\":785,\"./notifier\":759}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var a=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));a.exit().remove(),a.enter().append(\"g\").attr(\"class\",r),a.order();var i=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return a.each((function(t){t[0][i]=n.select(this)})),a}},{d3:169}],755:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,a=t.length;for(e=0;e<a;e++)n=Math.max(n,t[e].length);var i=new Array(n);for(e=0;e<n;e++)for(i[e]=new Array(a),r=0;r<a;r++)i[e][r]=t[r][e];return i},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,a,i=t.length;if(t[0].length)for(n=new Array(i),a=0;a<i;a++)n[a]=r.dot(t[a],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),a=0;a<o.length;a++)n[a]=r.dot(t,o[a])}else for(n=0,a=0;a<i;a++)n+=t[a]*e[a];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],756:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],757:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"./array\").isArrayOrTypedArray;function i(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=i(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!a(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,s=0,c=e.split(\".\");s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)s++,c.splice(s,0,Number(a[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:i(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var i,o,l=t,f=\"\",p=[[t,f]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(i=e[o])&&!a(l))throw\"array index but container is not an array\";if(-1===i){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!h(l,i,e[o+1],d))break;if(\"object\"!=typeof(l=l[i])||null===l)throw\"container is not an object\";f=c(f,i),p.push([l,f])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var i,o=a(r),c=!0,u=r,f=n.replace(\"-1\",0),p=!o&&s(r,f),d=e[0];for(i=0;i<t.length;i++)f=n.replace(\"-1\",i),o&&(p=s(u=r[i%r.length],f)),p&&(c=!1),h(t,i,d,p)&&l(t[i],e,n.replace(\"-1\",i))(u);return c}function h(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":731,\"fast-isnumeric\":241}],758:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],759:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=[];e.exports=function(t,e){if(-1===i.indexOf(t)){i.push(t);var r=1e3;a(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(i).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var a=n.select(this);a.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){a.transition().call(s)}));for(var i=a.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&i.append(\"br\"),i.append(\"span\").text(o[l]);\"stick\"===e?a.transition().duration(350).style(\"opacity\",1):a.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=i.indexOf(t);-1!==e&&i.splice(e,1),n.select(this).remove()}))}}},{d3:169,\"fast-isnumeric\":241}],760:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),a=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(a);if(e){if(!r){for(var i=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<i.length;o++){var s=i[o];0===s.indexOf(\"cursor-\")&&t.attr(a,s.substr(7)).classed(s,!1)}t.attr(a)||t.attr(a,\"!!\")}n(t,e)}else r&&(t.attr(a,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":769}],761:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,a=t(\"../constants/numerical\").BADNUM,i=e.exports={};i.tester=function(t){var e,r=t.slice(),n=r[0][0],i=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),i=Math.max(i,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:i,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===a||r<n||r>i||c===a||c<o||c>s)&&(!e||!l(t))}:function(t,e){var l=t[0],c=t[1];if(l===a||l<n||l>i||c===a||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,m=r[0][0],v=r[0][1],y=0;for(u=1;u<g;u++)if(h=m,f=v,m=r[u][0],v=r[u][1],!(l<(p=Math.min(h,m))||l>Math.max(h,m)||c>Math.max(f,v)))if(c<Math.min(f,v))l!==p&&y++;else{if(c===(d=m===h?c:f+(l-h)*(v-f)/(m-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},i.isSegmentBent=function(t,e,r,a){var i,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(i=e+1;i<r;i++)if(o=[t[i][0]-l[0],t[i][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>a)return!0;return!1},i.filter=function(t,e){var r=[t[0]],n=0,a=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(a+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||i.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,a=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":724,\"./matrix\":755}],762:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),a=t(\"regl\");e.exports=function(t,e){var i=t._fullLayout,o=!0;return i._glcanvas.each((function(n){if(!n.regl&&(!n.pick||i._has(\"parcoords\"))){try{n.regl=a({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}n.regl||(o=!1),o&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),o||n({container:i._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":770,regl:512}],763:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],764:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plot_api/plot_config\").dfltConfig;var i={add:function(t,e,r,n,i){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(i)),t.undoQueue.queue.length>a.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)i.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)i.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};i.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,a=[],i=0;i<e.length;i++)r=e[i],a[i]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return a}(t,r),e.apply(null,r)},e.exports=i},{\"../lib\":749,\"../plot_api/plot_config\":785}],765:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var a=(e||\"\")+(r?\"\":\"$\"),i=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(i+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+a):new RegExp(i+t+\"([2-9]|[1-9][0-9]+)?\"+a)}},{}],766:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,a=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(a))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],767:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,a=t(\"./is_plain_object\");e.exports=function t(e,r){for(var i in r){var o=r[i],s=e[i];if(s!==o)if(\"_\"===i.charAt(0)||\"function\"==typeof o){if(i in e)continue;e[i]=o}else if(n(o)&&n(s)&&a(o[0])){if(\"customdata\"===i||\"ids\"===i)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&a(o[c])&&a(s[c])&&t(s[c],o[c])}else a(o)&&a(s)&&(t(s,o),Object.keys(s).length||delete e[i])}}},{\"./array\":731,\"./is_plain_object\":750}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"./loggers\"),i=t(\"./identity\"),o=t(\"../constants/numerical\").BADNUM;function s(t,e){return t<e}function l(t,e){return t<=e}function c(t,e){return t>e}function u(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var i,o,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(o=d>=0?r?s:l:r?u:c,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)o(e[i=Math.floor((h+f)/2)],t)?h=i+1:f=i;return p>90&&a.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t,e){var n,a=(e||{}).unitMinDiff,i=t.slice();for(i.sort(r.sorterAsc),n=i.length-1;n>-1&&i[n]===o;n--);var s=1;a||(s=i[n]-i[0]||1);for(var l,c=s/(n||1)/1e4,u=[],h=0;h<=n;h++){var f=i[h],p=f-l;void 0===l?(u.push(f),l=f):p>c&&(s=Math.min(s,p),u.push(f),l=f)}return{vals:u,minDiff:s}},r.roundUp=function(t,e,r){for(var n,a=0,i=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;a<i&&o++<100;)e[n=c((a+i)/2)]<=t?a=n+s:i=n-l;return e[a]},r.sort=function(t,e){for(var r=0,n=0,a=1;a<t.length;a++){var i=e(t[a],t[a-1]);if(i<0?r=1:i>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||i;for(var r,n=1/0,a=0;a<t.length;a++){var o=e(t[a]);o<n&&(n=o,r=a)}return r}},{\"../constants/numerical\":724,\"./identity\":747,\"./loggers\":753,\"fast-isnumeric\":241}],769:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},{}],770:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),a=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=a);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var i=document.createElement(\"p\");return i.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",i.style.position=\"relative\",i.style.top=\"50%\",i.style.left=\"50%\",i.style.height=\"30%\",i.style.width=\"50%\",i.style.margin=\"-15% 0 0 -25%\",r.appendChild(i),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":615}],771:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,i,o){var s,l;if((!o||o>i.length)&&(o=i.length),n(e)||(e=!1),a(i[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,i[s]);i=l}for(s=0;s<o;s++)n(e)?n(i[s])&&(e=t(+e,+i[s])):e=i[s];return e},r.len=function(t){return r.aggNums((function(t){return t+1}),0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums((function(t,e){return t+e}),0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,a){return e||(e=r.len(t)),n(a)||(a=r.mean(t,e)),r.aggNums((function(t,e){return t+Math.pow(e-a,2)}),0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":731,\"fast-isnumeric\":241}],772:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":125}],773:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../lib\"),i=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var A=t.text(),E=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&A.match(l),C=n.select(t.node().parentNode);if(!C.empty()){var L=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return L+=\"-math\",C.selectAll(\"svg.\"+L).remove(),C.selectAll(\"g.\"+L+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":A,\"data-math\":\"N\"}),E?(e&&e._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),i={fontSize:r};!function(t,e,r){var i,o,s,l;MathJax.Hub.Queue((function(){return o=a.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(i=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),(function(){var r=\"math-output-\"+a.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())}),(function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())a.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==i)return MathJax.Hub.setRenderer(i)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)}))}(E[2],i,(function(n,a,i){C.selectAll(\"svg.\"+L).remove(),C.selectAll(\"g.\"+L+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return P(),void e();var l=C.append(\"g\").classed(L+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":A,\"data-math\":\"Y\"});l.node().appendChild(o.node()),a&&a.node()&&o.node().insertBefore(a.node().cloneNode(!0),o.node().firstChild),o.attr({class:L,height:i.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===L[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===L[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===L[0]&&0!==L.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)}))}))):P(),t}function P(){C.empty()||(L=t.attr(\"class\")+\"-math\",C.select(\"svg.\"+L).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(g,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(i.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var a=l;if(l=[{node:e}],a.length>1)for(var s=1;s<a.length;s++)M(a[s])}function M(t){var e,a=t.type,o={};if(\"a\"===a){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(i.svg,e);if(\"sup\"===a||\"sub\"===a){A(r,\"\\u200b\"),r.appendChild(h);var d=document.createElementNS(i.svg,\"tspan\");A(d,\"\\u200b\"),n.select(d).attr(\"dy\",p[a]),o.dy=f[a],r.appendChild(h),r.appendChild(d)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function A(t,e){t.appendChild(document.createTextNode(e))}function E(t){if(1!==l.length){var n=l.pop();t!==n.type&&a.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else a.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}y.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(m),L=0;L<C.length;L++){var P=C[L],I=P.match(v),z=I&&I[2].toLowerCase(),O=h[z];if(\"br\"===z)u();else if(void 0===O)A(r,S(P));else if(I[1])E(z);else{var D=I[4],R={type:z},F=T(D,x);if(F?(F=F.replace(k,\"$1 fill:\"),O&&(F+=\";\"+O)):O&&(F=O),F&&(R.style=F),\"a\"===z){s=!0;var B=T(D,b);if(B){var N=document.createElement(\"a\");N.href=B,-1!==d.indexOf(N.protocol)&&(R.href=encodeURI(decodeURI(B)),R.target=T(D,_)||\"_blank\",R.popup=T(D,w))}}M(R)}}return s}(t.node(),A)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],g=r.NEWLINES=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,v=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,y=/<br(\\s+.*)?>/i;r.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var x=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,b=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,_=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,w=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&S(n)}var k=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],a=\"...\".length,i=t.split(m),o=[],s=\"\",l=0,c=0;c<i.length;c++){var u=i[c],h=u.match(v),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=a||p<=a)&&o.pop(),r>a?o.push(u.substr(0,d-a)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},A=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function S(t){return t.replace(A,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t}))}function E(t,e,r){var n,a,i,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return a=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},i=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:a()-c.top+\"px\",left:i()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=S,r.sanitizeHTML=function(t){t=t.replace(g,\" \");for(var e=document.createElement(\"p\"),r=e,a=[],i=t.split(m),o=0;o<i.length;o++){var s=i[o],l=s.match(v),c=l&&l[2].toLowerCase();if(c in h)if(l[1])a.length&&(r=a.pop());else{var u=l[4],f=T(u,x),p=f?{style:f}:{};if(\"a\"===c){var y=T(u,b);if(y){var w=document.createElement(\"a\");if(w.href=y,-1!==d.indexOf(w.protocol)){p.href=encodeURI(decodeURI(y));var k=T(u,_);k&&(p.target=k)}}}var M=document.createElement(c);r.appendChild(M),n.select(M).attr(p),r=M,a.push(M)}else r.appendChild(document.createTextNode(S(s)))}return e.innerHTML},r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function a(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var i=a(\"x\",e),o=a(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:i,y:o})}))},r.makeEditable=function(t,e){var r=e.gd,a=e.delegate,i=n.dispatch(\"edit\",\"input\",\"cancel\"),o=a||t;if(t.style({\"pointer-events\":a?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var a=n.select(r).select(\".svg-container\"),o=a.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(E(t,a,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,a=n.select(this).attr(\"class\");(e=a?\".\"+a.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),i.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),i.cancel.call(t,this.textContent)):(i.input.call(t,this.textContent),n.select(this).call(E(t,a,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l)}(),t.style({opacity:0});var a,s=o.attr(\"class\");(a=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(a).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,i,\"on\")}},{\"../constants/alignment\":717,\"../constants/xmlns_namespaces\":725,\"../lib\":749,d3:169}],774:[function(t,e,r){\"use strict\";var n={};function a(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var i=n[t],o=Date.now();if(!i){for(var s in n)n[s].ts<o-6e4&&delete n[s];i=n[t]={ts:0,timer:null}}function l(){r(),i.ts=Date.now(),i.onDone&&(i.onDone(),i.onDone=null)}a(i),o>i.ts+e?l():i.timer=setTimeout((function(){l(),i.timer=null}),e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},r.clear=function(t){if(t)a(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],775:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":241}],776:[function(t,e,r){\"use strict\";var n=e.exports={},a=t(\"../plots/geo/constants\").locationmodeToLayer,i=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=a[t.locationmode],n=e.objects[r];return i(e,n).features}},{\"../plots/geo/constants\":828,\"topojson-client\":551}],777:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],778:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],779:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,a=n.layoutArrayContainers,i=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<i.length;s++)if((r=t.match(i[s]))&&0===r.index){e=r[0];break}if(e||(e=a[a.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":881}],780:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=n.extendFlat,i=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=a({},t);for(var o in n){var s=n[o];i(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var i=a({},t);if(i.editType=e,Array.isArray(t.items)){i.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)i.items[o]=f(t.items[o],e,\"from-root\")}return i}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),a=0;a<n.length;a++)t[n[a]]=!0},overrideAll:h}},{\"../lib\":749}],781:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"gl-mat4/fromQuat\"),i=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=i.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],a=t.title&&t.title[r];n&&!a&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function m(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var a,i=Math.min(t.length,e.length);for(a=0;a<i&&t.charAt(a)===e.charAt(a);a++);return t.substr(0,a).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var i=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var m=g[e];if(i&&i.test(m)){var v=t[m];v.anchor&&\"free\"!==v.anchor&&(v.anchor=u(v.anchor)),v.overlaying&&(v.overlaying=u(v.overlaying)),v.type||(v.isdate?v.type=\"date\":v.islog?v.type=\"log\":!1===v.isdate&&!1===v.islog&&(v.type=\"linear\")),\"withzero\"!==v.autorange&&\"tozero\"!==v.autorange||(v.autorange=!0,v.rangemode=\"tozero\"),delete v.islog,delete v.isdate,delete v.categories,y(v,\"domain\")&&delete v.domain,void 0!==v.autotick&&(void 0===v.tickmode&&(v.tickmode=v.autotick?\"auto\":\"linear\"),delete v.autotick),d(v)}else if(l&&l.test(m)){d(t[m].radialaxis)}else if(h&&h.test(m)){var x=t[m];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(m)){var b=t[m],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],T=_[1],k=_[2],M=a([],w),A=[];for(n=0;n<3;++n)A[n]=T[n]+k*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,a=t[e];if(\"histogramy\"===a.type&&\"xbins\"in a&&!(\"ybins\"in a)&&(a.ybins=a.xbins,delete a.xbins),a.error_y&&\"opacity\"in a.error_y){var l=c.defaults,h=a.error_y.color||(f(a,\"bar\")?c.defaultLine:l[e%l.length]);a.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*a.error_y.opacity),delete a.error_y.opacity}if(\"bardir\"in a&&(\"h\"!==a.bardir||!f(a,\"bar\")&&\"histogram\"!==a.type.substr(0,9)||(a.orientation=\"h\",r.swapXYData(a)),delete a.bardir),\"histogramy\"===a.type&&r.swapXYData(a),\"histogramx\"!==a.type&&\"histogramy\"!==a.type||(a.type=\"histogram\"),\"scl\"in a&&!(\"colorscale\"in a)&&(a.colorscale=a.scl,delete a.scl),\"reversescl\"in a&&!(\"reversescale\"in a)&&(a.reversescale=a.reversescl,delete a.reversescl),a.xaxis&&(a.xaxis=u(a.xaxis,\"x\")),a.yaxis&&(a.yaxis=u(a.yaxis,\"y\")),f(a,\"gl3d\")&&a.scene&&(a.scene=s.subplotsRegistry.gl3d.cleanId(a.scene)),!f(a,\"pie-like\")&&!f(a,\"bar-like\"))if(Array.isArray(a.textposition))for(n=0;n<a.textposition.length;n++)a.textposition[n]=v(a.textposition[n]);else a.textposition&&(a.textposition=v(a.textposition));var p=i.getModule(a);if(p&&p.colorbar){var x=p.colorbar.container,b=x?a[x]:a;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===a.type&&o.isPlainObject(a.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=a.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===a.type||\"ohlc\"===a.type){var T=!1!==(a.increasing||{}).showlegend,k=!1!==(a.decreasing||{}).showlegend,M=g(a.increasing),A=g(a.decreasing);if(!1!==M&&!1!==A){var S=m(M,A,T,k);S&&(a.name=S)}else!M&&!A||a.name||(a.name=M||A)}if(Array.isArray(a.transforms)){var E=a.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var I=0;I<P.length;I++)C.styles.push({target:P[I],value:L[P[I]]})}}}}y(a,\"line\")&&delete a.line,\"marker\"in a&&(y(a.marker,\"line\")&&delete a.marker.line,y(a,\"marker\")&&delete a.marker),c.clean(a),a.autobinx&&(delete a.autobinx,delete a.xbins),a.autobiny&&(delete a.autobiny,delete a.ybins),d(a),a.colorbar&&d(a.colorbar),a.marker&&a.marker.colorbar&&d(a.marker.colorbar),a.line&&a.line.colorbar&&d(a.line.colorbar),a.aaxis&&d(a.aaxis),a.baxis&&d(a.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var a=t.hoverinfo.split(\"+\");for(e=0;e<a.length;e++)\"x\"===a[e]?a[e]=\"y\":\"y\"===a[e]&&(a[e]=\"x\");t.hoverinfo=a.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],a=0;a<e.length;a++)o.isIndex(e[a],t.data.length)?r.push(e[a]):o.warn(\"trace index (\",e[a],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var a=t.obj,i=t.parts,s=i.length,l=i[s-1],c=n(l);if(c&&null===e){var u=i.slice(0,s-1).join(\".\");o.nestedProperty(a,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var a=t._fullData[n],i=0;i<3;i++){var s=h(t,a,_[i]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":615,\"../lib\":749,\"../plots/cartesian/axis_ids\":801,\"../plots/plots\":861,\"../registry\":881,\"fast-isnumeric\":241,\"gl-mat4/fromQuat\":275}],782:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var a=t(\"./template_api\");r.makeTemplate=a.makeTemplate,r.validateTemplate=a.validateTemplate},{\"../snapshot/download\":883,\"./plot_api\":784,\"./template_api\":789,\"./to_image\":790,\"./validate\":791}],783:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),a=t(\"../lib/noop\"),i=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===a||p===a,m=t.layout,v=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&i.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return i.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(m,v),p(t),!0)}var x,b,_,w,T,k,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(v,h).get(),P=[],I=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],T=Object.keys(w),k=w[\"\"],M=l(k),_<0||_>C.length-(M?0:1))i.warn(\"index out of range\",h,_);else if(void 0!==k)T.length>1&&i.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(k)?P.push(_):M?(\"add\"===k&&(k={}),C.splice(_,0,k),L&&L.splice(_,0,{})):i.warn(\"Unrecognized full object edit value\",h,_,k),-1===I&&(I=_);else for(b=0;b<T.length;b++)A=h+\"[\"+_+\"].\",u(C[_],T[b],A).set(w[T[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(m,v),d!==a){var O;if(-1===I)O=S;else{for(z=Math.max(C.length,z),O=[],x=0;x<S.length&&!((_=S[x])>=I);x++)O.push(_);for(x=I;x<z;x++)O.push(x)}for(x=0;x<O.length;x++)d(t,O[x])}else p(t);return!0}},{\"../lib/is_plain_object\":750,\"../lib/loggers\":753,\"../lib/noop\":758,\"../lib/search\":768,\"../registry\":881,\"./container_array_match\":779}],784:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),m=t(\"../components/color\"),v=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),T=t(\"./helpers\"),k=t(\"./subroutines\"),M=t(\"./edit_types\"),A=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0;function E(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function C(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){C(t,m.combine(e,\"white\"))}function P(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var a,s,l,c=t._context;if(e){for(s=Object.keys(e),a=0;a<s.length;a++)\"editable\"!==(l=s[a])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),a=0;a<s.length;a++)c.edits[s[a]]=u;if(e.edits)for(s=Object.keys(e.edits),a=0;a<s.length;a++)(l=s[a])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||i||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(a=0;a<p.length;a++)f[p[a]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function I(t,e){var r,n,a=e+1,i=[];for(r=0;r<t.length;r++)(n=t[r])<0?i.push(a+n):i.push(n);return i}function z(t,e,r){var n,a;for(n=0;n<e.length;n++){if((a=e[n])!==parseInt(a,10))throw new Error(\"all values in \"+r+\" must be integers\");if(a>=t.data.length||a<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(a,n+1)>-1||a>=0&&e.indexOf(-t.data.length+a)>-1||a<0&&e.indexOf(t.data.length+a)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function O(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),z(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&z(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function D(t,e,r,n,i){!function(t,e,r,n){var a=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var i in z(t,r,\"indices\"),e){if(!Array.isArray(e[i])||e[i].length!==r.length)throw new Error(\"attribute \"+i+\" must be an array of length equal to indices array length\");if(a&&(!(i in n)||!Array.isArray(n[i])||n[i].length!==e[i].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var i,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=I(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(i=t.data[r[g]],l=(c=s(i,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,a(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=i(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,e,n,a){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var i={};if(\"string\"==typeof e)i[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,a),Promise.reject();i=o.extendFlat({},e),void 0===a&&(a=n)}Object.keys(i).length&&(t.changed=!0);var s=T.coerceTraceIndices(t,a),l=U(t,i,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&T.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),G(h)),u.style&&h.push(k.doTraceStyle),u.colorbars&&h.push(k.doColorBars),h.push(E)),h.push(f.rehover,f.redrag),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var a=s(e,r),i=a.set;return a.set=function(e){j((n||\"\")+r,a.get(),e,t),i(e)},a}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var a=Array.isArray(e)?e:[],i=Array.isArray(r)?r:[],s=Math.max(a.length,i.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",a[l],i[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)j(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=B(e))}function U(t,e,r){var n,a=t._fullLayout,i=t._fullData,l=t.data,c=a._guiEditing,p=N(a._preGUI,c),g=o.extendDeepAll({},e);V(e);var m,v=M.traceFlags(),y={},x={};function b(){return r.map((function(){}))}function _(t){var e=d.id2name(t);-1===m.indexOf(e)&&m.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function k(t){return\"LAYOUT\"+t+\".range\"}function A(t){for(var e=t;e<i.length;e++)if(i[e]._input===l[t])return i[e]}function S(n,i,o){if(Array.isArray(n))n.forEach((function(t){S(t,i,o)}));else if(!(n in e)&&!T.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(a._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==i&&s.set(i)}}function E(t){return function(e){return i[e][t]}}function C(t){return function(e,n){return!1===e?i[r[n]][t]:null}}for(var L in e){if(T.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,I,z,O,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],I=A(r[n]),O=(z=N(a._tracePreGUI[I._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var j=z.parts[z.parts.length-1],U=L.substr(0,L.length-j.length-1),q=U?U+\".\":\"\",H=U?s(I,U).get():I;if((R=h.getTraceValObject(I,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||O===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===O)||\"funnelarea\"===D!=(\"funnelarea\"===O))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==O||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===O||\"funnelarea\"===O?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),a._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var Z=a._size,X=H.orient,J=\"top\"===X||\"bottom\"===X;if(\"thicknessmode\"===j){var K=J?Z.h:Z.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var Q=J?Z.w:Z.h;S(q+\"len\",H.len*(\"fraction\"===D?1/Q:Q),n)}}x[L][n]=B(O);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var $=P.x&&!P.y?\"h\":\"v\";if((z.get()||$)===I.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[I.orientation]);T.swapXYData(P),v.calc=v.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(T.manageArrayContainers(z,D,x),v.calc=!0):(R?R.arrayOk&&!u.traceIs(I,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(O))?v.calc=!0:M.update(v,R):v.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(m=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(_(rt.xaxis||\"x\"),_(rt.yaxis||\"y\"))}S(m.map(w),!0,0),S(m.map(k),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(z.get())],z.set(Array.isArray(F)?F[0]:F),v.calc=!0}return(v.calc||v.plot)&&(v.fullReplot=!0),{flags:v,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function V(t){var e,r,n,a=o.counterRegex(\"axis\",\".title\",!1,!1),i=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!a.test(r)&&!i.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var a=X(t,n),i=a.flags;i.calc&&(t.calcdata=void 0);var s=[f.previousPromises];i.layoutReplot?s.push(k.layoutReplot):Object.keys(n).length&&(H(t,i,a)||f.supplyDefaults(t),i.legend&&s.push(k.doLegend),i.layoutstyle&&s.push(k.layoutStyles),i.axrange&&G(s,a.rangesAltered),i.ticks&&s.push(k.doTicksRelayout),i.modebar&&s.push(k.doModeBar),i.camera&&s.push(k.doCamera),i.colorbars&&s.push(k.doColorBars),s.push(E)),s.push(f.rehover,f.redrag),c.add(t,q,[t,a.undoit],q,[t,a.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",a.eventData),t}))}function H(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var a in e)if(\"axrange\"!==a&&e[a])return!1;for(var i in r.rangesAltered){var o=d.id2name(i),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==i){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function G(t,e){var r=e?function(t){var r=[],n=!0;for(var a in e){var i=d.getFromId(t,a);if(r.push(a),i._matchGroup)for(var o in i._matchGroup)e[o]||r.push(o);i.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,k.doAutoRangeAndConstraints,r,k.drawData,k.finalDraw)}var Y=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,W=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function X(t,e){var r,n,a,i=t.layout,l=t._fullLayout,c=l._guiEditing,f=N(l._preGUI,c),p=Object.keys(e),g=d.list(t),m=o.extendDeepAll({},e),v={};for(V(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(a=0;a<g.length;a++){var y=g[a]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[a]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=M.layoutFlags(),k={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!T.hasParent(e,t)){var n=f(i,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var I in e){if(T.hasParent(e,I))throw new Error(\"cannot set \"+I+\" and a parent attribute simultaneously\");for(var z=f(i,I),O=e[I],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,j=z.parts.slice(0,D).join(\".\"),U=s(t.layout,j).get(),q=s(l,j).get(),H=z.get();if(void 0!==O){k[I]=O,S[I]=\"reverse\"===R?O:B(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==O)for(var X in G.impliedEdits)E(o.relativeAttr(I,X),G.impliedEdits[X]);if(-1!==[\"width\",\"height\"].indexOf(I))if(O){E(\"autosize\",null);var K=\"height\"===I?\"width\":\"height\";E(K,l[K])}else l[I]=t._initialAutoSize[I];else if(\"autosize\"===I)E(\"width\",O?null:l.width),E(\"height\",O?null:l.height);else if(F.match(Y))P(F),s(l,j+\"._inputRange\").set(null);else if(F.match(W)){P(F),s(l,j+\"._inputRange\").set(null);var Q=s(l,j).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(Z)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){var $=U,tt=\"linear\"===q.type&&\"log\"===O,et=\"log\"===q.type&&\"linear\"===O;if(tt||et){if($&&$.range)if(q.autorange)tt&&($.range=$.range[1]>$.range[0]?[1,2]:[2,1]);else{var rt=$.range[0],nt=$.range[1];tt?(rt<=0&&nt<=0&&E(j+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(j+\".range[0]\",Math.log(rt)/Math.LN10),E(j+\".range[1]\",Math.log(nt)/Math.LN10)):(E(j+\".range[0]\",Math.pow(10,rt)),E(j+\".range[1]\",Math.pow(10,nt)))}else E(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,O,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,O,E)}else E(j+\".autorange\",!0),E(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(A)){var at=s(l,I).get(),it=(O||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,at,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,at,it,E)}var ot=w.containerArrayMatch(I);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(O)?S[I]=null:w.isRemoveVal(O)?S[I]=(s(i,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),M.update(_,lt),v[r]||(v[r]={});var ct=v[r][n];ct||(ct=v[r][n]={}),ct[st]=O,delete e[I]}else\"reverse\"===R?(U.range?U.range.reverse():(E(j+\".autorange\",!0),U.range=[1,0]),q.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===I&&(\"lasso\"===O||\"select\"===O)&&\"lasso\"!==H&&\"select\"!==H||l._has(\"gl2d\")?_.plot=!0:G?M.update(_,G):_.calc=!0,z.set(O))}}for(r in v){w.applyContainerArrayChanges(t,f(i,r),v[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(J(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:k,eventData:m}}function J(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function K(t,e,n,a){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var i=T.coerceTraceIndices(t,a),s=U(t,o.extendFlat({},e),i),l=s.flags,u=X(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&T.clearAxisTypes(t,i,n);var p=[];h.layoutReplot?p.push(k.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),H(t,h,u)||f.supplyDefaults(t),l.style&&p.push(k.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(k.doColorBars),h.legend&&p.push(k.doLegend),h.layoutstyle&&p.push(k.layoutStyles),h.axrange&&G(p,u.rangesAltered),h.ticks&&p.push(k.doTicksRelayout),h.modebar&&p.push(k.doModeBar),h.camera&&p.push(k.doCamera),p.push(E)),p.push(f.rehover,f.redrag),c.add(t,K,[t,s.undoit,u.undoit,s.traces],K,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var $=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],a=t.match(n.pattern);if(a)return{head:a[1],attr:n.attr}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function it(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var a,i,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=a.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(M.update(u,a),\"none\"!==t&&u.nChanges++,n.transition&&a.anim&&u.nChangesAnim++,(Y.test(l)||W.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===i&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(i in t){if(u.calc&&!n.transition)return;var m=t[i],v=e[i],y=r.concat(i);if(l=y.join(\".\"),\"_\"!==i.charAt(0)&&\"function\"!=typeof m&&m!==v){if((\"tick0\"===i||\"dtick\"===i)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==i||!e.autorange)&&(\"zmin\"!==i&&\"zmax\"!==i||\"contourcarpet\"!==e.type)&&(a=c(y))&&(!a._compareAsJSON||JSON.stringify(m)!==JSON.stringify(v))){var b,_=a.valType,w=g(a),T=Array.isArray(m),k=Array.isArray(v);if(T&&k){var A=\"_input_\"+i,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===v)w&&T?u.calc=!0:d();else if(a._isLinkedToArray){var C=[],L=!1;f||(u.arrays[i]=C);var P=Math.min(m.length,v.length),I=Math.max(m.length,v.length);if(P!==I){if(\"arraydraw\"!==a.editType){d();continue}L=!0}for(b=0;b<P;b++)ot(m[b],v[b],y.concat(b),o.extendFlat({inArray:i,arrayIndex:b},n));if(L)for(b=P;b<I;b++)C.push(b)}else!_&&o.isPlainObject(m)?ot(m,v,y,n):w?T&&k?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):T!==k?u.calc=!0:d():T&&k&&m.length===v.length&&String(m)===String(v)||d()}}}for(i in e)if(!(i in t)&&\"_\"!==i.charAt(0)&&\"function\"!=typeof e[i]){if(g(a=c(r.concat(i)))&&Array.isArray(e[i]))return void(u.calc=!0);d()}}function st(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var a={};n.selectAll(\"defs\").each((function(){this.id&&(a[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(a)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var i=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=i.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=i.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var a=(r=f.supplyAnimationDefaults(r)).transition,i=r.frame;function s(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function l(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(i,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,T.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,m=0;function v(t){return Array.isArray(a)?m>=a.length?t.transitionOpts=a[m]:t.transitionOpts=a[0]:t.transitionOpts=a,m++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:v(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:v({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:v({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:v(o.extendFlat({},_))})}for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var k=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){k=d;break}if(k>0&&k<y.length-1){var M=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>k)&&M.push(g);y=M}}y.length>0?function(e){if(0!==e.length){for(var a=0;a<e.length;a++){var o;o=\"byname\"===e[a].type?f.computeFrame(t,e[a].name):e[a].data;var h=l(a),d=s(a);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[a].name,frameOpts:h,transitionOpts:d};a===e.length-1&&(g.onComplete=c(i,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),i())}))},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,a,i,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,m=(u[g]||d[g]||{}).name,v=e[n].name,y=u[m]||d[m];m&&v&&\"number\"==typeof v&&y&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[m]||d[m]).name+'\" with a frame whose name of type \"number\" also equates to \"'+m+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(a=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!a.name)for(;u[a.name=\"frame \"+t._transitionData._counter++];);if(u[a.name]){for(i=0;i<l.length&&(l[i]||{}).name!==a.name;i++);x.push({type:\"replace\",index:i,value:a}),b.unshift({type:\"replace\",index:i,value:l[i]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:a}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,T=f.modifyFrames,k=[t,b],M=[t,x];return c&&c.add(t,w,k,T,M),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,a=t._transitionData._frames,i=[],s=[];if(!e)for(e=[],r=0;r<a.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],i.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:a[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,i];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,i)},r.addTraces=function t(e,n,a){e=o.getGraphDiv(e);var i,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,a;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(a=e[n])||Array.isArray(a)||null===a)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,a),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),T.cleanData(n),i=0;i<n.length;i++)e.data.push(n[i]);for(i=0;i<n.length;i++)l.push(-n.length+i);if(\"undefined\"==typeof a)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(a)||(a=[a]);try{O(e,l,a)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,a),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var a,i,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),z(e,n,\"indices\"),(n=I(n,e.data.length-1)).sort(o.sorterDes),a=0;a<n.length;a+=1)i=e.data.splice(n[a],1)[0],s.push(i);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,a,i){function s(t,e,r){var n,a;if(o.isTypedArray(t))if(r<0){var i=new t.constructor(0),s=R(t,e);r<0?(n=s,a=i):(n=i,a=s)}else if(n=new t.constructor(r),a=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),a.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),a.set(t),a.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),a.set(t.subarray(0,u))}else n=t.concat(e),a=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,a]}var l=D(e=o.getGraphDiv(e),n,a,i,s),u=r.redraw(e),h=[e,l.update,a,l.maxPoints];return c.add(e,r.prependTraces,h,t,arguments),u},r.moveTraces=function t(e,n,a){var i,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),a,n],p=[e,n,a];if(O(e,n,a),n=Array.isArray(n)?n:[n],\"undefined\"==typeof a)for(a=[],i=0;i<n.length;i++)a.push(-n.length+i);for(a=Array.isArray(a)?a:[a],n=I(n,e.data.length-1),a=I(a,e.data.length-1),i=0;i<e.data.length;i++)-1===n.indexOf(i)&&s.push(e.data[i]);for(i=0;i<n.length;i++)l.push({newIndex:a[i],trace:e.data[n[i]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),i=0;i<l.length;i+=1)s.splice(l[i].newIndex,0,l[i].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,a,i){function s(t,e,r){var n,a;if(o.isTypedArray(t))if(r<=0){var i=new t.constructor(0),s=R(e,t);r<0?(n=s,a=i):(n=i,a=s)}else if(n=new t.constructor(r),a=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),a.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),a.set(e.subarray(l)),a.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),a.set(t.subarray(c))}else n=e.concat(t),a=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,a]}var l=D(e=o.getGraphDiv(e),n,a,i,s),u=r.redraw(e),h=[e,l.update,a,l.maxPoints];return c.add(e,r.extendTraces,h,t,arguments),u},r.newPlot=function(t,e,n,a){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,a)},r.plot=function(t,e,a,i){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,a=c.layout,i=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,a,i]))return Promise.reject();e||a||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),P(t,i),a||(a={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(T.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=T.cleanLayout(a)),f.supplyDefaults(t);var m=t._fullLayout,y=m._has(\"cartesian\");if(!m._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var a=n.select(t).selectAll(\".plot-container\").data([0]);a.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var i=a.selectAll(\".svg-container\").data([0]);i.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),i.html(\"\"),e&&(t.data=e);r&&(t.layout=r);p.manager.fillLayout(t),i.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},i.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(100).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)})));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",(function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)})).on(\"cancel\",(function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)}))};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,a);m._replotting=!0,(h||m._shouldCreateBgLayer)&&(st(t),m._shouldCreateBgLayer&&delete m._shouldCreateBgLayer),t.framework!==st&&(t.framework=st,st(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},m._size),M=0;function A(){if(f.clearAutoMarginIds(t),k.drawMarginPushers(t),d.allowAutoMargin(t),m._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&f.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(k.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var C=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=m._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!m._glcanvas&&m._has(\"gl\")&&(m._glcanvas=m._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),m._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),m._glcanvas){m._glcanvas.attr(\"width\",m.width).attr(\"height\",m.height);var a=m._glcanvas.data()[0].regl;if(a&&(Math.floor(m.width)!==a._gl.drawingBufferWidth||Math.floor(m.height)!==a._gl.drawingBufferHeight)){var i=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!M)return o.log(i+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,m),f.supplyDefaults(t),m=t._fullLayout,f.doCalcdata(t),M++,e();o.error(i)}}return\"h\"===m.modebar.orientation?m._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):m._modebardiv.style(\"width\",null).style(\"height\",m.height+\"px\"),f.previousPromises(t)},A,function(){if(f.didMarginChange(w,m._size))return o.syncOrAsync([A,k.layoutStyles],t)}];y&&C.push((function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()})),C.push(k.layoutStyles),y&&C.push((function(){return d.draw(t,h?\"\":\"redraw\")})),C.push(k.drawData,k.finalDraw,v,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(C,t);return L&&L.then||(L=Promise.resolve()),L.then((function(){return E(t),t}))},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,a){var i,l;t=o.getGraphDiv(t),T.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,a=d.config,i=d.frames}var g=!1;if(a){var m=o.extendDeep({},t._context);t._context=void 0,P(t,a),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var a=e[n],i=r[n];if(a!==i)if(o.isPlainObject(a)&&o.isPlainObject(i)){if(t(a,i))return!0}else{if(!Array.isArray(a)||!Array.isArray(i))return!0;if(a.length!==i.length)return!0;for(var s=0;s<a.length;s++)if(a[s]!==i[s]){if(!o.isPlainObject(a[s])||!o.isPlainObject(i[s]))return!0;if(t(a[s],i[s]))return!0}}}}(m,t._context)}t.data=e||[],T.cleanData(t.data),t.layout=n||{},T.cleanLayout(t.layout),function(t,e,r,n){var a,i,l,c,u,h,f,p,d=n._preGUI,g=[],m={};for(a in d){if(u=et(a,$)){if(i=u.attr||u.head+\".uirevision\",(c=(l=s(n,i).get())&&rt(i,e))&&c===l&&(null===(h=d[a])&&(h=void 0),it(p=(f=s(e,a)).get(),h))){void 0===p&&\"autorange\"===a.substr(a.length-9)&&g.push(a.substr(0,a.length-10)),f.set(B(s(n,a).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+a);delete d[a],\"range[\"===a.substr(a.length-8,6)&&(m[a.substr(0,a.length-9)]=1)}for(var v=0;v<g.length;v++){var y=g[v];if(m[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,T=b[_],k=null;for(a in T){if(!k){var M=nt(_,r);if(M<0){delete b[_];break}var A=at(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}k=t[A]}if(u=et(a,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=w.uirevision,void 0===(c=k.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=T[a])&&(h=void 0),it(p=(f=s(k,a)).get(),h))){f.set(B(s(w,a).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+a+\" in trace uid \"+_);delete T[a]}}}(t.data,t.layout,c,p);for(var v=Object.getOwnPropertyNames(p),y=0;y<v.length;y++){var x=v[y],b=x.substring(0,5);if(\"xaxis\"===b||\"yaxis\"===b){var _=p[x]._emptyCategories;_&&_()}}f.supplyDefaults(t,{skipUpdateCalc:!0});var w=t._fullData,A=t._fullLayout,S=void 0===A.datarevision,C=A.transition,L=function(t,e,r,n,a){var i=M.layoutFlags();function o(t){return h.getLayoutValObject(r,t)}i.arrays={},i.rangesAltered={},i.nChanges=0,i.nChangesAnim=0,ot(e,r,[],{getValObject:o,flags:i,immutable:n,transition:a,gd:t}),(i.plot||i.calc)&&(i.layoutReplot=!0);a&&i.nChanges&&i.nChangesAnim&&(i.anim=i.nChanges===i.nChangesAnim?\"all\":\"some\");return i}(t,p,A,S,C),I=L.newDataRevision,z=function(t,e,r,n,a,i){var o=e.length===r.length;if(!a&&!o)return{fullReplot:!0,calc:!0};var s,l,c=M.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:a,newDataRevision:i,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);a&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,w,S,C,I);J(t)&&(L.layoutReplot=!0),z.calc||L.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,w);var O=[];if(i&&(t._transitionData={},f.createTransitionData(t),O.push((function(){return r.addFrames(t,i)}))),A.transition&&!g&&(z.anim||L.anim))L.ticks&&O.push(k.doTicksRelayout),f.doCalcdata(t),k.doAutoRangeAndConstraints(t),O.push((function(){return f.transitionFromReact(t,z,L,p)}));else if(z.fullReplot||L.layoutReplot||g)t._fullLayout._skipDefaults=!0,O.push(r.plot);else{for(var D in L.arrays){var R=L.arrays[D];if(R.length){var F=u.getComponentMethod(D,\"drawOne\");if(F!==o.noop)for(var N=0;N<R.length;N++)F(t,R[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}O.push(f.previousPromises),z.style&&O.push(k.doTraceStyle),(z.colorbars||L.colorbars)&&O.push(k.doColorBars),L.legend&&O.push(k.doLegend),L.layoutstyle&&O.push(k.layoutStyles),L.axrange&&G(O),L.ticks&&O.push(k.doTicksRelayout),L.modebar&&O.push(k.doModeBar),L.camera&&O.push(k.doCamera),O.push(E)}O.push(f.rehover,f.redrag),(l=o.syncOrAsync(O,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,a);return l.then((function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t}))},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return T.cleanData(t.data),T.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},r.relayout=q,r.restyle=F,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=K,r._guiRelayout=Q(q),r._guiRestyle=Q(F),r._guiUpdate=Q(K),r._storeDirectGUIEdit=function(t,e,r){for(var n in r){j(n,s(t,n).get(),r[n],e)}}},{\"../components/color\":615,\"../components/drawing\":637,\"../constants/xmlns_namespaces\":725,\"../lib\":749,\"../lib/events\":738,\"../lib/queue\":764,\"../lib/svg_text_utils\":773,\"../plots/cartesian/axes\":798,\"../plots/cartesian/constants\":804,\"../plots/cartesian/graph_interact\":807,\"../plots/cartesian/select\":817,\"../plots/plots\":861,\"../plots/polar/legacy\":869,\"../registry\":881,\"./edit_types\":780,\"./helpers\":781,\"./manage_arrays\":783,\"./plot_config\":785,\"./plot_schema\":786,\"./subroutines\":788,d3:169,\"fast-isnumeric\":241,\"has-hover\":414}],785:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},a={};!function t(e,r){for(var n in e){var a=e[n];a.valType?r[n]=a.dflt:(r[n]||(r[n]={}),t(a,r[n]))}}(n,a),e.exports={configAttributes:n,dfltConfig:a}},{}],786:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),a=t(\"../lib\"),i=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=a.extendFlat,d=a.extendDeepAll,g=a.isPlainObject,m=a.isArrayOrTypedArray,v=a.nestedProperty,y=a.valObjectMeta,x=[\"_isSubplotObj\",\"_isLinkedToArray\",\"_arrayAttrRegexps\",\"_deprecated\"];function b(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(_(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!_(e[++r]))return!1}else if(\"info_array\"===t.valType){var a=e[++r];if(!_(a))return!1;var i=t.items;if(Array.isArray(i)){if(a>=i.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!_(o))return!1;t=i[a][o]}else t=i[a]}else t=i}}return t}function _(t){return t===Math.round(t)&&t>=0}function w(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var a=0;a<e.attr.length;a++)M(r,e,e.attr[a]);else M(r,e,\"subplot\"===e.attr?e.name:e.attr)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var i=(e=n.componentsRegistry[t]).schema;if(i&&(i.subplots||i.layout)){var s=i.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&A(r,e.layoutAttributes,e.name)}return{layoutAttributes:k(r)}}function T(){var t={frames:d({},s)};return k(t),t.frames}function k(t){return function(t){r.crawl(t,(function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")}))}(t),function(t){r.crawl(t,(function(t,e,r){if(t){var n=t._isLinkedToArray;n&&(delete t._isLinkedToArray,r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function M(t,e,r){var n=v(t,r),a=d({},e.layoutAttributes);a._isSubplotObj=!0,n.set(a)}function A(t,e,r){var n=v(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=\"_isSubplotObj\",r.IS_LINKED_TO_ARRAY=\"_isLinkedToArray\",r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=x,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach((function(e){t[e]=function(t){var e,a;\"area\"===t?(e={attributes:u},a={}):(e=n.modules[t]._module,a=e.basePlotModule);var o={type:null},s=d({},i),l=d({},e.attributes);r.crawl(l,(function(t,e,r,n,a){v(s,a).set(void 0),void 0===t&&v(l,a).set(void 0)})),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),a.attributes&&d(o,a.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:k(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=k(h)}e.animatable||r.crawl(c,(function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim}));return c}(e)}));var e={};return Object.keys(n.transformsRegistry).forEach((function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var a=n.componentsRegistry[e];a.schema&&a.schema.transforms&&a.schema.transforms[t]&&Object.keys(a.schema.transforms[t]).forEach((function(e){A(r,a.schema.transforms[t][e],e)}))})),{attributes:k(r)}}(t)})),{defs:{valObjects:y,metaKeys:x.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:w(),transforms:e,frames:T(),animation:k(l),config:k(c)}},r.crawl=function(t,e,n,a){var i=n||0;a=a||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===x.indexOf(n)){var s=(a?a+\".\":\"\")+n;e(o,n,t,i,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,i+1,s)}}))},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,a=[],o=[],s=[];function l(t,r,i,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,i){var l=e[o[r]],c=i+o[r];if(r===o.length-1)m(l)&&a.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(i,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return a},r.getTraceValObject=function(t,e){var r,a,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return i.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!_(c)||c>=l.length)return!1;a=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)a=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||i.type.dflt]||{})._module),!h)return!1;if(!(a=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(a=f.attributes[o])}a||(a=i[o])}return b(a,e,s)},r.getLayoutValObject=function(t,e){return b(function(t,e){var r,a,i,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((i=l[r]).attrRegex&&i.attrRegex.test(e)){if(i.layoutAttrOverrides)return i.layoutAttrOverrides;!c&&i.layoutAttributes&&(c=i.layoutAttributes)}var u=i.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(a in n.componentsRegistry){if(\"colorscale\"===(i=n.componentsRegistry[a]).name&&0===e.indexOf(\"coloraxis\"))return i.layoutAttributes[e];if(!i.schema&&e===i.name)return i.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":749,\"../plots/animation_attributes\":792,\"../plots/attributes\":794,\"../plots/frame_attributes\":827,\"../plots/layout_attributes\":852,\"../plots/polar/legacy/area_attributes\":867,\"../plots/polar/legacy/axis_attributes\":868,\"../registry\":881,\"./edit_types\":780,\"./plot_config\":785}],787:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plots/attributes\"),i={name:{valType:\"string\",editType:\"none\"}};function o(t){return t&&\"string\"==typeof t}function s(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}i.templateitemname={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=i.name,e.templateitemname=i.templateitemname,e},r.traceTemplater=function(t){var e,r,i={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(i[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},a,\"type\"),_template:null};if(e in i){r=t[e];var l=i[e]%r.length;i[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var a=t._template,i=a&&(a[e]||r&&a[r]);return n.isPlainObject(i)||(i=null),t[e]={_template:i}},r.arrayTemplater=function(t,e,r){var n=t._template,a=n&&n[s(e)],i=n&&n[e];Array.isArray(i)&&i.length||(i=[]);var l={};return{newItem:function(t){var e={name:t.name,_input:t},n=e.templateitemname=t.templateitemname;if(!o(n))return e._template=a,e;for(var s=0;s<i.length;s++){var c=i[s];if(c.name===n)return l[n]=1,e._template=c,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<i.length;e++){var r=i[e],n=r.name;if(o(n)&&!l[n]){var a={_template:r,name:n,_input:{_templateitemname:n}};a.templateitemname=r.templateitemname,t.push(a),l[n]=1}}return t}}},r.arrayDefaultKey=s,r.arrayEditor=function(t,e,r){var a=(n.nestedProperty(t,e).get()||[]).length,i=r._index,o=i>=a&&(r._input||{})._templateitemname;o&&(i=a);var s,l=e+\"[\"+i+\"]\";function c(){s={},o&&(s[l]={},s[l].templateitemname=o)}function u(t,e){o?n.nestedProperty(s[l],t).set(e):s[l+\".\"+t]=e}function h(){var t=s;return c(),t}return c(),{modifyBase:function(t,e){s[t]=e},modifyItem:u,getUpdateObj:h,applyUpdate:function(e,r){e&&u(e,r);var a=h();for(var i in a)n.nestedProperty(t,i).set(a[i])}}}},{\"../lib\":749,\"../plots/attributes\":794}],788:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../registry\"),i=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,m=d.clean,v=t(\"../plots/cartesian/autorange\").doAutoRange;function y(t,e,r){for(var n=0;n<r.length;n++){var a=r[n][0],i=r[n][1];if(!(a[0]>=t[1]||a[1]<=t[0])&&(i[0]<e[1]&&i[1]>e[0]))return!0}return!1}function x(t){var e,a,s,u,d,g,m=t._fullLayout,v=m._size,x=v.p,_=f.list(t,\"\",!0);if(m._paperdiv.style({width:t._context.responsive&&m.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":m.width+\"px\",height:t._context.responsive&&m.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":m.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,m.width,m.height),t._context.setBackground(t,m.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!m._has(\"cartesian\"))return i.previousPromises(t);function T(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-x-n:e._offset+e._length+x+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+x+n:e._offset-x-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<_.length;e++){var k=(u=_[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=T(u,k,u.side),u._mainMirrorPosition=u.mirror&&k?T(u,k,p.OPPOSITE_SIDE[u.side]):null}var M=[],A=[],S=[],E=1===l.opacity(m.paper_bgcolor)&&1===l.opacity(m.plot_bgcolor)&&m.paper_bgcolor===m.plot_bgcolor;for(a in m._plots)if((s=m._plots[a]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var C=s.xaxis.domain,L=s.yaxis.domain,P=s.plotgroup;if(y(C,L,S)){var I=P.node(),z=s.bg=o.ensureSingle(P,\"rect\",\"bg\");I.insertBefore(z.node(),I.childNodes[0]),A.push(a)}else P.select(\"rect.bg\").remove(),S.push([C,L]),E||(M.push(a),A.push(a))}var O,D,R,F,B,N,j,U,V,q,H,G,Y,W=m._bgLayer.selectAll(\".bg\").data(M);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each((function(t){m._plots[t].bg=n.select(this)})),e=0;e<A.length;e++)s=m._plots[A[e]],d=s.xaxis,g=s.yaxis,s.bg&&s.bg.call(c.setRect,d._offset-x,g._offset-x,d._length+2*x,g._length+2*x).call(l.fill,m.plot_bgcolor).style(\"stroke-width\",0);if(!m._hasOnlyLargeSploms)for(a in m._plots){s=m._plots[a],d=s.xaxis,g=s.yaxis;var Z,X,J=s.clipId=\"clip\"+m._uid+a+\"plot\",K=o.ensureSingleById(m._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(Z=null,X=J):(Z=J,X=null),c.setClipUrl(s.plot,Z,t),s.layerClipId=X}function Q(t){return\"M\"+O+\",\"+t+\"H\"+D}function $(t){return\"M\"+d._offset+\",\"+t+\"h\"+d._length}function tt(t){return\"M\"+t+\",\"+U+\"V\"+j}function et(t){return\"M\"+t+\",\"+g._offset+\"v\"+g._length}function rt(t,e,r){if(!t.showline||a!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(a in m._plots){s=m._plots[a],d=s.xaxis,g=s.yaxis;var nt=\"M0,0\";b(d,a)&&(B=w(d,\"left\",g,_),O=d._offset-(B?x+B:0),N=w(d,\"right\",g,_),D=d._offset+d._length+(N?x+N:0),R=T(d,g,\"bottom\"),F=T(d,g,\"top\"),!(Y=!d._anchorAxis||a!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[a]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",nt);var at=\"M0,0\";b(g,a)&&(H=w(g,\"bottom\",d,_),j=g._offset+g._length+(H?x:0),G=w(g,\"top\",d,_),U=g._offset-(G?x:0),V=T(g,d,\"left\"),q=T(g,d,\"right\"),!(Y=!g._anchorAxis||a!==g._mainSubplot)||\"allticks\"!==g.mirror&&\"all\"!==g.mirror||(g._linepositions[a]=[V,q]),at=rt(g,tt,et),Y&&g.showline&&(\"all\"===g.mirror||\"allticks\"===g.mirror)&&(at+=tt(V)+tt(q)),s.ylines.style(\"stroke-width\",g._lw+\"px\").call(l.stroke,g.showline?g.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",at)}return f.makeClipPaths(t),i.previousPromises(t)}function b(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function _(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var a=p.FROM_BL[e];return r.side===e?n.domain[a]===t.domain[a]:r.mirror&&n.domain[1-a]===t.domain[1-a]}function w(t,e,r,n){if(_(t,e,r))return r._lw;for(var a=0;a<n.length;a++){var i=n[a];if(i._mainAxis===r._mainAxis&&_(t,e,i))return i._lw}return 0}function T(t,e){var r=t.title,n=t._size,a=0;switch(\"start\"===e?a=r.pad.l:\"end\"===e&&(a=-r.pad.r),r.xref){case\"paper\":return n.l+n.w*r.x+a;case\"container\":default:return t.width*r.x+a}}function k(t,e){var r=t.title,n=t._size,a=0;if(\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(a=r.pad.t):a=-r.pad.b,\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+a;case\"container\":default:return t.height-t.height*r.y+a}}r.layoutStyles=function(t){return o.syncOrAsync([i.doAutoMargin,x],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=\"middle\";o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=\"start\");return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:T(e,r),y:k(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return i.style(t),a.getComponentMethod(\"legend\",\"draw\")(t),i.previousPromises(t)},r.doColorBars=function(t){return a.getComponentMethod(\"colorbar\",\"draw\")(t),i.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,a.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return a.getComponentMethod(\"legend\",\"draw\")(t),i.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(a.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),i.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return i.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var a=e[r[n]];a._scene.setViewport(a)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),i.style(t),a.getComponentMethod(\"shapes\",\"draw\")(t),a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"images\",\"draw\")(t),e._replotting=!1,i.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,a=t._fullData,i=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<a.length;r++){var l=a[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(i,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<i.length;r++)(n=e._plots[i[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,a=f.list(t,\"\",!0),i=n._axisMatchGroups||[],s={},l=0;l<a.length;l++)e=a[l],m(t,e),v(t,e),s[e._id]=1;g(t);t:for(var c=0;c<i.length;c++){var u,h=i[c],p=null;for(u in h)if(s[(e=f.getFromId(t,u))._id]){if(!1===e.autorange)continue t;r=o.simpleMap(e.range,e.r2l),p?p[0]<p[1]?(p[0]=Math.min(p[0],r[0]),p[1]=Math.max(p[1],r[1])):(p[0]=Math.max(p[0],r[0]),p[1]=Math.min(p[1],r[1])):p=r}for(u in h)(e=f.getFromId(t,u)).range=o.simpleMap(p,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){a.getComponentMethod(\"rangeslider\",\"draw\")(t),a.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"rangeselector\",\"draw\")(t),a.getComponentMethod(\"sliders\",\"draw\")(t),a.getComponentMethod(\"updatemenus\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":615,\"../components/drawing\":637,\"../components/modebar\":675,\"../components/titles\":710,\"../constants/alignment\":717,\"../lib\":749,\"../lib/clear_gl_canvases\":733,\"../plots/cartesian/autorange\":797,\"../plots/cartesian/axes\":798,\"../plots/cartesian/constraints\":805,\"../plots/plots\":861,\"../registry\":881,d3:169}],789:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=n.isPlainObject,i=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,i,o=Object.keys(t).sort();function s(e,r,n){if(a(r)&&a(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(i=0;i<r.length;i++){var s=r[i],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(i=0;i<h.length;i++)r.push(h[i]._template);for(i=0;i<r.length;i++)delete r[i].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,i,o){var s=o&&r(o);for(var c in t){var u=t[c],p=g(t,c,i),d=g(t,c,o),m=r(d);if(!m){var v=h(c);v!==c&&(m=r(d=g(t,v,o)))}if((!s||s!==m)&&!(!m||m._noTemplating||\"data_array\"===m.valType||m.arrayOk&&Array.isArray(u)))if(!m.valType&&a(u))f(u,e,r,p,d);else if(m._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(a(w)){var T=w.name;if(T)b[T]||(f(w,e,r,g(u,x,p),g(u,x,d)),x++,b[T]=1);else if(!y){var k=g(t,l.arrayDefaultKey(c),i),M=g(u,x,p);f(w,e,r,M,g(u,x,d));var A=n.nestedProperty(e,M);n.nestedProperty(e,k).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,p).set(u)}}}function p(t,e){return i.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return i.getTraceValObject(t,n.nestedProperty({},e).parts)}function g(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function m(t){for(var e=0;e<t.length;e++)if(a(t[e]))return!0}function v(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var i={data:{},layout:{}};e.forEach((function(t){var e={};f(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),a=i.data[r];a||(a=i.data[r]=[]),a.push(e)})),f(r,i.layout,p.bind(null,r)),delete i.layout.template;var l=r.template;if(a(l)){var h,g,m,v,y,x,b=l.layout;a(b)&&u(b,i.layout);var _=l.data;if(a(_)){for(g in i.data)if(m=_[g],Array.isArray(m)){for(x=(y=i.data[g]).length,v=m.length,h=0;h<x;h++)u(m[h%v],y[h]);for(h=x;h<v;h++)y.push(n.extendDeep({},m[h]))}for(g in _)g in i.data||(i.data[g]=n.extendDeep([],_[g]))}}return i},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),i=r.layout||{};a(e)||(e=i.template||{});var s=e.layout,l=e.data,u=[];r.layout=i,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,p=r._fullData,d={};if(a(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&a(e[n])){var i,o=h(n),s=[];for(i=0;i<r.length;i++)s.push(g(e,n,r[i])),o!==n&&s.push(g(e,o,r[i]));for(i=0;i<s.length;i++)d[s[i]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&a(e[n])){var i=g(e,n,r);d[i]?t(e[n],i):u.push({code:\"unused\",path:i})}}(s,\"layout\")):u.push({code:\"layout\"}),a(l)){for(var y,x={},b=0;b<p.length;b++){var _=p[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,T=x[y]||0;w>T?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var i=e[n],o=g(e,n,r);a(i)?(Array.isArray(e)&&!1===i._template&&i.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:i.templateitemname}),t(i,o)):Array.isArray(i)&&m(i)&&t(i,o)}}({data:p,layout:f},\"\"),u.length)return u.map(v)}},{\"../lib\":749,\"../plots/attributes\":794,\"../plots/plots\":861,\"./plot_config\":785,\"./plot_schema\":786,\"./plot_template\":787}],790:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"./plot_api\"),i=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../snapshot/helpers\"),l=t(\"../snapshot/tosvg\"),c=t(\"../snapshot/svgtoimg\"),u=t(\"../version\").version,h={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,f,p,d;function g(t){return!(t in e)||o.validate(e[t],h[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],f=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),f=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!g(\"width\")&&null!==e.width||!g(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!g(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var m={};function v(t,r){return o.coerce(e,m,h,t,r)}var y=v(\"format\"),x=v(\"width\"),b=v(\"height\"),_=v(\"scale\"),w=v(\"setBackground\"),T=v(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var M=o.extendFlat({},f);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function C(){return new Promise((function(t,e){var r=l(k,y,_),n=k._fullLayout.width,h=k._fullLayout.height;function f(){a.purge(k),document.body.removeChild(k)}if(\"full-json\"===y){var p=i.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),f(),t(T?p:s.encodeJSON(p))}if(f(),\"svg\"===y)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:y,width:n,height:h,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){a.plot(k,r,M,A).then(S).then(E).then(C).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},{\"../lib\":749,\"../plots/plots\":861,\"../snapshot/helpers\":885,\"../snapshot/svgtoimg\":887,\"../snapshot/tosvg\":889,\"../version\":1339,\"./plot_api\":784,\"fast-isnumeric\":241}],791:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plots/plots\"),i=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,a,i,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var p=h[f];if(\"transforms\"!==p){var v=o.slice();v.push(p);var y=t[p],x=e[p],b=m(r,p),_=(b||{}).valType,w=\"info_array\"===_,T=\"colorscale\"===_,k=(b||{}).items;if(g(r,p))if(s(y)&&s(x)&&\"any\"!==_)u(y,x,b,a,i,v);else if(w&&l(y)){y.length>x.length&&a.push(d(\"unused\",i,v.concat(x.length)));var M,A,S,E,C,L=x.length,P=Array.isArray(k);if(P&&(L=Math.min(L,k.length)),2===b.dimensions)for(A=0;A<L;A++)if(l(y[A])){y[A].length>x[A].length&&a.push(d(\"unused\",i,v.concat(A,x[A].length)));var I=x[A].length;for(M=0;M<(P?Math.min(I,k[A].length):I);M++)S=P?k[A][M]:k,E=y[A][M],C=x[A][M],n.validate(E,S)?C!==E&&C!==+E&&a.push(d(\"dynamic\",i,v.concat(A,M),E,C)):a.push(d(\"value\",i,v.concat(A,M),E))}else a.push(d(\"array\",i,v.concat(A),y[A]));else for(A=0;A<L;A++)S=P?k[A]:k,E=y[A],C=x[A],n.validate(E,S)?C!==E&&C!==+E&&a.push(d(\"dynamic\",i,v.concat(A),E,C)):a.push(d(\"value\",i,v.concat(A),E))}else if(b.items&&!w&&l(y)){var z,O,D=k[Object.keys(k)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((O=v.slice()).push(F),s(y[F])&&s(x[z])){R.push(F);var B=y[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?a.push(d(\"invisible\",i,O)):u(B,N,D,a,i,O)}}for(z=0;z<y.length;z++)(O=v.slice()).push(z),s(y[z])?-1===R.indexOf(z)&&a.push(d(\"unused\",i,O)):a.push(d(\"object\",i,O,y[z]))}else!s(y)&&s(x)?a.push(d(\"object\",i,v,y)):c(y)||!c(x)||w||T?p in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&a.push(d(\"dynamic\",i,v,y,x)):a.push(d(\"value\",i,v,y)):a.push(d(\"unused\",i,v,y)):a.push(d(\"array\",i,v,y));else a.push(d(\"schema\",i,v))}}return a}function h(t,e){for(var r=t.layout.layoutAttributes,a=0;a<e.length;a++){var i=e[a],o=t.traces[i.type],s=o.layoutAttributes;s&&(i.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}e.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,f=i.get(),p=[],g={_context:n.extendFlat({},o)};l(t)?(g.data=n.extendDeep([],t),r=t):(g.data=[],r=[],p.push(d(\"array\",\"data\"))),s(e)?(g.layout=n.extendDeep({},e),c=e):(g.layout={},c={},arguments.length>1&&p.push(d(\"object\",\"layout\"))),a.supplyDefaults(g);for(var m=g._fullData,v=r.length,y=0;y<v;y++){var x=r[y],b=[\"data\",y];if(s(x)){var _=m[y],w=_.type,T=f.traces[w].attributes;T.type={valType:\"enumerated\",values:[w]},!1===_.visible&&!1!==x.visible&&p.push(d(\"invisible\",b)),u(x,_,T,p,b);var k=x.transforms,M=_.transforms;if(k){l(k)||p.push(d(\"array\",b,[\"transforms\"])),b.push(\"transforms\");for(var A=0;A<k.length;A++){var S=[\"transforms\",A],E=k[A].type;if(s(k[A])){var C=f.transforms[E]?f.transforms[E].attributes:{};C.type={valType:\"enumerated\",values:Object.keys(f.transforms)},u(k[A],M[A],C,p,b,S)}else p.push(d(\"object\",b,S))}}}else p.push(d(\"object\",b))}var L=g._fullLayout,P=h(f,m);return u(c,L,P,p,\"layout\"),0===p.length?void 0:p};var f={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":p(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":p(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return p(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return p(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[p(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?p(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[p(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function p(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function d(t,e,r,a,i){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=f[t](e,c,a,i);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function g(t,e){var r=y(e),n=r.keyMinusId,a=r.id;return!!(n in t&&t[n]._isSubplotObj&&a)||e in t}function m(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":749,\"../plots/plots\":861,\"./plot_config\":785,\"./plot_schema\":786}],792:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],793:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var i,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=a.arrayTemplater(e,s,l);for(i=0;i<u.length;i++){var p=u[i];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=i,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(i=0;i<d.length;i++)(o=d[i])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(i=0;i<g;i++)n.relinkPrivateKeys(h[i],c[i])}return h}},{\"../lib\":749,\"../plot_api/plot_template\":787}],794:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":646}],795:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=a.dateTime2ms,o=a.incrementMonth,s=t(\"../../constants/numerical\").ONEAVGMONTH;e.exports=function(t,e,r,a){if(\"date\"!==e.type)return a;var l=t[r+\"periodalignment\"];if(!l)return a;var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return a}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var h=+u.substring(1);if(!(h>0&&Math.round(h)===h))return a;c=h}for(var f=e.calendar,p=\"start\"===l,d=\"end\"===l,g=t[r+\"period0\"],m=i(g,f)||0,v=[],y=a.length,x=0;x<y;x++){var b,_,w,T=a[x];if(c){for(b=Math.round((T-m)/(c*s)),w=o(m,c*b,f);w>T;)w=o(w,-c,f);for(;w<=T;)w=o(w,c,f);_=o(w,-c,f)}else{for(w=m+(b=Math.round((T-m)/u))*u;w>T;)w-=u;for(;w<=T;)w+=u;_=w-u}v[x]=p?_:d?w:(_+w)/2}return v}},{\"../../constants/numerical\":724,\"../../lib\":749,\"fast-isnumeric\":241}],796:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],797:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,i=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return a.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=a.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var m,v,y,x,b,_,w=e.rangemode,T=\"tozero\"===w,k=\"nonnegative\"===w,M=e._length,A=M/10,S=function(t,r){var n=0;if(e.rangebreaks)for(var a=e.locateBreaks(t,r),i=0;i<a.length;i++){var o=a[i];n+=o.max-o.min}return n},E=0;for(r=0;r<u.length;r++)for(m=u[r],n=0;n<h.length;n++)(_=(v=h[n]).val-m.val-S(m.val,v.val))>0&&((b=M-o(m)-o(v))>A?_/b>E&&(y=m,x=v,E=_/b):_/M>E&&(y={val:m.val,pad:0},x={val:v.val,pad:0},E=_/M));if(f===p){var C=f-1,L=f+1;if(T)if(0===f)i=[0,1];else{var P=(f>0?h:u).reduce((function(t,e){return Math.max(t,o(e))}),0),I=f/(1-Math.min(.5,P/M));i=f>0?[0,I]:[I,0]}else i=k?[Math.max(0,C),Math.max(1,L)]:[C,L]}else T?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):k&&(y.val-E*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),E=(x.val-y.val-S(m.val,v.val))/(M-o(y)-o(x)),i=[y.val-E*o(y),x.val+E*o(x)];return d&&i.reverse(),a.simpleMap(i,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,a,i=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[i];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)a=s.min[n],u(l,a.val,a.pad,{extrapad:a.extrapad});for(n=0;n<s.max.length;n++)a=s.max[n],h(c,a.val,a.pad,{extrapad:a.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,a){for(var i=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(a(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}a(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=i&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<i}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=a.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var i=e._anchorAxis;if(i&&i.rangeslider){var l=i.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),i._input.rangeslider[e._name]=a.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var a,o,s,l,c,f,d,g,m,v=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),C=M(r.vpadminus||r.vpad);if(!T){if(g=1/0,m=-1/0,w)for(a=0;a<x;a++)(o=e[a])<g&&o>0&&(g=o),o>m&&o<i&&(m=o);else for(a=0;a<x;a++)(o=e[a])<g&&o>-i&&(g=o),o>m&&o<i&&(m=o);e=[g,m],x=2}var L={tozero:_,extrapad:b};function P(r){s=e[r],n(s)&&(f=A(r),d=S(r),k?(l=t.c2l(s)-C(r),c=t.c2l(s)+E(r)):(g=s-C(r),m=s+E(r),w&&g<m/10&&(g=m/10),l=t.c2l(g),c=t.c2l(m)),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(v,l,d,L),p(c)&&h(y,c,f,L))}var I=Math.min(6,x);for(a=0;a<I;a++)P(a);for(a=x-1;a>=I;a--)P(a);return{min:v,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../registry\":881,\"fast-isnumeric\":241}],798:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEMAXYEAR,m=d.ONEAVGYEAR,v=d.ONEMINYEAR,y=d.ONEMAXQUARTER,x=d.ONEAVGQUARTER,b=d.ONEMINQUARTER,_=d.ONEMAXMONTH,w=d.ONEAVGMONTH,T=d.ONEMINMONTH,k=d.ONEWEEK,M=d.ONEDAY,A=M/2,S=d.ONEHOUR,E=d.ONEMIN,C=d.ONESEC,L=d.MINUS_SIGN,P=d.BADNUM,I=t(\"../../constants/alignment\"),z=I.MID_SHIFT,O=I.CAP_SHIFT,D=I.LINE_SPACING,R=I.OPPOSITE_SIDE,F=e.exports={};F.setConvert=t(\"./set_convert\");var B=t(\"./axis_autotype\"),N=t(\"./axis_ids\");F.id2name=N.id2name,F.name2id=N.name2id,F.cleanId=N.cleanId,F.list=N.list,F.listIds=N.listIds,F.getFromId=N.getFromId,F.getFromTrace=N.getFromTrace;var j=t(\"./autorange\");F.getAutoRange=j.getAutoRange,F.findExtremes=j.findExtremes;function U(t){var e=1e-4*(t[1]-t[0]);return[t[0]-e,t[1]+e]}F.coerceRef=function(t,e,r,n,a,i){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return a||(a=l[0]||i),i||(i=a),u[c]={valType:\"enumerated\",values:l.concat(i?[i]:[]),dflt:a},s.coerce(t,e,u,c)},F.coercePosition=function(t,e,r,n,a,i){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(a,i);else{var c=F.getFromId(e,n);l=r(a,i=c.fraction2r(i)),o=c.cleanPos}t[a]=o(l)},F.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:F.getFromId(e,r).cleanPos)(t)},F.redrawComponents=function(t,e){e=e||F.listIds(t);var r=t._fullLayout;function n(n,a,i,s){for(var l=o.getComponentMethod(n,a),c={},u=0;u<e.length;u++)for(var h=r[F.id2name(e[u])][i],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var V=F.getDataConversions=function(t,e,r,n){var a,i=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(i)){if(a={type:B(n),_categories:[]},F.setConvert(a),\"category\"===a.type)for(var o=0;o<n.length;o++)a.d2c(n[o])}else a=F.getFromTrace(t,e,i);return a?{d2c:a.d2c,c2d:a.c2d}:\"ids\"===i?{d2c:H,c2d:H}:{d2c:q,c2d:q}};function q(t){return+t}function H(t){return String(t)}F.getDataToCoordFunc=function(t,e,r,n){return V(t,e,r,n).d2c},F.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},F.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},F.saveRangeInitial=function(t,e){for(var r=F.list(t,\"\",!0),n=!1,a=0;a<r.length;a++){var i=r[a],o=void 0===i._rangeInitial,s=o||!(i.range[0]===i._rangeInitial[0]&&i.range[1]===i._rangeInitial[1]);(o&&!1===i.autorange||e&&s)&&(i._rangeInitial=i.range.slice(),n=!0)}return n},F.saveShowSpikeInitial=function(t,e){for(var r=F.list(t,\"\",!0),n=!1,a=\"on\",i=0;i<r.length;i++){var o=r[i],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==a||o.showspikes||(a=\"off\")}return t._fullLayout._cartesianSpikesEnabled=a,n},F.autoBin=function(t,e,r,n,i,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(i||(i=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,i),calendar:i},F.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,i);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),a(h)||(h=1)}F.autoTicks(l,h)}var m,v=l.dtick,y=F.tickIncrement(F.tickFirst(l),v,\"reverse\",i);if(\"number\"==typeof v)m=(y=function(t,e,r,n,i){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:a(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(i))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(y,t,l,c,u))+(1+Math.floor((u-y)/v))*v;else for(\"M\"===l.dtick.charAt(0)&&(y=function(t,e,r,n,a){var i=s.findExactDates(e,a);if(i.exactDays>.8){var o=Number(r.substr(1));i.exactYears>.8&&o%12==0?t=F.tickIncrement(t,\"M6\",\"reverse\")+1.5*M:i.exactMonths>.8?t=F.tickIncrement(t,\"M1\",\"reverse\")+15.5*M:t-=A;var l=F.tickIncrement(t,r);if(l<=n)return l}return t}(y,t,v,c,i)),m=y,0;m<=u;)m=F.tickIncrement(m,v,!1,i);return{start:e.c2r(y,0,i),end:e.c2r(m,0,i),size:v,_dataSpan:u-c}},F.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?1.2*(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),\"array\"===t.tickmode&&(a*=100),t._roughDTick=(Math.abs(r[1]-r[0])-(t._lBreaks||0))/a,F.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),$(t)},F.calcTicks=function(t,e){F.prepTicks(t,e);var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),a=U(s.simpleMap(t.range,t.r2l)),i=Math.min(a[0],a[1]),o=Math.max(a[0],a[1]),l=0;Array.isArray(r)||(r=[]);var c=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var u=0;u<e.length;u++){var h=c(e[u]);h>i&&h<o&&(void 0===r[u]?n[l]=F.tickText(t,h):n[l]=tt(t,h,String(r[u])),l++)}l<e.length&&n.splice(l,e.length-l);t.rangebreaks&&(n=n.filter((function(e){return t.maskBreaks(e.x)!==P})));return n}(t);t._tmin=F.tickFirst(t,e);var n=U(r),i=n[0],o=n[1],l=r[1]<r[0];if(t._tmin<i!==l)return[];\"category\"!==t.type&&\"multicategory\"!==t.type||(o=l?Math.max(-.5,o):Math.min(t._categories.length-.5,o));var c,u=\"log\"===t.type&&!(a(t.dtick)||\"L\"===t.dtick.charAt(0));!function(){var e=null,r=Math.max(1e3,t._length||0);c=[];for(var n=t._tmin;(l?n>=o:n<=o)&&!(c.length>r||n===e);n=F.tickIncrement(n,t.dtick,l,t.calendar)){e=n;var a=!1;u&&n!==(0|n)&&(a=!0),c.push({minor:a,value:n})}}();var h=\"period\"===t.ticklabelmode,f=!1;if(h&&c[0]&&(c.unshift({minor:!1,value:F.tickIncrement(c[0].value,t.dtick,!l,t.caldendar)}),f=!0),t.rangebreaks){var p=c.length;if(p){var d=0;\"auto\"===t.tickmode&&(d=(\"y\"===t._id.charAt(0)?2:6)*(t.tickfont?t.tickfont.size:12));for(var E,C=[],L=l?1:-1,I=l?p-1:0,z=l?0:p-1;L*z<=L*I;z+=L){var O=c[z];if(t.maskBreaks(O.value)!==P||(O.value=vt(O.value,t),!t._rl||t._rl[0]!==O.value&&t._rl[1]!==O.value)){var D=t.c2p(O.value);D===E?C[C.length-1].value<O.value&&(C[C.length-1]=O):(void 0===E||Math.abs(D-E)>d)&&(E=D,C.push(O))}}c=C.reverse()}}mt(t)&&360===Math.abs(r[1]-r[0])&&c.pop(),t._tmax=(c[c.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var R,B=Math.min(r[0],r[1]),N=Math.max(r[0],r[1]),j=F.getTickFormat(t);h&&j&&(/%[fLQsSMX]/.test(j)||(/%[HI]/.test(j)?R=S:/%p/.test(j)?R=A:/%[Aadejuwx]/.test(j)?R=M:/%[UVW]/.test(j)?R=k:/%[Bbm]/.test(j)?R=w:/%[q]/.test(j)?R=x:/%[Yy]/.test(j)&&(R=m)));var V,q,H=[];for(V=0;V<c.length;V++){var G=c[V].minor,Y=c[V].value,W=F.tickText(t,Y,!1,G);h&&q===W.text||(q=W.text,H.push(W))}if(h&&f){var Z=!1;for(V=0;V<H.length;V++){var X=H[V].x,J=V,K=V+1;V<H.length-1?(J=V,K=V+1):V>0?(J=V-1,K=V):(J=V,K=V);var Q=H[J].x,$=H[K].x,et=Math.abs($-Q),rt=R||et,nt=0;if(rt>=v?nt=et>=v&&et<=g?et:m:R===x&&rt>=b?nt=et>=b&&et<=y?et:x:rt>=T?nt=et>=T&&et<=_?et:w:R===k&&rt>=k?nt=k:rt>=M?nt=M:R===A&&rt>=A?nt=A:R===S&&rt>=S&&(nt=S),nt&&t.rangebreaks){for(var at=0,it=0,ot=0;ot<42;ot++){var st=ot/42;t.maskBreaks(Q*(1-st)+$*st)!==P&&(st<.5?at++:it++)}it&&(nt*=(at+it)/42)}nt<=et&&(X+=nt/2),H[V].periodX=X,(X>N||X<B)&&(H[V].text=\" \",Z=!0)}if(Z)for(V=0;V<H.length;V++)if(H[V].periodX<=N&&H[V].periodX>=B){t._prevDateHead=\"\",H[V].text=F.tickText(t,H[V].x).text;break}}return t._inCalcTicks=!1,H};var G=[2,5,10],Y=[1,2,3,6,12],W=[1,2,5,10,15,30],Z=[1,2,3,7,14],X=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],J=[-.301,0,.301,.699,1],K=[15,30,45,90,180];function Q(t,e,r){return e*s.roundUp(t/e,r)}function $(t){var e=t.dtick;if(t._tickexponent=0,a(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),i=n.length;if(\"M\"===String(e).charAt(0))i>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=M&&i<=10||e>=15*M)t._tickround=\"d\";else if(e>=E&&i<=16||e>=S)t._tickround=\"M\";else if(e>=C&&i<=19||e>=E)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(i,o)-20,t._tickround<0&&(t._tickround=4)}}else if(a(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);a(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(rt(t.exponentformat)&&!nt(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function tt(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}F.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var i=2*e;if(i>m)e/=m,r=n(10),t.dtick=\"M\"+12*Q(e,r,G);else if(i>w)e/=w,t.dtick=\"M\"+Q(e,1,Y);else if(i>M){t.dtick=Q(e,M,t._hasDayOfWeekBreaks?[1,2,7,14]:Z);var o=F.getTickFormat(t);/%[uVW]/.test(o)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1)}else i>S?t.dtick=Q(e,S,Y):i>E?t.dtick=Q(e,E,W):i>C?t.dtick=Q(e,C,W):(r=n(10),t.dtick=Q(e,r,G))}else if(\"log\"===t.type){t.tick0=0;var l=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(l[1]-l[0])<1){var c=1.5*Math.abs((l[1]-l[0])/e);e=Math.abs(Math.pow(10,l[1])-Math.pow(10,l[0]))/c,r=n(10),t.dtick=\"L\"+Q(e,r,G)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):mt(t)?(t.tick0=0,r=1,t.dtick=Q(e,r,K)):(t.tick0=0,r=n(10),t.dtick=Q(e,r,G));if(0===t.dtick&&(t.dtick=1),!a(t.dtick)&&\"string\"!=typeof t.dtick){var u=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(u)}},F.tickIncrement=function(t,e,r,i){var o=r?-1:1;if(a(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,i);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?J:X,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},F.tickFirst=function(t,e){var r=t.r2l||Number,i=s.simpleMap(t.range,r,void 0,void 0,e),o=i[1]<i[0],l=o?Math.floor:Math.ceil,c=U(i)[0],u=t.dtick,h=r(t.tick0);if(a(u)){var f=l((c-h)/u)*u+h;return\"category\"!==t.type&&\"multicategory\"!==t.type||(f=s.constrain(f,0,t._categories.length-1)),f}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var g,m,v,y=0,x=h;y<10;){if(((g=F.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,g):Math.max(x,g);m=(c-(x+g)/2)/(g-x),v=p+(Math.abs(Math.round(m))||1)*d,x=F.tickIncrement(x,v,m<0?!o:o,t.calendar),y++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-h)/d)*d+h)/Math.LN10;if(\"D\"===p){var b=\"D2\"===u?J:X,_=s.roundUp(s.mod(c,1),b,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,_),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},F.tickText=function(t,e,r,n){var i,o=tt(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=(Math.abs(f[1]-f[0])-(t._lBreaks||0))/1e4;for(i=0;i<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[i]))<p);i++);if(i<t.ticktext.length)return o.text=String(t.ticktext[i]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var a={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==a}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var i=t._tickround,o=r&&t.hoverformat||F.getTickFormat(t);n&&(i=a(i)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[i]);var l,c=s.formatDate(e.x,o,i,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===i?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,i){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===i&&(i=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=at(Math.pow(10,l),t,i,n);else if(a(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||rt(p)&&nt(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":L)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":L)+f:(e.text=at(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),a=t._categories[n]||[],i=void 0===a[1]?\"\":String(a[1]),o=void 0===a[0]?\"\":String(a[0]);r?e.text=o+\" - \"+i:(e.text=i,e.text2=o)}(t,o,r):mt(t)?function(t,e,r,n,a){if(\"radians\"!==t.thetaunit||r)e.text=at(e.x,t,a,n);else{var i=e.x/180;if(0===i)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,a=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/a),Math.round(r/a)]}(i);if(o[1]>=100)e.text=at(s.deg2rad(e.x),t,a,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=L+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,a){\"never\"===a?a=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(a=\"hide\");e.text=at(e.x,t,a,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var m=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[m(o.x-.5),m(o.x+t.dtick-.5)]}return o},F.hoverLabelText=function(t,e,r){if(r!==P&&r!==e)return F.hoverLabelText(t,e)+\" - \"+F.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,a=F.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":L+a:a};var et=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function rt(t){return\"SI\"===t||\"B\"===t}function nt(t){return t>14||t<-15}function at(t,e,r,n){var i=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=F.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:a(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};$(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,L);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",i=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var m=(t=String(t)).indexOf(\".\")+1;m&&(t=t.substr(0,m+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(rt(l)&&nt(c)&&(l=\"power\"),p=c<0?L+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":rt(l)&&(t+=et[c/3+5]));return i?L+t:t}function it(t,e){for(var r=[],n={},a=0;a<e.length;a++){var i=e[a];n[i.text2]?n[i.text2].push(i.x):n[i.text2]=[i.x]}for(var o in n)r.push(tt(t,s.interp(n[o],.5),o));return r}function ot(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function st(t){var e=t.title.font.size,r=(t.title.text.match(l.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?r?e*(O+r*D):e*O:r?e*(r+1)*D:e}function lt(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function ct(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function ut(t){return t._id+\".automargin\"}function ht(t){return ut(t)+\".mirror\"}function ft(t){return t._id+\".rangeslider\"}function pt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function dt(t,e,r){var n,a,i=[],o=[],l=t.layout;for(n=0;n<e.length;n++)i.push(F.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(F.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=i[0][p],g=o[0][p],m=!0,v=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(a=1;a<i.length&&m;a++){var x=i[a][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?v=!0:x!==d&&(m=!1)}for(a=1;a<o.length&&m;a++){var b=o[a][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[a][p]!==g&&(m=!1)}m&&(v&&(l[i[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),gt(l,p,i,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function gt(t,e,r,n,a){var i,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===a.x&&(l.text=a.y),c&&c.text===a.y&&(c.text=a.x)),i=0;i<r.length;i++)o(t,r[i]._name+\".\"+e).set(c);for(i=0;i<n.length;i++)o(t,n[i]._name+\".\"+e).set(l)}function mt(t){return\"angularaxis\"===t._id}function vt(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var a=e._rangebreaks[n];if(t>=a.min&&t<a.max)return a.max}return t}F.getTickFormat=function(t){var e,r,n,a,i,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*w}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),a=r.indexOf(e.charAt(0));return n===a?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-a}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],a=u(t,e[0])>=0,i=u(t,e[1])<=0;return(r||a)&&(n||i)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(a=t.dtick,i=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=i[0],l=i[1],(!s&&\"number\"!=typeof s||o(s)<=o(a))&&(!l&&\"number\"!=typeof l||o(l)>=o(a)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},F.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),a=e?F.findSubplotsWithAxis(n,e):n;return a.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),a},F.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],a=0;a<t.length;a++){var i=t[a];r.test(i)&&n.push(i)}return n},F.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,a,i={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=F.list(t,\"x\",!0),l=F.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),a=0;a<l.length;a++)0===r&&c.push({x:i,y:l[a]}),c.push({x:s[r],y:l[a]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},F.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e],a=r.xaxis,i=r.yaxis;r.xaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove()}));var a=e&&\"redraw\"!==e?e:F.listIds(t);return s.syncOrAsync(a.map((function(e){return function(){if(e){var n=F.getFromId(t,e),a=F.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),a}}})))},F.drawOne=function(t,e,r){var n,a,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=F.counterLetter(p),m=f._plots[e._mainSubplot];if(m){var v=m[d+\"axislayer\"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=F.calcTicks(e),_=[e.mirror,y,x].join(\"_\");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var T,k,M=F.makeTransFn(e),A=\"period\"===e.ticklabelmode?F.makeTransPeriodFn(e):F.makeTransFn(e);if(\"boundaries\"===e.tickson){var S=function(t,e){var r,n=[],a=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)a(e[r],0);a(e[r-1],1)}return n}(0,b);k=F.clipEnds(e,S),T=\"inside\"===e.ticks?k:S}else k=F.clipEnds(e,b),T=\"inside\"===e.ticks?k:b;var E=e._gridVals=k,C=function(t,e){var r,n,a=[],i=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&a.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,i?1:0),n=l.text2}o(e[r-1],i?0:1)}return a}(e,b);if(!f._hasOnlyLargeSploms){var L=e._subplotsWith,P={};for(n=0;n<L.length;n++){a=L[n];var I=(l=f._plots[a])[g+\"axis\"],z=I._mainAxis._id;if(!P[z]){P[z]=1;var O=\"x\"===d?\"M0,\"+I._offset+\"v\"+I._length:\"M\"+I._offset+\",0h\"+I._length;F.drawGrid(t,e,{vals:E,counterAxis:I,layer:l.gridlayer.select(\".\"+p),path:O,transFn:M}),F.drawZeroLine(t,e,{counterAxis:I,layer:l.zerolinelayer,path:O,transFn:M})}}}var B=F.getTickSigns(e),N=[];if(e.ticks){var j,U,V,q=F.makeTickPath(e,y,B[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(j=F.makeTickPath(e,x,B[3]),U=q+j):(j=\"\",U=q),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var H={};for(n=0;n<C.length;n++)H[C[n].x]=1;V=function(t){return H[t.x]?j:U}}else V=U;F.drawTicks(t,e,{vals:T,layer:v,path:V,transFn:M}),\"allticks\"===e.mirror&&(N=Object.keys(e._linepositions||{}))}for(n=0;n<N.length;n++){a=N[n],l=f._plots[a];var G=e._linepositions[a]||[],Y=F.makeTickPath(e,G[0],B[0])+F.makeTickPath(e,G[1],B[1]);F.drawTicks(t,e,{vals:T,layer:l[d+\"axislayer\"],path:Y,transFn:M})}var W=[];if(W.push((function(){return F.drawLabels(t,e,{vals:b,layer:v,transFn:A,labelFns:F.makeLabelFns(e,y)})})),\"multicategory\"===e.type){var Z={x:2,y:10}[d];W.push((function(){var r={x:\"height\",y:\"width\"}[d],n=J()[r]+Z+(e._tickAngles[p+\"tick\"]?e.tickfont.size*D:0);return F.drawLabels(t,e,{vals:it(e,b),layer:v,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:F.makeLabelFns(e,y+n*B[4])})})),W.push((function(){return e._depth=B[4]*(J(\"tick2\")[e.side]-y),function(t,e,r){var n=e._id+\"divider\",a=r.vals,i=r.layer.selectAll(\"path.\"+n).data(a,ot);i.exit().remove(),i.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),i.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:C,layer:v,path:F.makeTickPath(e,y,B[4],e._depth),transFn:M})}))}else e.title.hasOwnProperty(\"standoff\")&&W.push((function(){e._depth=B[4]*(J()[e.side]-y)}));var X=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return W.push((function(){var r,n,a,s,l=e.side.charAt(0),c=R[e.side].charAt(0),u=F.getPxPosition(t,e),h=\"outside\"===e.ticks?e.ticklen:0;if((e.automargin||X)&&(\"multicategory\"===e.type?r=J(\"tick2\"):(r=J(),\"x\"===d&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-u:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if(\"x\"===d){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?u-r.top:0,h),p.reverse()),r.width>0){var m=r.right-(e._offset+e._length);m>0&&(n.xr=1,n.r=m);var v=e._offset-r.left;v>0&&(n.xl=0,n.l=v)}}else if(\"l\"===l?n[l]=e._depth=Math.max(r.height>0?u-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-u:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==f._dfltTitle[d]&&(n[l]+=st(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((a={x:0,y:0,r:0,l:0,t:0,b:0})[c]=e.linewidth,e.mirror&&!0!==e.mirror&&(a[c]+=h),!0===e.mirror||\"ticks\"===e.mirror?a[g]=e._anchorAxis.domain[p[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(a[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}X&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),i.autoMargin(t,ut(e),n),i.autoMargin(t,ht(e),a),i.autoMargin(t,ft(e),s)})),r.skipTitle||X&&\"bottom\"===e.side||W.push((function(){return function(t,e){var r,n=t._fullLayout,a=e._id,i=a.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty(\"standoff\"))r=e._depth+e.title.standoff+st(e);else{if(\"multicategory\"===e.type)r=e._depth;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}r+=\"x\"===i?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0)}var s,l,u,f,p=F.getPxPosition(t,e);\"x\"===i?(l=e._offset+e._length/2,u=\"top\"===e.side?p-r:p+r):(u=e._offset+e._length/2,l=\"right\"===e.side?p+r:p-r,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}e.title.hasOwnProperty(\"standoff\")&&(f.pad=0)}return c.draw(t,a+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[i],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)})),s.syncOrAsync(W)}}function J(t){var r=p+(t||\"tick\");return w[r]||(w[r]=function(t,e){var r,n,a,i;t._selections[e].size()?(r=1/0,n=-1/0,a=1/0,i=-1/0,t._selections[e].each((function(){var t=ct(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),a=Math.min(a,e.left),i=Math.max(i,e.right)}))):(r=0,n=0,a=0,i=0);return{top:r,bottom:n,left:a,right:i,height:n-r,width:i-a}}(e,r)),w[r]}},F.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,a=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(a=a.map((function(t){return-t}))),t.side&&a.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),a},F.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},F.makeTransPeriodFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.periodX))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.periodX))+\")\"}},F.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var a=t._id.charAt(0),i=(t.linewidth||1)/2;return\"x\"===a?\"M0,\"+(e+i*r)+\"v\"+n*r:\"M\"+(e+i*r)+\",0h\"+n*r},F.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),i=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(i&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(i||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return a(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*z},d.anchorFn=function(e,r){return a(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},F.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",a=r.vals;\"period\"===e.ticklabelmode&&(a=a.slice()).shift();var i=r.layer.selectAll(\"path.\"+n).data(e.ticks?a:[],ot);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},F.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",a=r.vals,i=r.counterAxis;if(!1===e.showgrid)a=[];else if(i&&F.shouldShowZeroLine(t,e,i))for(var o=\"array\"===e.tickmode,s=0;s<a.length;s++){var l=a[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(a=a.slice(0,s).concat(a.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(a,ot);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},F.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",a=F.shouldShowZeroLine(t,e,r.counterAxis),i=r.layer.selectAll(\"path.\"+n).data(a?[{x:0,id:e._id}]:[]);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return N.idSort(t.id,e.id)}))})),i.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},F.drawLabels=function(t,e,r){r=r||{};var i=t._fullLayout,o=e._id,c=o.charAt(0),u=r.cls||o+\"tick\",f=r.vals,p=r.labelFns,d=r.secondary?0:e.tickangle,g=(e._prevTickAngles||{})[u],m=r.layer.selectAll(\"g.\"+u).data(e.showticklabels?f:[],ot),v=[];function y(t,e){t.each((function(t){var i=n.select(this),o=i.select(\".text-math-group\"),s=p.anchorFn(t,e),c=r.transFn.call(i.node(),t)+(a(e)&&0!=+e?\" rotate(\"+e+\",\"+p.xFn(t)+\",\"+(p.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(i),f=D*t.fontSize,d=p.heightFn(t,a(e)?+e:0,(u-1)*f);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())i.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}}))}m.enter().append(\"g\").classed(u,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),a=t._promises.length;r.call(l.positionText,p.xFn(e),p.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[a]?v.push(t._promises.pop().then((function(){y(r,d)}))):y(r,d)})),m.exit().remove(),r.repositionOnUpdate&&m.each((function(t){n.select(this).select(\"text\").call(l.positionText,p.xFn(t),p.yFn(t))})),y(m,g+1?g:d);var x=null;e._selections&&(e._selections[u]=m);var b=[function(){return v.length&&Promise.all(v)}];e.automargin&&i._redrawFromAutoMarginCount&&90===g?(x=90,b.push((function(){y(m,g)}))):b.push((function(){if(y(m,d),f.length&&\"x\"===c&&!a(d)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){x=0;var t,n=0,i=[];if(m.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),a=ct(this),o=h.bBox(a.node());i.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})})),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var o=f.length,l=Math.abs((f[o-1].x-f[0].x)*e._m)/(o-1)<2.5*n||\"multicategory\"===e.type;for(t=0;t<i.length-1;t++)if(s.bBoxIntersect(i[t],i[t+1])){x=l?90:30;break}}else{var u=2;for(e.ticks&&(u+=e.tickwidth/2),t=0;t<i.length;t++){var p=f[t].xbnd,g=i[t];if(null!==p[0]&&g.left-e.l2p(p[0])<u||null!==p[1]&&e.l2p(p[1])-g.right<u){x=90;break}}}x&&y(m,x)}})),e._tickAngles&&b.push((function(){e._tickAngles[u]=null===x?a(d)?d:0:x}));var _=s.syncOrAsync(b);return _&&_.then&&t._promises.push(_),_},F.getPxPosition=function(t,e){var r,n=t._fullLayout._size,a=e._id.charAt(0),i=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===a?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===a&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===i||\"left\"===i?r._offset:\"bottom\"===i||\"right\"===i?r._offset+r._length:void 0},F.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===P)&&(lt(e,0)||!function(t,e,r,n){var a=r._mainAxis;if(!a)return;var i=t._fullLayout,o=e._id.charAt(0),s=F.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var a=t._linepositions||{};for(var i in a)if(n(a[i][0])||n(a[i][1]))return!0}var u=i._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=F.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===a&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,a=e._id.charAt(0),i=0;i<r.length;i++){var s=r[i];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[a])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===a)return!0}}return!1}(t,e))},F.clipEnds=function(t,e){return e.filter((function(e){return lt(t,e.x)}))},F.allowAutoMargin=function(t){for(var e=F.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(i.allowAutoMargin(t,ut(n)),n.mirror&&i.allowAutoMargin(t,ht(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&i.allowAutoMargin(t,ft(n))}},F.swap=function(t,e){for(var r=function(t,e){var r,n,a=[];for(r=0;r<e.length;r++){var i=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<a.length;n++)-1===a[n].x.indexOf(o)&&-1===a[n].y.indexOf(s)||i.push(n);if(i.length){var l,c=a[i[0]];if(i.length>1)for(n=1;n<i.length;n++)l=a[i[n]],pt(c.x,l.x),pt(c.y,l.y);pt(c.x,[o]),pt(c.y,[s])}else a.push({x:[o],y:[s]})}}return a}(t,e),n=0;n<r.length;n++)dt(t,r[n].x,r[n].y)}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../components/titles\":710,\"../../constants/alignment\":717,\"../../constants/numerical\":724,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/plots\":861,\"../../registry\":881,\"./autorange\":797,\"./axis_autotype\":799,\"./axis_ids\":801,\"./clean_ticks\":803,\"./layout_attributes\":812,\"./set_convert\":818,d3:169,\"fast-isnumeric\":241}],799:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,a.isArrayOrTypedArray(o[0])&&a.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),i=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,a.isDateTime(c,e)&&(i+=1),n(c)&&(o+=1))}return i>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:a.cleanNumber(l)!==i?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":724,\"../../lib\":749,\"fast-isnumeric\":241}],800:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=t(\"../array_container_defaults\"),s=t(\"./layout_attributes\"),l=t(\"./tick_value_defaults\"),c=t(\"./tick_mark_defaults\"),u=t(\"./tick_label_defaults\"),h=t(\"./category_order_defaults\"),f=t(\"./line_grid_defaults\"),p=t(\"./set_convert\"),d=t(\"./constants\").WEEKDAY_PATTERN,g=t(\"./constants\").HOUR_PATTERN;function m(t,e,r){function a(r,n){return i.coerce(t,e,s.rangebreaks,r,n)}if(a(\"enabled\")){var o=a(\"bounds\");if(o&&o.length>=2){var l,c,u=\"\";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var h=a(\"pattern\",u);if(h===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(h)for(l=0;l<2;l++)switch(c=o[l],h){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case g:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var f=r.range;if(f[0]<f[1]){if(o[0]<f[0]&&o[1]>f[1])return void(e.enabled=!1)}else if(o[0]>f[0]&&o[1]<f[1])return void(e.enabled=!1)}}else{var p=a(\"values\");if(!p||!p.length)return void(e.enabled=!1);a(\"dvalue\")}}}e.exports=function(t,e,r,n,g){var v=n.letter,y=n.font||{},x=n.splomStash||{},b=r(\"visible\",!n.visibleDflt),_=e._template||{},w=e.type||_.type||\"-\";\"date\"===w&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar);p(e,g);var T=!e.isValidRange(t.range);T&&n.reverseDflt&&(T=\"reversed\"),!r(\"autorange\",T)||\"linear\"!==w&&\"-\"!==w||r(\"rangemode\"),r(\"range\"),e.cleanRange(),h(t,e,r,n),\"category\"===w||n.noHover||r(\"hoverformat\");var k=r(\"color\"),M=k!==s.color.dflt?k:y.color,A=x.label||g._dfltTitle[v];if(u(t,e,r,w,n,{pass:1}),!b)return e;r(\"title.text\",A),i.coerceFont(r,\"title.font\",{family:y.family,size:Math.round(1.2*y.size),color:M}),l(t,e,r,w),u(t,e,r,w,n,{pass:2}),c(t,e,r,n),f(t,e,r,{dfltColor:k,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r(\"mirror\"),n.automargin&&r(\"automargin\");var S,E=\"multicategory\"===w;n.noTickson||\"category\"!==w&&!E||!e.ticks&&!e.showgrid||(E&&(S=\"boundaries\"),r(\"tickson\",S));E&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));if(\"date\"===w)if(n.noTicklabelmode||r(\"ticklabelmode\"),o(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:m}),e.rangebreaks.length){for(var C=0;C<e.rangebreaks.length;C++)if(e.rangebreaks[C].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,g),g._has(\"scattergl\")||g._has(\"splom\"))for(var L=0;L<n.data.length;L++){var P=n.data[L];\"scattergl\"!==P.type&&\"splom\"!==P.type||(P.visible=!1,i.warn(P.type+\" traces do not work on axes with rangebreaks. Setting trace \"+P.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var v={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if(\"string\"==typeof t)return v[t.substr(0,3).toLowerCase()]}},{\"../../lib\":749,\"../../registry\":881,\"../array_container_defaults\":793,\"./category_order_defaults\":802,\"./constants\":804,\"./layout_attributes\":812,\"./line_grid_defaults\":814,\"./set_convert\":818,\"./tick_label_defaults\":819,\"./tick_mark_defaults\":820,\"./tick_value_defaults\":821,\"fast-isnumeric\":241}],801:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(a.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(a.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(\"string\"==typeof t&&t.match(a.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var a=t._fullLayout;if(!a)return[];var i,o=r.listIds(t,e),s=new Array(o.length);for(i=0;i<o.length;i++){var l=o[i];s[i]=a[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=a._subplots.gl3d||[];for(i=0;i<c.length;i++){var u=a[c[i]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var a=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),a[r.id2name(e)]},r.getFromTrace=function(t,e,a){var i=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=i[s][a+\"axis\"])}else o=r.getFromId(t,e[a+\"axis\"]||a);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":881,\"./constants\":804}],802:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var a,i=t.categoryarray,o=Array.isArray(i)&&i.length>0;o&&(a=\"array\");var s,l=r(\"categoryorder\",a);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,a,i=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[i+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][i];for(a=0;a<l.length;a++){var c=l[a];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],803:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../constants/numerical\"),o=i.ONEDAY,s=i.ONEWEEK;r.dtick=function(t,e){var r=\"log\"===e,a=\"date\"===e,i=\"category\"===e,s=a?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:i?Math.max(1,Math.round(t)):a?Math.max(.1,t):t;if(\"string\"!=typeof t||!a&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(a&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,i){return\"date\"===e?a.cleanDate(t,a.dateTick0(r,i%s==0?1:0)):\"D1\"!==i&&\"D2\"!==i?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":724,\"../../lib\":749,\"fast-isnumeric\":241}],804:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":765}],805:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./axis_ids\").id2name,i=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,i){var o,s,l,c,u=\"range\"!==i,h=n[a(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[a(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[a(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,a){var i,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(i=0;i<t.length;i++)if(s=t[i],i!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*a*e[l];return void t.splice(c,1)}if(1!==a)for(o=0;o<u.length;o++)e[u[o]]*=a;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],a=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[a+(r[0]-a)/e,a+(r[1]-a)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,a){var i,o,s,l,c=a.allAxisIds,f=a.layoutOut,p=a.scaleanchorDflt,d=a.constrainDflt,g=f._axisConstraintGroups,m=f._axisMatchGroups,v=e._id,y=v.charAt(0),x=((f._splomAxes||{})[y]||{})[v]||{},b=e._id,_=b.charAt(0),w=r(\"constrain\",d);if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===_?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===_?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!x.matches||e.fixedrange||(o=u(m,b,c,f),i=n.coerce(t,e,{matches:{valType:\"enumerated\",values:o.linkableAxes||[],dflt:x.matches}},\"matches\")),i||e.fixedrange&&\"domain\"!==w||!t.scaleanchor&&!p||(l=u(g,b,c,f,w),s=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:l.linkableAxes||[]}},\"scaleanchor\",p)),i?(delete e.constrain,h(m,o.thisGroup,b,i,1)):-1!==c.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),s){var T=r(\"scaleratio\");T||(T=e.scaleratio=1),h(g,l.thisGroup,b,s,T)}else-1!==c.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var m=g[e],v=Object.keys(m),y=1/0,x=0,b=1/0,_={},w={},T=!1;for(r=0;r<v.length;r++)w[n=v[r]]=c=d[a(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/m[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(T=!0);if(!(y>l*x)||T)for(r=0;r<v.length;r++)if(u=_[n=v[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)i(c,p);else{var k=c._inputDomain,M=(c.domain[1]-c.domain[0])/(k[1]-k[0]),A=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=M)*A<1){c.domain=c._input.domain=k.slice(),i(c,p);continue}if(A<1&&(c.range=c._input.range=c._inputRange.slice(),p*=A),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,I=Math.abs(E-C),z=C-I*p*1.0001,O=C+I*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<O&&R>P&&(P=R);p/=(P-L)/(2*I),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,a=t._fullLayout._axisConstraintGroups,i=0;i<a.length;i++)if(a[i][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":717,\"../../constants/numerical\":724,\"../../lib\":749,\"./autorange\":797,\"./axis_ids\":801,\"./scale_zoom\":816}],806:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"tinycolor2\"),i=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/dragelement/helpers\"),m=g.selectingOrDrawing,v=g.freeMode,y=t(\"../../constants/alignment\").FROM_TL,x=t(\"../../lib/clear_gl_canvases\"),b=t(\"../../plot_api/subroutines\").redrawReglTraces,_=t(\"../plots\"),w=t(\"./axis_ids\").getFromId,T=t(\"./select\").prepSelect,k=t(\"./select\").clearSelect,M=t(\"./select\").selectOnClick,A=t(\"./scale_zoom\"),S=t(\"./constants\"),E=S.MINDRAG,C=S.MINZOOM,L=!0;function P(t,e,r,n){var a=s.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return a.call(p,n),a.node()}function I(t,e,r,a,i,o,s){var l=P(t,\"rect\",e,r);return n.select(l).call(u.setRect,a,i,o,s),l}function z(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function O(t,e,r,n,a){for(var i=0;i<t.length;i++){var o=t[i];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],h=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+h*e),n[o._name+\".range[1]\"]=o.l2r(u+h*r)}}if(a&&a.length){var f=(e+(1-r))/2;O(a,f,1-f,n,[])}}function D(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var a=n._length,i=(n.p2l(0+e)-n.p2l(0)+(n.p2l(a+e)-n.p2l(a)))/2;n.range=[n.l2r(n._rl[0]-i),n.l2r(n._rl[1]-i)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function R(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function F(t,e,r,n,a){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",a+\"Z\")}function B(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function N(t,e,r,n,a,i){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),j(t,e,a,i)}function j(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function U(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function V(t){L&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),L=!1)}function q(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,C)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function H(t,e,r,n){for(var a,i,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(a in r)if(p[a]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=a);for(i in n)p[i]&&(c=!0)}for(i in n)if(p[i])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=i)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var m=w(t,o);g.push(m),d[m._id]=m}var v={},y=[];for(l in h){var x=w(t,l);y.push(x),v[x._id]=x}return{xaHash:d,yaHash:v,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function G(t,e){if(i){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function Y(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,i,c,p,g,L){var P,j,W,Z,X,J,K,Q,$,tt,et,rt,nt,at,it,ot,st,lt,ct,ut,ht,ft=t._fullLayout._zoomlayer,pt=g+L===\"nsew\",dt=1===(g+L).length;function gt(){if(P=e.xaxis,j=e.yaxis,$=P._length,tt=j._length,K=P._offset,Q=j._offset,(W={})[P._id]=P,(Z={})[j._id]=j,g&&L)for(var r=e.overlays,n=0;n<r.length;n++){var a=r[n].xaxis;W[a._id]=a;var i=r[n].yaxis;Z[i._id]=i}X=Y(W),J=Y(Z),nt=z(X,L),at=z(J,g),it=!at&&!nt,et=H(t,t._fullLayout._axisConstraintGroups,W,Z),rt=H(t,t._fullLayout._axisMatchGroups,W,Z),ot=L||et.isSubplotConstrained||rt.isSubplotConstrained,st=g||et.isSubplotConstrained||rt.isSubplotConstrained;var o=t._fullLayout;lt=o._has(\"scattergl\"),ct=o._has(\"splom\"),ut=o._has(\"svg\")}gt();var mt=function(t,e,r){if(!t)return\"pointer\";if(\"nsew\"===t)return r?\"\":\"pan\"===e?\"move\":\"crosshair\";return t.toLowerCase()+\"-resize\"}(at+nt,t._fullLayout.dragmode,pt),vt=I(e,g+L+\"drag\",mt,r,i,c,p);if(it&&!pt)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var yt,xt,bt,_t,wt,Tt,kt,Mt,At,St,Et={element:vt,gd:t,plotinfo:e};function Ct(){Et.plotinfo.selection=!1,k(t)}function Lt(t,r){var a=Et.gd;if(a._fullLayout._activeShapeIndex>=0)a._fullLayout._deactivateShape(a);else{var i=a._fullLayout.clickmode;if(U(a),2!==t||dt||Ut(),pt)i.indexOf(\"select\")>-1&&M(r,a,X,J,e.id,Et),i.indexOf(\"event\")>-1&&h.click(a,r,e.id);else if(1===t&&dt){var s=g?j:P,c=\"s\"===g||\"w\"===L?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,a=t.range[e],i=Math.abs(a-t.range[1-e]);return\"date\"===t.type?a:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(i)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,a))):(r=Math.floor(Math.log(Math.abs(a))/Math.LN10)-Math.floor(Math.log(i)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(a))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;g?(d=\"n\"===g?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===L&&(p=\"right\"),a._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:a,immediate:!0,background:a._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&o.call(\"_guiRelayout\",a,u,e)}))}}}function Pt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+yt)),a=Math.max(0,Math.min(tt,r+xt)),i=Math.abs(n-yt),o=Math.abs(a-xt);function s(){kt=\"\",bt.r=bt.l,bt.t=bt.b,At.attr(\"d\",\"M0,0Z\")}if(bt.l=Math.min(yt,n),bt.r=Math.max(yt,n),bt.t=Math.min(xt,a),bt.b=Math.max(xt,a),et.isSubplotConstrained)i>C||o>C?(kt=\"xy\",i/$>o/tt?(o=i*tt/$,xt>a?bt.t=xt-o:bt.b=xt+o):(i=o*$/tt,yt>n?bt.l=yt-i:bt.r=yt+i),At.attr(\"d\",q(bt))):s();else if(rt.isSubplotConstrained)if(i>C||o>C){kt=\"xy\";var l=Math.min(bt.l/$,(tt-bt.b)/tt),c=Math.max(bt.r/$,(tt-bt.t)/tt);bt.l=l*$,bt.r=c*$,bt.b=(1-l)*tt,bt.t=(1-c)*tt,At.attr(\"d\",q(bt))}else s();else!at||o<Math.min(Math.max(.6*i,E),C)?i<E||!nt?s():(bt.t=0,bt.b=tt,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-C-.5)+\"h-3v\"+(2*C+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-C-.5)+\"h3v\"+(2*C+1)+\"h-3Z\"}(bt,xt))):!nt||i<Math.min(.6*o,C)?(bt.l=0,bt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-C-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*C+1)+\"v3ZM\"+(e-C-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*C+1)+\"v-3Z\"}(bt,yt))):(kt=\"xy\",At.attr(\"d\",q(bt)));bt.w=bt.r-bt.l,bt.h=bt.b-bt.t,kt&&(St=!0),t._dragged=St,N(Mt,At,bt,wt,Tt,_t),It(),t.emit(\"plotly_relayouting\",ht),Tt=!0}function It(){ht={},\"xy\"!==kt&&\"x\"!==kt||(O(X,bt.l/$,bt.r/$,ht,et.xaxes),Nt(\"x\",ht)),\"xy\"!==kt&&\"y\"!==kt||(O(J,(tt-bt.b)/tt,(tt-bt.t)/tt,ht,et.yaxes),Nt(\"y\",ht))}function zt(){It(),U(t),Vt(),V(t)}Et.prepFn=function(e,r,n){var i=Et.dragmode,o=t._fullLayout.dragmode;o!==i&&(Et.dragmode=o),gt(),it||(pt?e.shiftKey?\"pan\"===o?o=\"zoom\":m(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),v(o)?Et.minDrag=1:Et.minDrag=void 0,m(o)?(Et.xaxes=X,Et.yaxes=J,T(e,r,n,Et,o)):(Et.clickFn=Lt,m(i)&&Ct(),it||(\"zoom\"===o?(Et.moveFn=Pt,Et.doneFn=zt,Et.minDrag=1,function(e,r,n){var i=vt.getBoundingClientRect();yt=r-i.left,xt=n-i.top,bt={l:yt,r:yt,w:0,t:xt,b:xt,h:0},_t=t._hmpixcount?t._hmlumcount/t._hmpixcount:a(t._fullLayout.plot_bgcolor).getLuminance(),Tt=!1,kt=\"xy\",St=!1,Mt=F(ft,_t,K,Q,wt=\"M0,0H\"+$+\"V\"+tt+\"H0V0\"),At=B(ft,K,Q)}(0,r,n)):\"pan\"===o&&(Et.moveFn=Bt,Et.doneFn=Vt))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===vt){var r=t._fullLayout.dragmode;m(r)||(gt(),qt([0,0,$,tt]),Et.moveFn(e.dx,e.dy))}}},d.init(Et);var Ot=[0,0,$,tt],Dt=null,Rt=S.REDRAWDELAY,Ft=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Bt(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===nt||\"ns\"===at)return nt&&(D(X,e),Nt(\"x\")),at&&(D(J,r),Nt(\"y\")),qt([nt?-e:0,at?-r:0,$,tt]),jt(),void t.emit(\"plotly_relayouting\",ht);if(et.isSubplotConstrained&&nt&&at){var n=\"w\"===nt==(\"n\"===at)?1:-1,a=(e/$+n*r/tt)/2;e=a*$,r=n*a*tt}\"w\"===nt?e=l(X,0,e):\"e\"===nt?e=l(X,1,-e):nt||(e=0),\"n\"===at?r=l(J,1,r):\"s\"===at?r=l(J,0,-r):at||(r=0);var i=\"w\"===nt?e:0,o=\"n\"===at?r:0;if(et.isSubplotConstrained){var s;if(!nt&&1===at.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),A(X[s],1-r/tt);i=(e=r*$/tt)/2}if(!at&&1===nt.length){for(s=0;s<J.length;s++)J[s].range=J[s]._r.slice(),A(J[s],1-e/$);o=(r=e*tt/$)/2}}Nt(\"x\"),Nt(\"y\"),qt([i,o,$-e,tt-r]),jt(),t.emit(\"plotly_relayouting\",ht)}function l(t,e,r){for(var n,a,i=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,a=s._rl[i]+(s._rl[e]-s._rl[i])/R(r/s._length);var l=s.l2r(a);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-a)/(n._rl[e]-n._rl[i])}}function Nt(t,e){for(var r=rt.isSubplotConstrained?{x:J,y:X}[t]:rt[t+\"axes\"],n=rt.isSubplotConstrained?{x:X,y:J}[t]:[],a=0;a<r.length;a++){var i=r[a],o=i._id,s=rt.xLinks[o]||rt.yLinks[o],l=n[0]||W[s]||Z[s];l&&(e?(e[i._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[i._name+\".range[1]\"]=e[l._name+\".range[1]\"]):i.range=l.range.slice())}}function jt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(ot&&(n(X),n(et.xaxes),n(rt.xaxes)),st&&(n(J),n(et.yaxes),n(rt.yaxes)),ht={},e=0;e<r.length;e++){var a=r[e],i=w(t,a);f.drawOne(t,i,{skipTitle:!0}),ht[i._name+\".range[0]\"]=i.range[0],ht[i._name+\".range[1]\"]=i.range[1]}f.redrawComponents(t,r)}function Ut(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];nt&&(r=r.concat(X)),at&&(r=r.concat(J)),rt.xaxes&&(r=r.concat(rt.xaxes)),rt.yaxes&&(r=r.concat(rt.yaxes));var n,a,i,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",a=0;a<r.length;a++)if((n=r[a])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(a=0;a<r.length;a++)(n=r[a]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((nt||et.isSubplotConstrained)&&(r=r.concat(et.xaxes)),at&&!et.isSubplotConstrained&&(r=r.concat(et.yaxes)),et.isSubplotConstrained&&(nt?at||(r=r.concat(J)):r=r.concat(X)),a=0;a<r.length;a++)(n=r[a]).fixedrange||(n._rangeInitial?(i=n._rangeInitial,s[n._name+\".range[0]\"]=i[0],s[n._name+\".range[1]\"]=i[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}function Vt(){qt([0,0,$,tt]),s.syncOrAsync([_.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ht)}],t)}function qt(e){var r,n,a,i,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(ct&&o.subplotsRegistry.splom.drag(t),lt)for(r=0;r<h.length;r++)if(a=(n=c[h[r]]).xaxis,i=n.yaxis,n._scene){var f=s.simpleMap(a.range,a.r2l),p=s.simpleMap(i.range,i.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((ct||lt)&&(x(t),b(t)),ut){var d=e[2]/P._length,m=e[3]/j._length;for(r=0;r<h.length;r++){a=(n=c[h[r]]).xaxis,i=n.yaxis;var v,y,_,w,T=ot&&!a.fixedrange&&W[a._id],k=st&&!i.fixedrange&&Z[i._id];if(T?(v=d,_=L?e[0]:Yt(a,v)):rt.xaHash[a._id]?(v=d,_=e[0]*a._length/P._length):rt.yaHash[a._id]?(v=m,_=\"ns\"===at?-e[1]*a._length/j._length:Yt(a,v,{n:\"top\",s:\"bottom\"}[at])):_=Gt(a,v=Ht(a,d,m)),k?(y=m,w=g?e[1]:Yt(i,y)):rt.yaHash[i._id]?(y=m,w=e[1]*i._length/j._length):rt.xaHash[i._id]?(y=d,w=\"ew\"===nt?-e[0]*i._length/P._length:Yt(i,y,{e:\"right\",w:\"left\"}[nt])):w=Gt(i,y=Ht(i,d,m)),v||y){v||(v=1),y||(y=1);var M=a._offset-_/v,A=i._offset-w/y;n.clipRect.call(u.setTranslate,_,w).call(u.setScale,v,y),n.plot.call(u.setTranslate,M,A).call(u.setScale,1/v,1/y),v===n.xScaleFactor&&y===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,v,y),u.setTextPointsScale(n.zoomScaleTxt,v,y)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=v,n.yScaleFactor=y}}}}function Ht(t,e,r){return t.fixedrange?0:ot&&et.xaHash[t._id]?e:st&&(et.isSubplotConstrained?et.xaHash:et.yaHash)[t._id]?r:0}function Gt(t,e){return e?(t.range=t._r.slice(),A(t,e),Yt(t,e)):0}function Yt(t,e,r){return t._length*(1-e)*y[r||t.constraintoward||\"middle\"]}return g.length*L.length!=1&&G(vt,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Ct(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();gt(),clearTimeout(Dt);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,a=Math.exp(-Math.min(Math.max(r,-20),20)/200),i=Ft.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-i.left)/i.width,l=(i.bottom-e.clientY)/i.height;if(ot){for(L||(o=.5),n=0;n<X.length;n++)c(X[n],o,a);Nt(\"x\"),Ot[2]*=a,Ot[0]+=Ot[2]*o*(1/a-1)}if(st){for(g||(l=.5),n=0;n<J.length;n++)c(J[n],l,a);Nt(\"y\"),Ot[3]*=a,Ot[1]+=Ot[3]*(1-l)*(1/a-1)}qt(Ot),jt(),t.emit(\"plotly_relayouting\",ht),Dt=setTimeout((function(){Ot=[0,0,$,tt],Vt()}),Rt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),a=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(a+(e-a)*r)}))}}})),vt},makeDragger:P,makeRectDragger:I,makeZoombox:F,makeCorners:B,updateZoombox:N,xyCorners:q,transitionZoombox:j,removeZoombox:U,showDoubleClickNotifier:V,attachWheelEventHandler:G}},{\"../../components/color\":615,\"../../components/dragelement\":634,\"../../components/dragelement/helpers\":633,\"../../components/drawing\":637,\"../../components/fx\":655,\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/clear_gl_canvases\":733,\"../../lib/setcursor\":769,\"../../lib/svg_text_utils\":773,\"../../plot_api/subroutines\":788,\"../../registry\":881,\"../plots\":861,\"./axes\":798,\"./axis_ids\":801,\"./constants\":804,\"./scale_zoom\":816,\"./select\":817,d3:169,\"has-passive-events\":415,tinycolor2:548}],807:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/fx\"),i=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort((function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),a=r.split(\"y\");return n[0]===a[0]?Number(n[1]||1)-Number(a[1]||1):Number(n[0]||1)-Number(a[0]||1)}return e._plots[t].mainplot?1:-1})).forEach((function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&a.hover(t,e,r)},a.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,i.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,a.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,a.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":634,\"../../components/fx\":655,\"../../lib/setcursor\":769,\"./constants\":804,\"./dragbox\":806,d3:169}],808:[function(t,e,r){\"use strict\";e.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearSelect:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._drawing=!1}}},{}],809:[function(t,e,r){\"use strict\";function n(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}e.exports={p2r:n,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return n(t,r[e])}},getTransform:function(t){return\"translate(\"+t.xaxis._offset+\",\"+t.yaxis._offset+\")\"}}},{}],810:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\");e.exports=function(t){return function(e,r){var i=e[t];if(Array.isArray(i))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<i.length;p++){var d=i[p];if(a.isPlainObject(d)){var g=d.xref,m=d.yref,v=s.x.test(g),y=s.y.test(m);if(v||y){f||a.pushUnique(r._basePlotModules,o);var x=!1;v&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(m)&&(u.push(m),x=!0),x&&v&&y&&h.push(g+m)}}}}}},{\"../../lib\":749,\"../../registry\":881}],811:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=i.ensureSingle;function p(t,e,r){return i.ensureSingle(t,e,r,(function(t){t.datum(r)}))}function d(t,e,r,i,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,m=[],v=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=a.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&m.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&v.push(\".\"+_)}}m.sort((function(t,e){return t.i-e.i}));var T=e.plot.selectAll(\"g.mlayer\").data(m,(function(t){return t.className}));if(T.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),T.exit().remove(),T.order(),T.each((function(r){var a=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,a,i,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(a,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=a.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var k=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=k.selectAll(\"path.point\"),e.zoomScaleTxt=k.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,a=u.layerValue2layerClass[e.xaxis.layer],i=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+a).select(\".\"+h),e.ylines=l.select(\".overlines-\"+i).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+a).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+i).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+a),e.ylines=r.select(\".ylines-\"+i),e.xaxislayer=r.select(\".xaxislayer-\"+a),e.yaxislayer=r.select(\".yaxislayer-\"+i)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function m(t,e){if(t){var r={};for(var a in t.each((function(t){var a=t[0];n.select(this).remove(),v(a,e),r[a]=!0})),e._plots)for(var i=e._plots[a].overlays||[],o=0;o<i.length;o++){var s=i[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,a,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(a=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(a)||(a=\"y\"),h.push(n+a),f.push(n+a),d[a]||(d[a]=1,i.pushUnique(l,a)));for(r=0;r<l.length;r++)d[a=l[r]]||(n=(t[c.id2name(a)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+a),f.push(n+a),p[n]||(p[n]=1,i.pushUnique(s,n)));if(!f.length){for(var m in n=\"\",a=\"\",t){if(u.attrRegex.test(m))\"x\"===m.charAt(0)?(!n||+m.substr(5)<+n.substr(5))&&(n=m):(!a||+m.substr(5)<+a.substr(5))&&(a=m)}n=n?c.name2id(n):\"x\",a=a?c.name2id(a):\"y\",s.push(n),l.push(a),h.push(n+a)}},r.plot=function(t,e,r,n){var a,i=t._fullLayout,o=i._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],a=0;a<s.length;a++)e.push(a);for(a=0;a<o.length;a++){for(var l,c=o[a],u=i._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var a,i,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(a=s[o]).plotgroup&&a.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(a=s[o])._scene&&a._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(i=0;i<p.length;i++){var d=p[i];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)m(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(i=0;i<u.cartesian.length;i++){var x=u.cartesian[i];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,a,i,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],a=s._plots[n],i=a.xaxis,o=a.yaxis;var f=i._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];a.overlays=[],d!==n&&g?(a.mainplot=d,a.mainplotinfo=g,h.push(n)):(a.mainplot=void 0,a.mainplotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(a=s._plots[n]).mainplotinfo.overlays.push(a);var m=u.concat(h),v=new Array(c);for(e=0;e<c;e++){n=m[e],a=s._plots[n],i=a.xaxis,o=a.yaxis;var y=[n,i.layer,o.layer,i.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<a.overlays.length;r++)y.push(a.overlays[r].id);v[e]=y}return v}(t),a=e._cartesianlayer.selectAll(\".subplot\").data(r,String);a.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),a.order(),a.exit().call(m,e),a.each((function(r){var a=r[0],i=e._plots[a];i.plotgroup=n.select(this),g(t,i),i.draglayer=f(e._draggers,\"g\",a)}))},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}))},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":637,\"../../constants/xmlns_namespaces\":725,\"../../lib\":749,\"../../registry\":881,\"../get_data\":835,\"../plots\":861,\"./attributes\":796,\"./axis_ids\":801,\"./constants\":804,\"./graph_interact\":807,\"./layout_attributes\":812,\"./layout_defaults\":813,\"./transition_axes\":822,d3:169}],812:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),a=t(\"../../components/color/attributes\"),i=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"../../constants/numerical\").ONEDAY),c=t(\"./constants\"),u=c.HOUR_PATTERN,h=c.WEEKDAY_PATTERN;e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:a.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[h,u,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:l},editType:\"calc\"}),tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:a.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},i,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:a.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:a.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:a.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:a.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":614,\"../../components/drawing/attributes\":636,\"../../constants/docs\":719,\"../../constants/numerical\":724,\"../../lib/extend\":739,\"../../plot_api/plot_template\":787,\"../font_attributes\":826,\"./constants\":804}],813:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../../components/fx/helpers\").isUnifiedHover,o=t(\"../../components/fx/hovermode_defaults\"),s=t(\"../../plot_api/plot_template\"),l=t(\"../layout_attributes\"),c=t(\"./layout_attributes\"),u=t(\"./type_defaults\"),h=t(\"./axis_defaults\"),f=t(\"./constraints\").handleConstraintDefaults,p=t(\"./position_defaults\"),d=t(\"./axis_ids\"),g=d.id2name,m=d.name2id,v=t(\"./constants\").AX_ID_PATTERN,y=t(\"../../registry\"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var d,y,w={},T={},k={},M={},A={},S={},E={},C={},L={},P={};for(d=0;d<r.length;d++){var I=r[d];if(x(I,\"cartesian\")||x(I,\"gl2d\")){var z,O;if(I.xaxis)z=g(I.xaxis),_(w,z,I);else if(I.xaxes)for(y=0;y<I.xaxes.length;y++)_(w,g(I.xaxes[y]),I);if(I.yaxis)O=g(I.yaxis),_(w,O,I);else if(I.yaxes)for(y=0;y<I.yaxes.length;y++)_(w,g(I.yaxes[y]),I);if(\"funnel\"===I.type?\"h\"===I.orientation?(z&&(T[z]=!0),O&&(E[O]=!0)):O&&(k[O]=!0):\"image\"===I.type?(O&&(C[O]=!0),z&&(C[z]=!0)):(O&&(A[O]=!0,S[O]=!0),x(I,\"carpet\")&&(\"carpet\"!==I.type||I._cheater)||z&&(M[z]=!0)),\"carpet\"===I.type&&I._cheater&&z&&(T[z]=!0),x(I,\"2dMap\")&&(L[z]=!0,L[O]=!0),x(I,\"oriented\"))P[\"h\"===I.orientation?O:z]=!0}}var D=e._subplots,R=D.xaxis,F=D.yaxis,B=n.simpleMap(R,g),N=n.simpleMap(F,g),j=B.concat(N),U=a.background;R.length&&F.length&&(U=n.coerce(t,e,l,\"plot_bgcolor\"));var V,q,H,G,Y,W=a.combine(U,e.paper_bgcolor);function Z(){var t=w[V]||[];Y._traceIndices=t.map((function(t){return t._expandedIndex})),Y._annIndices=[],Y._shapeIndices=[],Y._imgIndices=[],Y._subplotsWith=[],Y._counterAxes=[],Y._name=Y._attr=V,Y._id=q}function X(t,e){return n.coerce(G,Y,c,t,e)}function J(t,e){return n.coerce2(G,Y,c,t,e)}function K(t){return\"x\"===t?F:R}function Q(e,r){for(var n=\"x\"===e?B:N,a=[],i=0;i<n.length;i++){var o=n[i];o===r||(t[o]||{}).overlaying||a.push(m(o))}return a}var $={x:K(\"x\"),y:K(\"y\")},tt=$.x.concat($.y),et={},rt=[];function nt(){var t=G.matches;v.test(t)&&-1===tt.indexOf(t)&&(et[t]=G.type,rt=Object.keys(et))}var at=o(t,e,r),it=i(at);for(d=0;d<j.length;d++){V=j[d],q=m(V),H=V.charAt(0),n.isPlainObject(t[V])||(t[V]={}),G=t[V],Y=s.newContainer(e,V,H+\"axis\"),Z();var ot=\"x\"===H&&!M[V]&&T[V]||\"y\"===H&&!A[V]&&k[V],st=\"y\"===H&&(!S[V]&&E[V]||C[V]),lt={letter:H,font:e.font,outerTicks:L[V],showGrid:!P[V],data:w[V]||[],bgColor:W,calendar:e.calendar,automargin:!0,visibleDflt:ot,reverseDflt:st,splomStash:((e._splomAxes||{})[H]||{})[q]};X(\"uirevision\",e.uirevision),u(G,Y,X,lt),h(G,Y,X,lt,e);var ct=it&&H===at.charAt(0),ut=J(\"spikecolor\",it?Y.color:void 0),ht=J(\"spikethickness\",it?1.5:void 0),ft=J(\"spikedash\",it?\"dot\":void 0),pt=J(\"spikemode\",it?\"across\":void 0),dt=J(\"spikesnap\",it?\"hovered data\":void 0);X(\"showspikes\",!!(ct||ut||ht||ft||pt||dt))||(delete Y.spikecolor,delete Y.spikethickness,delete Y.spikedash,delete Y.spikemode,delete Y.spikesnap),p(G,Y,X,{letter:H,counterAxes:$[H],overlayableAxes:Q(H,V),grid:e.grid}),X(\"title.standoff\"),nt(),Y._input=G}for(d=0;d<rt.length;){q=rt[d++],H=(V=g(q)).charAt(0),n.isPlainObject(t[V])||(t[V]={}),G=t[V],Y=s.newContainer(e,V,H+\"axis\"),Z();var gt={letter:H,font:e.font,outerTicks:L[V],showGrid:!P[V],data:[],bgColor:W,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,splomStash:((e._splomAxes||{})[H]||{})[q]};X(\"uirevision\",e.uirevision),Y.type=et[q]||\"linear\",h(G,Y,X,gt,e),p(G,Y,X,{letter:H,counterAxes:$[H],overlayableAxes:Q(H,V),grid:e.grid}),X(\"fixedrange\"),nt(),Y._input=G}var mt=b(\"rangeslider\",\"handleDefaults\"),vt=b(\"rangeselector\",\"handleDefaults\");for(d=0;d<B.length;d++)V=B[d],G=t[V],Y=e[V],mt(t,e,V),\"date\"===Y.type&&vt(G,Y,e,N,Y.calendar),X(\"fixedrange\");for(d=0;d<N.length;d++){V=N[d],G=t[V],Y=e[V];var yt=e[g(Y.anchor)];X(\"fixedrange\",b(\"rangeslider\",\"isVisible\")(yt))}var xt=e._axisConstraintGroups=[],bt=e._axisMatchGroups=[],_t=tt.concat(rt),wt=j.concat(n.simpleMap(rt,g));for(d=0;d<wt.length;d++){var Tt,kt;H=(V=wt[d]).charAt(0),G=t[V],Y=e[V],Tt=\"y\"===H&&!G.hasOwnProperty(\"scaleanchor\")&&C[V]?Y.anchor:void 0,kt=!G.hasOwnProperty(\"constrain\")&&C[V]?\"domain\":void 0,f(G,Y,X,{allAxisIds:_t,layoutOut:e,scaleanchorDflt:Tt,constrainDflt:kt})}for(d=0;d<bt.length;d++){var Mt=bt[d],At=null,St=null;for(q in Mt)(Y=e[g(q)]).matches||(At=Y.range,St=Y.autorange);if(null===At||null===St)for(q in Mt){At=(Y=e[g(q)]).range,St=Y.autorange;break}for(q in Mt)(Y=e[g(q)]).matches&&(Y.range=At.slice(),Y.autorange=St),Y._matchGroup=Mt;if(xt.length)for(q in Mt)for(y=0;y<xt.length;y++){var Et=xt[y];for(var Ct in Et)q===Ct&&(n.warn(\"Axis \"+Ct+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete Et[Ct],Object.keys(Et).length<2&&xt.splice(y,1))}}}},{\"../../components/color\":615,\"../../components/fx/helpers\":651,\"../../components/fx/hovermode_defaults\":654,\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../registry\":881,\"../layout_attributes\":852,\"./axis_defaults\":800,\"./axis_ids\":801,\"./constants\":804,\"./constraints\":805,\"./layout_attributes\":812,\"./position_defaults\":815,\"./type_defaults\":823}],814:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,a=t(\"../../components/color/attributes\").lightFraction,i=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return i.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||a).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":614,\"../../lib\":749,tinycolor2:548}],815:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\");e.exports=function(t,e,r,i){var o,s,l,c,u=i.counterAxes||[],h=i.overlayableAxes||[],f=i.letter,p=i.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===a.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),a.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=a.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),a.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":749,\"fast-isnumeric\":241}],816:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var a=[t.r2l(t.range[0]),t.r2l(t.range[1])],i=a[0]+(a[1]-a[0])*r;t.range=t._input.range=[t.l2r(i+(a[0]-i)*e),t.l2r(i+(a[1]-i)*e)]}},{\"../../constants/alignment\":717}],817:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),a=t(\"../../registry\"),i=t(\"../../components/drawing\").dashStyle,o=t(\"../../components/color\"),s=t(\"../../components/fx\"),l=t(\"../../components/fx/helpers\").makeEventData,c=t(\"../../components/dragelement/helpers\"),u=c.freeMode,h=c.rectMode,f=c.drawMode,p=c.openMode,d=c.selectMode,g=t(\"../../components/shapes/draw_newshape/display_outlines\"),m=t(\"../../components/shapes/draw_newshape/helpers\").handleEllipse,v=t(\"../../components/shapes/draw_newshape/newshapes\"),y=t(\"../../lib\"),x=t(\"../../lib/polygon\"),b=t(\"../../lib/throttle\"),_=t(\"./axis_ids\").getFromId,w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"./constants\"),M=k.MINSELECT,A=x.filter,S=x.tester,E=t(\"./handle_outline\").clearSelect,C=t(\"./helpers\"),L=C.p2r,P=C.axValue,I=C.getTransform;function z(t,e,r,n,a,i,o){var s,l,c,u,h,f,d,m,v,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,b=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){F(t,e,i);var _=function(t,e){var r,n,a=t[0],i=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],a.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===a.hoverOnBox)break;void 0!==a.pointNumber?i=a.pointNumber:void 0!==a.binNumber&&(i=a.binNumber,o=a.pointNumbers);break}return{pointNumber:i,pointNumbers:o,searchInfo:r}}(y,s=N(e,r,n,a));if(_.pointNumbers.length>0?function(t,e){var r,n,a,i=[];for(a=0;a<t.length;a++)(r=t[a]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&i.push(r);if(1===i.length&&i[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(a=0;a<e.pointNumbers.length;a++)if(n.selectedpoints.indexOf(e.pointNumbers[a])<0)return!1;return!0}return!1}(s,_):function(t){var e,r,n,a=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((a+=r.selectedpoints.length)>1)return!1}return 1===a}(s)&&(f=j(_))){for(o&&o.remove(),v=0;v<s.length;v++)(l=s[v])._module.selectPoints(l,!1);U(e,s),B(i),x&&e.emit(\"plotly_deselect\",null)}else{for(d=t.shiftKey&&(void 0!==f?f:j(_)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(_.pointNumber,_.searchInfo,d),u=R(i.selectionDefs.concat([c])),v=0;v<s.length;v++)if(h=V(s[v]._module.selectPoints(s[v],u),s[v]),b.length)for(var w=0;w<h.length;w++)b.push(h[w]);else b=h;if(U(e,s,m={points:b}),c&&i&&i.selectionDefs.push(c),o){var T=i.mergedPolygons,k=p(i.dragmode);g(q(T,k),o,i)}x&&e.emit(\"plotly_selected\",m)}}}function O(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function D(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,a){var i=t.searchInfo.cd[0].trace._expandedIndex;return a.cd[0].trace._expandedIndex===i&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function R(t){for(var e=[],r=O(t[0])?0:t[0][0][0],n=r,a=O(t[0])?0:t[0][0][1],i=a,o=0;o<t.length;o++)if(O(t[o]))e.push(D(t[o]));else{var s=x.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),a=Math.min(a,s.ymin),i=Math.max(i,s.ymax)}return{xmin:r,xmax:n,ymin:a,ymax:i,pts:[],contains:function(t,r,n,a){for(var i=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,a)&&(i=!1===e[o].subtract);return i},isRect:!1,degenerate:!1}}function F(t,e,r){e._fullLayout._drawing=!1;var n=e._fullLayout,a=r.plotinfo,i=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===a.id,s=(t.shiftKey||t.altKey)&&!(f(i)&&p(i));o&&s&&a.selection&&a.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=a.selection.selectionDefs,r.mergedPolygons=a.selection.mergedPolygons):s&&a.selection||B(r),o||(E(e),n._lastSelectedSubplot=a.id)}function B(t){var e=t.dragmode,r=t.plotinfo,n=t.gd;if(n._fullLayout._activeShapeIndex>=0&&n._fullLayout._deactivateShape(n),f(e)){var i=n._fullLayout._zoomlayer.selectAll(\".select-outline-\"+r.id);if(i&&n._fullLayout._drawing){var o=v(i,t);o&&a.call(\"_guiRelayout\",n,{shapes:o}),n._fullLayout._drawing=!1}}r.selection={},r.selection.selectionDefs=t.selectionDefs=[],r.selection.mergedPolygons=t.mergedPolygons=[]}function N(t,e,r,n){var a,i,o,s=[],l=e.map((function(t){return t._id})),c=r.map((function(t){return t._id}));for(o=0;o<t.calcdata.length;o++)if(!0===(i=(a=t.calcdata[o])[0].trace).visible&&i._module&&i._module.selectPoints)if(!n||i.subplot!==n&&i.geo!==n)if(\"splom\"===i.type&&i._xaxes[l[0]]&&i._yaxes[c[0]]){var u=f(i._module,a,e[0],r[0]);u.scene=t._fullLayout._splomScenes[i.uid],s.push(u)}else if(\"sankey\"===i.type){var h=f(i._module,a,e[0],r[0]);s.push(h)}else{if(-1===l.indexOf(i.xaxis))continue;if(-1===c.indexOf(i.yaxis))continue;s.push(f(i._module,a,_(t,i.xaxis),_(t,i.yaxis)))}else s.push(f(i._module,a,e[0],r[0]));return s;function f(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function j(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,a=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(a)>-1}function U(t,e,r){var n,i,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],f=h.data,p=h.fullData;h.pointIndices?([].push.apply(f.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(p.selectedpoints,h.pointIndices)):(f.selectedpoints.push(h.pointIndex),s._fullInput!==s&&p.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var d=!1;for(n=0;n<e.length;n++){s=(o=(i=e[n]).cd)[0].trace,a.traceIs(s,\"regl\")&&(d=!0);var g=i._module,m=g.styleOnSelect||g.style;m&&(m(t,o,o[0].node3),o[0].nodeRangePlot3&&m(t,o,o[0].nodeRangePlot3))}d&&(w(t),T(t))}function V(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,a=0;a<t.length;a++)t[a]=l(t[a],n,r);return t}function q(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var a=0;a<t[n].length;a++){r[n][a]=[],r[n][a][0]=a?\"L\":\"M\";for(var i=0;i<t[n][a].length;i++)r[n][a].push(t[n][a][i])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}e.exports={prepSelect:function(t,e,r,a,l){var c,v,x,_,w,T,E,C=u(l),O=h(l),D=p(l),j=f(l),H=d(l),G=\"drawcircle\"===l,Y=\"drawline\"===l||G,W=a.gd,Z=W._fullLayout,X=Z._zoomlayer,J=a.element.getBoundingClientRect(),K=a.plotinfo,Q=I(K),$=e-J.left,tt=r-J.top,et=$,rt=tt,nt=\"M\"+$+\",\"+tt,at=a.xaxes[0]._length,it=a.yaxes[0]._length,ot=a.xaxes.concat(a.yaxes),st=t.altKey&&!(f(l)&&D);F(t,W,a),C&&(c=A([[$,tt]],k.BENDPX));var lt=X.selectAll(\"path.select-outline-\"+K.id).data(j?[0]:[1,2]),ct=Z.newshape;lt.enter().append(\"path\").attr(\"class\",(function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+K.id})).style(j?{opacity:ct.opacity/2,fill:D?void 0:ct.fillcolor,stroke:ct.line.color,\"stroke-dasharray\":i(ct.line.dash,ct.line.width),\"stroke-width\":ct.line.width+\"px\"}:{}).attr(\"fill-rule\",ct.fillrule).classed(\"cursor-move\",!!j).attr(\"transform\",Q).attr(\"d\",nt+\"Z\");var ut,ht=X.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:o.background,stroke:o.defaultLine,\"stroke-width\":1}).attr(\"transform\",Q).attr(\"d\",\"M0,0Z\"),ft=Z._uid+k.SELECTID,pt=[],dt=N(W,a.xaxes,a.yaxes,a.subplot);function gt(t,e){return t-e}ut=K.fillRangeItems?K.fillRangeItems:O?function(t,e){var r=t.range={};for(w=0;w<ot.length;w++){var n=ot[w],a=n._id.charAt(0);r[n._id]=[L(n,e[a+\"min\"]),L(n,e[a+\"max\"])].sort(gt)}}:function(t,e,r){var n=t.lassoPoints={};for(w=0;w<ot.length;w++){var a=ot[w];n[a._id]=r.filtered.map(P(a))}},a.moveFn=function(t,e){et=Math.max(0,Math.min(at,t+$)),rt=Math.max(0,Math.min(it,e+tt));var r=Math.abs(et-$),i=Math.abs(rt-tt);if(O){var o,s,l;if(H){var u=Z.selectdirection;switch(o=\"any\"===u?i<Math.min(.6*r,M)?\"h\":r<Math.min(.6*i,M)?\"v\":\"d\":u){case\"h\":s=G?it/2:0,l=it;break;case\"v\":s=G?at/2:0,l=at}}if(j)switch(Z.newshape.drawdirection){case\"vertical\":o=\"h\",s=G?it/2:0,l=it;break;case\"horizontal\":o=\"v\",s=G?at/2:0,l=at;break;case\"ortho\":r<i?(o=\"h\",s=tt,l=rt):(o=\"v\",s=$,l=et);break;default:o=\"d\"}\"h\"===o?((_=Y?m(G,[et,s],[et,l]):[[$,s],[$,l],[et,l],[et,s]]).xmin=Y?et:Math.min($,et),_.xmax=Y?et:Math.max($,et),_.ymin=Math.min(s,l),_.ymax=Math.max(s,l),ht.attr(\"d\",\"M\"+_.xmin+\",\"+(tt-M)+\"h-4v\"+2*M+\"h4ZM\"+(_.xmax-1)+\",\"+(tt-M)+\"h4v\"+2*M+\"h-4Z\")):\"v\"===o?((_=Y?m(G,[s,rt],[l,rt]):[[s,tt],[s,rt],[l,rt],[l,tt]]).xmin=Math.min(s,l),_.xmax=Math.max(s,l),_.ymin=Y?rt:Math.min(tt,rt),_.ymax=Y?rt:Math.max(tt,rt),ht.attr(\"d\",\"M\"+($-M)+\",\"+_.ymin+\"v-4h\"+2*M+\"v4ZM\"+($-M)+\",\"+(_.ymax-1)+\"v4h\"+2*M+\"v-4Z\")):\"d\"===o&&((_=Y?m(G,[$,tt],[et,rt]):[[$,tt],[$,rt],[et,rt],[et,tt]]).xmin=Math.min($,et),_.xmax=Math.max($,et),_.ymin=Math.min(tt,rt),_.ymax=Math.max(tt,rt),ht.attr(\"d\",\"M0,0Z\"))}else C&&(c.addPt([et,rt]),_=c.filtered);a.selectionDefs&&a.selectionDefs.length?(x=function(t,e,r){if(r)return n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions;return n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(a.mergedPolygons,_,st),_.subtract=st,v=R(a.selectionDefs.concat([_]))):(x=[_],v=S(_)),g(q(x,D),lt,a),H&&b.throttle(ft,k.SELECTDELAY,(function(){var t;pt=[];var e,r=[];for(w=0;w<dt.length;w++)if(e=(T=dt[w])._module.selectPoints(T,v),r.push(e),t=V(e,T),pt.length)for(var n=0;n<t.length;n++)pt.push(t[n]);else pt=t;U(W,dt,E={points:pt}),ut(E,_,c),a.gd.emit(\"plotly_selecting\",E)}))},a.clickFn=function(t,e){if(ht.remove(),W._fullLayout._activeShapeIndex>=0)W._fullLayout._deactivateShape(W);else if(!j){var r=Z.clickmode;b.done(ft).then((function(){if(b.clear(ft),2===t){for(lt.remove(),w=0;w<dt.length;w++)(T=dt[w])._module.selectPoints(T,!1);U(W,dt),B(a),W.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&z(e,W,a.xaxes,a.yaxes,a.subplot,a,lt),\"event\"===r&&W.emit(\"plotly_selected\",void 0);s.click(W,e)})).catch(y.error)}},a.doneFn=function(){ht.remove(),b.done(ft).then((function(){b.clear(ft),a.gd.emit(\"plotly_selected\",E),_&&a.selectionDefs&&(_.subtract=st,a.selectionDefs.push(_),a.mergedPolygons.length=0,[].push.apply(a.mergedPolygons,x)),a.doneFnCompleted&&a.doneFnCompleted(pt)})).catch(y.error),j&&B(a)}},clearSelect:E,clearSelectionsCache:B,selectOnClick:z}},{\"../../components/color\":615,\"../../components/dragelement/helpers\":633,\"../../components/drawing\":637,\"../../components/fx\":655,\"../../components/fx/helpers\":651,\"../../components/shapes/draw_newshape/display_outlines\":700,\"../../components/shapes/draw_newshape/helpers\":701,\"../../components/shapes/draw_newshape/newshapes\":702,\"../../lib\":749,\"../../lib/clear_gl_canvases\":733,\"../../lib/polygon\":761,\"../../lib/throttle\":774,\"../../plot_api/subroutines\":788,\"../../registry\":881,\"./axis_ids\":801,\"./constants\":804,\"./handle_outline\":808,\"./helpers\":809,polybooljs:491}],818:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"d3-time-format\").utcFormat,i=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=o.cleanNumber,l=o.ms2DateTime,c=o.dateTime2ms,u=o.ensureNumber,h=o.isArrayOrTypedArray,f=t(\"../../constants/numerical\"),p=f.FP_SAFE,d=f.BADNUM,g=f.LOG_CLIP,m=f.ONEWEEK,v=f.ONEDAY,y=f.ONEHOUR,x=f.ONEMIN,b=f.ONESEC,_=t(\"./axis_ids\"),w=t(\"./constants\"),T=w.HOUR_PATTERN,k=w.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function A(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",f=r.charAt(0);function S(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],a=t.range[1];return.5*(n+a-2*g*Math.abs(n-a))}return d}function E(e,r,n,a){if((a||{}).msUTC&&i(e))return+e;var s=c(e,n||t.calendar);if(s===d){if(!i(e))return d;e=+e;var l=Math.floor(10*o.mod(e+.05,1)),u=Math.round(e-l/10);s=c(new Date(u))+l/10}return s}function C(e,r,n){return l(e,r,n||t.calendar)}function L(e){return t._categories[Math.round(e)]}function P(e){if(A(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return d}function I(e){if(t._categoriesMap)return t._categoriesMap[e]}function z(t){var e=I(t);return void 0!==e?e:i(t)?+t:void 0}function O(t,e,r){return n.round(r+e*t,2)}function D(t,e,r){return(t-r)/e}var R=function(e){return i(e)?O(e,t._m,t._b):d},F=function(e){return D(e,t._m,t._b)};if(t.rangebreaks){var B=\"y\"===f;R=function(e){if(!i(e))return d;var r=t._rangebreaks.length;if(!r)return O(e,t._m,t._b);var n=B;t.range[0]>t.range[1]&&(n=!n);for(var a=n?-1:1,o=a*e,s=0,l=0;l<r;l++){var c=a*t._rangebreaks[l].min,u=a*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var h=t._B[s]||0;return isFinite(h)?O(e,t._m2,h):0},F=function(e){var r=t._rangebreaks.length;if(!r)return D(e,t._m,t._b);for(var n=0,a=0;a<r&&!(e<t._rangebreaks[a].pmin);a++)e>t._rangebreaks[a].pmax&&(n=a+1);return D(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?S:u,t.l2c=\"log\"===t.type?M:u,t.l2p=R,t.p2l=F,t.c2p=\"log\"===t.type?function(t,e){return R(S(t,e))}:R,t.p2c=\"log\"===t.type?function(t){return M(F(t))}:F,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=s,t.c2d=t.c2r=t.l2d=t.l2r=u,t.d2p=t.r2p=function(e){return t.l2p(s(e))},t.p2d=t.p2r=F,t.cleanPos=u):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return S(s(t),e)},t.r2d=t.r2c=function(t){return M(s(t))},t.d2c=t.r2l=s,t.c2d=t.l2r=u,t.c2r=S,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(F(t))},t.r2p=function(e){return t.l2p(s(e))},t.p2r=F,t.cleanPos=u):\"date\"===t.type?(t.d2r=t.r2d=o.identity,t.d2c=t.r2c=t.d2l=t.r2l=E,t.c2d=t.c2r=t.l2d=t.l2r=C,t.d2p=t.r2p=function(e,r,n){return t.l2p(E(e,0,n))},t.p2d=t.p2r=function(t,e,r){return C(F(t),e,r)},t.cleanPos=function(e){return o.cleanDate(e,d,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=P,t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(F(t))},t.r2p=t.d2p,t.p2r=F,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:u(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=I,t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(F(t))},t.r2p=t.d2p,t.p2r=F,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:u(t)},t.setupMultiCategory=function(n){var a,i,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(a=0;a<l.length;a++){var c=l[a];if(c[r])for(var u in c)if(u!==r){var p=e[_.id2name(u)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(a=0;a<s.length;a++){var m=n[s[a]];if(f in m){var v=m[f],y=m._length||o.minRowLength(v);if(h(v[0])&&h(v[1]))for(i=0;i<y;i++){var x=v[0][i],b=v[1][i];A(x)&&A(b)&&(g.push([x,b]),x in d[0][1]||(d[0][1][x]=d[0][0]++),b in d[1][1]||(d[1][1][b]=d[1][0]++))}}}for(g.sort((function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var a=d[1][1];return a[t[1]]-a[e[1]]})),a=0;a<g.length;a++)P(g[a])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,a,s=o.nestedProperty(t,e).get();if(a=(a=\"date\"===t.type?o.dfltRange(t.calendar):\"y\"===f?w.DFLTRANGEY:r.dfltRange||w.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(a[0]=0),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=o.cleanDate(s[0],d,t.calendar),s[1]=o.cleanDate(s[1],d,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!o.isDateTime(s[n],t.calendar)){t[e]=a;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=o.constrain(t.r2l(s[0]),o.MIN_MS+1e3,o.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=a;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-p?s[n]=-p:s[n]>p&&(s[n]=p),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else o.nestedProperty(t,e).set(a)},t.setScale=function(r){var n=e._size;if(t.overlaying){var a=_.getFromId({_fullLayout:e},t.overlaying);t.domain=a.domain}var i=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(i);var s,l,c=t.r2l(t[i][0],o),u=t.r2l(t[i][1],o),h=\"y\"===f;if((h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=h;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(h?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=R(l.min),l.pmax=R(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){for(var r,n,a,i,l,c=t.rangebreaks||[],u=0;u<c.length;u++){var h=c[u];if(h.enabled)if(h.bounds){var f=h.pattern;switch(n=(r=o.simpleMap(h.bounds,f?s:t.d2c))[0],a=r[1],f){case k:i=(l=new Date(e)).getUTCDay(),n>a&&(a+=7,i<n&&(i+=7));break;case T:i=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>a&&(a+=24,i<n&&(i+=24));break;case\"\":i=e}if(i>=n&&i<a)return d}else for(var p=o.simpleMap(h.values,t.d2c).sort(o.sorterAsc),g=0;g<p.length;g++)if(a=(n=p[g])+h.dvalue,e>=n&&e<a)return d}return e},t.locateBreaks=function(e,r){var n,a,i,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===k&&e.pattern===T?-1:e.pattern===k&&t.pattern===T?1:0})),h=function(t,n){if((t=o.constrain(t,e,r))!==(n=o.constrain(n,e,r))){for(var a=!0,i=0;i<c.length;i++){var s=c[i];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),a=!1)}a&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var f=u[n];if(f.enabled)if(f.bounds){var p=e,d=r;f.pattern&&(p=Math.floor(p)),i=(a=o.simpleMap(f.bounds,f.pattern?s:t.r2l))[0],l=a[1];var g,_,w=new Date(p);switch(f.pattern){case k:_=m,g=(l-i+(l<i?7:0))*v,p+=i*v-(w.getUTCDay()*v+w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case T:_=v,g=(l-i+(l<i?24:0))*y,p+=i*y-(w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(a[0],a[1]),g=_=(d=Math.max(a[0],a[1]))-p}for(var M=p;M<d;M+=_)h(M,M+g)}else for(var A=o.simpleMap(f.values,t.d2c),S=0;S<A.length;S++)h(i=A[S],l=i+f.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var a,i,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(a=e[r],l=e._length||o.minRowLength(a),o.isTypedArray(a)&&(\"linear\"===c||\"log\"===c)){if(l===a.length)return a;if(a.subarray)return a.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var a=(t[0]||[])[n],i=(t[1]||[])[n];r[n]=I([a,i])}return r}(a,l);for(i=new Array(l),s=0;s<l;s++)i[s]=t.d2c(a[s],0,u,n)}else{var h=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,f=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(a=e[{x:\"y\",y:\"x\"}[r]],l=e._length||a.length,i=new Array(l),s=0;s<l;s++)i[s]=h+s*f}if(t.rangebreaks)for(s=0;s<l;s++)i[s]=t.maskBreaks(i[s]);return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[f],null,r),a=t.r2l(t.range[0]),i=t.r2l(t.range[1]);return a<i?a<=n&&n<=i:i<=n&&n<=a},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var n=e._axisMatchGroups;if(n&&n.length){for(var a=!1,i=0;i<n.length;i++){var o=n[i];if(o[r]){a=!0;var s=null,l=null;for(var c in o){var u=e[_.id2name(c)];if(u._categories){s=u._categories,l=u._categoriesMap;break}}s&&l?(t._categories=s,t._categoriesMap=l):t._emptyCategories();break}}a||t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var h=0;h<t._initialCategories.length;h++)P(t._initialCategories[h])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var a=0;a<t._initialCategories.length;a++)P(t._initialCategories[a]);n=n.concat(t._traceIndices);var i=t._matchGroup;for(var o in i)if(r!==o){var s=e[_.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var N=e._d3locale;\"date\"===t.type&&(t._dateFormat=N?N.timeFormat:a,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=N?N.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":724,\"../../lib\":749,\"./axis_ids\":801,\"./constants\":804,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],819:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\"),i=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}function s(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,a){var i=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",i);r(\"ticksuffix\",a.tickSuffixDflt)&&r(\"showticksuffix\",i)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==a.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\");i(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),e.tickformatstops.length||delete e.tickformatstops,d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":749,\"../array_container_defaults\":793,\"./layout_attributes\":812}],820:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e,r,i){var o=n.coerce2(t,e,a,\"ticklen\"),s=n.coerce2(t,e,a,\"tickwidth\"),l=n.coerce2(t,e,a,\"tickcolor\",e.color);r(\"ticks\",i.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":749,\"./layout_attributes\":812}],821:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\"),a=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){function o(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var s=o(\"tick0\"),l=o(\"dtick\"),c=o(\"tickvals\"),u=r(\"tickmode\",a(c)?\"array\":l?\"linear\":\"auto\");if(\"auto\"===u)r(\"nticks\");else if(\"linear\"===u){var h=e.dtick=n.dtick(l,i);e.tick0=n.tick0(s,i,e.calendar,h)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"../../lib\":749,\"./clean_ticks\":803}],822:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"./axes\");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,h,f,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var i=e[n],o=i.plotinfo.xaxis,s=i.plotinfo.yaxis;i.xr0&&(r[o._name+\".range\"]=i.xr0.slice()),i.yr0&&(r[s._name+\".range\"]=i.yr0.slice())}return a.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}()})),h=Date.now(),p=window.requestAnimationFrame((function n(){f=Date.now();for(var i=Math.min(1,(f-h)/r.duration),o=d(i),s=0;s<e.length;s++)m(e[s],o);f-h>r.duration?(!function(){for(var r={},n=0;n<e.length;n++){var i=e[n],o=i.plotinfo.xaxis,s=i.plotinfo.yaxis;i.xr1&&(r[o._name+\".range\"]=i.xr1.slice()),i.yr1&&(r[s._name+\".range\"]=i.yr1.slice())}u&&u(),a.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function m(e,r){var n=e.plotinfo,a=n.xaxis,l=n.yaxis,c=a._length,u=l._length,h=!!e.xr1,f=!!e.yr1,p=[];if(h){var d=i.simpleMap(e.xr0,a.r2l),g=i.simpleMap(e.xr1,a.r2l),m=d[1]-d[0],v=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*v/m),a.range[0]=a.l2r(d[0]*(1-r)+r*g[0]),a.range[1]=a.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(f){var y=i.simpleMap(e.yr0,l.r2l),x=i.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=a.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,a,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[a._id,l._id]);var w=h?c/p[2]:1,T=f?u/p[3]:1,k=h?p[0]:0,M=f?p[1]:0,A=h?p[0]/p[2]*c:0,S=f?p[1]/p[3]*u:0,E=a._offset-A,C=l._offset-S;n.clipRect.call(o.setTranslate,k,M).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,C).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../registry\":881,\"./axes\":798,d3:169}],823:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,a=t(\"./axis_autotype\");function i(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=i(t),a=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return a&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var a=t[n];if(\"splom\"===a.type&&a._length>0&&(a[\"_\"+r+\"axes\"]||{})[e])return a;if((a[r+\"axis\"]||r)===e){if(o(a,r))return a;if((a[r]||[]).length||a[r+\"0\"])return a}}}(e,s,l);if(!c)return;if(\"histogram\"===c.type&&l==={v:\"y\",h:\"x\"}[c.orientation||\"v\"])return void(t.type=\"linear\");var u=l+\"calendar\",h=c[u],f={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(f.noMultiCategory=!0);if(o(c,l)){var p=i(c),d=[];for(r=0;r<e.length;r++){var g=e[r];n(g,\"box-violin\")&&(g[l+\"axis\"]||l)===s&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=a(d,h,f)}else if(\"splom\"===c.type){var m=c.dimensions[c._axesDim[s]];m.visible&&(t.type=a(m.values,h,f))}else t.type=a(c[l]||[c[l+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":881,\"./axis_autotype\":799}],824:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),a=t(\"../lib\");function i(t,e,r){var n,i,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return i=a.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==i&&(s=!0),o[e.prop]=i,{changed:s,value:i}}function o(t,e){var r=[],n=e[0],i={};if(\"string\"==typeof n)i[n]=e[1];else{if(!a.isPlainObject(n))return r;i=n}return l(i,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,i,o,s=[];if(n=e[0],i=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=i;else{if(!a.isPlainObject(n))return s;o=n,void 0===r&&(r=i)}return void 0===r&&(r=null),l(o,(function(e,n,a){var i,o;if(Array.isArray(a)){o=a.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),i=[];for(var c=0;c<l;c++)i[c]=r?r[c]:c}else o=a,i=r?r.slice():null;if(null===i)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(i)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<i.length;h++)o[h]=u}o.length=Math.min(i.length,o.length)}s.push({type:\"data\",prop:e,traces:i,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(i){var o=t[i];if(\"_\"!==i[0]){var s=r+(n>0?\".\":\"\")+i;a.isPlainObject(o)?l(o,e,s,n+1):e(s,i,o)}}))}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){i(t,c,s.cache),s.check=function(){if(l){var e=i(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else a.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var a,i,o=e.length;for(a=0;a<o;a++){var s,l=e[a],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(i){if((s=h[0]).type!==i.type)return!1;if(s.prop!==i.prop)return!1;if(Array.isArray(i.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<i.traces.length;f++)if(i.traces[f]!==s.traces[f])return!1}else if(s.prop!==i.prop)return!1}else i=h[0],Array.isArray(i.traces)&&i.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=a)}return i},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var i=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return i.apply(null,o).catch((function(t){return a.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":749,\"../registry\":881}],825:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},a=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(a.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},a.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),a},r.defaults=function(t,e,r,n){var a=n&&n.x||[0,1],i=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?a=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?i=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",a),u=r(\"domain.y\",i);c[0]<c[1]||(t.domain.x=a.slice()),u[0]<u[1]||(t.domain.y=i.slice())}},{\"../lib/extend\":739}],826:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],827:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],828:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],829:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../cartesian/autorange\").getAutoRange,f=t(\"../../components/dragelement\"),p=t(\"../cartesian/select\").prepSelect,d=t(\"../cartesian/select\").clearSelect,g=t(\"../cartesian/select\").selectOnClick,m=t(\"./zoom\"),v=t(\"./constants\"),y=t(\"../../lib/geo_location_utils\"),x=t(\"../../lib/topojson_utils\"),b=t(\"topojson-client\").feature;function _(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var w=_.prototype;function T(t,e){var r=v.clipPad,n=t[0]+r,a=t[1]-r,i=e[0]+r,o=e[1]-r;n>0&&a<0&&(a+=360);var s=(a-n)/4;return{type:\"Polygon\",coordinates:[[[n,i],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[a,o],[a,i],[a-s,i],[a-2*s,i],[a-3*s,i],[n,i]]]}}e.exports=function(t){return new _(t)},w.plot=function(t,e,r){var n=this,a=e[this.id],i=[],o=!1;for(var s in v.layerNameToAdjective)if(\"frame\"!==s&&a[\"show\"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=x.getTopojsonName(a);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&i.push(n.fetchTopojson()))}i=i.concat(y.fetchTraceGeoData(t)),r.push(new Promise((function(r,a){Promise.all(i).then((function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()})).catch(a)})))},w.fetchTopojson=function(){var t=this,e=x.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,a){n.json(e,(function(n,i){if(n)return 404===n.status?a(new Error([\"plotly.js could not find topojson file at\",e,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):a(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=i,r()}))}))},w.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var a=t[n],i=a[0].trace;\"choropleth\"===i.type&&(this.hasChoropleth=!0),!0===i.visible&&i._length>0&&i._module.calcGeoJSON(a,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=o.selectAll(\".point\"),this.dataPoints.text=o.selectAll(\"text\"),this.dataPaths.line=o.selectAll(\".js-line\");var s=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=s.selectAll(\"path\"),this.render()}},w.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,g=this.projection=function(t){for(var e=t.projection.type,r=n.geo[v.projNames[e]](),a=t._isClipped?v.lonaxisSpan[e]/2:null,i=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<i.length;s++){var l=i[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(a){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>a*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],a=t[1][1]-t[0][1],i=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),i&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),a/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(a-s*(o[1][1]+o[0][1]))/2;return i&&r.clipExtent(i),r.scale(150*s).translate([l,c])},r.precision(v.precision),a&&r.clipAngle(a-v.clipPad);return r}(o),m=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],y=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=m[1][0]-m[0][0],d._length=m[1][1]-m[0][1],p.range=h(r,p),d.range=h(r,d);var w=(p.range[0]+p.range[1])/2,k=(d.range[0]+d.range[1])/2;if(o._isScoped)y={lon:w,lat:k};else if(o._isClipped){y={lon:w,lat:k},x={lon:w,lat:k,roll:x.roll};var M=c.type,A=v.lonaxisSpan[M]/2||180,S=v.lataxisSpan[M]/2||90;b=[w-A,w+A],_=[k-S,k+S]}else y={lon:w,lat:k},x={lon:w,lat:x.lat,roll:x.roll}}g.center([y.lon-x.lon,y.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=T(b,_);g.fitExtent(m,E);var C=this.bounds=g.getBounds(E),L=this.fitScale=g.scale(),P=g.translate();if(!isFinite(C[0][0])||!isFinite(C[0][1])||!isFinite(C[1][0])||!isFinite(C[1][1])||isNaN(P[0])||isNaN(P[0])){for(var I=[\"fitbounds\",\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],z=\"Invalid geo settings, relayout'ing to default view.\",O={},D=0;D<I.length;D++)O[this.id+\".\"+I[D]]=null;return this.viewInitial=null,i.warn(z),r._promises.push(a.call(\"relayout\",r,O)),z}if(o.fitbounds){var R=g.getBounds(T(p.range,d.range)),F=Math.min((C[1][0]-C[0][0])/(R[1][0]-R[0][0]),(C[1][1]-C[0][1])/(R[1][1]-R[0][1]));isFinite(F)?g.scale(F*L):i.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else g.scale(c.scale*L);var B=this.midPt=[(C[0][0]+C[1][0])/2,(C[0][1]+C[1][1])/2];if(g.translate([P[0]+(B[0]-P[0]),P[1]+(B[1]-P[1])]).clipExtent(C),o._isAlbersUsa){var N=g([y.lon,y.lat]),j=g.translate();g.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},w.updateBaseLayers=function(t,e){var r=this,a=r.topojson,i=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(v.lineLayers[t])}function f(t){return Boolean(v.fillLayers[t])}var p=(this.hasChoropleth?v.layersForChoropleth:v.layers).filter((function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid})),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each((function(t){delete i[t],delete l[t],n.select(this).remove()})),d.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=i[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),d.order(),d.each((function(r){var n=l[r],i=v.layerNameToAdjective[r];\"frame\"===r?n.datum(v.sphereSVG):h(r)||f(r)?n.datum(b(a,a.objects[r])):c(r)&&n.datum(function(t,e,r){var n,a,i,o=e[t],s=v.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,a=s.lataxisRange,i=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,a=s.lonaxisRange,i=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,g=f[p]=[],m=a[0];m<a[1]+2.5;m+=2.5)g.push(i(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[i+\"color\"]).call(s.dashLine,\"\",e[i+\"width\"]):f(r)&&n.call(o.fill,e[i+\"color\"])}))},w.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,a=r[0][0]-n,i=r[0][1]-n,l=r[1][0]-a+n,c=r[1][1]-i+n;s.setRect(this.clipRect,a,i,l,c),this.bgRect.call(s.setRect,a,i,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=a,this.xaxis._length=l,this.yaxis._offset=i,this.yaxis._length=c},w.updateFx=function(t,e){var r=this,i=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var h={element:r.bgRect.node(),gd:i,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&d(i)}};\"pan\"===s?(o.node().onmousedown=null,o.call(m(r,e)),o.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];a.call(\"_guiRelayout\",i,e),i.emit(\"plotly_doubleclick\",null)})),i._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),h.prepFn=function(t,e,r){p(t,e,r,h,s)},f.init(h)),o.on(\"mousemove\",(function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return f.unhover(i,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(i,n.event,r.id)})),o.on(\"mouseout\",(function(){i._dragging||f.unhover(i,n.event)})),o.on(\"click\",(function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&g(n.event,i,[r.xaxis],[r.yaxis],r.id,h),c.indexOf(\"event\")>-1&&l.click(i,n.event))}))}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},w.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,a=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",a),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,a,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},w.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,a=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":a.lon,\"projection.rotation.lat\":a.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":a.lon},i.extendFlat(this.viewInitial,e)},w.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function a(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",a).attr(\"transform\",n)}},{\"../../components/color\":615,\"../../components/dragelement\":634,\"../../components/drawing\":637,\"../../components/fx\":655,\"../../lib\":749,\"../../lib/geo_location_utils\":742,\"../../lib/topojson_utils\":776,\"../../registry\":881,\"../cartesian/autorange\":797,\"../cartesian/axes\":798,\"../cartesian/select\":817,\"../plots\":861,\"./constants\":828,\"./projections\":833,\"./zoom\":834,d3:169,\"topojson-client\":551}],830:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex,i=t(\"./geo\"),o=\"geo\",s=a(o),l={};l.geo={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.geo,s=0;s<a.length;s++){var l=a[s],c=n(r,o,l),u=e[l]._subplot;u||(u=i({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var a=e[r[n]];a._subplot.updateFx(e,a)}},clean:function(t,e,r,n){for(var a=n._subplots.geo||[],i=0;i<a.length;i++){var o=a[i],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}}}},{\"../../lib\":749,\"../../plots/get_data\":835,\"./geo\":829,\"./layout_attributes\":831,\"./layout_defaults\":832}],831:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),a=t(\"../domain\").attributes,i=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:a({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(i.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(i.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:i.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:i.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:i.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:i.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":614,\"../../plot_api/edit_types\":780,\"../domain\":825,\"./constants\":828}],832:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../subplot_defaults\"),i=t(\"../get_data\").getSubplotData,o=t(\"./constants\"),s=t(\"./layout_attributes\"),l=o.axesNames;function c(t,e,r,a){var s=i(a.fullData,\"geo\",a.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),h=o.scopeDefaults[u],f=r(\"projection.type\",h.projType),p=e._isAlbersUsa=\"albers usa\"===f;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,g=e._isConic=-1!==f.indexOf(\"conic\"),m=e._isClipped=!!o.lonaxisSpan[f];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var y=r(\"visible\"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=h[_+\"Range\"];else{var T=o[_+\"Span\"],k=(T[f]||T[\"*\"])/2,M=r(\"projection.rotation.\"+_.substr(0,3),h.projRotate[x]);b=[M-k,M+k]}var A=r(_+\".range\",b);r(_+\".tick0\"),r(_+\".dtick\",w),r(_+\".showgrid\",!!y&&void 0)&&(r(_+\".gridcolor\"),r(_+\".gridwidth\")),e[_]._ax={type:\"linear\",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,C=S[0],L=S[1];C>0&&L<0&&(L+=360);var P,I,z,O=(C+L)/2;if(!p){var D=d?h.projRotate:[O,0,0];P=r(\"projection.rotation.lon\",D[0]),r(\"projection.rotation.lat\",D[1]),r(\"projection.rotation.roll\",D[2]),r(\"showcoastlines\",!d&&y)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!y&&void 0)&&r(\"oceancolor\")}(p?(I=-96.6,z=38.7):(I=d?O:P,z=(E[0]+E[1])/2),r(\"center.lon\",I),r(\"center.lat\",z),g)&&r(\"projection.parallels\",h.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\",!!y&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!y&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!y&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&y)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",y),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",y)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):m?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){a(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},{\"../../lib\":749,\"../get_data\":835,\"../subplot_defaults\":875,\"./constants\":828,\"./layout_attributes\":831}],833:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map((function(t){return r(t,n)}))};if(!c.hasOwnProperty(e.type))return null;var a=c[e.type];return t.geo.stream(e,n(a)),a.result()}t.geo.project=function(t,e){var a=e.stream;if(!a)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,a)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map((function(t){return e(t,r)}))}}},a=[],i=[],o={point:function(t,e){a.push([t,e])},result:function(){var t=a.length?a.length<2?{type:\"Point\",coordinates:a[0]}:{type:\"MultiPoint\",coordinates:a}:null;return a=[],t}},s={lineStart:u,point:function(t,e){a.push([t,e])},lineEnd:function(){a.length&&(i.push(a),a=[])},result:function(){var t=i.length?i.length<2?{type:\"LineString\",coordinates:i[0]}:{type:\"MultiLineString\",coordinates:i}:null;return i=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){a.push([t,e])},lineEnd:function(){var t=a.length;if(t){do{a.push(a[0].slice())}while(++t<4);i.push(a),a=[]}},polygonEnd:u,result:function(){if(!i.length)return null;var t=[],e=[];return i.forEach((function(r){!function(t){if((e=t.length)<4)return!1;var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];for(;++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],a=!1,i=0,o=t.length,s=o-1;i<o;s=i++){var l=t[i],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(a=!a)}return a}(t[0],r))return t.push(e),!0}))||t.push([e])})),i=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=Math.PI,p=f/2,d=(Math.sqrt(f),f/180),g=180/f;function m(t){return t>1?p:t<-1?-p:Math.asin(t)}function v(t){return t>1?0:t<-1?f:Math.acos(t)}var y=t.geo.projection,x=t.geo.projectionMutator;function b(t,e){var r=(2+p)*Math.sin(e);e/=2;for(var n=0,a=1/0;n<10&&Math.abs(a)>h;n++){var i=Math.cos(e);e-=a=(e+Math.sin(e)*(i+2)-r)/(2*i*(1+i))}return[2/Math.sqrt(f*(4+f))*t*(1+Math.cos(e)),2*Math.sqrt(f/(4+f))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-f,0],[0,p],[f,0]]],[[[-f,0],[0,-p],[f,0]]]];function a(t,r){for(var a=r<0?-1:1,i=n[+(r<0)],o=0,s=i.length-1;o<s&&t>i[o][2][0];++o);var l=e(t-i[o][1][0],r);return l[0]+=e(i[o][1][0],a*r>a*i[o][0][1]?i[o][0][1]:r)[0],l}function i(){r=n.map((function(t){return t.map((function(t){var r,n=e(t[0][0],t[0][1])[0],a=e(t[2][0],t[2][1])[0],i=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return i>o&&(r=i,i=o,o=r),[[n,i],[a,o]]}))}))}e.invert&&(a.invert=function(t,i){for(var o=r[+(i<0)],s=n[+(i<0)],l=0,u=o.length;l<u;++l){var h=o[l];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=i&&i<h[1][1]){var f=e.invert(t-e(s[l][1][0],0)[0],i);return f[0]+=s[l][1][0],c(a(f[0],f[1]),[t,i])?f:null}}});var o=t.geo.projection(a),s=o.stream;function l(t,e){for(var r,n,a,i=-1,o=t.length,s=t[0],l=[];++i<o;){n=((r=t[i])[0]-s[0])/e,a=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*a]);s=r}return l.push(r),l}function c(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return o.stream=function(e){var r=o.rotate(),a=s(e),i=(o.rotate([0,0]),s(e));return o.rotate(r),a.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],a=0,i=n[0].length;a<i;++a){var o=180*(p=n[0][a])[0][0]/f,s=180*p[0][1]/f,c=180*p[1][1]/f,u=180*p[2][0]/f,h=180*p[2][1]/f;r.push(l([[o+e,s+e],[o+e,c-e],[u-e,c-e],[u-e,h+e]],30))}for(a=n[1].length-1;a>=0;--a){var p;o=180*(p=n[1][a])[0][0]/f,s=180*p[0][1]/f,c=180*p[1][1]/f,u=180*p[2][0]/f,h=180*p[2][1]/f;r.push(l([[u-e,h-e],[u-e,c+e],[o+e,c+e],[o+e,s-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),i)},a},o.lobes=function(t){return arguments.length?(n=t.map((function(t){return t.map((function(t){return[[t[0][0]*f/180,t[0][1]*f/180],[t[1][0]*f/180,t[1][1]*f/180],[t[2][0]*f/180,t[2][1]*f/180]]}))})),i(),o):n.map((function(t){return t.map((function(t){return[[180*t[0][0]/f,180*t[0][1]/f],[180*t[1][0]/f,180*t[1][1]/f],[180*t[2][0]/f,180*t[2][1]/f]]}))}))},o},b.invert=function(t,e){var r=.5*e*Math.sqrt((4+f)/f),n=m(r),a=Math.cos(n);return[t/(2/Math.sqrt(f*(4+f))*(1+a)),m((n+r*(a+2))/(2+p))]},(t.geo.eckert4=function(){return y(b)}).raw=b;var _=t.geo.azimuthalEqualArea.raw;function w(t,e){if(arguments.length<2&&(e=t),1===e)return _;if(e===1/0)return T;function r(r,n){var a=_(r/e,n);return a[0]*=t,a}return r.invert=function(r,n){var a=_.invert(r/t,n);return a[0]*=e,a},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function k(t,e){return[3*t/(2*f)*Math.sqrt(f*f/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(f/4+.4*e))]}function A(t){return function(e){var r,n=t*Math.sin(e),a=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--a>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=x(w),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=w,k.invert=function(t,e){return[2/3*f*t/Math.sqrt(f*f/3-e*e),e]},(t.geo.kavrayskiy7=function(){return y(k)}).raw=k,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*f]},(t.geo.miller=function(){return y(M)}).raw=M,A(f);var S=function(t,e,r){var n=A(r);function a(r,a){return[t*r*Math.cos(a=n(a)),e*Math.sin(a)]}return a.invert=function(n,a){var i=m(a/e);return[n/(t*Math.cos(i)),m((2*i+Math.sin(2*i))/r)]},a}(Math.SQRT2/p,Math.SQRT2,f);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return y(S)}).raw=S,E.invert=function(t,e){var r,n=e,a=25;do{var i=n*n,o=i*i;n-=r=(n*(1.007226+i*(.015085+o*(.028874*i-.044475-.005916*o)))-e)/(1.007226+i*(.045255+o*(.259866*i-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--a>0);return[t/(.8707+(i=n*n)*(i*(i*i*i*(.003971-.001529*i)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return y(E)}).raw=E;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function L(t,e){var r,n=Math.min(18,36*Math.abs(e)/f),a=Math.floor(n),i=n-a,o=(r=C[a])[0],s=r[1],l=(r=C[++a])[0],c=r[1],u=(r=C[Math.min(19,++a)])[0],h=r[1];return[t*(l+i*(u-o)/2+i*i*(u-2*l+o)/2),(e>0?p:-p)*(c+i*(h-s)/2+i*i*(h-2*c+s)/2)]}function P(t,e){return[t*Math.cos(e),e]}function I(t,e){var r,n=Math.cos(e),a=(r=v(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*a,Math.sin(e)*a]}function z(t,e){var r=I(t,e);return[(r[0]+t/p)/2,(r[1]+e)/2]}C.forEach((function(t){t[1]*=1.0144})),L.invert=function(t,e){var r=e/p,n=90*r,a=Math.min(18,Math.abs(n/5)),i=Math.max(0,Math.floor(a));do{var o=C[i][1],s=C[i+1][1],l=C[Math.min(19,i+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,f=u/c,m=h*(1-f*h*(1-2*f*h));if(m>=0||1===i){n=(e>=0?5:-5)*(m+a);var v,y=50;do{m=(a=Math.min(18,Math.abs(n)/5))-(i=Math.floor(a)),o=C[i][1],s=C[i+1][1],l=C[Math.min(19,i+2)][1],n-=(v=(e>=0?p:-p)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*g}while(Math.abs(v)>1e-12&&--y>0);break}}while(--i>=0);var x=C[i][0],b=C[i+1][0],_=C[Math.min(19,i+2)][0];return[t/(b+m*(_-x)/2+m*m*(_-2*b+x)/2),n*d]},(t.geo.robinson=function(){return y(L)}).raw=L,P.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return y(P)}).raw=P,I.invert=function(t,e){if(!(t*t+4*e*e>f*f+h)){var r=t,n=e,a=25;do{var i,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),p=Math.sin(2*n),d=c*c,g=u*u,m=s*s,y=1-g*l*l,x=y?v(u*l)*Math.sqrt(i=1/y):i=0,b=2*x*u*s-t,_=x*c-e,w=i*(g*m+x*u*l*d),T=i*(.5*o*p-2*x*c*s),k=.25*i*(p*s-x*c*g*o),M=i*(d*l+x*m*u),A=T*k-M*w;if(!A)break;var S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--a>0);return[r,n]}},(t.geo.aitoff=function(){return y(I)}).raw=I,z.invert=function(t,e){var r=t,n=e,a=25;do{var i,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),d=Math.cos(r/2),g=Math.sin(r/2),m=g*g,y=1-u*d*d,x=y?v(o*d)*Math.sqrt(i=1/y):i=0,b=.5*(2*x*o*g+r/p)-t,_=.5*(x*s+n)-e,w=.5*i*(u*m+x*o*d*c)+.5/p,T=i*(f*l/4-x*s*g),k=.125*i*(l*g-x*s*u*f),M=.5*i*(c*d+x*m*o)+.5,A=T*k-M*w,S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--a>0);return[r,n]},(t.geo.winkel3=function(){return y(z)}).raw=z}},{}],834:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=a.nestedProperty(l,t).get(),i.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=a.nestedProperty(u,t);r.get()!==e&&(r.set(e),a.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function a(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),h(t,e,a)})),r}function p(t,e){var r,a,i,o,s,f,p,d,g,m=u(0,e);function v(t){return e.invert(t)}function y(r){var n=e.rotate(),a=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",a[0]),r(\"center.lat\",a[1])}return m.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),a=e.rotate(),i=e.translate(),o=a,s=v(r)})).on(\"zoom\",(function(){if(f=n.mouse(this),function(t){var r=v(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return m.scale(e.scale()),void m.translate(e.translate());e.scale(n.event.scale),e.translate([i[0],n.event.translate[1]]),s?v(f)&&(d=v(f),p=[o[0]+(d[0]-s[0]),a[1],a[2]],e.rotate(p),o=p):s=v(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),g&&h(t,e,y)})),m}function d(t,e){var r,a={r:e.rotate(),k:e.scale()},i=u(0,e),o=function(t){var e=0,r=arguments.length,a=[];for(;++e<r;)a.push(arguments[e]);var i=n.dispatch.apply(null,a);return i.of=function(e,r){return function(a){var o;try{o=a.sourceEvent=n.event,a.target=t,n.event=a,i[a.type].apply(e,r)}finally{n.event=o}}},i}(i,\"zoomstart\",\"zoom\",\"zoomend\"),s=0,f=i.on;function p(t){s++||t({type:\"zoomstart\"})}function d(t){t({type:\"zoom\"})}function b(t){--s||t({type:\"zoomend\"})}function _(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return i.on(\"zoomstart\",(function(){n.select(this).style(l);var t=n.mouse(this),s=e.rotate(),c=s,u=e.translate(),h=m(s);r=g(e,t),f.call(i,\"zoom\",(function(){var i=n.mouse(this);if(e.scale(a.k=n.event.scale),r){if(g(e,i)){e.rotate(s).translate(u);var l=g(e,i),f=y(r,l),p=T(v(h,f)),m=a.r=x(p,r,c);isFinite(m[0])&&isFinite(m[1])&&isFinite(m[2])||(m=c),e.rotate(m),c=m}}else r=g(e,t=i);d(o.of(this,arguments))})),p(o.of(this,arguments))})).on(\"zoomend\",(function(){n.select(this).style(c),f.call(i,\"zoom\",null),b(o.of(this,arguments)),h(t,e,_)})).on(\"zoom.redraw\",(function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(i,o,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function m(t){var e=.5*t[0]*o,r=.5*t[1]*o,n=.5*t[2]*o,a=Math.sin(e),i=Math.cos(e),s=Math.sin(r),l=Math.cos(r),c=Math.sin(n),u=Math.cos(n);return[i*l*u+a*s*c,a*l*u-i*s*c,i*s*u+a*l*c,i*l*c-a*s*u]}function v(t,e){var r=t[0],n=t[1],a=t[2],i=t[3],o=e[0],s=e[1],l=e[2],c=e[3];return[r*o-n*s-a*l-i*c,r*s+n*o+a*c-i*l,r*l-n*c+a*o+i*s,r*c+n*l-a*s+i*o]}function y(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(k(r,r)),a=.5*Math.acos(Math.max(-1,Math.min(1,k(t,e)))),i=Math.sin(a)/n;return n&&[Math.cos(a),r[2]*i,-r[1]*i,r[0]*i]}}function x(t,e,r){var n=w(e,2,t[0]);n=w(n,1,t[1]),n=w(n,0,t[2]-r[2]);var a,i,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(i=(h>0?90:-90)-p,a=0):(i=Math.asin(h/d)*s-p,a=Math.sqrt(d*d-h*h));var g=180-i-2*p,m=(Math.atan2(f,u)-Math.atan2(c,a))*s,v=(Math.atan2(f,u)-Math.atan2(c,-a))*s;return b(r[0],r[1],i,m)<=b(r[0],r[1],g,v)?[i,m,r[2]]:[g,v,r[2]]}function b(t,e,r,n){var a=_(r-t),i=_(n-e);return Math.sqrt(a*a+i*i)}function _(t){return(t%360+540)%360-180}function w(t,e,r){var n=r*o,a=t.slice(),i=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return a[i]=t[i]*l-t[s]*c,a[s]=t[s]*l+t[i]*c,a}function T(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}function k(t,e){for(var r=0,n=0,a=t.length;n<a;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":749,\"../../registry\":881,d3:169}],835:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),a=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var a=n.subplotsRegistry[e];if(!a)return[];for(var i=a.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[i]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,a=[],i=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[a,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?a.push(s):i.push(s))}return[a,i]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var i,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(a);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)i=t[h],\"gl2d\"===e&&n.traceIs(i,\"gl2d\")?i[l[0]]===o&&i[l[1]]===s&&c.push(i):i[l]===r&&c.push(i);return c}},{\"../registry\":881,\"./cartesian/constants\":804}],836:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),a=t(\"mouse-wheel\"),i=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,a){var i,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function m(e,r,n){var a=Math.min(r,n),i=Math.max(r,n);a!==i?(l[e]=a,l[e+2]=i,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,a*=r.pixelRatio,a=h[3]-h[1]-a,t.fullLayout.dragmode){case\"zoom\":if(e){var v=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=a/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=v,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=a),c.boxEnd[0]=v,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-a)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,a=0;a<e.length;a++)if(-1!==e[a][r]){if(-1!==e[a][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{i=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(i*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(i)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(i>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(i=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],i||s?(i&&(m(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(m(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=a),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-a)<d&&(a=c.dragStart[1]),i=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-a)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=i,l[2]+=i,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=a}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",(function(t){var r=i(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=i(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=a(e,(function(e,n){if(!t.scrollZoom)return!1;var a=t.calcDataBox(),i=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(i[3]-i[1])),h=o/(i[2]-i[0])*(a[2]-a[0])+a[0],f=s/(i[3]-i[1])*(a[3]-a[1])+a[1];return a[0]=(a[0]-h)*l+h,a[2]=(a[2]-h)*l+h,a[1]=(a[1]-f)*l+f,a[3]=(a[3]-f)*l+f,t.setRanges(a),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},{\"../cartesian/constants\":804,\"has-passive-events\":415,\"mouse-change\":457,\"mouse-event-offset\":458,\"mouse-wheel\":460}],837:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function i(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=i.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,i,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=a(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=a(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=a((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=a(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=a(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,i=r.mirror||!1,u=c?-1!==String(i).indexOf(\"all\"):!!i,h=c?\"allticks\"===i:-1!==String(i).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=a(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=a(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new i(t)}},{\"../../lib/str2rgbarray\":772,\"../cartesian/axes\":798}],838:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./scene2d\"),i=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:i.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,i=0;i<n.length;i++){var o=n[i],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new a({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var a=n._subplots.gl2d||[],i=0;i<a.length;i++){var o=a[i],s=n._plots[o];if(s._scene2d){var c=u(t,\"gl2d\",o);0===c.length&&(s._scene2d.destroy(),delete n._plots[o])}}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var a=e._plots[r[n]]._scene2d,i=a.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":i,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),a.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":656,\"../../constants/xmlns_namespaces\":725,\"../../plot_api/edit_types\":780,\"../cartesian\":811,\"../cartesian/attributes\":796,\"../cartesian/constants\":804,\"../get_data\":835,\"../layout_attributes\":852,\"./scene2d\":839}],839:[function(t,e,r){\"use strict\";var n,a,i=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),m=g.enforce,v=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=t(\"../../components/dragelement/helpers\"),b=x.drawMode,_=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=k;var M=k.prototype;M.makeFramework=function(){if(this.staticPlot){if(!(a||(n=document.createElement(\"canvas\"),a=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=a}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var i=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(i),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},M.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,a=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var i=new Uint8Array(r*a*4);e.readPixels(0,0,r,a,e.RGBA,e.UNSIGNED_BYTE,i);for(var o=0,s=a-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=i[4*(r*o+l)+c];i[4*(r*o+l)+c]=i[4*(r*s+l)+c],i[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=a;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,a);switch(d.data.set(i),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},M.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,a=r.height,i=0|Math.ceil(e*n),o=0|Math.ceil(e*a);return t.width===i&&t.height===o||(t.width=i,t.height=o),t},M.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},M.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},M.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,a={},o=a[e._name+\".range\"]=e.range.slice(),s=a[r._name+\".range\"]=r.range.slice();a[e._name+\".autorange\"]=e.autorange,a[r._name+\".autorange\"]=r.autorange,i.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,a);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,a.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",a)},M.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],a=e[r];if(n.length!==a.length)return!0;for(var i=0;i<n.length;++i)if(n[i].x!==a[i].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},M.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&i.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},M.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},M.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var a=r.width,i=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,a,i];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};v(s,this.xaxis),v(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,a-u.r-(1-h[1])*u.w,i-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();m(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},M.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,a=t.r2l,i=e.r2l;return[a(r[0]),i(n[0]),a(r[1]),i(n[1])]},M.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,a=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[a(t[1]),a(t[3])]},M.updateTraces=function(t,e){var r,n,a,i=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<i.length;r++){var o=i[r],s=this.traces[o];for(n=0;n<t.length;n++)if((a=t[n]).uid===o&&a.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){a=t[r];var l=e[r],c=this.traces[a.uid];c?c.update(a,l):(c=a._module.plot(this,a,l),this.traces[a.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},M.updateFx=function(t){_(t)||b(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},M.emitPointAction=function(t,e){for(var r,n=t.trace.uid,a=t.pointIndex,i=0;i<this.fullData.length;i++)this.fullData[i].uid===n&&(r=this.fullData[i]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:a,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,a),this.graphDiv.emit(e,{points:[o]})},M.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,a=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var i,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===a.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=a._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(i=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&i.object._trace.handlePick(i);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),i&&\"skip\"!==i.object._trace.hoverinfo&&a.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:i.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(i.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(i.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var m=this.fullData[g.trace.index]||{},v=g.pointIndex,y=s.castHoverinfo(m,a,v);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(m,v,\"bgcolor\")||g.color,borderColor:s.castHoverOption(m,v,\"bordercolor\"),fontFamily:s.castHoverOption(m,v,\"font.family\"),fontSize:s.castHoverOption(m,v,\"font.size\"),fontColor:s.castHoverOption(m,v,\"font.color\"),nameLength:s.castHoverOption(m,v,\"namelength\"),textAlign:s.castHoverOption(m,v,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}i||this.unhover(),t.draw()}},M.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},M.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/dragelement/helpers\":633,\"../../components/fx\":655,\"../../lib/show_no_webgl_msg\":770,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"../cartesian/autorange\":797,\"../cartesian/constants\":804,\"../cartesian/constraints\":805,\"./camera\":836,\"./convert\":837,\"gl-plot2d\":298,\"gl-select-box\":310,\"gl-spikes2d\":319,\"webgl-context\":578}],840:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../components/fx/layout_attributes\"),i=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:a.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,a=0;a<n.length;a++){var s=n[a],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new i({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var a=n._subplots.gl3d||[],i=0;i<a.length;i++){var o=a[i];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,a=0;a<r.length;a++){var i=e[r[a]],o=i.domain,s=i._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":656,\"../../constants/xmlns_namespaces\":725,\"../../lib\":749,\"../../plot_api/edit_types\":780,\"../get_data\":835,\"./layout/attributes\":841,\"./layout/defaults\":845,\"./layout/layout_attributes\":846,\"./scene\":850}],841:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],842:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),a=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:a.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:a.color,categoryorder:a.categoryorder,categoryarray:a.categoryarray,title:{text:a.title.text,font:a.title.font},type:i({},a.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:a.autorange,rangemode:a.rangemode,range:i({},a.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:a.tickmode,nticks:a.nticks,tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,mirror:a.mirror,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,tickfont:a.tickfont,tickangle:a.tickangle,tickprefix:a.tickprefix,showtickprefix:a.showtickprefix,ticksuffix:a.ticksuffix,showticksuffix:a.showticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:a.showline,linecolor:a.linecolor,linewidth:a.linewidth,showgrid:a.showgrid,gridcolor:i({},a.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:a.gridwidth,zeroline:a.zeroline,zerolinecolor:a.zerolinecolor,zerolinewidth:a.zerolinewidth,_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":615,\"../../../lib/extend\":739,\"../../../plot_api/edit_types\":780,\"../../cartesian/layout_attributes\":812}],843:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,a=t(\"../../../lib\"),i=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return a.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=i.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,noTicklabelmode:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=a.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":749,\"../../../plot_api/plot_template\":787,\"../../cartesian/axis_defaults\":800,\"../../cartesian/type_defaults\":823,\"./axis_attributes\":842,tinycolor2:548}],844:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),a=t(\"../../../lib\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[i[r]];o.visible?(this.labels[r]=t._meta?a.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":749,\"../../../lib/str2rgbarray\":772}],845:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),a=t(\"../../../components/color\"),i=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData;function u(t,e,r,n){for(var o=r(\"bgcolor\"),l=a.combine(o,n.paper_bgcolor),u=[\"up\",\"center\",\"eye\"],h=0;h<u.length;h++)r(\"camera.\"+u[h]+\".x\"),r(\"camera.\"+u[h]+\".y\"),r(\"camera.\"+u[h]+\".z\");r(\"camera.projection.type\");var f=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),p=r(\"aspectmode\",f?\"manual\":\"auto\");f||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===p&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var d=c(n.fullData,\"gl3d\",n.id);s(t,e,{font:n.font,scene:n.id,data:d,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),i.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var g=n.getDfltFromLayout(\"dragmode\");if(!1!==g&&!g)if(g=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,v=t.camera.up.y,y=t.camera.up.z;0!==y&&(m&&v&&y?y/Math.sqrt(m*m+v*v+y*y)>.999&&(g=\"turntable\"):g=\"turntable\")}else g=\"turntable\";r(\"dragmode\",g),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var a=e._basePlotModules.length>1;o(t,e,r,{type:\"gl3d\",attributes:l,handleDefaults:u,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!a)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":615,\"../../../lib\":749,\"../../../registry\":881,\"../../get_data\":835,\"../../subplot_defaults\":875,\"./axis_defaults\":843,\"./layout_attributes\":846}],846:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),a=t(\"../../domain\").attributes,i=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:i(s(0,0,1),{}),center:i(s(0,0,0),{}),eye:i(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:a({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":749,\"../../../lib/extend\":739,\"../../domain\":825,\"./axis_attributes\":842}],847:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function i(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}i.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[a[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new i;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":772}],848:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[i[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||a.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],a=new Array(n.length),i=0;i<n.length;++i)a[i]=n[i].x;e[r]=a}return e}(l)};var n=t(\"../../cartesian/axes\"),a=t(\"../../../lib\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":749,\"../../cartesian/axes\":798}],849:[function(t,e,r){\"use strict\";function n(t,e){var r,n,a=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)a[n]+=t[4*r+n]*e[r];return a}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],850:[function(t,e,r){\"use strict\";var n,a,i=t(\"gl-plot3d\"),o=i.createCamera,s=i.createScene,l=t(\"webgl-context\"),c=t(\"has-passive-events\"),u=t(\"../../registry\"),h=t(\"../../lib\"),f=t(\"../../plots/cartesian/axes\"),p=t(\"../../components/fx\"),d=t(\"../../lib/str2rgbarray\"),g=t(\"../../lib/show_no_webgl_msg\"),m=t(\"./project\"),v=t(\"./layout/convert\"),y=t(\"./layout/spikes\"),x=t(\"./layout/tick_marks\"),b=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function _(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\",r.appendChild(a),this.svgContainer=a,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=y(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:b,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(a||(n=document.createElement(\"canvas\"),a=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");t.gl=a,t.canvas=n}return t},w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode)e=!1;else try{h.warn([\"webgl setup failed possibly due to\",b?\"disabling\":\"enabling\",\"preserveDrawingBuffer config.\",\"The device may not be supported by is-mobile module!\",\"Inverting preserveDrawingBuffer option in second attempt to create webgl scene.\"].join(\" \")),b=t.glOptions.preserveDrawingBuffer=!t.glOptions.preserveDrawingBuffer,this.glplot=s(t)}catch(t){e=!1}}return e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return g(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},a=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",(function(){a(t)})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,i=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*i.x,y:n*i.y,z:n*i.z})}a(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,a=e.container.getBoundingClientRect(),i=a.width,o=a.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+i+\" \"+o),n.setAttributeNS(null,\"width\",i),n.setAttributeNS(null,\"height\",o),x(e),e.glplot.axes.update(e.axesOptions);for(var s,l=Object.keys(e.traces),c=null,u=e.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(t=e.traces[l[d]]).data.hoverinfo&&t.handlePick(u)&&(c=t),t.setContourLevels&&t.setContourLevels();function g(t,r){var n=e.fullSceneLayout[t];return f.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var v=m(e.glplot.cameraParams,u.dataCoordinate);t=c.data;var y,b=r._fullData[t.index],_=u.index,w={xLabel:g(\"xaxis\",u.traceCoordinate[0]),yLabel:g(\"yaxis\",u.traceCoordinate[1]),zLabel:g(\"zaxis\",u.traceCoordinate[2])},T=p.castHoverinfo(b,e.fullLayout,_),k=(T||\"\").split(\"+\"),M=T&&\"all\"===T;b.hovertemplate||M||(-1===k.indexOf(\"x\")&&(w.xLabel=void 0),-1===k.indexOf(\"y\")&&(w.yLabel=void 0),-1===k.indexOf(\"z\")&&(w.zLabel=void 0),-1===k.indexOf(\"text\")&&(u.textLabel=void 0),-1===k.indexOf(\"name\")&&(c.name=void 0));var A=[];\"cone\"===t.type||\"streamtube\"===t.type?(w.uLabel=g(\"xaxis\",u.traceCoordinate[3]),(M||-1!==k.indexOf(\"u\"))&&A.push(\"u: \"+w.uLabel),w.vLabel=g(\"yaxis\",u.traceCoordinate[4]),(M||-1!==k.indexOf(\"v\"))&&A.push(\"v: \"+w.vLabel),w.wLabel=g(\"zaxis\",u.traceCoordinate[5]),(M||-1!==k.indexOf(\"w\"))&&A.push(\"w: \"+w.wLabel),w.normLabel=u.traceCoordinate[6].toPrecision(3),(M||-1!==k.indexOf(\"norm\"))&&A.push(\"norm: \"+w.normLabel),\"streamtube\"===t.type&&(w.divergenceLabel=u.traceCoordinate[7].toPrecision(3),(M||-1!==k.indexOf(\"divergence\"))&&A.push(\"divergence: \"+w.divergenceLabel)),u.textLabel&&A.push(u.textLabel),y=A.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(w.valueLabel=f.tickText(e._mockAxis,e._mockAxis.d2l(u.traceCoordinate[3]),\"hover\").text,A.push(\"value: \"+w.valueLabel),u.textLabel&&A.push(u.textLabel),y=A.join(\"<br>\")):y=u.textLabel;var S={x:u.traceCoordinate[0],y:u.traceCoordinate[1],z:u.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};p.appendArrayPointValue(S,b,_),t._module.eventData&&(S=b._module.eventData(S,u,b,{},_));var E={points:[S]};e.fullSceneLayout.hovermode&&p.loneHover({trace:b,x:(.5+.5*v[0]/v[3])*i,y:(.5-.5*v[1]/v[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:y,name:c.name,color:p.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:p.castHoverOption(b,_,\"bordercolor\"),fontFamily:p.castHoverOption(b,_,\"font.family\"),fontSize:p.castHoverOption(b,_,\"font.size\"),fontColor:p.castHoverOption(b,_,\"font.color\"),nameLength:p.castHoverOption(b,_,\"namelength\"),textAlign:p.castHoverOption(b,_,\"align\"),hovertemplate:h.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:h.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),u.buttons&&u.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else p.loneUnhover(n),r.emit(\"plotly_unhover\",s);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):h.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var T=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,a=0;a<3;a++){var i=T[a],o=i.charAt(0),s=n[i],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(h.isArrayOrTypedArray(l))for(var f,p=0;p<(u||l.length);p++)if(h.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][a]=Math.min(r[0][a],f),r[1][a]=Math.max(r[1][a],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][a]=Math.min(r[0][a],f),r[1][a]=Math.max(r[1][a],f));else r[0][a]=Math.min(r[0][a],0),r[1][a]=Math.max(r[1][a],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,a,i,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(d(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(i=0;i<t.length;++i)!0===(n=t[i]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],a=0;a<3;a++)for(var i=T[a],o=i.charAt(0),s=r[i],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][a]=Math.min(e[0][a],u),e[1][a]=Math.max(e[1][a],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),i=0;i<t.length;++i)!0===(n=t[i]).visible&&0!==n._length&&((a=this.traces[n.uid])?a.data.type===n.type?a.update(n):(a.dispose(),a=n._module.plot(this,n),this.traces[n.uid]=a):(a=n._module.plot(this,n),this.traces[n.uid]=a),a.name=n.name);var p=Object.keys(this.traces);t:for(i=0;i<p.length;++i){for(o=0;o<t.length;++o)if(t[o].uid===p[i]&&!0===t[o].visible&&0!==t[o]._length)continue t;(a=this.traces[p[i]]).dispose(),delete this.traces[p[i]]}this.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var g,m=[[0,0,0],[0,0,0]],v=[],y={};for(i=0;i<3;++i){if((l=(s=c[T[i]]).type)in y?(y[l].acc*=f[i],y[l].count+=1):y[l]={acc:f[i],count:1},s.autorange){m[0][i]=1/0,m[1][i]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],M=w.bounds,A=w._trace.data._pad||0;\"ErrorBars\"===w.constructor.name&&s._lowerLogErrorBound?m[0][i]=Math.min(m[0][i],s._lowerLogErrorBound):m[0][i]=Math.min(m[0][i],M[0][i]/f[i]-A),m[1][i]=Math.max(m[1][i],M[1][i]/f[i]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);m[0][i]=Math.min(m[0][i],E),m[1][i]=Math.max(m[1][i],E)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(m[0][i]=Math.min(m[0][i],0),m[1][i]=Math.max(m[1][i],0)),m[0][i]>m[1][i])m[0][i]=-1,m[1][i]=1;else{var C=m[1][i]-m[0][i];m[0][i]-=C/32,m[1][i]+=C/32}if(\"reversed\"===s.autorange){var L=m[0][i];m[0][i]=m[1][i],m[1][i]=L}}else{var P=s.range;m[0][i]=s.r2l(P[0]),m[1][i]=s.r2l(P[1])}m[0][i]===m[1][i]&&(m[0][i]-=1,m[1][i]+=1),v[i]=m[1][i]-m[0][i],this.glplot.setBounds(i,{min:m[0][i]*f[i],max:m[1][i]*f[i]})}var I=c.aspectmode;if(\"cube\"===I)g=[1,1,1];else if(\"manual\"===I){var z=c.aspectratio;g=[z.x,z.y,z.z]}else{if(\"auto\"!==I&&\"data\"!==I)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var O=[1,1,1];for(i=0;i<3;++i){var D=y[l=(s=c[T[i]]).type];O[i]=Math.pow(D.acc,1/D.count)/f[i]}g=\"data\"===I||Math.max.apply(null,O)/Math.min.apply(null,O)<=4?O:[1,1,1]}c.aspectratio.x=u.aspectratio.x=g[0],c.aspectratio.y=u.aspectratio.y=g[1],c.aspectratio.z=u.aspectratio.z=g[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position=\"absolute\",B.left=F.l+R.x[0]*F.w+\"px\",B.top=F.t+(1-R.y[1])*F.h+\"px\",B.width=F.w*(R.x[1]-R.x[0])+\"px\",B.height=F.h*(R.y[1]-R.y[0])+\"px\"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),\"orthographic\"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=h.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var a=[\"up\",\"center\",\"eye\"],i=[\"x\",\"y\",\"z\"];return e[a[r]]&&t[a[r]][i[n]]===e[a[r]][i[n]]}var a=!1;if(void 0===r)a=!0;else{for(var i=0;i<3;i++)for(var o=0;o<3;o++)if(!n(e,r,i,o)){a=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(a=!0)}return a},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=h.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,a,i,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),f=l||c;if(f){var p={};if(l&&(e=this.getCamera(),n=(r=h.nestedProperty(t,this.id+\".camera\")).get(),p[this.id+\".camera\"]=n),c&&(a=this.glplot.getAspectratio(),o=(i=h.nestedProperty(t,this.id+\".aspectratio\")).get(),p[this.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,s._preGUI,p),l)r.set(e),h.nestedProperty(s,this.id+\".camera\").set(e);if(c)i.set(a),h.nestedProperty(s,this.id+\".aspectratio\").set(a),this.glplot.redraw()}return f},w.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,a=n._fullLayout,i=this.fullSceneLayout.camera,o=i.up.x,s=i.up.y,l=i.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[c]=f;var d=n.layout;u.call(\"_storeDirectGUIEdit\",d,a._preGUI,p),i.up=f,h.nestedProperty(d,c).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,a=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var i=new Uint8Array(r*a*4);e.readPixels(0,0,r,a,e.RGBA,e.UNSIGNED_BYTE,i),function(t,e,r){for(var n=0,a=r-1;n<a;++n,--a)for(var i=0;i<e;++i)for(var o=0;o<4;++o){var s=4*(e*n+i)+o,l=4*(e*a+i)+o,c=t[s];t[s]=t[l],t[l]=c}}(i,r,a),function(t,e,r){for(var n=0;n<r;++n)for(var a=0;a<e;++a){var i=4*(e*n+a),o=t[i+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[i+l]=Math.min(s*t[i+l],255)}}(i,r,a);var o=document.createElement(\"canvas\");o.width=r,o.height=a;var s,l=o.getContext(\"2d\"),c=l.createImageData(r,a);switch(c.data.set(i),l.putImageData(c,0,0),t){case\"jpeg\":s=o.toDataURL(\"image/jpeg\");break;case\"webp\":s=o.toDataURL(\"image/webp\");break;default:s=o.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[T[t]];f.setConvert(e,this.fullLayout),e.setScale=h.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},f.setConvert(this._mockAxis,t)},e.exports=_},{\"../../components/fx\":655,\"../../lib\":749,\"../../lib/show_no_webgl_msg\":770,\"../../lib/str2rgbarray\":772,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"./layout/convert\":844,\"./layout/spikes\":847,\"./layout/tick_marks\":848,\"./project\":849,\"gl-plot3d\":301,\"has-passive-events\":415,\"is-mobile\":441,\"webgl-context\":578}],851:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var a=new Array(n),i=0;i<n;i++)a[i]=[t[i],e[i],r[i]];return a}},{}],852:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),a=t(\"./animation_attributes\"),i=t(\"../components/color/attributes\"),o=t(\"../components/shapes/draw_newshape/attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=i.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:i.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:i.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:i.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},newshape:o.newshape,activeshape:o.activeshape,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:l({},a.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":614,\"../components/shapes/draw_newshape/attributes\":697,\"../lib/extend\":739,\"./animation_attributes\":792,\"./font_attributes\":826,\"./pad_attributes\":860}],853:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},a=Object.keys(n);e.exports={requiredVersion:\"1.10.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:a,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.10.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",a.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],854:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),a=r[0],i=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(a){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(i){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":749}],855:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),a=t(\"../../lib\"),i=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&(-1!==h.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\"))}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=a.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],i=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?a.pushUnique(n,u):(f(c._input.style)&&(a.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&a.pushUnique(i,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw a.error(p),new Error(p)}return n.length?(n.length>1&&a.warn(h.multipleTokensErrorMsg),n[0]):(i.length&&a.log([\"Listed mapbox access token(s)\",i.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=i(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:a.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var a=n._subplots.mapbox||[],i=0;i<a.length;i++){var o=a[i];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,a=0;a<r.length;a++){var i=e[r[a]],u=i.domain,f=i._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(i._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),m=e._glimages.append(\"g\"),v=m.append(\"text\");v.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(v.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");v.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(v.node())}v.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),m.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];m.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":637,\"../../constants/xmlns_namespaces\":725,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/get_data\":835,\"./constants\":853,\"./layout_attributes\":857,\"./layout_defaults\":858,\"./mapbox\":859,d3:169,\"mapbox-gl\":447}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../lib/svg_text_utils\").sanitizeHTML,i=t(\"./convert_text_opts\"),o=t(\"./constants\");function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates})},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=a(t.sourceattribution));return i}(t);e.addSource(this.idSource,r)}},l.updateLayer=function(t){var e,r=this.subplot,n=u(t),a=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===a)for(var i=r.getMapLayers(),s=0;s<i.length;s++){var l=i[s].id;if(\"string\"==typeof l&&0===l.indexOf(o.traceLayerPrefix)){e=l;break}}else e=a;this.removeLayer(),c(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=a},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},{\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"./constants\":853,\"./convert_text_opts\":854}],857:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\").defaultLine,i=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:i({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:a},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:a}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":615,\"../../lib\":749,\"../../plot_api/edit_types\":780,\"../../plot_api/plot_template\":787,\"../../traces/scatter/attributes\":1156,\"../domain\":825,\"../font_attributes\":826,\"./constants\":853}],858:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../subplot_defaults\"),i=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),i(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,a){return n.coerce(t,e,o.layers,r,a)}if(r(\"visible\")){var a,i=r(\"sourcetype\"),s=\"raster\"===i||\"image\"===i;r(\"source\"),r(\"sourceattribution\"),\"vector\"===i&&r(\"sourcelayer\"),\"image\"===i&&r(\"coordinates\"),s&&(a=\"raster\");var l=r(\"type\",a);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){a(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":749,\"../array_container_defaults\":793,\"../subplot_defaults\":875,\"./layout_attributes\":857}],859:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),a=t(\"../../lib\"),i=t(\"../../lib/geo_location_utils\"),o=t(\"../../registry\"),s=t(\"../cartesian/axes\"),l=t(\"../../components/dragelement\"),c=t(\"../../components/fx\"),u=t(\"../../components/dragelement/helpers\"),h=u.rectMode,f=u.drawMode,p=u.selectMode,d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").clearSelectionsCache,v=t(\"../cartesian/select\").selectOnClick,y=t(\"./constants\"),x=t(\"./layers\");function b(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=b.prototype;_.plot=function(t,e,r){var n,a=this,i=e[a.id];a.map&&i.accesstoken!==a.accessToken&&(a.map.remove(),a.map=null,a.styleObj=null,a.traceHash={},a.layerList=[]),n=a.map?new Promise((function(r,n){a.updateMap(t,e,r,n)})):new Promise((function(r,n){a.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,a){var o=this,s=e[o.id],l=o.styleObj=T(s.style);o.accessToken=s.accesstoken;var c=o.map=new n.Map({container:o.div,style:l.style,center:M(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left=\"0px\",c._canvas.style.top=\"0px\",o.rejectOnError(a),o.isStatic||o.initFx(t,e);var u=[];u.push(new Promise((function(t){c.once(\"load\",t)}))),u=u.concat(i.fetchTraceGeoData(t)),Promise.all(u).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(a)},_.updateMap=function(t,e,r,n){var a=this,o=a.map,s=e[this.id];a.rejectOnError(n);var l=[],c=T(s.style);JSON.stringify(a.styleObj)!==JSON.stringify(c)&&(a.styleObj=c,o.setStyle(c.style),a.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(i.fetchTraceGeoData(t)),Promise.all(l).then((function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,a=e[this.id].layers,i=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),i[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<a.length;r++){var c=a[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",i[\"layout-\"+r]=n}var u,h,f={};for(u in i)f[n=i[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var w={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function T(t){var e={};return a.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==y.styleValuesMapbox.indexOf(t)?e.style=k(t):y.stylesNonMapbox[t]?e.style=y.stylesNonMapbox[t]:e.style=t):(e.id=y.styleValueDflt,e.style=k(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function k(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function M(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,a,i=this.traceHash,o=t.slice().sort((function(t,e){return w[t[0].trace.type]-w[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=i[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(i[r.uid]=r._module.plot(this,s))}var c=Object.keys(i);t:for(n=0;n<c.length;n++){var u=c[n];for(a=0;a<t.length;a++)if(u===(r=t[a][0].trace).uid)continue t;(e=i[u]).dispose(),delete i[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(M(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,a=r.map;function i(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}a.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var a=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(a));var i=r.getView();a._input.center=a.center=i.center,a._input.zoom=a.zoom=i.zoom,a._input.bearing=a.bearing=i.bearing,a._input.pitch=a.pitch=i.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(i))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),a.on(\"wheel\",(function(){r.wheeling=!0})),a.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),a.on(\"dragstart\",(function(){r.dragging=!0,i()})),a.on(\"zoomstart\",i),a.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),a.on(\"drag\",s),a.on(\"zoom\",s),a.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;a.setCenter(M(e.center)),a.setZoom(e.zoom),a.setBearing(e.bearing),a.setPitch(e.pitch);var i=r.getView();t._input.center=t.center=i.center,t._input.zoom=t.zoom=i.zoom,t._input.bearing=t.bearing=i.bearing,t._input.pitch=t.pitch=i.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(i))})),r.clearSelect=function(){m(r.dragOptions),g(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var a=n._fullLayout.clickmode;a.indexOf(\"select\")>-1&&v(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),a.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,o=t.dragmode;i=h(o)?function(t,r){(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(c)};var s=e.dragOptions;e.dragOptions=a.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),p(o)||f(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){d(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(x(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);a.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),a=n.width,i=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([a,0]).toArray(),t.unproject([a,i]).toArray(),t.unproject([0,i]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},a=0;a<r.length;a++){var i=r[a];n[e+\".\"+i]=t[i]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},e.exports=b},{\"../../components/dragelement\":634,\"../../components/dragelement/helpers\":633,\"../../components/fx\":655,\"../../lib\":749,\"../../lib/geo_location_utils\":742,\"../../registry\":881,\"../cartesian/axes\":798,\"../cartesian/select\":817,\"./constants\":853,\"./layers\":856,\"mapbox-gl\":447}],860:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],861:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"d3-time-format\").timeFormatLocale,i=t(\"fast-isnumeric\"),o=t(\"../registry\"),s=t(\"../plot_api/plot_schema\"),l=t(\"../plot_api/plot_template\"),c=t(\"../lib\"),u=t(\"../components/color\"),h=t(\"../constants/numerical\").BADNUM,f=t(\"./cartesian/axis_ids\"),p=t(\"./cartesian/handle_outline\").clearSelect,d=t(\"./animation_attributes\"),g=t(\"./frame_attributes\"),m=t(\"../plots/get_data\").getModuleCalcData,v=c.relinkPrivateKeys,y=c._,x=e.exports={};c.extendFlat(x,o),x.attributes=t(\"./attributes\"),x.attributes.type.values=x.allTypes,x.fontAttrs=t(\"./font_attributes\"),x.layoutAttributes=t(\"./layout_attributes\"),x.fontWeight=\"normal\";var b=x.transformsRegistry,_=t(\"./command\");x.executeAPICommand=_.executeAPICommand,x.computeAPICommandBindings=_.computeAPICommandBindings,x.manageCommandObserver=_.manageCommandObserver,x.hasSimpleAPICommandBindings=_.hasSimpleAPICommandBindings,x.redrawText=function(t){var e=(t=c.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise((function(e){setTimeout((function(){o.getComponentMethod(\"annotations\",\"draw\")(t),o.getComponentMethod(\"legend\",\"draw\")(t),o.getComponentMethod(\"colorbar\",\"draw\")(t),e(x.previousPromises(t))}),300)}))},x.resize=function(t){var e;t=c.getGraphDiv(t);var r=new Promise((function(r,n){t&&!c.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||c.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,o.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},x.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},x.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=c.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:u.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),a=r.node(),i={y:e._paper.attr(\"height\")-9};document.body.contains(a)&&a.getComputedTextLength()>=e.width-20?(i[\"text-anchor\"]=\"start\",i.x=5):(i[\"text-anchor\"]=\"end\",i.x=e._paper.attr(\"width\")-7),r.attr(i);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){x.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),a=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+a})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},x.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),a=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return a.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=x.graphJson(t,!1,\"keepdata\"),a.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var w=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],T=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function k(t,e){var r=t._context.locale,n=!1,a={};function i(t){for(var r=!0,i=0;i<e.length;i++){var o=e[i];a[o]||(t[o]?a[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(i(u),n))break;l=o.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||i(o.localeRegistry.en.format),a}function M(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),a=t._mainAxis._anchorAxis,i=\"\",o=\"\",s=\"\";if(a&&(s=a._mainAxis._id,i=n?t._id+s:s+t._id),!i||!e._plots[i]){i=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],h=n?t._id+u:u+t._id;o||(o=h);var p=f.getFromId(r,u);if(s&&p.overlaying===s){i=h;break}}}return i||o}function A(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],a=n._module||b[n.type];if(a&&a.makesData)return!0}return!1}function S(t,e,r,n){for(var a=t.transforms,i=[t],o=0;o<a.length;o++){var s=a[o],l=b[s.type];l&&l.transform&&(i=l.transform(i,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return i}function E(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function C(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}x.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var s,l=t._fullLayout={},u=t.layout||{},h=t._fullData||[],f=t._fullData=[],d=t.data||[],g=t.calcdata||[],m=t._context||{};t._transitionData||x.createTransitionData(t),l._dfltTitle={plot:y(t,\"Click to enter Plot title\"),x:y(t,\"Click to enter X axis title\"),y:y(t,\"Click to enter Y axis title\"),colorbar:y(t,\"Click to enter Colorscale title\"),annotation:y(t,\"new text\")},l._traceWord=y(t,\"trace\");var b=k(t,w);if(l._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var _=i.width,M=i.height;x.supplyLayoutGlobalDefaults(u,l,b),u.width||(l.width=_),u.height||(l.height=M),x.sanitizeMargins(l)}else{x.supplyLayoutGlobalDefaults(u,l,b);var A=!u.width||!u.height,S=l.autosize,E=m.autosizable;A&&(S||E)?x.plotAutoSize(t,u,l):A&&x.sanitizeMargins(l),!S&&A&&(u.width=l.width,u.height=l.height)}l._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:n.locale(t).numberFormat,timeFormat:a(t).utcFormat}}(b,l.separators),l._extraFormat=k(t,T),l._initialAutoSizeIsDone=!0,l._dataLength=d.length,l._modules=[],l._visibleModules=[],l._basePlotModules=[];var L=l._subplots=function(){var t,e,r=o.collectableSubplotTypes,n={};if(!r){r=[];var a=o.subplotsRegistry;for(var i in a){var s=a[i].attr;if(s&&(r.push(i),Array.isArray(s)))for(e=0;e<s.length;e++)c.pushUnique(r,s[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),P=l._splomAxes={x:{},y:{}},I=l._splomSubplots={};l._splomGridDflt={},l._scatterStackOpts={},l._firstScatter={},l._alignmentOpts={},l._colorAxes={},l._requestRangeslider={},l._traceUids=function(t,e){var r,n,a=e.length,i=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&i.push(o),n=o}var s=i.length,l=new Array(a),u={};function h(t,e){l[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<a;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(i[r].uid,r)||h(c.randstr(u),r))}return l}(h,d),l._globalTransforms=(t._context||{}).globalTransforms,x.supplyDataDefaults(d,f,u,l);var z=Object.keys(P.x),O=Object.keys(P.y);if(z.length>1&&O.length>1){for(o.getComponentMethod(\"grid\",\"sizeDefaults\")(u,l),s=0;s<z.length;s++)c.pushUnique(L.xaxis,z[s]);for(s=0;s<O.length;s++)c.pushUnique(L.yaxis,O[s]);for(var D in I)c.pushUnique(L.cartesian,D)}if(l._has=x._hasPlotType.bind(l),h.length===f.length)for(s=0;s<f.length;s++)v(f[s],h[s]);x.supplyLayoutModuleDefaults(u,l,f,t._transitionData);var R=l._visibleModules,F=[];for(s=0;s<R.length;s++){var B=R[s].crossTraceDefaults;B&&c.pushUnique(F,B)}for(s=0;s<F.length;s++)F[s](f,l);l._hasOnlyLargeSploms=1===l._basePlotModules.length&&\"splom\"===l._basePlotModules[0].name&&z.length>15&&O.length>15&&0===l.shapes.length&&0===l.images.length,l._hasCartesian=l._has(\"cartesian\"),l._hasGeo=l._has(\"geo\"),l._hasGL3D=l._has(\"gl3d\"),l._hasGL2D=l._has(\"gl2d\"),l._hasTernary=l._has(\"ternary\"),l._hasPie=l._has(\"pie\"),x.linkSubplots(f,l,h,i),x.cleanPlot(f,l,h,i);var N=!(!i._has||!i._has(\"gl2d\")),j=!(!l._has||!l._has(\"gl2d\")),U=!(!i._has||!i._has(\"cartesian\"))||N,V=!(!l._has||!l._has(\"cartesian\"))||j;U&&!V?i._bgLayer.remove():V&&!U&&(l._shouldCreateBgLayer=!0),i._zoomlayer&&!t._dragging&&p({_fullLayout:i}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var a=0;a<t.length;a++){var i=t[a];i.meta?n[i.index]=i._meta={meta:i.meta}:e.meta&&(i._meta={meta:e.meta}),e.meta&&(i._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(f,l),v(l,i),o.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(f,l),l._preGUI||(l._preGUI={}),l._tracePreGUI||(l._tracePreGUI={});var q,H=l._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(s=0;s<f.length;s++)G[q=f[s]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];C(l),o.getComponentMethod(\"rangeslider\",\"makeData\")(l),r||g.length!==f.length||x.supplyDefaultsUpdateCalc(g,f)}},x.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],a=(t[r]||[])[0];if(a&&a.trace){var i=a.trace;if(i._hasCalcTransform){var o,s,l,u=i._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],l=c.nestedProperty(i,s).get().slice(),c.nestedProperty(n,s).set(l)}a.trace=n}}},x.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},x._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var a=n[e].name;if(a===t)return!0;var i=o.modules[a];if(i&&i.categories[t])return!0}return!1},x.cleanPlot=function(t,e,r,n){var a,i,o=n._basePlotModules||[];for(a=0;a<o.length;a++){var s=o[a];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(a=0;a<r.length;a++){var h=r[a].uid;for(i=0;i<t.length;i++){if(h===t[i].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},x.linkSubplots=function(t,e,r,n){var a,i,s=n._plots||{},l=e._plots={},u=e._subplots,h={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(a=0;a<p.length;a++){var d,g=p[a],m=s[g],v=f.getFromId(h,g,\"x\"),y=f.getFromId(h,g,\"y\");for(m?d=l[g]=m:(d=l[g]={}).id=g,v._counterAxes.push(y._id),y._counterAxes.push(v._id),v._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=v,d.yaxis=y,d._hasClipOnAxisFalse=!1,i=0;i<t.length;i++){var x=t[i];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=f.list(h,null,!0);for(a=0;a<_.length;a++){var w=null;(b=_[a]).overlaying&&(w=f.getFromId(h,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis=\"free\"===b.anchor?null:f.getFromId(h,b.anchor)}for(a=0;a<_.length;a++)if((b=_[a])._counterAxes.sort(f.idSort),b._subplotsWith.sort(c.subplotSort),b._mainSubplot=M(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf(\"across\")||b.automargin&&b.mirror&&\"free\"!==b.anchor||o.getComponentMethod(\"rangeslider\",\"isVisible\")(b))){var T=1,k=0;for(i=0;i<b._counterAxes.length;i++){var A=f.getFromId(h,b._counterAxes[i]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(b._counterDomainMin=T,b._counterDomainMax=k)}},x.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],s.crawl(t._module.attributes,(function(t,n,a,i){r[i]=n,r.length=i+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++){c.nestedProperty(t,\"_input.\"+e[n]).get()||c.nestedProperty(t,e[n]).set(null)}},x.supplyDataDefaults=function(t,e,r,n){var a,i,s,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,d=0;function g(t){e.push(t);var r=t._module;r&&(c.pushUnique(u,r),!0===t.visible&&c.pushUnique(h,r),c.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var m={},y=[],b=(r.template||{}).data||{},_=l.traceTemplater(b);for(a=0;a<t.length;a++){if(s=t[a],(i=_.newTrace(s)).uid=n._traceUids[a],x.supplyTraceDefaults(s,i,d,n,a),i.index=a,i._input=s,i._expandedIndex=p,i.transforms&&i.transforms.length)for(var w=!1!==s.visible&&!1===i.visible,T=S(i,e,r,n),k=0;k<T.length;k++){var M=T[k],A={_template:i._template,type:i.type,uid:i.uid+k};w&&!1===M.visible&&delete M.visible,x.supplyTraceDefaults(M,A,p,n,a),v(A,M),A.index=a,A._input=s,A._fullInput=i,A._expandedIndex=p,A._expandedInput=M,g(A)}else i._fullInput=i,i._expandedInput=i,g(i);o.traceIs(i,\"carpetAxis\")&&(m[i.carpet]=i),o.traceIs(i,\"carpetDependent\")&&y.push(a)}for(a=0;a<y.length;a++)if((i=e[y[a]]).visible){var E=m[i.carpet];i._carpet=E,E&&E.visible?(i.xaxis=E.xaxis,i.yaxis=E.yaxis):i.visible=!1}},x.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return c.coerce(t||{},r,d,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=x.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=x.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=x.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=x.supplyAnimationTransitionDefaults(t.transition||{});return r},x.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},x.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},x.supplyFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t,e,g,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},x.supplyTraceDefaults=function(t,e,r,n,a){var i,s=n.colorway||u.defaults,l=s[r%s.length];function h(r,n){return c.coerce(t,e,x.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+a),h(\"uirevision\",n.uirevision);var p=x.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var v=n._subplots,y=\"\";if(f||\"gl2d\"!==d.name){if(Array.isArray(g))for(i=0;i<g.length;i++){var b=g[i],_=c.coerce(t,e,m,b);v[b]&&c.pushUnique(v[b],_),y+=_}else y=c.coerce(t,e,m,g);v[d.name]&&c.pushUnique(v[d.name],y)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),o.traceIs(e,\"showLegend\")?(c.coerce(t,e,p.attributes.showlegend?p.attributes:x.attributes,\"showlegend\"),h(\"legendgroup\"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,l,n),o.traceIs(e,\"noOpacity\")||h(\"opacity\"),o.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),o.traceIs(e,\"noHover\")||(e.hovertemplate||c.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&o.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,l,n)),p&&p.selectPoints&&h(\"selectedpoints\"),x.supplyTransformDefaults(t,e,n)),e},x.hasMakesDataTransform=A,x.supplyTransformDefaults=function(t,e,r){if(e._length||A(t)){var n=r._globalTransforms||[],a=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var i=t.transforms||[],o=n.concat(i),s=e.transforms=[],l=0;l<o.length;l++){var u,h=o[l],f=h.type,p=b[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||c.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,c.pushUnique(a,p)):u=c.extendFlat({},h),s.push(u)}}},x.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return c.coerce(t,e,x.layoutAttributes,r,n)}var a=t.template;c.isPlainObject(a)&&(e.template=a,e._template=a.layout,e._dataTemplate=a.data);var i=c.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),c.coerceFont(n,\"title.font\",{family:i.family,size:Math.round(1.4*i.size),color:i.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&x.sanitizeMargins(e),o.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",u.addOpacity(e.paper_bgcolor,.5));var l=u.contrast(u.rgb(e.modebar.bgcolor));n(\"modebar.color\",u.addOpacity(l,.3)),n(\"modebar.activecolor\",u.addOpacity(l,.7)),n(\"modebar.uirevision\",s),o.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),n(\"meta\"),c.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),o.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),o.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},x.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,l=c.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=l?window.getComputedStyle(t):{};if(n=E(u.width)||E(u.maxWidth)||r.width,a=E(u.height)||E(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=x.layoutAttributes.width.min,p=x.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),x.sanitizeMargins(r)},x.supplyLayoutModuleDefaults=function(t,e,r,n){var a,i,s,l=o.componentsRegistry,u=e._basePlotModules,h=o.subplotsRegistry.cartesian;for(a in l)(s=l[a]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(o.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(c.subplotSort);for(i=0;i<u.length;i++)(s=u[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(i=0;i<p.length;i++)(s=p[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(i=0;i<d.length;i++)(s=d[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(a in l)(s=l[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},x.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),c.clearThrottle(),c.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},x.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var a=r[e];a.style&&c.pushUnique(n,a.style)}for(e=0;e<n.length;e++)n[e](t)},x.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,a=t.margin,i=r-(a.l+a.r),o=n-(a.t+a.b);i<0&&(e=(r-1)/(a.l+a.r),a.l=Math.floor(e*a.l),a.r=Math.floor(e*a.r)),o<0&&(e=(n-1)/(a.t+a.b),a.t=Math.floor(e*a.t),a.b=Math.floor(e*a.b))}},x.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},x.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},x.autoMargin=function(t,e,r){var n=t._fullLayout,a=n._pushmargin,i=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(c.log(\"Margin push\",e,\"is too big in x, dropping\"),r.l=r.r=0),r.b+r.t>.5*n.height&&(c.log(\"Margin push\",e,\"is too big in y, dropping\"),r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,u=void 0!==r.xr?r.xr:r.x,h=void 0!==r.yt?r.yt:r.y,f=void 0!==r.yb?r.yb:r.y;a[e]={l:{val:l,size:r.l+o},r:{val:u,size:r.r+o},b:{val:f,size:r.b+o},t:{val:h,size:r.t+o}},i[e]=1}else delete a[e],delete i[e];if(!n._replotting)return x.doAutoMargin(t)}},x.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),C(e);var r=e._size,n=e.margin,a=c.extendFlat({},r),s=n.l,l=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var v in d.base={l:{val:0,size:s},r:{val:1,size:l},t:{val:1,size:u},b:{val:0,size:h}},d){var y=d[v].l||{},b=d[v].b||{},_=y.val,w=y.size,T=b.val,k=b.size;for(var M in d){if(i(w)&&d[M].r){var A=d[M].r.val,S=d[M].r.size;if(A>_){var E=(w*A+(S-f)*_)/(A-_),L=(S*(1-_)+(w-f)*(1-A))/(A-_);E>=0&&L>=0&&f-(E+L)>0&&E+L>s+l&&(s=E,l=L)}}if(i(k)&&d[M].t){var P=d[M].t.val,I=d[M].t.size;if(P>T){var z=(k*P+(I-p)*T)/(P-T),O=(I*(1-T)+(k-p)*(1-P))/(P-T);z>=0&&O>=0&&p-(O+z)>0&&z+O>h+u&&(h=z,u=O)}}}}}if(r.l=Math.round(s),r.r=Math.round(l),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&x.didMarginChange(a,r)){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var D=3*(1+Object.keys(g).length);if(e._redrawFromAutoMarginCount<D)return o.call(\"plot\",t);c.warn(\"Too many auto-margin redraws.\")}};var L=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function P(t,e,r){var n=!1;var a=[x.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,x.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(a){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return o.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var i=0,s=0;function l(){return i++,function(){s++,n||s!==i||function(e){if(!t._transitionData)return;(function(t){if(t)for(;t.length;)t.shift()})(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return o.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)}(a)}}r.runFn(l),setTimeout(l())}))}],i=c.syncOrAsync(a,t);return i&&i.then||(i=Promise.resolve()),i.then((function(){return t}))}x.didMarginChange=function(t,e){for(var r=0;r<L.length;r++){var n=L[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},x.graphJson=function(t,e,r,n,a,i){(a&&e&&!t._fullData||a&&!e&&!t._fullLayout)&&x.supplyDefaults(t);var o=a?t._fullData:t.data,s=a?t._fullLayout:t.layout,l=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(c.isPlainObject(t)){var n,a={};return Object.keys(t).sort().forEach((function(i){if(-1===[\"_\",\"[\"].indexOf(i.charAt(0)))if(\"function\"!=typeof t[i]){if(\"keepdata\"===r){if(\"src\"===i.substr(i.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[i+\"src\"])&&n.indexOf(\":\")>0&&!c.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[i+\"src\"])&&n.indexOf(\":\")>0)return;a[i]=u(t[i],e)}else e&&(a[i]=\"_function\")})),a}return Array.isArray(t)?t.map((function(t){return u(t,e)})):c.isTypedArray(t)?c.simpleMap(t,c.identity):c.isJSDate(t)?c.ms2DateTimeLocal(+t):t}var h={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};return e||(h.layout=u(s)),t.framework&&t.framework.isPolar&&(h=t.framework.getConfig()),l&&(h.frames=u(l)),i&&(h.config=u(t._context,!0)),\"object\"===n?h:JSON.stringify(h)},x.modifyFrames=function(t,e){var r,n,a,i=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":a=n.value;var s=(i[n.index]||{}).name,l=a.name;i[n.index]=o[l]=a,l!==s&&(delete o[s],o[l]=a);break;case\"insert\":o[(a=n.value).name]=a,i.splice(n.index,0,a);break;case\"delete\":delete o[(a=i[n.index]).name],i.splice(n.index,1)}return Promise.resolve()},x.computeFrame=function(t,e){var r,n,a,i,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=x.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(a=n[r])&&(-1===(i=u.traces.indexOf(a))&&(i=u.data.length,u.traces[i]=a),u.data[i]=x.extendTrace(u.data[i],s.data[r]))}return u},x.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var a=r[n];a&&a.name&&(e[a.name]=a)}},x.extendObjectWithContainers=function(t,e,r){var n,a,i,o,s,l,u,h=c.extendDeepNoArrays({},e||{}),f=c.expandObjectPaths(h),p={};if(r&&r.length)for(i=0;i<r.length;i++)void 0===(a=(n=c.nestedProperty(f,r[i])).get())?c.nestedProperty(p,r[i]).set(null):(n.set(null),c.nestedProperty(p,r[i]).set(a));if(t=c.extendDeepNoArrays(t||{},f),r&&r.length)for(i=0;i<r.length;i++)if(l=c.nestedProperty(p,r[i]).get()){for(u=(s=c.nestedProperty(t,r[i])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<l.length;o++){var d=l[o];u[o]=null===d?null:x.extendObjectWithContainers(u[o],d)}s.set(u)}return t},x.dataArrayContainers=[\"transforms\",\"dimensions\"],x.layoutArrayContainers=o.layoutArrayContainers,x.extendTrace=function(t,e){return x.extendObjectWithContainers(t,e,x.dataArrayContainers)},x.extendLayout=function(t,e){return x.extendObjectWithContainers(t,e,x.layoutArrayContainers)},x.transition=function(t,e,r,n,a,i){var o={redraw:a.redraw},s={},l=[];return o.prepareFn=function(){for(var a=Array.isArray(e)?e.length:0,i=n.slice(0,a),o=0;o<i.length;o++){var u=i[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[i[o]]=x.extendTrace(t.data[i[o]],e[o])}}var p=c.expandObjectPaths(c.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;x.extendLayout(t.layout,p),delete t.calcdata,x.supplyDefaults(t),x.doCalcdata(t);var m=c.expandObjectPaths(r);if(m){var v=t._fullLayout._plots;for(var y in v){var b=v[y],_=b.xaxis,w=b.yaxis,T=_.range.slice(),k=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(m[_._name+\".range\"])?M=m[_._name+\".range\"].slice():Array.isArray((m[_._name]||{}).range)&&(M=m[_._name].range.slice()),Array.isArray(m[w._name+\".range\"])?A=m[w._name+\".range\"].slice():Array.isArray((m[w._name]||{}).range)&&(A=m[w._name].range.slice()),T&&M&&(_.r2l(T[0])!==_.r2l(M[0])||_.r2l(T[1])!==_.r2l(M[1]))&&(S={xr0:T,xr1:M}),k&&A&&(w.r2l(k[0])!==w.r2l(A[0])||w.r2l(k[1])!==w.r2l(A[1]))&&(E={yr0:k,yr1:A}),(S||E)&&l.push(c.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,a,o=t._fullLayout._basePlotModules,u=l.length;if(r)for(a=0;a<o.length;a++)o[a].transitionAxes&&o[a].transitionAxes(t,l,i,e);for(var h in u?((n=c.extendFlat({},i)).duration=0,delete s.cartesian):n=i,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},P(t,i,o)},x.transitionFromReact=function(t,e,r,n){var a=t._fullLayout,i=a.transition,o={},s=[];return o.prepareFn=function(){var t=a._plots;for(var i in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[i],u=l.xaxis,h=l.yaxis,f=n[u._name].range.slice(),p=n[h._name].range.slice(),d=u.range.slice(),g=h.range.slice();u.setScale(),h.setScale();var m=null,v=null;u.r2l(f[0])===u.r2l(d[0])&&u.r2l(f[1])===u.r2l(d[1])||(m={xr0:f,xr1:d}),h.r2l(p[0])===h.r2l(g[0])&&h.r2l(p[1])===h.r2l(g[1])||(v={yr0:p,yr1:g}),(m||v)&&s.push(c.extendFlat({plotinfo:l},m,v))}return Promise.resolve()},o.runFn=function(r){for(var n,a,o,l=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<l.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,a,r)}s.length&&e.anim?\"traces first\"===i.ordering?(n=c.extendFlat({},i,{duration:0}),o=h,a=i,setTimeout(p,i.duration),d()):(n=i,o=null,a=c.extendFlat({},i,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=i,p()):e.anim&&(o=h,a=i,d())},P(t,i,o)},x.doCalcdata=function(t,e){var r,n,a,i,l=f.list(t),u=t._fullData,p=t._fullLayout,d=new Array(u.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},a=0;a<u.length;a++)Array.isArray(e)&&-1===e.indexOf(a)&&(d[a]=g[a]);for(a=0;a<u.length;a++)(r=u[a])._arrayAttrs=s.findArrayAttributes(r),r._extremes={};var m=p._subplots.polar||[];for(a=0;a<m.length;a++)l.push(p[m[a]].radialaxis,p[m[a]].angularaxis);for(var v in p._colorAxes){var y=p[v];!1!==y.cauto&&(delete y.cmin,delete y.cmax)}var x=!1;function _(e){if(r=u[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var a=n.calc(t,r);a[0]&&a[0].t&&a[0].t._scene&&delete a[0].t._scene.dirty}for(i=0;i<r.transforms.length;i++){var o=r.transforms[i];(n=b[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function w(e,a){if(r=u[e],!!(n=r._module).isContainer===a){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var s=r.transforms||[];for(i=s.length-1;i>=0;i--)if(s[i].enabled){r._indexToPoints=s[i]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:h,y:h}]),o[0].t||(o[0].t={}),o[0].trace=r,d[e]=o}}for(z(l,u,p),a=0;a<u.length;a++)w(a,!0);for(a=0;a<u.length;a++)_(a);for(x&&z(l,u,p),a=0;a<u.length;a++)w(a,!0);for(a=0;a<u.length;a++)w(a,!1);O(t);var T=function(t,e){var r,n,a,i,s,l=[];function u(t,r,n){var a=r._id.charAt(0);if(\"histogram2dcontour\"===t){var i=r._counterAxes[0],o=f.getFromId(e,i),s=\"x\"===a||\"x\"===i&&\"category\"===o.type,l=\"y\"===a||\"y\"===i&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===a?e:t)-1}}return function(t,e){return\"y\"===a?e:t}}var h={min:function(t){return c.aggNums(Math.min,null,t)},max:function(t){return c.aggNums(Math.max,null,t)},sum:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return c.mean(t)},median:function(t){return c.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(I);if(d){var g=d[1],m=d[2],v=[];for(n=0;n<p._categories.length;n++)v.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;o.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(a=0;a<w.length;a++){var T,k,M,A=w[a];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var E=x._diag[S][0];E&&(p=e._fullLayout[f.id2name(E)])}var C=A.trace.dimensions[S].values;for(i=0;i<C.length;i++)for(T=C[i],k=p._categoriesMap[T],s=0;s<A.trace.dimensions.length;s++)if(s!==S){var L=A.trace.dimensions[s];v[k][1].push(L.values[i])}}else if(\"scattergl\"===_){for(i=0;i<A.t.x.length;i++)\"x\"===b&&(T=A.t.x[i],k=T,M=A.t.y[i]),\"y\"===b&&(T=A.t.y[i],k=T,M=A.t.x[i]),v[k][1].push(M);A.t&&A.t._scene&&delete A.t._scene.dirty}else if(A.hasOwnProperty(\"z\")){M=A.z;var P=u(x.type,p,M);for(i=0;i<M.length;i++)for(s=0;s<M[i].length;s++)(k=P(s,i))+1&&v[k][1].push(M[i][s])}else for(\"x\"===b?(T=A.p+1?A.p:A.x,M=A.s||A.v||A.y):\"y\"===b&&(T=A.p+1?A.p:A.y,M=A.s||A.v||A.x),Array.isArray(M)||(M=[M]),i=0;i<M.length;i++)v[T][1].push(M[i])}}}p._categoriesValue=v;var z=[];for(n=0;n<v.length;n++)z.push([v[n][0],h[g](v[n][1])]);z.sort((function(t,e){return t[1]-e[1]})),p._categoriesAggregatedValue=z,p._initialCategories=z.map((function(t){return t[0]})),\"descending\"===m&&p._initialCategories.reverse(),l=l.concat(p.sortByInitialCategories())}}}return l}(l,t);if(T.length){for(p._numBoxes=0,p._numViolins=0,a=0;a<T.length;a++)w(T[a],!0);for(a=0;a<T.length;a++)w(T[a],!1);O(t)}o.getComponentMethod(\"fx\",\"calc\")(t),o.getComponentMethod(\"errorbars\",\"calc\")(t)};var I=/(total|sum|min|max|mean|median) (ascending|descending)/;function z(t,e,r){var n,a,i,o={};for(n=0;n<t.length;n++)i=(a=t[n])._id,a.clearCalc(),\"multicategory\"===a.type&&a.setupMultiCategory(e),o[a._id]=1;var s=r._axisMatchGroups||[];for(n=0;n<s.length;n++)for(i in s[n])o[i]||(a=r[f.id2name(i)]).clearCalc()}function O(t){var e,r,n,a=t._fullLayout,i=a._visibleModules,o={};for(r=0;r<i.length;r++){var s=i[r],l=s.crossTraceCalc;if(l){var u=s.basePlotModule.name;o[u]?c.pushUnique(o[u],l):o[u]=[l]}}for(n in o){var h=o[n],f=a._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?a._plots[p]:a[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}x.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},x.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},x.generalUpdatePerTraceModule=function(t,e,r,n){var a,i=e.traceHash,o={};for(a=0;a<r.length;a++){var s=r[a],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var u in i)if(!o[u]){var h=i[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,c.filterVisible(p),n)}e.traceHash=o},x.plotBasePlot=function(t,e,r,n,a){var i=o.getModule(t),s=m(e.calcdata,i)[0];i.plot(e,s,n,a)},x.cleanBasePlot=function(t,e,r,n,a){var i=a._has&&a._has(t),o=r._has&&r._has(t);i&&!o&&a[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},{\"../components/color\":615,\"../constants/numerical\":724,\"../lib\":749,\"../plot_api/plot_schema\":786,\"../plot_api/plot_template\":787,\"../plots/get_data\":835,\"../registry\":881,\"./animation_attributes\":792,\"./attributes\":794,\"./cartesian/axis_ids\":801,\"./cartesian/handle_outline\":808,\"./command\":824,\"./font_attributes\":826,\"./frame_attributes\":827,\"./layout_attributes\":852,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],862:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],863:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../lib/polygon\").tester,i=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var a,i,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?i=u*(a=d/(u-p)):c?(a=s*f,i=s):(a=o,i=o*u):l&&c?(a=0,i=d):c?(a=0,i=s):a=i=NaN,[a,i]}function u(t,e,r,a){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,a=new Array(n+1);for(r=0;r<n;r++){var i=e[r];a[r]=[t*Math.cos(i),t*Math.sin(i)]}return a[r]=a[0].slice(),a}(t,a):function(t,e,r,a){var s,u,h=a.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function m(t){return o(t,[e,r])}var v=i(a,(function(t){return m(t)?l(t,e):1/0})),y=d(a[v],a[g(v-1)],e);for(f.push(y),s=v,u=0;u<h;s++,u++){var x=a[g(s)];if(!m(x))break;f.push(p(x))}var b=i(a,(function(t){return m(t)?l(t,r):1/0})),_=d(a[b],a[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,a)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,a=new Array(n),i=0;i<n;i++){var o=t[i];a[i]=[e+o[0],r-o[1]]}return a}e.exports={isPtInsidePolygon:function(t,e,r,n,i){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=a(u(s,n[0],n[1],i)),h=a(u(l,n[0],n[1],i)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var a=1/0,i=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];a=Math.min(a,l[0]),i=Math.min(i,-l[1])}return[a,i]},findEnclosingVertexAngles:function(t,e){var r=i(e,(function(e){var r=s(e,t);return r>0?r:1/0})),a=n.mod(r+1,e.length);return[e[r],e[a]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var a=-e*r,i=e*e+1,o=2*(e*a-r),s=a*a+r*r-t*t,l=Math.sqrt(o*o-4*i*s),c=(-o+l)/(2*i),u=(-o-l)/(2*i);return[[c,e*c+a+n],[u,e*u+a+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,a,i){return\"M\"+f(u(t,e,r,n),a,i).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,a,i,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,a),i,o);return\"M\"+f(u(l,r,n,a),i,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":749,\"../../lib/polygon\":761}],864:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex,i=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=a(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots[l],o=0;o<a.length;o++){var s=a[o],c=n(r,l,s),u=e[s]._subplot;u||(u=i(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var a=n._subplots[l]||[],i=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=i&&!o,c=0;c<a.length;c++){var u=a[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":749,\"../cartesian\":811,\"../get_data\":835,\"./constants\":862,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./polar\":873}],865:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),a=t(\"../cartesian/layout_attributes\"),i=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:a.color,showline:o({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:o({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:a.tickmode,nticks:a.nticks,tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,layer:a.layer},\"plot\",\"from-root\"),u={visible:o({},a.visible,{dflt:!0}),type:o({},a.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},a.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},a.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:a.categoryorder,categoryarray:a.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},a.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},a.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:a.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}};o(u,l,c);var h={visible:o({},a.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:a.categoryorder,categoryarray:a.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:a.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:i({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":614,\"../../lib\":749,\"../../plot_api/edit_types\":780,\"../cartesian/layout_attributes\":812,\"../domain\":825}],866:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),m=t(\"./constants\"),v=m.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=a.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,m.name,o.id),w=o.layoutOut;function T(t,e){return r(b+\".\"+t,e)}for(var k=0;k<v.length;k++){b=v[k],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=i.newContainer(e,b);A._id=A._name=b,A._attr=o.id+\".\"+b,A._traceIndices=_.map((function(t){return t._expandedIndex}));var S=m.axisName2dataArray[b],E=x(M,A,T,_,S);h(M,A,T,{axData:_,dataAttr:S});var C,L,P=T(\"visible\");switch(g(A,e,w),T(\"uirevision\",e.uirevision),P&&(L=(C=T(\"color\"))===M.color?C:o.font.color),A._m=1,b){case\"radialaxis\":var I=T(\"autorange\",!A.isValidRange(M.range));M.autorange=I,!I||\"linear\"!==E&&\"-\"!==E||T(\"rangemode\"),\"reversed\"===I&&(A._m=-1),T(\"range\"),A.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(T(\"side\"),T(\"angle\",y[0]),T(\"title.text\"),n.coerceFont(T,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=M.type=A.type=\"linear\"}T(\"linear\"===E?\"thetaunit\":\"period\");var O=T(\"direction\");T(\"rotation\",{counterclockwise:0,clockwise:90}[O])}if(P)l(M,A,T,A.type),u(M,A,T,A.type,{tickSuffixDflt:\"degrees\"===A.thetaunit?\"\\xb0\":void 0}),c(M,A,T,{outerTicks:!0}),T(\"showticklabels\")&&(n.coerceFont(T,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),T(\"tickangle\"),T(\"tickformat\")),f(M,A,T,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),T(\"layer\");\"category\"!==E&&T(\"hoverformat\"),A._input=M}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,a){if(\"-\"===r(\"type\")){for(var i,o=0;o<n.length;o++)if(n[o].visible){i=n[o];break}i&&i[a]&&(e.type=p(i[a],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:m.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":615,\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../cartesian/axis_autotype\":799,\"../cartesian/category_order_defaults\":802,\"../cartesian/line_grid_defaults\":814,\"../cartesian/tick_label_defaults\":819,\"../cartesian/tick_mark_defaults\":820,\"../cartesian/tick_value_defaults\":821,\"../get_data\":835,\"../subplot_defaults\":875,\"./constants\":862,\"./layout_attributes\":865,\"./set_convert\":874}],867:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),a=n.marker,i=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:i({},n.r,{}),t:i({},n.t,{}),marker:{color:i({},a.color,{}),size:i({},a.size,{}),symbol:i({},a.symbol,{}),opacity:i({},a.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":739,\"../../../traces/scatter/attributes\":1156}],868:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,i=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=a({},n.domain,{});function l(t,e){return a({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=i({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":739,\"../../../plot_api/edit_types\":780,\"../../cartesian/layout_attributes\":812}],869:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":870,\"./micropolar_manager\":871}],870:[function(t,e,r){var n=t(\"d3\"),a=t(\"../../../lib\").extendDeepAll,i=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each((function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach((function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize}));var p=c.filter((function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r})),d=!1,g=p.map((function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t}));if(d){var m=n.nest().key((function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"})).entries(g),v=[],y=m.map((function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map((function(t,e){return 0}));return t.values.forEach((function(t,e,n){t.yStack=[r],v.push(r),r=o.util.sumArrays(t.r,r)})),t.values}));p=n.merge(y)}p.forEach((function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]}));var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];d?b=[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(v)))]:b=n.extent(o.util.flattenArray(p.map((function(t,e){return t.r}))));f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,T=o.util.flattenArray(p.map((function(t,e){return t.t}))),k=\"string\"==typeof T[0];k&&(T=o.util.deduplicate(T),w=T.slice(),T=n.range(T.length),p=p.map((function(t,e){var r=t;return t.t=[T],d&&(r.yStack=t.yStack),r})));var M=p.filter((function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry})).length===p.length,A=null===f.needsEndSpacing?k||!M:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!k&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(T),E=Math.abs(T[1]-T[0]);M&&!k&&(E=0);var C=S.slice();A&&k&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var I=n.range.apply(this,C);if(I=I.map((function(t,e){return parseFloat(t.toPrecision(12))})),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=A?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),O=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(O)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map((function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor})).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map((function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r}));o.Legend().config({data:p.map((function(t,e){return t.name||\"Element\"+e})),legendConfig:a({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var Z=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(Z).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text((function(t,e){return this.textContent+f.radialAxis.ticksSuffix})).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var X=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(I),J=X.enter().append(\"g\").classed(\"angular-tick\",!0);X.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),X.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",(function(t,e){return e%(f.minorTicks+1)==0})).classed(\"minor\",(function(t,e){return!(e%(f.minorTicks+1)==0)})).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),X.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=X.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:i+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,a=f.angularAxis.tickOrientation;return\"horizontal\"==a?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==a?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text((function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix})).style(B);f.angularAxis.rewriteTicks&&K.text((function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)}));var Q=n.max(R.selectAll(\".angular-tick text\")[0].map((function(t,e){return t.getCTM().e+t.getBBox().width})));D.attr({transform:\"translate(\"+[x+Q,f.margin.top]+\")\"});var $=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach((function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter((function(t,r){return r==e})),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})}));var rt=n.nest().key((function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"})).entries(et),nt=[];rt.forEach((function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map((function(t,e){return[t]}))):nt.push(t.values)})),nt.forEach((function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map((function(t,e){return a(o[r].defaultConfig(),t)}));o[r]().config(n)()}))}var at,it,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!k){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",(function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;at=s.invert(n);var a=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(at)).move([a[0]+_[0],a[1]+_[1]])})).on(\"mouseout.angular-guide\",(function(t,e){ot.select(\"line\").style({opacity:0})}))}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",(function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),it=r.invert(o.util.getMousePos(Y).radius);var a=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(it)).move([a[0]+_[0],a[1]+_[1]])})).on(\"mouseout.radial-guide\",(function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()})),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",(function(e,r){var a=n.select(this),i=this.style.fill,s=\"black\",l=this.style.opacity||1;if(a.attr({\"data-opacity\":l}),i&&\"none\"!==i){a.attr({\"data-fill\":i}),s=n.hsl(i).darker().toString(),a.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};k&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else i=this.style.stroke||\"black\",a.attr({\"data-stroke\":i}),s=n.hsl(i).darker().toString(),a.style({stroke:s,opacity:1})})).on(\"mousemove.tooltip\",(function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()})).on(\"mouseout.tooltip\",(function(t,e){ut.hide();var r=n.select(this),a=r.attr(\"data-fill\");a?r.style({fill:a,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})}))}))}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach((function(t,e){l.data[e]||(l.data[e]={}),a(l.data[e],o.Axis.defaultConfig().data[0]),a(l.data[e],t)})),a(l.layout,o.Axis.defaultConfig().layout),a(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map((function(e,r){var n=e*Math.PI/180;return[e,t(n)]}))},o.util.dataFromEquation=function(t,e,r){var a=e||6,i=[],o=[];n.range(0,360+a,a).forEach((function(e,r){var n=e*Math.PI/180,a=t(n);i.push(e),o.push(a)}));var s={t:i,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map((function(t,e){return r[e]||r[0]}))},o.util.fillArrays=function(t,e,r){return e.forEach((function(e,n){t[e]=o.util.ensureArray(t[e],r)})),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map((function(t,e){return n.sum(t)}))},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter((function(t,e,r){return r.indexOf(t)==e}))},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],a=e[1],i={};return i.x=r,i.y=a,i.pos=e,i.angle=180*(Math.atan2(a,r)+Math.PI)/Math.PI,i.radius=Math.sqrt(r*r+a*a),i},o.util.duplicatesCount=function(t){for(var e,r={},n={},a=0,i=t.length;a<i;a++)(e=t[a])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var a=r.slice();r=e,e=a}var i=e.reduce((function(t,e){if(\"undefined\"!=typeof t)return t[e]}),t);\"undefined\"!=typeof i&&(e.reduce((function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]}),t),r.reduce((function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=i),t[e]}),t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function i(){var e=t[0].geometryConfig,a=e.container;\"string\"==typeof a&&(a=n.select(a)),a.datum(t).each((function(t,a){var i=!!t[0].data.yStack,o=t.map((function(t,e){return i?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])})),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,a,i){var o=t[i].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,a,i){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[i].data.dotSize).type(t[i].data.dotType)(r,a);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,a,i,s=(n=function(t,r){var n=e.radialScale(t[1]),a=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:a}}(o),a=n.r*Math.cos(n.t),i=n.r*Math.sin(n.t),{x:a,y:i});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius((function(t){return e.radialScale(t[1])})).angle((function(t){return e.angularScale(t[0])*Math.PI/180}));c.line=function(r,a,i){var s=r[2]?o[i].map((function(t,e){return[t[0],t[1]+t[2]]})):o[i];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[i].data.dotVisible},fill:d.stroke(r,a,i)}).attr({class:\"mark dot\"}),!(a>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,a,i)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,a,i)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,a,i)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,a,i)},opacity:function(t,e){return d.opacity(r,a,i)},display:function(t,e){return d.display(r,a,i)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle((function(t){return-f/2})).endAngle((function(t){return f/2})).innerRadius((function(t){return e.radialScale(l+(t[2]||0))})).outerRadius((function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])}));c.arc=function(t,r,a){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,a){return r[t[a].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var m=g.selectAll(\"path.mark\").data((function(t,e){return t}));m.enter().append(\"path\").attr({class:\"mark\"}),m.style(d).each(c[e.geometryType]),m.exit().remove(),g.exit().remove()}))}return i.config=function(e){return arguments.length?(e.forEach((function(e,r){t[r]||(t[r]={}),a(t[r],o.PolyChart.defaultConfig()),a(t[r],e)})),this):t},i.getColorScale=function(){},n.rebind(i,e,\"on\"),i},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,i=t.data.map((function(t,r){return[].concat(t).map((function(t,n){var i=a({},e.elements[r]);return i.name=t,i.color=[].concat(e.elements[r].color)[n],i}))})),o=n.merge(i);o=o.filter((function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)})),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map((function(t,e){return t.color})),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),m=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var v=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);v.enter().append(\"stop\"),v.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,m(e)+c/2]+\")\"},d:function(t,e){var r,a,i,o=t.symbol;return i=3*(a=c),\"line\"===(r=o)?\"M\"+[[-a/2,-a/12],[a/2,-a/12],[a/2,a/12],[-a/2,a/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(i)():n.svg.symbol().type(\"square\").size(i)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(m).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text((function(t,e){return o[e].name})),r}return r.config=function(e){return arguments.length?(a(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,i={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=i.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:i.padding+l,dy:.3*+i.fontSize}),c};return c.text=function(a){var o=n.hsl(i.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=a||\"\";e.style({fill:u,\"font-size\":i.fontSize+\"px\"}).text(h);var f=i.padding,p=e.node().getBBox(),d={fill:i.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,m=p.height+2*f;return r.attr({d:\"M\"+[[l,-m/2],[l,-m/4],[i.hasTick?0:l,0],[l,m/4],[l,m/2],[g,m/2],[g,-m/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-m/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return a(i,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map((function(t,r){var n=a({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n})),!e&&t.layout&&\"stack\"===t.layout.barmode)){var i=o.util.duplicates(r.data.map((function(t,e){return t.geometry})));r.data.forEach((function(t,e){var n=i.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)}))}if(t.layout){var s=a({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach((function(t,e){u[c[l.indexOf(t.key)]]=t.value})),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":717,\"../../../lib\":749,d3:169}],871:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../../lib\"),i=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=a.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,a,i,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,a||(a=o.Axis()),i=o.adapter.plotly().convert(e),a.config(i).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return a.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(a.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:a.angularScale(),r:a.radialScale()}},f.setUndoPoint=function(){var t,n,a=this,i=o.util.cloneJson(e);t=i,n=r,h.add({undo:function(){n&&a(n)},redo:function(){a(t)}}),r=o.util.cloneJson(i)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),a=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:i.background,_container:e,_paperdiv:r,_paper:a};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":615,\"../../../lib\":749,\"./micropolar\":870,\"./undo_manager\":872,d3:169}],872:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function a(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n||(e.splice(r+1,e.length-r),e.push(t),r=e.length-1),this},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(a(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(a(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],873:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"tinycolor2\"),i=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/fx\"),v=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"../../constants/alignment\").MID_SHIFT,M=t(\"./constants\"),A=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var I=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function O(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},I.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},I.updateLayers=function(t,e){var r=this.layers,a=e.radialaxis,i=e.angularaxis,o=M.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===i.layer,u=\"below traces\"===a.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",(function(t){return\"polarsublayer \"+t})).each((function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),h.order()},I.updateLayout=function(t,e){var r=this.layers,n=t._size,a=e.radialaxis,i=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,m,v,y=this.sectorBBox=function(t){var e,r,n,a,i=t[0],o=t[1]-i,s=E(i,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));a=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,a]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,v=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],m=[c[0]+v,c[1]-v]):(d=h,v=(u-(p=h/w))/n.w/2,g=[o[0]+v,o[1]-v],m=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=m;var T=this.xOffset2=n.l+n.w*g[0],k=this.yOffset2=n.t+n.h*(1-m[1]),M=this.radius=p/x,A=this.innerRadius=e.hole*M,S=this.cx=T-M*y[0],L=this.cy=k+M*y[3],P=this.cxx=S-T,I=this.cyy=L-k;this.radialAxis=this.mockAxis(t,e,a,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[a.side],domain:[A/n.w,M/n.w]}),this.angularAxis=this.mockAxis(t,e,i,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:m});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,I)),r.frontplot.attr(\"transform\",R(T,k)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},I.mockAxis=function(t,e,r,n){var a=o.extendFlat({},r,n);return f(a,e,t),a},I.mockCartesianAxis=function(t,e,r){var n=this,a=r._id,i=o.extendFlat({type:\"linear\"},r);h(i,t);var s={x:[0,2],y:[1,3]};return i.setRange=function(){var t=n.sectorBBox,r=s[a],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);i.range=[t[r[0]]*l,t[r[1]]*l]},i.isPtWithinRange=\"x\"===a?function(t){return n.isPtInside(t)}:function(){return!0},i.setRange(),i.setScale(),i},I.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,a=e.radialaxis;n.setScale(),p(r,n);var i=n.range;a.range=i.slice(),a._input.range=i.slice(),n._rl=[n.r2l(i[0],null,\"gregorian\"),n.r2l(i[1],null,\"gregorian\")]},I.updateRadialAxis=function(t,e){var r=this,n=r.gd,a=r.layers,i=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<i;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var m=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},v=z(f);if(r.radialTickLayout!==v&&(a[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=v),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:a[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:m,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:a[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:a[\"radial-axis\"],transFn:m,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(O(C(f.angle),r.vangles)):f.angle,w=R(c,h),T=w+F(-_);D(a[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:T}),D(a[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(a[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:i,y2:0,transform:T}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},I.updateRadialAxisTitle=function(t,e,r){var n=this.gd,a=this.radius,i=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,m=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*m:g+.8*m}this.layers[\"radial-axis-title\"]=v.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:i+a/2*f+d*p,y:o-a/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},I.updateAngularAxis=function(t,e){var r=this,n=r.gd,a=r.layers,i=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+i*Math.cos(t),h-i*Math.sin(t))},m=u.makeLabelFns(p,0).labelStandoff,v={xFn:function(t){var e=d(t);return Math.cos(e)*m},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(m+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*k)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(a[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter((function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)}))),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:a[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:a[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+i*r,h-i*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:a[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:v})}D(a[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},I.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},I.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=M.MINZOOM,c=M.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,v=e.cxx,_=e.cyy,w=e.sectorInRad,T=e.vangles,k=e.radialAxis,S=A.clampTiny,E=A.findXYatLength,C=A.findEnclosingVertexAngles,L=M.cornerHalfWidth,P=M.cornerLen/2,I=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(I).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,O,D,F,B,N,j,U,V,q={element:I,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-v,e-_)}function Y(t,e){return Math.atan2(_-e,t-v)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function Z(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,a=r-n,i=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,a)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,i)+\"L\"+W(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,a)+\"Z\"}function X(t,r,n){if(0===t)return e.pathSector(2*L);var a,i,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);a=E(P,h,f[0][0],f[0][1]),i=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),a=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+a.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function Q(t,r){var n,a,i=z+t,o=O+r,s=G(z,O),l=Math.min(G(i,o),u),c=Y(z,O);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),a=Z(D,c)+Z(F,c)),K(n,a)}function $(t,e,r,n){var a=A.findIntersectionXY(r,n,r,[t-v,_-e]);return H(a[0],a[1])}function tt(t,r){var n,a,i=z+t,o=O+r,s=Y(z,O),l=Y(i,o),c=C(s,T),h=C(l,T);J($(z,O,c[0],c[1]),Math.min($(i,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),a=[X(D,c[0],c[1]),X(F,c[0],c[1])].join(\" \")),K(n,a)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),i.call(\"_guiRelayout\",r,t)}}function rt(t){var r=k._rl,n=(r[1]-r[0])/(1-h/u)/u,a=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=a}function nt(t,n){var a=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),i.call(\"_guiRelayout\",r,o)}a.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),a.indexOf(\"event\")>-1&&m.click(r,n,e.id)}q.prepFn=function(t,n,i){var o=r._fullLayout.dragmode,l=I.getBoundingClientRect();if(z=n-l.left,O=i-l.top,T){var c=A.findPolygonOffset(u,w[0],w[1],T);z+=v+c[0],O+=_+c[1]}switch(o){case\"zoom\":q.moveFn=T?tt:Q,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=a(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,i,q,o)}},I.onmousemove=function(t){m.hover(r,t,e.id),r._fullLayout._lasthover=I,r._fullLayout._hoversubplot=e.id},I.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},I.updateRadialDrag=function(t,e,r){var a=this,s=a.gd,l=a.layers,c=a.radius,u=a.innerRadius,h=a.cx,f=a.cy,p=a.radialAxis,m=M.radialDragBoxSize,v=m/2;if(p.visible){var y,x,_,k=C(a.radialAxisAngle),A=p._rl,S=A[0],E=A[1],P=A[r],I=.75*(A[1]-A[0])/(1-e.hole)/c;r?(y=h+(c+v)*Math.cos(k),x=f-(c+v)*Math.sin(k),_=\"radialdrag\"):(y=h+(u-v)*Math.cos(k),x=f-(u-v)*Math.sin(k),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-v,-v,m,m),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<M.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],i=[Math.cos(k),Math.sin(k)],l=Math.abs(o.dot(n,i)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[a.id+\".radialaxis.angle\"]=B:null!==N&&(t[a.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?i.call(\"_guiRelayout\",s,a.id+\".radialaxis.angle\",B):null!==N&&i.call(\"_guiRelayout\",s,a.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,i=x+e;B=Math.atan2(f-i,n-h),a.vangles&&(B=O(B,a.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=a.gd._fullLayout,c=s[a.id];a.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(k),Math.sin(k)]);if(N=P-I*n,I>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[a.id];p.range[r]=N,p._rl[r]=N,a.updateRadialAxis(l,c),a.xaxis.setRange(),a.xaxis.setScale(),a.yaxis.setRange(),a.yaxis.setScale();var u=!1;for(var h in a.traceHash){var f=a.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,a,d,c),i.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),T(s))}else N=null}},I.updateAngularDrag=function(t){var e=this,r=e.gd,a=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,m=M.angularDragBoxSize,v=d.makeDragger(a,\"path\",\"angulardrag\",\"move\"),y={element:v,gd:r};function x(t,e){return Math.atan2(p+m-e,t-f-m)}n.select(v).attr(\"d\",e.pathAnnulus(s,s+m)).attr(\"transform\",R(u,h)).call(_,\"move\");var k,A,S,E,C,P,I=a.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=I.selectAll(\".point\"),O=I.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],m=x(k+t,A+s),v=L(m-P);if(E=S+v,a.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-v,f,p])),e.vangles){C=e.radialAxisAngle+v;var y=R(u,h)+F(-v),b=R(u,h)+F(-C);a.bg.attr(\"transform\",y),a[\"radial-grid\"].attr(\"transform\",y),a[\"radial-axis\"].attr(\"transform\",b),a[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(v));z.each((function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([v]))})),O.each((function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([v,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))})),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&I.call(l.hideOutsideRangePoints,e);var _=!1;for(var M in e.traceHash)if(i.traceIs(M,\"gl\")){var D=e.traceHash[M],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),T(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){O.select(\"text\").attr(\"transform\",null);var t={};B(t),i.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,a,i){var o=t[e.id];S=o.angularaxis.rotation;var s=v.getBoundingClientRect();k=a-s.left,A=i-s.top,P=x(k,A),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(v),null)),g.init(y)},I.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),a=this.radialAxis,i=a.c2l(t.r),s=a._rl;return(r?A.isPtInsidePolygon:o.isPtInsideSector)(i,n,s,e,r)},I.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?A.pathPolygon:o.pathArc)(t,e[0],e[1],r)},I.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?A.pathPolygon:o.pathSector)(t,e[0],e[1],r)},I.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?A.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},I.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},I.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":615,\"../../components/dragelement\":634,\"../../components/drawing\":637,\"../../components/fx\":655,\"../../components/titles\":710,\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/clear_gl_canvases\":733,\"../../lib/setcursor\":769,\"../../plot_api/subroutines\":788,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"../cartesian/autorange\":797,\"../cartesian/dragbox\":806,\"../cartesian/select\":817,\"../cartesian/set_convert\":818,\"../plots\":861,\"./constants\":862,\"./helpers\":863,\"./set_convert\":874,d3:169,tinycolor2:548}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../cartesian/set_convert\"),i=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(a(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],a=r.innerRadius,i=(r.radius-a)/(n-e),o=a/i,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*i},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var a=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?i(t):t}(a(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,a){var i,o,s=e[a],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(i=new Array(l),o=0;o<l;o++)i[o]=c(s[o])}else{var u=a+\"0\",h=\"d\"+a,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(i=new Array(l),o=0;o<l;o++)i[o]=f+o*p}return i},t.setGeometry=function(){var a,s,l,c,u=e.sector,h=u.map(i),f={clockwise:-1,counterclockwise:1}[t.direction],p=i(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=a=n.identity,c=i,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var m=t._categories.length,v=t.period?Math.max(t.period,m):m;0===v&&(v=1),s=c=function(t){return 2*t*Math.PI/v},a=l=function(t){return t*v/Math.PI/2},t.range=[0,v]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return a(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":749,\"../cartesian/set_convert\":818}],875:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plot_api/plot_template\"),i=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function m(t,e){return n.coerce(s,l,u,t,e)}for(var v=0;v<d;v++){var y=p[v];s=t[y]?t[y]:t[y]={},l=a.newContainer(e,y,g),m(\"uirevision\",e.uirevision);var x={};x[f]=[v/d,(v+1)/d],i(l,e,m,x),o.id=y,h(s,l,m,o)}}},{\"../lib\":749,\"../plot_api/plot_template\":787,\"./domain\":825}],876:[function(t,e,r){\"use strict\";['Variables are inserted using %{variable}, for example \"y: %{y}\".','Numbers are formatted using d3-format\\'s syntax %{variable:d3-format}, for example \"Price: %{y:$.2f}\".',t(\"../constants/docs\").FORMAT_LINK,\"for details on the formatting syntax.\",'Dates are formatted using d3-time-format\\'s syntax %{variable|d3-time-format}, for example \"Day: %{2019-01-01|%A}\".',t(\"../constants/docs\").DATE_FORMAT_LINK,\"for details on the date formatting syntax.\"].join(\" \");function n(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],a=0;a<r.length;a++)n[a]=\"`\"+r[a]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{\"../constants/docs\":719}],877:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),a=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=i(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.ternary,o=0;o<i.length;o++){var s=i[o],l=a(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var a=n._subplots.ternary||[],i=0;i<a.length;i++){var o=a[i],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":749,\"../../plots/get_data\":835,\"./layout_attributes\":878,\"./layout_defaults\":879,\"./ternary\":880}],878:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),a=t(\"../domain\").attributes,i=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:{text:i.title.text,font:i.title.font},color:i.color,tickmode:i.tickmode,nticks:s({},i.nticks,{dflt:6,min:1}),tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:s({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:s({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth,layer:i.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},c=e.exports=o({domain:a({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":614,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../cartesian/layout_attributes\":812,\"../domain\":825}],879:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),i=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,i){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");i.bgColor=n.combine(c,i.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=a.newContainer(e,o))._name=o,d(s,l,i,e);var p=e.aaxis,g=e.baxis,m=e.caxis;p.min+g.min+m.min>=u&&(p.min=0,g.min=0,m.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var a=h[e._name];function o(r,n){return i.coerce(t,e,a,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==a.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,m=o(\"title.text\",g);e._hovertitle=m===g?m:d,i.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(i.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:a}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":615,\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../cartesian/line_grid_defaults\":814,\"../cartesian/tick_label_defaults\":819,\"../cartesian/tick_mark_defaults\":820,\"../cartesian/tick_value_defaults\":821,\"../subplot_defaults\":875,\"./layout_attributes\":878}],880:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"tinycolor2\"),i=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),m=t(\"../../components/dragelement/helpers\"),v=m.freeMode,y=m.rectMode,x=t(\"../../components/titles\"),b=t(\"../cartesian/select\").prepSelect,_=t(\"../cartesian/select\").selectOnClick,w=t(\"../cartesian/select\").clearSelect,T=t(\"../cartesian/select\").clearSelectionsCache,k=t(\"../cartesian/constants\");function M(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=M;var A=M.prototype;A.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},A.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var a=0;a<t.length;a++){if(!1===t[a][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},A.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,a=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",a,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},A.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var a=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),i=[\"agrid\",\"bgrid\",\"cgrid\"];a.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&i.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),a.order()};var S=Math.sqrt(4/3);A.adjustLayout=function(t,e){var r,n,a,i,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,m=p.x[1]-p.x[0],v=p.y[1]-p.y[0],y=m*e.w,x=v*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>S*x?a=(i=x)*S:i=(a=y)/S,o=m*a/y,s=v*i/x,r=e.l+e.w*d-a/2,n=e.t+e.h*(1-g)-i/2,f.x0=r,f.y0=n,f.w=a,f.h=i,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var k=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[k,k+s*S],anchor:\"free\",position:0,_id:\"y\",_length:a});u(M,f.graphDiv._fullLayout),M.setScale();var A=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:a});u(A,f.graphDiv._fullLayout),A.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[k,k+s*S],anchor:\"free\",position:0,_id:\"y\",_length:a});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+i)+\"h\"+a+\"l-\"+a/2+\",-\"+i+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+i+\"h\"+a+\"l-\"+a/2+\",-\"+i+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var I=\"translate(\"+(r-A._offset)+\",\"+(n+i)+\")\";f.layers.baxis.attr(\"transform\",I),f.layers.bgrid.attr(\"transform\",I);var z=\"translate(\"+(r+a/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var O=\"translate(\"+(r+a/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",O),f.layers.cgrid.attr(\"transform\",O),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+i)+\"l\"+a/2+\",-\"+i:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",A.showline?\"M\"+r+\",\"+(n+i)+\"h\"+a:\"M0,0\").call(l.stroke,A.linecolor||\"#000\").style(\"stroke-width\",(A.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+a/2)+\",\"+n+\"l\"+a/2+\",\"+i:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},A.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,a=this.aaxis,i=this.baxis,o=this.caxis;if(this.drawAx(a),this.drawAx(i),this.drawAx(o),t){var l=Math.max(a.showticklabels?a.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(i.showticklabels?i.tickfont.size:0)+(\"outside\"===i.ticks?i.ticklen:0)+3;n[\"a-title\"]=x.draw(e,\"a\"+r,{propContainer:a,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-a.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=x.draw(e,\"b\"+r,{propContainer:i,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*i.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=x.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},A.drawAx=function(t){var e,r=this.graphDiv,n=t._name,a=n.charAt(0),i=t._id,s=this.layers[n],l=a+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+i+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),m=d*(t.linewidth||1)/2,v=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===a?\"M0,\"+m+\"l\"+Math.sin(g)*v+\",\"+Math.cos(g)*v:\"M\"+m+\",0l\"+Math.cos(g)*v+\",\"+-Math.sin(g)*v,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[a];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[a+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var E=k.MINZOOM/2+.87,C=\"m-0.87,.5h\"+E+\"v3h-\"+(E+5.2)+\"l\"+(E/2+2.6)+\",-\"+(.87*E+4.5)+\"l2.6,1.5l-\"+E/2+\",\"+.87*E+\"Z\",L=\"m0.87,.5h-\"+E+\"v3h\"+(E+5.2)+\"l-\"+(E/2+2.6)+\",-\"+(.87*E+4.5)+\"l-2.6,1.5l\"+E/2+\",\"+.87*E+\"Z\",P=\"m0,1l\"+E/2+\",\"+.87*E+\"l2.6,-1.5l-\"+(E/2+2.6)+\",-\"+(.87*E+4.5)+\"l-\"+(E/2+2.6)+\",\"+(.87*E+4.5)+\"l2.6,1.5l\"+E/2+\",-\"+.87*E+\"Z\",I=!0;function z(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}A.clearSelect=function(){T(this.dragOptions),w(this.dragOptions.gd)},A.initInteractions=function(){var t,e,r,n,u,h,f,p,m,x,w=this,T=w.layers.plotbg.select(\"path\").node(),M=w.graphDiv,A=M._fullLayout._zoomlayer;function E(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function O(t,e){var r=M._fullLayout.clickmode;z(M),2===t&&(M.emit(\"plotly_doubleclick\",null),i.call(\"_guiRelayout\",M,E({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&_(e,M,[w.xaxis],[w.yaxis],w.id,w.dragOptions),r.indexOf(\"event\")>-1&&g.click(M,e,w.id)}function D(t,e){return 1-e/w.h}function R(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function F(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function B(a,i){var o=t+a,s=e+i,l=Math.max(0,Math.min(1,D(0,e),D(0,s))),c=Math.max(0,Math.min(1,R(t,e),R(o,s))),d=Math.max(0,Math.min(1,F(t,e),F(o,s))),g=(l/2+d)*w.w,v=(1-l/2-c)*w.w,y=(g+v)/2,b=v-g,_=(1-l)*w.h,T=_-b/S;b<k.MINZOOM?(u=r,m.attr(\"d\",f),x.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},m.attr(\"d\",f+\"M\"+g+\",\"+_+\"H\"+v+\"L\"+y+\",\"+T+\"L\"+g+\",\"+_+\"Z\"),x.attr(\"d\",\"M\"+t+\",\"+e+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+g+\",\"+_+C+\"M\"+v+\",\"+_+L+\"M\"+y+\",\"+T+P)),p||(m.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),x.transition().style(\"opacity\",1).duration(200),p=!0),M.emit(\"plotly_relayouting\",E(u))}function N(){z(M),u!==r&&(i.call(\"_guiRelayout\",M,E(u)),I&&M.data&&M._context.showTips&&(o.notifier(s(M,\"Double-click to zoom back out\"),\"long\"),I=!1))}function j(t,e){var n=t/w.xaxis._m,a=e/w.yaxis._m,i=[(u={a:r.a-a,b:r.b+(n+a)/2,c:r.c-(n-a)/2}).a,u.b,u.c].sort(o.sorterAsc),s=i.indexOf(u.a),l=i.indexOf(u.b),h=i.indexOf(u.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),u={a:i[s],b:i[l],c:i[h]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var f=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",f);var p=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",p),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),M.emit(\"plotly_relayouting\",E(u))}function U(){i.call(\"_guiRelayout\",M,E(u))}this.dragOptions={element:T,gd:M,plotinfo:{id:w.id,domain:M._fullLayout[w.id].domain,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(i,o,s){w.dragOptions.xaxes=[w.xaxis],w.dragOptions.yaxes=[w.yaxis];var c=w.dragOptions.dragmode=M._fullLayout.dragmode;v(c)?w.dragOptions.minDrag=1:w.dragOptions.minDrag=void 0,\"zoom\"===c?(w.dragOptions.moveFn=B,w.dragOptions.clickFn=O,w.dragOptions.doneFn=N,function(i,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=a(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,m=A.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),x=A.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),w.clearSelect(M)}(0,o,s)):\"pan\"===c?(w.dragOptions.moveFn=j,w.dragOptions.clickFn=O,w.dragOptions.doneFn=U,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,w.clearSelect(M)):(y(c)||v(c))&&b(i,o,s,w.dragOptions,c)}},T.onmousemove=function(t){g.hover(M,t,w.id),M._fullLayout._lasthover=T,M._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){M._dragging||d.unhover(M,t)},d.init(this.dragOptions)}},{\"../../components/color\":615,\"../../components/dragelement\":634,\"../../components/dragelement/helpers\":633,\"../../components/drawing\":637,\"../../components/fx\":655,\"../../components/titles\":710,\"../../lib\":749,\"../../lib/extend\":739,\"../../registry\":881,\"../cartesian/axes\":798,\"../cartesian/constants\":804,\"../cartesian/select\":817,\"../cartesian/set_convert\":818,\"../plots\":861,d3:169,tinycolor2:548}],881:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),a=t(\"./lib/noop\"),i=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,a=t.categories,i=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var a in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(a,t.name)}(t.basePlotModule);for(var o={},l=0;l<a.length;l++)o[a[l]]=!0,r.allCategories[a[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},i&&Object.keys(i).length&&(r.modules[e].meta=i),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&i(r.layoutArrayContainers,e),v(t)),r.modules)y(e,n);for(var a in r.subplotsRegistry)b(e,a);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,a=\"function\"==typeof t.transform,i=\"function\"==typeof t.calcTransform;if(!a&&!i)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in a&&i&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function m(t){var e=t.name,n=e.split(\"-\")[0],a=t.dictionary,i=t.format,o=a&&Object.keys(a).length,s=i&&Object.keys(i).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=a),s&&u.format===c.format&&(u.format=i)}o&&(c.dictionary=a),s&&(c.format=i)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)i(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var a=n.traces[e];a&&f(r.modules[e]._module.attributes,a)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var a=n.transforms[e];a&&f(r.transformsRegistry[e].attributes,a)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var a=r.subplotsRegistry[e],i=a.layoutAttributes,o=\"subplot\"===a.attr?a.name:a.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];i&&s&&f(i,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":m(n);break;case\"apiMethod\":var a=n.name;r.apiMethodRegistry[a]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var a=r.modules[t];return a||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),a=r.modules[c.type.dflt]),!!a.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],a=0;a<n.length;a++)n[a].type===e&&r.push(a);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||a},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":737,\"./lib/extend\":739,\"./lib/is_plain_object\":750,\"./lib/loggers\":753,\"./lib/noop\":758,\"./lib/push_unique\":763,\"./plots/attributes\":794,\"./plots/layout_attributes\":852}],882:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),a=t(\"../lib\"),i=a.extendFlat,o=a.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var a,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)a=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(a.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter((function(t){return t.match(/^scene\\d*$/)}));if(g.length){var m={};for(\"thumbnail\"===e.tileClass&&(m={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var v=h[g[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),i(v.xaxis,m),i(v.yaxis,m),i(v.zaxis,m),v._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":749,\"../registry\":881}],883:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plot_api/to_image\"),i=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=a(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),i(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},{\"../lib\":749,\"../plot_api/to_image\":790,\"./filesaver\":884,\"./helpers\":885}],884:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"./helpers\");e.exports=function(t,e,r){var i=document.createElement(\"a\"),o=\"download\"in i;return new Promise((function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return a.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=a.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=a.createBlob(t,r),u=a.createObjectURL(c),i.href=u,i.download=e,document.body.appendChild(i),i.click(),document.body.removeChild(i),a.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))}))}},{\"../lib\":749,\"./helpers\":885}],885:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},r.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var a=window.URL||window.webkitURL;r.createObjectURL=function(t){return a.createObjectURL(t)},r.revokeObjectURL=function(t){return a.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),a=0;a<e;a++)n[a]=t.charCodeAt(a);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":881}],886:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),a={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=a},{\"./cloneplot\":882,\"./download\":883,\"./helpers\":885,\"./svgtoimg\":887,\"./toimage\":888,\"./tosvg\":889}],887:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"events\").EventEmitter,i=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new a,r=new Promise((function(a,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(i.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,m=t.height||150,v=d*g,y=d*m,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=i.encodeSVG(l):(h=i.createBlob(l,\"svg\"),f=i.createObjectURL(h)),p.width=v,p.height=y,b.onload=function(){var r;switch(h=null,i.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,v,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}a(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,i.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f}));return t.promise?r:e}},{\"../lib\":749,\"./helpers\":885,events:110}],888:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,a=t(\"../registry\"),i=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return a.call(\"plot\",h,u.data,u.layout,u.config).then(f).then((function(){var t=o.getDelay(h._fullLayout);setTimeout((function(){var t=l(h),n=document.createElement(\"canvas\");n.id=i.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},{\"../lib\":749,\"../registry\":881,\"./cloneplot\":882,\"./helpers\":885,\"./svgtoimg\":887,\"./tosvg\":889,events:110}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../lib\"),i=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(i.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var m=h._basePlotModules||[];for(u=0;u<m.length;u++){var v=m[u];v.toSVG&&v.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}if(h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()})),h._gradientUrlQueryParts){var _=[];for(var w in h._gradientUrlQueryParts)_.push(w);_.length&&f.selectAll(_.join(\",\")).each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}))}\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var T=(new window.XMLSerializer).serializeToString(f.node());return T=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(T),T=(T=T.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),a.isIE()&&(T=(T=(T=T.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),T}},{\"../components/color\":615,\"../components/drawing\":637,\"../constants/xmlns_namespaces\":725,\"../lib\":749,d3:169}],890:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var a=e.marker;if(a){n.mergeArray(a.opacity,t,\"mo\",!0),n.mergeArray(a.color,t,\"mc\");var i=a.line;i&&(n.mergeArray(i.color,t,\"mlc\"),n.mergeArrayCastPositive(i.width,t,\"mlw\"))}}},{\"../../lib\":749}],891:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=s({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),h=c({},n.marker.line.width,{dflt:0}),f=c({width:h,editType:\"calc\"},o(\"marker.line\")),p=c({line:f,editType:\"calc\"},o(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,texttemplate:i({editType:\"plot\"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:a({},{keys:l.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:p,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/font_attributes\":826,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156,\"./constants\":893}],892:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,o=t(\"../../components/colorscale/calc\"),s=t(\"./arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,c,u,h,f=n.getFromId(t,e.xaxis||\"x\"),p=n.getFromId(t,e.yaxis||\"y\"),d={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=f.makeCalcdata(e,\"x\",d),u=p.makeCalcdata(e,\"y\"),c=a(e,p,\"y\",u),h=!!e.yperiodalignment):(r=p.makeCalcdata(e,\"y\",d),u=f.makeCalcdata(e,\"x\"),c=a(e,f,\"x\",u),h=!!e.xperiodalignment);for(var g=Math.min(c.length,r.length),m=new Array(g),v=0;v<g;v++)m[v]={p:c[v],s:r[v]},h&&(m[v].orig_p=u[v]),e.ids&&(m[v].id=String(e.ids[v]));return i(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(m,e),l(m,e),m}},{\"../../components/colorscale/calc\":623,\"../../components/colorscale/helpers\":626,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"../scatter/calc_selection\":1158,\"./arrays_to_calcdata\":890}],893:[function(t,e,r){\"use strict\";e.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},{}],894:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,T;switch(function(t,e){var r,i;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(a(c)){for(i=0;i<Math.min(c.length,s.length);i++)o=h(c[i],0,u),n(o)?(s[i].b=+o,s[i].hasB=1):s[i].b=0;for(;i<s.length;i++)s[i].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,i=0;i<s.length;i++)s[i].b=o,f&&(s[i].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?_.push(T):b.push(T);_.length&&function(t,e,r,n,a){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!a.norm});(function(t,e,r,n){for(var a=t._fullLayout,i=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=i.length!==o.length,f=s*(1-n.gap),m=l(a,e._id)+c[0][0].trace.orientation,v=a._alignmentOpts[m]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,T=v[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,M=(x=k?f/k:h?f/u:f)*(1-(n.groupgap||0));b=k?((2*w._offsetIndex+1-k)*x-M)/2:h?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=f,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,a),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r];if(void 0===n[0].trace.base)for(var a=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),o=0;o<n.length;o++){var s=n[o];if(s.p!==i){var l=a.put(s.p,s.b+s.s);l&&(s.b=l)}}}}(o),a.norm?(v(o),y(r,o,a)):m(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?_.push(T):b.push(T);_.length&&function(t,e,r,n,a){var o=new c(n,{sepNegVal:\"relative\"===a.mode,overlapNoMerge:!(a.norm||\"stack\"===a.mode||\"relative\"===a.mode)});f(e,o,a),function(t,e,r){var n,a,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(a=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==i&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],a=n[0].trace,o=\"funnel\"===a.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==i){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),m=g+d;u.b=g,u[h]=m,r.norm||(p.push(m),u.hasB&&p.push(g))}r.norm||(a._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,a);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==i)p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}a.norm&&y(r,o,a)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,a,i,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(i=t[r],a=0;a<i.length;a++){var u=i[a].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(i=t[r])[0].t.extents=s;var p=i[0].t.poffset,d=Array.isArray(p);for(a=0;a<i.length;a++){var g=i[a],m=g[o]-g.w/2;if(n(m)){var v=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(m,s[y][0]),Math.max(v,s[y][1])]:s[y]=[m,v]}g.p0=g.p+(d?p[a]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var a=0;a<r.length;a++){var i=r[a],o=new c([i],{unitMinDiff:n.xCat||n.yCat,sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(v(o),y(e,o,n)):m(e,o)}}function f(t,e,r){for(var n=e.minDiff,a=e.traces,i=n*(1-r.gap),o=i*(1-(r.groupgap||0)),s=-o/2,l=0;l<a.length;l++){var c=a[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=i,c.bardelta=n}e.binWidth=a[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,i=t.traces;for(e=0;e<i.length;e++){var o,s=i[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(a(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(a(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++)for(var i=r[a],o=i[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<i.length;h++){var f=i[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,a=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var i=0;i<n.length;i++){var o,l,c,u,h=n[i],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-a,c=o.p+a,d.push(l,c);if(p.width||p.offset){var g=f.t,m=g.poffset,v=g.barwidth,y=Array.isArray(m),x=Array.isArray(v);for(u=0;u<h.length;u++){o=h[u];var b=y?m[u]:m,_=x?v[u]:v;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function m(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++){for(var i=r[a],o=i[0].trace,l=[],c=!1,u=0;u<i.length;u++){var h=i[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b||(c=!0)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:c,padded:!0})}}function v(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],a=0;a<n.length;a++){var o=n[a];o.s!==i&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var a=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<a.length;p++){for(var d=a[p],g=d[0].trace,m=[],v=!1,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==i){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var T=_.b,k=T+_.s;_[o]=k,m.push(k),y=y||f(k),_.hasB&&(m.push(T),y=y||f(T)),_.hasB&&_.b||(v=!0)}}g._extremes[t._id]=s.findExtremes(t,m,{tozero:v,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,a=t._fullLayout,i=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<i.length;h++){var f=i[h];if(!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]),f._computePh))for(var p=t.calcdata[h],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var g={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:a.barmode,norm:a.barnorm,gap:a.bargap,groupgap:a.bargroupgap};u(t,r,n,c,g),u(t,n,r,l,g)},setGroupPositions:u}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/axis_ids\":801,\"../../registry\":881,\"./sieve.js\":904,\"fast-isnumeric\":241}],895:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./style_defaults\"),c=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,u=t(\"./attributes\"),h=n.coerceFont;function f(t,e,r,n){var a=e.orientation,i=e[{v:\"x\",h:\"y\"}[a]+\"axis\"],o=c(r,i)+a,s=r._alignmentOpts||{},l=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[l];h?h.traces.push(e):h=u[l]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function p(t,e,r,a,i,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,g=Array.isArray(i)||\"auto\"===i,m=g||\"inside\"===i,v=g||\"outside\"===i;if(m||v){var y=h(a,\"textfont\",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,h(a,\"insidetextfont\",x),d){var _=n.extendFlat({},y);b&&delete _.color,h(a,\"pathbar.textfont\",_)}v&&h(a,\"outsidetextfont\",y),s&&a(\"selected.textfont.color\"),l&&a(\"unselected.textfont.color\"),c&&a(\"constraintext\"),u&&a(\"cliponaxis\"),f&&a(\"textangle\"),a(\"texttemplate\")}m&&p&&a(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,c){function h(r,a){return n.coerce(t,e,u,r,a)}if(o(t,e,c,h)){s(t,e,c,h),h(\"orientation\",e.x&&!e.y?\"h\":\"v\"),h(\"base\"),h(\"offset\"),h(\"width\"),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\");var f=h(\"textposition\");p(t,e,c,h,f,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),l(t,e,h,r,c);var d=(e.marker.line||{}).color,g=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");g(t,e,d||a.defaultLine,{axis:\"y\"}),g(t,e,d||a.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function a(t){return n.coerce(r._input,r,u,t)}if(\"group\"===e.barmode)for(var i=0;i<t.length;i++)\"bar\"===(r=t[i]).type&&(r._input,f(0,r,e,a))},handleGroupingDefaults:f,handleText:p}},{\"../../components/color\":615,\"../../lib\":749,\"../../plots/cartesian/axis_ids\":801,\"../../registry\":881,\"../scatter/period_defaults\":1176,\"../scatter/xy_defaults\":1183,\"./attributes\":891,\"./style_defaults\":906}],896:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],897:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),i=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var a=t.min,i=t.max;if(!(void 0!==a&&e<a||void 0!==i&&e>i))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return a(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:i(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":749,\"fast-isnumeric\":241,tinycolor2:548}],898:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),a=t(\"../../registry\"),i=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth,l=t(\"../../plots/cartesian/axes\").hoverLabelText,c=t(\"../../constants/numerical\").BADNUM;function u(t,e,r,a){var i,s,u,h,f,p,d,g=t.cd,m=g[0].trace,v=g[0].t,y=\"closest\"===a,x=\"waterfall\"===m.type,b=t.maxHoverDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var T=y?_:function(t){return Math.min(_(t),t.p-v.bardelta/2)},k=y?w:function(t){return Math.max(w(t),t.p+v.bardelta/2)};function M(t,e){return n.inbox(t-i,e-i,b+Math.min(1,Math.abs(e-t)/d)-1)}function A(t){return M(T(t),k(t))}function S(t){var e=s,r=t.b,a=t[h];if(x){var i=Math.abs(t.rawS)||0;e>0?a+=i:e<0&&(a-=i)}return n.inbox(r-e,a-e,b+(a-e)/(a-r)-1)}\"h\"===m.orientation?(i=r,s=e,u=\"y\",h=\"x\",f=S,p=A):(i=e,s=r,u=\"x\",h=\"y\",p=S,f=A);var E=t[u+\"a\"],C=t[h+\"a\"];d=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var L=n.getDistanceFunction(a,f,p,(function(t){return(f(t)+p(t))/2}));if(n.getClosest(g,L,t),!1!==t.index&&g[t.index].p!==c){y||(T=function(t){return Math.min(_(t),t.p-v.bargroupwidth/2)},k=function(t){return Math.max(w(t),t.p+v.bargroupwidth/2)});var P=g[t.index],I=m.base?P.b+P.s:P.s;t[h+\"0\"]=t[h+\"1\"]=C.c2p(P[h],!0),t[h+\"LabelVal\"]=I;var z=v.extents[v.extents.round(P.p)];t[u+\"0\"]=E.c2p(y?T(P):z[0],!0),t[u+\"1\"]=E.c2p(y?k(P):z[1],!0);var O=void 0!==P.orig_p;return t[u+\"LabelVal\"]=O?P.orig_p:P.p,t.labelLabel=l(E,t[u+\"LabelVal\"]),t.valueLabel=l(C,t[h+\"LabelVal\"]),t.spikeDistance=(S(P)+function(t){return M(_(t),w(t))}(P))/2-b,t[u+\"Spike\"]=E.c2p(P.p,!0),o(P,m,t),t.hovertemplate=m.hovertemplate,t}}function h(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,a=s(t,e);return i.opacity(r)?r:i.opacity(n)&&a?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var i=u(t,e,r,n);if(i){var o=i.cd,s=o[0].trace,l=o[i.index];return i.color=h(s,l),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(l,s,i),[i]}},hoverOnBars:u,getTraceColor:h}},{\"../../components/color\":615,\"../../components/fx\":655,\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"./helpers\":897}],899:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},{\"../../plots/cartesian\":811,\"../scatter/marker_colorbar\":1174,\"./arrays_to_calcdata\":890,\"./attributes\":891,\"./calc\":892,\"./cross_trace_calc\":894,\"./defaults\":895,\"./event_data\":896,\"./hover\":898,\"./layout_attributes\":900,\"./layout_defaults\":901,\"./plot\":902,\"./select\":903,\"./style\":905}],900:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],901:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return i.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==a.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"./layout_attributes\":900}],902:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./uniform_text\"),f=h.recordMinTextSize,p=h.clearMinTextSize,d=t(\"./style\"),g=t(\"./helpers\"),m=t(\"./constants\"),v=t(\"./attributes\"),y=v.text,x=v.textposition,b=t(\"../../components/fx/helpers\").appendArrayPointValue,_=m.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t,e){return t<e?1:-1}function M(t,e,r,n){var a;return!e.uniformtext.mode&&A(r)?(n&&(a=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){a&&a()})).each(\"interrupt\",(function(){a&&a()}))):t}function A(t){return t&&t.duration>0}function S(t){return\"auto\"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),a=Math.abs(Math.cos(r));return{x:t.width*a+t.height*n,y:t.width*n+t.height*a}}function C(t,e,r,n,a,i){var o=!!i.isHorizontal,s=!!i.constrained,l=i.angle||0,c=i.anchor||\"end\",u=\"end\"===c,h=\"start\"===c,f=((i.leftToRight||0)+1)/2,p=1-f,d=a.width,g=a.height,m=Math.abs(e-t),v=Math.abs(n-r),y=m>2*_&&v>2*_?_:0;m-=2*y,v-=2*y;var x=S(l);\"auto\"!==l||d<=m&&g<=v||!(d>m||g>v)||(d>v||g>m)&&d<g==m<v||(x+=90);var b=E(a,x),w=1;s&&(w=Math.min(1,m/b.x,v/b.y));var T=a.left*p+a.right*f,M=(a.top+a.bottom)/2,A=(t+_)*p+(e-_)*f,C=(r+n)/2,L=0,P=0;if(h||u){var I=(o?b.x:b.y)/2,z=o?k(t,e):k(r,n);o?h?(A=t+z*y,L=-z*I):(A=e-z*y,L=z*I):h?(C=r+z*y,P=-z*I):(C=n-z*y,P=z*I)}return{textX:T,textY:M,targetX:A,targetY:C,anchorX:L,anchorY:P,scale:w,rotate:x}}e.exports={plot:function(t,e,r,h,m,v){var w=e.xaxis,L=e.yaxis,P=t._fullLayout;m||(m={mode:P.barmode,norm:P.barmode,gap:P.bargap,groupgap:P.bargroupgap},p(\"bar\",P));var I=i.makeTraceGroups(h,r,\"trace bars\").each((function(r){var c=n.select(this),h=r[0].trace,p=\"waterfall\"===h.type,I=\"funnel\"===h.type,z=\"bar\"===h.type||I,O=0;p&&h.connector.visible&&\"between\"===h.connector.mode&&(O=h.connector.line.width/2);var D=\"h\"===h.orientation,R=A(m),F=i.ensureSingle(c,\"g\",\"points\"),B=T(h),N=F.selectAll(\"g.point\").data(i.identity,B);N.enter().append(\"g\").classed(\"point\",!0),N.exit().remove(),N.each((function(c,p){var T,A,I=n.select(this),F=function(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),n?[a,i]:[i,a]}(c,w,L,D),B=F[0][0],N=F[0][1],j=F[1][0],U=F[1][1],V=0==(D?N-B:U-j);if(V&&z&&g.getLineWidth(h,c)&&(V=!1),V||(V=!(a(B)&&a(N)&&a(j)&&a(U))),c.isBlank=V,V&&(D?N=B:U=j),O&&!V&&(D?(B-=k(B,N)*O,N+=k(B,N)*O):(j-=k(j,U)*O,U+=k(j,U)*O)),\"waterfall\"===h.type){if(!V){var q=h[c.dir].marker;T=q.line.width,A=q.color}}else T=g.getLineWidth(h,c),A=c.mc||h.marker.color;function H(t){var e=n.round(T/2%1,2);return 0===m.gap&&0===m.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||T>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,U,!D),U=G(U,j,!D)}var Y=M(i.ensureSingle(I,\"path\"),P,m,v);if(Y.style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",isNaN((N-B)*(U-j))?\"M0,0Z\":\"M\"+B+\",\"+j+\"V\"+U+\"H\"+N+\"V\"+j+\"Z\").call(l.setClipUrl,e.layerClipId,t),!P.uniformtext.mode&&R){var W=l.makePointStyleFns(h);l.singlePointStyle(c,Y,h,W,t)}!function(t,e,r,n,a,s,c,h,p,m,v){var w,T=e.xaxis,A=e.yaxis,L=t._fullLayout;function P(e,r,n){return i.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var I=n[0].trace,z=\"h\"===I.orientation,O=function(t,e,r,n,a){var o,s=e[0].trace;o=s.texttemplate?function(t,e,r,n,a){var o=e[0].trace,s=i.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,h,f,p=\"waterfall\"===o.type,d=\"funnel\"===o.type;\"h\"===o.orientation?(l=\"y\",c=a,h=\"x\",f=n):(l=\"x\",c=n,h=\"y\",f=a);function g(t){return u(f,+t,!0).text}var m=e[r],v={};v.label=m.p,v.labelLabel=v[l+\"Label\"]=(y=m.p,u(c,y,!0).text);var y;var x=i.castOption(o,m.i,\"text\");(0===x||x)&&(v.text=x);v.value=m.s,v.valueLabel=v[h+\"Label\"]=g(m.s);var _={};b(_,o,m.i),p&&(v.delta=+m.rawS||m.s,v.deltaLabel=g(v.delta),v.final=m.v,v.finalLabel=g(v.final),v.initial=v.final-v.delta,v.initialLabel=g(v.initial));d&&(v.value=m.s,v.valueLabel=g(v.value),v.percentInitial=m.begR,v.percentInitialLabel=i.formatPercent(m.begR),v.percentPrevious=m.difR,v.percentPreviousLabel=i.formatPercent(m.difR),v.percentTotal=m.sumR,v.percenTotalLabel=i.formatPercent(m.sumR));var w=i.castOption(o,m.i,\"customdata\");w&&(v.customdata=w);return i.texttemplateString(s,v,t._d3locale,_,v,o._meta||{})}(t,e,r,n,a):s.textinfo?function(t,e,r,n){var a=t[0].trace,o=\"h\"===a.orientation,s=\"waterfall\"===a.type,l=\"funnel\"===a.type;function c(t){return u(o?r:n,+t,!0).text}var h,f=a.textinfo,p=t[e],d=f.split(\"+\"),g=[],m=function(t){return-1!==d.indexOf(t)};m(\"label\")&&g.push((v=t[e].p,u(o?n:r,v,!0).text));var v;m(\"text\")&&(0===(h=i.castOption(a,p.i,\"text\"))||h)&&g.push(h);if(s){var y=+p.rawS||p.s,x=p.v,b=x-y;m(\"initial\")&&g.push(c(b)),m(\"delta\")&&g.push(c(y)),m(\"final\")&&g.push(c(x))}if(l){m(\"value\")&&g.push(c(p.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=i.formatPercent(p.begR),w&&(h+=\" of initial\"),g.push(h)),m(\"percent previous\")&&(h=i.formatPercent(p.difR),w&&(h+=\" of previous\"),g.push(h)),m(\"percent total\")&&(h=i.formatPercent(p.sumR),w&&(h+=\" of total\"),g.push(h))}return g.join(\"<br>\")}(e,r,n,a):g.getValue(s.text,r);return g.coerceString(y,o)}(L,n,a,T,A);w=function(t,e){var r=g.getValue(t.textposition,e);return g.coerceEnumerated(x,r)}(I,a);var D=\"stack\"===m.mode||\"relative\"===m.mode,R=n[a],F=!D||R._outmost;if(!O||\"none\"===w||(R.isBlank||s===c||h===p)&&(\"auto\"===w||\"inside\"===w))return void r.select(\"text\").remove();var B=L.font,N=d.getBarColor(n[a],I),j=d.getInsideTextFont(I,a,B,N),U=d.getOutsideTextFont(I,a,B),V=r.datum();z?\"log\"===T.type&&V.s0<=0&&(s=T.range[0]<T.range[1]?0:T._length):\"log\"===A.type&&V.s0<=0&&(h=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,Z=Math.abs(c-s)-2*_,X=Math.abs(p-h)-2*_;\"outside\"===w&&(F||R.hasB||(w=\"inside\"));if(\"auto\"===w)if(F){w=\"inside\",W=i.ensureUniformFontSize(t,j),q=P(r,O,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G<=Z&&Y<=X,K=G<=X&&Y<=Z,Q=z?Z>=G*(X/Y):X>=Y*(Z/G);G>0&&Y>0&&(J||K||Q)?w=\"inside\":(w=\"outside\",q.remove(),q=null)}else w=\"inside\";if(!q){W=i.ensureUniformFontSize(t,\"outside\"===w?U:j);var $=(q=P(r,O,W)).attr(\"transform\");if(q.attr(\"transform\",\"\"),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr(\"transform\",$),G<=0||Y<=0)return void q.remove()}var tt,et,rt=I.textangle;\"outside\"===w?(et=\"both\"===I.constraintext||\"outside\"===I.constraintext,tt=function(t,e,r,n,a,i){var o,s=!!i.isHorizontal,l=!!i.constrained,c=i.angle||0,u=a.width,h=a.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:f>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=S(c),m=E(a,g),v=(s?m.x:m.y)/2,y=(a.left+a.right)/2,x=(a.top+a.bottom)/2,b=(t+e)/2,w=(r+n)/2,T=0,M=0,A=s?k(e,t):k(r,n);s?(b=e-A*o,T=A*v):(w=n+A*o,M=-A*v);return{textX:y,textY:x,targetX:b,targetY:w,anchorX:T,anchorY:M,scale:d,rotate:g}}(s,c,h,p,H,{isHorizontal:z,constrained:et,angle:rt})):(et=\"both\"===I.constraintext||\"inside\"===I.constraintext,tt=C(s,c,h,p,H,{isHorizontal:z,constrained:et,angle:rt,anchor:I.insidetextanchor}));tt.fontSize=W.size,f(I.type,tt,L),R.transform=tt,M(q,L,m,v).attr(\"transform\",i.getTextTransform(tt))}(t,e,I,r,p,B,N,j,U,m,v),e.layerClipId&&l.hideOutsideRangePoint(c,I.select(\"text\"),w,L,h.xcalendar,h.ycalendar)}));var j=!1===h.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,I,e,m)},toMoveInsideBar:C}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../components/fx/helpers\":651,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"./attributes\":891,\"./constants\":893,\"./helpers\":897,\"./style\":905,\"./uniform_text\":907,d3:169,\"fast-isnumeric\":241}],903:[function(t,e,r){\"use strict\";function n(t,e,r,n,a){var i=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return a?[(i+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(i+o)/2,l]}e.exports=function(t,e){var r,a=t.cd,i=t.xaxis,o=t.yaxis,s=a[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<a.length;r++)a[r].selected=0;else for(r=0;r<a.length;r++){var h=a[r],f=\"ct\"in h?h.ct:n(h,i,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:i.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],904:[function(t,e,r){\"use strict\";e.exports=i;var n=t(\"../../lib\").distinctVals,a=t(\"../../constants/numerical\").BADNUM;function i(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,i=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==a&&i.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=i;var u=n(i,{unitMinDiff:e.unitMinDiff});this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}i.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},i.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},i.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":724,\"../../lib\":749}],905:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/color\"),i=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./uniform_text\").resizeText,c=t(\"./attributes\"),u=c.textfont,h=c.insidetextfont,f=c.outsidetextfont,p=t(\"./helpers\");function d(t,e,r){i.pointStyle(t.selectAll(\"path\"),e,r),g(t,e,r)}function g(t,e,r){t.selectAll(\"text\").each((function(t){var a=n.select(this),s=o.ensureUniformFontSize(r,m(a,t,e,r));i.font(a,s)}))}function m(t,e,r,n){var a=n._fullLayout.font,i=r.textfont;if(t.classed(\"bartext-inside\")){var o=_(e,r);i=y(r,e.i,a,o)}else t.classed(\"bartext-outside\")&&(i=x(r,e.i,a));return i}function v(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var i=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(i={color:a.contrast(n),family:i.family,size:i.size}),b(h,t.insidetextfont,e,i)}function x(t,e,r){var n=v(t,e,r);return b(f,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var a=p.getValue(e.family,r),i=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,a,n.family),size:p.coerceNumber(t.size,i,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),a=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===a.barmode&&r>1||0===a.bargap&&0===a.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:g,styleOnSelect:function(t,e,r){var a=e[0].trace;a.selectedpoints?function(t,e,r){i.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var a,s=n.select(this);if(t.selected){a=o.ensureUniformFontSize(r,m(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(a.color=l),i.font(s,a)}else i.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,a,t):(d(r,a,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../lib\":749,\"../../registry\":881,\"./attributes\":891,\"./helpers\":897,\"./uniform_text\":907,d3:169}],906:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),a(t,\"marker\")&&i(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),a(t,\"marker.line\")&&i(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":615,\"../../components/colorscale/defaults\":625,\"../../components/colorscale/helpers\":626}],907:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\");function i(t){return\"_\"+t+\"Text_minsize\"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=i(t),a=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<a,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,a)))}},clearMinTextSize:function(t,e){e[i(t)]=void 0},resizeText:function(t,e,r){var i=t._fullLayout,o=i[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===i.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select(\"text\").attr(\"transform\",a.getTextTransform(e)))}))}}}},{\"../../lib\":749,d3:169}],908:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../lib/extend\").extendFlat,i=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:i.r,theta:i.theta,r0:i.r0,dr:i.dr,theta0:i.theta0,dtheta:i.dtheta,thetaunit:i.thetaunit,base:a({},o.base,{}),offset:a({},o.offset,{}),width:a({},o.width,{}),text:a({},o.text,{}),hovertext:a({},o.hovertext,{}),marker:o.marker,hoverinfo:i.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":739,\"../../plots/template_attributes\":876,\"../bar/attributes\":891,\"../scatterpolar/attributes\":1230}],909:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),i=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,m=0;m<f;m++)p[m]={p:g[m],s:d[m]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),i(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,a=[],i=0;i<n.length;i++){var s=n[i],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&a.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,a,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":623,\"../../components/colorscale/helpers\":626,\"../../lib\":749,\"../../registry\":881,\"../bar/arrays_to_calcdata\":890,\"../bar/cross_trace_calc\":894,\"../scatter/calc_selection\":1158}],910:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,i=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}a(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),i(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":749,\"../bar/style_defaults\":906,\"../scatterpolar/defaults\":1232,\"./attributes\":908}],911:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),a=t(\"../../lib\"),i=t(\"../bar/hover\").getTraceColor,o=a.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:a.isPtInsideSector,m=t.maxHoverDistance,v=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,(function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?m+Math.min(1,Math.abs(t.thetag1-t.thetag0)/v)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=a.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=i(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":655,\"../../lib\":749,\"../../plots/polar/helpers\":863,\"../bar/hover\":898,\"../scatterpolar/hover\":1234}],912:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"../scatterpolar/format_labels\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":864,\"../bar/select\":903,\"../bar/style\":905,\"../scatter/marker_colorbar\":1174,\"../scatterpolar/format_labels\":1233,\"./attributes\":908,\"./calc\":909,\"./defaults\":910,\"./hover\":911,\"./layout_attributes\":913,\"./layout_defaults\":914,\"./plot\":915}],913:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],914:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e,r){var i,o={};function s(r,o){return n.coerce(t[i]||{},e[i],a,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[i=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[i]=1))}}},{\"../../lib\":749,\"./layout_attributes\":913}],915:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"fast-isnumeric\"),i=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,a,o,l){var c,u;i.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,a,c,u,h,e,r)};return function(t,n,a,o){return i.pathAnnulus(t,n,a,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");i.makeTraceGroups(p,r,\"trace bars\").each((function(){var r=n.select(this),s=i.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(i.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(a(o)&&a(s)&&a(p)&&a(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),m=(p+d)/2;t.ct=[l.c2p(g*Math.cos(m)),c.c2p(g*Math.sin(m))],e=f(o,s,p,d)}else e=\"M0,0Z\";i.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../plots/polar/helpers\":863,d3:169,\"fast-isnumeric\":241}],916:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),a=t(\"../bar/attributes\"),i=t(\"../../components/color/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:i.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},offsetgroup:a.offsetgroup,alignmentgroup:a.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":614,\"../../lib/extend\":739,\"../../plots/template_attributes\":876,\"../bar/attributes\":891,\"../scatter/attributes\":1156}],917:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),o=t(\"../../lib\"),s=t(\"../../constants/numerical\").BADNUM,l=o._;e.exports=function(t,e){var r,c,y,x,b,_,w,T=t._fullLayout,k=a.getFromId(t,e.xaxis||\"x\"),M=a.getFromId(t,e.yaxis||\"y\"),A=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(y=k,x=\"x\",b=M,_=\"y\",w=!!e.yperiodalignment):(y=M,x=\"y\",b=k,_=\"x\",w=!!e.xperiodalignment);var E,C,L,P,I,z,O=function(t,e,r,a){var s,l=e+\"0\"in t,c=\"d\"+e in t;if(e in t||l&&c){var u=r.makeCalcdata(t,e);return[i(t,r,e,u),u]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:a;for(var h=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),f=t._length,p=new Array(f),d=0;d<f;d++)p[d]=h;return[p]}(e,_,b,T[S]),D=O[0],R=O[1],F=o.distinctVals(D),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return y.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[_]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),C=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(z=y.d2c(U[r][c]))!==s&&(u(I={v:z,i:[r,c]},e,[r,c]),C.push(I));if(E.pts=C.sort(h),P=(L=E[x]=C.map(f)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Y=V(\"lowerfence\");E.lf=Y!==s&&Y<=E.q1?Y:p(E,L,P);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,L,P);var Z=V(\"mean\");E.mean=Z!==s?Z:P?o.mean(L,P):(E.q1+E.q3)/2;var X=V(\"sd\");E.sd=Z!==s&&X>=0?X:P?o.stdev(L,P,E.mean):E.q3-E.q1,E.lo=g(E),E.uo=m(E);var J=V(\"notchspan\");J=J!==s&&J>0?J:v(E,P),E.ln=E.med-J,E.un=E.med+J;var K=E.lf,Q=E.uf;e.boxpoints&&L.length&&(K=Math.min(K,L[0]),Q=Math.max(Q,L[P-1])),e.notched&&(K=Math.min(K,E.ln),Q=Math.max(Q,E.un)),E.min=K,E.max=Q}else{var $;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),$=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=$,E.q1=E.q3=$,E.lf=E.uf=$,E.mean=E.sd=$,E.ln=E.un=$,E.min=E.max=$}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=C.filter(j),A.push(E)}}e._extremes[y._id]=a.findExtremes(y,[q,H],{padded:!0})}else{var tt=y.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),a=0;a<r;a++)n[a]=t[a]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(z=tt[r],n(z)){var at=o.findBin(D[r],et);at>=0&&at<rt&&(u(I={v:z,i:r},e,r),nt[at].push(I))}var it=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ht;if((E={}).pos=E[_]=B[r],C=E.pts=nt[r].sort(h),P=(L=E[x]=C.map(f)).length,E.min=L[0],E.max=L[P-1],E.mean=o.mean(L,P),E.sd=o.stdev(L,P,E.mean),E.med=o.interp(L,.5),P%2&&(lt||ct))lt?(ut=L.slice(0,P/2),ht=L.slice(P/2+1)):ct&&(ut=L.slice(0,P/2+1),ht=L.slice(P/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ht,.5);else E.q1=o.interp(L,.25),E.q3=o.interp(L,.75);E.lf=p(E,L,P),E.uf=d(E,L,P),E.lo=g(E),E.uo=m(E);var ft=v(E,P);E.ln=E.med-ft,E.un=E.med+ft,it=Math.min(it,E.ln),ot=Math.max(ot,E.un),E.pts2=C.filter(j),A.push(E)}e._extremes[y._id]=a.findExtremes(y,e.notched?tt.concat([it,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},i=0;i<n.length;i++)a[n[i].i]=i;o.tagSelected(n,e,a)}}(A,e),A.length>0?(A[0].t={num:T[S],dPos:N,posLetter:_,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean?l(t,\"mean \\xb1 \\u03c3:\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,A):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function h(t,e){return t.v-e.v}function f(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function g(t){return 4*t.q1-3*t.q3}function m(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"fast-isnumeric\":241}],918:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var m=a.distinctVals(d,{unitMinDiff:\"category\"===o.type||\"multicategory\"===o.type}),v=m.minDiff/2;n.minDtick(o,m.minDiff,m.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,M,A,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=T=M=L/2,k=0;else if(w=v,x){var I=i(h,o._id)+E.orientation,z=(h._alignmentOpts[I]||{})[E.alignmentgroup]||{},O=Object.keys(z.offsetGroups||{}).length,D=O||y;T=w*b*_/D,k=2*w*(((O?E._offsetIndex:C.num)+.5)/D-.5)*b,M=w*b/D}else T=w*b*_,k=0,M=w;C.dPos=w,C.bPos=k,C.bdPos=T,C.wHover=M;var R,F,B,N,j,U,V=k+T,q=Boolean(L);if(\"positive\"===P?(A=w*(L?1:.5),R=V,S=R=k):\"negative\"===P?(A=R=k,S=w*(L?1:.5),F=V):(A=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var Z=0;H-G<=0&&((Z=-V*(H-G))>S?(q=!0,U=Y,N=Z):Z>F&&(U=Y,N=S)),Z<=S&&(N=S)}else B=A,N=S;var X=new Array(c.length);for(l=0;l<c.length;l++)X[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,X,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,a=e.yaxis,i=0;i<o.length;i++){for(var l=o[i],c=\"h\"===l?a:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==a._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/axis_ids\":801}],919:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\"),i=t(\"../../components/color\"),o=t(\"../scatter/period_defaults\"),s=t(\"../bar/defaults\").handleGroupingDefaults,l=t(\"../../plots/cartesian/axis_autotype\"),c=t(\"./attributes\");function u(t,e,r,i){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,h=r(\"y\"),f=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),g=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&g&&g.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(g))}var m,v,y=o(h),x=o(f),b=y&&n.minRowLength(h),_=x&&n.minRowLength(f);if(e._hasPreCompStats)switch(String(x)+String(y)){case\"00\":var w=s(\"x0\")||s(\"dx\");m=(s(\"y0\")||s(\"dy\"))&&!w?\"h\":\"v\",v=u;break;case\"10\":m=\"v\",v=Math.min(u,_);break;case\"20\":m=\"h\",v=Math.min(u,f.length);break;case\"01\":m=\"h\",v=Math.min(u,b);break;case\"02\":m=\"v\",v=Math.min(u,h.length);break;case\"12\":m=\"v\",v=Math.min(u,_,h.length);break;case\"21\":m=\"h\",v=Math.min(u,f.length,b);break;case\"11\":v=0;break;case\"22\":var T,k=!1;for(T=0;T<f.length;T++)if(\"category\"===l(f[T])){k=!0;break}if(k)m=\"v\",v=Math.min(u,_,h.length);else{for(T=0;T<h.length;T++)if(\"category\"===l(h[T])){k=!0;break}k?(m=\"h\",v=Math.min(u,f.length,b)):(m=\"v\",v=Math.min(u,_,h.length))}}else y>0?(m=\"v\",v=x>0?Math.min(_,b):Math.min(b)):x>0?(m=\"h\",v=Math.min(_)):v=0;if(v){e._length=v;var M=r(\"orientation\",m);e._hasPreCompStats?\"v\"===M&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===M&&0===y&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===M&&0===x?r(\"x0\"):\"h\"===M&&0===y&&r(\"y0\"),a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],i)}else e.visible=!1}function h(t,e,r,a){var i=a.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(i+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var h=r(\"hoveron\");\"all\"!==h&&-1===h.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,a){function s(r,a){return n.coerce(t,e,c,r,a)}if(u(t,e,s,a),!1!==e.visible){o(t,e,a,s);var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",i.addOpacity(e.line.color,.5));var f=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(f=!0,d&&d.length&&(f=\"sd\"))}s(\"boxmean\",f),s(\"whiskerwidth\"),s(\"width\"),s(\"quartilemethod\");var g=!1;if(l){var m=s(\"notchspan\");m&&m.length&&(g=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(g=!0);s(\"notched\",g)&&s(\"notchwidth\"),h(t,e,s,{prefix:\"box\"})}},crossTraceDefaults:function(t,e){var r,a;function i(t){return n.coerce(a._input,a,c,t)}for(var o=0;o<t.length;o++){var l=(a=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=a._input,\"group\"===e[l+\"mode\"]&&s(r,a,e,i))}},handleSampleDefaults:u,handlePointsDefaults:h}},{\"../../components/color\":615,\"../../lib\":749,\"../../plots/cartesian/axis_autotype\":799,\"../../registry\":881,\"../bar/defaults\":895,\"../scatter/period_defaults\":1176,\"./attributes\":916}],920:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],921:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),i=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=a.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,m,v,y,x,b,_,w=t.cd,T=t.xa,k=t.ya,M=w[0].trace,A=w[0].t,S=\"violin\"===M.type,E=[],C=A.bdPos,L=A.wHover,P=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&\"both\"!==M.side?(\"positive\"===M.side&&(m=function(t){var e=P(t);return i.inbox(e,e+L,v)},x=C,b=0),\"negative\"===M.side&&(m=function(t){var e=P(t);return i.inbox(e-L,e,v)},x=0,b=C)):(m=function(t){var e=P(t);return i.inbox(e-L,e+L,v)},x=b=C),_=S?function(t){return i.inbox(t.span[0]-f,t.span[1]-f,v)}:function(t){return i.inbox(t.min-f,t.max-f,v)},\"h\"===M.orientation?(f=e,p=r,d=_,g=m,l=\"y\",u=k,c=\"x\",h=T):(f=r,p=e,d=m,g=_,l=\"x\",u=T,c=\"y\",h=k);var I=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}v=t.maxHoverDistance-I,y=t.maxSpikeDistance-I;var O=i.getDistanceFunction(s,d,g,z);if(i.getClosest(w,O,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+\"0\"]=u.c2p(D.pos+A.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+A.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==D.orig_p?D.orig_p:D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/v,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(M.boxmean||(M.meanline||{}).visible)&&j.push(\"mean\"),(M.boxpoints||M.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=a.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(A.labels?A.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===M.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=i.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)})),m=!1,v=0;v<c.length;v++){o=c[v];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,m=[v,y])}}if(!m)return!1;l=(o=c[m[0]]).pts[m[1]];var b=u.c2p(l.x,!0),_=h.c2p(l.y,!0),w=l.mrc||1;n=a.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:b-w,x1:b+w,y0:_-w,y1:_+w,spikeDistance:t.distance,hovertemplate:f.hovertemplate});var T,k=o.orig_p,M=void 0!==k?k:o.pos;return\"h\"===f.orientation?(T=h,n.xLabelVal=l.x,n.yLabelVal=M):(T=u,n.xLabelVal=M,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var a,i=t.cd[0].trace.hoveron,o=[];return-1!==i.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==i.indexOf(\"points\")&&(a=c(t,e,r)),\"closest\"===n?a?[a]:o:a?(o.push(a),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":615,\"../../components/fx\":655,\"../../lib\":749,\"../../plots/cartesian/axes\":798}],922:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":811,\"./attributes\":916,\"./calc\":917,\"./cross_trace_calc\":918,\"./defaults\":919,\"./event_data\":920,\"./hover\":921,\"./layout_attributes\":923,\"./layout_defaults\":924,\"./plot\":925,\"./select\":926,\"./style\":927}],923:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],924:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"./layout_attributes\");function o(t,e,r,a,i){for(var o=i+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(a(i+\"mode\"),a(i+\"gap\"),a(i+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return a.coerce(t,e,i,r,n)}),\"box\")},_supply:o}},{\"../../lib\":749,\"../../registry\":881,\"./layout_attributes\":923}],925:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\");function o(t,e,r,i){var o,s,l=\"h\"===r.orientation,c=e.val,u=e.pos,h=!!u.rangebreaks,f=i.bPos,p=i.wdPos||0,d=i.bPosPxOffset||0,g=r.whiskerwidth||0,m=r.notched||!1,v=m?1-2*r.notchwidth:1;Array.isArray(i.bdPos)?(o=i.bdPos[0],s=i.bdPos[1]):(o=i.bdPos,s=i.bdPos);var y=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?a.identity:[]);y.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),y.exit().remove(),y.each((function(t){if(t.empty)return\"M0,0Z\";var e=u.c2l(t.pos+f,!0),i=u.l2p(e-o)+d,y=u.l2p(e+s)+d,x=h?(i+y)/2:u.l2p(e)+d,b=r.whiskerwidth,_=h?i*b+(1-b)*x:u.l2p(e-p)+d,w=h?y*b+(1-b)*x:u.l2p(e+p)+d,T=u.l2p(e-o*v)+d,k=u.l2p(e+s*v)+d,M=c.c2p(t.q1,!0),A=c.c2p(t.q3,!0),S=a.constrain(c.c2p(t.med,!0),Math.min(M,A)+1,Math.max(M,A)-1),E=void 0===t.lf||!1===r.boxpoints,C=c.c2p(E?t.min:t.lf,!0),L=c.c2p(E?t.max:t.uf,!0),P=c.c2p(t.ln,!0),I=c.c2p(t.un,!0);l?n.select(this).attr(\"d\",\"M\"+S+\",\"+T+\"V\"+k+\"M\"+M+\",\"+i+\"V\"+y+(m?\"H\"+P+\"L\"+S+\",\"+k+\"L\"+I+\",\"+y:\"\")+\"H\"+A+\"V\"+i+(m?\"H\"+I+\"L\"+S+\",\"+T+\"L\"+P+\",\"+i:\"\")+\"ZM\"+M+\",\"+x+\"H\"+C+\"M\"+A+\",\"+x+\"H\"+L+(0===g?\"\":\"M\"+C+\",\"+_+\"V\"+w+\"M\"+L+\",\"+_+\"V\"+w)):n.select(this).attr(\"d\",\"M\"+T+\",\"+S+\"H\"+k+\"M\"+i+\",\"+M+\"H\"+y+(m?\"V\"+P+\"L\"+k+\",\"+S+\"L\"+y+\",\"+I:\"\")+\"V\"+A+\"H\"+i+(m?\"V\"+I+\"L\"+T+\",\"+S+\"L\"+i+\",\"+P:\"\")+\"ZM\"+x+\",\"+M+\"V\"+C+\"M\"+x+\",\"+A+\"V\"+L+(0===g?\"\":\"M\"+_+\",\"+C+\"H\"+w+\"M\"+_+\",\"+L+\"H\"+w))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;a.seedPseudoRandom();var h=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);h.enter().append(\"g\").attr(\"class\",\"points\"),h.exit().remove();var f=h.selectAll(\"path\").data((function(t){var e,n,i=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,h=.01*o,f=[],p=0;if(r.jitter){if(0===o)for(p=1,f=new Array(i.length),e=0;e<i.length;e++)f[e]=1;else for(e=0;e<i.length;e++){var d=Math.max(0,e-5),g=i[d].v,m=Math.min(i.length-1,e+5),v=i[m].v;\"all\"!==u&&(i[e].v<t.lf?v=Math.min(v,t.lf):g=Math.max(g,t.uf));var y=Math.sqrt(h*(m-d)/(v-g+s))||0;y=a.constrain(Math.abs(y),0,1),f.push(y),p=Math.max(y,p)}n=2*r.jitter/(p||1)}for(e=0;e<i.length;e++){var x=i[e],b=x.v,_=r.jitter?n*f[e]*(a.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+_);\"h\"===r.orientation?(x.y=w,x.x=b):(x.x=w,x.y=b),\"suspectedoutliers\"===u&&b<t.uo&&b>t.lo&&(x.so=!0)}return i}));f.enter().append(\"path\").classed(\"point\",!0),f.exit().remove(),f.call(i.translatePoints,o,s)}function l(t,e,r,i){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,h=i.bPos,f=i.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(i.bdPos)?(o=i.bdPos[0],s=i.bdPos[1]):(o=i.bdPos,s=i.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?a.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+h,!0),a=c.l2p(e-o)+f,i=c.l2p(e+s)+f,d=u?(a+i)/2:c.l2p(e)+f,g=l.c2p(t.mean,!0),m=l.c2p(t.mean-t.sd,!0),v=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+g+\",\"+a+\"V\"+i+(\"sd\"===p?\"m0,0L\"+m+\",\"+d+\"L\"+g+\",\"+a+\"L\"+v+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+a+\",\"+g+\"H\"+i+(\"sd\"===p?\"m0,0L\"+d+\",\"+m+\"L\"+a+\",\"+g+\"L\"+d+\",\"+v+\"Z\":\"\"))}))}e.exports={plot:function(t,e,r,i){var c=e.xaxis,u=e.yaxis;a.makeTraceGroups(i,r,\"trace boxes\").each((function(t){var e,r,a=n.select(this),i=t[0],h=i.t,f=i.trace;(h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty)?a.remove():(\"h\"===f.orientation?(e=u,r=c):(e=c,r=u),o(a,{pos:e,val:r},f,h),s(a,{x:c,y:u},f,h),l(a,{pos:e,val:r},f,h))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},{\"../../components/drawing\":637,\"../../lib\":749,d3:169}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,a=t.cd,i=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<a.length;r++)for(n=0;n<(a[r].pts||[]).length;n++)a[r].pts[n].selected=0;else for(r=0;r<a.length;r++)for(n=0;n<(a[r].pts||[]).length;n++){var l=a[r].pts[n],c=i.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:i.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/color\"),i=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(a.stroke,r).call(a.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(a.stroke,o.line.color);var u=r.selectAll(\"path.point\");i.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,a=r.selectAll(\"path.point\");n.selectedpoints?i.selectedPointStyle(a,n):i.pointStyle(a,n,t)}}},{\"../../components/color\":615,\"../../components/drawing\":637,d3:169}],928:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,a=t(\"../ohlc/attributes\"),i=t(\"../box/attributes\");function o(t){return{line:{color:n({},i.line.color,{dflt:t}),width:i.line.width,editType:\"style\"},fillcolor:i.fillcolor,editType:\"style\"}}e.exports={xperiod:a.xperiod,xperiod0:a.xperiod0,xperiodalignment:a.xperiodalignment,x:a.x,open:a.open,high:a.high,low:a.low,close:a.close,line:{width:n({},i.line.width,{}),editType:\"style\"},increasing:o(a.increasing.line.color.dflt),decreasing:o(a.decreasing.line.color.dflt),text:a.text,hovertext:a.hovertext,whiskerwidth:n({},i.whiskerwidth,{dflt:0}),hoverlabel:a.hoverlabel}},{\"../../lib\":749,\"../box/attributes\":916,\"../ohlc/attributes\":1102}],929:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),o=t(\"../ohlc/calc\").calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,l=a.getFromId(t,e.xaxis),c=a.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),h=i(e,l,\"x\",u),f=o(t,e,u,h,c,s);return f.length?(n.extendFlat(f[0].t,{num:r._numBoxes,dPos:n.distinctVals(h).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,f):[{t:{empty:!0}}]}},{\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"../ohlc/calc\":1103}],930:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../ohlc/ohlc_defaults\"),o=t(\"../scatter/period_defaults\"),s=t(\"./attributes\");function l(t,e,r,n){var i=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",a.addOpacity(i,.5))}e.exports=function(t,e,r,a){function c(r,a){return n.coerce(t,e,s,r,a)}i(t,e,c,a)?(o(t,e,a,c,{x:!0}),c(\"line.width\"),l(t,e,c,\"increasing\"),l(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),a._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":615,\"../../lib\":749,\"../ohlc/ohlc_defaults\":1107,\"../scatter/period_defaults\":1176,\"./attributes\":928}],931:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":811,\"../box/cross_trace_calc\":918,\"../box/layout_attributes\":923,\"../box/layout_defaults\":924,\"../box/plot\":925,\"../box/style\":927,\"../ohlc/hover\":1105,\"../ohlc/select\":1109,\"./attributes\":928,\"./calc\":929,\"./defaults\":930}],932:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),a=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,i,o){i(\"a\")||(i(\"da\"),i(\"a0\")),i(\"b\")||(i(\"db\"),i(\"b0\")),function(t,e,r,i){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=a.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:i,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},{\"../../plot_api/plot_template\":787,\"./axis_defaults\":937}],933:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;for(var a=1/0,i=-1/0,o=e.length,s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(a=Math.min(c[0],a),i=Math.max(c[1],i))}else a=Math.min(l,a),i=Math.max(l,i)}return[a,i]}(t,0)}},{\"../../lib\":749}],934:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"./axis_attributes\"),i=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=i.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:a,baxis:a,font:o,color:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":614,\"../../plots/font_attributes\":826,\"./axis_attributes\":936}],935:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var i,o,s,l,c,u,h,f,p,d,g,m,v,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:a,w=\"a\"===y?a:r,T=\"a\"===y?e.a.length:e.b.length,k=\"a\"===y?e.b.length:e.a.length,M=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),A=\"a\"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(k-2,M)),l=M-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,I=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,O=C>0?Math.max:Math.min,D=P(S+L),R=I(E-L),F=[[h=A(S)]];for(i=D;i*C<R*C;i+=C)c=[],g=O(S,i),v=(m=z(E,i+C))-g,u=Math.max(0,Math.min(T-2,Math.floor(.5*(g+m)))),f=A(m),x&&(p=o(u,g-u),d=o(u,m-u),c.push([h[0]+p[0]/3*v,h[1]+p[1]/3*v]),c.push([f[0]-d[0]/3*v,f[1]-d[1]/3*v])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":749}],936:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"../../components/color/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(i.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:a.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:a.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":614,\"../../constants/docs\":719,\"../../plot_api/edit_types\":780,\"../../plots/cartesian/layout_attributes\":812,\"../../plots/font_attributes\":826}],937:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),a=t(\"../../components/color\").addOpacity,i=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function m(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var v=g(\"type\");(\"-\"===v&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"minexponent\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===v)&&i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,v),l(t,e,g,v,r),c(t,e,g,{data:r.data,dataAttr:f});var b=m(\"gridcolor\",a(y,.3)),_=m(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var T=m(\"startlinecolor\",y),k=m(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!T||!!k)||(delete e.startlinecolor,delete e.startlinewidth);var M=m(\"endlinecolor\",y),A=m(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",a(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":615,\"../../lib\":749,\"../../plots/cartesian/axis_autotype\":799,\"../../plots/cartesian/category_order_defaults\":802,\"../../plots/cartesian/set_convert\":818,\"../../plots/cartesian/tick_label_defaults\":819,\"../../plots/cartesian/tick_value_defaults\":821,\"../../registry\":881,\"./attributes\":934}],938:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\").isArray1D,i=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,m=e.baxis,v=e.x,y=e.y,x=[];v&&a(v)&&x.push(\"x\"),y&&a(y)&&x.push(\"y\"),x.length&&f(e,g,m,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;v=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===g.cheatertype?b.length:b,k=\"index\"===m.cheatertype?_.length:_;v=i(T,k,e.cheaterslope)}e._x=v=u(v),e._y=y=u(y),h(v,b,_),h(y,b,_),p(e),e.setScale();var M=o(v),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),C=.5*(A[1]-A[0]),L=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,m),w.clipsegments=c(e._xctrl,e._yctrl,g,m),w.x=v,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../heatmap/clean_2d_array\":1037,\"../heatmap/convert_column_xyz\":1039,\"./array_minmax\":933,\"./calc_clippath\":939,\"./calc_gridlines\":940,\"./calc_labels\":941,\"./cheater_basis\":943,\"./set_convert\":956,\"./smooth_fill_2d_array\":957}],939:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a,i,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(a=0,i=[],o=[];a<=u;a++)i[a]=t[0][a],o[a]=e[0][a];for(s.push({x:i,y:o,bicubic:l}),a=0,i=[],o=[];a<=h;a++)i[a]=t[a][u],o[a]=e[a][u];for(s.push({x:i,y:o,bicubic:c}),a=u,i=[],o=[];a>=0;a--)i[u-a]=t[h][a],o[u-a]=e[h][a];for(s.push({x:i,y:o,bicubic:l}),a=h,i=[],o=[];a>=0;a--)i[h-a]=t[a][0],o[h-a]=e[a][0];return s.push({x:i,y:o,bicubic:c}),s}},{}],940:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var i,o,s,l,c,u,h,f,p,d,g,m,v,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],T=b._boundarylines=[],k=t[\"_\"+r],M=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,C=A.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var I=b.smoothing?3:1;function z(n){var a,i,o,s,l,c,u,h,p,d,g,m,v=[],y=[],x={};if(\"b\"===e)for(i=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,i))),s=i-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,i)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},a=0;a<L;a++)c=Math.min(L-2,a),u=a-c,h=t.evalxy([],a,i),M.smoothing&&a>0&&(p=t.dxydi([],a-1,o,0,s),v.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],a-1,o,1,s),v.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),v.push(h[0]),y.push(h[1]),l=h;else for(a=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,a))),u=a-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],a,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},i=0;i<P;i++)o=Math.min(P-2,i),s=i-o,h=t.evalxy([],a,i),M.smoothing&&i>0&&(g=t.dxydj([],c,i-1,u,0),v.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),m=t.dxydj([],c,i-1,u,1),v.push(h[0]-m[0]/3),y.push(h[1]-m[1]/3)),v.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=f,x.x=v,x.y=y,x.smoothing=M.smoothing,x}function O(n){var a,i,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},a=0;a<E;a++)c[a]=A[n*I][a],u[a]=S[n*I][a];else for(i=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-i)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],i,e,s,r)},a=0;a<C;a++)c[a]=A[a][n*I],u[a]=S[a][n*I];return h.axisLetter=e,h.axis=b,h.crossAxis=M,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=M.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(a(O(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(m=x[s],v=x[g],i=0;i<b.minorgridcount;i++)(y=g-s)<=0||(d=m+(v-m)*(i+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(a(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(a(O(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(a(O(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort((function(t,e){return t-e})))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(a(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,i=0;i<b.minorgridcount;i++)(d=p+b.dtick*(i+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(a(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(a(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(a(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":739,\"../../plots/cartesian/axes\":798}],941:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,i,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(i=n.tickText(e,o.value),a(i,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(i)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(i=n.tickText(e,o.value),a(i,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(i))}},{\"../../lib/extend\":739,\"../../plots/cartesian/axes\":798}],942:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=t[0]-e[0],i=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(a*a+i*i,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*a-l*l*o)*n,h=(c*c*i-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],943:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var a,i,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,m=-1/0;for(i=0;i<f;i++)for(u[i]=[],l=d?(d[i]-d[0])*s:i/(f-1),a=0;a<h;a++)c=(p?(p[a]-p[0])*o:a/(h-1))-l*r,g=Math.min(c,g),m=Math.max(c,m),u[i][a]=c;var v=1/(m-g),y=-g*v;for(i=0;i<f;i++)for(a=0;a<h;a++)u[i][a]=v*u[i][a]+y;return u}},{\"../../lib\":749}],944:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),a=t(\"../../lib\").ensureArray;function i(t,e,r){var n=-.5*r[0]+1.5*e[0],a=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*a+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,m,v,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=a(t,w),e=a(e,w),h=0;h<w;h++)t[h]=a(t[h],_),e[h]=a(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],m=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=m[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)v=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=v[0][0],e[f][h-1]=v[0][1],t[f][h+1]=v[1][0],e[f][h+1]=v[1][1];y=i([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=i([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)v=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=v[0][0],e[f-1][h]=v[0][1],t[f+1][h]=v[1][0],e[f+1][h]=v[1][1];y=i([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=i([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)v=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+v[0][0]),e[f][h-1]=.5*(e[f][h-1]+v[0][1]),t[f][h+1]=.5*(t[f][h+1]+v[1][0]),e[f][h+1]=.5*(e[f][h+1]+v[1][1]);y=i([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=i([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":749,\"./catmull_rom\":942}],945:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],946:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=a*a,p=1-a,d=p*p,g=p*a*2,m=-3*d,v=3*(d-g),y=3*(g-f),x=3*f,b=i*i,_=b*i,w=1-i,T=w*w,k=T*w;for(h=0;h<t.length;h++)o=m*(u=t[h])[n][r]+v*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=m*u[n+1][r]+v*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=m*u[n+2][r]+v*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=m*u[n+3][r]+v*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=k*o+3*(T*i*s+w*b*l)+_*c;return e}:e?function(e,r,n,a,i){var o,s,l,c;e||(e=[]),r*=3;var u=a*a,h=1-a,f=h*h,p=h*a*2,d=-3*f,g=3*(f-p),m=3*(p-u),v=3*u,y=1-i;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+m*c[n][r+2]+v*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+m*c[n+1][r+2]+v*c[n+1][r+3],e[l]=y*o+i*s;return e}:r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=m*o+3*(g*i*s+d*f*l)+p*c;return e}:function(e,r,n,a,i){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+i*s;return e}}},{}],947:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,m=g*d,v=i*i,y=1-i,x=y*y,b=y*i*2,_=-3*x,w=3*(x-b),T=3*(b-v),k=3*v;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[h]=m*o+3*(g*a*s+d*f*l)+p*c;return e}:e?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=i*i,p=f*i,d=1-i,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=m*o+3*(g*i*s+d*f*l)+p*c;return e}:r?function(e,r,n,a,i){var o,s,l,c;e||(e=[]),n*=3;var u=1-a,h=i*i,f=1-i,p=f*f,d=f*i*2,g=-3*p,m=3*(p-d),v=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+m*c[n+1][r]+v*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+m*c[n+1][r+1]+v*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+a*s;return e}:function(e,r,n,a,i){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+a*s;return e}}},{}],948:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){var i=e-2,o=r-2;return n&&a?function(e,r,n){var a,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,T=1-g,k=T*T,M=k*T;for(h=0;h<t.length;h++)a=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*m*u[p][f+2])+v*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*m*u[p+1][f+2])+v*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*m*u[p+2][f+2])+v*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*m*u[p+3][f+2])+v*u[p+3][f+3],e[h]=M*a+3*(k*g*s+T*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var a,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)a=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*a+3*(x*d*s+y*m*l)+v*c;return e}:a?function(e,r,n){e||(e=[]);var a,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var m=g*g,v=m*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)a=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*a+3*(x*g*s+y*m*l)+v*c;return e}:function(e,r,n){e||(e=[]);var a,s,l,c,u=Math.max(0,Math.min(Math.floor(r),i)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)a=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*a+p*s;return e}}},{}],949:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./xy_defaults\"),i=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,o,r,a)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),i(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),a(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":614,\"../../lib\":749,\"./ab_defaults\":932,\"./attributes\":934,\"./xy_defaults\":958}],950:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":811,\"./attributes\":934,\"./calc\":938,\"./defaults\":949,\"./plot\":955}],951:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,a=0;a<n;a++){var i=t._fullData[a];if(i.index!==e.index&&(\"carpet\"===i.type&&(r||(r=i),i.carpet===e.carpet)))return i}return r}},{}],952:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,a=[],i=r?3:1;for(n=0;n<t.length;n+=i)a.push(t[n]+\",\"+e[n]),r&&n<t.length-i&&(a.push(\"C\"),a.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return a.join(r?\"\":\"L\")}},{}],953:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var a;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],a=0;a<e.length;a++)t[a]=r(e[a]);return t}},{\"../../lib\":749}],954:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a,i){var o=a[0]*t.dpdx(e),s=a[1]*t.dpdy(r),l=1,c=1;if(i){var u=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=(a[0]*i[0]+a[1]*i[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],955:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,a,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each((function(r){var a=r,s=a.x,l=a.y,c=i([],s,t.c2p),u=i([],l,e.c2p),h=\"M\"+o(c,u,a.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",a.width).style(\"stroke\",a.color).style(\"fill\",\"none\")})),u.exit().remove()}function f(t,e,r,i,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each((function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(i,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(i,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(a.font,o.font).text(o.text).call(l.convertToTspans,t),m=a.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*m.height+\")\"),p=Math.max(p,m.width+o.axis.labelpadding)})),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,a){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(a,r,\"trace\").each((function(e){var r=n.select(this),a=e[0],d=a.trace,m=d.aaxis,v=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,m,\"a\",m._gridlines),h(l,u,x,v,\"b\",v._gridlines),h(l,u,y,m,\"a\",m._minorgridlines),h(l,u,y,v,\"b\",v._minorgridlines),h(l,u,b,m,\"a-boundary\",m._boundarylines),h(l,u,b,v,\"b-boundary\",v._boundarylines);var w=f(t,l,u,d,a,_,m._labels,\"a-label\"),T=f(t,l,u,d,a,_,v._labels,\"b-label\");!function(t,e,r,n,a,i,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),m=c.aggNums(Math.max,null,r.a),v=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+m),h=v,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,a,i,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,a,i,o,\"a-title\"),u=d,h=.5*(v+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,a,i,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,a,i,l,\"b-title\")}(t,_,d,a,l,u,w,T),function(t,e,r,n,a){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=i([],s.x,n.c2p),u=i([],s.y,a.c2p),g.push(o(l,u,s.bicubic));var m=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",m)}(d,a,p,l,u)}))};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,i,o,c,u,h,f,g,m){var v=[];u.title.text&&v.push(u.title.text);var y=e.selectAll(\"text.\"+m).data(v),x=g.maxExtent;y.enter().append(\"text\").classed(m,!0),y.each((function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var i=u.title.font.size;x+=i+u.title.offset;var m=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,v=m>90&&m<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),v&&(x=(-l.lineCount(y)+d)*p*i-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").attr(\"text-anchor\",\"middle\").call(a.font,u.title.font)})),y.exit().remove()}},{\"../../components/drawing\":637,\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"./makepath\":952,\"./map_1d_array\":953,\"./orient_text\":954,d3:169}],956:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"../../lib/search\").findBin,i=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],m=r[u-1],v=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=v*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,m+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<m},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>m},t.setScale=function(){var e=t._x,r=t._y,n=i(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(a(t,e),c-2)),n=e[r],i=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(i-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(a(t,r),u-2)),n=r[e],i=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(i-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,a,i){if(!i&&(n<e[0]||n>e[c-1]|a<r[0]||a>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(a),l=t.evalxy([],o,s);if(i){var h,f,p,d,g=0,m=0,v=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),a<r[0]?(p=0,d=0,m=(a-r[0])/(r[1]-r[0])):a>r[u-1]?(p=u-2,d=1,m=(a-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(v,h,p,f,d),l[0]+=v[0]*g,l[1]+=v[1]*g),m&&(t.dxydj(v,h,p,f,d),l[0]+=v[0]*m,l[1]+=v[1]*m)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,a){var i=t.dxydi(null,e,r,n,a),o=t.dadi(e,n);return[i[0]/o,i[1]/o]},t.dxydb=function(e,r,n,a){var i=t.dxydj(null,e,r,n,a),o=t.dbdj(r,a);return[i[0]/o,i[1]/o]},t.dxyda_rough=function(e,r,n){var a=v*(n||.1),i=t.ab2xy(e+a,r,!0),o=t.ab2xy(e-a,r,!0);return[.5*(i[0]-o[0])/a,.5*(i[1]-o[1])/a]},t.dxydb_rough=function(e,r,n){var a=y*(n||.1),i=t.ab2xy(e,r+a,!0),o=t.ab2xy(e,r-a,!0);return[.5*(i[0]-o[0])/a,.5*(i[1]-o[1])/a]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":768,\"./compute_control_points\":944,\"./constants\":945,\"./create_i_derivative_evaluator\":946,\"./create_j_derivative_evaluator\":947,\"./create_spline_evaluator\":948}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var a,i,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,a=0,i=0;return e>0&&void 0!==(n=t[r][e-1])&&(i++,a+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(i++,a+=n),r>0&&void 0!==(n=t[r-1][e])&&(i++,a+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(i++,a+=n),a/Math.max(1,i)}var f,p,d,g,m,v,y,x,b,_,w,T=0;for(a=0;a<c;a++)for(i=0;i<u;i++)void 0===t[i][a]&&(s.push(a),l.push(i),t[i][a]=h(a,i)),T=Math.max(T,Math.abs(t[i][a]));if(!s.length)return t;var k=0,M=0,A=s.length;do{for(k=0,o=0;o<A;o++){a=s[o],i=l[o];var S,E,C,L,P,I,z=0,O=0;0===a?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[i][P],O+=(E=t[i][1])+(E-S)*(e[0]-L)/(L-C),z++):a===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[i][P],O+=(E=t[i][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===a||a===c-1)&&i>0&&i<u-1&&(f=r[i+1]-r[i],O+=((p=r[i]-r[i-1])*t[i+1][a]+f*t[i-1][a])/(p+f),z++),0===i?(C=r[I=Math.min(u-1,2)],L=r[1],S=t[I][a],O+=(E=t[1][a])+(E-S)*(r[0]-L)/(L-C),z++):i===u-1&&(C=r[I=Math.max(0,u-3)],L=r[u-2],S=t[I][a],O+=(E=t[u-2][a])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===i||i===u-1)&&a>0&&a<c-1&&(f=e[a+1]-e[a],O+=((p=e[a]-e[a-1])*t[i][a+1]+f*t[i][a-1])/(p+f),z++),z?O/=z:(d=e[a+1]-e[a],g=e[a]-e[a-1],x=(m=r[i+1]-r[i])*(v=r[i]-r[i-1])*(m+v),O=((y=d*g*(d+g))*(v*t[i+1][a]+m*t[i-1][a])+x*(g*t[i][a+1]+d*t[i][a-1]))/(x*(g+d)+y*(v+m))),k+=(_=(b=O-t[i][a])/T)*_,w=z?0:.85,t[i][a]+=b*(1+w)}k=Math.sqrt(k)}while(M++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",M,\"iterations\"),t}},{\"../../lib\":749}],958:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var a=r(\"x\"),i=a&&a.length,o=r(\"y\"),s=o&&o.length;if(!i&&!s)return!1;if(e._cheater=!a,i&&!n(a)||s&&!n(o))e._length=null;else{var l=i?a.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":749}],959:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../scattergeo/attributes\"),i=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=a.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:a.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},a.geojson,{}),featureidkey:a.featureidkey,text:l({},a.text,{}),hovertext:l({},a.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:a.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:a.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":614,\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scattergeo/attributes\":1198}],960:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../constants/numerical\").BADNUM,i=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=a),f.index=h}return o(u,e),i(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":623,\"../../constants/numerical\":724,\"../scatter/arrays_to_calcdata\":1155,\"../scatter/calc_selection\":1158,\"fast-isnumeric\":241}],961:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),i=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,h=s(\"geojson\");(\"string\"==typeof h&&\"\"!==h||n.isPlainObject(h))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),a(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"./attributes\":959}],962:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){t.location=e.location,t.z=e.z;var i=n[a];return i.fIn&&i.fIn.properties&&(t.properties=i.fIn.properties),t.ct=i.ct,t}},{}],963:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"./attributes\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?a.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),h=-1!==s.indexOf(\"text\"),f=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&f.push(o));u&&f.push(t.zLabel);h&&i(r,e,f);t.extraText=f.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"./attributes\":959}],964:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},{\"../../plots/geo\":830,\"../heatmap/colorbar\":1038,\"./attributes\":959,\"./calc\":960,\"./defaults\":961,\"./event_data\":962,\"./hover\":963,\"./plot\":965,\"./select\":966,\"./style\":967}],965:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../lib/geo_location_utils\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../plots/cartesian/autorange\").findExtremes,l=t(\"./style\").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],a=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?i.extractTraceFeature(t):o(r,a.topojson),h=[],f=[],p=0;p<c;p++){var d=t[p],g=\"geojson-id\"===l?d.fOut:i.locationToFeature(l,d.loc,u);if(g){d.geojson=g,d.ct=g.properties.ct,d._polygons=i.feature2polygons(g);var m=i.computeBbox(g);h.push(m[0],m[2]),f.push(m[1],m[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var v=i.computeBbox(i.getTraceGeojson(r));h=[v[0],v[2]],f=[v[1],v[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,h,y),r._extremes.lat=s(n.lataxis._ax,f,y)},plot:function(t,e,r){var i=e.layers.backplot.select(\".choroplethlayer\");a.makeTraceGroups(i,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(a.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},{\"../../lib\":749,\"../../lib/geo_location_utils\":742,\"../../lib/topojson_utils\":776,\"../../plots/cartesian/autorange\":797,\"./style\":967,d3:169}],966:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,a,i,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(a=(n=s[r]).ct)&&(i=l.c2p(a),o=c.c2p(a),e.contains([i,o],null,r,t)?(u.push({pointNumber:r,lon:a[0],lat:a[1]}),n.selected=1):n.selected=0);return u}},{}],967:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/color\"),i=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(a.stroke,t.mlc||c.color).call(i.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),i.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?i.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":615,\"../../components/colorscale\":627,\"../../components/drawing\":637,d3:169}],968:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),a=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:i({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../choropleth/attributes\":959}],969:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../components/colorscale\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/geojson_utils\").makeBlank,l=t(\"../../lib/geo_location_utils\");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=i.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=a.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return a.extendFlat(n.fill.paint,{\"fill-opacity\":e}),a.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},h=e._opts={fill:o,line:u,geojson:s()};if(!r)return h;var f=l.extractTraceFeature(t);if(!f)return h;var p,d,g,m=i.makeColorScaleFuncFromTrace(e),v=e.marker,y=v.line||{};a.isArrayOrTypedArray(v.opacity)&&(p=function(t){var e=t.mo;return n(e)?+a.constrain(e,0,1):0}),a.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),a.isArrayOrTypedArray(y.width)&&(g=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=m(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),g&&(w.mlw=g(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var T=p?{type:\"identity\",property:\"mo\"}:v.opacity;return a.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),a.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:y.color,\"line-width\":g?{type:\"identity\",property:\"mlw\"}:y.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",h.geojson={type:\"FeatureCollection\",features:f},c(t),h},convertOnSelect:c}},{\"../../components/colorscale\":627,\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/geo_location_utils\":742,\"../../lib/geojson_utils\":743,\"fast-isnumeric\":241}],970:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),i=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),a(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"./attributes\":968}],971:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var a=r[n].id;if(\"string\"==typeof a&&0===a.indexOf(\"water\"))for(var i=n+1;i<r.length;i++)if(\"string\"==typeof(a=r[i].id)&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":855,\"../choropleth/calc\":960,\"../choropleth/event_data\":962,\"../choropleth/hover\":963,\"../choropleth/select\":966,\"../heatmap/colorbar\":1038,\"./attributes\":968,\"./defaults\":970,\"./plot\":972}],972:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,a=t(\"./convert\").convertOnSelect,i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",i+e+\"-fill\"],[\"line\",i+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(a(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var a=0;a<r.length;a++){var i=r[a],o=i[0],s=i[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,a=this.sourceId,i=0;i<n.length;i++){var o=n[i],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:a,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,a=new o(t,r.uid),i=a.sourceId,s=n(e),l=a.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(i,{type:\"geojson\",data:s.geojson}),a._addLayers(s,l),e[0].trace._glTrace=a,a}},{\"../../plots/mapbox/constants\":853,\"./convert\":969}],973:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:a({editType:\"calc\"},{keys:[\"norm\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=i[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../mesh3d/attributes\":1097}],974:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,a=e.v,i=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,a.length,i.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=a[c],f=i[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":623}],975:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),a=t(\"gl-cone3d\").createConeMesh,i=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],a=this.data.z[e],i=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,a,i,o,s,Math.sqrt(i*i+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,a=t.dataScale,c={};function u(t,e){var n=r[e],o=a[h[e]];return i(t,(function(t){return n.d2l(t)*o}))}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),m=e.lightposition;return g.lightPosition=[m.x,m.y,m.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),i=a(r,n),o=new c(t,e.uid);return o.mesh=i,o.data=e,i._trace=o,t.glplot.add(i),o}},{\"../../components/colorscale\":627,\"../../lib\":749,\"../../lib/gl_format_color\":745,\"../../plots/gl3d/zip3\":851,\"gl-cone3d\":259}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),i=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),a(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"./attributes\":973}],977:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":840,\"./attributes\":973,\"./calc\":974,\"./convert\":975,\"./defaults\":976}],978:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),a=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,a.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:a.xperiod0,yperiod0:a.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},i(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":622,\"../../components/drawing/attributes\":636,\"../../constants/docs\":719,\"../../constants/filter_ops\":720,\"../../lib/extend\":739,\"../../plots/font_attributes\":826,\"../heatmap/attributes\":1035,\"../scatter/attributes\":1156}],979:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),a=t(\"../heatmap/calc\"),i=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=a(t,e),s=r[0].z;i(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":627,\"../heatmap/calc\":1036,\"./end_plus\":989,\"./set_contours\":997}],980:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t[0],a=n.z;switch(e.type){case\"levels\":var i=Math.min(a[0][0],a[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(i>o.level||o.starts.length&&i===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,a[r][0]),u=Math.min(u,a[r][s-1]),c=Math.max(c,a[r][0]),c=Math.max(c,a[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,a[0][r]),u=Math.min(u,a[l-1][r]),c=Math.max(c,a[0][r]),c=Math.max(c,a[l-1][r]);var h,f,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":h=Math.min(p[0],p[1]),((f=Math.max(p[0],p[1]))<u||h>c||n.starts.length&&f===u)&&(n.prefixBoundary=!0);break;case\"][\":h=Math.min(p[0],p[1]),f=Math.max(p[0],p[1]),h<u&&f>c&&(n.prefixBoundary=!0)}}}},{}],981:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),a=t(\"./make_color_map\"),i=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=a(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n.extractOpts(e);r._fillgradient=h.reversescale?n.flipScale(h.colorscale):h.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:i(o),size:l}}}},{\"../../components/colorscale\":627,\"./end_plus\":989,\"./make_color_map\":994}],982:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"./label_defaults\"),i=t(\"../../components/color\"),o=i.addOpacity,s=i.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,i,l,h){var f,p,d,g=e.contours,m=r(\"contours.operation\");(g._operation=c[m],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===m?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),a(r,i,p,h)}},{\"../../components/color\":615,\"../../constants/filter_ops\":720,\"./label_defaults\":993,\"fast-isnumeric\":241}],984:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),a=t(\"fast-isnumeric\");function i(t,e){var r,i=Array.isArray(e);function o(t){return a(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(i?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=i?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=i?e.map(o):[o(e)]),r}function o(t){return function(e){e=i(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=i(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":720,\"fast-isnumeric\":241}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=n(\"contours.start\"),i=n(\"contours.end\"),o=!1===a||!1===i,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function a(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,i,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),i=t[0],r=0;r<i.edgepaths.length;r++)i.edgepaths[r]=s(i.edgepaths[r]);for(r=0;r<i.paths.length;r++)i.paths[r]=s(i.paths[r]);for(r=0;r<i.starts.length;r++)i.starts[r]=s(i.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),i=a(t[0]),o=a(t[1]),r=0;r<i.edgepaths.length;r++)i.edgepaths[r]=s(i.edgepaths[r]);for(r=0;r<i.paths.length;r++)i.paths[r]=s(i.paths[r]);for(r=0;r<i.starts.length;r++)i.starts[r]=s(i.starts[r]);for(;o.edgepaths.length;)i.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)i.paths.push(l(o.paths.shift()));for(;o.starts.length;)i.starts.push(l(o.starts.shift()));return[i]}}},{\"../../lib\":749}],987:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../heatmap/xyz_defaults\"),i=t(\"../scatter/period_defaults\"),o=t(\"./constraint_defaults\"),s=t(\"./contours_defaults\"),l=t(\"./style_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}if(a(t,e,h,u)){i(t,e,u,h),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"hoverongaps\");var f=\"constraint\"===h(\"contours.type\");h(\"connectgaps\",n.isArray1D(e.z)),f?o(t,e,h,u,r):(s(t,e,h,(function(r){return n.coerce2(t,e,c,r)})),l(t,e,h,u))}else e.visible=!1}},{\"../../lib\":749,\"../heatmap/xyz_defaults\":1049,\"../scatter/period_defaults\":1176,\"./attributes\":978,\"./constraint_defaults\":983,\"./contours_defaults\":985,\"./style_defaults\":999}],988:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./constraint_mapping\"),i=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?a[t._operation](t.value):t,s=o.size,l=[],c=i(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":749,\"./constraint_mapping\":984,\"./end_plus\":989}],989:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],990:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./constants\");function i(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=t.crossings[u],f=function(t,e,r){var n=0,i=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:i=0===r[1]?1:-1:-1!==a.BOTTOMSTART.indexOf(t)?i=1:-1!==a.LEFTSTART.indexOf(t)?n=1:-1!==a.TOPSTART.indexOf(t)?i=-1:n=-1;return[n,i]}(h,r,e),p=[s(t,e,[-f[0],-f[1]])],d=t.z.length,g=t.z[0].length,m=e.slice(),v=f.slice();for(c=0;c<1e4;c++){if(h>20?(h=a.CHOOSESADDLE[h][(f[0]||f[1])<0?0:1],t.crossings[u]=a.SADDLEREMAINDER[h]):delete t.crossings[u],!(f=a.NEWDELTA[h])){n.log(\"Found bad marching index:\",h,e,t.level);break}p.push(s(t,e,f)),e[0]+=f[0],e[1]+=f[1],u=e.join(\",\"),i(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=f[0]&&(e[0]<0||e[0]>g-2)||f[1]&&(e[1]<0||e[1]>d-2);if(e[0]===m[0]&&e[1]===m[1]&&f[0]===v[0]&&f[1]===v[1]||r&&y)break;h=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,T,k,M,A,S,E,C,L,P,I,z,O=i(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)L=p[c],P=p[c-1],I=void 0,z=void 0,I=L[2]-P[2],z=L[3]-P[3],D+=M=Math.sqrt(I*I+z*z),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(O&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];T=c-b+_+1,k=Math.floor((c+b+_+2)/2),w=O||c!==p.length-2?O||-1!==b?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),O&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(O)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,m.join(\",\"),p.join(\"L\"));var U=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!U&&i(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(i((C=t.edgepaths[S])[C.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(C)):(S>A&&S--,t.edgepaths[S]=C.concat(p,E));break}V||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!U;A++)i((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),a=e[1]+Math.max(r[1],0),i=t.z[a][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-i)/(t.z[a][n+1]-i);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[a],!0),n+l,a]}var c=(t.level-i)/(t.z[a+1][n]-i);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[a]+c*t.y[a+1],!0),n,a+c]}e.exports=function(t,e,r){var a,i,s,l;for(e=e||.01,r=r||.01,i=0;i<t.length;i++){for(s=t[i],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(a=0;Object.keys(s.crossings).length&&a<1e4;)a++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===a&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":749,\"./constants\":982}],991:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"../heatmap/hover\");e.exports=function(t,e,r,i,o){var s=a(t,e,r,i,o,!0);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},{\"../../components/color\":615,\"../heatmap/hover\":1042}],992:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":811,\"./attributes\":978,\"./calc\":979,\"./colorbar\":981,\"./defaults\":987,\"./hover\":991,\"./plot\":996,\"./style\":998}],993:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,a){if(a||(a={}),t(\"contours.showlabels\")){var i=e.font;n.coerceFont(t,\"contours.labelfont\",{family:i.family,size:i.size,color:r}),t(\"contours.labelformat\")}!1!==a.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":749}],994:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/colorscale\"),i=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=i(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=a.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?a.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),m=new Array(d);if(\"heatmap\"===e.coloring){var v=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-v)+v,m[f]=h[1];var x=n.extent([v,y,e.start,e.start+s*(l-1)]),b=x[v<y?0:1],_=x[v<y?1:0];b!==v&&(g.splice(0,0,b),m.splice(0,0,m[0])),_!==y&&(g.push(_),m.push(m[m.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,m[f]=h[1];return a.makeColorScaleFunc({domain:g,range:m},{noNumericCheck:!0})}},{\"../../components/colorscale\":627,\"./end_plus\":989,d3:169}],995:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function a(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,i,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(i=o.slice(),0===e&&(i=i.concat(n.LEFTSTART)),e===d-2&&(i=i.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=a((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==i.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==i.indexOf(c,i.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":982}],996:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"../../plots/cartesian/set_convert\"),u=t(\"../heatmap/plot\"),h=t(\"./make_crossings\"),f=t(\"./find_all_paths\"),p=t(\"./empty_pathinfo\"),d=t(\"./convert_to_constraints\"),g=t(\"./close_boundaries\"),m=t(\"./constants\"),v=m.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,h=\"\",f=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function m(t){return Math.abs(t[0]-e[0][0])<.01}function v(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=i.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){a.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!v(r)?n=e[1]:m(r)?n=e[0]:g(r)?n=e[3]:v(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):a.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){a.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=i.smoothclosed(t.paths[f],t.smoothing);return h}function x(t,e,r,n){var i=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*i,h=Math.sin(c)*i,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,T=Math.sin(_.theta)*_.width/2,k=2*a.segmentDistance(g,m,y,x,_.x-w,_.y-T,_.x+w,_.y+T)/(e.height+_.height),M=_.level===e.level,A=M?v.SAMELEVELDISTANCE:1;if(k<=A)return 1/0;d+=v.NEIGHBORCOST*(M?v.SAMELEVELFACTOR:1)/(k-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,a=[],i=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<i;e++)a.push(s.slice());for(e=0;e<n.length;e++)a[(r=n[e])[0]][r[1]]=0;return t.zmask=a,a}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),v=o[0],x=v.trace,_=v.x,w=v.y,T=x.contours,k=p(T,e,v),M=a.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===T.coloring&&(A=[o]),u(t,e,A,M),h(k),f(k);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),C=c.c2p(w[0],!0),L=c.c2p(w[w.length-1],!0),P=[[S,L],[E,L],[E,C],[S,C]],I=k;\"constraint\"===T.type&&(I=d(k,T._operation)),function(t,e,r){var n=a.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,P,T),function(t,e,r,i){var o=\"fill\"===i.coloring||\"constraint\"===i.type&&\"=\"!==i._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&g(e,i);var l=a.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+y(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,I,P,T),function(t,e,o,s,l){var c=a.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),g=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(g.exit().remove(),g.enter().append(\"g\").classed(\"contourlabels\",!0),h){var v=[],y=[];a.clearLocationCache();var x=r.labelFormatter(o,s),b=i.tester.append(\"text\").attr(\"data-notex\",1).call(i.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,T=_._length,k=w._length,M=_.range,A=w.range,S=a.aggNums(Math.min,null,s.x),E=a.aggNums(Math.max,null,s.x),C=a.aggNums(Math.min,null,s.y),L=a.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),I=Math.min(_.c2p(E,!0),T),z=Math.max(w.c2p(L,!0),0),O=Math.min(w.c2p(C,!0),k),D={};M[0]<M[1]?(D.left=P,D.right=I):(D.left=I,D.right=P),A[0]<A[1]?(D.top=z,D.bottom=O):(D.top=O,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,v.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(T*T+k*k),F=m.LABELDISTANCE*R/Math.max(1,e.length/m.LABELINCREASE);p.each((function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each((function(){var t=a.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*m.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),m.LABELMAX),i=0;i<n;i++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,v)}}))})),b.remove(),r.drawLabels(g,y,o,d,f?v:null)}h&&!u&&p.remove()}(s,k,t,v,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};h([p]),f([p]),g([p],{type:\"levels\"}),a.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+y(p,o))}else c=null;i.setClipUrl(t,c,r)}(s,e,t,v,P)}))},r.createLines=function(t,e,r){var n=r[0].smoothing,a=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(a.exit().remove(),a.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=a.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",(function(t){return i.smoothopen(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=a.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",(function(t){return i.smoothclosed(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return a},r.createLineClip=function(t,e,r,n){var a=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+a).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",a),i.setClipUrl(t,a,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,a=n.contours,i={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(a.labelformat)i.tickformat=a.labelformat,c(i,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)i=s.colorbar._axis;else{if(\"constraint\"===a.type){var u=a.value;Array.isArray(u)?i.range=[u[0],u[u.length-1]]:i.range=[u,u]}else i.range=[a.start,a.end],i.nticks=(a.end-a.start)/a.size;i.range[0]===i.range[1]&&(i.range[1]+=i.range[0]||1),i.nticks||(i.nticks=1e3),c(i,r),l.prepTicks(i),i._tmin=null,i._tmax=null}}return function(t){return l.tickText(i,t).text}},r.calcTextOpts=function(t,e,r,n){var a=e(t);r.text(a).call(s.convertToTspans,n);var o=r.node(),l=i.bBox(o,!0);return{text:a,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,i){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=a.getTextLocation(t,e.total,d,h),m=x(g,r,n,i);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var a=e.fontSize,i=e.width+a/3,o=Math.max(0,e.height-a/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),h=Math.cos(c),f=function(t,e){return[s+t*h-e*u,l+t*u+e*h]},p=[f(-i/2,-o/2),f(-i/2,o/2),f(i/2,o/2),f(i/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:i,height:o}),n.push(p)},r.drawLabels=function(t,e,r,i,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,a=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:a,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+a+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";a.ensureSingle(i,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/colorscale\":627,\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/set_convert\":818,\"../heatmap/plot\":1046,\"./close_boundaries\":980,\"./constants\":982,\"./convert_to_constraints\":986,\"./empty_pathinfo\":988,\"./find_all_paths\":990,\"./make_crossings\":995,d3:169}],997:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function i(t,e,r){var a={type:\"linear\",range:[t,e]};return n.autoTicks(a,(e-t)/(r||15)),a}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=a.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=a.aggNums(Math.max,null,e));var l=i(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),a.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:i(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798}],998:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,i=r.contours,s=r.line,l=i.size||1,c=i.start,u=\"constraint\"===i.type,h=!u&&\"lines\"===i.coloring,f=!u&&\"fill\"===i.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(a.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)}));var d=i.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){a.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)})),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}})),i(t)}},{\"../../components/drawing\":637,\"../heatmap/style\":1047,\"./make_color_map\":994,d3:169}],999:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),a=t(\"./label_defaults\");e.exports=function(t,e,r,i,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,i,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),a(r,i,c,o)}},{\"../../components/colorscale/defaults\":625,\"./label_defaults\":993}],1e3:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),a=t(\"../contour/attributes\"),i=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=a.contours;e.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:a.fillcolor,autocontour:a.autocontour,ncontours:a.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:a.line.color,width:a.line.width,dash:a.line.dash,smoothing:a.line.smoothing,editType:\"plot\"},transforms:void 0},i(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../contour/attributes\":978,\"../heatmap/attributes\":1035}],1001:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),a=t(\"../../lib\"),i=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,m=e._carpetTrace,v=m.aaxis,y=m.baxis;v._minDtick=0,y._minDtick=0,a.isArray1D(e.z)&&i(e,v,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?v.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=a.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,v),w=\"scaled\"===e.ytype?\"\":f,T=c(e,w,p,d,g.length,y),k={a:_,b:T,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[k]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":623,\"../../lib\":749,\"../carpet/lookup_carpetid\":951,\"../contour/set_contours\":997,\"../heatmap/clean_2d_array\":1037,\"../heatmap/convert_column_xyz\":1039,\"../heatmap/find_empties\":1041,\"../heatmap/interp2d\":1044,\"../heatmap/make_bound_array\":1045,\"./defaults\":1002}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../heatmap/xyz_defaults\"),i=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,i,r,a)}if(u(\"carpet\"),t.a&&t.b){if(!a(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,i,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":749,\"../contour/constraint_defaults\":983,\"../contour/contours_defaults\":985,\"../contour/style_defaults\":999,\"../heatmap/xyz_defaults\":1049,\"./attributes\":1e3}],1003:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":811,\"../contour/colorbar\":981,\"../contour/style\":998,\"./attributes\":1e3,\"./calc\":1001,\"./defaults\":1002,\"./plot\":1004}],1004:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../carpet/map_1d_array\"),i=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"../contour/empty_pathinfo\"),d=t(\"../contour/close_boundaries\"),g=t(\"../carpet/lookup_carpetid\"),m=t(\"../carpet/axis_aligned_line\");function v(t,e,r){var n=t.getPointAtLength(e),a=t.getPointAtLength(r),i=a.x-n.x,o=a.y-n.y,s=Math.sqrt(i*i+o*o);return[i/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,\"contour\").each((function(r){var b=n.select(this),T=r[0],k=T.trace,M=k._carpetTrace=g(t,k),A=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var S=T.a,E=T.b,C=k.contours,L=p(C,e,T),P=\"constraint\"===C.type,I=C._operation,z=P?\"=\"===I?\"lines\":\"fill\":C.coloring,O=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(L);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(L,D,R);var F,B,N,j,U=L;\"constraint\"===C.type&&(U=f(L,I)),function(t,e){var r,n,a,i,o,s,l,c,u;for(r=0;r<t.length;r++){for(i=t[r],o=i.pedgepaths=[],s=i.ppaths=[],n=0;n<i.edgepaths.length;n++){for(u=i.edgepaths[n],l=[],a=0;a<u.length;a++)l[a]=e(u[a]);o.push(l)}for(n=0;n<i.paths.length;n++){for(u=i.paths[n],c=[],a=0;a<u.length;a++)c[a]=e(u[a]);s.push(c)}}}(L,H);var V=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=a([],F.x,_.c2p),N=a([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(i(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=a([],c.x,r.c2p),h=a([],c.y,n.c2p),d.push(i(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(b,A.clipsegments,_,w,P,z),function(t,e,r,a,i,l,c,u,h,f,p){var g=\"fill\"===f;g&&d(i,t.contours);var v=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(g?i:[]);v.enter().append(\"path\"),v.exit().remove(),v.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,a,i,l,c){var u,h,f,p,d,g,v,y=\"\",x=e.edgepaths.map((function(t,e){return e})),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!A(t)||k(t)&&!M(t)?(s=a.aaxis,o=m(a,i,[t[0],e[0]],.5*(t[1]+e[1]))):(s=a.baxis,o=m(a,i,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var h=o[r][n];u+=[l.c2p(h[0]),c.c2p(h[1])]+\" \"}return u}u=0,h=null;for(;x.length;){var E=e.edgepaths[u][0];for(h&&(y+=S(h,E)),v=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?v:v.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),h=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!h){s.log(\"Missing end?\",u,e);break}for(T(h)&&!A(h)?f=r[1]:M(h)?f=r[0]:k(h)?f=r[3]:A(h)&&(f=r[2]),g=0;g<e.edgepaths.length;g++){var C=e.edgepaths[g][0];Math.abs(h[0]-f[0])<_?Math.abs(h[0]-C[0])<_&&(C[1]-h[1])*(f[1]-C[1])>=0&&(f=C,d=g):Math.abs(h[1]-f[1])<w?Math.abs(h[1]-C[1])<w&&(C[0]-h[0])*(f[0]-C[0])>=0&&(f=C,d=g):s.log(\"endpt to newendpt is not vert. or horz.\",h,f,C)}if(d>=0)break;y+=S(h,f),h=f}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(h,f)+\"Z\",h=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,h,r,a);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,b,_,w,U,O,H,M,A,z,q),function(t,e,r,a,i,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==i.showlines,d=i.showlabels,g=p&&d,m=u.createLines(f,p||d,e),b=u.createLineClip(f,g,r,a.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,T=l.yaxis,k=w._length,M=T._length,A=[[[0,0],[k,0],[k,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,a),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,i.labelfont),L={left:0,right:k,center:k/2,top:0,bottom:M,middle:M/2},P=Math.sqrt(k*k+M*M),I=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);m.each((function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each((function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,a,i){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=a.a[0],c=a.a[a.a.length-1],u=a.b[0],h=a.b[a.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(a.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,i*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=y(a.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,i*x(e,r)/2)),n}var p=v(t,0,1),d=v(t,n.total,n.total-1),g=f(o[0],p),m=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>m&&(n.max=m);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var a=Math.min(Math.ceil(n.len/I),h.LABELMAX),i=0;i<a;i++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,A)}}))})),C.remove(),u.drawLabels(_,S,r,b,g?A:null)}d&&!p&&m.remove()}(b,L,t,T,C,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}}))}},{\"../../components/drawing\":637,\"../../lib\":749,\"../carpet/axis_aligned_line\":935,\"../carpet/lookup_carpetid\":951,\"../carpet/makepath\":952,\"../carpet/map_1d_array\":953,\"../contour/close_boundaries\":980,\"../contour/constants\":982,\"../contour/convert_to_constraints\":986,\"../contour/empty_pathinfo\":988,\"../contour/find_all_paths\":990,\"../contour/make_crossings\":995,\"../contour/plot\":996,d3:169}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},i.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:a(),showlegend:s({},i.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scattermapbox/attributes\":1221}],1006:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=a(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[i,i],u){var g=c[h];f.z=n(g)?g:i}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":623,\"../../constants/numerical\":724,\"../../lib\":749,\"fast-isnumeric\":241}],1007:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=a.isArrayOrTypedArray(f)&&f.length,g=a.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var m=t[u],v=m.lonlat;if(v[0]!==s){var y={};if(d){var x=m.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:v},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,i.opacity(w)<1?w:i.addOpacity(w,0)];for(u=1;u<_.length;u++)T.push(_[u][0],_[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return a.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(b.max-b.min),\"heatmap-color\":T,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":615,\"../../components/colorscale\":627,\"../../constants/numerical\":724,\"../../lib\":749,\"../../lib/geojson_utils\":743,\"fast-isnumeric\":241}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),i=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),a(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"./attributes\":1005}],1009:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=i(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=a.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var a=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==a.indexOf(\"all\"),o=-1!==a.indexOf(\"lon\"),s=-1!==a.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==a.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../scattermapbox/hover\":1226}],1011:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),formatLabels:t(\"../scattermapbox/format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var a=r[n],i=a.id;if(\"symbol\"===a.type&&\"string\"==typeof i&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":855,\"../heatmap/colorbar\":1038,\"../scattermapbox/format_labels\":1225,\"./attributes\":1005,\"./calc\":1006,\"./defaults\":1008,\"./event_data\":1009,\"./hover\":1010,\"./plot\":1012}],1012:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function i(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",a+e+\"-heatmap\"]],this.below=null}var o=i.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,a=n(t),i=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(a.geojson),i!==this.below&&(this._removeLayers(),this._addLayers(a,i),this.below=i);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=a[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,a=this.sourceId,i=0;i<n.length;i++){var o=n[i],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:a,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,a=new i(t,r.uid),o=a.sourceId,s=n(e),l=a.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),a._addLayers(s,l),a}},{\"../../plots/mapbox/constants\":853,\"./convert\":1007}],1013:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var a=e.marker;if(a){n.mergeArray(a.opacity,t,\"mo\"),n.mergeArray(a.color,t,\"mc\");var i=a.line;i&&(n.mergeArray(i.color,t,\"mlc\"),n.mergeArrayCastPositive(i.width,t,\"mlw\"))}}},{\"../../lib\":749}],1014:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),a=t(\"../scatter/attributes\").line,i=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},i.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\",\"value\"])}),text:n.text,textposition:c({},n.textposition,{dflt:\"auto\"}),insidetextanchor:c({},n.insidetextanchor,{dflt:\"middle\"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:c({},a.color,{dflt:u.defaultLine}),width:c({},a.width,{dflt:0,editType:\"plot\"}),dash:a.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":615,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../bar/attributes\":891,\"../scatter/attributes\":1156,\"./constants\":1016}],1015:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),i=t(\"./arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return t===s?0:t}e.exports=function(t,e){var r,c,u,h,f,p,d=n.getFromId(t,e.xaxis||\"x\"),g=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\"),u=g.makeCalcdata(e,\"y\"),c=a(e,g,\"y\",u),p=!!e.yperiodalignment):(r=g.makeCalcdata(e,\"y\"),u=d.makeCalcdata(e,\"x\"),c=a(e,d,\"x\",u),p=!!e.xperiodalignment);var m,v=Math.min(c.length,r.length),y=new Array(v);for(e._base=[],h=0;h<v;h++){r[h]<0&&(r[h]=s);var x=!1;r[h]!==s&&h+1<v&&r[h+1]!==s&&(x=!0),f=y[h]={p:c[h],s:r[h],cNext:x},e._base[h]=-.5*f.s,p&&(y[h].orig_p=u[h]),e.ids&&(f.id=String(e.ids[h])),0===h&&(y[0].vTotal=0),y[0].vTotal+=l(f.s),f.begR=l(f.s)/l(y[0].s)}for(h=0;h<v;h++)(f=y[h]).s!==s&&(f.sumR=f.s/y[0].vTotal,f.difR=void 0!==m?f.s/m:1,m=f.s);return i(y,e),o(y,e),y}},{\"../../constants/numerical\":724,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"../scatter/calc_selection\":1158,\"./arrays_to_calcdata\":1013}],1016:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],1017:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,a,i=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(a=0;a<o.length;a++){var p=o[a],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[a],d?f.push(r):h.push(r),u.push(r))}var g={mode:i.funnelmode,norm:i.funnelnorm,gap:i.funnelgap,groupgap:i.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),a=0;a<u.length;a++){r=u[a];for(var m=0;m<r.length;m++)m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0,r[m].nextP1=r[m+1].p1,r[m].nextS1=r[m+1].s1)}}},{\"../bar/cross_trace_calc\":894}],1018:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../bar/defaults\").handleGroupingDefaults,i=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,a){function u(r,a){return n.coerce(t,e,l,r,a)}if(o(t,e,a,u)){s(t,e,a,u),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var h=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var f=u(\"textposition\");i(t,e,a,u,f,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",Array.isArray(h)?\"text+value\":\"value\");var p=u(\"marker.color\",r);if(u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\"))u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,i;function o(t){return n.coerce(i._input,i,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(i=t[s])._input,a(r,i,e,o)}}},{\"../../components/color\":615,\"../../lib\":749,\"../bar/defaults\":895,\"../scatter/period_defaults\":1176,\"../scatter/xy_defaults\":1183,\"./attributes\":1014}],1019:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1020:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,i=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=a(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=i(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=i(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=i(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),m=function(t){return d||-1!==g.indexOf(t)};m(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),m(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),m(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,a=e.mc||r.color,i=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(a))return a;if(n(i)&&o)return i}(c,h),[s]}}},{\"../../components/color\":615,\"../../lib\":749,\"../bar/hover\":898}],1021:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":811,\"../bar/select\":903,\"./attributes\":1014,\"./calc\":1015,\"./cross_trace_calc\":1017,\"./defaults\":1018,\"./event_data\":1019,\"./hover\":1020,\"./layout_attributes\":1022,\"./layout_defaults\":1023,\"./plot\":1024,\"./style\":1025}],1022:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e,r){var i=!1;function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){i=!0;break}}i&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":749,\"./layout_attributes\":1022}],1024:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;function c(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),a[2]=o.c2p(t.nextS0,!0),i[2]=s.c2p(t.nextP0,!0),a[3]=o.c2p(t.nextS1,!0),i[3]=s.c2p(t.nextP1,!0),n?[a,i]:[i,a]}e.exports=function(t,e,r,u){var h=t._fullLayout;l(\"funnel\",h),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;a.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),h=r[0].trace,f=a.ensureSingle(s,\"g\",\"regions\");if(h.connector&&h.connector.visible){var p=\"h\"===h.orientation,d=f.selectAll(\"g.region\").data(a.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var h=c(r,l,u,p),f=h[0],d=h[1],m=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&f[2]!==o&&d[2]!==o&&f[3]!==o&&d[3]!==o&&(m+=p?\"M\"+f[0]+\",\"+d[1]+\"L\"+f[2]+\",\"+d[2]+\"H\"+f[3]+\"L\"+f[1]+\",\"+d[1]+\"Z\":\"M\"+f[1]+\",\"+d[1]+\"L\"+f[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+f[1]+\",\"+d[0]+\"Z\"),\"\"===m&&(m=\"M0,0Z\"),a.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(i.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;a.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,h=a.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(a.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),a.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(i.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:h.funnelmode,norm:h.funnelmode,gap:h.funnelgap,groupgap:h.funnelgroupgap})}},{\"../../components/drawing\":637,\"../../constants/numerical\":724,\"../../lib\":749,\"../bar/plot\":902,\"../bar/uniform_text\":907,d3:169}],1025:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(i.fill,t.mc||e.color).call(i.stroke,t.mlc||e.line.color).call(a.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(i.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;a.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../constants/interactions\":723,\"../bar/style\":905,\"../bar/uniform_text\":907,d3:169}],1026:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),a=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},a.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:i({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/domain\":825,\"../../plots/template_attributes\":876,\"../pie/attributes\":1130}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"funnelarea\",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{\"../../plots/plots\":861}],1028:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1132}],1029:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../pie/defaults\").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,a,r,i)}var u=c(\"labels\"),h=c(\"values\"),f=s(u,h),p=f.len;if(e._hasLabels=f.hasLabels,e._hasValues=f.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),p){e._length=p,c(\"marker.line.width\")&&c(\"marker.line.color\",l.paper_bgcolor),c(\"marker.colors\"),c(\"scalegroup\");var d,g=c(\"text\"),m=c(\"texttemplate\");if(m||(d=c(\"textinfo\",Array.isArray(g)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),m||d&&\"none\"!==d){var v=c(\"textposition\");o(t,e,l,c,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}i(e,l,c),c(\"title.text\")&&(c(\"title.position\"),n.coerceFont(c,\"title.font\",l.font)),c(\"aspectratio\"),c(\"baseratio\")}else e.visible=!1}},{\"../../lib\":749,\"../../plots/domain\":825,\"../bar/defaults\":895,\"../pie/defaults\":1133,\"./attributes\":1026}],1030:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1141,\"./attributes\":1026,\"./base_plot\":1027,\"./calc\":1028,\"./defaults\":1029,\"./layout_attributes\":1031,\"./layout_defaults\":1032,\"./plot\":1033,\"./style\":1034}],1031:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1137}],1032:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":749,\"./layout_attributes\":1031}],1033:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,h=t(\"../pie/helpers\"),f=t(\"../pie/plot\"),p=f.attachFxHandlers,d=f.determineInsideTextFont,g=f.layoutAreas,m=f.prerenderTitles,v=f.positionTitleOutside,y=f.formatSliceLabel;function x(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;u(\"funnelarea\",r),m(e,t),g(e,r._size),i.makeTraceGroups(r._funnelarealayer,e,\"trace\").each((function(e){var l=n.select(this),u=e[0],f=u.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,a=r.baseratio;a>.999&&(a=.999);var i,o=Math.pow(a,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,m=-1/0;for(h=0;h<p.length;h++)i=p[h],g=Math.min(g,i[1]),m=Math.max(m,i[1]);for(h=0;h<p.length;h++)p[h][1]-=(m+g)/2;var v=p[p.length-1][0],y=e.r,x=(m-g)/2,b=y/v,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(i=p[0])[0],i[1]],T=[i[0],i[1]],k=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var M=p[k+=1][0],A=p[k][1];f.TL=[-M,A],f.TR=[M,A],f.BL=w,f.BR=T,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,T=f.TR}var S,E}(e),l.each((function(){var l=n.select(this).selectAll(\"g.slice\").data(e);l.enter().append(\"g\").classed(\"slice\",!0),l.exit().remove(),l.each((function(l,g){if(l.hidden)n.select(this).selectAll(\"path,g\").remove();else{l.pointNumber=l.i,l.curveNumber=f.index;var m=u.cx,v=u.cy,b=n.select(this),_=b.selectAll(\"path.surface\").data([l]);_.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),b.call(p,t,e);var w=\"M\"+(m+l.TR[0])+\",\"+(v+l.TR[1])+x(l.TR,l.BR)+x(l.BR,l.BL)+x(l.BL,l.TL)+\"Z\";_.attr(\"d\",w),y(t,l,u);var T=h.castOption(f.textposition,l.pts),k=b.selectAll(\"g.slicetext\").data(l.text&&\"none\"!==T?[0]:[]);k.enter().append(\"g\").classed(\"slicetext\",!0),k.exit().remove(),k.each((function(){var u=i.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),h=i.ensureUniformFontSize(t,d(f,l,r.font));u.text(l.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(a.font,h).call(o.convertToTspans,t);var p,y,x,b=a.bBox(u.node()),_=Math.min(l.BL[1],l.BR[1])+v,w=Math.max(l.TL[1],l.TR[1])+v;y=Math.max(l.TL[0],l.BL[0])+m,x=Math.min(l.TR[0],l.BR[0])+m,(p=s(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=h.size,c(f.type,p,r),e[g].transform=p,u.attr(\"transform\",i.getTextTransform(p))}))}}));var g=n.select(this).selectAll(\"g.titletext\").data(f.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each((function(){var e=i.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),s=f.title.text;f._meta&&(s=i.templateString(s,f._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(a.font,f.title.font).call(o.convertToTspans,t);var l=v(u,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")}))}))}))}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../bar/plot\":902,\"../bar/uniform_text\":907,\"../pie/helpers\":1135,\"../pie/plot\":1139,d3:169}],1034:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../pie/style_one\"),i=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");i(t,e,\"funnelarea\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(a,t,e)}))}))}},{\"../bar/uniform_text\":907,\"../pie/style_one\":1141,d3:169}],1035:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=s({z:{valType:\"data_array\",editType:\"calc\"},x:s({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:s({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:s({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:s({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:s({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:s({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:s({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:s({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:s({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:s({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:s({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:s({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},{transforms:void 0},o(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":622,\"../../constants/docs\":719,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156}],1036:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../histogram2d/calc\"),l=t(\"../../components/colorscale/calc\"),c=t(\"./convert_column_xyz\"),u=t(\"./clean_2d_array\"),h=t(\"./interp2d\"),f=t(\"./find_empties\"),p=t(\"./make_bound_array\"),d=t(\"../../constants/numerical\").BADNUM;function g(t){for(var e=[],r=t.length,n=0;n<r;n++){var a=t[n];a!==d&&e.push(a)}return e}e.exports=function(t,e){var r,m,v,y,x,b,_,w,T,k,M,A=i.getFromId(t,e.xaxis||\"x\"),S=i.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),C=n.traceIs(e,\"histogram\"),L=n.traceIs(e,\"gl2d\"),P=E?\"best\":e.zsmooth;if(A._minDtick=0,S._minDtick=0,C)y=(M=s(t,e)).orig_x,r=M.x,m=M.x0,v=M.dx,w=M.orig_y,x=M.y,b=M.y0,_=M.dy,T=M.z;else{var I=e.z;a.isArray1D(I)?(c(e,A,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,I=e._z):(y=e.x?A.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,A,\"x\",y),x=o(e,S,\"y\",w),e._x=r,e._y=x),m=e.x0,v=e.dx,b=e.y0,_=e.dy,T=u(I,e,A,S)}function z(t){P=e._input.zsmooth=e.zsmooth=!1,a.warn('cannot use zsmooth: \"fast\": '+t)}if((A.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],a=-1,i=0;i<r.length;i++)if(e[i]!==d){a++,n[a]=[];for(var o=0;o<r[i].length;o++)t[o]!==d&&n[a].push(r[i][o])}return n}(r,x,T),C||(r=g(r),x=g(x),e._x=r,e._y=x)),C||!E&&!e.connectgaps||(e._emptypoints=f(T),h(T,e._emptypoints)),\"fast\"===P)if(\"log\"===A.type||\"log\"===S.type)z(\"log axis found\");else if(!C){if(r.length){var O=(r[r.length-1]-r[0])/(r.length-1),D=Math.abs(O/100);for(k=0;k<r.length-1;k++)if(Math.abs(r[k+1]-r[k]-O)>D){z(\"x scale is not linear\");break}}if(x.length&&\"fast\"===P){var R=(x[x.length-1]-x[0])/(x.length-1),F=Math.abs(R/100);for(k=0;k<x.length-1;k++)if(Math.abs(x[k+1]-x[k]-R)>F){z(\"y scale is not linear\");break}}}var B=a.maxRowLength(T),N=\"scaled\"===e.xtype?\"\":r,j=p(e,N,m,v,B,A),U=\"scaled\"===e.ytype?\"\":x,V=p(e,U,b,_,T.length,S);L||(e._extremes[A._id]=i.findExtremes(A,j),e._extremes[S._id]=i.findExtremes(S,V));var q={x:j,y:V,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&y&&(q.orig_x=y),e.yperiodalignment&&w&&(q.orig_y=w),N&&N.length===j.length-1&&(q.xCenter=N),U&&U.length===V.length-1&&(q.yCenter=U),C&&(q.xRanges=M.xRanges,q.yRanges=M.yRanges,q.pts=M.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var H={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};q.xfill=p(H,N,m,v,B,A),q.yfill=p(H,U,b,_,T.length,S)}return[q]}},{\"../../components/colorscale/calc\":623,\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"../histogram2d/calc\":1068,\"./clean_2d_array\":1037,\"./convert_column_xyz\":1039,\"./find_empties\":1041,\"./interp2d\":1044,\"./make_bound_array\":1045}],1037:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===i||r===i?i:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:i}}return a.identity}var m=g(r),v=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,v(h),m(f)));return y}},{\"../../constants/numerical\":724,\"../../lib\":749,\"fast-isnumeric\":241}],1038:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,i=t(\"../../plots/cartesian/align_period\");e.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),h=r.makeCalcdata(t,s);u=i(t,e,o,u),h=i(t,r,s,h);var f,p,d,g,m=t.text,v=void 0!==m&&n.isArray1D(m),y=t.hovertext,x=void 0!==y&&n.isArray1D(y),b=n.distinctVals(u),_=b.vals,w=n.distinctVals(h),T=w.vals,k=[],M=T.length,A=_.length;for(f=0;f<l.length;f++)k[f]=n.init2dArray(M,A);v&&(d=n.init2dArray(M,A)),x&&(g=n.init2dArray(M,A));var S=n.init2dArray(M,A);for(f=0;f<c;f++)if(u[f]!==a&&h[f]!==a){var E=n.findBin(u[f]+b.minDiff/2,_),C=n.findBin(h[f]+w.minDiff/2,T);for(p=0;p<l.length;p++){var L=t[l[p]];k[p][C][E]=L[f],S[C][E]=f}v&&(d[C][E]=m[f]),x&&(g[C][E]=y[f])}for(t[\"_\"+o]=_,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];v&&(t._text=d),x&&(t._hovertext=g),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=_.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795}],1040:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./xyz_defaults\"),i=t(\"../scatter/period_defaults\"),o=t(\"./style_defaults\"),s=t(\"../../components/colorscale/defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,l,r,a)}a(t,e,u,c)?(i(t,e,c,u),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\"),o(t,e,u,c),u(\"hoverongaps\"),u(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),s(t,e,c,u,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"../scatter/period_defaults\":1176,\"./attributes\":1035,\"./style_defaults\":1048,\"./xyz_defaults\":1049}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,a,i,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],m=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],a=0;a<m;a++)void 0===d[a]&&((s=(void 0!==d[a-1]?1:0)+(void 0!==d[a+1]?1:0)+(void 0!==e[a]?1:0)+(void 0!==p[a]?1:0))?(0===r&&s++,0===a&&s++,r===t.length-1&&s++,a===d.length-1&&s++,s<4&&(h[[r,a]]=[r,a,s]),u.push([r,a,s])):f.push([r,a]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(i=f[o])[0])-1,a=i[1]]]||g)[2]+(h[[r+1,a]]||g)[2]+(h[[r,a-1]]||g)[2]+(h[[r,a+1]]||g)[2])/20)&&(l[i]=[r,a,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(i in l)h[i]=l[i],u.push(l[i])}return u.sort((function(t,e){return e[2]-t[2]}))}},{\"../../lib\":749}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,m=t.xa,v=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,T=d.zmask,k=g.zhoverformat,M=y,A=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void a.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(M.length-2,a.findBin(e,M))),p=Math.max(0,Math.min(A.length-2,a.findBin(r,A)))}var E,C,L=m.c2p(y[f]),P=m.c2p(y[f+1]),I=v.c2p(x[p]),z=v.c2p(x[p+1]);c?(E=d.orig_x||y,C=d.orig_y||x,P=L,u=E[f],z=I,h=C[p]):(E=d.orig_x||_||y,C=d.orig_y||w||x,u=_?E[f]:(E[f]+E[f+1])/2,h=w?C[p]:(C[p]+C[p+1])/2,m&&\"category\"===m.type&&(u=y[f]),v&&\"category\"===v.type&&(h=x[p]),g.zsmooth&&(L=P=m.c2p(u),I=z=v.c2p(h)));var O=b[p][f];if(T&&!T[p][f]&&(O=void 0),void 0!==O||g.hoverongaps){var D;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?D=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(D=d.text[p][f]);var R=o(g),F={type:\"linear\",range:[R.min,R.max],hoverformat:k,_separators:m._separators,_numFormat:m._numFormat},B=i.tickText(F,O,\"hover\").text;return[a.extendFlat(t,{index:g._after2before?g._after2before[p][f]:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:L,x1:P,y0:I,y1:z,xLabelVal:u,yLabelVal:h,zLabelVal:O,zLabel:B,text:D})]}}},{\"../../components/colorscale\":627,\"../../components/fx\":655,\"../../lib\":749,\"../../plots/cartesian/axes\":798}],1043:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":811,\"./attributes\":1035,\"./calc\":1036,\"./colorbar\":1038,\"./defaults\":1040,\"./hover\":1042,\"./plot\":1046,\"./style\":1047}],1044:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=[[-1,0],[1,0],[0,-1],[0,1]];function i(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,i,o,s,l,c,u,h,f,p,d,g,m,v=0;for(s=0;s<e.length;s++){for(i=(n=e[s])[0],o=n[1],d=t[i][o],p=0,f=0,l=0;l<4;l++)(u=t[i+(c=a[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=m=h:(g=Math.min(g,h),m=Math.max(m,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[i][o]=p/f,void 0===d?f<4&&(v=1):(t[i][o]=(1+r)*t[i][o]-r*d,m>g&&(v=Math.max(v,Math.abs(t[i][o]-d)/(m-g))))}return v}e.exports=function(t,e){var r,a=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&a>.01;r++)a=o(t,e,i(a));return a>.01&&n.log(\"interp2d didn't converge quickly\",a),t}},{\"../../lib\":749}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(a(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var m=h[h.length-1],v=m-h[h.length-2];for(u=g;u<o;u++)m+=v,h.push(m)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(a(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=i||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":749,\"../../registry\":881}],1046:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"tinycolor2\"),i=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),a=e[n],i=e[n+1],s=o.constrain(n+(t-a)/(i-a)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),a=e[n],i=(t-a)/(e[n+1]-a)||0;return i<=0?{bin0:n,bin1:n,frac:0}:i<.5?{bin0:n,bin1:n+1,frac:i}:{bin0:n+1,bin1:n,frac:1-i}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each((function(e){var r,f,g,m,v,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,T=b.x,k=b.y,M=b.xCenter,A=b.yCenter,S=i.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,I=!1;for(y=0;void 0===r&&y<T.length-1;)r=p.c2p(T[y]),y++;for(y=T.length-1;void 0===f&&y>0;)f=p.c2p(T[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===m&&y<k.length-1;)m=d.c2p(k[y]),y++;for(y=k.length-1;void 0===v&&y>0;)v=d.c2p(k[y]),y--;if(v<m&&(g=m,m=v,v=g,I=!0),S&&(M=T,A=k,T=b.xfill,k=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),m=Math.max(-z*d._length,m),v=Math.min((1+z)*d._length,v)}var O=Math.round(f-r),D=Math.round(v-m);if(O<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=O,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=I?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(T[t])-r),0,O)},j=function(t){return o.constrain(Math.round(d.c2p(k[t])-m),0,D)});var q,H,G,Y,W,Z=j(0),X=[Z,Z],J=P?0:1,K=I?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(O*D*4)}catch(t){rt=new Array(O*D*4)}if(\"best\"===E){var at,it,ot,st=M||T,lt=A||k,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(O),ft=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-m);for(y=0;y<O;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(it=w[(at=pt(H,ut)).bin0],ot=w[at.bin1],y=0;y<O;y++,nt+=4)h(rt,nt,W=kt(it,ot,ht[y],at))}else for(H=0;H<C;H++)for(Y=w[H],X=j(H),y=0;y<O;y++)W=Tt(Y[y],1),h(rt,nt=4*(X*O+N(y)),W);var dt=U.createImageData(O,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,mt=gt.length;for(H=0;H<mt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var vt=_.xgap,yt=_.ygap,xt=Math.floor(vt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],X.reverse(),X[K]=j(H+1),X[0]!==X[1]&&void 0!==X[0]&&void 0!==X[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=Tt(Y[y],(q[1]-q[0])*(X[1]-X[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,X[0]+bt,q[1]-q[0]-vt,X[1]-X[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=a(\"rgb(\"+$+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:O,x:r,y:m,\"xlink:href\":B.toDataURL(\"image/png\")})}function Tt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function kt(t,e,r,n){var a=t[r.bin0];if(void 0===a)return Tt(void 0,1);var i,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-a||0,u=s-a||0;return i=void 0===o?void 0===l?0:void 0===s?2*(l-a):2*(2*l-s-a)/3:void 0===l?void 0===s?0:2*(2*a-o-s)/3:void 0===s?2*(2*l-o-a)/3:l+a-o-s,Tt(a+r.frac*c+n.frac*(u+r.frac*i))}}))}},{\"../../components/colorscale\":627,\"../../constants/xmlns_namespaces\":725,\"../../lib\":749,\"../../registry\":881,d3:169,tinycolor2:548}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},{d3:169}],1048:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1049:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(a.isArray1D(t.z)){u=r(l),h=r(c);var p=a.minRowLength(u),d=a.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,i=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!a.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(i=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&i&&o}(f))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||\"contourgl\"===t.type||i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":749,\"../../registry\":881,\"fast-isnumeric\":241}],1050:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),a=t(\"../../components/colorscale/attributes\"),i=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},i(l,a(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../heatmap/attributes\":1035}],1051:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,a=n%r[0],i=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[a],e.y[i],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[i,a],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,a=e.length,o=new Array(a),s=new Array(4*a),l=0;l<a;l++){var c=e[l],u=i(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,h=this.scene.xaxis,f=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[h._id]=a.findExtremes(h,r.x,c),t._extremes[f._id]=a.findExtremes(f,r.y,u)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":772,\"../../plots/cartesian/axes\":798,\"gl-heatmap2d\":268}],1052:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../heatmap/xyz_defaults\"),i=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}a(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),i(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"../heatmap/xyz_defaults\":1049,\"./attributes\":1050}],1053:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":838,\"../heatmap/calc\":1036,\"../heatmap/colorbar\":1038,\"./attributes\":1050,\"./convert\":1051,\"./defaults\":1052}],1054:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:i(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:i(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:a({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../lib/extend\":739,\"../../plots/template_attributes\":876,\"../bar/attributes\":891,\"./bin_attributes\":1056,\"./constants\":1060}],1055:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,a=0;a<r;a++)e[a]?(t[a]/=e[a],n+=t[a]):t[a]=null;return n}},{}],1056:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1057:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,a){var i=a[e];return n(i)?(i=Number(i),r[t]+=i,i):0},avg:function(t,e,r,a,i){var o=a[e];return n(o)&&(o=Number(o),r[t]+=o,i[t]++),0},min:function(t,e,r,a){var i=a[e];if(n(i)){if(i=Number(i),!n(r[t]))return r[t]=i,i;if(r[t]>i){var o=i-r[t];return r[t]=i,o}}return 0},max:function(t,e,r,a){var i=a[e];if(n(i)){if(i=Number(i),!n(r[t]))return r[t]=i,i;if(r[t]<i){var o=i-r[t];return r[t]=i,o}}return 0}}},{\"fast-isnumeric\":241}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),a=n.ONEAVGYEAR,i=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var a=Math.abs(e-t),i=\"date\"===r.type,o=f(a,i),s=0;s<10;s++){var l=f(80*o,i);if(o===l)break;if(!p(l,t,e,i,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*a?a:t>1.1*i?i:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,i,s){if(n&&t>o){var l=d(e,i,s),c=d(r,i,s),u=t===a?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,a,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,i){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],m=Math.min(h(d+f,d+p,n,i),h(g+f,g+p,n,i)),v=Math.min(h(d+c,d+f,n,i),h(g+c,g+f,n,i));if(m>v&&v<Math.abs(g-d)/4e3?(s=m,l=!1):(s=Math.min(m,v),l=!0),\"date\"===n.type&&s>o){var y=s===a?1:6,x=s===a?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,a,i),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,i);if(c<e){var h=u(c,x,!1,i);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,i):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":724,\"../../plots/cartesian/axes\":798}],1059:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,m,v=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?a.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],a.nestedProperty(u[0],v+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var A=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),A=a.concat(A,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),i.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),I=u[0]._autoBin={};if(g=I[b.dirs[0]]={},C&&(b.size||(P.start=T(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=T(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!i.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,i){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,a=e.orientation,i=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===a&&l.xaxis===r&&l.yaxis===n&&i.push(l)}return i}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),m=g[0],v=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],v?d.push(s):p=Math.min(p,m.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[i].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=a.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[i]=s[i]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&a.extendFlat(l,w)}return e[i]}(t,e,r,s,v)}(m=h.cumulative||{}).enabled&&\"include\"!==m.currentbin&&(\"decreasing\"===m.direction?P.start=T(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=T(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,a.nestedProperty(u[0],v+\".size\").set(P.size)),M(\"start\",b,P),M(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[v]||{},O=a.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:a.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),O.start=r.l2r(j),F||a.nestedProperty(e,v+\".start\").set(O.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:a.aggNums(Math.max,null,d);O.end=r.l2r(H),q||a.nestedProperty(e,v+\".start\").set(O.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[v]=a.extendFlat({},e[v]||{}),delete e._input[G],delete e[G]),[O,d]}e.exports={calc:function(t,e){var r,i,p,d,g=[],m=[],v=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,v,y),T=w[0],k=w[1],M=\"string\"==typeof T.size,A=[],S=M?A:T,E=[],C=[],L=[],P=0,I=e.histnorm,z=e.histfunc,O=-1!==I.indexOf(\"density\");_.enabled&&O&&(I=I.replace(/ ?density$/,\"\"),O=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[I],N=!1,j=function(t){return v.r2c(t,0,b)};for(a.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(T.start),p=j(T.end)+(r-o.tickIncrement(r,T.size,!1,b))/1e6;r<p&&g.length<1e6&&(i=o.tickIncrement(r,T.size,!1,b),g.push((r+i)/2),m.push(R),L.push([]),A.push(r),O&&E.push(1/(i-r)),N&&C.push(0),!(i<=r));)r=i;A.push(r),M||\"date\"!==v.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var U=e[\"_\"+y+\"bingroup\"],V={leftGap:1/0,rightGap:1/0};U&&(t._fullLayout._roundFnOpts[U]||(t._fullLayout._roundFnOpts[U]=V),V=t._fullLayout._roundFnOpts[U]);var q,H=m.length,G=!0,Y=V.leftGap,W=V.rightGap,Z={};for(r=0;r<k.length;r++){var X=k[r];(d=a.findBin(X,S))>=0&&d<H&&(P+=F(d,r,m,D,C),G&&L[d].length&&X!==k[L[d][0]]&&(G=!1),L[d].push(r),Z[r]=d,Y=Math.min(Y,X-A[d]),W=Math.min(W,A[d+1]-X))}V.leftGap=Y,V.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[U];return h(n.leftGap,n.rightGap,A,v,b)(e,r)}}),N&&(P=u(m,C)),B&&B(m,P,E),_.enabled&&function(t,e,r){var n,a,i;function o(e){i=t[e],t[e]/=2}function s(e){a=t[e],t[e]=i+a/2,i+=a}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(m,_.direction,_.currentbin);var J=Math.min(g.length,m.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(m[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(m[r]){$=r;break}for(r=Q;r<=$;r++)if(n(g[r])&&n(m[r])){var tt={p:g[r],s:m[r],b:0};_.enabled||(tt.pts=L[r],G?tt.ph0=tt.ph1=L[r].length?k[L[r][0]]:g[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,T.size,!1,b)-K[0].p),s(K,e),a.isArrayOrTypedArray(e.selectedpoints)&&a.tagSelected(K,e,Z),K},calcAllAutoBins:f}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../registry\":881,\"../bar/arrays_to_calcdata\":890,\"./average\":1055,\"./bin_functions\":1057,\"./bin_label_vals\":1058,\"./norm_functions\":1066,\"fast-isnumeric\":241}],1060:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=a.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,m,v=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function T(t,r,i){var o=t.uid+\"__\"+i;r||(r=o);var s=function(t,r){return a.getFromTrace({_fullLayout:e},t,r).type}(t,i),l=t[i+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(i)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[i],axType:s,calendar:t[i+\"calendar\"]||\"\"}),t[\"_\"+i+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],i(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,i(r,\"2dMap\")||o(r._input,r,e,_));var k=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!i(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var M=r[p+\"axis\"],A=l(e,M)+r.orientation;(k[A]||{})[r.alignmentgroup]&&(f=A)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,T(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(i(r,\"2dMap\"))for(m=0;m<2;m++){var L=_((p=u[m])+\"bingroup\",C?C+\"__\"+p:null);T(r,L,p)}else T(r,C,w(r))}for(f in v){var P=v[f];for(h=P.traces,g=0;g<c.length;g++){var I,z,O=c[g],D=O.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],I=O.aStr[p],void 0!==s(r._input,I).get()){P[D]=_(I),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,I).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(I,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(I))}}}}},{\"../../lib\":749,\"../../plots/cartesian/axis_ids\":801,\"../../registry\":881,\"../bar/defaults\":895}],1062:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return a.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(a.minRowLength(u)&&a.minRowLength(h)):a.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),a.coerceSelectionMarkerOpacity(e,c);var m=(e.marker.line||{}).color,v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,m||i.defaultLine,{axis:\"y\"}),v(t,e,m||i.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":615,\"../../lib\":749,\"../../registry\":881,\"../bar/style_defaults\":906,\"./attributes\":1054}],1063:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var i,o=Array.isArray(a)?n[0].pts[a[0]][a[1]]:n[a].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){i=[];for(var s=0;s<o.length;s++)i=i.concat(r._indexToPoints[o[s]])}else i=o;t.pointIndices=i}return t}},{}],1064:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,a=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,i){var o=n(t,e,r,i);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=a(t[c+\"a\"],s.ph0,s.ph1)}return o}}},{\"../../plots/cartesian/axes\":798,\"../bar/hover\":898}],1065:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":811,\"../bar/cross_trace_calc\":894,\"../bar/layout_attributes\":900,\"../bar/layout_defaults\":901,\"../bar/plot\":902,\"../bar/select\":903,\"../bar/style\":905,\"../scatter/marker_colorbar\":1174,\"./attributes\":1054,\"./calc\":1059,\"./cross_trace_defaults\":1061,\"./defaults\":1062,\"./event_data\":1063,\"./hover\":1064}],1066:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,a=0;a<r;a++)t[a]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var a=t.length;n=n||1;for(var i=0;i<a;i++)t[i]*=r[i]*n},\"probability density\":function(t,e,r,n){var a=t.length;n&&(e/=n);for(var i=0;i<a;i++)t[i]*=r[i]/e}}},{}],1067:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),a=t(\"../histogram/bin_attributes\"),i=t(\"../heatmap/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat;e.exports=c({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:a(\"x\"),nbinsy:n.nbinsy,ybins:a(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:c({},n.bingroup,{}),xbingroup:c({},n.bingroup,{}),ybingroup:c({},n.bingroup,{}),xgap:i.xgap,ygap:i.ygap,zsmooth:i.zsmooth,zhoverformat:i.zhoverformat,hovertemplate:s({},{keys:\"z\"}),showlegend:c({},o.showlegend,{dflt:!1})},l(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../heatmap/attributes\":1035,\"../histogram/attributes\":1054,\"../histogram/bin_attributes\":1056}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var a,i=new Array(t);if(n)for(a=0;a<t;a++)i[a]=1/(e[a+1]-e[a]);else{var o=1/r;for(a=0;a<t;a++)i[a]=o}return i}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,a,i){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,a,i);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=a.getFromId(t,e.xaxis),m=a.getFromId(t,e.yaxis),v=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,v)},b=function(t){return m.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],T=_[1],k=c(t,e,m,\"y\"),M=k[0],A=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,I=\"string\"==typeof M.size,z=[],O=[],D=P?z:w,R=I?O:M,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=i.count,G=o[j],Y=!1,W=[],Z=[],X=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";X&&\"count\"!==U&&(Y=\"avg\"===U,H=i[U]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-a.tickIncrement(K,J,!1,v))/1e6;for(r=K;r<Q;r=a.tickIncrement(r,J,!1,v))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var $,tt=C.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,v)),nt=M.size,at=b(M.start),it=b(M.end)+(at-a.tickIncrement(at,nt,!1,y))/1e6;for(r=at;r<it;r=a.tickIncrement(r,nt,!1,y)){E.push(C.slice()),O.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}O.push(r);var st=E.length,lt=(r-at)/st,ct=function(t){return m.c2r(t,0,y)}(at+lt/2);V&&(W=u(C.length,D,et,P),Z=u(E.length,R,lt,I)),P||\"date\"!==g.type||(D=h(x,D)),I||\"date\"!==m.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,mt=1/0,vt=1/0;for(r=0;r<S;r++){var yt=T[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],X,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),mt=Math.min(mt,xt-O[d]),vt=Math.min(vt,O[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,Z[d]);return{x:T,xRanges:f(z,ut&&ft,dt,gt,g,v),x0:rt,dx:et,y:A,yRanges:f(O,ht&&pt,mt,vt,m,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../histogram/average\":1055,\"../histogram/bin_functions\":1057,\"../histogram/bin_label_vals\":1058,\"../histogram/calc\":1059,\"../histogram/norm_functions\":1066}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./sample_defaults\"),i=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l),!1!==e.visible&&(i(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"../heatmap/style_defaults\":1048,\"./attributes\":1067,\"./sample_defaults\":1072}],1070:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),a=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,i,o,s){var l=n(t,e,r,i,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=a(t.xa,p[0],p[1]),t.yLabel=a(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":798,\"../heatmap/hover\":1042}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":811,\"../heatmap/calc\":1036,\"../heatmap/colorbar\":1038,\"../heatmap/plot\":1046,\"../heatmap/style\":1047,\"../histogram/cross_trace_defaults\":1061,\"../histogram/event_data\":1063,\"./attributes\":1067,\"./defaults\":1069,\"./hover\":1070}],1072:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\");e.exports=function(t,e,r,i){var o=r(\"x\"),s=r(\"y\"),l=a.minRowLength(o),c=a.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],i),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":749,\"../../registry\":881}],1073:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),a=t(\"../contour/attributes\"),i=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:a.autocontour,ncontours:a.ncontours,contours:a.contours,line:{color:a.line.color,width:o({},a.line.width,{dflt:.5}),dash:a.line.dash,smoothing:a.line.smoothing,editType:\"plot\"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../contour/attributes\":978,\"../histogram2d/attributes\":1067}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../histogram2d/sample_defaults\"),i=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l),!1!==e.visible&&(i(t,e,c,(function(r){return n.coerce2(t,e,s,r)})),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":749,\"../contour/contours_defaults\":985,\"../contour/style_defaults\":999,\"../histogram2d/sample_defaults\":1072,\"./attributes\":1073}],1075:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":811,\"../contour/calc\":979,\"../contour/colorbar\":981,\"../contour/hover\":991,\"../contour/plot\":996,\"../contour/style\":998,\"../histogram/cross_trace_defaults\":1061,\"./attributes\":1073,\"./defaults\":1074}],1076:[function(t,e,r){\"use strict\";for(var n=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../lib/extend\").extendFlat,o=t(\"./constants\").colormodel,s=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],l=[],c=[],u=0;u<s.length;u++){var h=o[s[u]];l.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(h.zminDflt||h.min).join(\", \")+\"].\"),c.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(h.zmaxDflt||h.max).join(\", \")+\"].\")}e.exports=i({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:s,editType:\"calc\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:i({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:a({},{keys:[\"z\",\"color\",\"colormodel\"]}),transforms:void 0})},{\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"./constants\":1078}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./constants\"),i=t(\"fast-isnumeric\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../lib\").maxRowLength,l=t(\"image-size\"),c=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX,u=t(\"buffer/\").Buffer;function h(t,e,r,a){return function(i){return n.constrain((i-t)*e,r,a)}}function f(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n,p,d,g;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var m=(p=e.source,d=p.replace(c,\"\"),g=new u(d,\"base64\"),l(g));r=m.height,n=m.width}var v,y=o.getFromId(t,e.xaxis||\"x\"),x=o.getFromId(t,e.yaxis||\"y\"),b=y.d2c(e.x0)-e.dx/2,_=x.d2c(e.y0)-e.dy/2,w=[b,b+n*e.dx],T=[_,_+r*e.dy];if(y&&\"log\"===y.type)for(v=0;v<n;v++)w.push(b+v*e.dx);if(x&&\"log\"===x.type)for(v=0;v<r;v++)T.push(_+v*e.dy);return e._extremes[y._id]=o.findExtremes(y,w),e._extremes[x._id]=o.findExtremes(x,T),e._scaler=function(t){var e=a.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(h(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(f(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),a=0;a<r;a++){var o=n[a];if(!i(o))return!1;n[a]=t._sArray[a](o)}return n}}(e),[{x0:b,y0:_,z:e.z,w:n,h:r}]}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../../snapshot/helpers\":885,\"./constants\":1078,\"buffer/\":111,\"fast-isnumeric\":241,\"image-size\":418}],1078:[function(t,e,r){\"use strict\";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\",\"\"]}}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"./constants\"),o=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX;e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");(e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource)?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=i.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=i.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../lib\":749,\"../../snapshot/helpers\":885,\"./attributes\":1076,\"./constants\":1078}],1080:[function(t,e,r){\"use strict\";e.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},{}],1081:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),a=t(\"../../lib\"),i=t(\"./constants\");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u,h=Math.floor((e-o.x0)/s.dx),f=Math.floor(Math.abs(r-o.y0)/s.dy);if(s._hasZ?u=o.z[f][h]:s._hasSource&&(u=s._canvas.el.getContext(\"2d\").getImageData(h,f,1,1).data),u){var p,d=o.hi||s.hoverinfo;if(d){var g=d.split(\"+\");-1!==g.indexOf(\"all\")&&(g=[\"color\"]),-1!==g.indexOf(\"color\")&&(p=!0)}var m,v=i.colormodel[s.colormodel],y=v.colormodel||s.colormodel,x=y.length,b=s._scaler(u),_=v.suffix,w=[];(s.hovertemplate||p)&&(w.push(\"[\"+[b[0]+_[0],b[1]+_[1],b[2]+_[2]].join(\", \")),4===x&&w.push(\", \"+b[3]+_[3]),w.push(\"]\"),w=w.join(\"\"),t.extraText=y.toUpperCase()+\": \"+w),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[f])?m=s.hovertext[f][h]:Array.isArray(s.text)&&Array.isArray(s.text[f])&&(m=s.text[f][h]);var T=c.c2p(o.y0+(f+.5)*s.dy),k=o.x0+(h+.5)*s.dx,M=o.y0+(f+.5)*s.dy,A=\"[\"+u.slice(0,s.colormodel.length).join(\", \")+\"]\";return[a.extendFlat(t,{index:[f,h],x0:l.c2p(o.x0+h*s.dx),x1:l.c2p(o.x0+(h+1)*s.dx),y0:T,y1:T,color:b,xVal:k,xLabelVal:k,yVal:M,yLabelVal:M,zLabelVal:A,text:m,hovertemplateLabels:{zLabel:A,colorLabel:w,\"color[0]Label\":b[0]+_[0],\"color[1]Label\":b[1]+_[1],\"color[2]Label\":b[2]+_[2],\"color[3]Label\":b[3]+_[3]}})]}}}},{\"../../components/fx\":655,\"../../lib\":749,\"./constants\":1078}],1082:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"image\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},{\"../../plots/cartesian\":811,\"./attributes\":1076,\"./calc\":1077,\"./defaults\":1079,\"./event_data\":1080,\"./hover\":1081,\"./plot\":1083,\"./style\":1084}],1083:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../constants/xmlns_namespaces\"),o=t(\"./constants\"),s=a.isIOS()||a.isSafari()||a.isIE();function l(t){return\"linear\"===t.type&&t.range[1]>t.range[0]==(\"x\"===t._id.charAt(0))}e.exports=function(t,e,r,c){var u=e.xaxis,h=e.yaxis,f=!(s||t._context._exportedPlot);a.makeTraceGroups(c,r,\"im\").each((function(e){var r=n.select(this),s=e[0],c=s.trace,p=f&&!c._hasZ&&c._hasSource&&l(u)&&l(h);c._fastImage=p;var d,g,m,v,y,x,b=s.z,_=s.x0,w=s.y0,T=s.w,k=s.h,M=c.dx,A=c.dy;for(x=0;void 0===d&&x<T;)d=u.c2p(_+x*M),x++;for(x=T;void 0===g&&x>0;)g=u.c2p(_+x*M),x--;for(x=0;void 0===v&&x<k;)v=h.c2p(w+x*A),x++;for(x=k;void 0===y&&x>0;)y=h.c2p(w+x*A),x--;if(g<d&&(m=g,g=d,d=m),y<v&&(m=v,v=y,y=m),!p){d=Math.max(-.5*u._length,d),g=Math.min(1.5*u._length,g),v=Math.max(-.5*h._length,v),y=Math.min(1.5*h._length,y)}var S=Math.round(g-d),E=Math.round(y-v);if(S<=0||E<=0){r.selectAll(\"image\").data([]).exit().remove()}else{var C=r.selectAll(\"image\").data([e]);C.enter().append(\"svg:image\").attr({xmlns:i.svg,preserveAspectRatio:\"none\"}),C.exit().remove(),C.attr(\"style\",\"image-rendering: optimizeSpeed; image-rendering: -moz-crisp-edges; image-rendering: -o-crisp-edges; image-rendering: -webkit-optimize-contrast; image-rendering: optimize-contrast; image-rendering: crisp-edges; image-rendering: pixelated;\");var L=new Promise((function(t){if(c._hasZ)t();else if(c._hasSource)if(c._canvas&&c._canvas.el.width===T&&c._canvas.el.height===k&&c._canvas.source===c.source)t();else{var e=document.createElement(\"canvas\");e.width=T,e.height=k;var r=e.getContext(\"2d\");c._image=c._image||new Image;var n=c._image;n.onload=function(){r.drawImage(n,0,0),c._canvas={el:e,source:c.source},t()},n.setAttribute(\"src\",c.source)}})).then((function(){var t;if(c._hasZ)t=P((function(t,e){return b[e][t]})).toDataURL(\"image/png\");else if(c._hasSource)if(p)t=c.source;else{var e=c._canvas.el.getContext(\"2d\").getImageData(0,0,T,k).data;t=P((function(t,r){var n=4*(r*T+t);return[e[n],e[n+1],e[n+2],e[n+3]]})).toDataURL(\"image/png\")}C.attr({\"xlink:href\":t,height:E,width:S,x:d,y:v})}));t._promises.push(L)}function P(t){var e=document.createElement(\"canvas\");e.width=S,e.height=E;var r,n=e.getContext(\"2d\"),i=function(t){return a.constrain(Math.round(u.c2p(_+t*M)-d),0,S)},l=function(t){return a.constrain(Math.round(h.c2p(w+t*A)-v),0,E)},f=o.colormodel[c.colormodel],p=f.colormodel||c.colormodel,g=f.fmt;for(x=0;x<s.w;x++){var m=i(x),y=i(x+1);if(y!==m&&!isNaN(y)&&!isNaN(m))for(var b=0;b<s.h;b++){var T=l(b),k=l(b+1);k===T||isNaN(k)||isNaN(T)||!t(x,b)||(r=c._scaler(t(x,b)),n.fillStyle=r?p+\"(\"+g(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(m,T,y-m,k-T))}}return e}}))}},{\"../../constants/xmlns_namespaces\":725,\"../../lib\":749,\"./constants\":1078,d3:169}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},{d3:169}],1085:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,a=t(\"../../lib/extend\").extendDeep,i=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",a({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:a({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:i({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":614,\"../../constants/delta.js\":718,\"../../constants/docs\":719,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/layout_attributes\":812,\"../../plots/domain\":825,\"../../plots/font_attributes\":826}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"indicator\",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{\"../../plots/plots\":861}],1087:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var a=e._lastValue,i=a;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(i=e.delta.reference),r[0]={y:n,lastY:a,delta:n-i,relativeDelta:(n-i)/i},r}}},{}],1088:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,i){return n.coerce(t,e,a.gauge.steps,r,i)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}i(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var m,v,y,x,b,_,w=new Array(2);function T(t,e){return n.coerce(y,x,a.gauge,t,e)}function k(t,e){return n.coerce(b,_,a.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),m=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(m||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),v=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(m||v||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),T(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),T(\"bgcolor\",p.paper_bgcolor),T(\"borderwidth\"),T(\"bordercolor\"),T(\"bar.color\"),T(\"bar.line.color\"),T(\"bar.line.width\"),T(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),T(\"threshold.value\"),T(\"threshold.thickness\"),T(\"threshold.line.width\"),T(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),k(\"visible\"),e._range=k(\"range\",e._range);var M={outerTicks:!0};c(b,_,k,\"linear\"),h(b,_,k,\"linear\",M),u(b,_,k,M)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../plots/array_container_defaults\":793,\"../../plots/cartesian/tick_label_defaults\":819,\"../../plots/cartesian/tick_mark_defaults\":820,\"../../plots/cartesian/tick_value_defaults\":821,\"../../plots/domain\":825,\"./attributes\":1085,\"./constants.js\":1088}],1090:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1085,\"./base_plot\":1086,\"./calc\":1087,\"./defaults\":1089,\"./plot\":1091}],1091:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=a.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},m={left:0,center:.5,right:1},v=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each((function(t){d.stroke(n.select(this),t.line.color)})).each((function(t){d.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function b(t,e,r){var n=t._fullLayout,i=a.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return a.coerce(i,o,p,t,e)}return h(i,o,l,s,n),f(i,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function T(t,e,r,a){var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(i);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,a).call(s.font,e),s.bBox(o.node())}function k(t,e,r,n,i,o){var s=\"_cache\"+e;t[s]&&t[s].key===i||(t[s]={key:i,value:r});var l=a.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),a.makeTraceGroups(p._indicatorlayer,e,\"trace\").each((function(e){var h,M,A,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,I=C._isAngular,z=C._isBullet,O=C.domain,D={w:p._size.w*(O.x[1]-O.x[0]),h:p._size.h*(O.y[1]-O.y[0]),l:p._size.l+p._size.w*O.x[0],r:p._size.r+p._size.w*(1-O.x[1]),t:p._size.t+p._size.h*(1-O.y[1]),b:p._size.b+p._size.h*O.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(M=F,P){if(I&&(h=R,M=F+B/2,A=function(t){return function(t,e){var r=Math.sqrt(t.width/2*(t.width/2)+t.height*t.height);return[e/r,t,e]}(t,.9*N)}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*m[j])*D.w,A=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+m[j]*D.w,A=function(t){return w(t,D.w,D.h)};!function(t,e,r,i){var o,l,h,f=r[0].trace,p=i.numbersX,x=i.numbersY,w=f.align||\"center\",M=g[w],A=i.transitionOpts,S=i.onComplete,E=a.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,a){if(!e.match(\"s\")||n>=0==a>=0||r(n).slice(-1).match(v)||r(a).slice(-1).match(v))return r;var i=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=b(t,{tickformat:i});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",(function(){return M})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var I,z=f.mode+f.align;f._hasDelta&&(I=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.prepTicks(e);var a=function(t){return u.tickText(e,t).text},i=function(t){return f.delta.relative?t.relativeDelta:t.delta},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=i(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(i(r[0]),a)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}return p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(A)?p.transition().duration(A.duration).ease(A.easing).tween(\"text\",(function(){var t=n.select(this),e=i(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,a,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}})).each(\"end\",(function(){g(),S&&S()})).each(\"interrupt\",(function(){g(),S&&S()})):g(),l=T(o(i(r[0]),a),f.delta.font,M,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.prepTicks(e);var a=function(t){return u.tickText(e,t).text},i=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+a(r[0].y)+i:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(A)?h.transition().duration(A.duration).ease(A.easing).each(\"end\",(function(){p(),S&&S()})).each(\"interrupt\",(function(){p(),S&&S()})).attrTween(\"text\",(function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,a,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+i)}})):p(),o=T(l+a(r[0].y)+i,f.number.font,M,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var O,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(O=k(f,\"deltaPos\",0,-1*(o.width*m[f.align]+l.width*(1-m[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+O,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(O=k(f,\"deltaPos\",0,o.width*(1-m[f.align])+l.width*m[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+O,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(O=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(O=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),I.attr({dx:O,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",(function(){var t=i.numbersScaler(h);z+=t[2];var e,r=k(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var a=p-r*n;return _(a=k(f,\"numbersTranslate\",0,a,z,Math.max),e)+\" scale(\"+r+\")\"}))}(t,L,e,{numbersX:h,numbersY:M,numbersScaler:A,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(I?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(I?e:[]);H.exit().remove(),I&&function(t,e,r,a){var s,l,c,h,f=r[0].trace,p=a.size,d=a.radius,g=a.innerRadius,m=a.gaugeBg,v=a.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],T=a.gauge,k=a.layer,M=a.transitionOpts,A=a.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=(t-e)/(f.gauge.axis.range[1]-e)*Math.PI-S;return r<-S?-S:r>S?S:r}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",(function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()}))}T.enter().append(\"g\").classed(\"angular\",!0),T.attr(\"transform\",_(w[0],w[1])),k.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),k.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},I={},z=u.makeLabelFns(s,0).labelStandoff;I.xFn=function(t){var e=P(t);return Math.cos(e)*z},I.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},I.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},I.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var O=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return O(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:k,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return O(e)+\"rotate(\"+-i(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:k,transFn:c,labelFns:I})}var R=[m].concat(f.gauge.steps),F=T.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=T.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(M)?(j.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){A&&A()})).each(\"interrupt\",(function(){A&&A()})).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=T.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=T.selectAll(\"g.gauge-outline\").data([v]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var a,i,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,m=n.gaugeOutline,v=n.size,_=h.domain,w=n.transitionOpts,T=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+v.l+\", \"+v.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var k=v.h,M=h.gauge.bar.thickness*k,A=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(a=b(t,h.gauge.axis))._id=\"xbulletaxis\",a.domain=[A,S],a.setScale(),i=u.calcTicks(a),o=u.makeTransFn(a),s=u.getTickSigns(a)[2],c=v.t+v.h,a.visible&&(u.drawTicks(t,a,{vals:\"inside\"===a.ticks?u.clipEnds(a,i):i,layer:p,path:u.makeTickPath(a,c,s),transFn:o}),u.drawLabels(t,a,{vals:i,layer:p,transFn:o,labelFns:u.makeLabelFns(a,c)}));function E(t){t.attr(\"width\",(function(t){return Math.max(0,a.c2p(t.range[1])-a.c2p(t.range[0]))})).attr(\"x\",(function(t){return a.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*k})).attr(\"height\",(function(t){return t.thickness*k}))}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",M).attr(\"y\",(k-M)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",(function(){T&&T()})).each(\"interrupt\",(function(){T&&T()})).attr(\"width\",Math.max(0,a.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,a.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var I=r.filter((function(){return h.gauge.threshold.value})),z=f.selectAll(\"g.threshold-bullet\").data(I);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",a.c2p(h.gauge.threshold.value)).attr(\"x2\",a.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*k).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*k).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var O=f.selectAll(\"g.gauge-outline\").data([m]);O.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),O.select(\"rect\").call(E).call(x),O.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",(function(){return z?g.right:g[C.title.align]})).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",(function(){var t,e=D.l+D.w*m[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(I)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=M-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)}))}))}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../constants/alignment\":717,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/axis_defaults\":800,\"../../plots/cartesian/layout_attributes\":812,\"../../plots/cartesian/position_defaults\":815,\"./constants\":1088,d3:169}],1092:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),showlegend:s({},o.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:i.opacity,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../mesh3d/attributes\":1097}],1093:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),a=t(\"../streamtube/calc\").processGrid,i=t(\"../streamtube/calc\").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=i(e.x,e._len),e._y=i(e.y,e._len),e._z=i(e.z,e._len),e._value=i(e.value,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":623,\"../streamtube/calc\":1264}],1094:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),a=t(\"../../lib/gl_format_color\").parseColorScale,i=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),a=Math.max(e[r],e[r-1]);if(a>n&&n<t&&t<=a)return{id:r,distRatio:(a-t)/(a-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],a=this.data._meshZ[e],i=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(a,this.data._Zs).id,h=t.index=u+o*c+o*i*s;t.traceCoordinate=[this.data._meshX[h],this.data._meshY[h],this.data._meshZ[h],this.data._value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=f(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:i(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=a(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var h=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function f(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,a,i,o,s,c=t.surface.show,u=t.spaceframe.show,f=t.surface.fill,p=t.spaceframe.fill,d=!1,g=!1,m=0,v=t._Xs,y=t._Ys,x=t._Zs,b=v.length,_=y.length,w=x.length,T=h.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function C(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===a[c]&&s===i[c])return c;return-1}function L(){r=e}function P(){n=[],a=[],i=[],o=[],e=0,L()}function I(t,r,s,l){return n.push(t),a.push(r),i.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],a=0;a<t.length;a++)n[a]=t[a]*(1-r)+r*e[a];return n}function O(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){L();var a,i,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],a=t[2],i=function(t,e,r){for(var n=[],a=0;a<t.length;a++)n[a]=(t[a]+e[a]+r[a])/3;return n}(r,n,a),o=Math.sqrt(1-s),l=z(i,r,o),c=z(i,n,o),u=z(i,a,o),h=e[0],f=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,a,u],[u,c,n],[a,r,l],[l,u,a]],abc:[[h,f,-1],[-1,-1,h],[f,p,-1],[-1,-1,f],[p,h,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var h=0;h<l.length;h++){r=l[h],n=c[h];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:C(d,g,v);f[p]=x>-1?x:I(d,g,v,R(e,y))}a=f[0],i=f[1],o=f[2],t._meshI.push(a),t._meshJ.push(i),t._meshK.push(o),++m}}function B(t,e,r,n){var a=t[3];a<r&&(a=r),a>n&&(a=n);for(var i=(t[3]-a)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-i)*t[s]+i*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var a=e[n];r.push([t._x[a],t._y[a],t._z[a],t._value[a]])}return r}function V(t,e,r,n,a,i){i||(i=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,a),N(e[1][3],n,a),N(e[2][3],n,a)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):i<3&&V(t,e,r,S,E,++i)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(i){if(s[i[0]]&&s[i[1]]&&!s[i[2]]){var u=e[i[0]],h=e[i[1]],f=e[i[2]],p=B(f,u,n,a),d=B(f,h,n,a);o=l(t,[d,p,u],[-1,-1,r[i[0]]])||o,o=l(t,[u,h,d],[r[i[0]],r[i[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(i){if(s[i[0]]&&!s[i[1]]&&!s[i[2]]){var u=e[i[0]],h=e[i[1]],f=e[i[2]],p=B(h,u,n,a),d=B(f,u,n,a);o=l(t,[d,p,u],[-1,-1,r[i[0]]])||o,c=!0}})),o}function q(t,e,r,n){var a=!1,i=U(e),o=[N(i[0][3],r,n),N(i[1][3],r,n),N(i[2][3],r,n),N(i[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return a;if(o[0]&&o[1]&&o[2]&&o[3])return g&&(a=function(t,e,r){var n=function(n,a,i){F(t,[e[n],e[a],e[i]],[r[n],r[a],r[i]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,i,e)||a),a;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=i[l[0]],u=i[l[1]],h=i[l[2]],f=i[l[3]];if(g)a=F(t,[c,u,h],[e[l[0]],e[l[1]],e[l[2]]])||a;else{var p=B(f,c,r,n),d=B(f,u,r,n),m=B(f,h,r,n);a=F(null,[p,d,m],[-1,-1,-1])||a}s=!0}})),s?a:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=i[l[0]],u=i[l[1]],h=i[l[2]],f=i[l[3]],p=B(h,c,r,n),d=B(h,u,r,n),m=B(f,u,r,n),v=B(f,c,r,n);g?(a=F(t,[c,v,p],[e[l[0]],-1,-1])||a,a=F(t,[u,d,m],[e[l[1]],-1,-1])||a):a=function(t,e,r){var n=function(n,a,i){F(t,[e[n],e[a],e[i]],[r[n],r[a],r[i]])};n(0,1,2),n(2,3,0)}(null,[p,d,m,v],[-1,-1,-1,-1])||a,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=i[l[0]],u=i[l[1]],h=i[l[2]],f=i[l[3]],p=B(u,c,r,n),d=B(h,c,r,n),m=B(f,c,r,n);g?(a=F(t,[c,p,d],[e[l[0]],-1,-1])||a,a=F(t,[c,d,m],[e[l[0]],-1,-1])||a,a=F(t,[c,m,p],[e[l[0]],-1,-1])||a):a=F(null,[p,d,m],[-1,-1,-1])||a,s=!0}})),a)}function H(t,e,r,n,a,i,o,s,l,c,u){var h=!1;return d&&(D(t,\"A\")&&(h=q(null,[e,r,n,i],c,u)||h),D(t,\"B\")&&(h=q(null,[r,n,a,l],c,u)||h),D(t,\"C\")&&(h=q(null,[r,i,o,l],c,u)||h),D(t,\"D\")&&(h=q(null,[n,i,s,l],c,u)||h),D(t,\"E\")&&(h=q(null,[r,n,i,l],c,u)||h)),g&&(h=q(t,[r,n,i,l],c,u)||h),h}function G(t,e,r,n,a,i,o,s){return[!0===s[0]||V(t,U([e,r,n]),[e,r,n],i,o),!0===s[1]||V(t,U([n,a,e]),[n,a,e],i,o)]}function Y(t,e,r,n,a,i,o,s,l){return s?G(t,e,r,a,n,i,o,l):G(t,r,a,n,e,i,o,l)}function W(t,e,r,n,a,i,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],a,i)||h,h=V(t,[c,u,s],[-1,-1,-1],a,i)||h},p=o[0],d=o[1],g=o[2];return p&&(s=z(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=z(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=z(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=z(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),f()),d&&(s=z(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=z(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=z(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=z(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),f()),g&&(s=z(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],g),l=z(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],g),c=z(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],g),u=z(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],g),f()),h}function Z(t,e,r,n,a,i,o,s,l,c,u,h){var f=t;return h?(d&&\"even\"===t&&(f=null),H(f,e,r,n,a,i,o,s,l,c,u)):(d&&\"odd\"===t&&(f=null),H(f,l,s,o,i,a,n,r,e,c,u))}function X(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)i.push(Y(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,a&&a[o]?a[o]:[])),o++;return i}function J(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)i.push(Y(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,a&&a[o]?a[o]:[])),o++;return i}function K(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)i.push(Y(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,a&&a[o]?a[o]:[])),o++;return i}function Q(t,e,r){for(var n=1;n<w;n++)for(var a=1;a<_;a++)for(var i=1;i<b;i++)Z(t,k(i-1,a-1,n-1),k(i-1,a-1,n),k(i-1,a,n-1),k(i-1,a,n),k(i,a-1,n-1),k(i,a-1,n),k(i,a,n-1),k(i,a,n),e,r,(i+a+n)%2)}function $(t,e,r){d=!0,Q(t,e,r),d=!1}function tt(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var h=1;h<_;h++)o.push(W(t,c,h,u,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function et(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var h=1;h<w;h++)o.push(W(t,u,c,h,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function rt(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var h=1;h<b;h++)o.push(W(t,h,u,c,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(P(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var a=k(e,r,n);I(t._x[a],t._y[a],t._z[a],t._value[a])}}(),u&&p&&(O(p),g=!0,Q(null,S,E),g=!1),c&&f){O(f);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var h=1===r?.5:s/(r-1),d=(1-h)*S+h*E,T=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];$(e,T[0],T[1])}}var C=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];[\"x\",\"y\",\"z\"].forEach((function(e){for(var r=[],n=0;n<C.length;n++){var a=0,i=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){O(s.fill);var c=[],u=[],h=[];if(s.locations.length)for(var f=0;f<s.locations.length;f++){var p=l(s.locations[f],\"x\"===e?v:\"y\"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),\"x\"===e?h.push([p.distRatio,0,0]):\"y\"===e?h.push([0,p.distRatio,0]):h.push([0,0,p.distRatio]))}else c=nt(1,\"x\"===e?b-1:\"y\"===e?_-1:w-1);u.length>0&&(r[a]=\"x\"===e?tt(null,u,i,o,h,r[a]):\"y\"===e?et(null,u,i,o,h,r[a]):rt(null,u,i,o,h,r[a]),a++),c.length>0&&(r[a]=\"x\"===e?X(null,c,i,o,r[a]):\"y\"===e?J(null,c,i,o,r[a]):K(null,c,i,o,r[a]),a++)}var d=t.caps[e];d.show&&d.fill&&(O(d.fill),r[a]=\"x\"===e?X(null,[0,b-1],i,o,r[a]):\"y\"===e?J(null,[0,_-1],i,o,r[a]):K(null,[0,w-1],i,o,r[a]),a++)}})),0===m&&P(),t._meshX=n,t._meshY=a,t._meshZ=i,t._meshIntensity=o,t._Xs=v,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:f,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new c(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}}},{\"../../components/colorscale\":627,\"../../lib/gl_format_color\":745,\"../../lib/str2rgbarray\":772,\"../../plots/gl3d/zip3\":851,\"gl-mesh3d\":292}],1095:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\"),i=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,i){var s=i(\"isomin\"),l=i(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=i(\"x\"),u=i(\"y\"),h=i(\"z\"),f=i(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach((function(t){var e=\"caps.\"+t;i(e+\".show\")&&i(e+\".fill\");var r=\"slices.\"+t;i(r+\".show\")&&(i(r+\".fill\"),i(r+\".locations\"))})),i(\"spaceframe.show\")&&i(\"spaceframe.fill\"),i(\"surface.show\")&&(i(\"surface.count\"),i(\"surface.fill\"),i(\"surface.pattern\")),i(\"contour.show\")&&(i(\"contour.color\"),i(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){i(t)})),o(t,e,n,i,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,a){s(t,e,r,a,(function(r,a){return n.coerce(t,e,i,r,a)}))},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"../../registry\":881,\"./attributes\":1092}],1096:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":840,\"./attributes\":1092,\"./calc\":1093,\"./convert\":1094,\"./defaults\":1095}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:a({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:i.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},i.contours.x.show,{}),color:i.contours.x.color,width:i.contours.x.width,editType:\"calc\"},lightposition:{x:s({},i.lightposition.x,{dflt:1e5}),y:s({},i.lightposition.y,{dflt:1e5}),z:s({},i.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},i.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"}),showlegend:s({},o.showlegend,{dflt:!1})})},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../surface/attributes\":1280}],1098:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":623}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),a=t(\"delaunay-triangulate\"),i=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var a=[],i=e.length,o=0;o<i;o++)a[o]=t.d2l(e[o],0,n)*r;return a}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function m(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!m(t.i,h)||!m(t.j,h)||!m(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?i(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],i=e.length,o=0;o<i;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return a(n)}(t.delaunayaxis,f);var v={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\";var x=t.intensitymode;v[x+\"Intensity\"]=t.intensity,v[x+\"IntensityBounds\"]=[y.min,y.max],v.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=p(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color));this.mesh.update(v)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new h(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{\"../../components/colorscale\":627,\"../../lib/gl_format_color\":745,\"../../lib/str2rgbarray\":772,\"../../plots/gl3d/zip3\":851,\"alpha-shape\":69,\"convex-hull\":135,\"delaunay-triangulate\":171,\"gl-mesh3d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return a.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&a.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),i(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"../../registry\":881,\"./attributes\":1097}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":840,\"./attributes\":1097,\"./calc\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,a=t(\"../scatter/attributes\"),i=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=a.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:i,editType:\"style\"},editType:\"style\"}}e.exports={xperiod:a.xperiod,xperiod0:a.xperiod0,xperiodalignment:a.xperiodalignment,x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},i,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":636,\"../../components/fx/attributes\":646,\"../../constants/delta.js\":718,\"../../lib\":749,\"../scatter/attributes\":1156}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=n._,i=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),h=l.makeCalcdata(e,\"high\"),f=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=Array.isArray(e.text),g=Array.isArray(e.hovertext),m=!0,v=null,y=!!e.xperiodalignment,x=[],b=0;b<o.length;b++){var _=o[b],w=u[b],T=h[b],k=f[b],M=p[b];if(_!==s&&w!==s&&T!==s&&k!==s&&M!==s){M===w?null!==v&&M!==v&&(m=M>v):m=M>w,v=M;var A=c(w,T,k,M);A.pos=_,A.yc=(w+M)/2,A.i=b,A.dir=m?\"increasing\":\"decreasing\",A.x=A.pos,A.y=[k,T],y&&(A.orig_p=r[b]),d&&(A.tx=e.text[b]),g&&(A.htx=e.hovertext[b]),x.push(A)}else x.push({pos:_,empty:!0})}return e._extremes[l._id]=i.findExtremes(l,n.concat(f,h),{padded:!0}),x.length&&(x[0].t={labels:{open:a(t,\"open:\")+\" \",high:a(t,\"high:\")+\" \",low:a(t,\"low:\")+\" \",close:a(t,\"close:\")+\" \"}}),x}e.exports={calc:function(t,e){var r=i.getFromId(t,e.xaxis),a=i.getFromId(t,e.yaxis),s=function(t,e,r){var a=r._minDiff;if(!a){var i,s=t._fullData,l=[];for(a=1/0,i=0;i<s.length;i++){var c=s[i];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var h=o(r,e,\"x\",u);c._xcalc=h;var f=n.distinctVals(h).minDiff;f&&isFinite(f)&&(a=Math.min(a,f))}}for(a===1/0&&(a=1),i=0;i<l.length;i++)l[i]._minDiff=a}return a*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var h=e._origX;e._origX=null;var f=e._xcalc;e._xcalc=null;var p=c(t,e,h,f,a,l);return e._extremes[r._id]=i.findExtremes(r,f,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798}],1104:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./ohlc_defaults\"),i=t(\"../scatter/period_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,o,r,a)}a(t,e,c,l)?(i(t,e,l,c,{x:!0}),c(\"line.width\"),c(\"line.dash\"),s(t,e,c,\"increasing\"),s(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":749,\"../scatter/period_defaults\":1176,\"./attributes\":1102,\"./ohlc_defaults\":1107}],1105:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),i=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var a,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,m=h.bdPos||h.tickLen,v=h.wHover,y=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function x(t){var r=function(t){return t.pos+g-e}(t);return i.inbox(r-v,r+v,a)}function b(t){var e=t[p],n=t[d];return e===n||i.inbox(e-r,n-r,a)}function _(t){return(x(t)+b(t))/2}a=t.maxHoverDistance-y,s=t.maxSpikeDistance-y;var w=i.getDistanceFunction(n,x,b,_);if(i.getClosest(l,w,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var k=u[T.dir],M=k.line.color;return o.opacity(M)&&k.line.width?t.color=M:t.color=k.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=void 0!==T.orig_p?T.orig_p:T.pos,t.spikeDistance=_(T)*s/a,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,i){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,i);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],m={},v=0;v<g.length;v++){var y,x=g[v],b=l[x][f.index],_=s.c2p(b,!0);b in m?(y=m[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=a.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),m[b]=y)}return h}function f(t,e,r,a){var i=t.cd,o=t.ya,l=i[0].trace,h=i[0].t,f=u(t,e,r,a);if(!f)return[];var p=i[f.index],d=f.index=p.i,g=p.dir;function m(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var v=p.hi||l.hoverinfo,y=v.split(\"+\"),x=\"all\"===v,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[m(\"open\"),m(\"high\"),m(\"low\"),m(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":615,\"../../components/fx\":655,\"../../constants/delta.js\":718,\"../../lib\":749,\"../../plots/cartesian/axes\":798}],1106:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":811,\"./attributes\":1102,\"./calc\":1103,\"./defaults\":1104,\"./hover\":1105,\"./plot\":1108,\"./select\":1109,\"./style\":1110}],1107:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\");e.exports=function(t,e,r,i){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],i),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,a.minRowLength(o))),e._length=h,h}}},{\"../../lib\":749,\"../../registry\":881}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\");e.exports=function(t,e,r,i){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;a.makeTraceGroups(i,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],i=r.t;if(!0!==r.trace.visible||i.empty)e.remove();else{var c=i.tickLen,u=e.selectAll(\"path\").data(a.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},{\"../../lib\":749,d3:169}],1109:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,a=t.xaxis,i=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([a.c2p(l.pos+s),i.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:a.c2d(l.pos),y:i.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1110:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(i.stroke,r.color).call(a.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},{\"../../components/color\":615,\"../../components/drawing\":637,d3:169}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,a=t(\"../../plots/attributes\"),i=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},a.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:i({editType:\"calc\"}),tickfont:i({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/domain\":825,\"../../plots/font_attributes\":826,\"../../plots/template_attributes\":876}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,i){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];a(t,s,r,i)}},r.clean=function(t,e,r,n){var a=n._has&&n._has(\"parcats\"),i=e._has&&e._has(\"parcats\");a&&!i&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":835,\"./plot\":1117}],1113:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,a=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"fast-isnumeric\");function u(t,e,r){t.valueInds.push(e),t.count+=r}function h(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function f(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,g,m=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},a=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var i=0;i<t.length;i++){var o,s=t[i];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),a.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:a}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map((function(t){return t.displayindex}))))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,m[e])}));var v,y=e.line;y?(a(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),v=s.tryColorscale(y)):v=l.identity;var x,b,_,w,T,k=r[0].values.length,M={},A=m.map((function(t){return t.inds}));for(g=0,x=0;x<k;x++){var S=[];for(b=0;b<A.length;b++)S.push(A[b][x]);d=p[x%p.length],g+=d;var E=(_=x,w=void 0,T=void 0,l.isArrayOrTypedArray(y.color)?T=w=y.color[_%y.color.length]:w=y.color,{color:v(w),rawColor:T}),C=S+\"-\"+E.rawColor;void 0===M[C]&&(M[C]=h(S,E.color,E.rawColor)),f(M[C],x,d)}var L,P=r.map((function(t,e){return function(t,e,r,n,a){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:a,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,g)}));for(x=0;x<k;x++)for(d=p[x%p.length],b=0;b<P.length;b++){var I=P[b].containerInd,z=m[b].inds[x],O=P[b].categories;if(void 0===O[z]){var D=e.dimensions[I]._categoryarray[z],R=e.dimensions[I]._ticktext[z];O[z]={dimensionInd:b,categoryInd:L=z,categoryValue:D,displayInd:L,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(O[z],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(P,M,g))}},{\"../../components/colorscale/calc\":623,\"../../components/colorscale/helpers\":626,\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/filter_unique.js\":740,\"../../lib/gup\":746,\"fast-isnumeric\":241}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,a){return n.coerce(t,e,l.dimensions,r,a)}var a=r(\"values\"),i=r(\"visible\");if(a&&a.length||(i=e.visible=!1),i){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,a){return n.coerce(t,e,l,r,a)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(a(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),i(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var m={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",m)}},{\"../../components/colorscale/defaults\":625,\"../../components/colorscale/helpers\":626,\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../../plots/domain\":825,\"../parcoords/merge_length\":1127,\"./attributes\":1111}],1115:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1111,\"./base_plot\":1112,\"./calc\":1113,\"./defaults\":1114,\"./plot\":1117}],1116:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../plot_api/plot_api\"),i=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,a){var i=t.map(D.bind(0,e,r)),l=a.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(i,h),m=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",(function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"})),m.append(\"g\").attr(\"class\",\"paths\");var v=u.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),h);v.attr(\"fill\",(function(t){return t.model.color}));var b=v.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);x(b),v.attr(\"d\",(function(t){return t.svgD})),b.empty()||v.sort(p),v.exit().remove(),v.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",y),m.append(\"g\").attr(\"class\",\"dimensions\");var T=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),h);T.enter().append(\"g\").attr(\"class\",\"dimension\"),T.attr(\"transform\",(function(t){return\"translate(\"+t.x+\", 0)\"})),T.exit().remove();var k=T.selectAll(\"g.category\").data((function(t){return t.categories}),h),M=k.enter().append(\"g\").attr(\"class\",\"category\");k.attr(\"transform\",(function(t){return\"translate(0, \"+t.y+\")\"})),M.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),k.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),_(M);var A=k.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h);A.each((function(){o.raiseToTop(this)})),A.attr(\"fill\",(function(t){return t.color}));var I=A.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);A.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),w(I),A.exit().remove(),M.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;k.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return f(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return f(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)})),M.append(\"text\").attr(\"class\",\"dimlabel\"),k.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)})),k.selectAll(\"rect.bandrect\").on(\"mouseover\",S).on(\"mouseout\",E),k.exit().remove(),T.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",C).on(\"drag\",L).on(\"dragend\",P)),u.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),b(n.select(this));var e=m(t),r=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var a,s,c,u=n.mouse(this)[0],h=t.parcatsViewModel.graphDiv,f=t.parcatsViewModel.trace,p=h._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(c=0;c<t.leftXs.length-1;c++)if(t.leftXs[c]+t.dimWidths[c]-2<=u&&u<=t.leftXs[c+1]+2){var y=t.parcatsViewModel.dimensions[c],x=t.parcatsViewModel.dimensions[c+1];a=(y.x+y.width+x.x)/2,s=(t.topYs[c]+t.topYs[c+1]+t.height)/2;break}var _=t.parcatsViewModel.x+a,w=t.parcatsViewModel.y+s,T=l.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,M=k/t.parcatsViewModel.model.count,A={countLabel:k,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",A.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",A.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),C=n.mouse(h)[0];i.loneHover({trace:f,x:_-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:C<_?\"right\":\"left\",hovertemplate:(f.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:f._input,fullData:f,count:k,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:h})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(x(n.select(this)),i.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=m(t),r=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function m(t){for(var e=[],r=I(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var a=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:a})}return e}function v(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var a=r[n],i=a.categories[t.model.categoryInds[n]];e[a.containerInd]=i.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function y(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=m(t),r=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function x(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function b(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function _(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function w(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function T(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function k(t,e,r){var a=n.select(t).datum(),i=a.categoryViewModel.model,o=a.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){T(t).each((function(t){Array.prototype.push.apply(l,m(t))}))}));var c={};c[i.dimensionInd]=i.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function M(t,e,r){var a=n.select(t).datum(),i=a.categoryViewModel.model,o=a.parcatsViewModel.graphDiv,s=T(a),l=[];s.each((function(t){Array.prototype.push.apply(l,m(t))}));var c={};c[i.dimensionInd]=i.categoryValue,void 0!==a.rawColor&&(c.color=a.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function A(t,e){var r,a,i=n.select(e.parentNode).select(\"rect.catrect\"),o=i.node().getBoundingClientRect(),s=i.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,a=\"left\"):(r=o.left+o.width,a=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},m=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&m.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&m.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var v=m.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:v,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function S(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,a=r._fullLayout,s=a._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=T(e);b(r),r.each((function(){o.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(this),M(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=T(t);b(e),e.each((function(){o.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,a,i=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=i.y+i.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=i.left,a=\"left\"):(r=i.left+i.width,a=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach((function(t){t.color===o.color&&(g+=t.count)}));var m=s.model.count,v=0;c.pathSelection.each((function(t){t.model.color===o.color&&(v+=t.model.count)}));var y=g/d,x=g/v,b=g/m,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var T=w.join(\"<br>\"),k=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:T,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:k,fontSize:10,idealAlign:a,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:m,colorcount:v,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){r.push(A(t,this))})),r}(s,this)),e&&i.loneHover(e,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r})}}function E(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(x(e.pathSelection),_(e.dimensionSelection.selectAll(\"g.category\")),w(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),i.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?M(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function C(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],a=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=a&&a<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<a&&a<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,i.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,a=e+1,i=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=i.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=i.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){i.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[a];void 0!==f&&i.model.dragX<f.x+f.width&&(i.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&i.model.dragX+i.width>p.x&&(i.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=i.model.displayInd}B(t.parcatsViewModel),F(t.parcatsViewModel),O(t.parcatsViewModel),z(t.parcatsViewModel)}}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=I(t.parcatsViewModel),i=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==i[e]}));o&&i.forEach((function(r,n){var a=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+a+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),h=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,B(t.parcatsViewModel),F(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){O(t.parcatsViewModel,!0),z(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&a.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function I(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function z(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function O(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),h);var a=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),h);r(t.dimensionSelection).attr(\"transform\",(function(t){return\"translate(\"+t.x+\", 0)\"})),r(a).attr(\"transform\",(function(t){return\"translate(0, \"+t.y+\")\"})),a.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),a.select(\".catlabel\").attr(\"text-anchor\",(function(t){return f(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return f(t)?t.width+5:-5})).each((function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var i=a.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h),s=i.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);i.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),w(s),i.each((function(){o.raiseToTop(this)})),i.exit().remove()}function D(t,e,r){var n,a=r[0],i=e.margin||{l:80,r:80,t:100,b:80},o=a.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+i.l,p=e.height-s.y[1]*e.height+i.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:a,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:i,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return a.dimensions&&(B(g),F(g)),g}function R(t,e,r,a,i){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(i)),c.push(o(1-i));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+a+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+a)+\" \"+l[s]+\",\"+(e[s]+a)+\" \"+(t[s]+r[s])+\",\"+(e[s]+a),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function F(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),a=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),i=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map((function(t,e){return a[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=h(e),a=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),a.reverse()),n.push(e.valueInds[0]),a.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),a.unshift(r.rawColor)),n<a?-1:n>a?1:0}));for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),g=0;g<c.length;g++){var m,v=c[g];m=p>0?d*(v.count/p):0;for(var y,x=new Array(n.length),b=0;b<v.categoryInds.length;b++){var _=v.categoryInds[b],w=a[b][_],T=i[b];x[T]=n[T][w],n[T][w]+=m;var k=t.dimensions[T].categories[w],M=k.bands.length,A=k.bands[M-1];if(void 0===A||v.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;k.bands.push({key:S,color:v.color,rawColor:v.rawColor,height:m,width:k.width,count:v.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[M-1];E.height+=m,E.count+=v.count}}y=\"hspline\"===t.pathShape?R(s,x,l,m,.5):R(s,x,l,m,0),f[g]={key:v.valueInds[0],model:v,height:m,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function B(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var a=e[n].dimensionInd,i=t.model.dimensions[a];r.push(N(t,i))}t.dimensions=r}function N(t,e){var r,n=t.model.dimensions.length,a=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*a;var i,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,m=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(m.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<f;c++)l=m[c].categoryInd,o=e.categories[l],i=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:i,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+i+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":637,\"../../components/fx\":655,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plot_api/plot_api\":784,d3:169,tinycolor2:548}],1117:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,a){var i=t._fullLayout,o=i._paper,s=i._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,a)}},{\"./parcats\":1116}],1118:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:i({editType:\"plot\"}),tickfont:i({editType:\"plot\"}),rangefont:i({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},a.tickvals,{editType:\"plot\"}),ticktext:s({},a.ticktext,{editType:\"plot\"}),tickformat:s({},a.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/layout_attributes\":812,\"../../plots/domain\":825,\"../../plots/font_attributes\":826}],1119:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"d3\"),i=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var a=t?-1:1,i=0,o=e.length-1;if(a<0){var s=i;i=o,o=s}for(var l=e[i],u=l,f=i;a*f<a*o;f+=a){var p=f+a,d=e[p];if(a*r<a*h(l,d))return c(l,u);if(a*r<a*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,a=m(t.brush.filter.getConsolidated(),t.height),i=[0],o=a.length?a[0][0]:null,s=0;s<a.length;s++)r=(e=a[s])[1]-e[0],i.push(o),i.push(r),(n=s+1)<a.length&&(o=a[n][0]-e[1]);return i.push(t.height),i}function m(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function v(){a.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=a.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,a=t.brush,i=NaN,o={};if(a.filterSpecified){var s=t.height,l=a.filter.getConsolidated(),c=m(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(i=u,isNaN(i)&&(i=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(i)){var d=c[i],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[i],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var v=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<v.length;r++){var x=[.25*v[Math.max(r-1,0)]+.75*v[r],.25*v[Math.min(r+1,v.length-1)]+.75*v[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){a.event.sourceEvent.stopPropagation();var r=e.height-a.mouse(t)[1]-2*n.verticalPadding,i=e.brush.svgBrush;i.wasDragged=!0,i._dragging=!0,i.grabbingBar?i.newExtent=[r-i.grabPoint,r+i.barLength-i.grabPoint].map(e.unitToPaddedPx.invert):i.newExtent=[i.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,i.extent=i.stayingIntervals.concat([i.newExtent]),i.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-a.mouse(t)[1]-2*n.verticalPadding),i=\"crosshair\";r.clickableOrdinalRange?i=\"pointer\":r.region&&(i=r.region+\"-resize\"),a.select(document.body).style(\"cursor\",i)}function T(t){t.on(\"mousemove\",(function(t){a.event.preventDefault(),t.parent.inBrushDrag||w(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||v()})).call(a.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){a.event.sourceEvent.stopPropagation();var r=e.height-a.mouse(t)[1]-2*n.verticalPadding,i=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:i,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){_(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,i=r.svgBrush;i._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),i._dragging=!1,a.event.sourceEvent.stopPropagation();var o=i.grabbingBar;if(i.grabbingBar=!1,i.grabLocation=void 0,e.parent.inBrushDrag=!1,v(),!i.wasDragged)return i.wasDragged=void 0,i.clickableOrdinalRange?r.filterSpecified&&e.multiselect?i.extent.push(i.clickableOrdinalRange):(i.extent=[i.clickableOrdinalRange],r.filterSpecified=!0):o?(i.extent=i.stayingIntervals,0===i.extent.length&&M(r)):M(r),i.brushCallback(e),x(t.parentNode),void i.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),i.newExtent=[f(0,l,i.newExtent[0],i.stayingIntervals),f(1,l,i.newExtent[1],i.stayingIntervals)];var c=i.newExtent[1]>i.newExtent[0];i.extent=i.stayingIntervals.concat(c?[i.newExtent]:[]),i.extent.length||M(r),i.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();i.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function k(t,e){return t[0]-e[0]}function M(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function A(t){for(var e,r=t.slice(),n=[],a=r.shift();a;){for(e=a.slice();(a=r.shift())&&a[0]<=e[1];)e[1]=Math.max(e[1],a[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}e.exports={makeBrush:function(t,e,r,n,a,i){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(k)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=A(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=a,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e).slice();e.filter.set(r),o()}),brushEndCallback:i}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,i);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(T).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",(function(t){return t.height})).call(y);var a=t.selectAll(\".highlight\").data(o);a.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),a.attr(\"y1\",(function(t){return t.height})).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?A(t.sort(k)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":749,\"../../lib/gup\":746,\"./constants\":1122,d3:169}],1120:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=a(t.calcdata,\"parcoords\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var a=n._has&&n._has(\"parcoords\"),i=e._has&&e._has(\"parcoords\");a&&!i&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},{\"../../constants/xmlns_namespaces\":725,\"../../plots/get_data\":835,\"./plot\":1129,d3:169}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../components/colorscale\"),i=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return a.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=a.extractOpts(e.line).colorscale,a.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),i({lineColor:r,cscale:o})}},{\"../../components/colorscale\":627,\"../../lib\":749,\"../../lib/gup\":746}],1122:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1123:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,a){function i(r,a){return n.coerce(t,e,c.dimensions,r,a)}var o=i(\"values\"),s=i(\"visible\");if(o&&o.length||(s=e.visible=!1),s){i(\"label\"),i(\"tickvals\"),i(\"ticktext\"),i(\"tickformat\");var h=i(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,a.layout),i(\"multiselect\");var f=i(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,a){return n.coerce(t,e,c,r,a)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),m=function(t,e,r,o,s){var l=s(\"line.color\",r);if(a(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),i(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",m);var v={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",v),n.coerceFont(u,\"tickfont\",v),n.coerceFont(u,\"rangefont\",v),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":625,\"../../components/colorscale/helpers\":626,\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../../plots/cartesian/axes\":798,\"../../plots/domain\":825,\"./attributes\":1118,\"./axisbrush\":1119,\"./constants\":1122,\"./merge_length\":1127}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":749}],1125:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1118,\"./base_plot\":1120,\"./calc\":1121,\"./defaults\":1123,\"./plot\":1129}],1126:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function h(t,e,r,n,a){var i=t._gl;i.enable(i.SCISSOR_TEST),i.scissor(e,r,n,a),t.clear({color:[0,0,0,0],depth:1})}function f(t,e,r,n,a,i){var o=i.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,a-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],h(t,i.scissorX,i.scissorY,i.scissorWidth,i.viewBoxSize[1])),r.clearOnly||(i.count=2*c,i.offset=2*l*n,e(i),l*n+c<a&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function g(t,e,r){for(var n=new Array(8*e),a=0,i=0;i<e;i++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*i+l];63===l&&0===o&&(c*=-1),n[a++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function v(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function y(t,e,r,n,a,i,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===a?1:0,d[1][g]=g===i?1:0;var m=t.lines.canvasOverdrag,v=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+m,l],viewBoxSize:[c,u],i0:a,i1:i,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+m)+(t.pad.l-m)+t.layoutWidth*v.x[0],scissorWidth:(n===r?y-o+m:c+.5)+(n===e?o+m:0),scissorY:l+t.pad.b+t.layoutHeight*v.y[0],scissorHeight:u,viewportX:t.pad.l-m+t.layoutWidth*v.x[0],viewportY:t.pad.b+t.layoutHeight*v.y[0],viewportWidth:y,viewportHeight:x},p)}function x(t){var e=Math.max(0,Math.floor(2047*t[0]),0),r=Math.min(2047,Math.ceil(2047*t[1]),2047);return[Math.min(e,r),Math.max(e,r)]}e.exports=function(t,e){var r,n,l,m,b,_=e.context,w=e.pick,T=e.regl,k={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[v(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),A=T.texture(u),S=[];C(e);var E=T({profile:!1,blend:{enable:_,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!_,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:a,frag:i,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:A,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function C(t){r=t.model,n=t.viewModel,l=n.dimensions.slice(),m=l[0]?l[0].values.length:0;var e=r.lines,a=w?e.color.map((function(t,r){return r/e.color.length})):e.color,i=function(t,e,r){for(var n,a=new Array(t*(o+4)),i=0,s=0;s<t;s++){for(var l=0;l<o;l++)a[i++]=l<e.length?e[l].paddedUnitValues[s]:.5;a[i++]=d(s,2),a[i++]=d(s,1),a[i++]=d(s,0),a[i++]=(n=r[s],Math.max(1e-6,Math.min(.999999,n)))}return a}(m,l,a);!function(t,e,r){for(var n=0;n<=o;n+=4)t[v(n)](g(n/4,e,r))}(M,m,i),_||w||(A=T.texture(s.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var a,i,o,s=t.length,c=1/0,u=-1/0;for(a=0;a<s;a++)t[a].dim0.canvasX<c&&(c=t[a].dim0.canvasX,i=a),t[a].dim1.canvasX>u&&(u=t[a].dim1.canvasX,o=a);0===s&&h(T,0,0,r.canvasWidth,r.canvasHeight);var p=function(t){var e,r,n,a=[[],[]];for(n=0;n<64;n++){var i=!t&&n<l.length?l[n].brush.filter.getBounds():[-1/0,1/0];a[0][n]=i[0],a[1][n]=i[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<l.length;e++){var s=e%8,c=(e-s)/8,u=Math.pow(2,s),h=l[e].brush.filter.get();if(!(h.length<2)){var f=x(h[0])[1];for(r=1;r<h.length;r++){var p=x(h[r]);for(n=f+1;n<p[0];n++)o[8*n+c]&=~u;f=Math.max(f,p[1])}}}var d={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(d):b=T.texture(d),{maskTexture:b,maskHeight:2048,loA:a[0].slice(0,16),loB:a[0].slice(16,32),loC:a[0].slice(32,48),loD:a[0].slice(48,64),hiA:a[1].slice(0,16),hiB:a[1].slice(16,32),hiC:a[1].slice(32,48),hiD:a[1].slice(48,64)}}(_);for(a=0;a<s;a++){var d=t[a],g=d.dim0.crossfilterDimensionIndex,v=d.dim1.crossfilterDimensionIndex,M=d.canvasX,A=d.canvasY,C=M+d.panelSizeX;if(e||!S[g]||S[g][0]!==M||S[g][1]!==C){S[g]=[M,C];var L=y(r,i,o,a,g,v,M,A,d.panelSizeX,d.panelSizeY,d.dim0.crossfilterDimensionIndex,_?0:w?2:1,p);k.clearOnly=n;var P=e?r.lines.blockLineCount:m;f(T,E,k,P,m,L)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var a=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:a}),a},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",A.destroy(),b&&b.destroy(),M)M[e].destroy()},update:C}}},{\"../../lib\":749,\"./constants\":1122,glslify:413}],1127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a,i;for(n||(n=1/0),a=0;a<e.length;a++)(i=e[a]).visible&&(n=Math.min(n,i[r].length));for(n===1/0&&(n=0),t._length=n,a=0;a<e.length;a++)(i=e[a]).visible&&(i._length=n);return n}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"color-rgba\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),m=t(\"./axisbrush\"),v=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t,e,r,a,i){var o,s,l=b(r);return a?n.scale.ordinal().domain(a.map((o=n.format(r.tickformat),s=i,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(a.map((function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(l).range([t-e,e])}function T(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function k(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=a(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),i=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((a=t,function(t){return t[a]})));var a}));return function(t){return i.map((function(e){return e(t)}))}}function M(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function A(t,e,r){var i=p(e),s=i.trace,l=d.convertTypedArray(i.lineColor),u=s.line,h={color:a(g.deselectedLineColor)},f=c.extractOpts(u),m=f.reversescale?c.flipScale(i.cscale):i.cscale,v=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,T=s.labelfont,M=s.tickfont,A=s.rangefont,S=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),E=Math.floor(x*(v.x[1]-v.x[0])),C=Math.floor(t.height*(v.y[1]-v.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},P=E,I=C;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:k(m),lines:S,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:T,tickFont:M,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:v,translateX:v.x[0]*x,translateY:t.height-v.y[1]*t.height,pad:L,canvasWidth:P*g.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:I*g.canvasPixelRatio,width:P,height:I,canvasPixelRatio:g.canvasPixelRatio}}function S(t,e,r){var a=r.width,i=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return a*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/i,h=function(t,e){return n.scale.linear().range([e,t-e])}(i,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map((function(a,s){var v=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(a,u),y=p[a.label];p[a.label]=(y||0)+1;var x=a.label+(y?\"__\"+y:\"\"),_=a.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var A=k?_.map((function(t){return t.map(v)})):[[-1/0,1/0]],S=a.values;S.length>a._length&&(S=S.slice(0,a._length));var E,C=a.tickvals;function L(t,e){return{val:t,text:E[e]}}function P(t,e){return t.val-e.val}if(Array.isArray(C)&&C.length){E=a.ticktext,Array.isArray(E)&&E.length?E.length>C.length?E=E.slice(0,C.length):C.length>E.length&&(C=C.slice(0,E.length)):E=C.map(n.format(a.tickformat));for(var I=1;I<C.length;I++)if(C[I]<C[I-1]){for(var z=C.map(L).sort(P),O=0;O<C.length;O++)C[O]=z[O].val,E[O]=z[O].text;break}}else C=void 0;return S=d.convertTypedArray(S),{key:x,label:a.label,tickFormat:a.tickformat,tickvals:C,ticktext:E,ordinal:d.isOrdinal(a),multiselect:a.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:a._index,height:i,values:S,paddedUnitValues:S.map(v),unitTickvals:C&&C.map(v),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:w(i,g.verticalPadding,a,C,E),ordinalScale:T(a),parent:f,model:r,brush:m.makeBrush(t,k,A,(function(){t.linePickActive(!1)}),(function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=M(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=v.invert,i=r.map((function(t){return t.map(n).sort(o.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(f.key,a._index,i)}}))}})),f}function E(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function C(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function L(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),a=0;a<n.length-1;a++){var i=r[a]||(r[a]={}),o=n[a],s=n[a+1];i.dim0=o,i.dim1=s,i.canvasX=o.canvasX,i.panelSizeX=s.canvasX-o.canvasX,i.panelSizeY=e.model.canvasHeight,i.y=0,i.canvasY=0}}function P(t,e){return i.tickText(t._ax,e,!1).text}function I(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return P(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,a){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,a=n.dimensions,o=0;o<a.length;o++){var s=a[o].values,l=a[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=a[o].tickformat,i.calcTicks(l),l.cleanRange())}}(e);var b,w,T=(b=!0,w=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?w=!!t:w}}),k=e.filter((function(t){return p(t).trace.visible})).map(A.bind(0,r)).map(S.bind(0,T,a));y.each((function(t,e){return o.extendFlat(t,k[e])}));var z=y.selectAll(\".gl-canvas\").each((function(t){t.viewModel=k[0],t.model=t.viewModel?t.viewModel.model:null})),O=null;z.filter((function(t){return t.pick})).style(\"pointer-events\",\"auto\").on(\"mousemove\",(function(t){if(T.linePickActive()&&t.lineLayer&&a&&a.hover){var e=n.event,r=this.width,i=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=i)return;var c=t.lineLayer.readPixel(s,i-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==O&&(u?a.hover(f):a.unhover&&a.unhover(f),O=h)}})),z.style(\"opacity\",(function(t){return t.pick?0:1})),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(k,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",(function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"}));var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",(function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"}));var F=R.selectAll(\".\"+g.cn.yAxis).data((function(t){return t.dimensions}),h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each((function(t){L(F,t)})),z.each((function(t){if(t.viewModel){!t.lineLayer||a?t.lineLayer=v(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||a;t.lineLayer.render(t.viewModel.panels,e)}})),F.attr(\"transform\",(function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"})),F.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;T.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),L(F,e),F.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"})),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each((function(r,n,a){a===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!M(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,L(F,e),n.select(this).attr(\"transform\",(function(t){return\"translate(\"+t.x+\", 0)\"})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!M(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),T.linePickActive(!0),a&&a.axesMoved&&a.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,a=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?a:null).tickFormat((function(e){return d.isOrdinal(t)?e:P(t.model.dimensions[t.visibleIndex],e)})).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)})),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",\"auto\"),U.text((function(t){return t.label})).each((function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=C(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"})).attr(\"text-anchor\",(function(t){var e=C(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(E),H.text((function(t){return I(t,!0)})).each((function(t){l.font(n.select(this),t.model.rangeFont)}));var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",(function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"}));var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(E),Y.text((function(t){return I(t,!1)})).each((function(t){l.font(n.select(this),t.model.rangeFont)})),m.ensureAxisBrush(B)}},{\"../../components/colorscale\":627,\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/gup\":746,\"../../lib/svg_text_utils\":773,\"../../plots/cartesian/axes\":798,\"./axisbrush\":1119,\"./constants\":1122,\"./helpers\":1124,\"./lines\":1126,\"color-rgba\":126,d3:169}],1129:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),a=t(\"../../lib/prepare_regl\"),i=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),a=t.indexOf(n);return-1===a&&(a+=e.length),a}e.exports=function(t,e){var r=t._fullLayout;if(a(t)){var s={},l={},c={},u={},h=r._size;e.forEach((function(e,r){var n=e[0].trace;c[r]=n.index;var a=u[r]=n._fullInput.index;s[r]=t.data[a].dimensions,l[r]=t.data[a].dimensions.slice()}));n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,a){var i=l[e][n],o=a.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=i.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),i.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete i.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(i));s[e].sort(n),l[e].filter((function(t){return!i(t)})).sort((function(t){return l[e].indexOf(t)})).forEach((function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":762,\"./helpers\":1124,\"./parcoords\":1128}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,i=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"../../lib/extend\").extendFlat,u=i({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},u,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},u,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:a({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},u,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":614,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/domain\":825,\"../../plots/font_attributes\":826,\"../../plots/template_attributes\":876}],1131:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"pie\",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{\"../../plots/plots\":861}],1132:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),i=t(\"../../components/color\"),o={};function s(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=i.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,i=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],h=e.values,f=e._length,p=e._hasValues&&f;if(e.dlabel)for(c=new Array(f),r=0;r<f;r++)c[r]=String(e.label0+r*e.dlabel);var d={},g=s(o[\"_\"+e.type+\"colormap\"]),m=0,v=!1;for(r=0;r<f;r++){var y,x,b;if(p){if(y=h[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=i.length,(b=-1!==l.indexOf(x))||(m+=y),i.push({v:y,label:x,color:g(u[r],x),i:r,pts:[r],hidden:b})):(v=!0,(a=i[_]).v+=y,a.pts.push(r),a.hidden||(m+=y),!1===a.color&&u[r]&&(a.color=g(u[r],x)))}return(\"funnelarea\"===e.type?v:e.sort)&&i.sort((function(t,e){return e.v-t.v})),i[0]&&(i[0].vTotal=m),i},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,a=t.calcdata,i=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(i=l(i,o));for(var c=0,u=0;u<a.length;u++){var h=a[u];if(h[0].trace.type===r)for(var f=0;f<h.length;f++){var p=h[f];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=i[c%i.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{\"../../components/color\":615,\"fast-isnumeric\":241,tinycolor2:548}],1133:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"./attributes\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText;function l(t,e){var r=Array.isArray(t),i=a.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,i?e.length:1/0);if(isFinite(o)||(o=0),o&&i){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:i,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return a.coerce(t,e,i,r,n)}var u=l(c(\"labels\"),c(\"values\")),h=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),h){e._length=h,c(\"marker.line.width\")&&c(\"marker.line.color\"),c(\"marker.colors\"),c(\"scalegroup\");var f,p=c(\"text\"),d=c(\"texttemplate\");if(d||(f=c(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),d||f&&\"none\"!==f){var g=c(\"textposition\");s(t,e,n,c,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||\"auto\"===g||\"outside\"===g)&&c(\"automargin\"),(\"inside\"===g||\"auto\"===g||Array.isArray(g))&&c(\"insidetextorientation\")}o(e,n,c);var m=c(\"hole\");if(c(\"title.text\")){var v=c(\"title.position\",m?\"middle center\":\"top center\");m||\"middle center\"!==v||(e.title.position=\"top center\"),a.coerceFont(c,\"title.font\",n.font)}c(\"sort\"),c(\"direction\"),c(\"rotation\"),c(\"pull\")}else e.visible=!1}}},{\"../../lib\":749,\"../../plots/domain\":825,\"../bar/defaults\":895,\"./attributes\":1130,\"fast-isnumeric\":241}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":651}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function a(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}r.formatPiePercent=function(t,e){var r=a((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=a(t.toPrecision(10));return n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||\"\"===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":749}],1136:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1130,\"./base_plot\":1131,\"./calc\":1132,\"./defaults\":1133,\"./layout_attributes\":1137,\"./layout_defaults\":1138,\"./plot\":1139,\"./style\":1140,\"./style_one\":1141}],1137:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1138:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":749,\"./layout_attributes\":1137}],1139:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../plots/plots\"),i=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../bar/uniform_text\"),h=u.recordMinTextSize,f=u.clearMinTextSize,p=t(\"../bar/constants\").TEXTPAD,d=t(\"./helpers\"),g=t(\"./event_data\"),m=t(\"../../lib\").isValidTextValue;function v(t,e,r){var a=r[0],o=a.trace,s=a.cx,c=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var h=u.hoverinfo;if(Array.isArray(h)&&(h=i.castHoverinfo({hoverinfo:[d.castOption(h,t.pts)],_module:o._module},r,0)),\"all\"===h&&(h=\"label+text+value+percent+name\"),u.hovertemplate||\"none\"!==h&&\"skip\"!==h&&h){var f=t.rInscribed||0,p=s+t.pxmid[0]*(1-f),m=c+t.pxmid[1]*(1-f),v=r.separators,y=[];if(h&&-1!==h.indexOf(\"label\")&&y.push(t.label),t.text=d.castOption(u.hovertext||u.text,t.pts),h&&-1!==h.indexOf(\"text\")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=d.formatPieValue(t.v,v),h&&-1!==h.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=d.formatPiePercent(t.percent,v),h&&-1!==h.indexOf(\"percent\")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;i.loneHover({trace:o,x0:p-f*a.r,x1:p+f*a.r,y:m,text:y.join(\"<br>\"),name:u.hovertemplate||-1!==h.indexOf(\"name\")?u.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:d.castOption(b.bgcolor,t.pts)||t.color,borderColor:d.castOption(b.bordercolor,t.pts),fontFamily:d.castOption(_.family,t.pts),fontSize:d.castOption(_.size,t.pts),fontColor:d.castOption(_.color,t.pts),nameLength:d.castOption(b.namelength,t.pts),textAlign:d.castOption(b.align,t.pts),hovertemplate:d.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[g(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[g(t,u)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[g(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[g(t,a)],i.click(e,n.event))}))}function y(t,e,r){var n=d.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=d.castOption(t._input.textfont.color,e.pts));var a=d.castOption(t.insidetextfont.family,e.pts)||d.castOption(t.textfont.family,e.pts)||r.family,i=d.castOption(t.insidetextfont.size,e.pts)||d.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:a,size:i}}function x(t,e){for(var r,n,a=0;a<t.length;a++)if((n=(r=t[a][0]).trace).title.text){var i=n.title.text;n._meta&&(i=l.templateString(i,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(i).call(s.font,n.title.font).call(c.convertToTspans,e),u=s.bBox(o.node(),!0);r.titleBox={width:u.width,height:u.height},o.remove()}}function b(t,e,r){var n=r.r||e.rpx1,a=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-a,scale:0,rotate:0,textPosAngle:0};var i,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,h=\"horizontal\"===u,f=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,g=[];if(!d){var m,v=function(r,a){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(i=\"tan\"===a?w(t,n,o,c,0):_(t,n,o,c,Math.PI/2)).textPosAngle=r,g.push(i)}};if(h||f){for(m=4;m>=-4;m-=2)v(Math.PI*m,\"tan\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+1),\"tan\")}if(h||p){for(m=4;m>=-4;m-=2)v(Math.PI*(m+1.5),\"rad\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+.5),\"rad\")}}if(s||d||h){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((i={scale:a*n*2/y,rCenter:1-a,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,i.scale>=1)return i;g.push(i)}(d||p)&&((i=_(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(i)),(d||f)&&((i=w(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(i));for(var x=0,b=0,T=0;T<g.length;T++){var k=g[T].scale;if(b<k&&(b=k,x=T),!d&&b>=1)break}return g[x]}function _(t,e,r,n,a){e=Math.max(0,e-2*p);var i=t.width/t.height,o=M(i,n,e,r);return{scale:2*o/t.height,rCenter:T(i,o/e),rotate:k(a)}}function w(t,e,r,n,a){e=Math.max(0,e-2*p);var i=t.height/t.width,o=M(i,n,e,r);return{scale:2*o/t.width,rCenter:T(i,o/e),rotate:k(a+Math.PI/2)}}function T(t,e){return Math.cos(e)-t*e}function k(t){return(180/Math.PI*t+720)%180-90}function M(t,e,r,n){var a=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(a*a+.5)+a),n/(Math.sqrt(t*t+n/2)+t))}function A(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function S(t,e){var r=e.pxmid[0],n=e.pxmid[1],a=t.width/2,i=t.height/2;return r<0&&(a*=-1),n<0&&(i*=-1),{scale:1,rCenter:1,rotate:0,x:a+Math.abs(i)*(a>0?1:-1)/2,y:i/(1+r*r/(n*n)),outside:!0}}function E(t,e){var r,n,a,i=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=i.title.font.size,a=L(i),-1!==i.title.position.indexOf(\"top\")?(o.y-=(1+a)*t.r,s.ty-=t.titleBox.height):-1!==i.title.position.indexOf(\"bottom\")&&(o.y+=(1+a)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(i.domain.x[1]-i.domain.x[0])/2;return-1!==i.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+a)*u,s.tx+=t.titleBox.width/2):-1!==i.title.position.indexOf(\"center\")?h*=2:-1!==i.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+a)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=C(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function C(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function L(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function P(t,e){for(var r=[],n=0;n<t.length;n++){var a=t[n][0],i=a.trace,o=i.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);i.title.text&&\"middle center\"!==i.title.position&&(l-=C(a,e));var c=s/2,u=l/2;\"funnelarea\"!==i.type||i.scalegroup||(u/=i.aspectratio),a.r=Math.min(c,u)/(1+L(i)),a.cx=e.l+e.w*(i.domain.x[1]+i.domain.x[0])/2,a.cy=e.t+e.h*(1-i.domain.y[0])-l/2,i.title.text&&-1!==i.title.position.indexOf(\"bottom\")&&(a.cy-=C(a,e)),i.scalegroup&&-1===r.indexOf(i.scalegroup)&&r.push(i.scalegroup)}!function(t,e){for(var r,n,a,i=0;i<e.length;i++){var o=1/0,s=e[i];for(n=0;n<t.length;n++)if(r=t[n][0],(a=r.trace).scalegroup===s){var l;if(\"pie\"===a.type)l=r.r*r.r;else if(\"funnelarea\"===a.type){var c,u;a.aspectratio>1?(c=r.r,u=c/a.aspectratio):(u=r.r,c=u*a.aspectratio),c*=(1+a.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(a=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===a.type&&(h/=(1+a.baseratio)/2,h/=a.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}function I(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function z(t,e,r){var n=t._fullLayout,a=r.trace,i=a.texttemplate,o=a.textinfo;if(!i&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},h=u(\"label\"),f=u(\"text\"),p=u(\"value\"),g=u(\"percent\"),v=n.separators;if(s=h?[e.label]:[],f){var y=d.getFirstFilled(a.text,e.pts);m(y)&&s.push(y)}p&&s.push(d.formatPieValue(e.v,v)),g&&s.push(d.formatPiePercent(e.v/r.vTotal,v)),e.text=s.join(\"<br>\")}if(i){var x=l.castOption(a,e.i,\"texttemplate\");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:d.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:d.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(a,t.i,\"customdata\")}}(e),_=d.getFirstFilled(a.text,e.pts);(m(_)||\"\"===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,a._meta||{})}else e.text=\"\"}}function O(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),a=Math.sin(r),i=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=i*n-o*a,t.textY=i*a+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,i=r._size;f(\"pie\",r),x(e,t),P(e,i);var u=l.makeTraceGroups(r._pielayer,e,\"trace\").each((function(e){var u=n.select(this),f=e[0],p=f.trace;!function(t){var e,r,n,a=t[0],i=a.r,o=a.trace,s=o.rotation*Math.PI/180,l=2*Math.PI/a.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=I(i,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=I(i,s),r.midangle=s,s+=l*r.v/2,n=I(i,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>a.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/a.vTotal,.5),r.ring=1-o.hole,r.rInscribed=A(r,a))}(e),u.attr(\"stroke-linejoin\",\"round\"),u.each((function(){var g=n.select(this).selectAll(\"g.slice\").data(e);g.enter().append(\"g\").classed(\"slice\",!0),g.exit().remove();var m=[[[],[]],[[],[]]],x=!1;g.each((function(a,i){if(a.hidden)n.select(this).selectAll(\"path,g\").remove();else{a.pointNumber=a.i,a.curveNumber=p.index,m[a.pxmid[1]<0?0:1][a.pxmid[0]<0?0:1].push(a);var o=f.cx,u=f.cy,g=n.select(this),_=g.selectAll(\"path.surface\").data([a]);if(_.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),g.call(v,t,e),p.pull){var w=+d.castOption(p.pull,a.pts)||0;w>0&&(o+=w*a.pxmid[0],u+=w*a.pxmid[1])}a.cxFinal=o,a.cyFinal=u;var T=p.hole;if(a.v===f.vTotal){var k=\"M\"+(o+a.px0[0])+\",\"+(u+a.px0[1])+L(a.px0,a.pxmid,!0,1)+L(a.pxmid,a.px0,!0,1)+\"Z\";T?_.attr(\"d\",\"M\"+(o+T*a.px0[0])+\",\"+(u+T*a.px0[1])+L(a.px0,a.pxmid,!1,T)+L(a.pxmid,a.px0,!1,T)+\"Z\"+k):_.attr(\"d\",k)}else{var M=L(a.px0,a.px1,!0,1);if(T){var A=1-T;_.attr(\"d\",\"M\"+(o+T*a.px1[0])+\",\"+(u+T*a.px1[1])+L(a.px1,a.px0,!1,T)+\"l\"+A*a.px0[0]+\",\"+A*a.px0[1]+M+\"Z\")}else _.attr(\"d\",\"M\"+o+\",\"+u+\"l\"+a.px0[0]+\",\"+a.px0[1]+M+\"Z\")}z(t,a,f);var E=d.castOption(p.textposition,a.pts),C=g.selectAll(\"g.slicetext\").data(a.text&&\"none\"!==E?[0]:[]);C.enter().append(\"g\").classed(\"slicetext\",!0),C.exit().remove(),C.each((function(){var g=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),m=l.ensureUniformFontSize(t,\"outside\"===E?function(t,e,r){var n=d.castOption(t.outsidetextfont.color,e.pts)||d.castOption(t.textfont.color,e.pts)||r.color,a=d.castOption(t.outsidetextfont.family,e.pts)||d.castOption(t.textfont.family,e.pts)||r.family,i=d.castOption(t.outsidetextfont.size,e.pts)||d.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:a,size:i}}(p,a,r.font):y(p,a,r.font));g.text(a.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,m).call(c.convertToTspans,t);var v,_=s.bBox(g.node());if(\"outside\"===E)v=S(_,a);else if(v=b(_,a,f),\"auto\"===E&&v.scale<1){var w=l.ensureUniformFontSize(t,p.outsidetextfont);g.call(s.font,w),v=S(_=s.bBox(g.node()),a)}var T=v.textPosAngle,k=void 0===T?a.pxmid:I(f.r,T);if(v.targetX=o+k[0]*v.rCenter+(v.x||0),v.targetY=u+k[1]*v.rCenter+(v.y||0),O(v,_),v.outside){var M=v.targetY;a.yLabelMin=M-_.height/2,a.yLabelMid=M,a.yLabelMax=M+_.height/2,a.labelExtraX=0,a.labelExtraY=0,x=!0}v.fontSize=m.size,h(p.type,v,r),e[i].transform=v,g.attr(\"transform\",l.getTextTransform(v))}))}function L(t,e,r,n){var i=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*f.r+\",\"+n*f.r+\" 0 \"+a.largeArc+(r?\" 1 \":\" 0 \")+i+\",\"+o}}));var _=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);if(_.enter().append(\"g\").classed(\"titletext\",!0),_.exit().remove(),_.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),a=p.title.text;p._meta&&(a=l.templateString(a,p._meta)),r.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,p.title.font).call(c.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(f):E(f,i),r.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")})),x&&function(t,e){var r,n,a,i,o,s,l,c,u,h,f,p,g;function m(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var a,c,u,f,p=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),g=n?t.yLabelMin:t.yLabelMax,m=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),y=p-g;if(y*l>0&&(t.labelExtraY=y),Array.isArray(e.pull))for(c=0;c<h.length;c++)(u=h[c])===t||(d.castOption(e.pull,t.pts)||0)>=(d.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(y=u.cyFinal+o(u.px0[1],u.px1[1])-g-t.labelExtraY)*l>0&&(t.labelExtraY+=y):(m+t.labelExtraY-v)*l>0&&(a=3*s*Math.abs(c-h.indexOf(t)),(f=u.cxFinal+i(u.px0[0],u.px1[0])+a-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=f)))}for(n=0;n<2;n++)for(a=n?m:v,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(i=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(a),u=t[1-n][r],h=u.concat(c),p=[],f=0;f<c.length;f++)void 0!==c[f].yLabelMid&&p.push(c[f]);for(g=!1,f=0;n&&f<u.length;f++)if(void 0!==u[f].yLabelMid){g=u[f];break}for(f=0;f<p.length;f++){var x=f&&p[f-1];g&&!f&&(x=g),y(p[f],x)}}}(m,p),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var a=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,a.attr(\"transform\",l.getTextTransform(t.transform));var i=t.cxFinal+t.pxmid[0],s=\"M\"+i+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],h=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(h)?s+=\"l\"+h*t.pxmid[0]/t.pxmid[1]+\",\"+h+\"H\"+(i+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(h-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(g,p),x&&p.automargin){var w=s.bBox(u.node()),T=p.domain,k=i.w*(T.x[1]-T.x[0]),M=i.h*(T.y[1]-T.y[0]),A=(.5*k-f.r)/i.w,C=(.5*M-f.r)/i.h;a.autoMargin(t,\"pie.\"+p.uid+\".automargin\",{xl:T.x[0]-A,xr:T.x[1]+A,yb:T.y[0]-C,yt:T.y[1]+C,l:Math.max(f.cx-f.r-w.left,0),r:Math.max(w.right-(f.cx+f.r),0),b:Math.max(w.bottom-(f.cy+f.r),0),t:Math.max(f.cy-f.r-w.top,0),pad:5})}}))}));setTimeout((function(){u.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:z,transformInsideText:b,determineInsideTextFont:y,positionTitleOutside:E,prerenderTitles:x,layoutAreas:P,attachFxHandlers:v,computeTransform:O}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../components/fx\":655,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../../plots/plots\":861,\"../bar/constants\":893,\"../bar/uniform_text\":907,\"./event_data\":1134,\"./helpers\":1135,d3:169}],1140:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"./style_one\"),i=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");i(t,e,\"pie\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(a,t,e)}))}))}},{\"../bar/uniform_text\":907,\"./style_one\":1141,d3:169}],1141:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"./helpers\").castOption;e.exports=function(t,e,r){var i=r.marker.line,o=a(i.color,e.pts)||n.defaultLine,s=a(i.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":615,\"./helpers\":1135}],1142:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1156}],1143:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),a=t(\"../../lib/str2rgbarray\"),i=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=a(t.marker.color),m=a(t.marker.border.color),v=t.opacity*t.marker.opacity;g[3]*=v,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,m[3]*=v,this.pointcloudOptions.borderColor=m;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,T=b/2||.5;t._extremes[_._id]=i(_,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=i(w,[d[1],d[3]],{ppad:T})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":772,\"../../plots/cartesian/autorange\":797,\"../scatter/get_trace_color\":1166,\"gl-pointcloud2d\":303}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\");e.exports=function(t,e,r){function i(r,i){return n.coerce(t,e,a,r,i)}i(\"x\"),i(\"y\"),i(\"xbounds\"),i(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),i(\"text\"),i(\"marker.color\",r),i(\"marker.opacity\"),i(\"marker.blend\"),i(\"marker.sizemin\"),i(\"marker.sizemax\"),i(\"marker.border.color\",r),i(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":749,\"./attributes\":1142}],1145:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":838,\"../scatter3d/calc\":1185,\"./attributes\":1142,\"./convert\":1143,\"./defaults\":1144}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),a=t(\"../../plots/attributes\"),i=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},a.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:i.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:i.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":614,\"../../components/colorscale/attributes\":622,\"../../components/fx/attributes\":646,\"../../constants/docs\":719,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plot_api/plot_template\":787,\"../../plots/attributes\":794,\"../../plots/domain\":825,\"../../plots/font_attributes\":826,\"../../plots/template_attributes\":876}],1147:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,a=n.dragmode,i=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==a&&\"zoom\"!==a){s(o,i);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,a=t._fullData[e],i=a.node.groups.slice(),o=[];function s(t){for(var e=a._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);i[c.pointNumber-a.node._count]=!1}else o.push(c.pointNumber)}n=i.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,a)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=a(t.calcdata,\"sankey\")[0];i(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var a=n._has&&n._has(\"sankey\"),i=e._has&&e._has(\"sankey\");a&&!i&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":634,\"../../components/fx/layout_attributes\":656,\"../../lib\":749,\"../../lib/setcursor\":769,\"../../plot_api/edit_types\":780,\"../../plots/cartesian/select\":817,\"../../plots/get_data\":835,\"../../registry\":881,\"./plot\":1152}],1148:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),a=t(\"../../lib\"),i=t(\"../../lib/gup\").wrap,o=a.isArrayOrTypedArray,s=a.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,i=t.link,c=[],u=o(i.color),h=o(i.customdata),f={},p={},d=i.colorscales.length;for(e=0;e<d;e++){var g=i.colorscales[e],m=l.extractScale(g,{cLetter:\"c\"}),v=l.makeColorScaleFunc(m);p[g.label]=v}var y=0;for(e=0;e<i.value.length;e++)i.source[e]>y&&(y=i.source[e]),i.target[e]>y&&(y=i.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var T=_[e];for(x=0;x<T.length;x++){var k=T[x],M=b+e;w.hasOwnProperty(k)?a.warn(\"Node \"+k+\" is already part of a group.\"):w[k]=M}}var A={source:[],target:[]};for(e=0;e<i.value.length;e++){var S=i.value[e],E=i.source[e],C=i.target[e];if(S>0&&s(E,b)&&s(C,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(C)||w[E]!==w[C])){w.hasOwnProperty(C)&&(C=w[C]),w.hasOwnProperty(E)&&(E=w[E]),C=+C,f[E=+E]=f[C]=!0;var L=\"\";i.label&&i.label[e]&&(L=i.label[e]);var P=null;L&&p.hasOwnProperty(L)&&(P=p[L]),c.push({pointNumber:e,label:L,color:u?i.color[e]:i.color,customdata:h?i.customdata[e]:i.customdata,concentrationscale:P,source:E,target:C,value:+S}),A.source.push(E),A.target.push(C)}}var I=b+_.length,z=o(r.color),O=o(r.customdata),D=[];for(e=0;e<I;e++)if(f[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:z?r.color[e]:r.color,customdata:O?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var i=a.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(a.isIndex(e[o],t)&&a.isIndex(r[o],t)){if(e[o]===r[o])return!0;i[e[o]].push(r[o])}return n(i).components.some((function(t){return t.length>1}))}(I,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return i({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":627,\"../../lib\":749,\"../../lib/gup\":746,\"strongly-connected-components\":541}],1149:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1150:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,i){return n.coerce(t,e,a.link.colorscales,r,i)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,a,r,i)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,m=c.newContainer(e,\"node\");function v(t,e){return n.coerce(g,m,a.node,t,e)}v(\"label\"),v(\"groups\"),v(\"x\"),v(\"y\"),v(\"pad\"),v(\"thickness\"),v(\"line.color\"),v(\"line.width\"),v(\"hoverinfo\",t.hoverinfo),l(g,m,v,d),v(\"hovertemplate\");var y=f.colorway;v(\"color\",m.label.map((function(t,e){return i.addOpacity(function(t){return y[t%y.length]}(e),.8)}))),v(\"customdata\");var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,a.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,T=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(T,b.value.length)),_(\"customdata\"),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),m.x.length&&m.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":615,\"../../components/fx/hoverlabel_defaults\":653,\"../../lib\":749,\"../../plot_api/plot_template\":787,\"../../plots/array_container_defaults\":793,\"../../plots/domain\":825,\"./attributes\":1146,tinycolor2:548}],1151:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1146,\"./base_plot\":1147,\"./calc\":1148,\"./defaults\":1150,\"./plot\":1152,\"./select.js\":1154}],1152:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"./render\"),i=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter((function(t){return t.key===e.traceId}))}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var a=n.datum().link.label;n.style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),a&&h(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===a})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(m)}function x(t,e,r,n){var a=n.datum().link.label;n.style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),a&&h(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===a})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",T=c(t,\"concentration:\")+\" \",k=c(t,\"incoming flow count:\")+\" \",M=c(t,\"outgoing flow count:\")+\" \";a(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,a,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,a){if(!1!==t._fullLayout.hovermode){var s=a.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<a.flow.links.length;h++){var d=a.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||a.link.pointNumber===d.pointNumber){a.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=a.link.trace.link;var g=v(d),m={valueLabel:n.format(a.valueFormat)(d.value)+a.valueSuffix};l.push({x:g[0],y:g[1],name:m.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?T+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:m,eventData:[d]})}}i.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each((function(){a.link.concentrationscale||f(this,.65),p(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=a.parent.translateX,n[1]+=a.parent.translateY,n}},unhover:function(e,a,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,a,o,!0)),\"skip\"!==a.link.trace.link.hoverinfo&&(a.link.fullData=a.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[a.link]})),i.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var a=r.link;a.originalEvent=n.event,t._hoverdata=[a],i.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,r,a),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,a){if(!1!==t._fullLayout.hovermode){var o=a.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,m=h.top+h.height/4-c.top,v={valueLabel:n.format(a.valueFormat)(a.node.value)+a.valueSuffix};a.node.fullData=a.node.trace;var y=i.loneHover({x0:d,x1:g,y:m,name:n.format(a.valueFormat)(a.node.value)+a.valueSuffix,text:[a.node.label,k+a.node.targetLinks.length,M+a.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||a.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[a.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,a,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,a,o),\"skip\"!==a.node.trace.node.hoverinfo&&(a.node.fullData=a.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[a.node]})),i.loneUnhover(r._hoverlayer.node()))},select:function(e,r,a){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(v,r,a),i.click(t,{target:!0})}}})}},{\"../../components/color\":615,\"../../components/fx\":655,\"../../lib\":749,\"./constants\":1149,\"./render\":1153,d3:169}],1153:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"d3\"),i=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,m=t(\"d3-interpolate\").interpolateNumber,v=t(\"../../registry\");function y(t,e,r){var a,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,m=t.width*(u.x[1]-u.x[0]),v=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(a=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[m,v]:[v,m]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodes(y).links(x);var _,w,T,k=a();for(var M in a.nodePadding()<p&&h.warn(\"node.pad was reduced to \",a.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var A,S=parseInt(o._groupLookup[M]);for(_=0;_<k.nodes.length;_++)if(k.nodes[_].pointNumber===S){A=k.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};k.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<k.nodes.length;_++){var t,e,r=k.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var a=Object.keys(n);for(w=0;w<a.length;w++){var o=n[t=a[w]],s=0,l={};for(T=0;T<o.length;T++)l[(e=o[T]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(T=0;T<o.length;T++)(e=o[T]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=i(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,k.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*m,s.node.y[_]*v];k.nodes[_].x0=C[0]-d/2,k.nodes[_].x1=C[0]+d/2;var L=k.nodes[_].y1-k.nodes[_].y0;k.nodes[_].y0=C[1]-L/2,k.nodes[_].y1=C[1]+L/2}if(\"snap\"===s.arrangement)!function(t){t.forEach((function(t){var e,r,n,a=0,i=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<i;++n)(e=t[n]).y0>=a||(r=a-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),a=e.y1+p}))}(function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),a=[],i=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(i+=1,e=s.x0),o=s.x0,a[i]||(a[i]=[]),a[i].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return a}(y=k.nodes));a.update(k)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:m,height:v,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?v:m,dragPerpendicular:f?m:v,arrangement:s.arrangement,sankey:a,graph:k,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function x(t,e,r){var n=i(e.color),a=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:a,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:b,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function b(){return function(t){if(t.link.circular)return e=t.link,r=e.width/2,n=e.circularPathData,\"top\"===e.circularLinkType?\"M \"+n.targetX+\" \"+(n.targetY+r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"L\"+n.targetX+\" \"+(n.targetY-r)+\"Z\":\"M \"+n.targetX+\" \"+(n.targetY-r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"L\"+n.targetX+\" \"+(n.targetY+r)+\"Z\";var e,r,n,a=t.link.source.x1,i=t.link.target.x0,o=m(a,i),s=o(.5),l=o(.5),c=t.link.y0-t.link.width/2,u=t.link.y0+t.link.width/2,h=t.link.y1-t.link.width/2,f=t.link.y1+t.link.width/2;return\"M\"+a+\",\"+c+\"C\"+s+\",\"+c+\" \"+l+\",\"+h+\" \"+i+\",\"+h+\"L\"+i+\",\"+f+\"C\"+l+\",\"+f+\" \"+s+\",\"+u+\" \"+a+\",\"+u+\"Z\"}}function _(t,e){var r=i(e.color),a=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-a,zoneY:-s,zoneWidth:l+2*a,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}function w(t){t.attr(\"transform\",(function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"}))}function T(t){t.call(w)}function k(t,e){t.call(T),e.attr(\"d\",b())}function M(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function A(t){return t.link.width>1||t.linkLineWidth>0}function S(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function E(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function C(t){return a.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function L(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function P(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function I(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function z(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function O(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function D(t,e,r,i){var o=a.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(a){if(\"fixed\"!==a.arrangement&&(h.ensureSingle(i._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){i._fullLayout._dragCover=t})),h.raiseToTop(this),a.interactionState.dragInProgress=a.node,F(a.node),a.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,a.interactionState.hovered),a.interactionState.hovered=!1),\"snap\"===a.arrangement)){var o=a.traceId+\"|\"+a.key;a.forceLayouts[o]?a.forceLayouts[o].alpha(1):function(t,e,r,a){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var i=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=u.forceSimulation(i).alphaDecay(0).force(\"collide\",u.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,a){return function(){for(var t=0,i=0;i<r.length;i++){var o=r[i];o===a.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(a.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!a.interactionState.dragInProgress&&t<.1&&a.forceLayouts[e].alpha()>0&&a.forceLayouts[e].alpha(0)}}(0,e,i,r)).stop()}(0,o,a),function(t,e,r,a,i){window.requestAnimationFrame((function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[a].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),k(t.filter(B(r)),e),r.forceLayouts[a].alpha()>0)window.requestAnimationFrame(o);else{var l=r.node.originalX;r.node.x0=l-r.visibleWidth/2,r.node.x1=l+r.visibleWidth/2,R(r,i)}}))}(t,e,a,o,i)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=a.event.x,i=a.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),i=Math.max(0,Math.min(r.size-r.visibleHeight/2,i)),r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2),F(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),k(t.filter(B(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&R(t,i)}}));t.on(\".drag\",null).call(o)}function R(t,e){for(var r=[],n=[],a=0;a<t.graph.nodes.length;a++){var i=(t.graph.nodes[a].x0+t.graph.nodes[a].x1)/2,o=(t.graph.nodes[a].y0+t.graph.nodes[a].y1)/2;r.push(i/t.figure.width),n.push(o/t.figure.height)}v.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function F(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function B(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,l,c){var u=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){u=!0}));var f=t._fullLayout._dragCover,m=r.filter((function(t){return g(t).trace.visible})).map(y.bind(null,l)),v=e.selectAll(\".\"+n.cn.sankey).data(m,p);v.exit().remove(),v.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",S),v.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=a.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),v.transition().ease(n.ease).duration(n.duration).attr(\"transform\",S);var T=v.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);T.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var k=T.selectAll(\".\"+n.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(x.bind(null,t))}),p);k.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(O,v,c.linkEvents),k.style(\"stroke\",(function(t){return A(t)?o.tinyRGB(i(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return A(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return A(t)?t.linkLineWidth:1})).attr(\"d\",b()),k.style(\"opacity\",(function(){return t._context.staticPlot||u||f?1:0})).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),k.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var R=v.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);R.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),R.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var F=R.selectAll(\".\"+n.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(_.bind(null,t))}),p);F.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(w).style(\"opacity\",(function(e){return!t._context.staticPlot&&!u||e.partOfGroup?0:1})),F.call(O,v,c.nodeEvents).call(D,k,c,t),F.transition().ease(n.ease).duration(n.duration).call(w).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),F.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var B=F.selectAll(\".\"+n.cn.nodeRect).data(d);B.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(M),B.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return o.tinyRGB(i(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return o.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),B.transition().ease(n.ease).duration(n.duration).call(M);var N=F.selectAll(\".\"+n.cn.nodeCapture).data(d);N.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),N.attr(\"x\",(function(t){return t.zoneX})).attr(\"y\",(function(t){return t.zoneY})).attr(\"width\",(function(t){return t.zoneWidth})).attr(\"height\",(function(t){return t.zoneHeight}));var j=F.selectAll(\".\"+n.cn.nodeCentered).data(d);j.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",E),j.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var U=j.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);U.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",(function(t){return t.uniqueNodeLabelPathId})).attr(\"d\",C).attr(\"transform\",L),U.transition().ease(n.ease).duration(n.duration).attr(\"d\",C).attr(\"transform\",L);var V=j.selectAll(\".\"+n.cn.nodeLabel).data(d);V.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",P).style(\"cursor\",\"default\").style(\"fill\",\"black\"),V.style(\"text-shadow\",(function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"})).each((function(t){s.font(V,t.textFont)})),V.transition().ease(n.ease).duration(n.duration).attr(\"transform\",P);var q=V.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);q.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",(function(t){return\"#\"+t.uniqueNodeLabelPathId})).attr(\"startOffset\",z).style(\"fill\",I),q.text((function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"})).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})),q.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",z).style(\"fill\",I)}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/gup\":746,\"../../registry\":881,\"./constants\":1149,\"@plotly/d3-sankey\":56,\"@plotly/d3-sankey-circular\":55,d3:169,\"d3-force\":160,\"d3-interpolate\":162,tinycolor2:548}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,a=n._sankey.graph.nodes,i=0;i<a.length;i++){var o=a[i];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,i,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var a=e.marker;if(a){n.mergeArrayCastPositive(a.size,t,\"ms\"),n.mergeArrayCastPositive(a.opacity,t,\"mo\"),n.mergeArray(a.symbol,t,\"mx\"),n.mergeArray(a.color,t,\"mc\");var i=a.line;a.line&&(n.mergeArray(i.color,t,\"mlc\"),n.mergeArrayCastPositive(i.width,t,\"mlw\"));var o=a.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":749}],1156:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../components/drawing\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:n({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:a({},{keys:c.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:u({},s,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:u({symbol:{valType:\"enumerated\",values:l.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:u({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:o({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":622,\"../../components/drawing\":637,\"../../components/drawing/attributes\":636,\"../../lib/extend\":739,\"../../plots/font_attributes\":826,\"../../plots/template_attributes\":876,\"./constants\":1160}],1157:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"./subtypes\"),c=t(\"./colorscale_calc\"),u=t(\"./arrays_to_calcdata\"),h=t(\"./calc_selection\");function f(t,e,r,n,a,o,s){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[g(e)]===e.uid,d=(m(e,u,r,n)||{}).orientation,v=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};s&&(y.ppad=x.ppad=s);var b=c<2||a[0]!==a[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===v||\"tonextx\"===v&&(p||\"h\"===d))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==v&&\"tozeroy\"!==v&&(l.hasMarkers(e)||l.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===v||\"tonexty\"===v&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==v&&\"tozerox\"!==v||(x.padded=!1),h&&(e._extremes[h]=i.findExtremes(r,a,y)),f&&(e._extremes[f]=i.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},a.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};i.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function d(t,e){var r=g(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function g(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function m(t,e,r,n){var a=t.stackgroup;if(a){var i=e._scatterStackOpts[r._id+n._id][a],o=\"v\"===i.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?i:void 0}}e.exports={calc:function(t,e){var r,l,g,v,y,x,b=t._fullLayout,_=i.getFromId(t,e.xaxis||\"x\"),w=i.getFromId(t,e.yaxis||\"y\"),T=_.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),M=o(e,_,\"x\",T),A=o(e,w,\"y\",k),S=e._length,E=new Array(S),C=e.ids,L=m(e,b,_,w),P=!1;d(b,e);var I,z=\"x\",O=\"y\";L?(a.pushUnique(L.traceIndices,e._expandedIndex),(r=\"v\"===L.orientation)?(O=\"s\",I=\"x\"):(z=\"s\",I=\"y\"),y=\"interpolate\"===L.stackgaps):f(t,e,_,w,M,A,p(e,S));var D=!!e.xperiodalignment,R=!!e.yperiodalignment;for(l=0;l<S;l++){var F=E[l]={},B=n(M[l]),N=n(A[l]);B&&N?(F[z]=M[l],F[O]=A[l],D&&(F.orig_x=T[l]),R&&(F.orig_y=k[l])):L&&(r?B:N)?(F[I]=r?M[l]:A[l],F.gap=!0,y?(F.s=s,P=!0):F.s=0):F[z]=F[O]=s,C&&(F.id=String(C[l]))}if(u(E,e),c(t,e),h(E,e),L){for(l=0;l<E.length;)E[l][I]===s?E.splice(l,1):l++;if(a.sort(E,(function(t,e){return t[I]-e[I]||t.i-e.i})),P){for(l=0;l<E.length-1&&E[l].gap;)l++;for((x=E[l].s)||(x=E[l].s=0),g=0;g<l;g++)E[g].s=x;for(v=E.length-1;v>l&&E[v].gap;)v--;for(x=E[v].s,g=E.length-1;g>v;g--)E[g].s=x;for(;l<v;)if(E[++l].gap){for(g=l+1;E[g].gap;)g++;for(var j=E[l-1][I],U=E[l-1].s,V=(E[g].s-U)/(E[g][I]-j);l<g;)E[l].s=U+(E[l][I]-j)*V,l++}}}return E},calcMarkerSize:p,calcAxisExpansion:f,setFirstScatter:d,getStackOpts:m}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"./arrays_to_calcdata\":1155,\"./calc_selection\":1158,\"./colorscale_calc\":1159,\"./subtypes\":1181,\"fast-isnumeric\":241}],1158:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":749}],1159:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),i=t(\"./subtypes\");e.exports=function(t,e){i.hasLines(e)&&n(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),i.hasMarkers(e)&&(n(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":623,\"../../components/colorscale/helpers\":626,\"./subtypes\":1181}],1160:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1161:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function a(t,e,r,n,a,i,o){a[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else i&&(s.s=function(t,e,r,n){var a=t[e-1],i=t[e+1];return i?a?a.s+(i.s-a.s)*(r-a[n])/(i[n]-a[n]):i.s:a.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,i=e.yaxis,o=r._id+i._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,m,v,y,x,b,_,w,T=t.calcdata;for(var k in s){var M=(v=s[k]).traceIndices;if(M.length){for(y=\"interpolate\"===v.stackgaps,x=v.groupnorm,\"v\"===v.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=T[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(f=T[M[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>A[u]&&u<A.length;u++)a(f,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(h=0;h<l;h++)a(T[M[h]],u,d,h,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)a(f,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<M.length;l++)(f=T[M[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(m=(\"fraction\"===x?g:g/100)||1,l=0;l<M.length;l++){var E=T[M[l]][c];E[_]/=m,E.sNorm=E.s/m}}for(l=0;l<M.length;l++){var C=(f=T[M[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var I=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?I[f[c].i]:I}var z=new Array(S),O=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,O[c]=f[c].y;n.calcAxisExpansion(t,C,r,i,z,O,L),f[0].t.orientation=v.orientation}}}}}},{\"./calc\":1157}],1162:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var a=e-1;a>=0;a--){var i=t[a];if(\"scatter\"===i.type&&i.xaxis===r.xaxis&&i.yaxis===r.yaxis){i.opacity=void 0;break}}}}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\"),i=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./period_defaults\"),u=t(\"./stack_defaults\"),h=t(\"./marker_defaults\"),f=t(\"./line_defaults\"),p=t(\"./line_shape_defaults\"),d=t(\"./text_defaults\"),g=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,m){function v(r,a){return n.coerce(t,e,i,r,a)}var y=l(t,e,m,v);if(y||(e.visible=!1),e.visible){c(t,e,m,v);var x=u(t,e,m,v),b=!x&&y<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasLines(e)&&(f(t,e,r,m,v),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&h(t,e,r,m,v,{gradient:!0}),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,m,v));var _=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),_.push(\"points\")),v(\"fill\",x?x.fillDflt:\"none\"),\"none\"!==e.fill&&(g(t,e,r,v),s.hasLines(e)||p(t,e,v));var w=(e.line||{}).color,T=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||_.push(\"fills\"),v(\"hoveron\",_.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,w||T||r,{axis:\"y\"}),k(t,e,w||T||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":749,\"../../registry\":881,\"./attributes\":1156,\"./constants\":1160,\"./fillcolor_defaults\":1164,\"./line_defaults\":1169,\"./line_shape_defaults\":1171,\"./marker_defaults\":1175,\"./period_defaults\":1176,\"./stack_defaults\":1179,\"./subtypes\":1181,\"./text_defaults\":1182,\"./xy_defaults\":1183}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!a(s)?o=s:l&&!a(l)&&(o=l)}i(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":615,\"../../lib\":749}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a={},i={_fullLayout:r},o=n.getFromTrace(i,e,\"x\"),s=n.getFromTrace(i,e,\"y\");return a.xLabel=n.tickText(o,t.x,!0).text,a.yLabel=n.tickText(s,t.y,!0).text,a}},{\"../../plots/cartesian/axes\":798}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"./subtypes\");e.exports=function(t,e){var r,i;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(i=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(i)<.3?n.addOpacity(i,.3):i:(r=(t.line||{}).color)&&n.opacity(r)&&a.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":615,\"./subtypes\":1181}],1167:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/fx\"),i=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),m=[d,g],v=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==v.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=a.getDistanceFunction(c,(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r}),(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r}),x);if(a.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),T=p.c2p(_.y,!0),k=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S=\"h\"===M?A:void 0!==_.orig_x?_.orig_x:_.x,E=\"v\"===M?A:void 0!==_.orig_y?_.orig_y:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-k,x1:w+k,xLabelVal:S,y0:T-k,y1:T+k,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==v.indexOf(\"fills\")&&h._polygons){var C,L,P,I,z,O,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(m)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(I=N[C].pts,L=1;L<I.length;L++)(R=I[L-1][1])>G!=(F=I[L][1])>=G&&(O=I[L-1][0],D=I[L][0],F-R&&(z=O+(D-O)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":615,\"../../components/fx\":655,\"../../lib\":749,\"../../registry\":881,\"./get_trace_color\":1166}],1168:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),formatLabels:t(\"./format_labels\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":811,\"./arrays_to_calcdata\":1155,\"./attributes\":1156,\"./calc\":1157,\"./cross_trace_calc\":1161,\"./cross_trace_defaults\":1162,\"./defaults\":1163,\"./format_labels\":1165,\"./hover\":1167,\"./marker_colorbar\":1174,\"./plot\":1177,\"./select\":1178,\"./style\":1180,\"./subtypes\":1181}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),a(t,\"line\"))?i(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":625,\"../../components/colorscale/helpers\":626,\"../../lib\":749}],1170:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),a=n.BADNUM,i=n.LOG_CLIP,o=i+.5,s=i-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,i,f,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,I=E._length,z=e.connectGaps,O=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(r){var n=t[r];if(!n)return!1;var i=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(i===a){if(C&&(i=S.c2p(n.x,!0)),i===a)return!1;L&&l===a&&(i*=Math.abs(S._m*I*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),i*=1e3}if(l===a){if(L&&(l=E.c2p(n.y,!0)),l===a)return!1;l*=1e3}return[i,l]}function H(t,e,r,n){var a=r-t,i=n-e,o=.5-t,s=.5-e,l=a*a+i*i,c=a*o+i*s;if(c>0&&c<l){var u=o*i-s*a;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/I,a=Math.max(0,-r,r-1,-n,n-1);return a&&void 0!==M&&H(r,n,M,A)&&(a=0),a&&e&&H(r,n,e[0]/P,e[1]/I)&&(a=0),(1+h.toleranceGrowth*a)*O}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,Z,X,J,K,Q,$,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-I*tt,at=I*(1+tt),it=[[et,nt,rt,nt],[rt,nt,rt,at],[rt,at,et,at],[et,at,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>at)return[u(t[0],et,rt),u(t[1],nt,at)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===at)||void 0)}function lt(t,e,r){return function(n,a){var i=ot(n),o=ot(a),s=[];if(i&&o&&st(i,o))return s;i&&s.push(i),o&&s.push(o);var c=2*l.constrain((n[t]+a[t])/2,e,r)-((i||n)[t]+(o||a)[t]);c&&((i&&o?c>0==i[t]>o[t]?i:o:i||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],a=r===U[V-1][1];if(!n||!a)if(V>1){var i=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&i?o?V--:U[V-1]=t:a&&(r===nt||r===at)&&o?i?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([X,J]),ct(t),K=null,X=J=0}function ht(t){if(M=t[0]/P,A=t[1]/I,W=t[0]<et?et:t[0]>rt?rt:0,Z=t[1]<nt?nt:t[1]>at?at:0,W||Z){if(V)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else Q=$(U[V-1],t)[0],U[V++]=Q;else U[V++]=[W||t[0],Z||t[1]];var r=U[V-1];W&&Z&&(r[0]!==W||r[1]!==Z)?(K&&(X!==W&&J!==Z?ct(X&&J?(n=K,i=(a=t)[0]-n[0],o=(a[1]-n[1])/i,(n[1]*a[0]-a[1]*n[0])/i>0?[o>0?et:rt,at]:[o>0?rt:et,nt]):[X||W,J||Z]):X&&J&&ct([X,J])),ct([W,Z])):X-W&&J-Z&&ct([W||X,Z||J]),K=t,X=W,J=Z}else K&&ut($(K,t)[0]),U[V++]=t;var n,a,i,o}for(\"linear\"===D||\"spline\"===D?$=function(t,e){for(var r=[],n=0,a=0;a<4;a++){var i=it[a],o=c(t[0],t[1],e[0],e[1],i[0],i[1],i[2],i[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?$=function(t,e){var r=[],n=ot(t),a=ot(e);return n&&a&&st(n,a)||(n&&r.push(n),a&&r.push(a)),r}:\"hvh\"===D?$=lt(0,et,rt):\"vhv\"===D&&($=lt(1,nt,at)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(m=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=T=0,g=!1,i=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(k=(v=[d[0]-n[0],d[1]-n[1]])[0]*m[1]-v[1]*m[0],w=Math.min(w,k),(T=Math.max(T,k))-w>G(d,ft))break;i=d,(_=v[0]*m[0]+v[1]*m[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),i!==p&&ht(p)):(p!==n&&ht(p),i!==f&&ht(f)),ht(i),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([X||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":724,\"../../lib\":749,\"./constants\":1160}],1171:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1172:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var a,i,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(i=0;i<r.length;i++)(o=(a=r[i][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):a.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),a._groupIndex=h=l;var d=r.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var g={};for(i=0;i<d.length;i++)o=(a=d[i][0].trace).stackgroup||\"\",!0===a.visible?(a._nexttrace=null,a.fill in n&&(s=g[o],a._prevtrace=s||null,s&&(s._nexttrace=a)),a._ownfill=a.fill&&(\"tozero\"===a.fill.substr(0,6)||\"toself\"===a.fill||\"to\"===a.fill.substr(0,2)&&!a._prevtrace),g[o]=a):a._prevtrace=a._nexttrace=a._ownfill=null;return d}},{}],1173:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,a=e.sizemin||0,i=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=i(t/2);return n(e)&&e>0?Math.max(e,a):0}}},{\"fast-isnumeric\":241}],1174:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),a(t,\"marker\")&&i(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),a(t,\"marker.line\")&&i(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":615,\"../../components/colorscale/defaults\":625,\"../../components/colorscale/helpers\":626,\"./subtypes\":1181}],1176:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").dateTick0,a=t(\"../../constants/numerical\").ONEWEEK;function i(t,e){return n(e,t%a==0?1:0)}e.exports=function(t,e,r,n,a){if(a||(a={x:!0,y:!0}),a.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",i(o,e.xcalendar)),n(\"xperiodalignment\"))}if(a.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",i(s,e.ycalendar)),n(\"yperiodalignment\"))}}},{\"../../constants/numerical\":724,\"../../lib\":749}],1177:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../lib\"),o=i.ensureSingle,s=i.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var m;!function(t,e,r,a,o){var s=r.xaxis,l=r.yaxis,u=n.extent(i.simpleMap(s.range,s.r2c)),h=n.extent(i.simpleMap(l.range,l.r2c)),f=a[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=a.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]})),g=Math.ceil(d.length/p),m=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&m++}));var v=Math.round(m*g/3+Math.floor(m/3)*g/7.1);a.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+v)%g)&&(t.vis=!0)}))}(0,e,r,h,p);var v=!!g&&g.duration>0;function y(t){return v?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,T=n.select(d),k=o(T,\"g\",\"errorbars\"),M=o(T,\"g\",\"lines\"),A=o(T,\"g\",\"points\"),S=o(T,\"g\",\"text\");if(a.getComponentMethod(\"errorbars\",\"plot\")(t,k,r,g),!0===_.visible){var E,C;y(T).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=T;var P,I,z=\"\",O=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,O=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=i.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),m=0;m<G.length;m++)_._polygons[m]=f(G[m]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),I=B(e),q?L?(q+=\"L\"+P.substr(1),H=I+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=I+\"Z\"+H):(q=P,H=I),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var a=y(r);a.attr(\"d\",P),l.singleLineStyle(h,a)}}}}}var W=M.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(O)):(X(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?X(E):C&&X(C),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(h),S.datum(h),function(e,a,i){var o,u=i[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var m=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?m=w?K:J:_&&!w&&(m=Q),h&&(d=m),f&&(g=m)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(T=l.makePointStyleFns(u)),o.each((function(e){var a=n.select(this),i=y(a);l.translatePoint(e,i,x,b)?(l.singlePointStyle(e,i,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,i,x,b,u.xcalendar,u.ycalendar),u.customdata&&a.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):i.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=a.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),a=y(e.select(\"text\"));l.translatePoint(t,a,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){y(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(A,S,h);var Z=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,Z,t),l.setClipUrl(S,Z,t)}function X(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter((function(t){return!t.gap&&t.vis}))}function K(t){return t.filter((function(t){return t.vis}))}function Q(t){return t.filter((function(t){return!t.gap}))}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,a,i,c){var u,f,d=!i,g=!!i&&i.duration>0,m=h(t,e,r);((u=a.selectAll(\"g.trace\").data(m,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var a=o(n.select(this),\"g\",\"fills\");l.setClipUrl(a,r.layerClipId,t);var i=e[0].trace,c=[];i._ownfill&&c.push(\"_ownFill\"),i._nexttrace&&c.push(\"_nextFill\");var u=a.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){i[t]=null})).remove(),u.order().each((function(t){i[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),g)?(c&&(f=c()),n.transition().duration(i.duration).ease(i.easing).each(\"end\",(function(){f&&f()})).each(\"interrupt\",(function(){f&&f()})).each((function(){a.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,m,this,i)}))}))):u.each((function(r,n){p(t,n,e,r,m,this,i)}));d&&u.exit().remove(),a.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/polygon\":761,\"../../registry\":881,\"./line_points\":1170,\"./link_traces\":1172,\"./subtypes\":1181,d3:169}],1178:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,a,i,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)a=s[r],i=l.c2p(a.x),o=c.c2p(a.y),null!==a.i&&e.contains([i,o],!1,r,t)?(u.push({pointNumber:a.i,x:l.c2d(a.x),y:c.c2d(a.y)}),a.selected=1):a.selected=0;return u}},{\"./subtypes\":1181}],1179:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,a){var i=r._scatterStackOpts,o=a(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=i[s];l||(l=i[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],m=\"orientation\"===p;if((g||u)&&(c[p]=a(p,h[p]),m&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],m))))for(var v=0;v<c.traces.length-1;v++){var y=c.traces[v];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1180:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../../registry\");function o(t,e,r){a.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){a.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(a.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(a.fillGroupStyle),i.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(a.selectedPointStyle(r.selectAll(\"path.point\"),n),a.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":637,\"../../registry\":881,d3:169}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":749}],1182:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,a,i){i=i||{},a(\"textposition\"),n.coerceFont(a,\"textfont\",r.font),i.noSelect||(a(\"selected.textfont.color\"),a(\"unselected.textfont.color\"))}},{\"../../lib\":749}],1183:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\");e.exports=function(t,e,r,i){var o,s=i(\"x\"),l=i(\"y\");if(a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,i(\"y0\"),i(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),i(\"x0\"),i(\"dx\")}return e._length=o,o}},{\"../../lib\":749,\"../../registry\":881}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../plots/attributes\"),l=t(\"../../constants/gl3d_dashes\"),c=t(\"../../constants/gl3d_markers\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll,f=n.line,p=n.marker,d=p.line,g=u({width:f.width,dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},a(\"line\"));var m=e.exports=h({x:n.x,y:n.y,z:{valType:\"data_array\"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:i(),mode:u({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:\"enumerated\",values:Object.keys(c),dflt:\"circle\",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},a(\"marker.line\"))},a(\"marker\")),textposition:u({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},\"calc\",\"nested\");m.x.editType=m.y.editType=m.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":622,\"../../constants/gl3d_dashes\":721,\"../../constants/gl3d_markers\":722,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),a=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),a(t,e),r}},{\"../scatter/arrays_to_calcdata\":1155,\"../scatter/colorscale_calc\":1159}],1186:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function a(t,e,r,a){if(!e||!e.visible)return null;for(var i=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=i(+t[s],s);if(\"log\"===a.type){var c=a.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(a.c2l(u,!0)-c)*r,(a.c2l(h,!0)-c)*r],u>0){var f=a.c2l(u);a._lowerLogErrorBound||(a._lowerLogErrorBound=f),a._lowerErrorBound=Math.min(a._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[a(t.x,t.error_x,e[0],r.xaxis),a(t.y,t.error_y,e[1],r.yaxis),a(t.z,t.error_z,e[2],r.zaxis)],i=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===i)return null;for(var o=new Array(i),s=0;s<i;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":881}],1187:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),a=t(\"gl-scatter3d\"),i=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"../../plots/cartesian/axes\"),g=t(\"../../components/fx/helpers\").appendArrayPointValue,m=t(\"./calc_errors\");function v(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=v.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function b(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,a){var i=null;if(l.isArrayOrTypedArray(t)){i=[];for(var o=0;o<e;o++)void 0===t[o]?i[o]=n:i[o]=r(t[o],a)}else i=r(t,l.identity);return i}function k(t,e){var r,n,a,i,o,s,f=[],p=t.fullSceneLayout,v=t.dataScale,y=p.xaxis,k=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],C=e.y||[],L=e.z||[],P=E.length,I=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<P;o++)r=y.d2l(E[o],0,I)*v[0],n=k.d2l(C[o],0,z)*v[1],a=M.d2l(L[o],0,O)*v[2],f[o]=[r,n,a];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(P),o=0;o<P;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,P):P,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:C[o],z:L[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",C[o]),zLabel:D(\"zaxis\",L[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(i={position:f,mode:e.mode,text:s},\"line\"in e&&(i.lineColor=u(S,1,P),i.lineWidth=S.width,i.lineDashes=S.dash),\"marker\"in e){var G=h(e);i.scatterColor=u(A,1,P),i.scatterSize=T(A.size,P,_,20,G),i.scatterMarker=T(A.symbol,P,w,\"\\u25cf\"),i.scatterLineWidth=A.line.width,i.scatterLineColor=u(A.line,1,P),i.scatterAngle=0}\"textposition\"in e&&(i.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),i.textColor=u(e.textfont,1,P),i.textSize=T(e.textfont.size,P,l.identity,12),i.textFont=e.textfont.family,i.textAngle=0);var Y=[\"x\",\"y\",\"z\"];for(i.project=[!1,!1,!1],i.projectScale=[1,1,1],i.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(i.project[o]=W.show)&&(i.projectOpacity[o]=W.opacity,i.projectScale[o]=W.scale)}i.errorBounds=m(e,v,p);var Z=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],a=0;a<3;a++){var i=t[a];i&&!1!==i.copy_zstyle&&!1!==t[2].visible&&(i=t[2]),i&&i.visible&&(e[a]=i.width/2,r[a]=c(i.color),n[a]=i.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return i.errorColor=Z.color,i.errorLineWidth=Z.lineWidth,i.errorCapSize=Z.capSize,i.delaunayAxis=e.surfaceaxis,i.delaunayColor=c(e.surfacecolor),i}function M(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?M(t):t.map(M):null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=k(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=a(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=a(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=i(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,a=(r+1)%3,i=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[a])&&isFinite(c[a])&&!isNaN(c[i])&&isFinite(c[i])&&(o.push([c[a],c[i]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new v(t,e.uid);return r.update(e),r}},{\"../../components/fx/helpers\":651,\"../../constants/gl3d_dashes\":721,\"../../constants/gl3d_markers\":722,\"../../lib\":749,\"../../lib/gl_format_color\":745,\"../../lib/str2rgbarray\":772,\"../../plots/cartesian/axes\":798,\"../scatter/make_bubble_size_func\":1173,\"./calc_errors\":1186,\"delaunay-triangulate\":171,\"gl-error3d\":264,\"gl-line3d\":271,\"gl-mesh3d\":292,\"gl-scatter3d\":308}],1188:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return a.coerce(t,e,c,r,n)}if(function(t,e,r,a){var i=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],a),o&&s&&l&&(i=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=i);return i}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),i.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),i.hasText(e)&&(h(\"texttemplate\"),l(t,e,u,h,{noSelect:!0}));var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var m=\"projection.\"+d[g];h(m+\".show\")&&(h(m+\".opacity\"),h(m+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,f||p||r,{axis:\"z\"}),v(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),v(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":749,\"../../registry\":881,\"../scatter/line_defaults\":1169,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"./attributes\":1184}],1189:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../constants/gl3d_markers\":722,\"../../plots/gl3d\":840,\"./attributes\":1184,\"./calc\":1185,\"./convert\":1187,\"./defaults\":1188}],1190:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=n.line,h=c.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:l({},n.mode,{dflt:\"markers\"}),text:l({},n.text,{}),texttemplate:o({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},s(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},s(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:i()}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156}],1191:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),m=r.isVisible(+u,+h);m||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:m}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),a(t,e),i(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":951,\"../scatter/arrays_to_calcdata\":1155,\"../scatter/calc\":1157,\"../scatter/calc_selection\":1158,\"../scatter/colorscale_calc\":1159,\"fast-isnumeric\":241}],1192:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/constants\"),i=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),m=Math.min(d.length,g.length);if(m){e._length=m,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",m<a.PTS_LINESONLY?\"lines+markers\":\"lines\"),i.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),i.hasText(e)&&c(t,e,f,p);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),i.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),\"fills\"!==p(\"hoveron\",v.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":749,\"../scatter/constants\":1160,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/line_shape_defaults\":1171,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"./attributes\":1190}],1193:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){var i=n[a];return t.a=i.a,t.b=i.b,t.y=i.y,t}},{}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r={},n=e._carpet,a=n.ab2ij([t.a,t.b]),i=Math.floor(a[0]),o=a[0]-i,s=Math.floor(a[1]),l=a[1]-s,c=n.evalxy([],i,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r,i){var o=n(t,e,r,i);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(f,p);s.yLabel=g.yLabel,delete s.text;var m=[];if(!p.hovertemplate){var v=(f.hi||p.hoverinfo).split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"text\"]),-1!==v.indexOf(\"a\")&&y(d.aaxis,f.a),-1!==v.indexOf(\"b\")&&y(d.baxis,f.b),m.push(\"y: \"+s.yLabel),-1!==v.indexOf(\"text\")&&a(f,p,m),s.extraText=m.join(\"<br>\")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,m.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":749,\"../scatter/hover\":1167}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":811,\"../scatter/marker_colorbar\":1174,\"../scatter/select\":1178,\"../scatter/style\":1180,\"./attributes\":1190,\"./calc\":1191,\"./defaults\":1192,\"./event_data\":1193,\"./format_labels\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:a.getFromId(t,u.xaxis||\"x\"),yaxis:a.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),i.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":637,\"../../plots/cartesian/axes\":798,\"../scatter/plot\":1177}],1198:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.marker,f=i.line,p=h.line;e.exports=u({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:c({},i.mode,{dflt:\"markers\"}),text:c({},i.text,{}),texttemplate:a({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:c({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:f.color,width:f.width,dash:l},connectgaps:i.connectgaps,marker:c({symbol:h.symbol,opacity:h.opacity,size:h.size,sizeref:h.sizeref,sizemin:h.sizemin,sizemode:h.sizemode,colorbar:h.colorbar,line:c({width:p.width},s(\"marker.line\")),gradient:h.gradient},s(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":622,\"../../components/drawing/attributes\":636,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156}],1199:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../constants/numerical\").BADNUM,i=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;function c(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),h=u?e.locations.length:e._length,f=new Array(h);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<h;p++){var d=f[p]={};if(u){var g=e.locations[p];d.loc=r(g)?g:null}else{var m=e.lon[p],v=e.lat[p];n(m)&&n(v)?d.lonlat=[+m,+v]:d.lonlat=[a,a]}}return o(f,e),i(t,e),s(f,e),h&&(f[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),f}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../scatter/arrays_to_calcdata\":1155,\"../scatter/calc_selection\":1158,\"../scatter/colorscale_calc\":1159,\"fast-isnumeric\":241}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),i=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}var f,p=h(\"locations\");if(p&&p.length){var d,g=h(\"geojson\");(\"string\"==typeof g&&\"\"!==g||n.isPlainObject(g))&&(d=\"geojson-id\"),\"geojson-id\"===h(\"locationmode\",d)&&h(\"featureidkey\"),f=p.length}else{var m=h(\"lon\")||[],v=h(\"lat\")||[];f=Math.min(m.length,v.length)}f?(e._length=f,h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),a.hasMarkers(e)&&i(t,e,r,u,h,{gradient:!0}),a.hasText(e)&&(h(\"texttemplate\"),s(t,e,u,h)),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)):e.visible=!1}},{\"../../lib\":749,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"./attributes\":1198}],1201:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var i=n[a];return i.fIn&&i.fIn.properties&&(t.properties=i.fIn.properties),t}},{}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a={},i=r[e.geo]._subplot.mockAxis,o=t.lonlat;return a.lonLabel=n.tickText(i,i.c2l(o[0]),!0).text,a.latLabel=n.tickText(i,i.c2l(o[1]),!0).text,a}},{\"../../plots/cartesian/axes\":798}],1203:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),a=t(\"../../constants/numerical\").BADNUM,i=t(\"../scatter/get_trace_color\"),o=t(\"../../lib\").fillText,s=t(\"./attributes\");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=f.projection.isLonLatOverEdges,d=f.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(p(n))return 1/0;var i=d(n),o=d([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[u.c2p(m),h.c2p(m)],y=g.mrc||1;t.x0=v[0]-y,t.x1=v[0]+y,t.y0=v[1]-y,t.y1=v[1]+y,t.loc=g.loc,t.lon=m[0],t.lat=m[1];var x={};x[c.geo]={_subplot:f};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=i(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var a=e.hi||t.hoverinfo,i=\"all\"===a?s.hoverinfo.flags:a.split(\"+\"),l=-1!==i.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==i.indexOf(\"lon\"),u=-1!==i.indexOf(\"lat\"),h=-1!==i.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}l?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&o(e,t,f);return f.join(\"<br>\")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":655,\"../../constants/numerical\":724,\"../../lib\":749,\"../scatter/get_trace_color\":1166,\"./attributes\":1198}],1204:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":830,\"../scatter/marker_colorbar\":1174,\"../scatter/style\":1180,\"./attributes\":1198,\"./calc\":1199,\"./defaults\":1200,\"./event_data\":1201,\"./format_labels\":1202,\"./hover\":1203,\"./plot\":1205,\"./select\":1206,\"./style\":1207}],1205:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../lib/topojson_utils\").getTopojsonFeatures,o=t(\"../../lib/geojson_utils\"),s=t(\"../../lib/geo_location_utils\"),l=t(\"../../plots/cartesian/autorange\").findExtremes,c=t(\"../../constants/numerical\").BADNUM,u=t(\"../scatter/calc\").calcMarkerSize,h=t(\"../scatter/subtypes\"),f=t(\"./style\");e.exports={calcGeoJSON:function(t,e){var r,n,a=t[0].trace,o=e[a.geo],h=o._subplot,f=a._length;if(Array.isArray(a.locations)){var p=a.locationmode,d=\"geojson-id\"===p?s.extractTraceFeature(t):i(a,h.topojson);for(r=0;r<f;r++){n=t[r];var g=\"geojson-id\"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=g?g.properties.ct:[c,c]}}var m,v,y={padded:!0};if(\"geojson\"===o.fitbounds&&\"geojson-id\"===a.locationmode){var x=s.computeBbox(s.getTraceGeojson(a));m=[x[0],x[2]],v=[x[1],x[3]]}else{for(m=new Array(f),v=new Array(f),r=0;r<f;r++)n=t[r],m[r]=n.lonlat[0],v[r]=n.lonlat[1];y.ppad=u(a,f)}a._extremes.lon=l(o.lonaxis._ax,m,y),a._extremes.lat=l(o.lataxis._ax,v,y)},plot:function(t,e,r){var i=e.layers.frontplot.select(\".scatterlayer\"),s=a.makeTraceGroups(i,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),i=e[0].trace;if(h.hasLines(i)||\"none\"!==i.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==i.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:i}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}h.hasMarkers(i)&&r.selectAll(\"path.point\").data(a.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),h.hasText(i)&&r.selectAll(\"g\").data(a.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),f(t,e)}))}}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../lib/geo_location_utils\":742,\"../../lib/geojson_utils\":743,\"../../lib/topojson_utils\":776,\"../../plots/cartesian/autorange\":797,\"../scatter/calc\":1157,\"../scatter/subtypes\":1181,\"./style\":1207,d3:169}],1206:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,i,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(i=(r=c[l]).lonlat)[0]!==a&&(o=u.c2p(i),s=h.c2p(i),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:i[0],lat:i[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":724,\"../scatter/subtypes\":1181}],1207:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(i.stroke,o.color).call(a.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(i.fill,r.fillcolor)}))}(t,e)}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../scatter/style\":1180,d3:169}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),a=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=a.line,u=a.marker,h=u.line,f=e.exports=s({x:a.x,x0:a.x0,dx:a.dx,y:a.y,y0:a.y0,dy:a.dy,xperiod:a.xperiod,yperiod:a.yperiod,xperiod0:a.xperiod0,yperiod0:a.yperiod0,xperiodalignment:a.xperiodalignment,yperiodalignment:a.yperiodalignment,text:a.text,hovertext:a.hovertext,textposition:a.textposition,textfont:a.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},i(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},i(\"marker.line\"),{width:h.width})}),connectgaps:a.connectgaps,fill:o({},a.fill,{dflt:\"none\"}),fillcolor:a.fillcolor,selected:{marker:a.selected.marker,textfont:a.selected.textfont},unselected:{marker:a.unselected.marker,textfont:a.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=a.hovertemplate,f.texttemplate=a.texttemplate},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../scatter/attributes\":1156,\"./constants\":1210}],1209:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../../plots/cartesian/align_period\"),l=t(\"../scatter/calc\"),c=l.calcMarkerSize,u=l.calcAxisExpansion,h=l.setFirstScatter,f=t(\"../scatter/colorscale_calc\"),p=t(\"./convert\"),d=t(\"./scene_update\"),g=t(\"../../constants/numerical\").BADNUM,m=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],a=o(e,r._bnds,{padded:!0});n.min=n.min.concat(a.min),n.max=n.max.concat(a.max)}e.exports=function(t,e){var r,o,l,y=t._fullLayout,x=i.getFromId(t,e.xaxis),b=i.getFromId(t,e.yaxis),_=y._plots[e.xaxis+e.yaxis],w=e._length,T=w>=m,k=2*w,M={},A=x.makeCalcdata(e,\"x\"),S=b.makeCalcdata(e,\"y\"),E=s(e,x,\"x\",A),C=s(e,b,\"y\",S);e._x=E,e._y=C,e.xperiodalignment&&(e._origX=A),e.yperiodalignment&&(e._origY=S);var L=new Array(k);for(r=0;r<w;r++)o=E[r],l=C[r],L[2*r]=o===g?NaN:o,L[2*r+1]=l===g?NaN:l;if(\"log\"===x.type)for(r=0;r<k;r+=2)L[r]=x.c2l(L[r]);if(\"log\"===b.type)for(r=1;r<k;r+=2)L[r]=b.c2l(L[r]);if(T&&\"log\"!==x.type&&\"log\"!==b.type)M.tree=n(L);else{var P=M.ids=new Array(w);for(r=0;r<w;r++)P[r]=r}f(t,e);var I,z=function(t,e,r,n,i,o){var s=p.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&a.extendFlat(s.line,p.linePositions(t,r,n));if(s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,i,o);s.errorX&&a.extendFlat(s.errorX,l.x),s.errorY&&a.extendFlat(s.errorY,l.y)}s.text&&(a.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),a.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),a.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,L,E,C),O=d(t,_);return h(y,e),T?z.marker&&(I=2*(z.marker.sizeAvg||Math.max(z.marker.size,3))):I=c(e,w),u(t,e,x,b,E,C,I),z.errorX&&v(e,x,z.errorX),z.errorY&&v(e,b,z.errorY),z.fill&&!O.fill2d&&(O.fill2d=!0),z.marker&&!O.scatter2d&&(O.scatter2d=!0),z.line&&!O.line2d&&(O.line2d=!0),!z.errorX&&!z.errorY||O.error2d||(O.error2d=!0),z.text&&!O.glText&&(O.glText=!0),z.marker&&(z.marker.snap=w),O.lineOptions.push(z.line),O.errorXOptions.push(z.errorX),O.errorYOptions.push(z.errorY),O.fillOptions.push(z.fill),O.markerOptions.push(z.marker),O.markerSelectedOptions.push(z.markerSel),O.markerUnselectedOptions.push(z.markerUnsel),O.textOptions.push(z.text),O.textSelectedOptions.push(z.textSel),O.textUnselectedOptions.push(z.textUnsel),O.selectBatch.push([]),O.unselectBatch.push([]),M._scene=O,M.index=O.count,M.x=E,M.y=C,M.positions=L,O.count++,[{x:!1,y:!1,t:M,trace:e}]}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/autorange\":797,\"../../plots/cartesian/axis_ids\":801,\"../scatter/calc\":1157,\"../scatter/colorscale_calc\":1159,\"./constants\":1210,\"./convert\":1211,\"./scene_update\":1219,\"@plotly/point-cluster\":57}],1210:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1211:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"svg-path-sdf\"),i=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./helpers\"),d=t(\"./constants\"),g=t(\"../../constants/interactions\").DESELECTDIM,m={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t(\"../../components/fx/helpers\").appendArrayPointValue;function y(t,e){var r,a=t._fullLayout,i=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,h=o.size,f=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=a._d3locale,m=Array.isArray(d),y=m?Math.min(d.length,i):i,x=m?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,a),w={};v(w,e,r);var T=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,T))}}else Array.isArray(e.text)&&e.text.length<i?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<i;r++)p.text[r]=\"\";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var k=c[r].split(/\\s+/);switch(k[1]){case\"left\":p.align.push(\"right\");break;case\"right\":p.align.push(\"left\");break;default:p.align.push(k[1])}switch(k[0]){case\"top\":p.baseline.push(\"bottom\");break;case\"bottom\":p.baseline.push(\"top\");break;default:p.baseline.push(k[0])}}if(Array.isArray(u))for(p.color=new Array(i),r=0;r<i;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(h)||Array.isArray(f))for(p.font=new Array(i),r=0;r<i;r++){var M=p.font[r]={};M.size=s.isTypedArray(h)?h[r]:Array.isArray(h)?n(h[r])?h[r]:0:h,M.family=Array.isArray(f)?f[r]:f}else p.font={size:h,family:f};return p}function x(t){var e,r,n=t._length,a=t.marker,o={},l=s.isArrayOrTypedArray(a.symbol),c=s.isArrayOrTypedArray(a.color),h=s.isArrayOrTypedArray(a.line.color),d=s.isArrayOrTypedArray(a.opacity),g=s.isArrayOrTypedArray(a.size),m=s.isArrayOrTypedArray(a.line.width);if(l||(r=p.isOpenSymbol(a.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var v=u(a,a.opacity,n),y=u(a.line,a.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(v[0])){var b=v;for(v=Array(n),e=0;e<n;e++)v[e]=b}for(o.colors=v,o.borderColors=y,e=0;e<n;e++){if(l){var _=a.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=v[e].slice(),v[e]=v[e].slice(),v[e][3]=0)}o.opacity=t.opacity}else r?(o.color=i(a.color,\"uint8\"),o.color[3]=0,o.borderColor=i(a.color,\"uint8\")):(o.color=i(a.color,\"uint8\"),o.borderColor=i(a.line.color,\"uint8\")),o.opacity=t.opacity*a.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(a.symbol[e]);else o.marker=E(a.symbol);var w,T=f(t);if(g||m){var k,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(g){for(e=0;e<n;e++)M[e]=T(a.size[e]),S+=M[e];k=S/n}else for(w=T(a.size),e=0;e<n;e++)M[e]=w;if(m)for(e=0;e<n;e++)A[e]=a.line.width[e]/2;else for(w=a.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=k}else o.size=T(a&&a.size||10),o.borderSizes=T(a.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var a={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(a.textfont,r.textfont),n=y(t,a)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var T=d.SYMBOL_SDF_SIZE,k=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*k);function E(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),i=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?i(1.1*k)+S:i(k),r=a(e,{w:T,h:T,viewBox:[-k,-k,k,k],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),h.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var a=e.marker.opacity;for(n.markerUnsel.opacity=new Array(a.length),r=0;r<a.length;r++)n.markerUnsel.opacity[r]=g*a[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var i=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<i.length;++r)i[r]*=e.line.width;n.line.dashes=i}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,a,i=r.length,o=i/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],a=0;a<o-1;a++)isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*a],r[2*a+1]),isNaN(r[2*a+2])||isNaN(r[2*a+3])?n.push(NaN,NaN):n.push(r[2*a+2],r[2*a+1]));n.push(r[i-2],r[i-1])}else if(\"hvh\"===e.line.shape){for(n=[],a=0;a<o-1;a++)if(isNaN(r[2*a])||isNaN(r[2*a+1])||isNaN(r[2*a+2])||isNaN(r[2*a+3]))isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+1]),n.push(NaN,NaN);else{var s=(r[2*a]+r[2*a+2])/2;n.push(r[2*a],r[2*a+1],s,r[2*a+1],s,r[2*a+3])}n.push(r[i-2],r[i-1])}else if(\"vhv\"===e.line.shape){for(n=[],a=0;a<o-1;a++)if(isNaN(r[2*a])||isNaN(r[2*a+1])||isNaN(r[2*a+2])||isNaN(r[2*a+3]))isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+1]),n.push(NaN,NaN);else{var l=(r[2*a+1]+r[2*a+3])/2;n.push(r[2*a],r[2*a+1],r[2*a],l,r[2*a+2],l)}n.push(r[i-2],r[i-1])}else if(\"vh\"===e.line.shape){for(n=[],a=0;a<o-1;a++)isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*a],r[2*a+1]),isNaN(r[2*a+2])||isNaN(r[2*a+3])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+3]));n.push(r[i-2],r[i-1])}else n=r;var c=!1;for(a=0;a<n.length;a++)if(isNaN(n[a])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS||h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],p=n[1];for(a=0;a<n.length;a+=2)isNaN(n[a])||isNaN(n[a+1])?(n[a]=f,n[a+1]=p):(f=n[a],p=n[a+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,a,i){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,a){var i=a._id.charAt(0),o=e[\"error_\"+i];if(o&&o.visible&&(\"linear\"===a.type||\"log\"===a.type)){for(var l=s(o),c={x:0,y:1}[i],u={x:[0,1,2,3],y:[2,3,0,1]}[i],p=new Float64Array(4*h),d=1/0,g=-1/0,m=0,v=0;m<h;m++,v+=4){var y=t[m];if(n(y)){var x=r[2*m+c],b=l(y,m),_=b[0],w=b[1];if(n(_)&&n(w)){var T=y-_,k=y+w;p[v+u[0]]=x-a.c2l(T),p[v+u[1]]=a.c2l(k)-x,p[v+u[2]]=0,p[v+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[i]={positions:r,errors:p,_bnds:[d,g]}}}return p(a,l),p(i,u),f},textPosition:function(t,e,r,n){var a,i=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(i),a=0;a<i;a++){var u=n.sizes?n.sizes[a]:n.size,f=Array.isArray(s)?s[a].size:s.size,p=Array.isArray(l)?l.length>1?l[a]:l[0]:l,d=Array.isArray(c)?c.length>1?c[a]:c[0]:c,g=m[p],v=m[d],y=u?u/.8+1:0,x=-v*y-.5*v;o.offset[a]=[g*y/f,x/f]}}return o}}},{\"../../components/drawing\":637,\"../../components/fx/helpers\":651,\"../../constants/interactions\":723,\"../../lib\":749,\"../../lib/gl_format_color\":745,\"../../plots/cartesian/axis_ids\":801,\"../../registry\":881,\"../scatter/make_bubble_size_func\":1173,\"../scatter/subtypes\":1181,\"./constants\":1210,\"./helpers\":1215,\"color-normalize\":125,\"fast-isnumeric\":241,\"svg-path-sdf\":546}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../registry\"),i=t(\"./helpers\"),o=t(\"./attributes\"),s=t(\"../scatter/constants\"),l=t(\"../scatter/subtypes\"),c=t(\"../scatter/xy_defaults\"),u=t(\"../scatter/period_defaults\"),h=t(\"../scatter/marker_defaults\"),f=t(\"../scatter/line_defaults\"),p=t(\"../scatter/fillcolor_defaults\"),d=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,g){function m(r,a){return n.coerce(t,e,o,r,a)}var v=!!t.marker&&i.isOpenSymbol(t.marker.symbol),y=l.isBubble(t),x=c(t,e,g,m);if(x){u(t,e,g,m);var b=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";m(\"text\"),m(\"hovertext\"),m(\"hovertemplate\"),m(\"mode\",b),l.hasLines(e)&&(m(\"connectgaps\"),f(t,e,r,g,m),m(\"line.shape\")),l.hasMarkers(e)&&(h(t,e,r,g,m),m(\"marker.line.width\",v||y?1:0)),l.hasText(e)&&(m(\"texttemplate\"),d(t,e,g,m));var _=(e.line||{}).color,w=(e.marker||{}).color;m(\"fill\"),\"none\"!==e.fill&&p(t,e,r,m);var T=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,_||w||r,{axis:\"y\"}),T(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,m)}else e.visible=!1}},{\"../../lib\":749,\"../../registry\":881,\"../scatter/constants\":1160,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/marker_defaults\":1175,\"../scatter/period_defaults\":1176,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"../scatter/xy_defaults\":1183,\"./attributes\":1208,\"./helpers\":1215}],1213:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},m=n.extendFlat({},p);if(h.length||f.length){var v=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(m.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],m.color[r]=v||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;m.color[r]=y||(v?_:a.addOpacity(_,i))}}c.glText[u].update(m)}}},{\"../../components/color\":615,\"../../constants/interactions\":723,\"../../lib\":749}],1214:[function(t,e,r){\"use strict\";var n=t(\"../scatter/format_labels\");e.exports=function(t,e,r){var a=t.i;return\"x\"in t||(t.x=e._x[a]),\"y\"in t||(t.y=e._y[a]),n(t,e,r)}},{\"../scatter/format_labels\":1165}],1215:[function(t,e,r){\"use strict\";var n=t(\"./constants\");r.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},{\"./constants\":1210}],1216:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=a.isArrayOrTypedArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=a.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=a.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=a.isArrayOrTypedArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=a.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=a.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var m=d&&d.gradient;m&&\"none\"!==m.type&&(f.mgt=Array.isArray(m.type)?m.type[h]:m.type,f.mgc=Array.isArray(m.color)?m.color[h]:m.color);var v=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=a.isArrayOrTypedArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=a.isArrayOrTypedArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var T={};T[t.index]=f;var k=o._origX,M=o._origY,A=a.extendFlat({},t,{color:i(o,f),x0:v-x,x1:v+x,xLabelVal:k?k[h]:f.x,y0:y-x,y1:y+x,yLabelVal:M?M[h]:f.y,cd:T,distance:c,spikeDistance:u,hovertemplate:f.ht});return f.htx?A.text=f.htx:f.tx?A.text=f.tx:o.text&&(A.text=o.text),a.fillText(f,o,A),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,A),A}e.exports={hoverPoints:function(t,e,r,n){var a,i,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,m=d[0].trace,v=t.xa,y=t.ya,x=g.x,b=g.y,_=v.c2p(e),w=y.c2p(r),T=t.distance;if(g.tree){var k=v.p2c(_-T),M=v.p2c(_+T),A=y.p2c(w-T),S=y.p2c(w+T);a=\"x\"===n?g.tree.range(Math.min(k,M),Math.min(y._rl[0],y._rl[1]),Math.max(k,M),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(k,M),Math.min(A,S),Math.max(k,M),Math.max(A,S))}else a=g.ids;var E=T;if(\"x\"===n)for(c=0;c<a.length;c++)s=x[a[c]],(u=Math.abs(v.c2p(s)-_))<E&&(E=u,h=y.c2p(b[a[c]])-w,p=Math.sqrt(u*u+h*h),i=a[c]);else for(c=a.length-1;c>-1;c--)s=x[a[c]],l=b[a[c]],u=v.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,i=a[c]);return t.index=i,t.distance=E,t.dxy=p,void 0===i?[t]:[o(t,x,b,m)]},calcHover:o}},{\"../../lib\":749,\"../../registry\":881,\"../scatter/get_trace_color\":1166}],1217:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":811,\"../scatter/cross_trace_defaults\":1162,\"../scatter/marker_colorbar\":1174,\"./attributes\":1208,\"./calc\":1209,\"./defaults\":1212,\"./format_labels\":1214,\"./hover\":1216,\"./plot\":1218,\"./select\":1220}],1218:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),a=t(\"regl-line2d\"),i=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../components/dragelement/helpers\").selectMode,c=t(\"../../lib/prepare_regl\"),u=t(\"../scatter/subtypes\"),h=t(\"../scatter/link_traces\"),f=t(\"./edit_style\").styleTextSelection;function p(t,e,r){var n=t._size,a=t.width,i=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,a-n.r-(1-e.domain[1])*n.w,i-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var d,g,m=t._fullLayout,v=e._scene,y=e.xaxis,x=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var b=v.count,_=m._glcanvas.data()[0].regl;if(h(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=i(_)),!0===v.line2d&&(v.line2d=a(_)),!0===v.scatter2d&&(v.scatter2d=n(_,{constPointSize:!0})),!0===v.fill2d&&(v.fill2d=a(_)),!0===v.glText)for(v.glText=new Array(b),d=0;d<b;d++)v.glText[d]=new o(_);if(v.glText){if(b>v.glText.length){var w=b-v.glText.length;for(d=0;d<w;d++)v.glText.push(new o(_))}else if(b<v.glText.length){var T=v.glText.length-b;v.glText.splice(b,T).forEach((function(t){t.destroy()}))}for(d=0;d<b;d++)v.glText[d].update(v.textOptions[d])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var a,i,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],a=0,i=0;i<d.length;i+=2)(isNaN(d[i])||isNaN(d[i+1]))&&((p=p.concat(d.slice(a,i))).push(d[a],d[a+1]),a=i+2);p=p.concat(d.slice(a)),a&&p.push(d[a],d[a+1])}else{var g=s._nexttrace;if(g){var m=v.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=g.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,T=[a=w];for(i=0;i<_.length;i+=2)(isNaN(_[i])||isNaN(_[i+1]))&&(T.push(i/2+w+1),a=i+2);p=p.concat(_),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=m.dragmode,A=l(M),S=m.clickmode.indexOf(\"select\")>-1;for(d=0;d<b;d++){var E=r[d][0],C=E.trace,L=E.t,P=L.index,I=C._length,z=L.x,O=L.y;if(C.selectedpoints||A||S){if(A||(A=!0),C.selectedpoints){var D=v.selectBatch[P]=s.selIndices2selPoints(C),R={};for(g=0;g<D.length;g++)R[D[g]]=1;var F=[];for(g=0;g<I;g++)R[g]||F.push(g);v.unselectBatch[P]=F}var B=L.xpx=new Array(I),N=L.ypx=new Array(I);for(g=0;g<I;g++)B[g]=y.c2p(z[g]),N[g]=x.c2p(O[g])}else L.xpx=L.ypx=null}if(A){if(v.select2d||(v.select2d=n(m._glcanvas.data()[1].regl)),v.scatter2d){var j=new Array(b);for(d=0;d<b;d++)j[d]=v.selectBatch[d].length||v.unselectBatch[d].length?v.markerUnselectedOptions[d]:{};v.scatter2d.update(j)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&f(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var U={viewport:p(m,y,x),range:[(y._rl||y.range)[0],(x._rl||x.range)[0],(y._rl||y.range)[1],(x._rl||x.range)[1]]},V=s.repeat(U,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach((function(t){t.update(U)}))}else v.init()}}},{\"../../components/dragelement/helpers\":633,\"../../lib\":749,\"../../lib/prepare_regl\":762,\"../scatter/link_traces\":1172,\"../scatter/subtypes\":1181,\"./edit_style\":1213,\"gl-text\":326,\"regl-error2d\":508,\"regl-line2d\":509,\"regl-scatter2d\":510}],1219:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,a={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},i={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,i,a)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var a=0;a<r.count;a++)r.glText[a].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,a=r.error2d,i=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),i&&r.lineOptions[h]&&i.draw(h),a&&(r.errorXOptions[h]&&a.draw(h),r.errorYOptions[h]&&a.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,a),r}},{\"../../lib\":749}],1220:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),a=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,i=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return i;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return i;var m=[],v=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(m.push(y),i.push({pointNumber:y,x:c[y],y:u[y]})):v.push(y);if(d){var x=h.scatter2d;if(m.length||v.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=m,h.unselectBatch[f]=v,p&&a(r),i}},{\"../scatter/subtypes\":1181,\"./edit_style\":1213}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../scattergeo/attributes\"),o=t(\"../scatter/attributes\"),s=t(\"../../plots/mapbox/layout_attributes\"),l=t(\"../../plots/attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll,f=i.line,p=i.marker;e.exports=h({lon:i.lon,lat:i.lat,mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:a({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:f.color,width:f.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c(\"marker\")),fill:i.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../../plots/mapbox/layout_attributes\":857,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156,\"../scattergeo/attributes\":1198}],1222:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\"),f=t(\"../../components/fx/helpers\").appendArrayPointValue,p=t(\"../../lib/svg_text_utils\").NEWLINES,d=t(\"../../lib/svg_text_utils\").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function m(t,e){return a.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function y(t){return t[0]===i}e.exports=function(t,e){var r,i=e[0].trace,x=!0===i.visible&&0!==i._length,b=\"none\"!==i.fill,_=u.hasLines(i),w=u.hasMarkers(i),T=u.hasText(i),k=w&&\"circle\"===i.marker.symbol,M=w&&\"circle\"!==i.marker.symbol,A=g(),S=g(),E=g(),C=g(),L={fill:A,line:S,circle:E,symbol:C};if(!x)return L;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility=\"visible\",a.extendFlat(A.paint,{\"fill-color\":i.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility=\"visible\",a.extendFlat(S.paint,{\"line-width\":i.line.width,\"line-color\":i.line.color,\"line-opacity\":i.opacity})),k){var P=function(t){var e,r,i,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=a.isArrayOrTypedArray(h.color),d=a.isArrayOrTypedArray(h.size),g=a.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):a.identity);d&&(i=c(u));g&&(o=function(t){return m(n(t)?+a.constrain(t,0,1):0)});var v,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),i&&(w.mrc=b.mrc=i(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(v=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var T=x[e].properties;v.selectedOpacityFn&&(T.mo=m(v.selectedOpacityFn(T))),v.selectedColorFn&&(T.mcc=v.selectedColorFn(T)),v.selectedSizeFn&&(T.mrc=v.selectedSizeFn(T))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||v&&v.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||v&&v.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(k=h.size,k/2),mo:g||v&&v.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var k}(e);E.geojson=P.geojson,E.layout.visibility=\"visible\",a.extendFlat(E.paint,{\"circle-color\":P.mcc,\"circle-radius\":P.mrc,\"circle-opacity\":P.mo})}if((M||T)&&(C.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,i=n.marker||{},o=i.symbol,s=i.angle,l=\"circle\"!==o?m(o):v,c=\"auto\"!==s?m(s,!0):v,h=u.hasText(n)?m(n.text):v,g=[],x=0;x<t.length;x++){var b=t[x];if(!y(b.lonlat)){var _,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[x]||\"\":w,k=n._module.formatLabels(b,n,r),M={};f(M,n,b.i);var A=n._meta||{};_=a.texttemplateString(T,k,r._d3locale,M,b,A)}else _=h(x);_&&(_=_.replace(p,\"\").replace(d,\"\\n\")),g.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:b.lonlat},properties:{symbol:l(x),angle:c(x),text:_}})}}return{type:\"FeatureCollection\",features:g}}(e,t),a.extendFlat(C.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),M&&(a.extendFlat(C.layout,{\"icon-size\":i.marker.size/10}),\"angle\"in i.marker&&\"auto\"!==i.marker.angle&&a.extendFlat(C.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),C.layout[\"icon-allow-overlap\"]=i.marker.allowoverlap,a.extendFlat(C.paint,{\"icon-opacity\":i.opacity*i.marker.opacity,\"icon-color\":i.marker.color})),T)){var I=(i.marker||{}).size,z=h(i.textposition,I);a.extendFlat(C.layout,{\"text-size\":i.textfont.size,\"text-anchor\":z.anchor,\"text-offset\":z.offset}),a.extendFlat(C.paint,{\"text-color\":i.textfont.color,\"text-opacity\":i.opacity})}return L}},{\"../../components/colorscale\":627,\"../../components/drawing\":637,\"../../components/fx/helpers\":651,\"../../constants/numerical\":724,\"../../lib\":749,\"../../lib/geojson_utils\":743,\"../../lib/svg_text_utils\":773,\"../../plots/mapbox/convert_text_opts\":854,\"../scatter/make_bubble_size_func\":1173,\"../scatter/subtypes\":1181,\"fast-isnumeric\":241}],1223:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),i=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}if(function(t,e,r){var n=r(\"lon\")||[],a=r(\"lat\")||[],i=Math.min(n.length,a.length);return e._length=i,i}(0,e,h)){if(h(\"text\"),h(\"texttemplate\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),a.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),a.hasMarkers(e)){i(t,e,r,u,h,{noLine:!0}),h(\"marker.allowoverlap\"),h(\"marker.angle\");var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}a.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":749,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"./attributes\":1221}],1224:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a={},i=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return a.lonLabel=n.tickText(i,i.c2l(o[0]),!0).text,a.latLabel=n.tickText(i,i.c2l(o[1]),!0).text,a}},{\"../../plots/cartesian/axes\":798}],1226:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),a=t(\"../../lib\"),i=t(\"../scatter/get_trace_color\"),o=a.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=a.modHalf(e[0],360),i=e[1],o=f.project([n,i]),l=o.x-u.c2p([d,i]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[a.modHalf(m[0],360)+p,m[1]],y=u.c2p(v),x=h.c2p(v),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:f};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=i(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==n.indexOf(\"all\"),i=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||i&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):i?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":655,\"../../constants/numerical\":724,\"../../lib\":749,\"../scatter/get_trace_color\":1166}],1227:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/mapbox\":855,\"../scatter/marker_colorbar\":1174,\"../scattergeo/calc\":1199,\"./attributes\":1221,\"./defaults\":1223,\"./event_data\":1224,\"./format_labels\":1225,\"./hover\":1226,\"./plot\":1228,\"./select\":1229}],1228:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),a=t(\"../../plots/mapbox/constants\").traceLayerPrefix,i=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:a+e+\"-fill\",line:a+e+\"-line\",circle:a+e+\"-circle\",symbol:a+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,a,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=i.length-1;e>=0;e--)r=i[e],s.removeLayer(this.layerIds[r]);for(e=0;e<i.length;e++)a=l[r=i[e]],this.addLayer(r,a,c);this.below=c}for(e=0;e<i.length;e++)a=l[r=i[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",a.layout),\"visible\"===a.layout.visibility&&(this.setSourceData(r,a),o.setOptions(this.layerIds[r],\"setPaintProperty\",a.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=i.length-1;e>=0;e--){var r=i[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,a=new o(t,r.uid),s=n(t.gd,e),l=a.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<i.length;c++){var u=i[c],h=s[u];a.addSource(u,h),a.addLayer(u,h,l)}return e[0].trace._glTrace=a,a}},{\"../../plots/mapbox/constants\":853,\"./convert\":1222}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!a.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==i){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../scatter/subtypes\":1181}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../../lib/extend\").extendFlat,o=t(\"../scatter/attributes\"),s=t(\"../../plots/attributes\"),l=o.line;e.exports={mode:o.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:o.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:i({},l.shape,{values:[\"linear\",\"spline\"]}),smoothing:l.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:i({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:i({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o.fillcolor,hoverinfo:i({},s.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156}],1231:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../../constants/numerical\").BADNUM,i=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,m=new Array(g),v=0;v<g;v++){var y=p[v],x=d[v],b=m[v]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=a}var _=c(e,g);return e._extremes.x=i.findExtremes(h,p,{ppad:_}),o(t,e),s(m,e),l(m,e),m}},{\"../../constants/numerical\":724,\"../../plots/cartesian/axes\":798,\"../scatter/arrays_to_calcdata\":1155,\"../scatter/calc\":1157,\"../scatter/calc_selection\":1158,\"../scatter/colorscale_calc\":1159,\"fast-isnumeric\":241}],1232:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),i=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var a,i=n(\"r\"),o=n(\"theta\");if(i)o?a=Math.min(i.length,o.length):(a=i.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;a=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=a,a}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,h,r,a)}var g=f(t,e,p,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),a.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),a.hasMarkers(e)&&i(t,e,r,p,d,{gradient:!0}),a.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var m=[];(a.hasMarkers(e)||a.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),m.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),a.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),d(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":749,\"../scatter/constants\":1160,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/line_shape_defaults\":1171,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"./attributes\":1230}],1233:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i,o,s={},l=r[e.subplot]._subplot;l?(i=l.radialAxis,o=l.angularAxis):(i=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=i.c2l(t.r);s.rLabel=a.tickText(i,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=a.tickText(o,u,!0).text,s}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798}],1234:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");function a(t,e,r,n){var a=r.radialAxis,i=r.angularAxis;a._hovertitle=\"r\",i._hovertitle=\"\\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var h=l.split(\"+\");-1!==h.indexOf(\"all\")&&(h=[\"r\",\"theta\",\"text\"]),-1!==h.indexOf(\"r\")&&u(a,n.rLabel),-1!==h.indexOf(\"theta\")&&u(i,n.thetaLabel),-1!==h.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var o=n(t,e,r,i);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,a(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:a}},{\"../scatter/hover\":1167}],1235:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":864,\"../scatter/marker_colorbar\":1174,\"../scatter/select\":1178,\"../scatter/style\":1180,\"./attributes\":1230,\"./calc\":1231,\"./defaults\":1232,\"./format_labels\":1233,\"./hover\":1234,\"./plot\":1236}],1236:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var i=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===a)f.x=f.y=a;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,i)}},{\"../../constants/numerical\":724,\"../scatter/plot\":1177}],1237:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),a=t(\"../scattergl/attributes\"),i=t(\"../../plots/template_attributes\").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:a.line,connectgaps:a.connectgaps,marker:a.marker,fill:a.fill,fillcolor:a.fillcolor,textposition:a.textposition,textfont:a.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../../plots/template_attributes\":876,\"../scattergl/attributes\":1208,\"../scatterpolar/attributes\":1230}],1238:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/calc\").calcMarkerSize,i=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=e._r=c.makeCalcdata(e,\"r\"),f=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,m=d.opts=i.style(t,e);return p<s?g=a(e,p):m.marker&&(g=2*(m.marker.sizeAvg||Math.max(m.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":798,\"../scatter/calc\":1157,\"../scatter/colorscale_calc\":1159,\"../scattergl/constants\":1210,\"../scattergl/convert\":1211}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}var d=i(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),a.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p),a.hasText(e)&&(p(\"texttemplate\"),l(t,e,f,p)),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":749,\"../scatter/constants\":1160,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"../scatterpolar/defaults\":1232,\"./attributes\":1237}],1240:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/format_labels\");e.exports=function(t,e,r){var a=t.i;return\"r\"in t||(t.r=e._r[a]),\"theta\"in t||(t.theta=e._theta[a]),n(t,e,r)}},{\"../scatterpolar/format_labels\":1233}],1241:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),a=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,i){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,i);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,a(f,p,h,u),c}}}},{\"../scattergl/hover\":1216,\"../scatterpolar/hover\":1234}],1242:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":864,\"../scatter/marker_colorbar\":1174,\"../scattergl/select\":1220,\"./attributes\":1237,\"./calc\":1238,\"./defaults\":1239,\"./format_labels\":1240,\"./hover\":1241,\"./plot\":1243}],1243:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),a=t(\"fast-isnumeric\"),i=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var i,o=r[0],p=o.trace,d=o.t,g=p._length,m=d.r,v=d.theta,y=d.opts,x=m.slice(),b=v.slice();for(i=0;i<m.length;i++)e.isPtInside({r:m[i],theta:v[i]})||(x[i]=NaN,b[i]=NaN);var _=new Array(2*g),w=Array(g),T=Array(g);for(i=0;i<g;i++){var k,M,A=x[i];if(a(A)){var S=u.c2g(A),E=h.c2g(b[i],p.thetaunit);k=S*Math.cos(E),M=S*Math.sin(E)}else k=M=NaN;w[i]=_[2*i]=k,T[i]=_[2*i+1]=M}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=m,d.theta=v,d.positions=_,d._scene=f,d.index=f.count,f.count++}})),i(t,e,r)}}},{\"../../lib\":749,\"../scattergl/constants\":1210,\"../scattergl/convert\":1211,\"../scattergl/plot\":1218,\"../scattergl/scene_update\":1219,\"@plotly/point-cluster\":57,\"fast-isnumeric\":241}],1244:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=i.marker,h=i.line,f=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},i.mode,{dflt:\"markers\"}),text:c({},i.text,{}),texttemplate:a({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:c({},i.hovertext,{}),line:{color:h.color,width:h.width,dash:l,shape:c({},h.shape,{values:[\"linear\",\"spline\"]}),smoothing:h.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:c({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:f.width,editType:\"calc\"},s(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},s(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":622,\"../../components/drawing/attributes\":636,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156}],1245:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),a=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,m=e.sum||g,v={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!v[h=l[r]]){for(p=v[c[h][0]],d=v[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=m-p[u]-d[u];v[h]=f}var y,x,b,_,w,T,k=e._length,M=new Array(k);for(r=0;r<k;r++)y=v.a[r],x=v.b[r],b=v.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),T=y,w=b-x,M[r]={x:w,y:T,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,k),a(t,e),i(M,e),o(M,e),M}},{\"../scatter/arrays_to_calcdata\":1155,\"../scatter/calc\":1157,\"../scatter/calc_selection\":1158,\"../scatter/colorscale_calc\":1159,\"fast-isnumeric\":241}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/constants\"),i=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}var d,g=p(\"a\"),m=p(\"b\"),v=p(\"c\");if(g?(d=g.length,m?(d=Math.min(d,m.length),v&&(d=Math.min(d,v.length))):d=v?Math.min(d,v.length):0):m&&v&&(d=Math.min(m.length,v.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<a.PTS_LINESONLY?\"lines+markers\":\"lines\"),i.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),i.hasText(e)&&(p(\"texttemplate\"),c(t,e,f,p));var y=[];(i.hasMarkers(e)||i.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),i.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":749,\"../scatter/constants\":1160,\"../scatter/fillcolor_defaults\":1164,\"../scatter/line_defaults\":1169,\"../scatter/line_shape_defaults\":1171,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scatter/text_defaults\":1182,\"./attributes\":1244}],1247:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,a){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[a]){var i=n[a];t.a=i.a,t.b=i.b,t.c=i.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1248:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a={},i=r[e.subplot]._subplot;return a.aLabel=n.tickText(i.aaxis,t.a,!0).text,a.bLabel=n.tickText(i.baxis,t.b,!0).text,a.cLabel=n.tickText(i.caxis,t.c,!0).text,a}},{\"../../plots/cartesian/axes\":798}],1249:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,a){var i=n(t,e,r,a);if(i&&!1!==i[0].index){var o=i[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),i}var h=o.cd[o.index],f=o.trace,p=o.subplot;o.a=h.a,o.b=h.b,o.c=h.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[f.subplot]={_subplot:p};var g=f._module.formatLabels(h,f,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var m=h.hi||f.hoverinfo,v=[];if(!f.hovertemplate){var y=m.split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"c\"]),-1!==y.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==y.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==y.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=v.join(\"<br>\"),o.hovertemplate=f.hovertemplate,i}function x(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../scatter/hover\":1167}],1250:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":877,\"../scatter/marker_colorbar\":1174,\"../scatter/select\":1178,\"../scatter/style\":1180,\"./attributes\":1244,\"./calc\":1245,\"./defaults\":1246,\"./event_data\":1247,\"./format_labels\":1248,\"./hover\":1249,\"./plot\":1251}],1251:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var a=e.plotContainer;a.select(\".scatterlayer\").selectAll(\"*\").remove();var i={xaxis:e.xaxis,yaxis:e.yaxis,plot:a,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,i,r,o)}},{\"../scatter/plot\":1177}],1252:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(a(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(a(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:i(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/plot_template\":787,\"../../plots/cartesian/constants\":804,\"../../plots/template_attributes\":876,\"../scatter/attributes\":1156,\"../scattergl/attributes\":1208}],1253:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),a=t(\"../../registry\"),i=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine;function u(t,e,r){for(var n=r.matrixOptions.data.length,a=e._visibleDims,i=r.viewOpts.ranges=new Array(n),o=0;o<a.length;o++){var s=a[o],c=i[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:i},{ranges:i}):r.matrix.update({ranges:i})}function h(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,a=e._splomGrid;a||(a=e._splomGrid=n(r)),a.update(function(t){var e,r=t._fullLayout,n=r._size,a=[0,0,r.width,r.height],i={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in i?i[u].data.push(NaN,NaN,r,n,o,s):i[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:a,range:a,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._gridVals,d=f._gridVals,g=n.b+f.domain[0]*n.h,m=-f._m,v=-m*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+v+m*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+v+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in i)y.push(i[e]);return y}(t))}e.exports={name:\"splom\",attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=a.getModule(\"splom\"),n=o(t.calcdata,r)[0];i(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&h(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&h(t);for(var n=0;n<e.length;n++){var a=e[n][0].trace,i=r._splomScenes[a.uid];\"splom\"===a.type&&i&&i.matrix&&u(t,a,i)}},updateGrid:h,clean:function(t,e,r,n){var a,i={};if(n._splomScenes){for(a=0;a<t.length;a++){var o=t[a];\"splom\"===o.type&&(i[o.uid]=1)}for(a=0;a<r.length;a++){var l=r[a];if(!i[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":762,\"../../plots/cartesian\":811,\"../../plots/cartesian/axes\":798,\"../../plots/cartesian/axis_ids\":801,\"../../plots/get_data\":835,\"../../registry\":881,\"regl-line2d\":509}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,m,v,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],T=e._visibleDims=[];function k(t,r){for(var a=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),i=0;i<a.length;i++)a[i]=a[i]===h?NaN:a[i];_.push(a),w.push(\"log\"===t.type?n.simpleMap(a,t.c2l):a)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=a.getFromId(t,e._diag[r][0]),m=a.getFromId(t,e._diag[r][1]),g&&m&&g.type!==m.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(k(g,d),m&&\"category\"===m.type&&(m._categories=g._categories.slice())):k(m,d),T.push(r)}for(s(t,e),n.extendFlat(b,c(e)),v=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):i(e,x),p=0;p<T.length;p++)d=y[r=T[p]],g=a.getFromId(t,e._diag[r][0])||{},m=a.getFromId(t,e._diag[r][1])||{},o(t,e,g,m,_[p],_[p],v);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/axis_ids\":801,\"../scatter/calc\":1157,\"../scatter/colorscale_calc\":1159,\"../scattergl/constants\":1210,\"../scattergl/convert\":1211,\"./scene_update\":1261}],1255:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/array_container_defaults\"),i=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=t(\"../scattergl/helpers\").isOpenSymbol;function u(t,e){function r(r,a){return n.coerce(t,e,i.dimensions,r,a)}r(\"label\");var a=r(\"values\");a&&a.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,a){return n.coerce(t,e,i,r,a)}var p=a(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),m=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||m)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var v=c(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",v||y?1:0),function(t,e,r,n){var a,i,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(a=0;a<s;a++){var p=a?a+1:\"\";h[a]=\"x\"+p,f[a]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),m=e._diag=new Array(s);e._xaxes={},e._yaxes={};var v=[],y=[];function x(t,n,a,i){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,i.push(t),!(t in s)){var l=s[t]={};a&&(l.label=a.label||\"\",a.visible&&a.axis&&(a.axis.type&&(l.type=a.axis.type),a.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},a=0;a<s;a++){var w=o[a],T=0===a,k=a===s-1,M=T&&b||k&&_?void 0:d[a],A=T&&_||k&&b?void 0:g[a];x(M,A,w,v),x(A,M,w,y),m[a]=[M,A],e._axesDim[M]=a,e._axesDim[A]=a}for(a=0;a<v.length;a++)for(i=0;i<y.length;i++){var S=v[a]+y[i];a>i&&l||a<i&&c?r._splomSubplots[S]=1:a!==i||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":749,\"../../plots/array_container_defaults\":793,\"../parcoords/merge_length\":1127,\"../scatter/marker_defaults\":1175,\"../scatter/subtypes\":1181,\"../scattergl/helpers\":1215,\"./attributes\":1252}],1256:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/colorscale_calc\"),i=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){a(t,r),n.extendFlat(o.matrixOptions,i(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":749,\"../scatter/colorscale_calc\":1159,\"../scattergl/convert\":1211}],1257:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],a=t._visibleDims,i=0;i<a.length;i++){var o=a[i];if(t._diag[o][n]===r)return i}return!1}},{}],1258:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),a=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var i=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(i,s),p=n.getDimIndex(i,l);if(!1===f||!1===p)return[t];for(var d,g,m=o[f],v=o[p],y=h,x=0;x<m.length;x++){var b=m[x],_=v[x],w=s.c2p(b)-c,T=l.c2p(_)-u,k=Math.sqrt(w*w+T*T);k<y&&(y=g=k,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[a(t,m,v,i)]}}},{\"../scattergl/hover\":1216,\"./helpers\":1257}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(a)},{\"../../components/grid\":659,\"../../registry\":881,\"../scatter/marker_colorbar\":1174,\"./attributes\":1252,\"./base_plot\":1253,\"./calc\":1254,\"./defaults\":1255,\"./edit_style\":1256,\"./hover\":1258,\"./plot\":1260,\"./select\":1262}],1260:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),a=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../components/dragelement/helpers\").selectMode;function s(t,e){var r,s,l,c,u,h=t._fullLayout,f=h._size,p=e.trace,d=e.t,g=h._splomScenes[p.uid],m=g.matrixOptions,v=m.cdata,y=h._glcanvas.data()[0].regl,x=h.dragmode;if(0!==v.length){m.lower=p.showupperhalf,m.upper=p.showlowerhalf,m.diagonal=p.diagonal.visible;var b=p._visibleDims,_=v.length,w=g.viewOpts={};for(w.ranges=new Array(_),w.domains=new Array(_),u=0;u<b.length;u++){l=b[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=i.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=i.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}w.viewport=[f.l,f.b,f.w+f.l,f.h+f.b],!0===g.matrix&&(g.matrix=n(y));var M=h.clickmode.indexOf(\"select\")>-1,A=!0;if(o(x)||!!p.selectedpoints||M){var S=p._length;if(p.selectedpoints){g.selectBatch=p.selectedpoints;var E=p.selectedpoints,C={};for(l=0;l<E.length;l++)C[E[l]]=!0;var L=[];for(l=0;l<S;l++)C[l]||L.push(l);g.unselectBatch=L}var P=d.xpx=new Array(_),I=d.ypx=new Array(_);for(u=0;u<b.length;u++){if(l=b[u],r=i.getFromId(t,p._diag[l][0]))for(P[u]=new Array(S),c=0;c<S;c++)P[u][c]=r.c2p(v[u][c]);if(s=i.getFromId(t,p._diag[l][1]))for(I[u]=new Array(S),c=0;c<S;c++)I[u][c]=s.c2p(v[u][c])}if(g.selectBatch.length||g.unselectBatch.length){var z=a.extendFlat({},m,g.unselectedOptions,w),O=a.extendFlat({},m,g.selectedOptions,w);g.matrix.update(z,O),A=!1}}else d.xpx=d.ypx=null;if(A){var D=a.extendFlat({},m,w);g.matrix.update(D,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},{\"../../components/dragelement/helpers\":633,\"../../lib\":749,\"../../plots/cartesian/axis_ids\":801,\"regl-splom\":511}],1261:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,a=e.uid,i=r._splomScenes;i||(i=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=i[e.uid];return s||((s=i[a]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":749}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),i=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!a.hasMarkers(o)&&!a.hasText(o);if(!0!==o.visible||p)return f;var d=i.getDimIndex(o,u),g=i.getDimIndex(o,h);if(!1===d||!1===g)return f;var m=s.xpx[d],v=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([m[w],v[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var T=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},T,l.selectedOptions,l.viewOpts)):l.matrix.update(T,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":749,\"../scatter/subtypes\":1181,\"./helpers\":1257}],1263:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:a({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=i[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../mesh3d/attributes\":1097}],1264:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/calc\");function i(t){var e,r,a,i,s,l,c,u,h,f,p,d,g=t._x,m=t._y,v=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,T=-1/0,k=1/0,M=\"\";for(y&&(c=g[0],h=m[0],p=v[0]),y>1&&(u=g[y-1],f=m[y-1],d=v[y-1]),e=0;e<y;e++)x=Math.max(x,g[e]),b=Math.min(b,g[e]),_=Math.max(_,m[e]),w=Math.min(w,m[e]),T=Math.max(T,v[e]),k=Math.min(k,v[e]),i||g[e]===c||(i=!0,M+=\"x\"),s||m[e]===h||(s=!0,M+=\"y\"),l||v[e]===p||(l=!0,M+=\"z\");i||(M+=\"x\"),s||(M+=\"y\"),l||(M+=\"z\");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(h>f?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var C=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&C();var L=function(t){return\"x\"===t?g:\"y\"===t?m:v},P=function(t){return\"x\"===t?A:\"y\"===t?S:E},I=function(t){return t[y-1]<t[0]?-1:1},z=L(M[1]),O=L(M[3]),D=L(M[5]),R=P(M[1]).length,F=P(M[3]).length,B=P(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=I(L(M[1])),V=I(L(M[3])),q=I(L(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(a=0;a<R-1;a++){var H=j(e,r,a),G=j(e,r,a+1),Y=j(e,r+1,a),W=j(e+1,r,a);if(z[H]*U<z[G]*U&&O[H]*V<O[Y]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),C()),{xMin:b,yMin:w,zMin:k,xMax:x,yMax:_,zMax:T,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],a=0;a<e;a++)r[a]=+t[a];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,h=0,f=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],g=e._w[u],m=Math.sqrt(p*p+d*d+g*g);h=Math.max(h,m),f=Math.min(f,m)}for(a(t,e,{vals:[f,h],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var v=n[u];r.xMax=Math.max(r.xMax,v),r.xMin=Math.min(r.xMin,v);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=h,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:i}},{\"../../components/colorscale/calc\":623,\"../../lib\":749}],1265:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),a=n.createTubeMesh,i=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,a=t.dataScale,u=e._len,h={};function d(t,e){var n=r[e],o=a[c[e]];return i.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(h.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,\"xaxis\"),m=d(e._Ys,\"yaxis\"),v=d(e._Zs,\"zaxis\");if(h.meshgrid=[g,m,v],h.gridFill=e._gridFill,e._slen)h.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var y=m[0],x=f(g),b=f(v),_=new Array(x.length*b.length),w=0,T=0;T<x.length;T++)for(var k=0;k<b.length;k++)_[w++]=[x[T],y,b[k]];h.startingPositions=_}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var M=d(e._xbnds,\"xaxis\"),A=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(g),C=p(m),L=p(v),P=[[M[0]-E[0],A[0]-C[0],S[0]-L[0]],[M[1]+E[1],A[1]+C[1],S[1]+L[1]]],I=n(h,P),z=s(e);I.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var O=e.lightposition;return I.lightPosition=[O.x,O.y,O.z],I.ambient=e.lighting.ambient,I.diffuse=e.lighting.diffuse,I.specular=e.lighting.specular,I.roughness=e.lighting.roughness,I.fresnel=e.lighting.fresnel,I.opacity=e.opacity,e._pad=I.tubeScale*e.sizeref*2,I}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var a=e[n],i=r[c[n]];return a.l2c(t)/i}if(t.object===this.mesh){var a=t.data.position,i=t.data.velocity;return t.traceCoordinate=[n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),i=a(r,n),o=new u(t,e.uid);return o.mesh=i,o.data=e,i._trace=o,t.glplot.add(i),o}},{\"../../components/colorscale\":627,\"../../lib\":749,\"../../lib/gl_format_color\":745,\"../../plots/gl3d/zip3\":851,\"gl-streamtube3d\":323}],1266:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),i=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),a(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"./attributes\":1263}],1267:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\").calc,plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":840,\"./attributes\":1263,\"./calc\":1264,\"./convert\":1265,\"./defaults\":1266}],1268:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../pie/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:a({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),sort:l.sort,domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/domain\":825,\"../../plots/template_attributes\":876,\"../pie/attributes\":1130,\"./constants\":1271}],1269:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"sunburst\",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{\"../../plots/plots\":861}],1270:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),a=t(\"fast-isnumeric\"),i=t(\"../../lib\"),o=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,s=t(\"../pie/calc\").makePullColorFn,l=t(\"../pie/calc\").generateExtendedColors,c=t(\"../../components/colorscale\").calc,u=t(\"../../constants/numerical\").ALMOST_EQUAL,h={},f={};r.calc=function(t,e){var r,l,h,f,p,d,g=t._fullLayout,m=e.ids,v=i.isArrayOrTypedArray(m),y=e.labels,x=e.parents,b=e.values,_=i.isArrayOrTypedArray(b),w=[],T={},k={},M=function(t){return t||\"number\"==typeof t},A=function(t){return!_||a(b[t])&&b[t]>=0};v?(r=Math.min(m.length,x.length),l=function(t){return M(m[t])&&A(t)},h=function(t){return String(m[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},h=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=h(S),C=M(x[S])?String(x[S]):\"\",L={i:S,id:E,pid:C,label:M(y[S])?String(y[S]):\"\"};_&&(L.v=+b[S]),w.push(L),p=E,T[f=C]?T[f].push(p):T[f]=[p],k[p]=1}if(T[\"\"]){if(T[\"\"].length>1){for(var P=i.randstr(),I=0;I<w.length;I++)\"\"===w[I].pid&&(w[I].pid=P);w.unshift({hasMultipleRoots:!0,id:P,pid:\"\",label:\"\"})}}else{var z,O=[];for(z in T)k[z]||O.push(z);if(1!==O.length)return i.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",O.join(\", \")].join(\" \"));z=O[0],w.unshift({hasImpliedRoot:!0,id:z,pid:\"\",label:z})}try{d=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(w)}catch(t){return i.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case\"remainder\":D.sum((function(t){return t.data.v}));break;case\"total\":D.each((function(t){var r=t.data.data,n=r.v;if(t.children){var a=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=a),n<a*u)return R=!0,i.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",a].join(\" \"))}t.value=n}))}else!function t(e,r,n){var a=0,i=e.children;if(i){for(var o=i.length,s=0;s<o;s++)a+=t(i[s],r,n);n.branches&&a++}else n.leaves&&a++;e.value=e.data.data.value=a,r._values||(r._values=[]);return r._values[e.data.data.i]=a,a}(D,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!R){var F,B;e.sort&&D.sort((function(t,e){return e.value-t.value}));var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:\"marker\",cLetter:\"c\"}),B=o(e.marker)):F=s(g[\"_\"+e.type+\"colormap\"]),D.each((function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)})),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,a=r[t+\"colorway\"],i=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(a=l(a,\"treemap\"===t?f:h));var o=0;function s(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=a[o%a.length],o++):e.color=\"rgba(0,0,0,0)\")}for(var c=0;c<n.length;c++){var u=n[c][0];u.trace.type===t&&u.hierarchy&&u.hierarchy.each(s)}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc(\"sunburst\",t)}},{\"../../components/colorscale\":627,\"../../constants/numerical\":724,\"../../lib\":749,\"../pie/calc\":1132,\"d3-hierarchy\":161,\"fast-isnumeric\":241}],1271:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},{}],1272:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../../components/colorscale\"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,i){return n.coerce(t,e,a,r,i)}var h=u(\"labels\"),f=u(\"parents\");if(h&&h.length&&f&&f.length){var p=u(\"values\");p&&p.length?u(\"branchvalues\"):u(\"count\"),u(\"level\"),u(\"maxdepth\"),u(\"marker.line.width\")&&u(\"marker.line.color\",s.paper_bgcolor),u(\"marker.colors\");var d=e._hasColorscale=l(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:\"marker.\",cLetter:\"c\"}),u(\"leaf.opacity\",d?1:.7);var g=u(\"text\");u(\"texttemplate\"),e.texttemplate||u(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),u(\"hovertext\"),u(\"hovertemplate\");o(t,e,s,u,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u(\"insidetextorientation\"),u(\"sort\"),i(e,s,u),e._length=null}else e.visible=!1}},{\"../../components/colorscale\":627,\"../../lib\":749,\"../../plots/domain\":825,\"../bar/defaults\":895,\"./attributes\":1268}],1273:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../registry\"),i=t(\"../../components/fx/helpers\").appendArrayPointValue,o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/events\"),c=t(\"./helpers\"),u=t(\"../pie/helpers\").formatPieValue;function h(t,e,r){for(var n=t.data.data,a={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(a[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(a.parent=t.parentString),i(a,e,n.i),a}e.exports=function(t,e,r,i,f){var p=i[0],d=p.trace,g=p.hierarchy,m=\"sunburst\"===d.type,v=\"treemap\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1);t.on(\"mouseover\",(function(a){var i=r._fullLayout;if(!r._dragging&&!1!==i.hovermode){var l=r._fullData[d.index],y=a.data.data,x=y.i,b=c.isHierarchyRoot(a),_=c.getParent(g,a),w=c.getValue(a),T=function(t){return s.castOption(l,x,t)},k=T(\"hovertemplate\"),M=o.castHoverinfo(l,i,x),A=i.separators;if(k||M&&\"none\"!==M&&\"skip\"!==M){var S,E;m&&(S=p.cx+a.pxmid[0]*(1-a.rInscribed),E=p.cy+a.pxmid[1]*(1-a.rInscribed)),v&&(S=a._hoverX,E=a._hoverY);var C,L={},P=[],I=[],z=function(t){return-1!==P.indexOf(t)};M&&(P=\"all\"===M?l._module.attributes.hoverinfo.flags:M.split(\"+\")),L.label=y.label,z(\"label\")&&L.label&&I.push(L.label),y.hasOwnProperty(\"v\")&&(L.value=y.v,L.valueLabel=u(L.value,A),z(\"value\")&&I.push(L.valueLabel)),L.currentPath=a.currentPath=c.getPath(a.data),z(\"current path\")&&!b&&I.push(L.currentPath);var O=[],D=function(){-1===O.indexOf(C)&&(I.push(C),O.push(C))};L.percentParent=a.percentParent=w/c.getValue(_),L.parent=a.parentString=c.getPtLabel(_),z(\"percent parent\")&&(C=c.formatPercent(L.percentParent,A)+\" of \"+L.parent,D()),L.percentEntry=a.percentEntry=w/c.getValue(e),L.entry=a.entry=c.getPtLabel(e),!z(\"percent entry\")||b||a.onPathbar||(C=c.formatPercent(L.percentEntry,A)+\" of \"+L.entry,D()),L.percentRoot=a.percentRoot=w/c.getValue(g),L.root=a.root=c.getPtLabel(g),z(\"percent root\")&&!b&&(C=c.formatPercent(L.percentRoot,A)+\" of \"+L.root,D()),L.text=T(\"hovertext\")||T(\"text\"),z(\"text\")&&(C=L.text,s.isValidTextValue(C)&&I.push(C));var R={trace:l,y:E,text:I.join(\"<br>\"),name:k||z(\"name\")?l.name:void 0,color:T(\"hoverlabel.bgcolor\")||y.color,borderColor:T(\"hoverlabel.bordercolor\"),fontFamily:T(\"hoverlabel.font.family\"),fontSize:T(\"hoverlabel.font.size\"),fontColor:T(\"hoverlabel.font.color\"),nameLength:T(\"hoverlabel.namelength\"),textAlign:T(\"hoverlabel.align\"),hovertemplate:k,hovertemplateLabels:L,eventData:[h(a,l,f.eventDataKeys)]};m&&(R.x0=S-a.rInscribed*a.rpx1,R.x1=S+a.rInscribed*a.rpx1,R.idealAlign=a.pxmid[0]<0?\"left\":\"right\"),v&&(R.x=S,R.idealAlign=S<0?\"left\":\"right\"),o.loneHover(R,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r}),d._hasHoverLabel=!0}if(v){var F=t.select(\"path.surface\");f.styleOne(F,a,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:[h(a,l,f.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var a=r._fullLayout,i=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[h(s,i,f.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(a._hoverlayer.node()),d._hasHoverLabel=!1),v){var l=t.select(\"path.surface\");f.styleOne(l,s,i,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,i=r._fullData[d.index],s=m&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(g,u):c.findEntryWithLevel(g,u),v=c.getPtId(p),y={points:[h(t,i,f.eventDataKeys)],event:n.event};s||(y.nextLevel=v);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[h(t,i,f.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){a.call(\"_storeDirectGUIEdit\",i,e._tracePreGUI[i.uid],{level:i.level});var b={data:[{level:v}],traces:[d.index]},_={frame:{redraw:!1,duration:f.transitionTime},transition:{duration:f.transitionTime,easing:f.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),a.call(\"animate\",r,b,_)}}))}},{\"../../components/fx\":655,\"../../components/fx/helpers\":651,\"../../lib\":749,\"../../lib/events\":738,\"../../registry\":881,\"../pie/helpers\":1135,\"./helpers\":1274,d3:169}],1274:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../../lib/setcursor\"),o=t(\"../pie/helpers\");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter((function(t){if(r.getPtId(t)===e)return n=t.copy()})),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter((function(t){for(var a=t.children||[],i=0;i<a.length;i++){var o=a[i];if(r.getPtId(o)===e)return n=t.copy()}})),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return\"\"===s(t)},r.setSliceCursor=function(t,e,n){var a=n.isTransitioning;if(!a){var o=t.datum();a=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}i(t,a?null:\"pointer\")},r.getInsideTextFontKey=function(t,e,r,a,i){var o=(i||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||a.size},r.getOutsideTextFontKey=function(t,e,r,a){var i=r.data.data.i;return n.castOption(e,i,\"outsidetextfont.\"+t)||n.castOption(e,i,\"textfont.\"+t)||a.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,i,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey(\"color\",t,e,n),family:r.getOutsideTextFontKey(\"family\",t,e,n),size:r.getOutsideTextFontKey(\"size\",t,e,n)}}(t,e,i):function(t,e,i,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||a.contrast(l.color),family:r.getInsideTextFontKey(\"family\",t,e,i,o),size:r.getInsideTextFontKey(\"size\",t,e,i,o)}}(t,e,i,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var a=e?[n.data[e]]:[n];return r.listPath(n,e).concat(a)},r.getPath=function(t){return r.listPath(t,\"label\").join(\"/\")+\"/\"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},{\"../../components/color\":615,\"../../lib\":749,\"../../lib/setcursor\":769,\"../pie/helpers\":1135}],1275:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1174,\"./attributes\":1268,\"./base_plot\":1269,\"./calc\":1270,\"./defaults\":1272,\"./layout_attributes\":1276,\"./layout_defaults\":1277,\"./plot\":1278,\"./style\":1279}],1276:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1277:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":749,\"./layout_attributes\":1276}],1278:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"d3-hierarchy\"),i=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,h=t(\"../pie/plot\"),f=h.computeTransform,p=h.transformInsideText,d=t(\"./style\").styleOne,g=t(\"../bar/style\").resizeText,m=t(\"./fx\"),v=t(\"./constants\"),y=t(\"./helpers\");function x(t,e,l,u){var h=t._fullLayout,g=!h.uniformtext.mode&&y.hasTransition(u),x=n.select(l).selectAll(\"g.slice\"),_=e[0],w=_.trace,T=_.hierarchy,k=y.findEntryWithLevel(T,w.level),M=y.getMaxDepth(w),A=h._size,S=w.domain,E=A.w*(S.x[1]-S.x[0]),C=A.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=_.cx=A.l+A.w*(S.x[1]+S.x[0])/2,I=_.cy=A.t+A.h*(1-S.y[0])-C/2;if(!k)return x.remove();var z=null,O={};g&&x.each((function(t){O[y.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&y.isEntry(t)&&(z=t)}));var D=function(t){return a.partition().size([2*Math.PI,t.height+1])(t)}(k).descendants(),R=k.height+1,F=0,B=M;_.hasMultipleRoots&&y.isHierarchyRoot(k)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter((function(t){return t.y1<=B}));var N=Math.min(R,M),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,I)},q=function(t){return P+b(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},H=function(t){return I+b(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(x=x.data(D,y.getPtId)).enter().append(\"g\").classed(\"slice\",!0),g?x.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=y.getPtId(t),a=O[r],i=O[y.getPtId(k)];if(i){var o=t.x1>i.x1?2*Math.PI:0;e=t.rpx1<i.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=y.getPtId(t.parent);x.each((function(t){if(y.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(y.getPtId(t)===r)return c=e}));var h=u.length,f=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:f(c/h),x1:f((c+1)/h)}}return n.interpolate(a,e)}(t);return function(t){return V(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():x.exit().remove(),x.order();var G=null;if(g&&z){var Y=y.getPtId(z);x.each((function(t){null===G&&y.getPtId(t)===Y&&(G=t.x1)}))}var W=x;function Z(t){var e=t.parent,r=O[y.getPtId(e)],a={};if(r){var i=e.children,o=i.indexOf(t),s=i.length,l=n.interpolate(r.x0,r.x1);a.x0=l(o/s),a.x1=l(o/s)}else a.x0=a.x1=0;return a}g&&(W=W.transition().each(\"end\",(function(){var e=n.select(this);y.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),W.each((function(a){var l=n.select(this),u=o.ensureSingle(l,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));a.rpx0=j(a.y0),a.rpx1=j(a.y1),a.xmid=(a.x0+a.x1)/2,a.pxmid=U(a.rpx1,a.xmid),a.midangle=-(a.xmid-Math.PI/2),a.startangle=-(a.x0-Math.PI/2),a.stopangle=-(a.x1-Math.PI/2),a.halfangle=.5*Math.min(o.angleDelta(a.x0,a.x1)||Math.PI,Math.PI),a.ring=1-a.rpx0/a.rpx1,a.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(a),g?u.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=O[y.getPtId(t)],a={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var i=t.x1>G?2*Math.PI:0;e={x0:i,x1:i}}else e={rpx0:L,rpx1:L},o.extendFlat(e,Z(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,a)}(t);return function(t){return V(e(t))}})):u.attr(\"d\",V),l.call(m,k,t,e,{eventDataKeys:v.eventDataKeys,transitionTime:v.CLICK_TRANSITION_TIME,transitionEasing:v.CLICK_TRANSITION_EASING}).call(y.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(d,a,w);var x=o.ensureSingle(l,\"g\",\"slicetext\"),b=o.ensureSingle(x,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),T=o.ensureUniformFontSize(t,y.determineTextFont(w,a,h.font));b.text(r.formatSliceLabel(a,k,w,e,h)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(i.font,T).call(s.convertToTspans,t);var M=i.bBox(b.node());a.transform=p(M,a,_),a.transform.targetX=q(a),a.transform.targetY=H(a);var A=function(t,e){var r=t.transform;return f(r,e),r.fontSize=T.size,c(w.type,r,h),o.getTextTransform(r)};g?b.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=O[y.getPtId(t)],a=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:a.textPosAngle,scale:0,rotate:a.rotate,rCenter:a.rCenter,x:a.x,y:a.y}},z)if(t.parent)if(G){var i=t.x1>G?2*Math.PI:0;e.x0=e.x1=i}else o.extendFlat(e,Z(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),f=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,a.scale),d=n.interpolate(e.transform.rotate,a.rotate),g=0===a.rCenter?3:0===e.transform.rCenter?1/3:1,m=n.interpolate(e.transform.rCenter,a.rCenter);return function(t){var e=l(t),r=u(t),n=f(t),i=function(t){return m(Math.pow(t,g))}(t),o={pxmid:U(e,(r+n)/2),rpx1:e,transform:{textPosAngle:s(t),rCenter:i,x:a.x,y:a.y}};return c(w.type,a,h),{transform:{targetX:q(o),targetY:H(o),scale:p(t),rotate:d(t),rCenter:i}}}}(t);return function(t){return A(e(t),M)}})):b.attr(\"transform\",A(a,M))}))}function b(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,a){var i,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,h=!s.uniformtext.mode&&y.hasTransition(r);(u(\"sunburst\",s),(i=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),i.order(),h)?(a&&(o=a()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){x(t,e,this,r)}))}))):(i.each((function(e){x(t,e,this,r)})),s.uniformtext.mode&&g(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\"));c&&i.exit().remove()},r.formatSliceLabel=function(t,e,r,n,a){var i=r.texttemplate,s=r.textinfo;if(!(i||s&&\"none\"!==s))return\"\";var l=a.separators,c=n[0],u=t.data.data,h=c.hierarchy,f=y.isHierarchyRoot(t),p=y.getParent(h,t),d=y.getValue(t);if(!i){var g,m=s.split(\"+\"),v=function(t){return-1!==m.indexOf(t)},x=[];if(v(\"label\")&&u.label&&x.push(u.label),u.hasOwnProperty(\"v\")&&v(\"value\")&&x.push(y.formatValue(u.v,l)),!f){v(\"current path\")&&x.push(y.getPath(t.data));var b=0;v(\"percent parent\")&&b++,v(\"percent entry\")&&b++,v(\"percent root\")&&b++;var _=b>1;if(b){var w,T=function(t){g=y.formatPercent(w,l),_&&(g+=\" of \"+t),x.push(g)};v(\"percent parent\")&&!f&&(w=d/y.getValue(p),T(\"parent\")),v(\"percent entry\")&&(w=d/y.getValue(e),T(\"entry\")),v(\"percent root\")&&(w=d/y.getValue(h),T(\"root\"))}}return v(\"text\")&&(g=o.castOption(r,u.i,\"text\"),o.isValidTextValue(g)&&x.push(g)),x.join(\"<br>\")}var k=o.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var M={};u.label&&(M.label=u.label),u.hasOwnProperty(\"v\")&&(M.value=u.v,M.valueLabel=y.formatValue(u.v,l)),M.currentPath=y.getPath(t.data),f||(M.percentParent=d/y.getValue(p),M.percentParentLabel=y.formatPercent(M.percentParent,l),M.parent=y.getPtLabel(p)),M.percentEntry=d/y.getValue(e),M.percentEntryLabel=y.formatPercent(M.percentEntry,l),M.entry=y.getPtLabel(e),M.percentRoot=d/y.getValue(h),M.percentRootLabel=y.formatPercent(M.percentRoot,l),M.root=y.getPtLabel(h),u.hasOwnProperty(\"color\")&&(M.color=u.color);var A=o.castOption(r,u.i,\"text\");return(o.isValidTextValue(A)||\"\"===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,\"customdata\"),o.texttemplateString(k,M,a._d3locale,M,r._meta||{})}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../bar/style\":905,\"../bar/uniform_text\":907,\"../pie/plot\":1139,\"./constants\":1271,\"./fx\":1273,\"./helpers\":1274,\"./style\":1279,d3:169,\"d3-hierarchy\":161}],1279:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/color\"),i=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=i.castOption(r,s,\"marker.line.color\")||a.defaultLine,c=i.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(a.fill,n.color).call(a.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":615,\"../../lib\":749,\"../bar/uniform_text\":907,d3:169}],1280:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),a=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},a(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:s({},a.zauto,{}),zmin:s({},a.zmin,{}),zmax:s({},a.zmax,{})},hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":615,\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876}],1281:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":623}],1282:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),a=t(\"ndarray\"),i=t(\"ndarray-linear-interpolate\").d2,o=t(\"../heatmap/interp2d\"),s=t(\"../heatmap/find_empties\"),l=t(\"../../lib\").isArrayOrTypedArray,c=t(\"../../lib/gl_format_color\").parseColorScale,u=t(\"../../lib/str2rgbarray\"),h=t(\"../../components/colorscale\").extractOpts;function f(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=f.prototype;p.getXat=function(t,e,r,n){var a=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?a:n.d2l(a,0,r)},p.getYat=function(t,e,r,n){var a=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?a:n.d2l(a,0,r)},p.getZat=function(t,e,r,n){var a=this.data.z[e][t];return null===a&&this.data.connectgaps&&this.data._interpolatedZ&&(a=this.data._interpolatedZ[e][t]),void 0===r?a:n.d2l(a,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),a=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,a],t.traceCoordinate=[this.getXat(n,a),this.getYat(n,a),this.getZat(n,a)],t.dataCoordinate=[this.getXat(n,a,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,a,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,a,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var i=0;i<3;i++){var o=t.dataCoordinate[i];null!=o&&(t.dataCoordinate[i]*=this.scene.dataScale[i])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[a]&&void 0!==s[a][n]?t.textLabel=s[a][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function g(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(g(t,n))}return e}function v(t){for(var e=m(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function y(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),a=1,i=0;i<d.length;i++)a*=Math.pow(d[i],Math.max(r[i],n[i]));return a}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),a=this.getXat(e,0);r[e-1]=a!==n&&null!=n&&null!=a?Math.abs(a-n):0}var i=0;for(e=1;e<t;e++)i+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(i/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),a=this.getYat(0,e);r[e-1]=a!==n&&null!=n&&null!=a?Math.abs(a-n):0}var i=0;for(e=1;e<t;e++)i+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(i/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],b=x[9],_=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var a=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(a,[l,c],n),t.set(l,c,i(e,a[0],a[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=y(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<b;)r*=2;for(;r>_;)r--,r/=v(r),++r<b&&(r=_);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],i=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+i+1,u=a(new Float32Array(l*c),[l,c]),h=[1/e,0,0,0,1/r,0,0,0,1],f=0;f<t.length;++f){this.surface.padField(u,t[f]);var p=a(new Float32Array(o*s),[o,s]);T(p,u,h),t[f]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],a=[!1,!1,!1],i=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(i=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(a[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(i){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=a[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,i,l=this.scene,f=l.fullSceneLayout,p=this.surface,d=c(t),g=l.dataScale,m=t.z[0].length,v=t._ylength,y=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<m;r++)x[e][r]=[];for(r=0;r<m;r++)for(n=0;n<v;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,f.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,f.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,f.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<m;r++)for(t._interpolatedZ[r]=[],n=0;n<v;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null==(i=x[e][r][n])?x[e][r][n]=NaN:i=x[e][r][n]*=g[e];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(i=x[e][r][n])&&(this.minValues[e]>i&&(this.minValues[e]=i),this.maxValues[e]<i&&(this.maxValues[e]=i));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(i=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var b=[a(new Float32Array(m*v),[m,v]),a(new Float32Array(m*v),[m,v]),a(new Float32Array(m*v),[m,v])];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)b[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=h(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=a(new Float32Array(m*v),[m,v]);for(r=0;r<m;r++)for(n=0;n<v;n++)k.set(r,n,t.surfacecolor[n][r]);b.push(k)}else w.intensityBounds[0]*=g[2],w.intensityBounds[1]*=g[2];(_<b[0].shape[0]||_<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(w.intensity=b.pop());var M=[!0,!0,!0],A=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[A[e]];M[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=y[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=b,p.update(w),p.visible=t.visible,p.enableDynamic=M,p.enableHighlight=M,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new f(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{\"../../components/colorscale\":627,\"../../lib\":749,\"../../lib/gl_format_color\":745,\"../../lib/str2rgbarray\":772,\"../heatmap/find_empties\":1041,\"../heatmap/interp2d\":1044,\"gl-surface3d\":325,ndarray:469,\"ndarray-linear-interpolate\":463}],1283:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),a=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=n(\"opacityscale\");\"max\"===a?e.opacityscale=[[0,.1],[1,1]]:\"min\"===a?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===a?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var a=n/31,i=e+(1-e)*(1-Math.pow(Math.sin(t*a*Math.PI),2));r.push([a,Math.max(0,Math.min(1,i))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(a)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,c){var u,h;function f(r,n){return a.coerce(t,e,o,r,n)}var p=f(\"x\"),d=f(\"y\"),g=f(\"z\");if(!g||!g.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&a.isArrayOrTypedArray(p[0])?g.length:g[0].length,e._ylength=g.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){f(t)}));var m=f(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var y=\"contours.\"+v[u],x=f(y+\".show\"),b=f(y+\".highlight\");if(x||b)for(h=0;h<3;++h)f(y+\".project.\"+v[h]);x&&(f(y+\".color\"),f(y+\".width\"),f(y+\".usecolormap\")),b&&(f(y+\".highlightcolor\"),f(y+\".highlightwidth\")),f(y+\".start\"),f(y+\".end\"),f(y+\".size\")}m||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),i(t,e,c,f,{prefix:\"\",cLetter:\"c\"}),s(t,e,c,f),e._length=null}},opacityscaleDefaults:s}},{\"../../components/colorscale/defaults\":625,\"../../lib\":749,\"../../registry\":881,\"./attributes\":1280}],1284:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":840,\"./attributes\":1280,\"./calc\":1281,\"./convert\":1282,\"./defaults\":1283}],1285:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),a=t(\"../../lib/extend\").extendFlat,i=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=i({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:a({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:a({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:a({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:a({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":598,\"../../constants/docs\":719,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/domain\":825,\"../../plots/font_attributes\":826}],1286:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var a=n._has&&n._has(\"table\"),i=e._has&&e._has(\"table\");a&&!i&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":835,\"./plot\":1293}],1287:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":746}],1288:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1289:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"../../lib/extend\").extendFlat,i=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,a=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),a=Math.max(a,r[e].length);if(n!==a)for(e=0;e<r.length;e++){var i=a-r[e].length;i&&(r[e]=r[e].concat(c(i)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function h(t,e){return Object.keys(t).map((function(r){return a({},t[r],{auxiliaryBlocks:e})}))}function f(t,e){for(var r,n={},a=0,i=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((i+=r)>=e||c===t.length-1)&&(n[a]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},a+=i,s=c+1,i=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map((function(){return c((d[0]||[\"\"]).length)}))),m=e.domain,v=Math.floor(t._fullLayout._size.w*(m.x[1]-m.x[0])),y=Math.floor(t._fullLayout._size.h*(m.y[1]-m.y[0])),x=e.header.values.length?g[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),T=h(f(x,_),[]),k=h(w,T),M={},A=e._fullInput.columnorder.concat(p(r.map((function(t,e){return e})))),S=g.map((function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return i(n)?Number(n):1})),E=S.reduce(s,0);S=S.map((function(t){return t/E*v}));var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:m.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-m.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:C,height:y,columnOrder:A,groupHeight:y,rowBlocks:k,headerRowBlocks:T,scrollY:0,cells:a({},e.cells,{values:r}),headerCells:a({},e.header,{values:g}),gdColumns:g.map((function(t){return t[0]})),gdColumnsOriginalOrder:g.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}}))};return L.columns.forEach((function(t){t.calcdata=L,t.x=u(t)})),L}},{\"../../lib/extend\":739,\"./constants\":1288,\"fast-isnumeric\":241}],1290:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},{\"../../lib/extend\":739}],1291:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}i(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,a=r.slice(0,n),i=a.slice().sort((function(t,e){return t-e})),o=a.map((function(t){return i.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":749,\"../../plots/domain\":825,\"./attributes\":1285}],1292:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1285,\"./base_plot\":1286,\"./calc\":1287,\"./defaults\":1291,\"./plot\":1293}],1293:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),a=t(\"d3\"),i=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function m(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function v(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(i.repeat,i.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?O(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-M(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+M(t)+\")\"}));var s=o.selectAll(\".\"+n.cn.scrollbar).data(i.repeat,i.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(i.repeat,i.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"}));var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(i.repeat,i.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(i.repeat,i.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=a.event.y,i=this.getBoundingClientRect(),o=r.scrollbarState,s=n-i.top,l=a.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)})).call(a.behavior.drag().origin((function(t){return a.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",S(e,t)).on(\"dragend\",(function(){}))),u.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(i.repeat,i.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,a={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=a}))}(l),function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=a.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(i.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(i.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){a.event.stopPropagation()})),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(i.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each((function(t){o.font(a.select(this),t.font)}))}(c),x(c,e,s,t),I(l)}function x(t,e,r,i){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,i=t.value,o=\"string\"==typeof i,s=o&&i.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&i.match(/[<&>]/);var c,u=\"string\"==typeof(c=i)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,m=p+(g?a.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(m)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(m):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var v=(\" \"===n.wrapSplitCharacter?m.replace(/<a href=/gi,\"<a_href=\"):m).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?v.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):v;t.fragments=y.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=m;return f})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=a.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,i,l(r,this,e,i,t)):a.select(this.parentNode).attr(\"transform\",(function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function T(t){return\"cells\"===t.type}function k(t){return\"header\"===t.type}function M(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+O(e,1/0)}),0)}function A(t,e,r){var n=m(e)[0];if(void 0!==n){var a=n.rowBlocks,i=n.calcdata,o=z(a,a.length),s=n.calcdata.groupHeight-M(n),l=i.scrollY=Math.max(0,Math.min(o-s,i.scrollY)),c=function(t,e,r){for(var n=[],a=0,i=0;i<t.length;i++){for(var o=t[i],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l;e<a+l&&e+r>a&&n.push(i),a+=l}return n}(a,l,s);1===c.length&&(c[0]===a.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each((function(t,e){t.page=c[e],t.scrollY=l})),e.attr(\"transform\",(function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"})),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),v(r,t))}}function S(t,e,r,i){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===i?s.scrollY+c*a.event.dy:i;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(T);return A(t,h,l),s.scrollY===u}}function E(t,e,r,n,a,i,o){n[o]!==a[o]&&(clearTimeout(i.currentRepaint[o]),i.currentRepaint[o]=setTimeout((function(){var i=r.filter((function(t,e){return e===o&&n[e]!==a[e]}));y(t,e,i,r),a[o]=n[o]})))}function C(t,e,r,i){return function(){var o=a.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,a,i=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(a=(r=s.shift()).width+i)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=a;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,i),a.select(e.parentNode.parentNode).call(I)}}function L(t,e,r,i,o){return function(){if(!o.settledY){var s=a.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(I),A(null,t.filter(T),0),v(r,i,!0)),s.attr(\"transform\",(function(){var t=this.parentNode.getBoundingClientRect(),e=a.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),i=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,a.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+i+\")\"})),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function I(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+O(e,1/0)}),0);return\"translate(0 \"+(O(R(t),t.key)+e)+\")\"})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function O(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=i.unwrap(e).trace;return u(t,r)})),i.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"}));var f=s.selectAll(\".\"+n.cn.tableControlView).data(i.repeat,i.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var b=\"onwheel\"in document?\"wheel\":\"mousewheel\";x.on(\"mousemove\",(function(e){f.filter((function(t){return e===t})).call(v,t)})).on(b,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+a.event.deltaY;S(t,f,null,r)(e)||(a.event.stopPropagation(),a.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(v,t,!0)}f.attr(\"transform\",(function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"}));var _=f.selectAll(\".\"+n.cn.scrollBackground).data(i.repeat,i.keyFun);_.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),_.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),f.each((function(e){o.setClipUrl(a.select(this),d(t,e),t)}));var M=f.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),i.keyFun);M.enter().append(\"g\").classed(n.cn.yColumn,!0),M.exit().remove(),M.attr(\"transform\",(function(t){return\"translate(\"+t.x+\" 0)\"})),r&&M.call(a.behavior.drag().origin((function(e){return w(a.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,v(f.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=a.select(this),r=function(e){return(t===e?a.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,a.event.x)),m(M).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),M.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return\"translate(\"+t.x+\" 0)\"})),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")})).on(\"dragend\",(function(e){var r=a.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),M.each((function(e){o.setClipUrl(a.select(this),g(t,e),t)}));var E=M.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,i.keyFun);E.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),E.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var C=E.filter(k),L=E.filter(T);r&&L.call(a.behavior.drag().origin((function(t){return a.event.stopPropagation(),t})).on(\"drag\",S(t,f,-1)).on(\"dragend\",(function(){}))),y(t,f,C,E),y(t,f,L,E);var P=f.selectAll(\".\"+n.cn.scrollAreaClip).data(i.repeat,i.keyFun);P.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return d(t,e)}));var I=P.selectAll(\".\"+n.cn.scrollAreaClipRect).data(i.repeat,i.keyFun);I.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),I.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),M.selectAll(\".\"+n.cn.columnBoundary).data(i.repeat,i.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var z=M.selectAll(\".\"+n.cn.columnBoundaryClippath).data(i.repeat,i.keyFun);z.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),z.attr(\"id\",(function(e){return g(t,e)}));var O=z.selectAll(\".\"+n.cn.columnBoundaryRect).data(i.repeat,i.keyFun);O.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),O.attr(\"width\",(function(t){return t.columnWidth+2*p(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*p(t)+n.uplift})).attr(\"x\",(function(t){return-p(t)})).attr(\"y\",(function(t){return-p(t)})),A(null,L,f)}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/gup\":746,\"../../lib/svg_text_utils\":773,\"./constants\":1288,\"./data_preparation_helper\":1289,\"./data_split_helpers\":1290,d3:169}],1294:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,editType:\"calc\"},i(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plots/domain\":825,\"../../plots/template_attributes\":876,\"../pie/attributes\":1130,\"../sunburst/attributes\":1268,\"./constants\":1297}],1295:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"treemap\",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{\"../../plots/plots\":861}],1296:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},{\"../sunburst/calc\":1270}],1297:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},{}],1298:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,h=c.handleDefaults;e.exports=function(t,e,r,c){function f(r,i){return n.coerce(t,e,a,r,i)}var p=f(\"labels\"),d=f(\"parents\");if(p&&p.length&&d&&d.length){var g=f(\"values\");g&&g.length?f(\"branchvalues\"):f(\"count\"),f(\"level\"),f(\"maxdepth\"),\"squarify\"===f(\"tiling.packing\")&&f(\"tiling.squarifyratio\"),f(\"tiling.flip\"),f(\"tiling.pad\");var m=f(\"text\");f(\"texttemplate\"),e.texttemplate||f(\"textinfo\",Array.isArray(m)?\"text+label\":\"label\"),f(\"hovertext\"),f(\"hovertemplate\");var v=f(\"pathbar.visible\");s(t,e,c,f,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),f(\"textposition\");var y=-1!==e.textposition.indexOf(\"bottom\");f(\"marker.line.width\")&&f(\"marker.line.color\",c.paper_bgcolor);var x=f(\"marker.colors\"),b=e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;b?h(t,e,c,f,{prefix:\"marker.\",cLetter:\"c\"}):f(\"marker.depthfade\",!(x||[]).length);var _=2*e.textfont.size;f(\"marker.pad.t\",y?_/4:_),f(\"marker.pad.l\",_/4),f(\"marker.pad.r\",_/4),f(\"marker.pad.b\",y?_:_/4),b&&h(t,e,c,f,{prefix:\"marker.\",cLetter:\"c\"}),e._hovered={marker:{line:{width:2,color:i.contrast(c.paper_bgcolor)}}},v&&(f(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),f(\"pathbar.side\"),f(\"pathbar.edgeshape\")),f(\"sort\"),o(e,c,f),e._length=null}else e.visible=!1}},{\"../../components/color\":615,\"../../components/colorscale\":627,\"../../lib\":749,\"../../plots/domain\":825,\"../bar/constants\":893,\"../bar/defaults\":895,\"./attributes\":1294}],1299:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),h=t(\"../sunburst/fx\");e.exports=function(t,e,r,f,p){var d=p.barDifY,g=p.width,m=p.height,v=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,T=p.handleSlicesExit,k=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],C=E.trace,L=E.hierarchy,P=g/C._entryDepth,I=u.listPath(r.data,\"id\"),z=s(L.copy(),[g,m],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter((function(t){var e=I.indexOf(t.data.id);return-1!==e&&(t.x0=P*e,t.x1=P*(e+1),t.y0=d,t.y1=d+m,t.onPathbar=!0,!0)}))).reverse(),(f=f.data(z,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),T(f,!0,A,[g,m],x),f.order();var O=f;w&&(O=O.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),O.each((function(s){s._hoverX=v(s.x1-Math.min(g,m)/2),s._hoverY=y(s.y1-m/2);var f=n.select(this),p=a.ensureSingle(f,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?p.transition().attrTween(\"d\",(function(t){var e=k(t,!0,A,[g,m]);return function(t){return x(e(t))}})):p.attr(\"d\",x),f.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,C,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var d=a.ensureSingle(f,\"g\",\"slicetext\"),T=a.ensureSingle(d,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),E=a.ensureUniformFontSize(t,u.determineTextFont(C,s,S.font,{onPathbar:!0}));T.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(i.font,E).call(o.convertToTspans,t),s.textBB=i.bBox(T.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?T.transition().attrTween(\"transform\",(function(t){var e=M(t,!0,A,[g,m]);return function(t){return _(e(t))}})):T.attr(\"transform\",_(s))}))}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../sunburst/fx\":1273,\"../sunburst/helpers\":1274,\"./constants\":1297,\"./partition\":1304,\"./style\":1306,d3:169}],1300:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),h=t(\"../sunburst/fx\"),f=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,m=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,C=-1!==E.textposition.indexOf(\"left\"),L=-1!==E.textposition.indexOf(\"right\"),P=-1!==E.textposition.indexOf(\"bottom\"),I=!P&&!E.marker.pad.t||P&&!E.marker.pad.b,z=s(r,[g,m],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),O=1/0,D=-1/0;z.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(O=Math.min(O,e),D=Math.max(D,e))})),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-O+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[g,m],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each((function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var B=function(){return R||{x0:0,x1:g,y0:0,y1:m}},N=p;return w&&(N=N.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),N.each((function(s){var p=u.isHeader(s,E);s._hoverX=v(s.x1-E.marker.pad.r),s._hoverY=y(P?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),T=a.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?T.transition().attrTween(\"d\",(function(t){var e=k(t,!1,B(),[g,m]);return function(t){return x(e(t))}})):T.attr(\"d\",x),d.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),T.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=p?I?\"\":u.getPtLabel(s)||\"\":f(s,r,E,e,S)||\"\";var A=a.ensureSingle(d,\"g\",\"slicetext\"),z=a.ensureSingle(A,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),O=a.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));z.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",L?\"end\":C||p?\"start\":\"middle\").call(i.font,O).call(o.convertToTspans,t),s.textBB=i.bBox(z.node()),s.transform=b(s,{fontSize:O.size,isHeader:p}),s.transform.fontSize=O.size,w?z.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,B(),[g,m]);return function(t){return _(e(t))}})):z.attr(\"transform\",_(s))})),R}},{\"../../components/drawing\":637,\"../../lib\":749,\"../../lib/svg_text_utils\":773,\"../sunburst/fx\":1273,\"../sunburst/helpers\":1274,\"../sunburst/plot\":1278,\"./constants\":1297,\"./partition\":1304,\"./style\":1306,d3:169}],1301:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1174,\"./attributes\":1294,\"./base_plot\":1295,\"./calc\":1296,\"./defaults\":1298,\"./layout_attributes\":1302,\"./layout_defaults\":1303,\"./plot\":1305,\"./style\":1306}],1302:[function(t,e,r){\"use strict\";e.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1303:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},{\"../../lib\":749,\"./layout_attributes\":1302}],1304:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\");e.exports=function(t,e,r){var a,i=r.flipX,o=r.flipY,s=\"dice-slice\"===r.packing,l=r.pad[o?\"bottom\":\"top\"],c=r.pad[i?\"right\":\"left\"],u=r.pad[i?\"left\":\"right\"],h=r.pad[o?\"top\":\"bottom\"];s&&(a=c,c=l,l=a,a=u,u=h,h=a);var f=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(h).size(s?[e[1],e[0]]:e)(t);return(s||i||o)&&function t(e,r,n){var a;n.swapXY&&(a=e.x0,e.x0=e.y0,e.y0=a,a=e.x1,e.x1=e.y1,e.y1=a);n.flipX&&(a=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-a);n.flipY&&(a=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-a);var i=e.children;if(i)for(var o=0;o<i.length;o++)t(i[o],r,n)}(f,e,{swapXY:s,flipX:i,flipY:o}),f}},{\"d3-hierarchy\":161}],1305:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../sunburst/helpers\"),i=t(\"../../lib\"),o=t(\"../bar/constants\").TEXTPAD,s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,h=t(\"../bar/style\").resizeText,f=t(\"./constants\"),p=t(\"./draw_descendants\"),d=t(\"./draw_ancestors\");function g(t){return a.isHierarchyRoot(t)?\"\":a.getPtId(t)}function m(t,e,r,l){var u=t._fullLayout,h=e[0],m=h.trace,v=h.hierarchy,y=a.findEntryWithLevel(v,m.level),x=n.select(r),b=x.selectAll(\"g.pathbar\"),_=x.selectAll(\"g.slice\");if(!y)return b.remove(),void _.remove();var w=a.isHierarchyRoot(y),T=!u.uniformtext.mode&&a.hasTransition(l),k=a.getMaxDepth(m),M=u._size,A=m.domain,S=M.w*(A.x[1]-A.x[0]),E=M.h*(A.y[1]-A.y[0]),C=S,L=m.pathbar.thickness,P=m.marker.line.width+f.gapWithPathbar,I=m.pathbar.visible?m.pathbar.side.indexOf(\"bottom\")>-1?E+P:-(L+P):0,z={x0:C,x1:C,y0:I,y1:I+L},O=function(t,e,r){var n=m.tiling.pad,a=function(t){return t-n<=e.x0},i=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:a(t.x0-n)?0:i(t.x0-n)?r[0]:t.x0,x1:a(t.x1+n)?0:i(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},D=null,R={},F={},B=null,N=function(t,e){return e?R[g(t)]:F[g(t)]},j=function(t,e,r,n){if(e)return R[g(v)]||z;var a=F[m.level]||r;return function(t){return t.data.depth-y.data.depth<k}(t)?O(t,a,n):{}};h.hasMultipleRoots&&w&&k++,m._maxDepth=k,m._backgroundColor=u.paper_bgcolor,m._entryDepth=y.data.depth,m._atRootLevel=w;var U=-S/2+M.l+M.w*(A.x[1]+A.x[0])/2,V=-E/2+M.t+M.h*(1-(A.y[1]+A.y[0])/2),q=function(t){return U+t},H=function(t){return V+t},G=H(0),Y=q(0),W=function(t){return Y+t},Z=function(t){return G+t};function X(t,e){return t+\",\"+e}var J=W(0),K=function(t){t.x=Math.max(J,t.x)},Q=m.pathbar.edgeshape,$=function(t,e){var r=t.x0,n=t.x1,a=t.y0,i=t.y1,l=t.textBB,h=function(t){return-1!==m.textposition.indexOf(t)},f=h(\"bottom\"),p=h(\"top\")||e.isHeader&&!f?\"start\":f?\"end\":\"middle\",d=h(\"right\"),g=h(\"left\")||e.onPathbar?-1:d?1:0,v=m.marker.pad;if(e.isHeader){if((r+=v.l-o)>=(n-=v.r-o)){var y=(r+n)/2;r=y,n=y}var x;f?a<(x=i-v.b)&&x<i&&(a=x):a<(x=a+v.t)&&x<i&&(i=x)}var b=s(r,n,a,i,l,{isHorizontal:!1,constrained:!0,angle:0,anchor:p,leftToRight:g});return b.fontSize=e.fontSize,b.targetX=q(b.targetX),b.targetY=H(b.targetY),isNaN(b.targetX)||isNaN(b.targetY)?{}:(r!==n&&a!==i&&c(m.type,b,u),{scale:b.scale,rotate:b.rotate,textX:b.textX,textY:b.textY,anchorX:b.anchorX,anchorY:b.anchorY,targetX:b.targetX,targetY:b.targetY})},tt=function(t,e){for(var r,n=0,a=t;!r&&n<k;)n++,(a=a.parent)?r=N(a,e):n=k;return r||{}},et=function(t,e,r,a){var o,s=N(t,e);if(s)o=s;else if(e)o=z;else if(D)if(t.parent){var l=B||r;l&&!e?o=O(t,l,a):(o={},i.extendFlat(o,tt(t,e)))}else o=t;else o={};return n.interpolate(o,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},rt=function(t,e,r,o){var s=N(t,e),l={},h=j(t,e,r,o);i.extendFlat(l,{transform:$({x0:h.x0,x1:h.x1,y0:h.y0,y1:h.y1,textBB:t.textBB,_text:t._text},{isHeader:a.isHeader(t,m)})}),s?l=s:t.parent&&i.extendFlat(l,tt(t,e));var f=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,f,u),n.interpolate(l,{transform:{scale:f.scale,rotate:f.rotate,textX:f.textX,textY:f.textY,anchorX:f.anchorX,anchorY:f.anchorY,targetX:f.targetX,targetY:f.targetY}})},nt=function(t,e,r,a,i){var o=a[0],s=a[1];T?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,a){var i,o=N(t,e);if(e)i=z;else{var s=N(y,e);i=s?O(t,s,a):{}}return n.interpolate(o,i)}(t,e,0,[o,s]);return function(t){return i(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},at=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,e,u),i.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};T&&(b.each((function(t){R[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),_.each((function(t){F[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!D&&a.isEntry(t)&&(D=t)}))),B=p(t,e,y,_,{width:S,height:E,viewX:q,viewY:H,pathSlice:function(t){var e=q(t.x0),r=q(t.x1),n=H(t.y0),a=H(t.y1),i=r-e,o=a-n;if(!i||!o)return\"\";return\"M\"+X(e,n+0)+\"L\"+X(r-0,n)+\"L\"+X(r,a-0)+\"L\"+X(e+0,a)+\"Z\"},toMoveInsideSlice:$,prevEntry:D,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:at}),m.pathbar.visible?d(t,e,y,b,{barDifY:I,width:C,height:L,viewX:W,viewY:Z,pathSlice:function(t){var e=W(Math.max(Math.min(t.x0,t.x0),0)),r=W(Math.min(Math.max(t.x1,t.x1),C)),n=Z(t.y0),a=Z(t.y1),i=L/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+a)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:a},h={x:e,y:a};return\">\"===Q?(l.x-=i,c.x-=i,u.x-=i,h.x-=i):\"/\"===Q?(u.x-=i,h.x-=i,o.x-=i/2,s.x-=i/2):\"\\\\\"===Q?(l.x-=i,c.x-=i,o.x-=i/2,s.x-=i/2):\"<\"===Q&&(o.x-=i,s.x-=i),K(l),K(h),K(o),K(c),K(u),K(s),\"M\"+X(l.x,l.y)+\"L\"+X(c.x,c.y)+\"L\"+X(s.x,s.y)+\"L\"+X(u.x,u.y)+\"L\"+X(h.x,h.y)+\"L\"+X(o.x,o.y)+\"Z\"},toMoveInsideSlice:$,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:at}):b.remove()}e.exports=function(t,e,r,i){var o,s,l=t._fullLayout,c=l._treemaplayer,f=!r;(u(\"treemap\",l),(o=c.selectAll(\"g.trace.treemap\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"treemap\",!0),o.order(),!l.uniformtext.mode&&a.hasTransition(r))?(i&&(s=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){s&&s()})).each(\"interrupt\",(function(){s&&s()})).each((function(){c.selectAll(\"g.trace\").each((function(e){m(t,e,this,r)}))}))):(o.each((function(e){m(t,e,this,r)})),l.uniformtext.mode&&h(t,l._treemaplayer.selectAll(\".trace\"),\"treemap\"));f&&o.exit().remove()}},{\"../../lib\":749,\"../bar/constants\":893,\"../bar/plot\":902,\"../bar/style\":905,\"../bar/uniform_text\":907,\"../sunburst/helpers\":1274,\"./constants\":1297,\"./draw_ancestors\":1299,\"./draw_descendants\":1300,d3:169}],1306:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/color\"),i=t(\"../../lib\"),o=t(\"../sunburst/helpers\"),s=t(\"../bar/uniform_text\").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,h=u.i,f=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&\"rgba(0,0,0,0)\"===f)d=0,s=\"rgba(0,0,0,0)\",l=0;else if(s=i.castOption(r,h,\"marker.line.color\")||a.defaultLine,l=i.castOption(r,h,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var m,v=a.combine(a.addOpacity(r._backgroundColor,.75),f);if(!0===g){var y=o.getMaxDepth(r);m=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else m=e.data.depth-r._entryDepth,r._atRootLevel||m++;if(m>0)for(var x=0;x<m;x++){var b=.5*x/m;f=a.combine(a.addOpacity(v,b),f)}}}t.style(\"stroke-width\",l).call(a.fill,f).call(a.stroke,s).style(\"opacity\",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(l,t,r,{hovered:!1})}))}))},styleOne:l}},{\"../../components/color\":615,\"../../lib\":749,\"../bar/uniform_text\":907,\"../sunburst/helpers\":1274,d3:169}],1307:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),a=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:a({},n.name,{}),orientation:a({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:a({},n.boxpoints,{}),jitter:a({},n.jitter,{}),pointpos:a({},n.pointpos,{}),width:a({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":739,\"../box/attributes\":916}],1308:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var a=e.max-e.min;if(!a)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,a/1e4);var i=r.length,o=n.stdev(r,i-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(i,o,e.q3-e.q1),a/100)}function c(t,e,r,n){var i,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var a=l[n],i=\"multicategory\"===r.type?r.r2c(a):r.d2c(a,0,t[e.valLetter+\"calendar\"]);return i===s?u[n]:i}var f={type:\"linear\",range:i=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return a.setConvert(f),f.cleanRange(),i}e.exports=function(t,e){var r=i(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=a.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var m=r[g],v=m.pts.map(o.extractVal),y=m.bandwidth=l(e,m,v),x=m.span=c(e,m,u,y);if(m.min===m.max&&0===y)x=m.span=[m.min,m.max],m.density=[{v:1,t:x[0]}],m.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(m,e,v);m.density=new Array(_);for(var k=0,M=x[0];M<x[1]+w/2;k++,M+=w){var A=T(M);m.density[k]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,v.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=a.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../box/calc\":917,\"./helpers\":1311}],1309:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,a=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,i=e.xaxis,o=e.yaxis,s=0;s<a.length;s++){for(var l=a[s],c=\"h\"===l?o:i,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==i._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":918}],1310:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../components/color\"),i=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}function c(r,a){return n.coerce2(t,e,o,r,a)}if(i.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",a.addOpacity(e.line.color,.5));i.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),m=c(\"box.fillcolor\",d),v=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||m||v||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":615,\"../../lib\":749,\"../box/defaults\":919,\"./attributes\":1307}],1311:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,i=a,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,a=0;a<n;a++)e+=i((t-r[a])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var a,i;\"h\"===e.orientation?(a=\"y\",i=\"x\"):(a=\"x\",i=\"y\");var o=n.findPointOnPath(t.path,r,i,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[a];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var a=t.pts.map(r.extractVal);return r.makeKDE(t,e,a)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":749}],1312:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),i=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),m=[];if(d||g){var v=i.hoverOnBoxes(t,e,r,s);if(g&&v.length>0){var y,x,b,_,w,T=t.xa,k=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=k,x=\"x\",_=T):(w=r,y=\"x\",b=T,x=\"y\",_=k);var M=h[t.index];if(w>=M.span[0]&&w<=M.span[1]){var A=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(M,f,w),C=o.getPositionOnKdePath(M,f,S),L=b._offset,P=b._length;A[y+\"0\"]=C[0],A[y+\"1\"]=C[1],A[x+\"0\"]=A[x+\"1\"]=S,A[x+\"Label\"]=x+\": \"+a.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),A.spikeDistance=v[0].spikeDistance;var I=y+\"Spike\";A[I]=v[0][I],v[0].spikeDistance=void 0,v[0][I]=void 0,A.hovertemplate=!1,m.push(A),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(m=m.concat(v))}-1!==p.indexOf(\"points\")&&(c=i.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:m:c?(m.push(c),m):m}},{\"../../lib\":749,\"../../plots/cartesian/axes\":798,\"../box/hover\":921,\"./helpers\":1311}],1313:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":811,\"../box/defaults\":919,\"../box/select\":926,\"../scatter/style\":1180,\"./attributes\":1307,\"./calc\":1308,\"./cross_trace_calc\":1309,\"./defaults\":1310,\"./hover\":1312,\"./layout_attributes\":1314,\"./layout_defaults\":1315,\"./plot\":1316,\"./style\":1317}],1314:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),a=t(\"../../lib\").extendFlat;e.exports={violinmode:a({},n.boxmode,{}),violingap:a({},n.boxgap,{}),violingroupgap:a({},n.boxgroupgap,{})}},{\"../../lib\":749,\"../box/layout_attributes\":923}],1315:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\"),i=t(\"../box/layout_defaults\");e.exports=function(t,e,r){i._supply(t,e,r,(function(r,i){return n.coerce(t,e,a,r,i)}),\"violin\")}},{\"../../lib\":749,\"../box/layout_defaults\":924,\"./layout_attributes\":1314}],1316:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return i.smoothopen(e[0],1)}a.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),i=t[0],s=i.t,c=i.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,m=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(a.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each((function(t){var e,r,a,i,o,l,h,f,_=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+d,!0),M=v.l2p(k);if(c.width)e=s.maxKDE/g;else{var A=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?A.maxKDE/g*(A.maxCount/t.pts.length):A.maxKDE/g}if(x){for(h=new Array(T),o=0;o<T;o++)(f=h[o]={})[s.posLetter]=k+w[o].v/e,f[s.valLetter]=m.c2l(w[o].t,!0);r=p(h)}if(b){for(h=new Array(T),l=0,o=T-1;l<T;l++,o--)(f=h[l]={})[s.posLetter]=k-w[o].v/e,f[s.valLetter]=m.c2l(w[o].t,!0);a=p(h)}if(y)i=r+\"L\"+a.substr(1)+\"Z\";else{var S=[M,m.c2p(w[0].t)],E=[M,m.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),i=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+a.substr(1)+\"L\"+S}_.attr(\"d\",i),t.posCenterPx=M,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)}));var w,T,k,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=g*A,T=0):x?(w=[0,g*A/2],T=S*{x:1,y:-1}[s.posLetter]):(w=[g*A/2,0],T=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),o.plotBoxMean(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),!c.box.visible&&c.meanline.visible&&(k=a.identity);var E=r.selectAll(\"path.meanline\").data(k||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each((function(t){var e=m.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:h,y:f},c,s)}}))}},{\"../../components/drawing\":637,\"../../lib\":749,\"../box/plot\":925,\"../scatter/line_points\":1170,\"./helpers\":1311,d3:169}],1317:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/color\"),i=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(a.stroke,r.line.color).call(a.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(a.stroke,l.color).call(a.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(a.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(a.stroke,c.color),i(o,r,t)}))}},{\"../../components/color\":615,\"../scatter/style\":1180,d3:169}],1318:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),a=t(\"../isosurface/attributes\"),i=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=e.exports=l(s({x:a.x,y:a.y,z:a.z,value:a.value,isomin:a.isomin,isomax:a.isomax,surface:a.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:a.slices,caps:a.caps,text:a.text,hovertext:a.hovertext,hovertemplate:a.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:a.colorbar,opacity:a.opacity,opacityscale:i.opacityscale,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":622,\"../../lib/extend\":739,\"../../plot_api/edit_types\":780,\"../../plots/attributes\":794,\"../isosurface/attributes\":1092,\"../surface/attributes\":1280}],1319:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),a=t(\"../../lib/gl_format_color\").parseColorScale,i=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],a=this.data._meshZ[e],i=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(a,this.data._Zs).id,h=t.index=u+o*c+o*i*s;t.traceCoordinate=[this.data._meshX[h],this.data._meshY[h],this.data._meshZ[h],this.data._value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:i(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=a(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new u(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{\"../../components/colorscale\":627,\"../../lib/gl_format_color\":745,\"../../lib/str2rgbarray\":772,\"../../plots/gl3d/zip3\":851,\"../isosurface/convert\":1094,\"gl-mesh3d\":292}],1320:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./attributes\"),i=t(\"../isosurface/defaults\").supplyIsoDefaults,o=t(\"../surface/defaults\").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,r,s,l),o(t,e,s,l)}},{\"../../lib\":749,\"../isosurface/defaults\":1095,\"../surface/defaults\":1283,\"./attributes\":1318}],1321:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":840,\"../isosurface/calc\":1093,\"./attributes\":1318,\"./convert\":1319,\"./defaults\":1320}],1322:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),a=t(\"../scatter/attributes\").line,i=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");function h(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},i.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:h(),decreasing:h(),totals:h(),connector:{line:{color:c({},a.color,{dflt:u.defaultLine}),width:c({},a.width,{editType:\"plot\"}),dash:a.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":615,\"../../lib/extend\":739,\"../../plots/attributes\":794,\"../../plots/template_attributes\":876,\"../bar/attributes\":891,\"../scatter/attributes\":1156,\"./constants\":1324}],1323:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),i=t(\"../../lib\").mergeArray,o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,u,h,f,p=n.getFromId(t,e.xaxis||\"x\"),d=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=p.makeCalcdata(e,\"x\"),h=d.makeCalcdata(e,\"y\"),u=a(e,d,\"y\",h),f=!!e.yperiodalignment):(r=d.makeCalcdata(e,\"y\"),h=p.makeCalcdata(e,\"x\"),u=a(e,p,\"x\",h),f=!!e.xperiodalignment);for(var g,m=Math.min(u.length,r.length),v=new Array(m),y=0,x=!1,b=0;b<m;b++){var _=r[b]||0,w=!1;(r[b]!==s||c(e.measure[b])||l(e.measure[b]))&&b+1<m&&(r[b+1]!==s||c(e.measure[b+1])||l(e.measure[b+1]))&&(w=!0);var T=v[b]={i:b,p:u[b],s:_,rawS:_,cNext:w};l(e.measure[b])?(y=T.s,T.isSum=!0,T.dir=\"totals\",T.s=y):c(e.measure[b])?(T.isSum=!0,T.dir=\"totals\",T.s=y):(T.isSum=!1,T.dir=T.rawS<0?\"decreasing\":\"increasing\",g=T.s,T.s=y+g,y+=g),\"totals\"===T.dir&&(x=!0),f&&(v[b].orig_p=h[b]),e.ids&&(T.id=String(e.ids[b])),T.v=(e.base||0)+y}return v.length&&(v[0].hasTotals=x),i(e.text,v,\"tx\"),i(e.hovertext,v,\"htx\"),o(v,e),v}},{\"../../constants/numerical\":724,\"../../lib\":749,\"../../plots/cartesian/align_period\":795,\"../../plots/cartesian/axes\":798,\"../scatter/calc_selection\":1158}],1324:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1325:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,a,i=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(a=0;a<o.length;a++){var p=o[a];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[a],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:i.waterfallmode,norm:i.waterfallnorm,gap:i.waterfallgap,groupgap:i.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),a=0;a<u.length;a++){r=u[a];for(var g=0;g<r.length;g++){var m=r[g];!1===m.isSum&&(m.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":894}],1326:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"../bar/defaults\").handleGroupingDefaults,i=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\"),u=t(\"../../constants/delta.js\"),h=u.INCREASING.COLOR,f=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,a){function c(r,a){return n.coerce(t,e,l,r,a)}if(o(t,e,a,c)){s(t,e,a,c),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");if(i(t,e,a,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",h),p(c,\"decreasing\",f),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\"))c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,i;function o(t){return n.coerce(i._input,i,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(i=t[s])._input,a(r,i,e,o)}}},{\"../../components/color\":615,\"../../constants/delta.js\":718,\"../../lib\":749,\"../bar/defaults\":895,\"../scatter/period_defaults\":1176,\"../scatter/xy_defaults\":1183,\"./attributes\":1322}],1327:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1328:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,a=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=i(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var m=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+m+\")\":m,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var v=d.hi||h.hoverinfo,y=[];if(v&&\"none\"!==v&&\"skip\"!==v){var x=\"all\"===v,b=v.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,i=r.line.color,o=r.line.width;if(a(n))return n;if(a(i)&&o)return i}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":615,\"../../constants/delta.js\":718,\"../../plots/cartesian/axes\":798,\"../bar/hover\":898}],1329:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":811,\"../bar/select\":903,\"./attributes\":1322,\"./calc\":1323,\"./cross_trace_calc\":1325,\"./defaults\":1326,\"./event_data\":1327,\"./hover\":1328,\"./layout_attributes\":1330,\"./layout_defaults\":1331,\"./plot\":1332,\"./style\":1333}],1330:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1331:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),a=t(\"./layout_attributes\");e.exports=function(t,e,r){var i=!1;function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){i=!0;break}}i&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":749,\"./layout_attributes\":1330}],1332:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../lib\"),i=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,h=a.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=u.connector.mode,d=h.selectAll(\"g.line\").data(a.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var u=function(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),a[2]=o.c2p(t.nextS0,!0),i[2]=s.c2p(t.nextP0,!0),n?[a,i]:[i,a]}(r,l,c,f),h=u[0],d=u[1],m=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(m+=f?\"M\"+h[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+h[1]+\",\"+d[0]+\"H\"+h[0]),\"between\"!==p&&(r.isSum||s<g-1)&&(m+=f?\"M\"+h[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+h[0]+\",\"+d[1]+\"H\"+h[1]),h[2]!==o&&d[2]!==o&&(m+=f?\"M\"+h[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+h[1]+\",\"+d[1]+\"H\"+h[2])),\"\"===m&&(m=\"M0,0Z\"),a.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(i.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,c)}},{\"../../components/drawing\":637,\"../../constants/numerical\":724,\"../../lib\":749,\"../bar/plot\":902,\"../bar/uniform_text\":907,d3:169}],1333:[function(t,e,r){\"use strict\";var n=t(\"d3\"),a=t(\"../../components/drawing\"),i=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(i.fill,e.color).call(i.stroke,e.line.color).call(a.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;a.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":615,\"../../components/drawing\":637,\"../../constants/interactions\":723,\"../bar/style\":905,\"../bar/uniform_text\":907,d3:169}],1334:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),a=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,i){if(i.enabled){for(var o=i.target,l=a.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(a.sorterAsc);var c=(r.length-1)/2;return i((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var a,i=0,o=0,l=1,c=s;for(a=0;a<r.length&&c===s;a++)c=n(e[r[a]]);if(c===s)return s;for(;a<r.length;a++){var u=n(e[r[a]]);if(u!==s){var h=u-c;i+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-i*i/l)/f):0}}}(i,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===i.func&&a.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return a.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=i.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return a.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var m=g(\"target\"),v=g(\"func\");g(\"enabled\")&&m&&(u[m]||\"count\"===v&&void 0===u[m])?(\"stddev\"===v&&g(\"funcmode\"),u[m]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,i=a.getTargetArray(e,{target:n});if(i){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),m=i.length;for(e._length&&(m=Math.min(m,e._length)),s=0;s<m;s++)void 0===(c=f[l=i[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var v=r.aggregations;for(s=0;s<v.length;s++)u(t,e,d,v[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":724,\"../lib\":749,\"../plot_api/plot_schema\":786,\"../plots/cartesian/axes\":798,\"./helpers\":1337}],1335:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../registry\"),i=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(a,i){return n.coerce(t,e,r.attributes,a,i)}if(i(\"enabled\")){var o=i(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;i(\"preservegaps\"),i(\"operation\"),i(\"value\");var s=a.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var a=n.getTargetArray(e,r);if(a){var s=r.target,h=a.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var m,v,y=function(t,e,r){var n=t.operation,a=t.value,i=Array.isArray(a);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(i?a[0]:a):o(c)?s=i?[h(a[0]),h(a[1])]:[h(a),h(a)]:o(u)&&(s=i?a.map(h):[h(a)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,i.getDataToCoordFunc(t,e,s,a),f),x={},b={},_=0;d?(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},v=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},v=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(m);for(var w=o(e.transforms,r),T=0;T<h;T++){y(a[T])?(k(v,T),b[_++]=w(T)):d&&_++}r._indexToPoints=b,e._length=_}}function k(t,r){for(var a=0;a<p.length;a++){t(n.nestedProperty(e,p[a]),r)}}}},{\"../constants/filter_ops\":720,\"../lib\":749,\"../plots/cartesian/axes\":798,\"../registry\":881,\"./helpers\":1337}],1336:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),i=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,m=e.transform,v=e.transformIndex,y=t.transforms[v].groups,x=o(t.transforms,m);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,T=a.findArrayAttributes(t),k=m.styles||[],M={};for(r=0;r<k.length;r++)M[k[r].target]=k[r].value;m.styles&&(g=n.keyedContainer(m,\"styles\",\"target\",\"value.name\"));var A={},S={};for(r=0;r<b.length;r++){A[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[v]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(m.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(f,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[A[y[s]]]).transforms[v]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],i.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,M[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,a){var i,o={};function s(e,a){return n.coerce(t,o,r.attributes,e,a)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",a._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(i=0;i<l.length;i++){var u=c[i]={};n.coerce(l[i],c[i],r.attributes.styles,\"target\");var h=n.coerce(l[i],c[i],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,a,i=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),a=0;a<r.length;a++)i.push(r[a]);return i}},{\"../lib\":749,\"../plot_api/plot_schema\":786,\"../plots/plots\":861,\"./helpers\":1337}],1337:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,a=0;a<t.length&&(r=t[a])!==e;a++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1338:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),a=t(\"../plots/cartesian/axes\"),i=t(\"./helpers\").pointsAccessorFunction,o=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(a,i){return n.coerce(t,e,r.attributes,a,i)}return a(\"enabled\")&&(a(\"target\"),a(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,h,f=e._arrayAttrs,p=function(t,e,r,n){var a,i=new Array(n),s=new Array(n);for(a=0;a<n;a++)i[a]={v:e[a],i:a};for(i.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),a=e(r.v);return n===o?1:a===o?-1:n-a};case\"descending\":return function(t,r){var n=e(t.v),a=e(r.v);return n===o?1:a===o?-1:a-n}}}(t,r)),a=0;a<n;a++)s[a]=i[a].i;return s}(r,s,a.getDataToCoordFunc(t,e,l,s),c),d=i(e.transforms,r),g={};for(u=0;u<f.length;u++){var m=n.nestedProperty(e,f[u]),v=m.get(),y=new Array(c);for(h=0;h<c;h++)y[h]=v[p[h]];m.set(y)}for(h=0;h<c;h++)g[h]=d(p[h]);r._indexToPoints=g,e._length=c}}}},{\"../constants/numerical\":724,\"../lib\":749,\"../plots/cartesian/axes\":798,\"./helpers\":1337}],1339:[function(t,e,r){\"use strict\";r.version=\"1.56.0\"},{}]},{},[26])(26)}));\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "colorbar": {
          "x": 0.75
         },
         "colorscale": [
          [
           0,
           "rgb(253, 253, 204)"
          ],
          [
           0.09090909090909091,
           "rgb(206, 236, 179)"
          ],
          [
           0.18181818181818182,
           "rgb(156, 219, 165)"
          ],
          [
           0.2727272727272727,
           "rgb(111, 201, 163)"
          ],
          [
           0.36363636363636365,
           "rgb(86, 177, 163)"
          ],
          [
           0.45454545454545453,
           "rgb(76, 153, 160)"
          ],
          [
           0.5454545454545454,
           "rgb(68, 130, 155)"
          ],
          [
           0.6363636363636364,
           "rgb(62, 108, 150)"
          ],
          [
           0.7272727272727273,
           "rgb(62, 82, 143)"
          ],
          [
           0.8181818181818182,
           "rgb(64, 60, 115)"
          ],
          [
           0.9090909090909091,
           "rgb(54, 43, 77)"
          ],
          [
           1,
           "rgb(39, 26, 44)"
          ]
         ],
         "opacity": 0.9,
         "type": "surface",
         "x": [
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ]
         ],
         "y": [
          [
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793
          ],
          [
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478
          ],
          [
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632
          ],
          [
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483
          ],
          [
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333
          ],
          [
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184
          ],
          [
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035
          ],
          [
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885
          ],
          [
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736
          ],
          [
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586
          ],
          [
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437
          ],
          [
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288
          ],
          [
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014
          ],
          [
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699
          ],
          [
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384
          ],
          [
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069
          ],
          [
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754
          ],
          [
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439
          ],
          [
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124
          ],
          [
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092
          ],
          [
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943
          ],
          [
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793
          ],
          [
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644
          ],
          [
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495
          ],
          [
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345
          ],
          [
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196
          ],
          [
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046
          ],
          [
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897
          ],
          [
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748
          ],
          [
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866
          ],
          [
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345
          ],
          [
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203
          ],
          [
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715
          ],
          [
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654
          ],
          [
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085
          ],
          [
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877
          ],
          [
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455
          ],
          [
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403
          ],
          [
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253
          ],
          [
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104
          ],
          [
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955
          ],
          [
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805
          ],
          [
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656
          ],
          [
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506
          ],
          [
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357
          ],
          [
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207
          ],
          [
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058
          ],
          [
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909
          ],
          [
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676
          ],
          [
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361
          ],
          [
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046
          ],
          [
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731
          ],
          [
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162
          ],
          [
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012
          ],
          [
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863
          ],
          [
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713
          ],
          [
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564
          ],
          [
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414
          ],
          [
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265
          ],
          [
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116
          ],
          [
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966
          ],
          [
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817
          ],
          [
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667
          ],
          [
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518
          ],
          [
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369
          ],
          [
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322
          ],
          [
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007
          ],
          [
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692
          ],
          [
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377
          ],
          [
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621
          ],
          [
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472
          ],
          [
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323
          ],
          [
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173
          ],
          [
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024
          ],
          [
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874
          ],
          [
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725
          ],
          [
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576
          ],
          [
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426
          ],
          [
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277
          ],
          [
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127
          ],
          [
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978
          ],
          [
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828
          ],
          [
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679
          ],
          [
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653
          ],
          [
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338
          ],
          [
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231
          ],
          [
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814
          ],
          [
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932
          ],
          [
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825
          ],
          [
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633
          ],
          [
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837
          ],
          [
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343
          ],
          [
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185
          ],
          [
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355
          ],
          [
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886
          ],
          [
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366
          ],
          [
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872
          ],
          [
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378
          ],
          [
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884
          ],
          [
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896
          ],
          [
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954
          ],
          [
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14
          ],
          [
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093
          ],
          [
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587
          ],
          [
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081
          ],
          [
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575
          ],
          [
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907
          ],
          [
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564
          ],
          [
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058
          ],
          [
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552
          ],
          [
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046
          ],
          [
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654
          ],
          [
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034
          ],
          [
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953
          ],
          [
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023
          ],
          [
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517
          ],
          [
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401
          ],
          [
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505
          ],
          [
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137
          ],
          [
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849
          ],
          [
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999
          ],
          [
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148
          ],
          [
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298
          ],
          [
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447
          ],
          [
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596
          ],
          [
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746
          ],
          [
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895
          ],
          [
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045
          ],
          [
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194
          ],
          [
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344
          ],
          [
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493
          ],
          [
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642
          ],
          [
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792
          ],
          [
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941
          ],
          [
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409
          ],
          [
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724
          ],
          [
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039
          ],
          [
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539
          ],
          [
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688
          ],
          [
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838
          ],
          [
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987
          ],
          [
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137
          ],
          [
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286
          ],
          [
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435
          ],
          [
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585
          ],
          [
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734
          ],
          [
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884
          ],
          [
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033
          ],
          [
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182
          ],
          [
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332
          ],
          [
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481
          ],
          [
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763
          ],
          [
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078
          ],
          [
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393
          ],
          [
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708
          ],
          [
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228
          ],
          [
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378
          ],
          [
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527
          ],
          [
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677
          ],
          [
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826
          ],
          [
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975
          ],
          [
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125
          ],
          [
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274
          ],
          [
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424
          ],
          [
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573
          ],
          [
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723
          ],
          [
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487
          ],
          [
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802
          ],
          [
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117
          ],
          [
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432
          ],
          [
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747
          ],
          [
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062
          ],
          [
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377
          ],
          [
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692
          ],
          [
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067
          ],
          [
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217
          ],
          [
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366
          ],
          [
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516
          ],
          [
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665
          ],
          [
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814
          ],
          [
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964
          ],
          [
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113
          ],
          [
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263
          ],
          [
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841
          ],
          [
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156
          ],
          [
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471
          ],
          [
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786
          ],
          [
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101
          ],
          [
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416
          ],
          [
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731
          ],
          [
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046
          ],
          [
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607
          ],
          [
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757
          ],
          [
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906
          ],
          [
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056
          ],
          [
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205
          ],
          [
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354
          ],
          [
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504
          ],
          [
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653
          ],
          [
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803
          ],
          [
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195
          ],
          [
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151
          ]
         ],
         "z": [
          [
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1.0000000000000002,
           -1,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1.0000000000000002,
           -1,
           -1.0000000000000002,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1.0000000000000002,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1.0000000000000002,
           -1,
           -1,
           -1,
           -1.0000000000000002,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -1.0000000000000002,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1.0000000000000002,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1.0000000000000002,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1.0000000000000002,
           -1,
           -1.0000000000000002,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1.0000000000000002,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1.0000000000000002,
           -1,
           -0.9999999999999998,
           -0.9999999999999999,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -0.9999999999999999,
           -1,
           -1,
           -0.9999999999999999,
           -1,
           -0.9999999999999998,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -0.9999999999999999,
           -1,
           -1,
           -1,
           -1,
           -0.9999999999999999,
           -1.0000000000000002
          ],
          [
           -1.0004837177080117,
           -1.0004834838382903,
           -1.0004827824550522,
           -1.0004816142358575,
           -1.0004799803092508,
           -1.0004778822536728,
           -1.0004753220959446,
           -1.000472302309317,
           -1.00046882581109,
           -1.0004648959598101,
           -1.000460516552036,
           -1.000455691818688,
           -1.0004504264209768,
           -1.0004447254459197,
           -1.0004385944014447,
           -1.0004320392110913,
           -1.0004250662083112,
           -1.0004176821303699,
           -1.000409894111866,
           -1.0004017096778615,
           -1.0003931367366383,
           -1.0003841835720853,
           -1.0003748588357217,
           -1.0003651715383663,
           -1.0003551310414602,
           -1.0003447470480504,
           -1.0003340295934422,
           -1.0003229890355332,
           -1.0003116360448314,
           -1.0002999815941753,
           -1.0002880369481557,
           -1.0002758136522611,
           -1.000263323521745,
           -1.0002505786302363,
           -1.0002375912980939,
           -1.0002243740805272,
           -1.0002109397554833,
           -1.0001973013113203,
           -1.0001834719342748,
           -1.0001694649957356,
           -1.0001552940393375,
           -1.0001409727678876,
           -1.000126515030134,
           -1.00011193480739,
           -1.0000972462000333,
           -1.0000824634138812,
           -1.0000676007464664,
           -1.0000526725732204,
           -1.0000376933335768,
           -1.0000226775170145,
           -1.000007639649046,
           -0.9999925942771707,
           -0.999977555956804,
           -0.999962539237196,
           -0.9999475586473529,
           -0.9999326286819769,
           -0.9999177637874352,
           -0.9999029783477758,
           -0.9998882866707965,
           -0.9998737029741914,
           -0.999859241371777,
           -0.999844915859819,
           -0.999830740303471,
           -0.9998167284233356,
           -0.9998028937821662,
           -0.9997892497717181,
           -0.9997758095997621,
           -0.999762586277277,
           -0.9997495926058284,
           -0.9997368411651512,
           -0.9997243443009424,
           -0.9997121141128815,
           -0.9997001624428871,
           -0.9996885008636212,
           -0.999677140667255,
           -0.9996660928545031,
           -0.9996553681239421,
           -0.9996449768616181,
           -0.999634929130959,
           -0.9996252346629971,
           -0.9996159028469157,
           -0.9996069427209235,
           -0.9995983629634723,
           -0.9995901718848216,
           -0.9995823774189602,
           -0.9995749871158935,
           -0.9995680081343037,
           -0.9995614472345881,
           -0.9995553107722857,
           -0.9995496046918969,
           -0.9995443345211019,
           -0.9995395053653833,
           -0.9995351219030616,
           -0.9995311883807432,
           -0.9995277086091896,
           -0.9995246859596103,
           -0.9995221233603827,
           -0.9995200232942028,
           -0.9995183877956699,
           -0.9995172184493069,
           -0.9995165163880182,
           -0.9995162822919882,
           -0.9995165163880181,
           -0.9995172184493067,
           -0.9995183877956697,
           -0.9995200232942029,
           -0.9995221233603827,
           -0.9995246859596104,
           -0.9995277086091895,
           -0.9995311883807433,
           -0.9995351219030617,
           -0.9995395053653834,
           -0.9995443345211018,
           -0.999549604691897,
           -0.9995553107722859,
           -0.9995614472345881,
           -0.9995680081343037,
           -0.9995749871158937,
           -0.9995823774189603,
           -0.9995901718848217,
           -0.9995983629634725,
           -0.9996069427209237,
           -0.9996159028469156,
           -0.9996252346629972,
           -0.9996349291309587,
           -0.999644976861618,
           -0.9996553681239421,
           -0.9996660928545033,
           -0.999677140667255,
           -0.9996885008636212,
           -0.999700162442887,
           -0.9997121141128816,
           -0.9997243443009423,
           -0.999736841165151,
           -0.9997495926058283,
           -0.9997625862772768,
           -0.9997758095997622,
           -0.9997892497717181,
           -0.9998028937821665,
           -0.9998167284233355,
           -0.9998307403034709,
           -0.999844915859819,
           -0.9998592413717768,
           -0.9998737029741915,
           -0.9998882866707967,
           -0.9999029783477759,
           -0.9999177637874352,
           -0.9999326286819769,
           -0.999947558647353,
           -0.9999625392371958,
           -0.9999775559568042,
           -0.9999925942771707,
           -1.0000076396490458,
           -1.0000226775170145,
           -1.0000376933335768,
           -1.0000526725732204,
           -1.0000676007464666,
           -1.000082463413881,
           -1.000097246200033,
           -1.00011193480739,
           -1.000126515030134,
           -1.0001409727678878,
           -1.0001552940393375,
           -1.0001694649957353,
           -1.0001834719342746,
           -1.0001973013113206,
           -1.0002109397554833,
           -1.000224374080527,
           -1.0002375912980939,
           -1.0002505786302363,
           -1.0002633235217453,
           -1.0002758136522611,
           -1.0002880369481557,
           -1.0002999815941753,
           -1.0003116360448316,
           -1.0003229890355332,
           -1.0003340295934424,
           -1.0003447470480504,
           -1.0003551310414602,
           -1.0003651715383661,
           -1.0003748588357217,
           -1.0003841835720853,
           -1.0003931367366383,
           -1.0004017096778615,
           -1.0004098941118658,
           -1.0004176821303696,
           -1.000425066208311,
           -1.0004320392110915,
           -1.0004385944014444,
           -1.0004447254459197,
           -1.0004504264209766,
           -1.0004556918186878,
           -1.0004605165520362,
           -1.0004648959598104,
           -1.00046882581109,
           -1.0004723023093167,
           -1.0004753220959448,
           -1.0004778822536728,
           -1.0004799803092506,
           -1.0004816142358572,
           -1.0004827824550522,
           -1.0004834838382903
          ],
          [
           -1.0019344028664054,
           -1.0019334689675852,
           -1.0019306681693905,
           -1.0019260031657735,
           -1.0019194784438241,
           -1.0019111002795296,
           -1.0019008767318422,
           -1.0018888176350618,
           -1.0018749345895364,
           -1.0018592409506948,
           -1.001841751816415,
           -1.001822484012745,
           -1.0018014560779824,
           -1.001778688245134,
           -1.001754202422763,
           -1.0017280221742488,
           -1.0017001726954713,
           -1.0016706807909412,
           -1.0016395748484008,
           -1.0016068848119142,
           -1.0015726421534699,
           -1.0015368798431248,
           -1.001499632317715,
           -1.0014609354481598,
           -1.0014208265053872,
           -1.0013793441249188,
           -1.001336528270134,
           -1.0012924201942581,
           -1.0012470624010998,
           -1.001200498604582,
           -1.0011527736870913,
           -1.001103933656698,
           -1.0010540256032716,
           -1.0010030976535438,
           -1.00095119892515,
           -1.0008983794797002,
           -1.0008446902749146,
           -1.000790183115876,
           -1.0007349106054357,
           -1.0006789260938245,
           -1.0006222836275158,
           -1.0005650378973838,
           -1.0005072441862102,
           -1.0004489583155847,
           -1.0003902365922523,
           -1.0003311357539575,
           -1.0002717129148313,
           -1.0002120255103826,
           -1.0001521312421366,
           -1.0000920880219788,
           -1.0000319539162548,
           -0.9999717870896841,
           -0.9999116457491323,
           -0.9998515880873076,
           -0.9997916722264277,
           -0.9997319561619146,
           -0.999672497706172,
           -0.9996133544325008,
           -0.9995545836192044,
           -0.9994962421939436,
           -0.9994383866783915,
           -0.999381073133244,
           -0.9993243571036429,
           -0.9992682935650614,
           -0.9992129368697094,
           -0.9991583406935104,
           -0.9991045579837022,
           -0.9990516409071173,
           -0.998999640799189,
           -0.9989486081137423,
           -0.9988985923736127,
           -0.9988496421221478,
           -0.9988018048756399,
           -0.998755127076736,
           -0.9987096540488756,
           -0.9986654299518002,
           -0.9986224977381825,
           -0.9985808991114171,
           -0.998540674484618,
           -0.9985018629408662,
           -0.9984645021947437,
           -0.9984286285551993,
           -0.9983942768897826,
           -0.9983614805902787,
           -0.9983302715397906,
           -0.998300680081288,
           -0.9982727349876717,
           -0.9982464634333712,
           -0.9982218909675131,
           -0.9981990414886867,
           -0.9981779372213314,
           -0.9981585986937724,
           -0.998141044717928,
           -0.9981252923707079,
           -0.9981113569771244,
           -0.9980992520951336,
           -0.9980889895022197,
           -0.9980805791837425,
           -0.9980740293230544,
           -0.9980693462934015,
           -0.9980665346516133,
           -0.9980655971335944,
           -0.9980665346516134,
           -0.9980693462934014,
           -0.9980740293230546,
           -0.9980805791837424,
           -0.9980889895022197,
           -0.9980992520951337,
           -0.9981113569771245,
           -0.998125292370708,
           -0.998141044717928,
           -0.9981585986937724,
           -0.9981779372213314,
           -0.9981990414886868,
           -0.9982218909675133,
           -0.9982464634333712,
           -0.9982727349876719,
           -0.998300680081288,
           -0.9983302715397906,
           -0.9983614805902788,
           -0.9983942768897827,
           -0.9984286285551995,
           -0.9984645021947437,
           -0.9985018629408662,
           -0.9985406744846181,
           -0.998580899111417,
           -0.9986224977381826,
           -0.9986654299518003,
           -0.9987096540488756,
           -0.9987551270767359,
           -0.9988018048756397,
           -0.9988496421221479,
           -0.9988985923736128,
           -0.9989486081137424,
           -0.9989996407991891,
           -0.9990516409071172,
           -0.9991045579837022,
           -0.9991583406935105,
           -0.9992129368697095,
           -0.9992682935650613,
           -0.999324357103643,
           -0.9993810731332439,
           -0.9994383866783915,
           -0.9994962421939436,
           -0.9995545836192044,
           -0.9996133544325008,
           -0.999672497706172,
           -0.9997319561619146,
           -0.9997916722264278,
           -0.9998515880873076,
           -0.9999116457491322,
           -0.9999717870896841,
           -1.000031953916255,
           -1.0000920880219788,
           -1.0001521312421366,
           -1.0002120255103828,
           -1.0002717129148315,
           -1.0003311357539575,
           -1.0003902365922523,
           -1.0004489583155844,
           -1.0005072441862102,
           -1.000565037897384,
           -1.000622283627516,
           -1.0006789260938247,
           -1.0007349106054357,
           -1.0007901831158763,
           -1.0008446902749148,
           -1.0008983794797002,
           -1.00095119892515,
           -1.001003097653544,
           -1.0010540256032718,
           -1.001103933656698,
           -1.0011527736870915,
           -1.001200498604582,
           -1.0012470624011,
           -1.001292420194258,
           -1.0013365282701343,
           -1.001379344124919,
           -1.0014208265053874,
           -1.0014609354481596,
           -1.0014996323177152,
           -1.0015368798431248,
           -1.00157264215347,
           -1.0016068848119142,
           -1.001639574848401,
           -1.001670680790941,
           -1.0017001726954713,
           -1.001728022174249,
           -1.0017542024227628,
           -1.001778688245134,
           -1.0018014560779824,
           -1.001822484012745,
           -1.001841751816415,
           -1.0018592409506948,
           -1.0018749345895366,
           -1.0018888176350618,
           -1.0019008767318425,
           -1.0019111002795293,
           -1.001919478443824,
           -1.0019260031657735,
           -1.0019306681693905,
           -1.0019334689675852
          ],
          [
           -1.0043506520309813,
           -1.0043485566575978,
           -1.0043422725383706,
           -1.0043318056742343,
           -1.004317166060629,
           -1.0042983676783248,
           -1.004275428480593,
           -1.0042483703767222,
           -1.0042172192118999,
           -1.0041820047434729,
           -1.0041427606136046,
           -1.0040995243183488,
           -1.0040523371731662,
           -1.0040012442749104,
           -1.00394629446031,
           -1.00388754026098,
           -1.003825037855003,
           -1.003758847015108,
           -1.0036890310534956,
           -1.0036156567633503,
           -1.0035387943570864,
           -1.0034585174013742,
           -1.0033749027490022,
           -1.003288030467628,
           -1.0031979837654716,
           -1.0031048489140209,
           -1.0030087151677975,
           -1.0029096746812625,
           -1.0028078224229209,
           -1.0027032560867002,
           -1.0025960760006731,
           -1.0024863850332033,
           -1.0023742884965907,
           -1.0022598940482994,
           -1.0021433115898482,
           -1.0020246531634553,
           -1.00190403284652,
           -1.0017815666440375,
           -1.0016573723790354,
           -1.0015315695811313,
           -1.0014042793733064,
           -1.0012756243570002,
           -1.0011457284956204,
           -1.00101471699658,
           -1.0008827161919647,
           -1.0007498534179382,
           -1.0006162568929975,
           -1.0004820555951888,
           -1.0003473791383968,
           -1.0002123576478268,
           -1.0000771216347908,
           -0.9999418018709196,
           -0.9998065292619194,
           -0.9996714347209935,
           -0.9995366490420523,
           -0.9994023027728302,
           -0.9992685260880401,
           -0.9991354486626847,
           -0.99900319954565,
           -0.998871907033711,
           -0.9987416985460698,
           -0.998612700499557,
           -0.9984850381846213,
           -0.998358835642233,
           -0.9982342155418271,
           -0.9981112990604146,
           -0.9979902057629857,
           -0.9978710534843277,
           -0.9977539582123846,
           -0.9976390339732815,
           -0.997526392718132,
           -0.9974161442117535,
           -0.9973083959234067,
           -0.9972032529196787,
           -0.9971008177596252,
           -0.997001190392285,
           -0.9969044680566781,
           -0.9968107451844015,
           -0.9967201133049225,
           -0.9966326609536833,
           -0.9965484735831095,
           -0.9964676334766295,
           -0.9963902196657984,
           -0.9963163078506165,
           -0.9962459703231379,
           -0.99617927589445,
           -0.996116289825113,
           -0.9960570737591306,
           -0.9960016856615358,
           -0.9959501797596564,
           -0.9959026064881321,
           -0.9958590124377437,
           -0.9958194403081156,
           -0.9957839288643436,
           -0.995752512897601,
           -0.9957252231897666,
           -0.9957020864821172,
           -0.9956831254481202,
           -0.9956683586703563,
           -0.9956578006216044,
           -0.9956514616501044,
           -0.9956493479690186,
           -0.9956514616501045,
           -0.9956578006216046,
           -0.9956683586703563,
           -0.9956831254481201,
           -0.9957020864821174,
           -0.9957252231897665,
           -0.9957525128976011,
           -0.9957839288643436,
           -0.9958194403081159,
           -0.9958590124377438,
           -0.9959026064881321,
           -0.9959501797596564,
           -0.996001685661536,
           -0.9960570737591308,
           -0.996116289825113,
           -0.9961792758944502,
           -0.9962459703231381,
           -0.9963163078506168,
           -0.9963902196657987,
           -0.9964676334766296,
           -0.9965484735831095,
           -0.9966326609536834,
           -0.9967201133049226,
           -0.9968107451844014,
           -0.9969044680566782,
           -0.997001190392285,
           -0.9971008177596256,
           -0.9972032529196788,
           -0.9973083959234067,
           -0.9974161442117537,
           -0.9975263927181323,
           -0.9976390339732818,
           -0.9977539582123847,
           -0.9978710534843277,
           -0.9979902057629859,
           -0.9981112990604146,
           -0.9982342155418272,
           -0.9983588356422332,
           -0.9984850381846216,
           -0.9986127004995571,
           -0.9987416985460696,
           -0.9988719070337111,
           -0.9990031995456502,
           -0.9991354486626849,
           -0.9992685260880404,
           -0.9994023027728303,
           -0.9995366490420524,
           -0.9996714347209937,
           -0.9998065292619195,
           -0.9999418018709196,
           -1.000077121634791,
           -1.000212357647827,
           -1.000347379138397,
           -1.000482055595189,
           -1.000616256892998,
           -1.0007498534179384,
           -1.000882716191965,
           -1.0010147169965802,
           -1.0011457284956204,
           -1.0012756243570005,
           -1.0014042793733067,
           -1.0015315695811313,
           -1.0016573723790356,
           -1.001781566644038,
           -1.00190403284652,
           -1.0020246531634551,
           -1.0021433115898484,
           -1.0022598940482994,
           -1.002374288496591,
           -1.0024863850332033,
           -1.0025960760006731,
           -1.0027032560867002,
           -1.002807822422921,
           -1.0029096746812625,
           -1.0030087151677978,
           -1.0031048489140213,
           -1.0031979837654719,
           -1.0032880304676277,
           -1.0033749027490024,
           -1.0034585174013742,
           -1.0035387943570866,
           -1.0036156567633503,
           -1.0036890310534956,
           -1.003758847015108,
           -1.003825037855003,
           -1.0038875402609801,
           -1.0039462944603097,
           -1.0040012442749107,
           -1.0040523371731662,
           -1.0040995243183486,
           -1.0041427606136046,
           -1.004182004743473,
           -1.0042172192118999,
           -1.0042483703767222,
           -1.0042754284805933,
           -1.004298367678325,
           -1.0043171660606287,
           -1.004331805674234,
           -1.0043422725383704,
           -1.0043485566575978
          ],
          [
           -1.0077301276367234,
           -1.007726417113038,
           -1.0077152890497447,
           -1.0076967539670463,
           -1.0076708293883312,
           -1.0076375398247532,
           -1.0075969167536605,
           -1.0075489985908808,
           -1.0074938306568808,
           -1.007431465136828,
           -1.0073619610345645,
           -1.0072853841205378,
           -1.007201806873709,
           -1.007111308417478,
           -1.0070139744496684,
           -1.0069098971666117,
           -1.0067991751813805,
           -1.006681913436224,
           -1.006558223109261,
           -1.0064282215154872,
           -1.0062920320021675,
           -1.006149783838677,
           -1.0060016121008633,
           -1.0058476575500104,
           -1.005688066506485,
           -1.0055229907181462,
           -1.0053525872236155,
           -1.0051770182104978,
           -1.0049964508686524,
           -1.0048110572386224,
           -1.0046210140553218,
           -1.0044265025871055,
           -1.0042277084703277,
           -1.0040248215395209,
           -1.0038180356533146,
           -1.0036075485162321,
           -1.0033935614964984,
           -1.0031762794399997,
           -1.0029559104805434,
           -1.0027326658465676,
           -1.0025067596644552,
           -1.0022784087586125,
           -1.002047832448481,
           -1.0018152523426433,
           -1.0015808921302078,
           -1.0013449773696412,
           -1.001107735275237,
           -1.0008693945014056,
           -1.0006301849249757,
           -1.0003903374257082,
           -1.0001500836652133,
           -0.9999096558644818,
           -0.9996692865802356,
           -0.9994292084803047,
           -0.9991896541182508,
           -0.9989508557074495,
           -0.9987130448948549,
           -0.998476452534669,
           -0.9982413084621402,
           -0.9980078412677231,
           -0.9977762780718248,
           -0.9975468443003739,
           -0.9973197634614464,
           -0.9970952569231808,
           -0.9968735436932208,
           -0.9966548401999225,
           -0.9964393600755636,
           -0.9962273139417936,
           -0.9960189091975579,
           -0.9958143498097395,
           -0.9956138361067485,
           -0.9954175645752977,
           -0.9952257276605956,
           -0.9950385135701892,
           -0.9948561060816848,
           -0.994678684354572,
           -0.9945064227463765,
           -0.9943394906333591,
           -0.994178052235975,
           -0.9940222664493108,
           -0.9938722866786979,
           -0.9937282606807096,
           -0.9935903304097385,
           -0.9934586318703398,
           -0.9933332949755297,
           -0.9932144434112163,
           -0.9931021945069317,
           -0.9929966591130316,
           -0.9928979414845192,
           -0.9928061391716391,
           -0.9927213429173872,
           -0.9926436365620627,
           -0.992573096954992,
           -0.9925097938735336,
           -0.9924537899494735,
           -0.9924051406029076,
           -0.9923638939836935,
           -0.9923300909205531,
           -0.9923037648778917,
           -0.992284941920389,
           -0.9922736406854106,
           -0.9922698723632766,
           -0.9922736406854107,
           -0.992284941920389,
           -0.9923037648778915,
           -0.9923300909205532,
           -0.9923638939836935,
           -0.9924051406029076,
           -0.9924537899494738,
           -0.9925097938735336,
           -0.9925730969549921,
           -0.9926436365620629,
           -0.9927213429173871,
           -0.992806139171639,
           -0.9928979414845192,
           -0.9929966591130317,
           -0.9931021945069317,
           -0.9932144434112166,
           -0.9933332949755298,
           -0.9934586318703398,
           -0.9935903304097389,
           -0.9937282606807099,
           -0.9938722866786978,
           -0.9940222664493109,
           -0.9941780522359751,
           -0.9943394906333591,
           -0.9945064227463768,
           -0.9946786843545723,
           -0.9948561060816851,
           -0.9950385135701896,
           -0.9952257276605958,
           -0.9954175645752978,
           -0.9956138361067488,
           -0.9958143498097398,
           -0.9960189091975581,
           -0.9962273139417938,
           -0.9964393600755638,
           -0.9966548401999226,
           -0.9968735436932209,
           -0.997095256923181,
           -0.9973197634614467,
           -0.997546844300374,
           -0.9977762780718249,
           -0.9980078412677235,
           -0.9982413084621404,
           -0.9984764525346692,
           -0.9987130448948551,
           -0.9989508557074496,
           -0.999189654118251,
           -0.9994292084803049,
           -0.9996692865802357,
           -0.999909655864482,
           -1.0001500836652135,
           -1.0003903374257084,
           -1.0006301849249761,
           -1.0008693945014058,
           -1.0011077352752376,
           -1.0013449773696415,
           -1.001580892130208,
           -1.0018152523426436,
           -1.0020478324484812,
           -1.0022784087586127,
           -1.0025067596644552,
           -1.0027326658465678,
           -1.0029559104805434,
           -1.0031762794399999,
           -1.0033935614964984,
           -1.0036075485162321,
           -1.0038180356533148,
           -1.004024821539521,
           -1.004227708470328,
           -1.0044265025871055,
           -1.004621014055322,
           -1.0048110572386224,
           -1.0049964508686529,
           -1.005177018210498,
           -1.0053525872236158,
           -1.0055229907181464,
           -1.0056880665064851,
           -1.0058476575500104,
           -1.0060016121008633,
           -1.006149783838677,
           -1.0062920320021678,
           -1.0064282215154872,
           -1.006558223109261,
           -1.0066819134362242,
           -1.0067991751813803,
           -1.0069098971666117,
           -1.0070139744496684,
           -1.0071113084174783,
           -1.0072018068737087,
           -1.007285384120538,
           -1.0073619610345645,
           -1.0074314651368281,
           -1.007493830656881,
           -1.0075489985908805,
           -1.0075969167536607,
           -1.007637539824753,
           -1.007670829388331,
           -1.0076967539670463,
           -1.0077152890497447,
           -1.0077264171130382
          ],
          [
           -1.0120695602592433,
           -1.0120637916076674,
           -1.0120464910365605,
           -1.012017674692309,
           -1.0119773694706282,
           -1.0119256129941743,
           -1.0118624535812175,
           -1.0117879502053835,
           -1.0117021724464808,
           -1.0116052004324372,
           -1.0114971247723659,
           -1.0113780464807893,
           -1.011248076893054,
           -1.0111073375719715,
           -1.0109559602057228,
           -1.0107940864970741,
           -1.0106218680439518,
           -1.0104394662114249,
           -1.010247051995161,
           -1.0100448058764095,
           -1.009832917668588,
           -1.0096115863555366,
           -1.009381019921523,
           -1.0091414351730834,
           -1.008893057552781,
           -1.0086361209449861,
           -1.0083708674737726,
           -1.0080975472930394,
           -1.0078164183689728,
           -1.00752774625497,
           -1.0072318038591461,
           -1.0069288712045648,
           -1.0066192351823322,
           -1.0063031892977012,
           -1.005981033409343,
           -1.005653073461953,
           -1.005319621212358,
           -1.004980993949309,
           -1.0046375142071469,
           -1.0042895094735342,
           -1.0039373118914652,
           -1.0035812579557577,
           -1.003221688204262,
           -1.0028589469040026,
           -1.0024933817325081,
           -1.0021253434545652,
           -1.0017551855946623,
           -1.001383264105386,
           -1.0010099370320458,
           -1.0006355641738118,
           -1.0002605067416577,
           -0.999885127013411,
           -0.9995097879862208,
           -0.9991348530267585,
           -0.9987606855194818,
           -0.9983876485132949,
           -0.9980161043669449,
           -0.9976464143935078,
           -0.997278938504317,
           -0.9969140348527016,
           -0.9965520594778987,
           -0.9961933659495238,
           -0.9958383050129729,
           -0.9954872242361464,
           -0.9951404676578888,
           -0.9947983754385327,
           -0.9944612835129532,
           -0.9941295232465298,
           -0.9938034210944222,
           -0.9934832982645653,
           -0.9931694703847898,
           -0.9928622471744777,
           -0.9925619321211566,
           -0.992268822162441,
           -0.9919832073737243,
           -0.9917053706620197,
           -0.9914355874663535,
           -0.991174125465099,
           -0.9909212442906412,
           -0.9906771952517575,
           -0.9904422210640861,
           -0.9902165555890536,
           -0.9900004235816209,
           -0.9897940404471981,
           -0.9895976120080695,
           -0.9894113342796595,
           -0.9892353932569579,
           -0.9890699647114093,
           -0.9889152139985623,
           -0.9887712958767577,
           -0.9886383543371184,
           -0.9885165224450928,
           -0.9884059221937873,
           -0.988306664369301,
           -0.9882188484282675,
           -0.9881425623877867,
           -0.9880778827279092,
           -0.9880248743068218,
           -0.9879835902888645,
           -0.9879540720854832,
           -0.9879363493092131,
           -0.9879304397407567,
           -0.987936349309213,
           -0.9879540720854832,
           -0.9879835902888645,
           -0.988024874306822,
           -0.9880778827279091,
           -0.988142562387787,
           -0.9882188484282675,
           -0.9883066643693011,
           -0.9884059221937874,
           -0.9885165224450929,
           -0.9886383543371186,
           -0.9887712958767577,
           -0.9889152139985625,
           -0.9890699647114095,
           -0.9892353932569581,
           -0.9894113342796599,
           -0.9895976120080696,
           -0.9897940404471983,
           -0.9900004235816211,
           -0.9902165555890537,
           -0.9904422210640863,
           -0.9906771952517577,
           -0.9909212442906414,
           -0.9911741254650993,
           -0.9914355874663537,
           -0.9917053706620199,
           -0.9919832073737246,
           -0.9922688221624414,
           -0.9925619321211568,
           -0.9928622471744778,
           -0.9931694703847901,
           -0.9934832982645656,
           -0.9938034210944224,
           -0.99412952324653,
           -0.9944612835129537,
           -0.994798375438533,
           -0.9951404676578892,
           -0.9954872242361468,
           -0.9958383050129731,
           -0.9961933659495243,
           -0.9965520594778992,
           -0.996914034852702,
           -0.9972789385043175,
           -0.9976464143935083,
           -0.9980161043669451,
           -0.9983876485132953,
           -0.9987606855194824,
           -0.9991348530267588,
           -0.9995097879862211,
           -0.9998851270134115,
           -1.000260506741658,
           -1.0006355641738123,
           -1.0010099370320462,
           -1.0013832641053864,
           -1.0017551855946627,
           -1.0021253434545654,
           -1.0024933817325083,
           -1.0028589469040028,
           -1.0032216882042622,
           -1.0035812579557581,
           -1.0039373118914654,
           -1.0042895094735347,
           -1.004637514207147,
           -1.0049809939493095,
           -1.0053196212123583,
           -1.0056530734619533,
           -1.0059810334093435,
           -1.0063031892977017,
           -1.0066192351823327,
           -1.006928871204565,
           -1.0072318038591463,
           -1.0075277462549703,
           -1.0078164183689733,
           -1.0080975472930396,
           -1.008370867473773,
           -1.0086361209449868,
           -1.0088930575527812,
           -1.0091414351730834,
           -1.0093810199215232,
           -1.0096115863555368,
           -1.0098329176685883,
           -1.0100448058764095,
           -1.010247051995161,
           -1.0104394662114249,
           -1.0106218680439518,
           -1.0107940864970741,
           -1.0109559602057225,
           -1.0111073375719717,
           -1.011248076893054,
           -1.0113780464807893,
           -1.0114971247723659,
           -1.0116052004324374,
           -1.011702172446481,
           -1.0117879502053837,
           -1.011862453581218,
           -1.0119256129941743,
           -1.011977369470628,
           -1.012017674692309,
           -1.0120464910365605,
           -1.0120637916076674
          ],
          [
           -1.0173647517777364,
           -1.0173564954743815,
           -1.0173317341499521,
           -1.0172904905554738,
           -1.017232802589718,
           -1.017158723269795,
           -1.0170683206899969,
           -1.0169616779688861,
           -1.016838893184642,
           -1.0167000792986798,
           -1.0165453640675448,
           -1.016374889943106,
           -1.0161888139610575,
           -1.015987307617753,
           -1.0157705567353934,
           -1.0155387613155924,
           -1.0152921353813495,
           -1.0150309068074646,
           -1.0147553171394266,
           -1.0144656214008212,
           -1.0141620878892996,
           -1.01384499796116,
           -1.0135146458045958,
           -1.0131713382016774,
           -1.0128153942791247,
           -1.0124471452479562,
           -1.0120669341320851,
           -1.01167511548596,
           -1.0112720551013392,
           -1.0108581297033072,
           -1.0104337266356478,
           -1.009999243535693,
           -1.0095550879987831,
           -1.0091016772324823,
           -1.0086394377006986,
           -1.0081688047578787,
           -1.0076902222734514,
           -1.0072041422467084,
           -1.006711024412326,
           -1.0062113358367415,
           -1.0057055505056103,
           -1.005194148902591,
           -1.0046776175797123,
           -1.0041564487195884,
           -1.0036311396897812,
           -1.0031021925895982,
           -1.0025701137896532,
           -1.0020354134645169,
           -1.0014986051188133,
           -1.0009602051071214,
           -1.0004207321480718,
           -0.9998807068330302,
           -0.9993406511297905,
           -0.9988010878817043,
           -0.9982625403026995,
           -0.9977255314686531,
           -0.9971905838055957,
           -0.9966582185752523,
           -0.996128955358426,
           -0.9956033115367577,
           -0.9950818017734018,
           -0.9945649374931794,
           -0.994053226362776,
           -0.9935471717715716,
           -0.9930472723136985,
           -0.9925540212719338,
           -0.9920679061040502,
           -0.9915894079322465,
           -0.9911190010363011,
           -0.9906571523510913,
           -0.9902043209691282,
           -0.9897609576487653,
           -0.9893275043287415,
           -0.9889043936497189,
           -0.9884920484834837,
           -0.9880908814704678,
           -0.9877012945662611,
           -0.9873236785977663,
           -0.9869584128296525,
           -0.9866058645417575,
           -0.9862663886180753,
           -0.985940327147957,
           -0.98562800904015,
           -0.9853297496502714,
           -0.9850458504223146,
           -0.9847765985447582,
           -0.9845222666218356,
           -0.9842831123605003,
           -0.984059378273605,
           -0.9838512913997847,
           -0.9836590630405152,
           -0.9834828885147863,
           -0.9833229469318119,
           -0.9831794009821588,
           -0.9830523967476568,
           -0.982942063530417,
           -0.9828485137012549,
           -0.9827718425677819,
           -0.9827121282623962,
           -0.9826694316503672,
           -0.9826437962581811,
           -0.9826352482222636,
           -0.982643796258181,
           -0.9826694316503675,
           -0.9827121282623962,
           -0.982771842567782,
           -0.982848513701255,
           -0.982942063530417,
           -0.983052396747657,
           -0.983179400982159,
           -0.983322946931812,
           -0.9834828885147864,
           -0.9836590630405152,
           -0.9838512913997849,
           -0.9840593782736051,
           -0.9842831123605007,
           -0.9845222666218358,
           -0.9847765985447587,
           -0.985045850422315,
           -0.9853297496502716,
           -0.9856280090401504,
           -0.9859403271479575,
           -0.9862663886180756,
           -0.9866058645417579,
           -0.9869584128296527,
           -0.9873236785977667,
           -0.9877012945662615,
           -0.9880908814704682,
           -0.988492048483484,
           -0.9889043936497195,
           -0.9893275043287418,
           -0.9897609576487658,
           -0.9902043209691287,
           -0.9906571523510918,
           -0.9911190010363017,
           -0.9915894079322468,
           -0.9920679061040507,
           -0.9925540212719344,
           -0.9930472723136989,
           -0.9935471717715723,
           -0.9940532263627767,
           -0.9945649374931801,
           -0.9950818017734023,
           -0.9956033115367582,
           -0.9961289553584265,
           -0.9966582185752529,
           -0.9971905838055961,
           -0.9977255314686535,
           -0.9982625403027002,
           -0.9988010878817047,
           -0.9993406511297911,
           -0.9998807068330309,
           -1.0004207321480723,
           -1.0009602051071218,
           -1.0014986051188137,
           -1.0020354134645175,
           -1.0025701137896537,
           -1.0031021925895989,
           -1.0036311396897817,
           -1.0041564487195889,
           -1.0046776175797125,
           -1.0051941489025915,
           -1.0057055505056107,
           -1.006211335836742,
           -1.0067110244123265,
           -1.0072041422467088,
           -1.0076902222734518,
           -1.0081688047578792,
           -1.008639437700699,
           -1.0091016772324828,
           -1.0095550879987838,
           -1.0099992435356935,
           -1.0104337266356485,
           -1.0108581297033077,
           -1.0112720551013397,
           -1.0116751154859605,
           -1.0120669341320858,
           -1.0124471452479566,
           -1.0128153942791251,
           -1.0131713382016776,
           -1.0135146458045963,
           -1.0138449979611601,
           -1.0141620878893,
           -1.0144656214008216,
           -1.0147553171394266,
           -1.0150309068074646,
           -1.0152921353813498,
           -1.0155387613155926,
           -1.0157705567353938,
           -1.0159873076177532,
           -1.0161888139610573,
           -1.0163748899431062,
           -1.016545364067545,
           -1.0167000792986798,
           -1.0168388931846422,
           -1.0169616779688861,
           -1.017068320689997,
           -1.0171587232697947,
           -1.0172328025897175,
           -1.0172904905554738,
           -1.0173317341499521,
           -1.0173564954743817
          ],
          [
           -1.0236105794363932,
           -1.0235994219534166,
           -1.0235659595693036,
           -1.0235102224713504,
           -1.0234322609478697,
           -1.023332145352418,
           -1.0232099660537055,
           -1.0230658333711784,
           -1.0228998774962654,
           -1.022712248399279,
           -1.0225031157219524,
           -1.0222726686556023,
           -1.022021115804897,
           -1.0217486850372166,
           -1.0214556233175804,
           -1.0211421965291365,
           -1.0208086892791806,
           -1.0204554046906995,
           -1.020082664179419,
           -1.01969080721634,
           -1.0192801910757576,
           -1.0188511905687496,
           -1.0184041977621339,
           -1.0179396216828884,
           -1.0174578880080474,
           -1.0169594387400764,
           -1.0164447318677454,
           -1.0159142410125261,
           -1.0153684550605444,
           -1.0148078777801304,
           -1.0142330274250138,
           -1.0136444363232346,
           -1.013042650451835,
           -1.0124282289974231,
           -1.011801743902708,
           -1.011163779399123,
           -1.010514931525665,
           -1.0098558076340975,
           -1.0091870258806834,
           -1.008509214704632,
           -1.0078230122934568,
           -1.0071290660354797,
           -1.0064280319597116,
           -1.0057205741633901,
           -1.0050073642274573,
           -1.0042890806202949,
           -1.0035664080900593,
           -1.0028400370459776,
           -1.0021106629290026,
           -1.0013789855722433,
           -1.0006457085516194,
           -0.9999115385272196,
           -0.9991771845758634,
           -0.9984433575154067,
           -0.9977107692213539,
           -0.9969801319363691,
           -0.9962521575733155,
           -0.9955275570124731,
           -0.9948070393936226,
           -0.9940913114037087,
           -0.9933810765608262,
           -0.9926770344953015,
           -0.9919798802286721,
           -0.9912903034513877,
           -0.9906089878000949,
           -0.9899366101353786,
           -0.9892738398208685,
           -0.9886213380046391,
           -0.9879797569038474,
           -0.987349739093582,
           -0.9867319168009089,
           -0.9861269112051123,
           -0.9855353317451548,
           -0.984957775435377,
           -0.9843948261904809,
           -0.983847054160834,
           -0.9833150150791518,
           -0.9827992496195994,
           -0.9823002827703666,
           -0.98181862322076,
           -0.9813547627638464,
           -0.9809091757156781,
           -0.9804823183521123,
           -0.9800746283642193,
           -0.9796865243332606,
           -0.9793184052261886,
           -0.978970649912598,
           -0.9786436167040264,
           -0.9783376429164745,
           -0.9780530444569746,
           -0.9777901154350037,
           -0.9775491277994902,
           -0.9773303310021315,
           -0.9771339516876738,
           -0.9769601934117788,
           -0.9768092363870331,
           -0.9766812372576132,
           -0.9765763289030596,
           -0.9764946202715563,
           -0.9764361962430593,
           -0.9764011175225454,
           -0.9763894205636069,
           -0.9764011175225455,
           -0.9764361962430594,
           -0.9764946202715565,
           -0.9765763289030596,
           -0.9766812372576136,
           -0.9768092363870333,
           -0.9769601934117789,
           -0.977133951687674,
           -0.9773303310021317,
           -0.9775491277994904,
           -0.9777901154350038,
           -0.9780530444569749,
           -0.9783376429164747,
           -0.9786436167040266,
           -0.9789706499125984,
           -0.9793184052261893,
           -0.9796865243332611,
           -0.9800746283642198,
           -0.9804823183521127,
           -0.9809091757156785,
           -0.9813547627638467,
           -0.9818186232207606,
           -0.9823002827703672,
           -0.9827992496195999,
           -0.9833150150791522,
           -0.9838470541608346,
           -0.9843948261904814,
           -0.9849577754353778,
           -0.9855353317451554,
           -0.9861269112051129,
           -0.9867319168009094,
           -0.9873497390935828,
           -0.9879797569038479,
           -0.9886213380046397,
           -0.9892738398208691,
           -0.9899366101353793,
           -0.9906089878000955,
           -0.9912903034513882,
           -0.9919798802286728,
           -0.9926770344953025,
           -0.993381076560827,
           -0.9940913114037093,
           -0.9948070393936234,
           -0.9955275570124738,
           -0.9962521575733162,
           -0.9969801319363699,
           -0.9977107692213546,
           -0.9984433575154076,
           -0.9991771845758639,
           -0.9999115385272203,
           -1.00064570855162,
           -1.001378985572244,
           -1.0021106629290033,
           -1.0028400370459785,
           -1.0035664080900601,
           -1.0042890806202958,
           -1.0050073642274582,
           -1.0057205741633908,
           -1.0064280319597123,
           -1.0071290660354806,
           -1.0078230122934575,
           -1.0085092147046326,
           -1.0091870258806843,
           -1.0098558076340982,
           -1.0105149315256656,
           -1.0111637793991235,
           -1.0118017439027085,
           -1.0124282289974238,
           -1.013042650451836,
           -1.0136444363232353,
           -1.0142330274250142,
           -1.0148078777801306,
           -1.015368455060545,
           -1.0159142410125266,
           -1.016444731867746,
           -1.016959438740077,
           -1.017457888008048,
           -1.0179396216828887,
           -1.018404197762134,
           -1.0188511905687503,
           -1.019280191075758,
           -1.0196908072163404,
           -1.0200826641794194,
           -1.0204554046907,
           -1.0208086892791808,
           -1.0211421965291367,
           -1.0214556233175807,
           -1.0217486850372168,
           -1.0220211158048975,
           -1.0222726686556025,
           -1.0225031157219526,
           -1.0227122483992792,
           -1.0228998774962659,
           -1.0230658333711786,
           -1.0232099660537062,
           -1.023332145352418,
           -1.0234322609478694,
           -1.0235102224713504,
           -1.023565959569304,
           -1.023599421953417
          ],
          [
           -1.030801000800334,
           -1.0307865469009319,
           -1.0307431979705217,
           -1.0306709923043307,
           -1.0305699937005346,
           -1.0304402914194308,
           -1.0302820001262583,
           -1.0300952598176234,
           -1.029880235731498,
           -1.0296371182407422,
           -1.0293661227300959,
           -1.029067489456578,
           -1.0287414833932258,
           -1.0283883940560907,
           -1.0280085353144177,
           -1.0276022451839142,
           -1.0271698856030167,
           -1.0267118421920525,
           -1.026228523995207,
           -1.0257203632051743,
           -1.0251878148704001,
           -1.024631356584795,
           -1.0240514881598208,
           -1.0234487312788276,
           -1.0228236291335502,
           -1.0221767460426436,
           -1.0215086670521676,
           -1.0208199975179193,
           -1.0201113626695255,
           -1.0193834071562131,
           -1.0186367945741825,
           -1.0178722069755222,
           -1.0170903443586163,
           -1.0162919241400052,
           -1.015477680607673,
           -1.014648364355767,
           -1.0138047417007516,
           -1.0129475940790351,
           -1.012077717426123,
           -1.0111959215373776,
           -1.0103030294104853,
           -1.009399876569768,
           -1.0084873103724956,
           -1.0075661892973904,
           -1.006637382215555,
           -1.0057017676440747,
           -1.004760232982597,
           -1.00381367373322,
           -1.0028629927040609,
           -1.0019090991969297,
           -1.000952908179557,
           -0.9999953394428852,
           -0.9990373167439743,
           -0.9980797669351175,
           -0.9971236190798111,
           -0.9961698035562815,
           -0.9952192511493068,
           -0.9942728921311383,
           -0.9933316553323661,
           -0.9923964672036341,
           -0.9914682508691544,
           -0.9905479251730327,
           -0.9896364037194556,
           -0.9887345939078556,
           -0.9878433959642071,
           -0.9869637019696699,
           -0.9860963948878273,
           -0.985242347591832,
           -0.9844024218927996,
           -0.9835774675708439,
           -0.9827683214101804,
           -0.981975806239766,
           -0.9812007299809726,
           -0.9804438847038248,
           -0.9797060456933595,
           -0.9789879705276809,
           -0.9782903981693147,
           -0.9776140480714653,
           -0.9769596193007988,
           -0.9763277896783744,
           -0.9757192149403464,
           -0.9751345279200496,
           -0.9745743377530772,
           -0.9740392291069303,
           -0.9735297614368067,
           -0.9730464682690597,
           -0.9725898565138247,
           -0.9721604058082749,
           -0.9717585678919116,
           -0.9713847660152536,
           -0.9710393943832245,
           -0.9707228176344745,
           -0.9704353703578121,
           -0.970177356646834,
           -0.96994904969378,
           -0.9697506914235436,
           -0.9695824921686877,
           -0.9694446303862251,
           -0.9693372524168307,
           -0.9692604722870456,
           -0.9692143715549503,
           -0.9691989991996659,
           -0.9692143715549504,
           -0.9692604722870456,
           -0.9693372524168307,
           -0.9694446303862253,
           -0.9695824921686877,
           -0.969750691423544,
           -0.9699490496937804,
           -0.9701773566468342,
           -0.9704353703578125,
           -0.9707228176344751,
           -0.9710393943832248,
           -0.971384766015254,
           -0.971758567891912,
           -0.9721604058082753,
           -0.9725898565138252,
           -0.9730464682690602,
           -0.9735297614368074,
           -0.9740392291069307,
           -0.9745743377530778,
           -0.9751345279200503,
           -0.975719214940347,
           -0.976327789678375,
           -0.9769596193007994,
           -0.9776140480714659,
           -0.9782903981693154,
           -0.9789879705276818,
           -0.9797060456933603,
           -0.9804438847038257,
           -0.9812007299809733,
           -0.9819758062397668,
           -0.9827683214101812,
           -0.9835774675708447,
           -0.9844024218928006,
           -0.9852423475918329,
           -0.9860963948878284,
           -0.9869637019696708,
           -0.9878433959642081,
           -0.9887345939078563,
           -0.9896364037194564,
           -0.9905479251730336,
           -0.9914682508691552,
           -0.9923964672036348,
           -0.9933316553323672,
           -0.9942728921311395,
           -0.9952192511493076,
           -0.9961698035562824,
           -0.997123619079812,
           -0.9980797669351184,
           -0.9990373167439753,
           -0.9999953394428861,
           -1.0009529081795578,
           -1.0019090991969308,
           -1.002862992704062,
           -1.0038136737332208,
           -1.0047602329825984,
           -1.0057017676440754,
           -1.0066373822155559,
           -1.0075661892973913,
           -1.0084873103724965,
           -1.009399876569769,
           -1.0103030294104862,
           -1.0111959215373785,
           -1.0120777174261242,
           -1.0129475940790362,
           -1.0138047417007527,
           -1.0146483643557678,
           -1.015477680607674,
           -1.0162919241400061,
           -1.0170903443586174,
           -1.0178722069755228,
           -1.018636794574183,
           -1.019383407156214,
           -1.0201113626695264,
           -1.02081999751792,
           -1.0215086670521683,
           -1.0221767460426445,
           -1.0228236291335508,
           -1.0234487312788283,
           -1.0240514881598213,
           -1.0246313565847958,
           -1.0251878148704006,
           -1.0257203632051748,
           -1.0262285239952071,
           -1.026711842192053,
           -1.0271698856030167,
           -1.0276022451839146,
           -1.028008535314418,
           -1.0283883940560912,
           -1.0287414833932262,
           -1.0290674894565786,
           -1.029366122730096,
           -1.0296371182407424,
           -1.0298802357314982,
           -1.0300952598176234,
           -1.0302820001262585,
           -1.0304402914194308,
           -1.0305699937005346,
           -1.0306709923043307,
           -1.0307431979705215,
           -1.030786546900932
          ],
          [
           -1.038929059601276,
           -1.0389109343601213,
           -1.03885657427531,
           -1.0387660262540137,
           -1.0386393684455644,
           -1.0384767101974919,
           -1.0382781919939172,
           -1.0380439853762418,
           -1.037774292846051,
           -1.0374693477501453,
           -1.0371294141475857,
           -1.0367547866586264,
           -1.0363457902953952,
           -1.0359027802741658,
           -1.0354261418090485,
           -1.0349162898869162,
           -1.0343736690233678,
           -1.033798752999516,
           -1.033192044579379,
           -1.0325540752076412,
           -1.0318854046875439,
           -1.031186620838644,
           -1.0304583391341935,
           -1.0297012023178638,
           -1.0289158799995475,
           -1.0281030682299626,
           -1.0272634890537784,
           -1.0263978900409911,
           -1.0255070437962621,
           -1.0245917474459574,
           -1.023652822102605,
           -1.0226911123065203,
           -1.0217074854443347,
           -1.0207028311441924,
           -1.0196780606473828,
           -1.0186341061561945,
           -1.0175719201577988,
           -1.0164924747239876,
           -1.0153967607866141,
           -1.014285787388618,
           -1.013160580910536,
           -1.0120221842724422,
           -1.010871656111292,
           -1.0097100699336785,
           -1.008538513244068,
           -1.0073580866486058,
           -1.0061699029346483,
           -1.0049750861262219,
           -1.0037747705156665,
           -1.0025700996717766,
           -1.001362225424821,
           -1.0001523068288793,
           -0.9989415091020104,
           -0.9977310025448236,
           -0.9965219614381162,
           -0.9953155629203024,
           -0.994112985845441,
           -0.9929154096227549,
           -0.9917240130386096,
           -0.9905399730620124,
           -0.9893644636347684,
           -0.9881986544475273,
           -0.9870437097030352,
           -0.9859007868679939,
           -0.9847710354150255,
           -0.983655595556315,
           -0.9825555969705985,
           -0.9814721575252509,
           -0.9804063819952973,
           -0.9793593607812675,
           -0.97833216862788,
           -0.9773258633456146,
           -0.9763414845373097,
           -0.9753800523319766,
           -0.9744425661280812,
           -0.9735300033486055,
           -0.9726433182102346,
           -0.971783440509065,
           -0.9709512744252538,
           -0.9701476973490573,
           -0.9693735587307183,
           -0.9686296789566702,
           -0.9679168482545238,
           -0.9672358256292833,
           -0.9665873378332268,
           -0.9659720783718414,
           -0.9653907065481722,
           -0.9648438465478791,
           -0.9643320865672428,
           -0.9638559779862816,
           -0.9634160345890581,
           -0.9630127318331594,
           -0.9626465061702385,
           -0.9623177544193801,
           -0.9620268331949416,
           -0.9617740583903902,
           -0.9615597047195117,
           -0.9613840053162309,
           -0.9612471513941276,
           -0.9611492919665738,
           -0.9610905336282627,
           -0.9610709403987242,
           -0.9610905336282627,
           -0.961149291966574,
           -0.9612471513941279,
           -0.9613840053162311,
           -0.9615597047195119,
           -0.9617740583903905,
           -0.9620268331949419,
           -0.9623177544193804,
           -0.962646506170239,
           -0.9630127318331596,
           -0.9634160345890584,
           -0.9638559779862822,
           -0.9643320865672433,
           -0.9648438465478796,
           -0.9653907065481729,
           -0.9659720783718422,
           -0.9665873378332275,
           -0.967235825629284,
           -0.9679168482545246,
           -0.9686296789566711,
           -0.969373558730719,
           -0.970147697349058,
           -0.9709512744252545,
           -0.9717834405090657,
           -0.9726433182102355,
           -0.9735300033486065,
           -0.9744425661280822,
           -0.9753800523319776,
           -0.9763414845373108,
           -0.9773258633456156,
           -0.9783321686278811,
           -0.9793593607812686,
           -0.9804063819952982,
           -0.9814721575252519,
           -0.9825555969705996,
           -0.983655595556316,
           -0.9847710354150269,
           -0.9859007868679951,
           -0.9870437097030363,
           -0.9881986544475286,
           -0.9893644636347695,
           -0.9905399730620136,
           -0.9917240130386107,
           -0.9929154096227559,
           -0.9941129858454422,
           -0.9953155629203037,
           -0.9965219614381176,
           -0.9977310025448247,
           -0.9989415091020116,
           -1.0001523068288805,
           -1.0013622254248218,
           -1.0025700996717777,
           -1.0037747705156679,
           -1.0049750861262234,
           -1.0061699029346494,
           -1.007358086648607,
           -1.0085385132440692,
           -1.0097100699336796,
           -1.0108716561112931,
           -1.0120221842724435,
           -1.013160580910537,
           -1.014285787388619,
           -1.0153967607866152,
           -1.0164924747239887,
           -1.0175719201577997,
           -1.0186341061561954,
           -1.0196780606473836,
           -1.0207028311441935,
           -1.0217074854443358,
           -1.0226911123065212,
           -1.0236528221026062,
           -1.0245917474459583,
           -1.0255070437962632,
           -1.026397890040992,
           -1.0272634890537795,
           -1.0281030682299632,
           -1.0289158799995484,
           -1.0297012023178644,
           -1.0304583391341942,
           -1.0311866208386447,
           -1.0318854046875445,
           -1.0325540752076419,
           -1.0331920445793794,
           -1.0337987529995165,
           -1.0343736690233685,
           -1.0349162898869169,
           -1.0354261418090487,
           -1.0359027802741665,
           -1.0363457902953956,
           -1.0367547866586269,
           -1.0371294141475862,
           -1.0374693477501458,
           -1.0377742928460514,
           -1.038043985376242,
           -1.0382781919939175,
           -1.0384767101974917,
           -1.0386393684455641,
           -1.0387660262540137,
           -1.0388565742753102,
           -1.0389109343601217
          ],
          [
           -1.0479868924672706,
           -1.0479647429965993,
           -1.0478983132053077,
           -1.0477876589466302,
           -1.0476328732795106,
           -1.0474340864238818,
           -1.047191465697963,
           -1.046905215437481,
           -1.046575576896684,
           -1.046202828131013,
           -1.0457872838612428,
           -1.0453292953188975,
           -1.0448292500727097,
           -1.0442875718358728,
           -1.0437047202538057,
           -1.0430811906721287,
           -1.0424175138845246,
           -1.041714255860134,
           -1.0409720174501125,
           -1.0401914340729599,
           -1.0393731753782038,
           -1.0385179448880029,
           -1.0376264796162245,
           -1.0366995496645197,
           -1.03573795779492,
           -1.034742538978446,
           -1.0337141599192299,
           -1.0326537185536209,
           -1.0315621435237452,
           -1.0304403936249915,
           -1.0292894572268676,
           -1.0281103516666998,
           -1.0269041226156266,
           -1.025671843416348,
           -1.024414614392108,
           -1.0231335621263797,
           -1.0218298387127562,
           -1.0205046209745523,
           -1.0191591096536496,
           -1.0177945285681456,
           -1.0164121237383896,
           -1.0150131624810277,
           -1.0135989324707169,
           -1.0121707407692069,
           -1.0107299128215481,
           -1.0092777914192197,
           -1.0078157356300497,
           -1.0063451196948507,
           -1.0048673318907662,
           -1.0033837733614042,
           -1.0018958569139063,
           -1.000405005783197,
           -0.9989126523637387,
           -0.9974202369092284,
           -0.9959292062007649,
           -0.994441012184127,
           -0.992957110576923,
           -0.9914789594464803,
           -0.9900080177594746,
           -0.988545743904425,
           -0.9870935941883081,
           -0.9856530213086885,
           -0.9842254728028917,
           -0.9828123894758906,
           -0.9814152038087217,
           -0.9800353383493842,
           -0.9786742040883242,
           -0.9773331988207493,
           -0.9760137054981554,
           -0.9747170905715975,
           -0.9734447023293641,
           -0.9721978692318503,
           -0.9709778982465573,
           -0.9697860731862595,
           -0.9686236530535011,
           -0.9674918703946872,
           -0.966391929667135,
           -0.9653250056225305,
           -0.9642922417103188,
           -0.9632947485046158,
           -0.962333602158279,
           -0.9614098428878078,
           -0.9605244734927729,
           -0.9596784579134685,
           -0.9588727198304776,
           -0.9581081413098089,
           -0.9573855614972185,
           -0.9567057753652665,
           -0.9560695325165773,
           -0.9554775360466772,
           -0.9549304414696537,
           -0.9544288557097667,
           -0.9539733361619709,
           -0.9535643898241503,
           -0.9532024725036818,
           -0.9528879881007433,
           -0.9526212879705657,
           -0.952402670366609,
           -0.9522323799663981,
           -0.9521106074815056,
           -0.9520374893529151,
           -0.9520131075327295,
           -0.9520374893529151,
           -0.9521106074815057,
           -0.9522323799663983,
           -0.9524026703666093,
           -0.9526212879705658,
           -0.9528879881007437,
           -0.9532024725036822,
           -0.9535643898241507,
           -0.9539733361619714,
           -0.9544288557097672,
           -0.9549304414696541,
           -0.9554775360466776,
           -0.9560695325165781,
           -0.9567057753652671,
           -0.9573855614972192,
           -0.9581081413098098,
           -0.9588727198304785,
           -0.9596784579134693,
           -0.9605244734927739,
           -0.9614098428878088,
           -0.96233360215828,
           -0.9632947485046168,
           -0.9642922417103197,
           -0.9653250056225315,
           -0.9663919296671362,
           -0.9674918703946885,
           -0.9686236530535022,
           -0.9697860731862608,
           -0.9709778982465584,
           -0.9721978692318515,
           -0.9734447023293654,
           -0.9747170905715989,
           -0.9760137054981568,
           -0.9773331988207506,
           -0.9786742040883257,
           -0.9800353383493855,
           -0.9814152038087232,
           -0.9828123894758919,
           -0.9842254728028931,
           -0.9856530213086899,
           -0.9870935941883094,
           -0.9885457439044263,
           -0.9900080177594761,
           -0.9914789594464817,
           -0.9929571105769243,
           -0.9944410121841284,
           -0.9959292062007665,
           -0.99742023690923,
           -0.9989126523637402,
           -1.0004050057831986,
           -1.001895856913908,
           -1.0033837733614057,
           -1.0048673318907677,
           -1.0063451196948523,
           -1.0078157356300514,
           -1.009277791419221,
           -1.0107299128215494,
           -1.0121707407692084,
           -1.0135989324707182,
           -1.0150131624810292,
           -1.016412123738391,
           -1.0177945285681471,
           -1.019159109653651,
           -1.0205046209745539,
           -1.0218298387127578,
           -1.0231335621263808,
           -1.0244146143921091,
           -1.0256718434163494,
           -1.0269041226156277,
           -1.0281103516667012,
           -1.0292894572268687,
           -1.0304403936249926,
           -1.0315621435237465,
           -1.0326537185536215,
           -1.0337141599192312,
           -1.034742538978447,
           -1.0357379577949208,
           -1.0366995496645208,
           -1.0376264796162251,
           -1.0385179448880038,
           -1.0393731753782047,
           -1.0401914340729608,
           -1.0409720174501131,
           -1.0417142558601347,
           -1.0424175138845253,
           -1.0430811906721293,
           -1.0437047202538061,
           -1.0442875718358735,
           -1.04482925007271,
           -1.0453292953188977,
           -1.0457872838612434,
           -1.0462028281310134,
           -1.0465755768966842,
           -1.046905215437481,
           -1.0471914656979635,
           -1.0474340864238818,
           -1.0476328732795106,
           -1.0477876589466304,
           -1.0478983132053081,
           -1.0479647429965997
          ],
          [
           -1.0579657365300115,
           -1.0579392333990898,
           -1.0578597456646581,
           -1.0577273382931753,
           -1.0575421195336017,
           -1.0573042408746167,
           -1.057013896984602,
           -1.0566713256342428,
           -1.0562768076015792,
           -1.0558306665593078,
           -1.0553332689440744,
           -1.0547850238074845,
           -1.0541863826485056,
           -1.0535378392269001,
           -1.0528399293573012,
           -1.0520932306834918,
           -1.0512983624324235,
           -1.0504559851474657,
           -1.0495668004003558,
           -1.0486315504812593,
           -1.0476510180663503,
           -1.0466260258622546,
           -1.0455574362266917,
           -1.0444461507646048,
           -1.0432931098990463,
           -1.0420992924160524,
           -1.0408657149827156,
           -1.0395934316376407,
           -1.0382835332529396,
           -1.0369371469669086,
           -1.0355554355865018,
           -1.0341395969587093,
           -1.032690863309925,
           -1.0312105005523893,
           -1.0296998075567732,
           -1.0281601153899806,
           -1.026592786517238,
           -1.024999213967548,
           -1.0233808204615984,
           -1.0217390575012286,
           -1.0200754044195837,
           -1.0183913673911036,
           -1.016688478400543,
           -1.014968294170243,
           -1.0132323950449376,
           -1.0114823838334208,
           -1.00971988460647,
           -1.0079465414504944,
           -1.0061640171764492,
           -1.0043739919836503,
           -1.0025781620782215,
           -1.0007782382460098,
           -0.9989759443799225,
           -0.9971730159617646,
           -0.9953711984987903,
           -0.9935722459153277,
           -0.9917779188999885,
           -0.9899899832091388,
           -0.9882102079274827,
           -0.986440363686787,
           -0.9846822208439683,
           -0.9829375476199668,
           -0.981208108201024,
           -0.9794956608042109,
           -0.9778019557092532,
           -0.9761287332589409,
           -0.9744777218306191,
           -0.972850635781504,
           -0.9712491733707794,
           -0.9696750146616823,
           -0.9681298194069897,
           -0.9666152249215726,
           -0.9651328439458788,
           -0.9636842625044385,
           -0.9622710377636885,
           -0.9608946958935989,
           -0.9595567299377847,
           -0.9582585976969414,
           -0.9570017196306038,
           -0.955787476782365,
           -0.9546172087338021,
           -0.9534922115924553,
           -0.9524137360192796,
           -0.9513829853010258,
           -0.9504011134730427,
           -0.9494692234979699,
           -0.9485883655057684,
           -0.947759535100463,
           -0.946983671738878,
           -0.9462616571865263,
           -0.9455943140556509,
           -0.9449824044302344,
           -0.944426628582581,
           -0.9439276237858225,
           -0.9434859632264305,
           -0.943102155020525,
           -0.9427766413374296,
           -0.9425097976335903,
           -0.9423019319995939,
           -0.9421532846226445,
           -0.9420640273664412,
           -0.9420342634699886,
           -0.9420640273664412,
           -0.9421532846226447,
           -0.942301931999594,
           -0.9425097976335904,
           -0.9427766413374301,
           -0.9431021550205253,
           -0.943485963226431,
           -0.9439276237858231,
           -0.9444266285825816,
           -0.944982404430235,
           -0.9455943140556515,
           -0.946261657186527,
           -0.9469836717388788,
           -0.9477595351004637,
           -0.9485883655057692,
           -0.9494692234979709,
           -0.9504011134730439,
           -0.9513829853010269,
           -0.9524137360192808,
           -0.9534922115924565,
           -0.9546172087338031,
           -0.9557874767823662,
           -0.9570017196306051,
           -0.9582585976969427,
           -0.9595567299377861,
           -0.9608946958936003,
           -0.9622710377636899,
           -0.9636842625044401,
           -0.9651328439458802,
           -0.9666152249215744,
           -0.9681298194069914,
           -0.9696750146616838,
           -0.9712491733707812,
           -0.9728506357815054,
           -0.9744777218306209,
           -0.9761287332589426,
           -0.9778019557092551,
           -0.9794956608042126,
           -0.9812081082010258,
           -0.9829375476199684,
           -0.9846822208439703,
           -0.9864403636867889,
           -0.9882102079274846,
           -0.9899899832091406,
           -0.9917779188999901,
           -0.9935722459153294,
           -0.9953711984987921,
           -0.9971730159617663,
           -0.9989759443799242,
           -1.0007782382460115,
           -1.0025781620782233,
           -1.004373991983652,
           -1.006164017176451,
           -1.0079465414504964,
           -1.0097198846064719,
           -1.0114823838334226,
           -1.0132323950449393,
           -1.0149682941702445,
           -1.0166884784005445,
           -1.0183913673911054,
           -1.0200754044195854,
           -1.0217390575012304,
           -1.0233808204616,
           -1.0249992139675497,
           -1.0265927865172397,
           -1.028160115389982,
           -1.0296998075567747,
           -1.0312105005523908,
           -1.0326908633099265,
           -1.0341395969587104,
           -1.035555435586503,
           -1.0369371469669098,
           -1.038283533252941,
           -1.039593431637642,
           -1.040865714982717,
           -1.0420992924160537,
           -1.0432931098990474,
           -1.044446150764606,
           -1.0455574362266926,
           -1.0466260258622557,
           -1.0476510180663516,
           -1.0486315504812604,
           -1.0495668004003567,
           -1.0504559851474666,
           -1.051298362432424,
           -1.0520932306834927,
           -1.0528399293573019,
           -1.053537839226901,
           -1.0541863826485063,
           -1.0547850238074854,
           -1.0553332689440749,
           -1.0558306665593082,
           -1.0562768076015798,
           -1.056671325634243,
           -1.0570138969846026,
           -1.0573042408746167,
           -1.0575421195336014,
           -1.0577273382931758,
           -1.0578597456646583,
           -1.0579392333990902
          ],
          [
           -1.0688559379023412,
           -1.0688247762454626,
           -1.0687313159731957,
           -1.0685756311730739,
           -1.068357845299051,
           -1.068078131133512,
           -1.0677367107339235,
           -1.0673338553639495,
           -1.066869885408815,
           -1.0663451702746582,
           -1.0657601282715488,
           -1.0651152264798143,
           -1.0644109805992565,
           -1.0636479547808053,
           -1.0628267614400837,
           -1.0619480610523393,
           -1.0610125619281214,
           -1.0600210199690414,
           -1.0589742384029168,
           -1.057873067497522,
           -1.056718404252154,
           -1.0555111920661329,
           -1.054252420383344,
           -1.0529431243118546,
           -1.0515843842175963,
           -1.0501773252910673,
           -1.0487231170859412,
           -1.0472229730284457,
           -1.0456781498963104,
           -1.044089947266061,
           -1.0424597069273733,
           -1.040788812263184,
           -1.0390786875942057,
           -1.0373307974864672,
           -1.035546646020469,
           -1.0337277760205217,
           -1.0318757682428088,
           -1.029992240520706,
           -1.0280788468658772,
           -1.0261372765236578,
           -1.024169252981247,
           -1.0221765329272365,
           -1.0201609051610148,
           -1.0181241894506239,
           -1.0160682353376758,
           -1.01399492088797,
           -1.0119061513865324,
           -1.009803857975841,
           -1.0076899962360961,
           -1.0055665447064774,
           -1.00343550334644,
           -1.0012988919362174,
           -0.999158748415834,
           -0.9970171271620745,
           -0.9948760972030272,
           -0.9927377403699913,
           -0.9906041493867361,
           -0.9884774258963133,
           -0.9863596784258416,
           -0.9842530202899454,
           -0.982159567433762,
           -0.980081436216733,
           -0.9780207411386687,
           -0.9759795925098784,
           -0.973960094067491,
           -0.9719643405403993,
           -0.9699944151656162,
           -0.9680523871591753,
           -0.9661403091450591,
           -0.964260214546013,
           -0.9624141149404507,
           -0.9606039973900354,
           -0.9588318217428823,
           -0.957099517917677,
           -0.9554089831743703,
           -0.9537620793774343,
           -0.9521606302580043,
           -0.9506064186815274,
           -0.9491011839278314,
           -0.9476466189907932,
           -0.94624436790501,
           -0.9448960231070939,
           -0.9436031228393659,
           -0.9423671486038675,
           -0.9411895226746916,
           -0.9400716056766876,
           -0.9390146942385927,
           -0.9380200187286011,
           -0.937088741080284,
           -0.9362219527166356,
           -0.9354206725798163,
           -0.9346858452739261,
           -0.9340183393278378,
           -0.9334189455847807,
           -0.9328883757249576,
           -0.9324272609270511,
           -0.9320361506739782,
           -0.9317155117077269,
           -0.931465727137552,
           -0.9312870957051983,
           -0.9311798312102013,
           -0.9311440620976589,
           -0.9311798312102013,
           -0.9312870957051986,
           -0.9314657271375522,
           -0.9317155117077273,
           -0.9320361506739786,
           -0.9324272609270515,
           -0.932888375724958,
           -0.9334189455847813,
           -0.9340183393278386,
           -0.9346858452739267,
           -0.9354206725798172,
           -0.9362219527166363,
           -0.9370887410802848,
           -0.9380200187286021,
           -0.9390146942385938,
           -0.9400716056766888,
           -0.9411895226746929,
           -0.9423671486038687,
           -0.9436031228393674,
           -0.9448960231070954,
           -0.9462443679050114,
           -0.9476466189907945,
           -0.949101183927833,
           -0.9506064186815288,
           -0.9521606302580059,
           -0.9537620793774361,
           -0.9554089831743721,
           -0.9570995179176789,
           -0.9588318217428841,
           -0.9606039973900372,
           -0.9624141149404525,
           -0.964260214546015,
           -0.966140309145061,
           -0.9680523871591772,
           -0.9699944151656184,
           -0.9719643405404013,
           -0.9739600940674932,
           -0.9759795925098803,
           -0.9780207411386708,
           -0.9800814362167352,
           -0.982159567433764,
           -0.9842530202899474,
           -0.9863596784258438,
           -0.9884774258963155,
           -0.9906041493867384,
           -0.9927377403699935,
           -0.9948760972030294,
           -0.9970171271620767,
           -0.9991587484158361,
           -1.0012988919362196,
           -1.003435503346442,
           -1.0055665447064794,
           -1.0076899962360983,
           -1.009803857975843,
           -1.0119061513865344,
           -1.013994920887972,
           -1.016068235337678,
           -1.018124189450626,
           -1.0201609051610165,
           -1.0221765329272383,
           -1.0241692529812492,
           -1.0261372765236596,
           -1.0280788468658792,
           -1.029992240520708,
           -1.0318757682428106,
           -1.0337277760205237,
           -1.035546646020471,
           -1.037330797486469,
           -1.0390786875942075,
           -1.0407888122631856,
           -1.0424597069273749,
           -1.0440899472660625,
           -1.045678149896312,
           -1.0472229730284468,
           -1.048723117085943,
           -1.0501773252910689,
           -1.0515843842175978,
           -1.0529431243118557,
           -1.0542524203833454,
           -1.055511192066134,
           -1.0567184042521554,
           -1.0578730674975234,
           -1.0589742384029177,
           -1.0600210199690425,
           -1.061012561928122,
           -1.0619480610523404,
           -1.0628267614400844,
           -1.0636479547808062,
           -1.0644109805992572,
           -1.0651152264798147,
           -1.0657601282715494,
           -1.0663451702746587,
           -1.0668698854088157,
           -1.0673338553639498,
           -1.0677367107339244,
           -1.0680781311335121,
           -1.068357845299051,
           -1.068575631173074,
           -1.068731315973196,
           -1.068824776245463
          ],
          [
           -1.0806469610177643,
           -1.0806108613329068,
           -1.0805025899699687,
           -1.08032222999781,
           -1.0800699198443438,
           -1.079745853266162,
           -1.0793502793058074,
           -1.0788835022365029,
           -1.0783458814940705,
           -1.0777378315957384,
           -1.0770598220454544,
           -1.0763123772252765,
           -1.0754960762723524,
           -1.074611552940935,
           -1.0736594954488157,
           -1.07264064630751,
           -1.0715558021354492,
           -1.0704058134533774,
           -1.0691915844610906,
           -1.067914072794579,
           -1.0665742892625762,
           -1.0651732975614436,
           -1.06371221396726,
           -1.0621922070038992,
           -1.0606144970858375,
           -1.0589803561343225,
           -1.057291107165509,
           -1.055548123849059,
           -1.0537528300356553,
           -1.0519066992518025,
           -1.0500112541602113,
           -1.0480680659840136,
           -1.0460787538929655,
           -1.0440449843497541,
           -1.0419684704144445,
           -1.0398509710050567,
           -1.0376942901122026,
           -1.0355002759656644,
           -1.0332708201507497,
           -1.0310078566722238,
           -1.0287133609635817,
           -1.0263893488394065,
           -1.0240378753885373,
           -1.0216610338057686,
           -1.0192609541598132,
           -1.0168398020952658,
           -1.0143997774663502,
           -1.0119431129002652,
           -1.0094720722880115,
           -1.0069889492006625,
           -1.0044960652291237,
           -1.0019957682455587,
           -0.9994904305847779,
           -0.996982447144054,
           -0.9944742334000013,
           -0.9919682233413618,
           -0.9894668673167685,
           -0.9869726297968078,
           -0.9844879870499829,
           -0.9820154247324884,
           -0.9795574353920337,
           -0.9771165158863148,
           -0.9746951647171266,
           -0.9722958792815056,
           -0.969921153041747,
           -0.967573472616592,
           -0.9652553147963704,
           -0.9629691434853882,
           -0.9607174065753784,
           -0.9585025327543689,
           -0.9563269282558811,
           -0.9541929735539347,
           -0.952103020009903,
           -0.9500593864778384,
           -0.9480643558754498,
           -0.9461201717284818,
           -0.9442290346967855,
           -0.942393099090903,
           -0.9406144693884873,
           -0.9388951967603576,
           -0.937237275616415,
           -0.9356426401820463,
           -0.934113161115983,
           -0.9326506421808665,
           -0.9312568169780095,
           -0.9299333457579929,
           -0.9286818123188412,
           -0.9275037210035305,
           -0.9264004938085216,
           -0.925373467614873,
           -0.9244238915532608,
           -0.9235529245139199,
           -0.9227616328121342,
           -0.9220509880194137,
           -0.921421864969949,
           -0.9208750399512825,
           -0.9204111890874259,
           -0.9200308869218654,
           -0.919734605207046,
           -0.9195227119060144,
           -0.9193954704109407,
           -0.9193530389822356,
           -0.9193954704109409,
           -0.9195227119060146,
           -0.9197346052070462,
           -0.9200308869218656,
           -0.9204111890874263,
           -0.9208750399512831,
           -0.9214218649699495,
           -0.9220509880194144,
           -0.922761632812135,
           -0.9235529245139208,
           -0.9244238915532617,
           -0.9253734676148739,
           -0.9264004938085227,
           -0.9275037210035317,
           -0.9286818123188425,
           -0.9299333457579941,
           -0.931256816978011,
           -0.9326506421808681,
           -0.9341131611159846,
           -0.935642640182048,
           -0.9372372756164166,
           -0.9388951967603594,
           -0.9406144693884891,
           -0.9423930990909046,
           -0.9442290346967874,
           -0.9461201717284838,
           -0.9480643558754518,
           -0.9500593864778404,
           -0.952103020009905,
           -0.9541929735539367,
           -0.9563269282558833,
           -0.9585025327543711,
           -0.9607174065753806,
           -0.9629691434853905,
           -0.9652553147963726,
           -0.9675734726165943,
           -0.9699211530417495,
           -0.9722958792815081,
           -0.9746951647171291,
           -0.9771165158863174,
           -0.9795574353920362,
           -0.9820154247324911,
           -0.9844879870499854,
           -0.9869726297968103,
           -0.9894668673167709,
           -0.9919682233413645,
           -0.994474233400004,
           -0.9969824471440565,
           -0.9994904305847805,
           -1.0019957682455611,
           -1.0044960652291262,
           -1.006988949200665,
           -1.0094720722880142,
           -1.0119431129002676,
           -1.014399777466353,
           -1.0168398020952683,
           -1.0192609541598157,
           -1.021661033805771,
           -1.0240378753885395,
           -1.026389348839409,
           -1.028713360963584,
           -1.031007856672226,
           -1.0332708201507521,
           -1.0355002759656666,
           -1.037694290112205,
           -1.0398509710050587,
           -1.0419684704144467,
           -1.0440449843497561,
           -1.0460787538929677,
           -1.0480680659840154,
           -1.0500112541602131,
           -1.0519066992518045,
           -1.0537528300356573,
           -1.0555481238490605,
           -1.057291107165511,
           -1.058980356134324,
           -1.060614497085839,
           -1.062192207003901,
           -1.0637122139672612,
           -1.0651732975614452,
           -1.0665742892625776,
           -1.0679140727945806,
           -1.069191584461092,
           -1.0704058134533783,
           -1.0715558021354503,
           -1.072640646307511,
           -1.0736594954488166,
           -1.074611552940936,
           -1.0754960762723533,
           -1.0763123772252772,
           -1.0770598220454553,
           -1.0777378315957393,
           -1.078345881494071,
           -1.0788835022365035,
           -1.079350279305808,
           -1.0797458532661621,
           -1.0800699198443442,
           -1.0803222299978097,
           -1.0805025899699687,
           -1.0806108613329066
          ],
          [
           -1.0933273988229284,
           -1.0932861074695879,
           -1.0931622640035266,
           -1.092955960202624,
           -1.092667349016663,
           -1.0922966445471884,
           -1.0918441220191033,
           -1.0913101177437647,
           -1.0906950290733126,
           -1.089999314345881,
           -1.0892234928212754,
           -1.0883681446066438,
           -1.0874339105715958,
           -1.086421492252149,
           -1.085331651742822,
           -1.0841652115761118,
           -1.082923054588521,
           -1.0816061237722265,
           -1.0802154221113982,
           -1.078752012402094,
           -1.077217017054581,
           -1.0756116178768373,
           -1.0739370558379095,
           -1.072194630809703,
           -1.0703857012856934,
           -1.0685116840749513,
           -1.0665740539697752,
           -1.0645743433851265,
           -1.062514141967963,
           -1.0603950961744604,
           -1.0582189088130107,
           -1.055987338550779,
           -1.053702199381499,
           -1.0513653600520767,
           -1.0489787434454723,
           -1.0465443259172245,
           -1.0440641365828802,
           -1.0415402565534975,
           -1.0389748181162861,
           -1.0363700038573744,
           -1.0337280457235918,
           -1.0310512240200904,
           -1.0283418663405548,
           -1.0256023464266917,
           -1.0228350829536468,
           -1.020042538237954,
           -1.0172272168646115,
           -1.0143916642298691,
           -1.011538464996331,
           -1.0086702414570086,
           -1.0057896518050244,
           -1.0028993883057429,
           -1.0000021753682165,
           -0.9971007675129786,
           -0.994197947233377,
           -0.9912965227478514,
           -0.9883993256407944,
           -0.9855092083899122,
           -0.9826290417783149,
           -0.979761712189923,
           -0.9769101187871779,
           -0.9740771705704784,
           -0.9712657833192575,
           -0.9684788764151419,
           -0.9657193695482036,
           -0.962990179307946,
           -0.9602942156613083,
           -0.9576343783206948,
           -0.9550135530057531,
           -0.9524346076034288,
           -0.9499003882316018,
           -0.947413715212476,
           -0.9449773789627254,
           -0.9425941358082963,
           -0.9402667037326338,
           -0.937997758067995,
           -0.9357899271403903,
           -0.9336457878795579,
           -0.9315678614062158,
           -0.9295586086096501,
           -0.927620425729446,
           -0.9257556399558884,
           -0.9239665050641924,
           -0.9222551970982868,
           -0.9206238101203582,
           -0.9190743520427355,
           -0.9176087405589766,
           -0.9162287991911757,
           -0.9149362534705465,
           -0.9137327272682496,
           -0.9126197392932058,
           -0.9115986997732765,
           -0.9106709073356939,
           -0.9098375461019801,
           -0.9090996830118235,
           -0.9084582653894677,
           -0.9079141187651288,
           -0.9074679449627994,
           -0.9071203204645277,
           -0.9068716950598864,
           -0.9067223907878882,
           -0.9066726011770717,
           -0.9067223907878882,
           -0.9068716950598866,
           -0.907120320464528,
           -0.9074679449627999,
           -0.9079141187651294,
           -0.9084582653894685,
           -0.9090996830118243,
           -0.9098375461019811,
           -0.9106709073356949,
           -0.9115986997732775,
           -0.9126197392932068,
           -0.9137327272682508,
           -0.9149362534705479,
           -0.9162287991911772,
           -0.917608740558978,
           -0.919074352042737,
           -0.92062381012036,
           -0.9222551970982885,
           -0.9239665050641942,
           -0.9257556399558904,
           -0.9276204257294478,
           -0.929558608609652,
           -0.9315678614062178,
           -0.9336457878795599,
           -0.9357899271403924,
           -0.9379977580679972,
           -0.9402667037326361,
           -0.9425941358082986,
           -0.9449773789627277,
           -0.9474137152124785,
           -0.9499003882316045,
           -0.9524346076034313,
           -0.9550135530057559,
           -0.9576343783206972,
           -0.9602942156613113,
           -0.9629901793079488,
           -0.9657193695482065,
           -0.9684788764151446,
           -0.9712657833192604,
           -0.9740771705704812,
           -0.9769101187871808,
           -0.9797617121899259,
           -0.9826290417783178,
           -0.9855092083899152,
           -0.9883993256407971,
           -0.9912965227478543,
           -0.9941979472333801,
           -0.9971007675129817,
           -1.0000021753682193,
           -1.0028993883057458,
           -1.005789651805027,
           -1.0086702414570115,
           -1.011538464996334,
           -1.0143916642298723,
           -1.0172272168646144,
           -1.0200425382379568,
           -1.0228350829536497,
           -1.0256023464266946,
           -1.0283418663405575,
           -1.0310512240200933,
           -1.0337280457235947,
           -1.036370003857377,
           -1.0389748181162888,
           -1.0415402565535,
           -1.0440641365828829,
           -1.0465443259172267,
           -1.0489787434454747,
           -1.0513653600520791,
           -1.0537021993815014,
           -1.0559873385507812,
           -1.0582189088130127,
           -1.0603950961744626,
           -1.0625141419679651,
           -1.0645743433851285,
           -1.0665740539697772,
           -1.0685116840749533,
           -1.0703857012856952,
           -1.0721946308097048,
           -1.073937055837911,
           -1.075611617876839,
           -1.0772170170545827,
           -1.0787520124020957,
           -1.0802154221113998,
           -1.0816061237722279,
           -1.0829230545885222,
           -1.084165211576113,
           -1.0853316517428233,
           -1.0864214922521505,
           -1.0874339105715967,
           -1.0883681446066447,
           -1.089223492821276,
           -1.089999314345882,
           -1.0906950290733133,
           -1.0913101177437647,
           -1.0918441220191042,
           -1.0922966445471889,
           -1.092667349016663,
           -1.0929559602026244,
           -1.093162264003527,
           -1.0932861074695885
          ],
          [
           -1.1068849838132095,
           -1.1068382732235034,
           -1.1066981748214104,
           -1.1064647887065144,
           -1.1061382817064596,
           -1.1057188873693375,
           -1.1052069059528182,
           -1.1046027044097848,
           -1.1039067163701926,
           -1.103119442118793,
           -1.1022414485683019,
           -1.1012733692275078,
           -1.1002159041637687,
           -1.0990698199592381,
           -1.0978359496601182,
           -1.0965151927181258,
           -1.0951085149233013,
           -1.0936169483271816,
           -1.0920415911552832,
           -1.0903836077077405,
           -1.0886442282468445,
           -1.086824748870131,
           -1.0849265313675553,
           -1.0829510030611817,
           -1.0808996566256996,
           -1.0787740498879583,
           -1.0765758056035826,
           -1.0743066112086146,
           -1.0719682185439736,
           -1.0695624435504032,
           -1.067091165931427,
           -1.064556328781678,
           -1.0619599381778329,
           -1.0593040627292136,
           -1.0565908330849647,
           -1.053822441394566,
           -1.0510011407182627,
           -1.0481292443838475,
           -1.0452091252860634,
           -1.0422432151247354,
           -1.0392340035775873,
           -1.036184037403542,
           -1.0330959194721638,
           -1.0299723077147562,
           -1.026815913992509,
           -1.0236295028769598,
           -1.0204158903379443,
           -1.0171779423341134,
           -1.0139185733010392,
           -1.0106407445318788,
           -1.0073474624455525,
           -1.0040417767374037,
           -1.0007267784073466,
           -0.9974055976605916,
           -0.9940814016761582,
           -0.9907573922385423,
           -0.9874368032281178,
           -0.9841228979661155,
           -0.9808189664103342,
           -0.9775283221981148,
           -0.9742542995335416,
           -0.9710002499163405,
           -0.967769538710509,
           -0.9645655415513448,
           -0.9613916405902652,
           -0.9582512205775726,
           -0.9551476647841912,
           -0.9520843507643205,
           -0.9490646459619492,
           -0.9460919031652423,
           -0.9431694558139451,
           -0.9403006131661327,
           -0.9374886553318859,
           -0.934736828182755,
           -0.9320483381472013,
           -0.9294263469035589,
           -0.926873965983418,
           -0.9243942512997049,
           -0.9219901976150713,
           -0.9196647329675435,
           -0.9174207130716391,
           -0.9152609157143826,
           -0.9131880351667724,
           -0.9112046766322788,
           -0.9093133507548656,
           -0.9075164682097951,
           -0.9058163344010913,
           -0.9042151442899887,
           -0.9027149773789436,
           -0.9013177928758536,
           -0.9000254250629768,
           -0.8988395788946718,
           -0.8977618258474916,
           -0.8967936000453389,
           -0.8959361946813452,
           -0.8951907587568686,
           -0.8945582941565152,
           -0.8940396530764065,
           -0.8936355358210345,
           -0.8933464889819956,
           -0.8931729040096956,
           -0.8931150161867906,
           -0.8931729040096958,
           -0.8933464889819961,
           -0.8936355358210348,
           -0.894039653076407,
           -0.8945582941565157,
           -0.8951907587568694,
           -0.895936194681346,
           -0.8967936000453398,
           -0.8977618258474926,
           -0.898839578894673,
           -0.9000254250629782,
           -0.9013177928758549,
           -0.902714977378945,
           -0.9042151442899904,
           -0.905816334401093,
           -0.907516468209797,
           -0.9093133507548676,
           -0.9112046766322809,
           -0.9131880351667747,
           -0.9152609157143848,
           -0.9174207130716414,
           -0.9196647329675457,
           -0.9219901976150737,
           -0.9243942512997073,
           -0.9268739659834206,
           -0.9294263469035615,
           -0.9320483381472041,
           -0.9347368281827578,
           -0.9374886553318887,
           -0.9403006131661354,
           -0.9431694558139481,
           -0.9460919031652454,
           -0.9490646459619523,
           -0.9520843507643235,
           -0.9551476647841942,
           -0.9582512205775757,
           -0.9613916405902686,
           -0.9645655415513482,
           -0.9677695387105124,
           -0.9710002499163439,
           -0.9742542995335449,
           -0.9775283221981181,
           -0.9808189664103378,
           -0.9841228979661188,
           -0.9874368032281212,
           -0.9907573922385459,
           -0.9940814016761618,
           -0.9974055976605949,
           -1.00072677840735,
           -1.0040417767374072,
           -1.0073474624455558,
           -1.010640744531882,
           -1.0139185733010427,
           -1.017177942334117,
           -1.0204158903379477,
           -1.023629502876963,
           -1.0268159139925122,
           -1.0299723077147593,
           -1.033095919472167,
           -1.0361840374035451,
           -1.0392340035775904,
           -1.0422432151247385,
           -1.0452091252860665,
           -1.0481292443838506,
           -1.0510011407182656,
           -1.0538224413945687,
           -1.0565908330849674,
           -1.059304062729216,
           -1.0619599381778357,
           -1.0645563287816806,
           -1.0670911659314295,
           -1.0695624435504059,
           -1.071968218543976,
           -1.074306611208617,
           -1.076575805603585,
           -1.0787740498879606,
           -1.080899656625702,
           -1.0829510030611837,
           -1.0849265313675573,
           -1.0868247488701328,
           -1.0886442282468465,
           -1.0903836077077422,
           -1.0920415911552848,
           -1.093616948327183,
           -1.0951085149233029,
           -1.0965151927181271,
           -1.0978359496601195,
           -1.0990698199592397,
           -1.1002159041637696,
           -1.1012733692275092,
           -1.1022414485683028,
           -1.103119442118794,
           -1.1039067163701932,
           -1.1046027044097853,
           -1.105206905952819,
           -1.105718887369338,
           -1.1061382817064596,
           -1.1064647887065149,
           -1.1066981748214106,
           -1.1068382732235038
          ],
          [
           -1.1213065999007323,
           -1.1212542685225326,
           -1.1210973103668642,
           -1.1208358333719002,
           -1.1204700174391649,
           -1.120000114440284,
           -1.119426448226227,
           -1.1187494146388237,
           -1.1179694815242875,
           -1.1170871887484046,
           -1.116103148212981,
           -1.1150180438730786,
           -1.1138326317544853,
           -1.1125477399708101,
           -1.111164268739489,
           -1.1096831903959303,
           -1.1081055494049241,
           -1.1064324623683508,
           -1.1046651180281364,
           -1.1028047772632865,
           -1.1008527730797297,
           -1.0988105105915846,
           -1.096679466992345,
           -1.0944611915143423,
           -1.0921573053747173,
           -1.0897695017059867,
           -1.0872995454691314,
           -1.0847492733469912,
           -1.0821205936155611,
           -1.079415485990632,
           -1.0766360014470133,
           -1.0737842620073996,
           -1.0708624604977317,
           -1.0678728602656995,
           -1.0648177948588164,
           -1.0616996676582717,
           -1.0585209514645355,
           -1.0552841880304595,
           -1.051991987537367,
           -1.0486470280093885,
           -1.0452520546610513,
           -1.0418098791728707,
           -1.0383233788894575,
           -1.0347954959344003,
           -1.031229236235943,
           -1.0276276684572407,
           -1.0239939228247625,
           -1.0203311898481886,
           -1.0166427189249665,
           -1.0129318168225123,
           -1.0092018460309025,
           -1.0054562229787867,
           -1.0016984161051636,
           -0.9979319437796347,
           -0.9941603720637471,
           -0.9903873123061014,
           -0.9866164185640153,
           -0.9828513848447192,
           -0.9790959421593101,
           -0.9753538553830243,
           -0.971628919915807,
           -0.9679249581376643,
           -0.9642458156538849,
           -0.9605953573259294,
           -0.956977463084603,
           -0.9533960235230499,
           -0.9498549352681518,
           -0.9463580961300838,
           -0.942909400031044,
           -0.9395127317155916,
           -0.9361719612465296,
           -0.9328909382918971,
           -0.9296734862103777,
           -0.9265233959442444,
           -0.9234444197308924,
           -0.9204402646459844,
           -0.9175145859932884,
           -0.914670980558357,
           -0.9119129797453026,
           -0.909244042618007,
           -0.9066675488691603,
           -0.9041867917425136,
           -0.9018049709356359,
           -0.8995251855122425,
           -0.897350426854782,
           -0.8952835716894186,
           -0.8933273752167569,
           -0.8914844643826318,
           -0.8897573313239932,
           -0.8881483270252938,
           -0.8866596552208773,
           -0.8852933665785732,
           -0.8840513531990876,
           -0.882935343464779,
           -0.8819468972700346,
           -0.8810874016637429,
           -0.8803580669322585,
           -0.8797599231488273,
           -0.879293817212694,
           -0.8789604103980652,
           -0.8787601764298112,
           -0.8786934000992677,
           -0.8787601764298113,
           -0.8789604103980655,
           -0.8792938172126944,
           -0.8797599231488278,
           -0.8803580669322589,
           -0.8810874016637437,
           -0.8819468972700355,
           -0.8829353434647802,
           -0.884051353199089,
           -0.8852933665785745,
           -0.8866596552208789,
           -0.8881483270252953,
           -0.8897573313239949,
           -0.8914844643826338,
           -0.893327375216759,
           -0.8952835716894209,
           -0.8973504268547841,
           -0.8995251855122448,
           -0.9018049709356386,
           -0.9041867917425163,
           -0.9066675488691629,
           -0.9092440426180096,
           -0.9119129797453052,
           -0.9146709805583598,
           -0.9175145859932914,
           -0.9204402646459874,
           -0.9234444197308955,
           -0.9265233959442477,
           -0.9296734862103809,
           -0.9328909382919006,
           -0.936171961246533,
           -0.939512731715595,
           -0.9429094000310473,
           -0.9463580961300874,
           -0.9498549352681556,
           -0.9533960235230533,
           -0.9569774630846067,
           -0.960595357325933,
           -0.9642458156538888,
           -0.9679249581376684,
           -0.971628919915811,
           -0.975353855383028,
           -0.9790959421593141,
           -0.9828513848447231,
           -0.9866164185640192,
           -0.9903873123061052,
           -0.9941603720637511,
           -0.9979319437796385,
           -1.0016984161051674,
           -1.0054562229787904,
           -1.0092018460309062,
           -1.012931816822516,
           -1.0166427189249705,
           -1.0203311898481924,
           -1.0239939228247663,
           -1.0276276684572445,
           -1.0312292362359468,
           -1.034795495934404,
           -1.0383233788894608,
           -1.041809879172874,
           -1.0452520546610546,
           -1.048647028009392,
           -1.0519919875373702,
           -1.0552841880304629,
           -1.0585209514645388,
           -1.0616996676582746,
           -1.0648177948588198,
           -1.0678728602657026,
           -1.0708624604977348,
           -1.0737842620074025,
           -1.0766360014470162,
           -1.0794154859906346,
           -1.082120593615564,
           -1.084749273346994,
           -1.0872995454691343,
           -1.0897695017059892,
           -1.0921573053747198,
           -1.0944611915143445,
           -1.0966794669923474,
           -1.0988105105915866,
           -1.1008527730797317,
           -1.1028047772632885,
           -1.1046651180281382,
           -1.1064324623683524,
           -1.1081055494049254,
           -1.109683190395932,
           -1.1111642687394903,
           -1.1125477399708115,
           -1.1138326317544864,
           -1.1150180438730797,
           -1.1161031482129822,
           -1.1170871887484055,
           -1.1179694815242887,
           -1.1187494146388246,
           -1.119426448226228,
           -1.1200001144402847,
           -1.1204700174391649,
           -1.1208358333719002,
           -1.1210973103668644,
           -1.1212542685225328
          ],
          [
           -1.1365782951033379,
           -1.1365201670979124,
           -1.1363458214861075,
           -1.1360553734858398,
           -1.1356490151419587,
           -1.1351270153486357,
           -1.1344897198805366,
           -1.1337375514325885,
           -1.1328710096681076,
           -1.1318906712750014,
           -1.130797190029687,
           -1.1295912968683204,
           -1.1282737999648507,
           -1.126845584815358,
           -1.125307614328047,
           -1.1236609289181938,
           -1.1219066466072658,
           -1.1200459631253268,
           -1.1180801520157562,
           -1.116010564741197,
           -1.1138386307895454,
           -1.1115658577786505,
           -1.1091938315582934,
           -1.106724216307847,
           -1.1041587546278826,
           -1.1014992676238249,
           -1.0987476549795838,
           -1.0959058950189082,
           -1.0929760447520078,
           -1.0899602399047879,
           -1.0868606949278072,
           -1.0836797029818457,
           -1.0804196358967104,
           -1.077082944099648,
           -1.0736721565094562,
           -1.0701898803920866,
           -1.066638801173239,
           -1.0630216822031129,
           -1.0593413644681595,
           -1.0556007662443334,
           -1.0518028826859767,
           -1.0479507853441148,
           -1.0440476216075627,
           -1.0400966140598564,
           -1.0361010597446485,
           -1.032064329331812,
           -1.027989866176113,
           -1.0238811852599425,
           -1.0197418720112132,
           -1.0155755809871894,
           -1.0113860344146695,
           -1.0071770205766382,
           -1.0029523920352337,
           -0.9987160636806293,
           -0.9944720105952504,
           -0.9902242657226097,
           -0.9859769173299856,
           -0.9817341062541733,
           -0.9775000229196349,
           -0.9732789041185761,
           -0.9690750295427684,
           -0.9648927180573674,
           -0.96073632370752,
           -0.9566102314492579,
           -0.9525188525970123,
           -0.9484666199811042,
           -0.9444579828097363,
           -0.9404974012313904,
           -0.9365893405950655,
           -0.9327382654075499,
           -0.928948632988845,
           -0.9252248868289857,
           -0.921571449651823,
           -0.9179927161938282,
           -0.9144930457086438,
           -0.9110767542109341,
           -0.907748106476044,
           -0.9045113078150373,
           -0.9013704956478482,
           -0.8983297309004629,
           -0.895392989255265,
           -0.8925641522868466,
           -0.8898469985186783,
           -0.8872451944389953,
           -0.884762285517034,
           -0.8824016872632929,
           -0.8801666763797461,
           -0.8780603820478332,
           -0.8760857774035602,
           -0.8742456712501031,
           -0.8725427000588647,
           -0.8709793203099782,
           -0.8695578012227219,
           -0.8682802179251986,
           -0.8671484451109319,
           -0.8661641512277275,
           -0.8653287932412553,
           -0.864643612012353,
           -0.86410962832306,
           -0.8637276395819067,
           -0.8634982172340612,
           -0.8634217048966623,
           -0.8634982172340613,
           -0.863727639581907,
           -0.8641096283230607,
           -0.8646436120123534,
           -0.8653287932412561,
           -0.8661641512277286,
           -0.867148445110933,
           -0.8682802179251998,
           -0.8695578012227232,
           -0.8709793203099797,
           -0.8725427000588665,
           -0.874245671250105,
           -0.8760857774035623,
           -0.8780603820478353,
           -0.8801666763797484,
           -0.8824016872632955,
           -0.8847622855170366,
           -0.887245194438998,
           -0.8898469985186811,
           -0.8925641522868496,
           -0.895392989255268,
           -0.8983297309004659,
           -0.9013704956478513,
           -0.9045113078150405,
           -0.9077481064760473,
           -0.9110767542109377,
           -0.9144930457086473,
           -0.9179927161938319,
           -0.9215714496518268,
           -0.9252248868289894,
           -0.928948632988849,
           -0.9327382654075539,
           -0.9365893405950694,
           -0.9404974012313942,
           -0.9444579828097404,
           -0.9484666199811081,
           -0.9525188525970164,
           -0.9566102314492619,
           -0.9607363237075243,
           -0.9648927180573716,
           -0.9690750295427728,
           -0.9732789041185804,
           -0.9775000229196392,
           -0.9817341062541779,
           -0.9859769173299899,
           -0.9902242657226139,
           -0.9944720105952548,
           -0.9987160636806337,
           -1.002952392035238,
           -1.0071770205766424,
           -1.0113860344146737,
           -1.0155755809871936,
           -1.0197418720112172,
           -1.0238811852599468,
           -1.0279898661761175,
           -1.0320643293318161,
           -1.036101059744653,
           -1.0400966140598602,
           -1.0440476216075665,
           -1.0479507853441188,
           -1.0518028826859804,
           -1.0556007662443374,
           -1.0593413644681633,
           -1.0630216822031167,
           -1.066638801173243,
           -1.0701898803920904,
           -1.0736721565094598,
           -1.0770829440996517,
           -1.0804196358967137,
           -1.083679702981849,
           -1.0868606949278103,
           -1.089960239904791,
           -1.092976044752011,
           -1.0959058950189111,
           -1.0987476549795867,
           -1.1014992676238278,
           -1.1041587546278855,
           -1.1067242163078497,
           -1.109193831558296,
           -1.1115658577786527,
           -1.1138386307895474,
           -1.1160105647411993,
           -1.118080152015758,
           -1.1200459631253288,
           -1.1219066466072676,
           -1.1236609289181954,
           -1.1253076143280485,
           -1.1268455848153598,
           -1.128273799964852,
           -1.1295912968683215,
           -1.1307971900296883,
           -1.1318906712750025,
           -1.1328710096681087,
           -1.1337375514325891,
           -1.1344897198805373,
           -1.135127015348636,
           -1.1356490151419587,
           -1.13605537348584,
           -1.136345821486108,
           -1.1365201670979126
          ],
          [
           -1.152685295042224,
           -1.15262121976157,
           -1.1524290345447756,
           -1.1521088612751078,
           -1.1516609031172,
           -1.1510854445557697,
           -1.1503828514496992,
           -1.1495535711013436,
           -1.1485981323408938,
           -1.1475171456255913,
           -1.1463113031535237,
           -1.1449813789916976,
           -1.1435282292180295,
           -1.1419527920768298,
           -1.1402560881472963,
           -1.1384392205244744,
           -1.1365033750120386,
           -1.1344498203261988,
           -1.1322799083099182,
           -1.129995074156543,
           -1.127596836641829,
           -1.125086798363233,
           -1.1224666459852017,
           -1.1197381504890496,
           -1.1169031674258643,
           -1.1139636371706976,
           -1.110921585176128,
           -1.1077791222230702,
           -1.1045384446664923,
           -1.1012018346734709,
           -1.0977716604507506,
           -1.0942503764587166,
           -1.0906405236083805,
           -1.0869447294376753,
           -1.0831657082630175,
           -1.0793062613017346,
           -1.0753692767605785,
           -1.071357729885137,
           -1.0672746829645297,
           -1.0631232852853316,
           -1.058906773028176,
           -1.0546284691000134,
           -1.0502917828944693,
           -1.0459002099722179,
           -1.0414573316527234,
           -1.0369668145081368,
           -1.0324324097495516,
           -1.0278579524952238,
           -1.0232473609097668,
           -1.0186046352027383,
           -1.0139338564744391,
           -1.0092391853961717,
           -1.004524860711647,
           -0.9997951975457047,
           -0.9950545855060329,
           -0.9903074865631336,
           -0.9855584326934171,
           -0.9808120232700284,
           -0.9760729221858003,
           -0.9713458546926601,
           -0.9666356039418471,
           -0.9619470072094991,
           -0.9572849517925061,
           -0.9526543705600787,
           -0.9480602371472099,
           -0.9435075607771712,
           -0.9390013807013967,
           -0.9345467602465558,
           -0.9301487804603715,
           -0.9258125333497573,
           -0.9215431147071824,
           -0.9173456165238161,
           -0.9132251189909528,
           -0.909186682094488,
           -0.9052353368107888,
           -0.9013760759161613,
           -0.8976138444262594,
           -0.8939535296861524,
           -0.8903999511363537,
           -0.8869578497848648,
           -0.8836318774201329,
           -0.880426585604728,
           -0.8773464144944163,
           -0.8743956815320754,
           -0.871578570070487,
           -0.8688991179823498,
           -0.8663612063197932,
           -0.8639685480891566,
           -0.8617246772097185,
           -0.8596329377273403,
           -0.85769647335554,
           -0.8559182174172548,
           -0.854300883260433,
           -0.8528469552195586,
           -0.8515586801932143,
           -0.8504380599048467,
           -0.8494868439099614,
           -0.8487065234081431,
           -0.8480983259125298,
           -0.8476632108228233,
           -0.8474018659406012,
           -0.847314704957776,
           -0.8474018659406015,
           -0.8476632108228237,
           -0.8480983259125302,
           -0.8487065234081437,
           -0.8494868439099623,
           -0.8504380599048477,
           -0.8515586801932156,
           -0.8528469552195599,
           -0.8543008832604346,
           -0.8559182174172564,
           -0.857696473355542,
           -0.8596329377273424,
           -0.8617246772097206,
           -0.863968548089159,
           -0.8663612063197959,
           -0.8688991179823525,
           -0.8715785700704898,
           -0.8743956815320784,
           -0.8773464144944195,
           -0.8804265856047313,
           -0.8836318774201362,
           -0.8869578497848682,
           -0.8903999511363573,
           -0.8939535296861559,
           -0.8976138444262632,
           -0.9013760759161653,
           -0.9052353368107929,
           -0.9091866820944924,
           -0.9132251189909569,
           -0.9173456165238204,
           -0.9215431147071866,
           -0.9258125333497617,
           -0.930148780460376,
           -0.9345467602465602,
           -0.9390013807014013,
           -0.943507560777176,
           -0.9480602371472145,
           -0.9526543705600836,
           -0.9572849517925108,
           -0.9619470072095039,
           -0.9666356039418521,
           -0.9713458546926648,
           -0.9760729221858052,
           -0.9808120232700333,
           -0.9855584326934219,
           -0.9903074865631383,
           -0.9950545855060378,
           -0.9997951975457093,
           -1.0045248607116517,
           -1.0092391853961766,
           -1.013933856474444,
           -1.018604635202743,
           -1.0232473609097716,
           -1.0278579524952287,
           -1.0324324097495563,
           -1.0369668145081412,
           -1.0414573316527278,
           -1.0459002099722225,
           -1.0502917828944738,
           -1.0546284691000176,
           -1.0589067730281805,
           -1.0631232852853358,
           -1.067274682964534,
           -1.0713577298851409,
           -1.0753692767605827,
           -1.0793062613017386,
           -1.0831657082630213,
           -1.086944729437679,
           -1.0906405236083843,
           -1.0942503764587201,
           -1.0977716604507541,
           -1.1012018346734744,
           -1.1045384446664959,
           -1.1077791222230735,
           -1.1109215851761314,
           -1.1139636371707007,
           -1.1169031674258671,
           -1.1197381504890525,
           -1.1224666459852044,
           -1.1250867983632358,
           -1.1275968366418314,
           -1.1299950741565452,
           -1.1322799083099204,
           -1.1344498203262008,
           -1.1365033750120406,
           -1.1384392205244762,
           -1.1402560881472978,
           -1.1419527920768313,
           -1.143528229218031,
           -1.1449813789916992,
           -1.146311303153525,
           -1.1475171456255926,
           -1.1485981323408947,
           -1.1495535711013443,
           -1.1503828514497005,
           -1.1510854445557703,
           -1.1516609031172005,
           -1.1521088612751083,
           -1.1524290345447759,
           -1.15262121976157
          ],
          [
           -1.1696120172352042,
           -1.1695418685060175,
           -1.1693314649475441,
           -1.1689809344580762,
           -1.1684904902381976,
           -1.1678604308459035,
           -1.1670911402737074,
           -1.1661830880476727,
           -1.1651368293482907,
           -1.1639530051530946,
           -1.1626323424008806,
           -1.1611756541773706,
           -1.1595838399221194,
           -1.1578578856564306,
           -1.1559988642319943,
           -1.1540079355999169,
           -1.1518863470997431,
           -1.1496354337680095,
           -1.1472566186657962,
           -1.144751413224641,
           -1.1421214176101062,
           -1.1393683211021544,
           -1.1364939024913887,
           -1.133500030490063,
           -1.1303886641566212,
           -1.1271618533323546,
           -1.1238217390885816,
           -1.1203705541825502,
           -1.1168106235200275,
           -1.1131443646223118,
           -1.1093742880951052,
           -1.10550299809641,
           -1.1015331928002734,
           -1.0974676648528607,
           -1.0933093018169444,
           -1.089061086600497,
           -1.084726097864616,
           -1.0803075104055295,
           -1.0758085955049228,
           -1.071232721242259,
           -1.0665833527621913,
           -1.0618640524895173,
           -1.0570784802834774,
           -1.0522303935224755,
           -1.0473236471095757,
           -1.0423621933883311,
           -1.0373500819577046,
           -1.032291459373985,
           -1.0271905687267344,
           -1.0220517490749121,
           -1.0168794347283945,
           -1.0116781543592044,
           -1.0064525299258271,
           -1.001207275393079,
           -0.995947195229101,
           -0.9906771826601883,
           -0.9854022176633522,
           -0.9801273646757763,
           -0.9748577699996658,
           -0.969598658880446,
           -0.9643553322358541,
           -0.9591331630132222,
           -0.9539375921521753,
           -0.9487741241301383,
           -0.9436483220684451,
           -0.9385658023775364,
           -0.9335322289207427,
           -0.9285533066775064,
           -0.9236347748886431,
           -0.9187823996683987,
           -0.9140019660706618,
           -0.9092992695997643,
           -0.9046801071598601,
           -0.9001502674409387,
           -0.8957155207440988,
           -0.8913816082537838,
           -0.8871542307702523,
           -0.8830390369215827,
           -0.8790416108809713,
           -0.8751674596219177,
           -0.8714219997510075,
           -0.8678105439653682,
           -0.8643382871893239,
           -0.8610102924522516,
           -0.8578314765769722,
           -0.8548065957550857,
           -0.8519402310923024,
           -0.8492367742128971,
           -0.8467004130177384,
           -0.8443351176947816,
           -0.8421446270842938,
           -0.8401324355032547,
           -0.8383017801342599,
           -0.8366556290836757,
           -0.8351966702117429,
           -0.8339273008337159,
           -0.8328496183859426,
           -0.8319654121440908,
           -0.8312761560725249,
           -0.8307830028742883,
           -0.830486779300335,
           -0.8303879827647959,
           -0.8304867793003351,
           -0.8307830028742889,
           -0.8312761560725256,
           -0.8319654121440915,
           -0.8328496183859437,
           -0.833927300833717,
           -0.8351966702117445,
           -0.8366556290836774,
           -0.8383017801342618,
           -0.8401324355032567,
           -0.8421446270842962,
           -0.8443351176947841,
           -0.8467004130177408,
           -0.8492367742128998,
           -0.8519402310923052,
           -0.8548065957550888,
           -0.8578314765769754,
           -0.861010292452255,
           -0.8643382871893275,
           -0.8678105439653718,
           -0.8714219997510112,
           -0.8751674596219216,
           -0.8790416108809754,
           -0.8830390369215867,
           -0.8871542307702566,
           -0.8913816082537882,
           -0.8957155207441033,
           -0.9001502674409434,
           -0.9046801071598648,
           -0.909299269599769,
           -0.9140019660706667,
           -0.9187823996684036,
           -0.9236347748886482,
           -0.9285533066775115,
           -0.9335322289207479,
           -0.9385658023775417,
           -0.9436483220684505,
           -0.9487741241301437,
           -0.9539375921521808,
           -0.9591331630132276,
           -0.9643553322358597,
           -0.9695986588804513,
           -0.9748577699996713,
           -0.9801273646757817,
           -0.9854022176633577,
           -0.9906771826601937,
           -0.9959471952291066,
           -1.0012072753930843,
           -1.0064525299258325,
           -1.0116781543592095,
           -1.0168794347283996,
           -1.0220517490749175,
           -1.0271905687267398,
           -1.0322914593739903,
           -1.03735008195771,
           -1.042362193388336,
           -1.0473236471095808,
           -1.0522303935224804,
           -1.057078480283482,
           -1.0618640524895222,
           -1.0665833527621962,
           -1.0712327212422637,
           -1.0758085955049272,
           -1.0803075104055342,
           -1.0847260978646205,
           -1.0890610866005015,
           -1.0933093018169486,
           -1.097467664852865,
           -1.1015331928002778,
           -1.1055029980964137,
           -1.109374288095109,
           -1.1131443646223156,
           -1.1168106235200312,
           -1.1203705541825535,
           -1.1238217390885854,
           -1.127161853332358,
           -1.1303886641566245,
           -1.1335000304900662,
           -1.1364939024913916,
           -1.139368321102157,
           -1.1421214176101093,
           -1.144751413224644,
           -1.1472566186657984,
           -1.1496354337680117,
           -1.1518863470997454,
           -1.1540079355999189,
           -1.1559988642319963,
           -1.1578578856564326,
           -1.1595838399221212,
           -1.1611756541773721,
           -1.162632342400882,
           -1.163953005153096,
           -1.165136829348292,
           -1.1661830880476738,
           -1.1670911402737085,
           -1.1678604308459044,
           -1.1684904902381978,
           -1.1689809344580766,
           -1.1693314649475448,
           -1.169541868506018
          ],
          [
           -1.1873420861717516,
           -1.1872657614138513,
           -1.1870368315506088,
           -1.1866554298275906,
           -1.1861217783680613,
           -1.1854361882439741,
           -1.1845990595753888,
           -1.183610881658331,
           -1.1824722331211257,
           -1.1811837821092332,
           -1.1797462864986061,
           -1.1781605941375983,
           -1.176427643117422,
           -1.1745484620711597,
           -1.1725241705012934,
           -1.1703559791357014,
           -1.1680451903120346,
           -1.1655931983903334,
           -1.1630014901937005,
           -1.1602716454767834,
           -1.1574053374217343,
           -1.1544043331612424,
           -1.1512704943281187,
           -1.1480057776308061,
           -1.1446122354540471,
           -1.1410920164837908,
           -1.1374473663552491,
           -1.1336806283228142,
           -1.1297942439503346,
           -1.1257907538199952,
           -1.121672798257779,
           -1.1174431180731805,
           -1.113104555310505,
           -1.1086600540087141,
           -1.1041126609663663,
           -1.0994655265077529,
           -1.094721905245828,
           -1.0898851568370018,
           -1.0849587467222588,
           -1.0799462468484382,
           -1.0748513363628107,
           -1.06967780227333,
           -1.0644295400661357,
           -1.059110554271009,
           -1.0537249589645525,
           -1.0482769781998664,
           -1.0427709463504475,
           -1.0372113083549077,
           -1.0316026198479342,
           -1.025949547161686,
           -1.0202568671805152,
           -1.0145294670305849,
           -1.008772343584564,
           -1.0029906027601856,
           -0.9971894585900226,
           -0.9913742320384133,
           -0.9855503495400519,
           -0.9797233412333884,
           -0.9738988388606479,
           -0.9680825733050655,
           -0.9622803717347981,
           -0.956498154322026,
           -0.9507419305049791,
           -0.9450177947600925,
           -0.9393319218512413,
           -0.933690561523092,
           -0.9281000326060724,
           -0.9225667165013771,
           -0.9170970500158411,
           -0.9116975175184837,
           -0.9063746423931174,
           -0.9011349777646671,
           -0.8959850964808346,
           -0.8909315803354683,
           -0.8859810085255512,
           -0.8811399453400529,
           -0.8764149270860918,
           -0.8718124482658258,
           -0.8673389470262779,
           -0.8630007899138064,
           -0.8588042559750804,
           -0.854755520257135,
           -0.8508606367701834,
           -0.84712552098824,
           -0.8435559319740208,
           -0.8401574542258662,
           -0.8369354793552961,
           -0.8338951877140313,
           -0.8310415300986098,
           -0.8283792096688285,
           -0.825912664222863,
           -0.8236460489768133,
           -0.8215832199993462,
           -0.8197277184528435,
           -0.8180827557908521,
           -0.8166512000575713,
           -0.8154355634285059,
           -0.8144379911223173,
           -0.8136602518023498,
           -0.813103729572469,
           -0.8127694176559273,
           -0.8126579138282485,
           -0.8127694176559274,
           -0.8131037295724693,
           -0.8136602518023504,
           -0.8144379911223181,
           -0.8154355634285068,
           -0.8166512000575726,
           -0.8180827557908538,
           -0.8197277184528453,
           -0.8215832199993482,
           -0.8236460489768155,
           -0.8259126642228656,
           -0.8283792096688313,
           -0.8310415300986126,
           -0.8338951877140344,
           -0.8369354793552993,
           -0.8401574542258697,
           -0.8435559319740243,
           -0.8471255209882437,
           -0.8508606367701874,
           -0.854755520257139,
           -0.8588042559750846,
           -0.8630007899138107,
           -0.8673389470262823,
           -0.8718124482658304,
           -0.8764149270860967,
           -0.8811399453400579,
           -0.8859810085255562,
           -0.8909315803354735,
           -0.8959850964808397,
           -0.9011349777646726,
           -0.9063746423931227,
           -0.9116975175184893,
           -0.9170970500158466,
           -0.9225667165013828,
           -0.9281000326060782,
           -0.9336905615230978,
           -0.939331921851247,
           -0.9450177947600983,
           -0.9507419305049851,
           -0.9564981543220319,
           -0.9622803717348041,
           -0.9680825733050715,
           -0.973898838860654,
           -0.9797233412333944,
           -0.985550349540058,
           -0.9913742320384193,
           -0.9971894585900286,
           -1.0029906027601914,
           -1.00877234358457,
           -1.0145294670305907,
           -1.020256867180521,
           -1.025949547161692,
           -1.03160261984794,
           -1.0372113083549135,
           -1.0427709463504535,
           -1.048276978199872,
           -1.053724958964558,
           -1.0591105542710146,
           -1.064429540066141,
           -1.0696778022733353,
           -1.0748513363628158,
           -1.0799462468484433,
           -1.0849587467222637,
           -1.0898851568370067,
           -1.094721905245833,
           -1.0994655265077575,
           -1.1041126609663712,
           -1.1086600540087188,
           -1.1131045553105094,
           -1.1174431180731847,
           -1.121672798257783,
           -1.1257907538199994,
           -1.1297942439503388,
           -1.133680628322818,
           -1.137447366355253,
           -1.1410920164837945,
           -1.1446122354540504,
           -1.1480057776308092,
           -1.1512704943281218,
           -1.1544043331612455,
           -1.1574053374217375,
           -1.1602716454767863,
           -1.1630014901937031,
           -1.1655931983903356,
           -1.1680451903120368,
           -1.1703559791357032,
           -1.1725241705012954,
           -1.1745484620711621,
           -1.1764276431174239,
           -1.1781605941375999,
           -1.1797462864986075,
           -1.1811837821092348,
           -1.1824722331211273,
           -1.183610881658332,
           -1.18459905957539,
           -1.1854361882439748,
           -1.1861217783680613,
           -1.186655429827591,
           -1.1870368315506092,
           -1.187265761413852
          ],
          [
           -1.2058583491552484,
           -1.2057757683623287,
           -1.2055280719527284,
           -1.2051153978510638,
           -1.204537975988848,
           -1.2037961283902792,
           -1.2028902692924694,
           -1.2018209053002327,
           -1.2005886355755864,
           -1.1991941520621465,
           -1.1976382397446297,
           -1.195921776943688,
           -1.1940457356463345,
           -1.1920111818722223,
           -1.189819276076051,
           -1.1874712735863868,
           -1.18496852508116,
           -1.18231247710011,
           -1.179504672594421,
           -1.1765467515137509,
           -1.1734404514308285,
           -1.1701876082037326,
           -1.1667901566758903,
           -1.163250131413759,
           -1.1595696674820488,
           -1.1557510012562136,
           -1.1517964712718076,
           -1.147708519110128,
           -1.1434896903193732,
           -1.1391426353703291,
           -1.134670110645329,
           -1.130074979458964,
           -1.1253602131086722,
           -1.1205288919529877,
           -1.1155842065147996,
           -1.1105294586065264,
           -1.1053680624735784,
           -1.1001035459519262,
           -1.0947395516349443,
           -1.0892798380440076,
           -1.083728280796542,
           -1.0780888737643883,
           -1.072365730214403,
           -1.0665630839222127,
           -1.0606852902489379,
           -1.0547368271695012,
           -1.0487222962398497,
           -1.0426464234890223,
           -1.0365140602205103,
           -1.0303301837057581,
           -1.0240998977509537,
           -1.01782843311647,
           -1.0115211477664223,
           -1.005183526923832,
           -0.9988211829048241,
           -0.992439854703175,
           -0.9860454072943373,
           -0.9796438306258906,
           -0.9732412382591386,
           -0.9668438656244203,
           -0.9604580678505829,
           -0.9540903171270598,
           -0.9477471995551677,
           -0.9414354114435907,
           -0.9351617550016896,
           -0.9289331333832643,
           -0.9227565450328369,
           -0.9166390772864681,
           -0.9105878991796742,
           -0.9046102534162691,
           -0.8987134474540065,
           -0.8929048436658633,
           -0.8871918485397534,
           -0.8815819008845105,
           -0.8760824590162052,
           -0.8707009869063291,
           -0.865444939282161,
           -0.8603217456797283,
           -0.8553387934612324,
           -0.8505034098215574,
           -0.8458228428224623,
           -0.8413042415081821,
           -0.8369546351722326,
           -0.8327809118620408,
           -0.8287897962253438,
           -0.8249878268197817,
           -0.821381333024418,
           -0.8179764117086187,
           -0.8147789038293971,
           -0.8117943711425014,
           -0.8090280732247167,
           -0.8064849450146175,
           -0.804169575085874,
           -0.8020861848708019,
           -0.8002386090518099,
           -0.7986302773344729,
           -0.7972641978079923,
           -0.7961429420867443,
           -0.7952686324105336,
           -0.7946429308612679,
           -0.794267030830365,
           -0.7941416508447515,
           -0.7942670308303652,
           -0.7946429308612684,
           -0.7952686324105342,
           -0.7961429420867452,
           -0.7972641978079935,
           -0.7986302773344744,
           -0.8002386090518117,
           -0.8020861848708039,
           -0.8041695750858765,
           -0.80648494501462,
           -0.8090280732247193,
           -0.8117943711425044,
           -0.8147789038294003,
           -0.8179764117086221,
           -0.8213813330244216,
           -0.8249878268197854,
           -0.8287897962253479,
           -0.8327809118620452,
           -0.836954635172237,
           -0.8413042415081866,
           -0.8458228428224669,
           -0.8505034098215624,
           -0.8553387934612374,
           -0.8603217456797334,
           -0.8654449392821664,
           -0.8707009869063347,
           -0.8760824590162107,
           -0.8815819008845163,
           -0.8871918485397592,
           -0.8929048436658692,
           -0.8987134474540124,
           -0.9046102534162752,
           -0.9105878991796804,
           -0.9166390772864741,
           -0.9227565450328433,
           -0.9289331333832707,
           -0.9351617550016962,
           -0.9414354114435973,
           -0.9477471995551743,
           -0.9540903171270665,
           -0.9604580678505893,
           -0.9668438656244269,
           -0.9732412382591451,
           -0.9796438306258972,
           -0.9860454072943439,
           -0.9924398547031814,
           -0.9988211829048308,
           -1.0051835269238385,
           -1.011521147766429,
           -1.0178284331164762,
           -1.0240998977509599,
           -1.0303301837057646,
           -1.0365140602205165,
           -1.0426464234890285,
           -1.0487222962398557,
           -1.0547368271695075,
           -1.0606852902489436,
           -1.0665630839222184,
           -1.072365730214409,
           -1.0780888737643943,
           -1.0837282807965476,
           -1.0892798380440132,
           -1.09473955163495,
           -1.100103545951932,
           -1.1053680624735838,
           -1.1105294586065315,
           -1.1155842065148047,
           -1.1205288919529925,
           -1.1253602131086773,
           -1.1300749794589686,
           -1.1346701106453339,
           -1.1391426353703333,
           -1.1434896903193776,
           -1.147708519110132,
           -1.1517964712718118,
           -1.1557510012562175,
           -1.1595696674820526,
           -1.1632501314137624,
           -1.1667901566758936,
           -1.1701876082037361,
           -1.1734404514308319,
           -1.1765467515137538,
           -1.179504672594424,
           -1.1823124771001128,
           -1.1849685250811623,
           -1.1874712735863895,
           -1.189819276076053,
           -1.1920111818722243,
           -1.1940457356463365,
           -1.1959217769436898,
           -1.1976382397446315,
           -1.1991941520621483,
           -1.200588635575588,
           -1.2018209053002342,
           -1.2028902692924708,
           -1.20379612839028,
           -1.2045379759888488,
           -1.205115397851064,
           -1.2055280719527284,
           -1.205775768362329
          ],
          [
           -1.2251428928971122,
           -1.2250539975070693,
           -1.224787358647028,
           -1.224343118267023,
           -1.2237215130163863,
           -1.2229228743427696,
           -1.2219476286310085,
           -1.2207962973820536,
           -1.2194694974322555,
           -1.2179679412133613,
           -1.2162924370536294,
           -1.2144438895205278,
           -1.2124232998055386,
           -1.2102317661516349,
           -1.2078704843240404,
           -1.205340748124932,
           -1.2026439499527606,
           -1.1997815814069088,
           -1.1967552339384167,
           -1.1935665995475107,
           -1.190217471528682,
           -1.1867097452640358,
           -1.183045419065618,
           -1.1792265950673817,
           -1.1752554801673911,
           -1.1711343870208077,
           -1.1668657350840723,
           -1.1624520517106136,
           -1.1578959732982332,
           -1.1532002464881699,
           -1.1483677294156105,
           -1.1434013930111895,
           -1.1383043223527178,
           -1.1330797180660614,
           -1.127730897773695,
           -1.1222612975890318,
           -1.1166744736541259,
           -1.110974103717781,
           -1.1051639887504576,
           -1.0992480545916672,
           -1.0932303536247188,
           -1.087115066472802,
           -1.0809065037093812,
           -1.0746091075747664,
           -1.0682274536895,
           -1.0617662527538445,
           -1.055230352221158,
           -1.0486247379313285,
           -1.0419545356886382,
           -1.035225012766512,
           -1.028441579319485,
           -1.0216097896804817,
           -1.0147353435190525,
           -1.0078240868336241,
           -1.0008820127480593,
           -0.9939152620799042,
           -0.9869301236446344,
           -0.979933034257036,
           -0.9729305783875428,
           -0.9659294874279983,
           -0.9589366385178895,
           -0.9519590528787079,
           -0.9450038936007563,
           -0.9380784628235171,
           -0.93119019824772,
           -0.9243466689145556,
           -0.9175555701852274,
           -0.9108247178522829,
           -0.9041620413131097,
           -0.8975755757357009,
           -0.8910734531475097,
           -0.884663892380033,
           -0.8783551878048992,
           -0.8721556968018341,
           -0.8660738259051252,
           -0.8601180155832471,
           -0.8542967236163048,
           -0.8486184070479917,
           -0.8430915027029666,
           -0.8377244062769166,
           -0.8325254500251176,
           -0.8275028790959147,
           -0.8226648265780843,
           -0.8180192873552328,
           -0.8135740908859465,
           -0.8093368730548358,
           -0.8053150472664637,
           -0.8015157749807338,
           -0.79794593591399,
           -0.7946120981540662,
           -0.7915204884590232,
           -0.7886769630275132,
           -0.7860869790428058,
           -0.7837555673017457,
           -0.7816873062436331,
           -0.7798862976916663,
           -0.7783561446107938,
           -0.7770999311704042,
           -0.7761202053782281,
           -0.775418964523436,
           -0.7749976436326181,
           -0.7748571071028877,
           -0.7749976436326184,
           -0.7754189645234365,
           -0.7761202053782289,
           -0.7770999311704052,
           -0.7783561446107953,
           -0.779886297691668,
           -0.7816873062436351,
           -0.783755567301748,
           -0.7860869790428083,
           -0.7886769630275162,
           -0.7915204884590262,
           -0.7946120981540695,
           -0.7979459359139935,
           -0.8015157749807377,
           -0.8053150472664677,
           -0.8093368730548401,
           -0.813574090885951,
           -0.8180192873552375,
           -0.8226648265780891,
           -0.8275028790959199,
           -0.8325254500251228,
           -0.837724406276922,
           -0.8430915027029722,
           -0.8486184070479975,
           -0.8542967236163107,
           -0.8601180155832533,
           -0.8660738259051313,
           -0.8721556968018406,
           -0.8783551878049056,
           -0.8846638923800396,
           -0.8910734531475162,
           -0.8975755757357077,
           -0.9041620413131165,
           -0.9108247178522898,
           -0.9175555701852344,
           -0.9243466689145627,
           -0.931190198247727,
           -0.9380784628235241,
           -0.9450038936007634,
           -0.9519590528787151,
           -0.9589366385178967,
           -0.9659294874280056,
           -0.97293057838755,
           -0.9799330342570434,
           -0.9869301236446416,
           -0.9939152620799113,
           -1.0008820127480667,
           -1.0078240868336312,
           -1.0147353435190594,
           -1.0216097896804885,
           -1.0284415793194919,
           -1.035225012766519,
           -1.0419545356886453,
           -1.0486247379313354,
           -1.0552303522211648,
           -1.0617662527538512,
           -1.0682274536895067,
           -1.0746091075747726,
           -1.0809065037093875,
           -1.0871150664728084,
           -1.093230353624725,
           -1.0992480545916734,
           -1.1051639887504636,
           -1.110974103717787,
           -1.1166744736541316,
           -1.1222612975890374,
           -1.1277308977737004,
           -1.133079718066067,
           -1.1383043223527232,
           -1.1434013930111944,
           -1.1483677294156154,
           -1.1532002464881748,
           -1.157895973298238,
           -1.162452051710618,
           -1.1668657350840772,
           -1.1711343870208122,
           -1.1752554801673953,
           -1.1792265950673855,
           -1.1830454190656219,
           -1.186709745264039,
           -1.1902174715286853,
           -1.193566599547514,
           -1.1967552339384198,
           -1.1997815814069117,
           -1.2026439499527635,
           -1.205340748124935,
           -1.2078704843240424,
           -1.210231766151637,
           -1.2124232998055406,
           -1.2144438895205296,
           -1.2162924370536312,
           -1.217967941213363,
           -1.2194694974322569,
           -1.2207962973820552,
           -1.2219476286310098,
           -1.22292287434277,
           -1.223721513016387,
           -1.2243431182670232,
           -1.2247873586470281,
           -1.2250539975070693
          ],
          [
           -1.2451770608467454,
           -1.2450818125276264,
           -1.2447961160127314,
           -1.2443201166514561,
           -1.2436540567662118,
           -1.2427982757627207,
           -1.241753210284774,
           -1.2405193944137805,
           -1.2390974599135498,
           -1.2374881365208323,
           -1.2356922522822384,
           -1.2337107339382476,
           -1.2315446073551113,
           -1.2291949980055337,
           -1.2266631314991026,
           -1.2239503341635192,
           -1.221058033677758,
           -1.2179877597583433,
           -1.2147411449000145,
           -1.2113199251720868,
           -1.2077259410718824,
           -1.203961138436638,
           -1.2000275694153213,
           -1.1959273935018138,
           -1.1916628786309107,
           -1.187236402338584,
           -1.1826504529879096,
           -1.1779076310620158,
           -1.1730106505253222,
           -1.1679623402542367,
           -1.1627656455383348,
           -1.1574236296528697,
           -1.1519394755032495,
           -1.1463164873418545,
           -1.1405580925572456,
           -1.134667843535461,
           -1.128649419592645,
           -1.1225066289777557,
           -1.1162434109435013,
           -1.109863837882986,
           -1.1033721175287594,
           -1.0967725952100837,
           -1.0900697561632198,
           -1.0832682278883945,
           -1.0763727825458296,
           -1.06938833938176,
           -1.0623199671737618,
           -1.0551728866828967,
           -1.047952473098192,
           -1.0406642584567363,
           -1.0333139340202429,
           -1.0259073525862357,
           -1.0184505307090674,
           -1.0109496508027849,
           -1.0034110630943691,
           -0.9958412873921363,
           -0.9882470146300523,
           -0.9806351081444299,
           -0.9730126046349178,
           -0.9653867147569145,
           -0.9577648232875476,
           -0.9501544888022113,
           -0.9425634427933958,
           -0.9349995881582557,
           -0.9274709969761238,
           -0.919985907492107,
           -0.9125527202181127,
           -0.9051799930583243,
           -0.8978764353624179,
           -0.8906509008069259,
           -0.8835123790032984,
           -0.8764699857306639,
           -0.8695329516923077,
           -0.8627106096977432,
           -0.8560123801772738,
           -0.8494477549434007,
           -0.8430262791236273,
           -0.8367575312024289,
           -0.8306511011266103,
           -0.8247165664481636,
           -0.8189634665021677,
           -0.8134012746442735,
           -0.8080393686027825,
           -0.8028869990340453,
           -0.7979532564065052,
           -0.7932470363776353,
           -0.7887770038685864,
           -0.7845515560826515,
           -0.7805787847546654,
           -0.776866437957928,
           -0.773421881831931,
           -0.7702520626266081,
           -0.7673634694856754,
           -0.76476209841145,
           -0.7624534178650939,
           -0.7604423364584287,
           -0.7587331731854783,
           -0.7573296306231793,
           -0.7562347715011544,
           -0.7554509990002762,
           -0.7549800410897082,
           -0.7548229391532547,
           -0.7549800410897085,
           -0.7554509990002769,
           -0.7562347715011554,
           -0.7573296306231806,
           -0.7587331731854797,
           -0.7604423364584306,
           -0.7624534178650961,
           -0.7647620984114527,
           -0.7673634694856782,
           -0.7702520626266112,
           -0.7734218818319345,
           -0.7768664379579316,
           -0.7805787847546692,
           -0.7845515560826558,
           -0.7887770038685907,
           -0.7932470363776402,
           -0.7979532564065102,
           -0.8028869990340505,
           -0.8080393686027879,
           -0.8134012746442792,
           -0.8189634665021734,
           -0.8247165664481695,
           -0.8306511011266166,
           -0.8367575312024352,
           -0.8430262791236337,
           -0.8494477549434075,
           -0.8560123801772807,
           -0.8627106096977502,
           -0.8695329516923148,
           -0.8764699857306711,
           -0.8835123790033055,
           -0.8906509008069332,
           -0.8978764353624255,
           -0.9051799930583319,
           -0.9125527202181203,
           -0.9199859074921147,
           -0.9274709969761316,
           -0.9349995881582635,
           -0.9425634427934036,
           -0.9501544888022192,
           -0.9577648232875555,
           -0.9653867147569224,
           -0.9730126046349257,
           -0.9806351081444379,
           -0.98824701463006,
           -0.9958412873921441,
           -1.003411063094377,
           -1.0109496508027924,
           -1.018450530709075,
           -1.0259073525862432,
           -1.0333139340202504,
           -1.0406642584567434,
           -1.0479524730981995,
           -1.0551728866829042,
           -1.062319967173769,
           -1.0693883393817674,
           -1.0763727825458367,
           -1.0832682278884016,
           -1.0900697561632267,
           -1.0967725952100906,
           -1.103372117528766,
           -1.1098638378829926,
           -1.1162434109435078,
           -1.122506628977762,
           -1.1286494195926513,
           -1.134667843535467,
           -1.1405580925572514,
           -1.1463164873418603,
           -1.1519394755032555,
           -1.157423629652875,
           -1.1627656455383404,
           -1.167962340254242,
           -1.1730106505253275,
           -1.1779076310620207,
           -1.1826504529879145,
           -1.1872364023385886,
           -1.1916628786309151,
           -1.195927393501818,
           -1.2000275694153257,
           -1.203961138436642,
           -1.2077259410718864,
           -1.2113199251720903,
           -1.214741144900018,
           -1.2179877597583464,
           -1.2210580336777608,
           -1.2239503341635218,
           -1.226663131499105,
           -1.2291949980055366,
           -1.2315446073551135,
           -1.2337107339382496,
           -1.2356922522822402,
           -1.2374881365208341,
           -1.2390974599135514,
           -1.2405193944137816,
           -1.2417532102847753,
           -1.2427982757627218,
           -1.243654056766212,
           -1.2443201166514566,
           -1.244796116012732,
           -1.2450818125276268
          ],
          [
           -1.2659414712405423,
           -1.2658398506164996,
           -1.2655350381234578,
           -1.2650271819224754,
           -1.2643165290280336,
           -1.2634034254273376,
           -1.262288316247787,
           -1.2609717459730636,
           -1.259454358708415,
           -1.2577368984958344,
           -1.2558202096799738,
           -1.2537052373257451,
           -1.2513930276886942,
           -1.2488847287393594,
           -1.2461815907429479,
           -1.2432849668957862,
           -1.24019631402012,
           -1.2369171933189609,
           -1.2334492711927876,
           -1.2297943201200177,
           -1.2259542196032822,
           -1.2219309571836199,
           -1.2177266295248084,
           -1.2133434435701371,
           -1.2087837177739864,
           -1.204049883410648,
           -1.1991444859628613,
           -1.1940701865925742,
           -1.1888297636964351,
           -1.183426114548511,
           -1.1778622570326838,
           -1.1721413314671003,
           -1.1662666025229274,
           -1.1602414612395253,
           -1.1540694271379295,
           -1.1477541504342776,
           -1.1412994143544972,
           -1.1347091375511578,
           -1.1279873766229211,
           -1.1211383287364465,
           -1.11416633434992,
           -1.1070758800365919,
           -1.099871601405752,
           -1.092558286117517,
           -1.0851408769865292,
           -1.0776244751682529,
           -1.0700143434199,
           -1.0623159094261645,
           -1.0545347691778153,
           -1.046676690388826,
           -1.0387476159350204,
           -1.030753667294214,
           -1.0227011479644743,
           -1.0145965468333962,
           -1.0064465414671666,
           -0.998258001283656,
           -0.9900379905688002,
           -0.9817937712901149,
           -0.9735328056553175,
           -0.9652627583576955,
           -0.9569914984430982,
           -0.9487271007262427,
           -0.9404778466764693,
           -0.9322522246851979,
           -0.924058929619247,
           -0.9159068615559348,
           -0.9078051235876843,
           -0.8997630185758319,
           -0.8917900447257369,
           -0.8838958898483403,
           -0.8760904241673317,
           -0.868383691526409,
           -0.8607858988481263,
           -0.8533074036949637,
           -0.8459586997850053,
           -0.8387504003194441,
           -0.8316932189876072,
           -0.824797948527797,
           -0.8180754367395006,
           -0.8115365598648737,
           -0.8051921932852345,
           -0.7990531795118961,
           -0.7931302934901096,
           -0.7874342052801272,
           -0.7819754402301318,
           -0.7767643368114118,
           -0.7718110023458519,
           -0.7671252669183442,
           -0.7627166358306222,
           -0.7585942410164266,
           -0.7547667918987708,
           -0.7512425262260597,
           -0.7480291614724957,
           -0.7451338474271193,
           -0.742563120622624,
           -0.7403228612676322,
           -0.7384182533426684,
           -0.7368537484994381,
           -0.735633034364586,
           -0.7347590077930495,
           -0.7342337535433566,
           -0.7340585287594575,
           -0.7342337535433571,
           -0.7347590077930503,
           -0.7356330343645873,
           -0.7368537484994395,
           -0.7384182533426702,
           -0.7403228612676345,
           -0.7425631206226265,
           -0.745133847427122,
           -0.748029161472499,
           -0.7512425262260631,
           -0.7547667918987746,
           -0.7585942410164307,
           -0.7627166358306265,
           -0.7671252669183488,
           -0.7718110023458568,
           -0.7767643368114171,
           -0.7819754402301373,
           -0.787434205280133,
           -0.7931302934901157,
           -0.7990531795119025,
           -0.8051921932852408,
           -0.8115365598648804,
           -0.8180754367395074,
           -0.8247979485278039,
           -0.8316932189876142,
           -0.8387504003194515,
           -0.8459586997850128,
           -0.8533074036949713,
           -0.860785898848134,
           -0.8683836915264169,
           -0.8760904241673396,
           -0.8838958898483484,
           -0.8917900447257452,
           -0.89976301857584,
           -0.9078051235876926,
           -0.9159068615559431,
           -0.9240589296192553,
           -0.9322522246852061,
           -0.9404778466764777,
           -0.9487271007262513,
           -0.9569914984431066,
           -0.965262758357704,
           -0.973532805655326,
           -0.9817937712901232,
           -0.9900379905688087,
           -0.9982580012836645,
           -1.006446541467175,
           -1.0145965468334044,
           -1.0227011479644827,
           -1.0307536672942224,
           -1.0387476159350284,
           -1.0466766903888343,
           -1.0545347691778233,
           -1.0623159094261723,
           -1.070014343419908,
           -1.0776244751682607,
           -1.085140876986537,
           -1.0925582861175243,
           -1.0998716014057592,
           -1.1070758800365992,
           -1.1141663343499273,
           -1.1211383287364534,
           -1.1279873766229283,
           -1.1347091375511646,
           -1.1412994143545039,
           -1.1477541504342839,
           -1.1540694271379357,
           -1.1602414612395318,
           -1.1662666025229336,
           -1.172141331467106,
           -1.1778622570326898,
           -1.1834261145485165,
           -1.1888297636964409,
           -1.1940701865925796,
           -1.1991444859628664,
           -1.204049883410653,
           -1.2087837177739913,
           -1.2133434435701413,
           -1.2177266295248124,
           -1.2219309571836237,
           -1.2259542196032862,
           -1.2297943201200212,
           -1.233449271192791,
           -1.2369171933189642,
           -1.240196314020123,
           -1.2432849668957895,
           -1.2461815907429505,
           -1.248884728739362,
           -1.2513930276886964,
           -1.2537052373257476,
           -1.255820209679976,
           -1.2577368984958364,
           -1.2594543587084166,
           -1.2609717459730656,
           -1.262288316247788,
           -1.2634034254273385,
           -1.2643165290280345,
           -1.2650271819224757,
           -1.265535038123458,
           -1.2658398506164996
          ],
          [
           -1.2874160358524958,
           -1.2873080411921376,
           -1.2869841073466861,
           -1.2864443847481002,
           -1.2856891242000117,
           -1.2847186770035555,
           -1.2835334951340829,
           -1.2821341314693162,
           -1.2805212400696488,
           -1.27869557651148,
           -1.2766579982746,
           -1.2744094651848372,
           -1.2719510399133143,
           -1.2692838885338462,
           -1.2664092811401586,
           -1.2633285925247844,
           -1.260043302921661,
           -1.256554998814603,
           -1.2528653738140205,
           -1.2489762296043827,
           -1.2448894769651286,
           -1.240607136867862,
           -1.236131341652841,
           -1.2314643362879332,
           -1.2266084797133436,
           -1.2215662462755872,
           -1.2163402272542914,
           -1.2109331324855617,
           -1.2053477920857314,
           -1.1995871582794277,
           -1.1936543073359482,
           -1.1875524416179961,
           -1.1812848917468342,
           -1.1748551188879068,
           -1.168266717160916,
           -1.1615234161782275,
           -1.1546290837153217,
           -1.1475877285167662,
           -1.1404035032408764,
           -1.1330807075458302,
           -1.125623791319496,
           -1.1180373580546061,
           -1.1103261683701509,
           -1.1024951436789405,
           -1.0945493700001965,
           -1.0864941019147272,
           -1.0783347666587209,
           -1.070076968350405,
           -1.0617264923417482,
           -1.0532893096849922,
           -1.0447715817010435,
           -1.0361796646336083,
           -1.0275201143693633,
           -1.0187996912003872,
           -1.0100253646004753,
           -1.0012043179817989,
           -0.9923439533925863,
           -0.9834518961100691,
           -0.974535999075801,
           -0.9656043471126134,
           -0.9566652608538652,
           -0.947727300306286,
           -0.9387992679576173,
           -0.9298902113294096,
           -0.9210094248638538,
           -0.9121664510214322,
           -0.9033710804536407,
           -0.8946333511022125,
           -0.885963546063381,
           -0.8773721900430792,
           -0.8688700442168866,
           -0.8604680992975022,
           -0.8521775666029975,
           -0.844009866911739,
           -0.8359766168853195,
           -0.8280896128398774,
           -0.8203608116496615,
           -0.8128023085754861,
           -0.8054263118257566,
           -0.7982451136799197,
           -0.7912710580343799,
           -0.7845165042698651,
           -0.7779937873874968,
           -0.7717151744187594,
           -0.7656928171821611,
           -0.7599387015362448,
           -0.7544645933638431,
           -0.7492819816146588,
           -0.7444020188303637,
           -0.7398354596758399,
           -0.735592598098717,
           -0.7316832038333356,
           -0.7281164590505406,
           -0.7249008960270449,
           -0.7220443367631566,
           -0.7195538355114293,
           -0.717435625187765,
           -0.715695068618006,
           -0.714336615525487,
           -0.7133637660880872,
           -0.7127790417881182,
           -0.7125839641475042,
           -0.7127790417881187,
           -0.7133637660880878,
           -0.7143366155254882,
           -0.7156950686180076,
           -0.717435625187767,
           -0.7195538355114318,
           -0.7220443367631595,
           -0.724900896027048,
           -0.7281164590505441,
           -0.7316832038333395,
           -0.7355925980987214,
           -0.7398354596758443,
           -0.7444020188303686,
           -0.7492819816146639,
           -0.7544645933638486,
           -0.7599387015362506,
           -0.7656928171821673,
           -0.7717151744187657,
           -0.7779937873875035,
           -0.784516504269872,
           -0.791271058034387,
           -0.7982451136799269,
           -0.8054263118257641,
           -0.8128023085754938,
           -0.8203608116496693,
           -0.8280896128398855,
           -0.8359766168853275,
           -0.8440098669117474,
           -0.8521775666030059,
           -0.860468099297511,
           -0.8688700442168952,
           -0.8773721900430879,
           -0.88596354606339,
           -0.8946333511022214,
           -0.90337108045365,
           -0.9121664510214413,
           -0.921009424863863,
           -0.9298902113294187,
           -0.9387992679576265,
           -0.9477273003062953,
           -0.9566652608538743,
           -0.9656043471126227,
           -0.9745359990758101,
           -0.9834518961100784,
           -0.9923439533925954,
           -1.0012043179818078,
           -1.0100253646004844,
           -1.0187996912003965,
           -1.0275201143693724,
           -1.036179664633617,
           -1.0447715817010523,
           -1.053289309685001,
           -1.0617264923417569,
           -1.0700769683504137,
           -1.0783347666587295,
           -1.0864941019147356,
           -1.0945493700002047,
           -1.1024951436789485,
           -1.1103261683701589,
           -1.1180373580546141,
           -1.1256237913195037,
           -1.133080707545838,
           -1.1404035032408837,
           -1.1475877285167735,
           -1.1546290837153288,
           -1.1615234161782344,
           -1.168266717160923,
           -1.1748551188879135,
           -1.1812848917468406,
           -1.1875524416180026,
           -1.1936543073359545,
           -1.1995871582794337,
           -1.2053477920857374,
           -1.2109331324855672,
           -1.2163402272542971,
           -1.2215662462755923,
           -1.2266084797133487,
           -1.2314643362879378,
           -1.2361313416528457,
           -1.2406071368678662,
           -1.2448894769651329,
           -1.2489762296043867,
           -1.2528653738140243,
           -1.2565549988146067,
           -1.2600433029216642,
           -1.2633285925247877,
           -1.2664092811401613,
           -1.2692838885338493,
           -1.271951039913317,
           -1.2744094651848394,
           -1.2766579982746025,
           -1.278695576511482,
           -1.2805212400696508,
           -1.2821341314693175,
           -1.2835334951340847,
           -1.2847186770035564,
           -1.2856891242000124,
           -1.2864443847481009,
           -1.2869841073466866,
           -1.2873080411921378
          ],
          [
           -1.309579979428256,
           -1.3094656253155794,
           -1.3091226137074161,
           -1.3085510968192304,
           -1.3077513284297604,
           -1.3067236640107895,
           -1.3054685609094747,
           -1.303986578583881,
           -1.3022783788925612,
           -1.3003447264392098,
           -1.2981864889736086,
           -1.2958046378502825,
           -1.2932002485464775,
           -1.2903745012412677,
           -1.2873286814578173,
           -1.284064180771018,
           -1.2805824975829365,
           -1.2768852379687206,
           -1.272974116595846,
           -1.2688509577197757,
           -1.264517696259375,
           -1.2599763789556053,
           -1.255229165617299,
           -1.2502783304580147,
           -1.2451262635282325,
           -1.2397754722473655,
           -1.2342285830403186,
           -1.228488343083534,
           -1.2225576221657108,
           -1.2164394146685875,
           -1.210136841673393,
           -1.2036531531987642,
           -1.1969917305760973,
           -1.1901560889684615,
           -1.1831498800393083,
           -1.1759768947773155,
           -1.1686410664837181,
           -1.1611464739284902,
           -1.1534973446816366,
           -1.1456980586257073,
           -1.1377531516553965,
           -1.1296673195697182,
           -1.1214454221617631,
           -1.1130924875104042,
           -1.1046137164775016,
           -1.0960144874131281,
           -1.0873003610700986,
           -1.0784770857275499,
           -1.069550602521485,
           -1.0605270509780125,
           -1.0514127747424145,
           -1.042214327494132,
           -1.0329384790341916,
           -1.0235922215274584,
           -1.0141827758773072,
           -1.0047175982048002,
           -0.9952043863981545,
           -0.9856510866911021,
           -0.97606590022062,
           -0.966457289505343,
           -0.9568339847757067,
           -0.9472049900754334,
           -0.937579589041312,
           -0.9279673502543091,
           -0.9183781320398605,
           -0.9088220865787695,
           -0.8993096631725321,
           -0.8898516104882659,
           -0.8804589775888972,
           -0.8711431135341828,
           -0.8619156653178217,
           -0.8527885738858937,
           -0.8437740679627074,
           -0.8348846553926562,
           -0.8261331116917326,
           -0.8175324654910526,
           -0.8090959805482989,
           -0.8008371340027979,
           -0.7927695905575037,
           -0.7849071722880948,
           -0.77726382380728,
           -0.7698535725529084,
           -0.7626904840229755,
           -0.7557886118503108,
           -0.7491619426954077,
           -0.7428243360376955,
           -0.736789459063068,
           -0.7310707169772789,
           -0.7256811792184947,
           -0.7206335021943704,
           -0.715939849324853,
           -0.7116118093258228,
           -0.707660313814003,
           -0.7040955554429803,
           -0.700926907886051,
           -0.6981628490563947,
           -0.695810888991984,
           -0.6938775038259961,
           -0.6923680772095053,
           -0.6912868504502759,
           -0.6906368824805678,
           -0.6904200205717438,
           -0.6906368824805681,
           -0.6912868504502768,
           -0.6923680772095068,
           -0.6938775038259979,
           -0.6958108889919861,
           -0.6981628490563973,
           -0.700926907886054,
           -0.7040955554429837,
           -0.7076603138140068,
           -0.7116118093258271,
           -0.7159398493248577,
           -0.7206335021943754,
           -0.7256811792185002,
           -0.7310707169772845,
           -0.7367894590630741,
           -0.7428243360377019,
           -0.7491619426954146,
           -0.7557886118503178,
           -0.7626904840229829,
           -0.769853572552916,
           -0.7772638238072878,
           -0.7849071722881028,
           -0.7927695905575118,
           -0.8008371340028062,
           -0.8090959805483074,
           -0.8175324654910614,
           -0.8261331116917415,
           -0.8348846553926653,
           -0.8437740679627166,
           -0.8527885738859029,
           -0.8619156653178311,
           -0.8711431135341923,
           -0.8804589775889069,
           -0.8898516104882755,
           -0.8993096631725419,
           -0.908822086578779,
           -0.9183781320398704,
           -0.927967350254319,
           -0.937579589041322,
           -0.9472049900754432,
           -0.9568339847757167,
           -0.9664572895053529,
           -0.97606590022063,
           -0.9856510866911121,
           -0.9952043863981643,
           -1.00471759820481,
           -1.014182775877317,
           -1.0235922215274682,
           -1.0329384790342013,
           -1.0422143274941416,
           -1.051412774742424,
           -1.0605270509780218,
           -1.069550602521494,
           -1.0784770857275592,
           -1.0873003610701075,
           -1.096014487413137,
           -1.1046137164775105,
           -1.113092487510413,
           -1.1214454221617713,
           -1.1296673195697267,
           -1.137753151655405,
           -1.1456980586257153,
           -1.1534973446816446,
           -1.1611464739284982,
           -1.1686410664837257,
           -1.1759768947773226,
           -1.1831498800393156,
           -1.1901560889684686,
           -1.1969917305761044,
           -1.2036531531987709,
           -1.2101368416733995,
           -1.216439414668594,
           -1.222557622165717,
           -1.22848834308354,
           -1.2342285830403243,
           -1.2397754722473713,
           -1.2451262635282379,
           -1.2502783304580196,
           -1.2552291656173034,
           -1.2599763789556098,
           -1.2645176962593794,
           -1.2688509577197802,
           -1.2729741165958497,
           -1.2768852379687243,
           -1.2805824975829398,
           -1.2840641807710218,
           -1.2873286814578202,
           -1.2903745012412706,
           -1.2932002485464802,
           -1.295804637850285,
           -1.2981864889736106,
           -1.3003447264392118,
           -1.302278378892563,
           -1.303986578583883,
           -1.305468560909476,
           -1.3067236640107904,
           -1.3077513284297613,
           -1.3085510968192309,
           -1.3091226137074163,
           -1.3094656253155794
          ],
          [
           -1.3324118597838495,
           -1.3322911757895854,
           -1.3319291749878712,
           -1.3313260109480605,
           -1.3304819397062395,
           -1.3293973198963358,
           -1.3280726129344027,
           -1.3265083832568134,
           -1.3247052986133068,
           -1.3226641304160567,
           -1.32038575414614,
           -1.3178711498190152,
           -1.3151214025108477,
           -1.3121377029477492,
           -1.3089213481602395,
           -1.3054737422054972,
           -1.3017963969601933,
           -1.2978909329869905,
           -1.2937590804780439,
           -1.2894026802791156,
           -1.2848236849982102,
           -1.280024160202923,
           -1.2750062857110025,
           -1.2697723569789379,
           -1.2643247865937033,
           -1.2586661058731172,
           -1.252798966580621,
           -1.246726142760607,
           -1.2404505327007964,
           -1.2339751610285004,
           -1.227303180947964,
           -1.2204378766263433,
           -1.2133826657362121,
           -1.2061411021628428,
           -1.1987168788848195,
           -1.191113831036873,
           -1.1833359391640879,
           -1.1753873326768896,
           -1.1672722935164257,
           -1.1589952600400941,
           -1.150560831137049,
           -1.141973770583507,
           -1.1332390116475484,
           -1.1243616619528647,
           -1.1153470086105013,
           -1.1062005236270451,
           -1.0969278695969027,
           -1.0875349056852408,
           -1.0780276939067748,
           -1.068412505703862,
           -1.0586958288251904,
           -1.048884374503714,
           -1.0389850849292783,
           -1.0290051410075394,
           -1.0189519703921763,
           -1.008833255771986,
           -0.9986569433880463,
           -0.9884312517487047,
           -0.9781646805014464,
           -0.9678660194107411,
           -0.9575443573794338,
           -0.9472090914381726,
           -0.9368699356124627,
           -0.9265369295601814,
           -0.9162204468536009,
           -0.9059312027591012,
           -0.895680261344733,
           -0.8854790417206629,
           -0.8753393231903324,
           -0.8652732490611216,
           -0.8552933288326816,
           -0.8454124384493737,
           -0.8356438182710343,
           -0.8260010683844283,
           -0.8164981408473421,
           -0.8071493284296506,
           -0.7979692493925505,
           -0.7889728278303981,
           -0.7801752690915426,
           -0.7715920297977048,
           -0.7632387819986027,
           -0.7551313710325698,
           -0.747285766717754,
           -0.7397180075748567,
           -0.732444137883613,
           -0.7254801375029981,
           -0.7188418445401499,
           -0.7125448711346476,
           -0.706604512830845,
           -0.7010356522373249,
           -0.6958526579130229,
           -0.6910692796658242,
           -0.6866985416910745,
           -0.6827526352023418,
           -0.6792428124016535,
           -0.6761792837875922,
           -0.6735711208939659,
           -0.6714261665778576,
           -0.6697509549250672,
           -0.6685506427085716,
           -0.6678289541215771,
           -0.6675881402161504,
           -0.6678289541215776,
           -0.6685506427085726,
           -0.6697509549250686,
           -0.6714261665778595,
           -0.6735711208939683,
           -0.6761792837875952,
           -0.6792428124016568,
           -0.6827526352023454,
           -0.6866985416910788,
           -0.691069279665829,
           -0.6958526579130281,
           -0.7010356522373306,
           -0.7066045128308509,
           -0.7125448711346538,
           -0.7188418445401565,
           -0.7254801375030052,
           -0.7324441378836204,
           -0.7397180075748643,
           -0.7472857667177621,
           -0.755131371032578,
           -0.7632387819986111,
           -0.7715920297977134,
           -0.7801752690915514,
           -0.7889728278304072,
           -0.7979692493925598,
           -0.8071493284296601,
           -0.8164981408473517,
           -0.8260010683844382,
           -0.8356438182710442,
           -0.8454124384493837,
           -0.8552933288326917,
           -0.8652732490611317,
           -0.8753393231903427,
           -0.8854790417206733,
           -0.8956802613447437,
           -0.9059312027591119,
           -0.9162204468536116,
           -0.926536929560192,
           -0.9368699356124732,
           -0.9472090914381833,
           -0.9575443573794443,
           -0.9678660194107516,
           -0.9781646805014572,
           -0.988431251748715,
           -0.9986569433880569,
           -1.0088332557719963,
           -1.0189519703921868,
           -1.0290051410075496,
           -1.0389850849292883,
           -1.0488843745037242,
           -1.0586958288252006,
           -1.0684125057038718,
           -1.0780276939067845,
           -1.0875349056852506,
           -1.0969278695969127,
           -1.1062005236270545,
           -1.1153470086105108,
           -1.1243616619528738,
           -1.1332390116475572,
           -1.141973770583516,
           -1.1505608311370576,
           -1.1589952600401026,
           -1.1672722935164341,
           -1.175387332676898,
           -1.183335939164096,
           -1.1911138310368807,
           -1.198716878884827,
           -1.2061411021628503,
           -1.2133826657362197,
           -1.2204378766263502,
           -1.2273031809479709,
           -1.2339751610285072,
           -1.240450532700803,
           -1.246726142760613,
           -1.2527989665806272,
           -1.2586661058731232,
           -1.2643247865937088,
           -1.2697723569789434,
           -1.2750062857110076,
           -1.2800241602029279,
           -1.284823684998215,
           -1.2894026802791203,
           -1.2937590804780483,
           -1.2978909329869945,
           -1.3017963969601969,
           -1.3054737422055012,
           -1.3089213481602426,
           -1.3121377029477521,
           -1.3151214025108506,
           -1.3178711498190177,
           -1.3203857541461423,
           -1.3226641304160591,
           -1.3247052986133088,
           -1.3265083832568154,
           -1.3280726129344043,
           -1.329397319896337,
           -1.3304819397062402,
           -1.3313260109480607,
           -1.3319291749878712,
           -1.3322911757895854
          ],
          [
           -1.3558895885496056,
           -1.3557626179184399,
           -1.3553817575343081,
           -1.3547471619511744,
           -1.3538590888453201,
           -1.3527178991452522,
           -1.3513240572143785,
           -1.349678131087241,
           -1.3477807927603527,
           -1.345632818538912,
           -1.343235089440905,
           -1.3405885916603715,
           -1.3376944170918468,
           -1.3345537639182776,
           -1.3311679372649512,
           -1.3275383499222877,
           -1.323666523140618,
           -1.3195540875003768,
           -1.3152027838614524,
           -1.310614464395769,
           -1.305791093707504,
           -1.300734750045717,
           -1.2954476266145136,
           -1.2899320329862807,
           -1.2841903966239085,
           -1.2782252645183525,
           -1.2720393049483116,
           -1.2656353093692716,
           -1.2590161944396123,
           -1.2521850041919882,
           -1.2451449123586844,
           -1.2378992248601726,
           -1.2304513824666288,
           -1.2228049636427183,
           -1.2149636875864969,
           -1.2069314174738488,
           -1.1987121639204181,
           -1.1903100886735485,
           -1.1817295085472657,
           -1.1729748996138496,
           -1.164050901665991,
           -1.1549623229639572,
           -1.145714145282512,
           -1.1363115292725925,
           -1.1267598201528786,
           -1.1170645537463513,
           -1.107231462876767,
           -1.097266484139519,
           -1.0871757650606786,
           -1.076965671656968,
           -1.0666427964079968,
           -1.056213966650192,
           -1.0456862533993931,
           -1.0350669806059567,
           -1.0243637348423178,
           -1.0135843754181386,
           -1.0027370449123083,
           -0.9918301801039615,
           -0.9808725232761829,
           -0.9698731338559534,
           -0.9588414003419461,
           -0.9477870524577754,
           -0.9367201734519676,
           -0.9256512124470223,
           -0.914590996718191,
           -0.9035507437577777,
           -0.8925420729526261,
           -0.8815770166708217,
           -0.870668030518369,
           -0.8598280024876878,
           -0.8490702606772833,
           -0.8384085792161776,
           -0.8278571819780972,
           -0.8174307436197898,
           -0.8071443874262861,
           -0.7970136793949166,
           -0.7870546179414711,
           -0.7772836185684963,
           -0.7677174928005018,
           -0.7583734206674385,
           -0.7492689160104764,
           -0.7404217838976433,
           -0.7318500694763926,
           -0.7235719976609755,
           -0.7156059031597333,
           -0.7079701504956529,
           -0.7006830438662119,
           -0.6937627269274311,
           -0.687227072871528,
           -0.6810935654939891,
           -0.6753791723069892,
           -0.6701002111406137,
           -0.6652722120658846,
           -0.6609097768548198,
           -0.6570264385402351,
           -0.6536345239273117,
           -0.6507450221154736,
           -0.6483674621901795,
           -0.6465098032213065,
           -0.6451783395459152,
           -0.6443776240147955,
           -0.6441104114503944,
           -0.6443776240147959,
           -0.6451783395459163,
           -0.646509803221308,
           -0.6483674621901817,
           -0.6507450221154762,
           -0.653634523927315,
           -0.6570264385402389,
           -0.6609097768548239,
           -0.6652722120658894,
           -0.6701002111406189,
           -0.6753791723069948,
           -0.6810935654939954,
           -0.6872270728715345,
           -0.693762726927438,
           -0.7006830438662193,
           -0.7079701504956607,
           -0.7156059031597414,
           -0.7235719976609838,
           -0.7318500694764014,
           -0.7404217838976523,
           -0.7492689160104856,
           -0.7583734206674481,
           -0.7677174928005116,
           -0.7772836185685061,
           -0.7870546179414813,
           -0.797013679394927,
           -0.8071443874262967,
           -0.8174307436198006,
           -0.827857181978108,
           -0.8384085792161885,
           -0.8490702606772943,
           -0.8598280024876989,
           -0.8706680305183803,
           -0.8815770166708329,
           -0.8925420729526373,
           -0.903550743757789,
           -0.9145909967182023,
           -0.9256512124470335,
           -0.9367201734519788,
           -0.9477870524577867,
           -0.9588414003419573,
           -0.9698731338559645,
           -0.9808725232761942,
           -0.9918301801039728,
           -1.0027370449123194,
           -1.0135843754181497,
           -1.024363734842329,
           -1.0350669806059676,
           -1.045686253399404,
           -1.0562139666502026,
           -1.0666427964080072,
           -1.0769656716569784,
           -1.087175765060689,
           -1.0972664841395294,
           -1.1072314628767772,
           -1.1170645537463615,
           -1.1267598201528886,
           -1.1363115292726023,
           -1.145714145282521,
           -1.1549623229639665,
           -1.1640509016660003,
           -1.1729748996138585,
           -1.1817295085472748,
           -1.1903100886735571,
           -1.1987121639204268,
           -1.2069314174738572,
           -1.214963687586505,
           -1.222804963642726,
           -1.2304513824666368,
           -1.2378992248601801,
           -1.2451449123586917,
           -1.2521850041919953,
           -1.2590161944396192,
           -1.2656353093692783,
           -1.272039304948318,
           -1.2782252645183587,
           -1.2841903966239148,
           -1.2899320329862864,
           -1.2954476266145194,
           -1.3007347500457223,
           -1.3057910937075092,
           -1.3106144643957736,
           -1.315202783861457,
           -1.319554087500381,
           -1.3236665231406222,
           -1.3275383499222917,
           -1.3311679372649545,
           -1.3345537639182812,
           -1.3376944170918497,
           -1.3405885916603741,
           -1.343235089440908,
           -1.3456328185389141,
           -1.347780792760355,
           -1.3496781310872425,
           -1.3513240572143803,
           -1.3527178991452535,
           -1.3538590888453208,
           -1.3547471619511753,
           -1.3553817575343088,
           -1.3557626179184403
          ],
          [
           -1.3799904525392286,
           -1.3798572509060085,
           -1.379457697741481,
           -1.378791948276185,
           -1.3778602613116093,
           -1.3766629993465018,
           -1.375200628754553,
           -1.3734737200143028,
           -1.3714829479923782,
           -1.3692290922814172,
           -1.3667130375943028,
           -1.3639357742165896,
           -1.3608983985192933,
           -1.357602113534491,
           -1.3540482295964786,
           -1.3502381650515458,
           -1.3461734470397477,
           -1.3418557123523815,
           -1.3372867083692503,
           -1.3324682940801373,
           -1.3274024411953333,
           -1.3220912353504433,
           -1.3165368774111477,
           -1.3107416848840352,
           -1.3047080934401152,
           -1.2984386585581096,
           -1.291936057295162,
           -1.285203090193173,
           -1.2782426833295373,
           -1.271057890521706,
           -1.2636518956956357,
           -1.2560280154288725,
           -1.2481897016797454,
           -1.2401405447148857,
           -1.2318842762480715,
           -1.2234247728042158,
           -1.214766059323141,
           -1.2059123130186562,
           -1.1968678675093263,
           -1.18763721723822,
           -1.1782250221998083,
           -1.1686361129930873,
           -1.1588754962208476,
           -1.1489483602558497,
           -1.1388600813954308,
           -1.1286162304267318,
           -1.1182225796253142,
           -1.1076851102103167,
           -1.097010020279504,
           -1.086203733247499,
           -1.0752729068100804,
           -1.0642244424566292,
           -1.0530654955514966,
           -1.0418034860031358,
           -1.0304461095371664,
           -1.0190013495859713,
           -1.0074774898027636,
           -0.9958831272021412,
           -0.984227185921684,
           -0.9725189315899244,
           -0.9607679862746944,
           -0.9489843439721147,
           -0.9371783865799409,
           -0.9253609002792378,
           -0.9135430922249475,
           -0.9017366074184031,
           -0.8899535456027339,
           -0.8782064779849269,
           -0.8665084635456205,
           -0.854873064649105,
           -0.8433143616112164,
           -0.83184696582169,
           -0.8204860309502146,
           -0.8092472616922657,
           -0.7981469194326598,
           -0.787201824122987,
           -0.7764293515856701,
           -0.7658474253751764,
           -0.7554745022496049,
           -0.745329550238304,
           -0.7354320182392565,
           -0.7258017960508211,
           -0.7164591637442409,
           -0.7074247293252228,
           -0.6987193537245208,
           -0.6903640623084705,
           -0.6823799423196467,
           -0.6747880259522785,
           -0.6676091591407458,
           -0.6608638565919258,
           -0.6545721441171508,
           -0.6487533899038108,
           -0.6434261269890571,
           -0.6386078698294189,
           -0.6343149284637757,
           -0.6305622243006754,
           -0.6273631119792011,
           -0.6247292120112828,
           -0.6226702589739583,
           -0.6211939698545916,
           -0.6203059367473825,
           -0.6200095474607715,
           -0.6203059367473831,
           -0.6211939698545929,
           -0.62267025897396,
           -0.6247292120112853,
           -0.627363111979204,
           -0.6305622243006791,
           -0.6343149284637799,
           -0.6386078698294235,
           -0.6434261269890623,
           -0.6487533899038165,
           -0.6545721441171571,
           -0.6608638565919325,
           -0.6676091591407529,
           -0.674788025952286,
           -0.6823799423196547,
           -0.690364062308479,
           -0.6987193537245295,
           -0.7074247293252319,
           -0.7164591637442506,
           -0.7258017960508308,
           -0.7354320182392665,
           -0.7453295502383143,
           -0.7554745022496154,
           -0.7658474253751871,
           -0.7764293515856812,
           -0.7872018241229982,
           -0.7981469194326712,
           -0.8092472616922771,
           -0.8204860309502262,
           -0.8318469658217017,
           -0.8433143616112282,
           -0.8548730646491169,
           -0.8665084635456324,
           -0.878206477984939,
           -0.8899535456027461,
           -0.9017366074184152,
           -0.9135430922249596,
           -0.9253609002792499,
           -0.937178386579953,
           -0.9489843439721269,
           -0.9607679862747066,
           -0.9725189315899364,
           -0.984227185921696,
           -0.9958831272021532,
           -1.0074774898027756,
           -1.0190013495859829,
           -1.030446109537178,
           -1.041803486003147,
           -1.0530654955515082,
           -1.0642244424566405,
           -1.0752729068100915,
           -1.0862037332475103,
           -1.0970100202795148,
           -1.1076851102103276,
           -1.1182225796253251,
           -1.1286162304267422,
           -1.138860081395441,
           -1.14894836025586,
           -1.1588754962208576,
           -1.1686361129930973,
           -1.178225022199818,
           -1.1876372172382297,
           -1.1968678675093358,
           -1.2059123130186653,
           -1.2147660593231502,
           -1.2234247728042245,
           -1.23188427624808,
           -1.2401405447148939,
           -1.2481897016797538,
           -1.2560280154288803,
           -1.2636518956956435,
           -1.2710578905217134,
           -1.2782426833295444,
           -1.2852030901931801,
           -1.291936057295169,
           -1.298438658558116,
           -1.3047080934401214,
           -1.3107416848840412,
           -1.3165368774111534,
           -1.322091235350449,
           -1.327402441195339,
           -1.3324682940801424,
           -1.3372867083692552,
           -1.3418557123523862,
           -1.3461734470397517,
           -1.3502381650515496,
           -1.354048229596482,
           -1.357602113534495,
           -1.3608983985192966,
           -1.3639357742165923,
           -1.3667130375943055,
           -1.3692290922814196,
           -1.3714829479923807,
           -1.3734737200143048,
           -1.3752006287545548,
           -1.3766629993465032,
           -1.37786026131161,
           -1.378791948276186,
           -1.3794576977414816,
           -1.379857250906009
          ],
          [
           -1.4046911357233376,
           -1.404551769869118,
           -1.4041337241850638,
           -1.40343715433097,
           -1.4024623198198718,
           -1.4012095841385512,
           -1.3996794149171257,
           -1.3978723841486103,
           -1.3957891684595902,
           -1.3934305494334318,
           -1.390797413987707,
           -1.3878907548078054,
           -1.3847116708389988,
           -1.381261367839516,
           -1.3775411589975122,
           -1.3735524656151448,
           -1.3692968178633123,
           -1.3647758556109741,
           -1.359991329333367,
           -1.3549451011038187,
           -1.3496391456743055,
           -1.3440755516503462,
           -1.338256522766312,
           -1.3321843792677355,
           -1.3258615594077607,
           -1.3192906210654374,
           -1.3124742434941965,
           -1.3054152292094858,
           -1.2981165060252555,
           -1.290581129249715,
           -1.2828122840515794,
           -1.2748132880088718,
           -1.2665875938532227,
           -1.258138792423577,
           -1.2494706158442068,
           -1.2405869409430013,
           -1.231491792927119,
           -1.2221893493342741,
           -1.21268394427916,
           -1.2029800730158116,
           -1.1930823968380517,
           -1.1829957483415667,
           -1.1727251370725704,
           -1.1622757555894996,
           -1.151652985965633,
           -1.1408624067620043,
           -1.1299098005014045,
           -1.1188011616756508,
           -1.1075427053195426,
           -1.0961408761860705,
           -1.0846023585583076,
           -1.0729340867340518,
           -1.061143256219494,
           -1.0492373356679345,
           -1.037224079598662,
           -1.0251115419294394,
           -1.0129080903533567,
           -1.0006224215869433,
           -0.988263577511048,
           -0.9758409622188436,
           -0.963364359975941,
           -0.950843954085657,
           -0.9382903466374097,
           -0.9257145790974758,
           -0.9131281536783002,
           -0.9005430553944817,
           -0.8879717746796714,
           -0.8754273303981189,
           -0.8629232930365376,
           -0.8504738078054975,
           -0.8380936173137751,
           -0.8257980834032306,
           -0.8136032076452319,
           -0.8015256499020241,
           -0.7895827442478881,
           -0.777792511426034,
           -0.7661736668894673,
           -0.7547456233400109,
           -0.7435284865431314,
           -0.7325430430626597,
           -0.7218107384362604,
           -0.7113536442091325,
           -0.7011944121717203,
           -0.691356214121305,
           -0.6818626655034113,
           -0.672737731404662,
           -0.6640056135821747,
           -0.6556906175429656,
           -0.6478169991441983,
           -0.6404087907800399,
           -0.6334896079535207,
           -0.6270824378908983,
           -0.6212094128164266,
           -0.615891571526167,
           -0.611148613923624,
           -0.606998654136349,
           -0.6034579786400677,
           -0.600540816390986,
           -0.5982591282291296,
           -0.5966224227032313,
           -0.595637604944163,
           -0.5953088642766623,
           -0.5956376049441636,
           -0.5966224227032325,
           -0.5982591282291317,
           -0.6005408163909887,
           -0.6034579786400711,
           -0.6069986541363531,
           -0.6111486139236285,
           -0.6158915715261722,
           -0.6212094128164325,
           -0.6270824378909047,
           -0.6334896079535276,
           -0.6404087907800472,
           -0.6478169991442061,
           -0.655690617542974,
           -0.6640056135821835,
           -0.6727377314046712,
           -0.6818626655034209,
           -0.6913562141213149,
           -0.7011944121717307,
           -0.7113536442091432,
           -0.7218107384362713,
           -0.7325430430626708,
           -0.7435284865431429,
           -0.7547456233400225,
           -0.7661736668894793,
           -0.7777925114260462,
           -0.7895827442479003,
           -0.8015256499020365,
           -0.8136032076452443,
           -0.8257980834032431,
           -0.8380936173137876,
           -0.8504738078055103,
           -0.8629232930365504,
           -0.8754273303981316,
           -0.8879717746796844,
           -0.9005430553944945,
           -0.9131281536783133,
           -0.9257145790974887,
           -0.9382903466374227,
           -0.9508439540856699,
           -0.9633643599759539,
           -0.9758409622188566,
           -0.9882635775110608,
           -1.000622421586956,
           -1.0129080903533694,
           -1.0251115419294519,
           -1.0372240795986745,
           -1.0492373356679467,
           -1.061143256219506,
           -1.0729340867340638,
           -1.0846023585583193,
           -1.0961408761860825,
           -1.1075427053195541,
           -1.1188011616756623,
           -1.129909800501416,
           -1.1408624067620152,
           -1.1516529859656441,
           -1.1622757555895102,
           -1.1727251370725806,
           -1.182995748341577,
           -1.1930823968380622,
           -1.2029800730158215,
           -1.21268394427917,
           -1.222189349334284,
           -1.2314917929271283,
           -1.2405869409430104,
           -1.2494706158442157,
           -1.2581387924235858,
           -1.2665875938532316,
           -1.2748132880088803,
           -1.2828122840515874,
           -1.290581129249723,
           -1.2981165060252633,
           -1.3054152292094932,
           -1.3124742434942036,
           -1.3192906210654445,
           -1.3258615594077674,
           -1.3321843792677417,
           -1.338256522766318,
           -1.3440755516503518,
           -1.349639145674311,
           -1.3549451011038243,
           -1.359991329333372,
           -1.3647758556109786,
           -1.3692968178633165,
           -1.3735524656151492,
           -1.377541158997516,
           -1.3812613678395196,
           -1.3847116708390022,
           -1.3878907548078085,
           -1.39079741398771,
           -1.3934305494334347,
           -1.3957891684595929,
           -1.3978723841486125,
           -1.3996794149171277,
           -1.4012095841385523,
           -1.402462319819873,
           -1.4034371543309705,
           -1.404133724185064,
           -1.404551769869118
          ],
          [
           -1.4299677417862213,
           -1.42982228844288,
           -1.429385980372285,
           -1.4286589734751496,
           -1.4276415276608563,
           -1.4263340069602024,
           -1.4247368796841338,
           -1.4228507186293737,
           -1.4206762013321101,
           -1.4182141103711887,
           -1.4154653337225196,
           -1.412430865166723,
           -1.409111804752306,
           -1.405509359317015,
           -1.401624843070296,
           -1.3974596782401776,
           -1.3930153957882234,
           -1.3882936361966067,
           -1.3832961503317538,
           -1.3780248003894313,
           -1.372481560926634,
           -1.36666851998608,
           -1.3605878803196834,
           -1.3542419607179028,
           -1.3476331974524753,
           -1.3407641458406823,
           -1.3336374819399766,
           -1.3262560043825422,
           -1.318622636360146,
           -1.3107404277704844,
           -1.3026125575371428,
           -1.29424233611627,
           -1.2856332082041089,
           -1.2767887556606567,
           -1.2677127006659432,
           -1.2584089091266986,
           -1.248881394352582,
           -1.2391343210226164,
           -1.229172009464062,
           -1.218998940267644,
           -1.208619759264847,
           -1.1980392828948845,
           -1.1872625039909537,
           -1.1762945980175086,
           -1.1651409297924804,
           -1.1538070607306792,
           -1.1422987566469869,
           -1.1306219961603765,
           -1.1187829797422624,
           -1.1067881394551298,
           -1.0946441494298,
           -1.0823579371319734,
           -1.0699366954707759,
           -1.0573878958038512,
           -1.0447193018949144,
           -1.031938984880511,
           -1.019055339302779,
           -1.0060771002640831,
           -0.9930133617571819,
           -0.9798735962207591,
           -0.9666676753642811,
           -0.9534058922977429,
           -0.9400989849903221,
           -0.9267581610666036,
           -0.9133951239290101,
           -0.900022100169448,
           -0.8866518682008319,
           -0.8732977879988782,
           -0.8599738317948898,
           -0.8466946154997589,
           -0.833475430566357,
           -0.8203322759102062,
           -0.8072818894051333,
           -0.7943417783499067,
           -0.7815302481623662,
           -0.7688664283985056,
           -0.7563702950153324,
           -0.7440626875993,
           -0.7319653200694739,
           -0.7201007831412686,
           -0.7084925366103267,
           -0.6971648892979819,
           -0.6861429643049217,
           -0.6754526470677488,
           -0.6651205136285316,
           -0.6551737365389876,
           -0.6456399659611685,
           -0.6365471838297986,
           -0.6279235294410888,
           -0.6197970955572306,
           -0.61219569508276,
           -0.6051465995800331,
           -0.5986762523246933,
           -0.5928099602081998,
           -0.5875715704910828,
           -0.5829831400833138,
           -0.5790646065356932,
           -0.575833471110929,
           -0.573304505007955,
           -0.5714894899021729,
           -0.5703970033454343,
           -0.5700322582137787,
           -0.5703970033454351,
           -0.5714894899021743,
           -0.5733045050079572,
           -0.5758334711109319,
           -0.5790646065356968,
           -0.5829831400833183,
           -0.5875715704910879,
           -0.5928099602082054,
           -0.5986762523246997,
           -0.60514659958004,
           -0.6121956950827675,
           -0.6197970955572386,
           -0.6279235294410974,
           -0.6365471838298077,
           -0.6456399659611781,
           -0.6551737365389976,
           -0.6651205136285421,
           -0.6754526470677595,
           -0.686142964304933,
           -0.6971648892979935,
           -0.7084925366103384,
           -0.7201007831412806,
           -0.731965320069486,
           -0.7440626875993125,
           -0.756370295015345,
           -0.7688664283985187,
           -0.7815302481623793,
           -0.79434177834992,
           -0.8072818894051468,
           -0.8203322759102195,
           -0.8334754305663705,
           -0.8466946154997725,
           -0.8599738317949034,
           -0.873297787998892,
           -0.8866518682008458,
           -0.9000221001694616,
           -0.913395123929024,
           -0.9267581610666173,
           -0.9400989849903358,
           -0.9534058922977566,
           -0.9666676753642948,
           -0.9798735962207724,
           -0.9930133617571953,
           -1.0060771002640967,
           -1.0190553393027924,
           -1.031938984880524,
           -1.0447193018949275,
           -1.0573878958038643,
           -1.0699366954707887,
           -1.0823579371319862,
           -1.0946441494298125,
           -1.106788139455142,
           -1.1187829797422746,
           -1.1306219961603887,
           -1.1422987566469986,
           -1.153807060730691,
           -1.165140929792492,
           -1.17629459801752,
           -1.1872625039909648,
           -1.1980392828948956,
           -1.2086197592648578,
           -1.2189989402676542,
           -1.2291720094640721,
           -1.2391343210226267,
           -1.2488813943525918,
           -1.258408909126708,
           -1.2677127006659528,
           -1.2767887556606659,
           -1.285633208204118,
           -1.2942423361162787,
           -1.3026125575371512,
           -1.3107404277704926,
           -1.318622636360154,
           -1.32625600438255,
           -1.333637481939984,
           -1.3407641458406896,
           -1.3476331974524822,
           -1.3542419607179093,
           -1.3605878803196896,
           -1.366668519986086,
           -1.3724815609266399,
           -1.378024800389437,
           -1.383296150331759,
           -1.3882936361966118,
           -1.3930153957882279,
           -1.397459678240182,
           -1.4016248430703002,
           -1.405509359317019,
           -1.4091118047523095,
           -1.4124308651667261,
           -1.4154653337225227,
           -1.4182141103711912,
           -1.4206762013321128,
           -1.4228507186293757,
           -1.4247368796841355,
           -1.4263340069602037,
           -1.4276415276608572,
           -1.4286589734751503,
           -1.4293859803722857,
           -1.4298222884428802
          ],
          [
           -1.4557958172439769,
           -1.4556443619541763,
           -1.4551900480811135,
           -1.4544330316343368,
           -1.4533735726983266,
           -1.4520120355357886,
           -1.4503488887331604,
           -1.4483847053892238,
           -1.4461201633479899,
           -1.443556045477297,
           -1.4406932399948373,
           -1.437532740843619,
           -1.4340756481191856,
           -1.4303231685512154,
           -1.426276616042469,
           -1.421937412268401,
           -1.4173070873411218,
           -1.4123872805417885,
           -1.407179741125931,
           -1.4016863292066524,
           -1.3959090167211359,
           -1.389849888486391,
           -1.3835111433507261,
           -1.3768950954480232,
           -1.3700041755625276,
           -1.362840932612546,
           -1.355408035262189,
           -1.3477082736710932,
           -1.3397445613929089,
           -1.3315199374342863,
           -1.3230375684870912,
           -1.3143007513476748,
           -1.3053129155382048,
           -1.2960776261463427,
           -1.2865985869009346,
           -1.2768796435028882,
           -1.2669247872320184,
           -1.2567381588524125,
           -1.246324052840745,
           -1.2356869219640316,
           -1.2248313822355086,
           -1.2137622182797085,
           -1.2024843891403525,
           -1.1910030345674176,
           -1.1793234818226868,
           -1.1674512530461907,
           -1.1553920732293128,
           -1.1431518788438157,
           -1.13073682717978,
           -1.1181533064493079,
           -1.1054079467168758,
           -1.092507631721342,
           -1.0794595116588095,
           -1.0662710169997118,
           -1.0529498734175569,
           -1.039504117910586,
           -1.025942116201043,
           -1.0122725814995734,
           -0.9985045947242295,
           -0.9846476262643146,
           -0.9707115593784369,
           -0.9567067153131357,
           -0.9426438802226709,
           -0.9285343339612249,
           -0.9143898808049249,
           -0.9002228821415849,
           -0.8860462911395398,
           -0.8718736893717547,
           -0.8577193253256323,
           -0.8435981546704262,
           -0.8295258820803212,
           -0.8155190043193128,
           -0.8015948541808336,
           -0.7877716447374328,
           -0.7740685131903248,
           -0.7605055634121894,
           -0.7471039060465189,
           -0.7338856947614106,
           -0.7208741569548589,
           -0.7080936168746098,
           -0.6955695087542058,
           -0.6833283771883271,
           -0.6713978615913083,
           -0.6598066612265745,
           -0.648584476994303,
           -0.6377619259620544,
           -0.627370424570402,
           -0.6174420366031512,
           -0.6080092824454373,
           -0.5991049069284459,
           -0.590761604233753,
           -0.5830116999403899,
           -0.5758867923473787,
           -0.5694173576495442,
           -0.563632326280863,
           -0.558558640596216,
           -0.5542208068030497,
           -0.5506404563926544,
           -0.5478359339484408,
           -0.5458219288375057,
           -0.5446091677021494,
           -0.5442041827560231,
           -0.5446091677021503,
           -0.5458219288375072,
           -0.5478359339484433,
           -0.5506404563926575,
           -0.5542208068030537,
           -0.5585586405962207,
           -0.5636323262808686,
           -0.5694173576495505,
           -0.5758867923473858,
           -0.5830116999403977,
           -0.5907616042337612,
           -0.5991049069284548,
           -0.6080092824454467,
           -0.6174420366031613,
           -0.6273704245704126,
           -0.6377619259620653,
           -0.6485844769943143,
           -0.6598066612265863,
           -0.6713978615913205,
           -0.6833283771883396,
           -0.6955695087542183,
           -0.7080936168746228,
           -0.7208741569548721,
           -0.7338856947614241,
           -0.7471039060465325,
           -0.7605055634122032,
           -0.7740685131903389,
           -0.787771644737447,
           -0.801594854180848,
           -0.8155190043193269,
           -0.8295258820803355,
           -0.8435981546704407,
           -0.857719325325647,
           -0.8718736893717691,
           -0.8860462911395545,
           -0.9002228821415993,
           -0.9143898808049394,
           -0.9285343339612393,
           -0.9426438802226854,
           -0.9567067153131503,
           -0.9707115593784512,
           -0.9846476262643288,
           -0.9985045947242436,
           -1.0122725814995877,
           -1.025942116201057,
           -1.0395041179105997,
           -1.0529498734175706,
           -1.0662710169997252,
           -1.0794595116588228,
           -1.0925076317213553,
           -1.105407946716889,
           -1.1181533064493208,
           -1.1307368271797926,
           -1.1431518788438286,
           -1.1553920732293255,
           -1.1674512530462031,
           -1.1793234818226987,
           -1.1910030345674296,
           -1.202484389140364,
           -1.21376221827972,
           -1.2248313822355197,
           -1.2356869219640427,
           -1.246324052840756,
           -1.2567381588524231,
           -1.2669247872320286,
           -1.276879643502898,
           -1.2865985869009446,
           -1.2960776261463522,
           -1.3053129155382144,
           -1.314300751347684,
           -1.3230375684871,
           -1.331519937434295,
           -1.3397445613929173,
           -1.3477082736711012,
           -1.3554080352621969,
           -1.3628409326125532,
           -1.370004175562535,
           -1.3768950954480301,
           -1.383511143350733,
           -1.3898498884863972,
           -1.395909016721142,
           -1.4016863292066581,
           -1.4071797411259366,
           -1.4123872805417936,
           -1.4173070873411264,
           -1.4219374122684056,
           -1.426276616042473,
           -1.4303231685512194,
           -1.4340756481191894,
           -1.4375327408436225,
           -1.4406932399948402,
           -1.4435560454773,
           -1.4461201633479923,
           -1.448384705389226,
           -1.4503488887331628,
           -1.45201203553579,
           -1.4533735726983275,
           -1.4544330316343377,
           -1.4551900480811142,
           -1.4556443619541768
          ],
          [
           -1.482150375101679,
           -1.4819930111391635,
           -1.4815209712585165,
           -1.4807344114988006,
           -1.4796335919864712,
           -1.4782188770278355,
           -1.476490735239365,
           -1.474449739716752,
           -1.4720965682438332,
           -1.4694320035428061,
           -1.4664569335674098,
           -1.4631723518410493,
           -1.4595793578421365,
           -1.4556791574392336,
           -1.4514730633789144,
           -1.4469624958296246,
           -1.4421489829851677,
           -1.4370341617318647,
           -1.4316197783838451,
           -1.4259076894913765,
           -1.419899862727638,
           -1.4135983778598562,
           -1.407005427811282,
           -1.4001233198211065,
           -1.392954476710064,
           -1.3855014382601738,
           -1.3777668627178694,
           -1.369753528430567,
           -1.3614643356276719,
           -1.352902308357982,
           -1.3440705965965418,
           -1.334972478535176,
           -1.3256113630721968,
           -1.3159907925181953,
           -1.3061144455363276,
           -1.2959861403371855,
           -1.285609838150144,
           -1.274989646995054,
           -1.2641298257803095,
           -1.2530347887556754,
           -1.241709110350815,
           -1.2301575304332686,
           -1.2183849600226644,
           -1.2063964875012698,
           -1.1941973853645773,
           -1.1817931175595326,
           -1.1691893474622421,
           -1.1563919465515633,
           -1.1434070038399076,
           -1.1302408361278788,
           -1.1168999991550266,
           -1.1033912997250188,
           -1.0897218088899192,
           -1.0758988762849462,
           -1.0619301457120662,
           -1.0478235720779432,
           -1.0335874397990161,
           -1.0192303827936897,
           -1.0047614061885353,
           -0.9901899098718059,
           -0.9755257140330472,
           -0.9607790868316983,
           -0.9459607743397106,
           -0.9310820329025844,
           -0.9161546640588548,
           -0.9011910521487251,
           -0.8862042047267046,
           -0.8712077958688719,
           -0.8562162124304223,
           -0.8412446032606915,
           -0.8263089313174681,
           -0.811426028536171,
           -0.7966136531977162,
           -0.7818905493963135,
           -0.7672765080291328,
           -0.7527924285073065,
           -0.7384603801155197,
           -0.7243036616190486,
           -0.7103468573271036,
           -0.6966158873661737,
           -0.6831380493965722,
           -0.6699420484246416,
           -0.6570580107347717,
           -0.6445174773127267,
           -0.6323533714917381,
           -0.6205999349792257,
           -0.6092926259884296,
           -0.598467973000062,
           -0.5881633778282842,
           -0.5784168622909515,
           -0.5692667540172242,
           -0.5607513088825062,
           -0.5529082703175536,
           -0.5457743693011834,
           -0.5393847731170933,
           -0.5337724957073896,
           -0.5289677873178502,
           -0.5249975256004452,
           -0.5218846338269403,
           -0.5196475537733256,
           -0.5182998006521455,
           -0.517849624898321,
           -0.5182998006521464,
           -0.5196475537733274,
           -0.5218846338269431,
           -0.5249975256004489,
           -0.5289677873178547,
           -0.533772495707395,
           -0.5393847731170995,
           -0.5457743693011904,
           -0.5529082703175614,
           -0.5607513088825147,
           -0.5692667540172334,
           -0.5784168622909611,
           -0.5881633778282944,
           -0.5984679730000729,
           -0.609292625988441,
           -0.6205999349792376,
           -0.6323533714917505,
           -0.6445174773127395,
           -0.6570580107347849,
           -0.6699420484246552,
           -0.6831380493965857,
           -0.6966158873661877,
           -0.7103468573271178,
           -0.7243036616190629,
           -0.7384603801155344,
           -0.7527924285073213,
           -0.7672765080291478,
           -0.7818905493963287,
           -0.7966136531977313,
           -0.8114260285361862,
           -0.8263089313174833,
           -0.8412446032607069,
           -0.8562162124304378,
           -0.8712077958688873,
           -0.88620420472672,
           -0.9011910521487403,
           -0.9161546640588705,
           -0.9310820329025997,
           -0.9459607743397258,
           -0.9607790868317134,
           -0.9755257140330625,
           -0.9901899098718211,
           -1.0047614061885501,
           -1.0192303827937046,
           -1.033587439799031,
           -1.0478235720779578,
           -1.0619301457120809,
           -1.0758988762849604,
           -1.0897218088899334,
           -1.1033912997250326,
           -1.1168999991550401,
           -1.1302408361278924,
           -1.1434070038399209,
           -1.1563919465515766,
           -1.1691893474622552,
           -1.1817931175595453,
           -1.19419738536459,
           -1.2063964875012825,
           -1.2183849600226764,
           -1.2301575304332804,
           -1.241709110350827,
           -1.253034788755687,
           -1.2641298257803206,
           -1.2749896469950648,
           -1.2856098381501548,
           -1.295986140337196,
           -1.3061144455363378,
           -1.3159907925182055,
           -1.3256113630722068,
           -1.3349724785351853,
           -1.344070596596551,
           -1.352902308357991,
           -1.361464335627681,
           -1.3697535284305753,
           -1.3777668627178776,
           -1.3855014382601818,
           -1.3929544767100717,
           -1.4001233198211136,
           -1.4070054278112885,
           -1.4135983778598626,
           -1.4198998627276445,
           -1.425907689491382,
           -1.431619778383851,
           -1.4370341617318698,
           -1.4421489829851724,
           -1.4469624958296294,
           -1.4514730633789183,
           -1.4556791574392378,
           -1.4595793578421403,
           -1.4631723518410529,
           -1.4664569335674131,
           -1.469432003542809,
           -1.4720965682438358,
           -1.4744497397167544,
           -1.4764907352393675,
           -1.478218877027837,
           -1.4796335919864727,
           -1.4807344114988013,
           -1.481520971258517,
           -1.4819930111391637
          ],
          [
           -1.5090059190266825,
           -1.5088427463803278,
           -1.5083532804485815,
           -1.507537677269385,
           -1.5063961969593904,
           -1.5049292037945021,
           -1.5031371663234756,
           -1.501020657515417,
           -1.4985803549422805,
           -1.4958170409977214,
           -1.492731603153925,
           -1.4893250342583144,
           -1.4855984328723262,
           -1.481553003654763,
           -1.4771900577925285,
           -1.4725110134819275,
           -1.4675173964640467,
           -1.4622108406181438,
           -1.4565930886173764,
           -1.4506659926516554,
           -1.4444315152228941,
           -1.437891730018431,
           -1.43104882286899,
           -1.423905092798128,
           -1.4164629531708062,
           -1.4087249329494211,
           -1.4006936780664359,
           -1.3923719529235958,
           -1.3837626420286546,
           -1.3748687517815554,
           -1.3656934124231337,
           -1.3562398801606288,
           -1.346511539485639,
           -1.3365119057016226,
           -1.326244627679663,
           -1.3157134908629957,
           -1.3049224205427412,
           -1.2938754854294212,
           -1.2825769015472144,
           -1.27103103648047,
           -1.2592424140048728,
           -1.2472157191387694,
           -1.234955803653619,
           -1.2224676920863258,
           -1.2097565883003722,
           -1.196827882647246,
           -1.1836871597846839,
           -1.1703402072137632,
           -1.156793024602901,
           -1.1430518339734255,
           -1.1291230908285803,
           -1.115013496315669,
           -1.1007300105195497,
           -1.086279866994897,
           -1.0716705886545665,
           -1.056910005141993,
           -1.042006271826849,
           -1.0269678905750765,
           -1.0118037324567999,
           -0.9965230625683601,
           -0.981135567157537,
           -0.9656513832535839,
           -0.9500811310155373,
           -0.9344359490226857,
           -0.9187275327392552,
           -0.9029681763900951,
           -0.8871708184839546,
           -0.8713490912138566,
           -0.8555173739476003,
           -0.8396908509924326,
           -0.8238855737723929,
           -0.8081185274898964,
           -0.7924077022486655,
           -0.7767721684858824,
           -0.7612321563886505,
           -0.7458091387433535,
           -0.730525916374657,
           -0.7154067049609071,
           -0.7004772215510929,
           -0.6857647685421464,
           -0.6712983121928647,
           -0.6571085519450192,
           -0.6432279758937516,
           -0.6296908967108217,
           -0.61653346120642,
           -0.6037936255739818,
           -0.591511087286464,
           -0.5797271637307455,
           -0.5684846071530334,
           -0.5578273455610413,
           -0.5478001401422432,
           -0.5384481517787046,
           -0.5298164126083789,
           -0.5219492034570606,
           -0.5148893443453426,
           -0.5086774129302613,
           -0.5033509141492031,
           -0.4989434326601351,
           -0.49548380682078924,
           -0.492995367694664,
           -0.49149528777381407,
           -0.4909940809733175,
           -0.49149528777381507,
           -0.4929953676946661,
           -0.49548380682079224,
           -0.49894343266013913,
           -0.503350914149208,
           -0.5086774129302672,
           -0.5148893443453494,
           -0.5219492034570683,
           -0.5298164126083873,
           -0.538448151778714,
           -0.5478001401422531,
           -0.557827345561052,
           -0.5684846071530447,
           -0.5797271637307573,
           -0.5915110872864764,
           -0.6037936255739946,
           -0.6165334612064335,
           -0.6296908967108354,
           -0.6432279758937658,
           -0.6571085519450335,
           -0.6712983121928793,
           -0.6857647685421614,
           -0.7004772215511081,
           -0.7154067049609226,
           -0.7305259163746726,
           -0.7458091387433694,
           -0.7612321563886663,
           -0.7767721684858984,
           -0.7924077022486816,
           -0.8081185274899125,
           -0.8238855737724091,
           -0.8396908509924488,
           -0.8555173739476167,
           -0.8713490912138727,
           -0.887170818483971,
           -0.9029681763901112,
           -0.9187275327392714,
           -0.9344359490227018,
           -0.9500811310155534,
           -0.9656513832535999,
           -0.9811355671575528,
           -0.9965230625683761,
           -1.0118037324568154,
           -1.0269678905750923,
           -1.0420062718268643,
           -1.0569100051420082,
           -1.0716705886545816,
           -1.0862798669949119,
           -1.1007300105195643,
           -1.1150134963156837,
           -1.1291230908285945,
           -1.1430518339734397,
           -1.156793024602915,
           -1.170340207213777,
           -1.1836871597846974,
           -1.1968278826472591,
           -1.2097565883003856,
           -1.2224676920863387,
           -1.2349558036536317,
           -1.247215719138782,
           -1.2592424140048852,
           -1.2710310364804818,
           -1.2825769015472261,
           -1.293875485429433,
           -1.3049224205427525,
           -1.3157134908630068,
           -1.3262446276796735,
           -1.336511905701633,
           -1.3465115394856493,
           -1.3562398801606386,
           -1.3656934124231432,
           -1.3748687517815648,
           -1.3837626420286637,
           -1.3923719529236047,
           -1.4006936780664445,
           -1.4087249329494294,
           -1.4164629531708142,
           -1.4239050927981354,
           -1.4310488228689968,
           -1.437891730018438,
           -1.4444315152229008,
           -1.4506659926516616,
           -1.4565930886173821,
           -1.462210840618149,
           -1.4675173964640518,
           -1.4725110134819324,
           -1.477190057792533,
           -1.4815530036547675,
           -1.4855984328723304,
           -1.489325034258318,
           -1.4927316031539284,
           -1.4958170409977245,
           -1.4985803549422831,
           -1.5010206575154192,
           -1.5031371663234778,
           -1.5049292037945041,
           -1.5063961969593915,
           -1.5075376772693858,
           -1.5083532804485822,
           -1.5088427463803282
          ],
          [
           -1.5363364680146776,
           -1.5361675924383227,
           -1.5356610177215688,
           -1.5348168999148073,
           -1.533635499146994,
           -1.532117179693495,
           -1.53026241007187,
           -1.5280717631663852,
           -1.5255459163822889,
           -1.5226856518311493,
           -1.519491856548768,
           -1.5159655227474875,
           -1.5121077481049607,
           -1.5079197360917604,
           -1.5034027963405021,
           -1.4985583450594937,
           -1.4933879054942685,
           -1.4878931084407354,
           -1.48207569281409,
           -1.475937506278049,
           -1.4694805059394622,
           -1.4627067591138347,
           -1.4556184441678823,
           -1.4482178514457997,
           -1.4405073842866114,
           -1.4324895601406662,
           -1.424167011794122,
           -1.4155424887111279,
           -1.4066188585043318,
           -1.3973991085453852,
           -1.3878863477282306,
           -1.3780838083992124,
           -1.3679948484694007,
           -1.357622953726049,
           -1.346971740361743,
           -1.3360449577416533,
           -1.3248464914313198,
           -1.3133803665096473,
           -1.3016507511942652,
           -1.2896619608091553,
           -1.2774184621274975,
           -1.26492487812605,
           -1.2521859931911192,
           -1.2392067588203288,
           -1.2259922998689903,
           -1.2125479213949748,
           -1.1988791161616588,
           -1.1849915728647775,
           -1.1708911851559929,
           -1.1565840615436813,
           -1.142076536259996,
           -1.1273751811926993,
           -1.11248681899069,
           -1.0974185374636678,
           -1.0821777054090338,
           -1.0667719900130213,
           -1.0512093759882601,
           -1.0354981866265365,
           -1.019647106963442,
           -1.0036652092709364,
           -0.9875619811144508,
           -0.9713473562329394,
           -0.9550317485229418,
           -0.9386260894308808,
           -0.9221418690808301,
           -0.9055911814870024,
           -0.8889867742199583,
           -0.8723421029113296,
           -0.8556713909913445,
           -0.8389896950535719,
           -0.8223129762279249,
           -0.8056581779107672,
           -0.789043310143029,
           -0.7724875408347216,
           -0.7560112938960711,
           -0.7396363541378335,
           -0.723385978529379,
           -0.7072850130326893,
           -0.6913600137400332,
           -0.6756393704064184,
           -0.6601534296567808,
           -0.6449346141344959,
           -0.6300175326184523,
           -0.6154390746569036,
           -0.601238481552434,
           -0.587457383618891,
           -0.5741397915991034,
           -0.5613320281263755,
           -0.5490825833605248,
           -0.5374418777559644,
           -0.526461914753432,
           -0.5161958075448607,
           -0.5066971674999393,
           -0.4980193478713823,
           -0.49021454533549963,
           -0.48333277373456324,
           -0.4774207384822818,
           -0.47252065521103725,
           -0.46866907043330425,
           -0.4658957528195272,
           -0.4642227286412914,
           -0.4636635319853224,
           -0.46422272864129255,
           -0.4658957528195295,
           -0.46866907043330763,
           -0.4725206552110417,
           -0.47742073848228733,
           -0.48333277373456984,
           -0.4902145453355072,
           -0.49801934787139074,
           -0.5066971674999488,
           -0.5161958075448709,
           -0.5264619147534428,
           -0.5374418777559761,
           -0.5490825833605372,
           -0.5613320281263884,
           -0.5741397915991169,
           -0.5874573836189049,
           -0.6012384815524484,
           -0.6154390746569183,
           -0.6300175326184675,
           -0.6449346141345115,
           -0.6601534296567966,
           -0.6756393704064343,
           -0.6913600137400495,
           -0.7072850130327057,
           -0.7233859785293957,
           -0.7396363541378502,
           -0.756011293896088,
           -0.7724875408347386,
           -0.7890433101430461,
           -0.8056581779107841,
           -0.822312976227942,
           -0.8389896950535892,
           -0.8556713909913616,
           -0.8723421029113466,
           -0.8889867742199756,
           -0.9055911814870193,
           -0.9221418690808472,
           -0.9386260894308975,
           -0.9550317485229587,
           -0.9713473562329562,
           -0.9875619811144675,
           -1.003665209270953,
           -1.0196471069634585,
           -1.035498186626553,
           -1.0512093759882764,
           -1.066771990013037,
           -1.0821777054090498,
           -1.0974185374636833,
           -1.1124868189907053,
           -1.1273751811927144,
           -1.142076536260011,
           -1.1565840615436958,
           -1.1708911851560075,
           -1.184991572864792,
           -1.1988791161616728,
           -1.2125479213949888,
           -1.225992299869004,
           -1.2392067588203421,
           -1.252185993191132,
           -1.264924878126063,
           -1.2774184621275104,
           -1.2896619608091677,
           -1.3016507511942774,
           -1.3133803665096595,
           -1.3248464914313314,
           -1.3360449577416647,
           -1.346971740361754,
           -1.3576229537260598,
           -1.367994848469411,
           -1.3780838083992226,
           -1.3878863477282406,
           -1.3973991085453947,
           -1.406618858504341,
           -1.415542488711137,
           -1.424167011794131,
           -1.4324895601406746,
           -1.4405073842866198,
           -1.4482178514458073,
           -1.4556184441678899,
           -1.4627067591138418,
           -1.4694805059394687,
           -1.4759375062780555,
           -1.482075692814096,
           -1.4878931084407407,
           -1.4933879054942736,
           -1.498558345059499,
           -1.5034027963405068,
           -1.507919736091765,
           -1.5121077481049647,
           -1.5159655227474913,
           -1.5194918565487718,
           -1.5226856518311525,
           -1.5255459163822918,
           -1.5280717631663874,
           -1.5302624100718727,
           -1.5321171796934967,
           -1.5336354991469952,
           -1.5348168999148084,
           -1.5356610177215695,
           -1.5361675924383231
          ],
          [
           -1.564115581524634,
           -1.563941113653531,
           -1.563417762075247,
           -1.5625456829056896,
           -1.5613251363742418,
           -1.5597564868784373,
           -1.5578402030612402,
           -1.5555768579116738,
           -1.5529671288897589,
           -1.5500117980769637,
           -1.5467117523535778,
           -1.543067983604702,
           -1.5390815889567835,
           -1.534753771046901,
           -1.5300858383273104,
           -1.525079205408055,
           -1.5197353934407756,
           -1.5140560305472248,
           -1.5080428522963578,
           -1.5016977022342868,
           -1.4950225324718396,
           -1.488019404334942,
           -1.4806904890835757,
           -1.4730380687056324,
           -1.4650645367926265,
           -1.456772399504903,
           -1.448164276634745,
           -1.4392429027766096,
           -1.430011128614633,
           -1.4204719223385558,
           -1.410628371200322,
           -1.400483683224838,
           -1.3900411890897262,
           -1.3793043441904096,
           -1.3682767309085209,
           -1.3569620611034812,
           -1.3453641788491293,
           -1.3334870634395601,
           -1.3213348326908632,
           -1.3089117465682638,
           -1.2962222111713093,
           -1.2832707831132444,
           -1.2700621743346214,
           -1.2566012573955563,
           -1.242893071295916,
           -1.2289428278781698,
           -1.2147559188737393,
           -1.2003379236605025,
           -1.1856946178067456,
           -1.1708319824854185,
           -1.155756214852115,
           -1.1404737394909388,
           -1.1249912210444126,
           -1.1093155781570228,
           -1.0934539988770116,
           -1.077413957677805,
           -1.061203234279156,
           -1.0448299344689258,
           -1.0283025131495311,
           -1.0116297998586976,
           -0.9948210270423797,
           -0.977885861388688,
           -0.9608344385654337,
           -0.9436774017404166,
           -0.9264259443026591,
           -0.9090918572439992,
           -0.8916875817031032,
           -0.8742262672169189,
           -0.8567218362661247,
           -0.8391890557387867,
           -0.8216436159666362,
           -0.8041022180061836,
           -0.7865826698355013,
           -0.769103992107726,
           -0.7516865340319044,
           -0.7343520998245358,
           -0.7171240859701107,
           -0.7000276292192662,
           -0.6830897648052713,
           -0.6663395937321919,
           -0.6498084571321193,
           -0.6335301145480212,
           -0.6175409215120927,
           -0.6018799998966632,
           -0.5865893921656987,
           -0.5717141878256607,
           -0.5573026070903305,
           -0.5434060231428759,
           -0.530078900631842,
           -0.5173786245797249,
           -0.5053651913338157,
           -0.4941007324109844,
           -0.48364884416275067,
           -0.47407370231393986,
           -0.4654389517083772,
           -0.4578063786841137,
           -0.4512343961605593,
           -0.44577639816807896,
           -0.4414790679868561,
           -0.43838074759890805,
           -0.4365099903345916,
           -0.43588441847536596,
           -0.4365099903345928,
           -0.43838074759891066,
           -0.44147906798685993,
           -0.4457763981680839,
           -0.4512343961605655,
           -0.457806378684121,
           -0.4654389517083856,
           -0.4740737023139492,
           -0.48364884416276094,
           -0.49410073241099567,
           -0.5053651913338276,
           -0.5173786245797376,
           -0.5300789006318555,
           -0.5434060231428899,
           -0.5573026070903452,
           -0.5717141878256758,
           -0.5865893921657143,
           -0.6018799998966792,
           -0.6175409215121092,
           -0.6335301145480378,
           -0.6498084571321362,
           -0.6663395937322089,
           -0.6830897648052886,
           -0.7000276292192837,
           -0.7171240859701284,
           -0.7343520998245535,
           -0.7516865340319223,
           -0.769103992107744,
           -0.7865826698355192,
           -0.8041022180062016,
           -0.8216436159666541,
           -0.8391890557388048,
           -0.8567218362661427,
           -0.874226267216937,
           -0.8916875817031209,
           -0.909091857244017,
           -0.9264259443026771,
           -0.9436774017404344,
           -0.9608344385654514,
           -0.9778858613887057,
           -0.9948210270423972,
           -1.011629799858715,
           -1.028302513149548,
           -1.0448299344689427,
           -1.061203234279173,
           -1.0774139576778217,
           -1.093453998877028,
           -1.1093155781570387,
           -1.1249912210444286,
           -1.1404737394909548,
           -1.1557562148521305,
           -1.1708319824854339,
           -1.1856946178067609,
           -1.2003379236605174,
           -1.2147559188737542,
           -1.228942827878184,
           -1.24289307129593,
           -1.2566012573955703,
           -1.2700621743346348,
           -1.2832707831132577,
           -1.2962222111713224,
           -1.3089117465682767,
           -1.3213348326908758,
           -1.3334870634395724,
           -1.3453641788491415,
           -1.356962061103493,
           -1.3682767309085322,
           -1.3793043441904207,
           -1.3900411890897373,
           -1.4004836832248482,
           -1.410628371200332,
           -1.4204719223385658,
           -1.4300111286146429,
           -1.439242902776619,
           -1.448164276634754,
           -1.4567723995049116,
           -1.465064536792635,
           -1.4730380687056404,
           -1.480690489083583,
           -1.488019404334949,
           -1.4950225324718467,
           -1.5016977022342932,
           -1.5080428522963643,
           -1.5140560305472306,
           -1.519735393440781,
           -1.5250792054080604,
           -1.5300858383273155,
           -1.5347537710469052,
           -1.5390815889567877,
           -1.543067983604706,
           -1.546711752353581,
           -1.550011798076967,
           -1.5529671288897617,
           -1.555576857911676,
           -1.5578402030612426,
           -1.5597564868784388,
           -1.561325136374243,
           -1.56254568290569,
           -1.5634177620752476,
           -1.5639411136535313
          ],
          [
           -1.5923163850583166,
           -1.5921364395920308,
           -1.5915966552801728,
           -1.590697188391904,
           -1.5894382994031377,
           -1.5878203530378328,
           -1.5858438183264885,
           -1.583509268682502,
           -1.5808173819972755,
           -1.5777689407551698,
           -1.5743648321695938,
           -1.5706060483417819,
           -1.5664936864440138,
           -1.5620289489293155,
           -1.5572131437699208,
           -1.552047684727074,
           -1.546534091655063,
           -1.5406739908426805,
           -1.5344691153956929,
           -1.5279213056642593,
           -1.5210325097196686,
           -1.513804783885216,
           -1.5062402933265349,
           -1.4983413127072385,
           -1.4901102269163202,
           -1.4815495318744158,
           -1.472661835426735,
           -1.4634498583312723,
           -1.4539164353517697,
           -1.4440645164658559,
           -1.433897168199868,
           -1.4234175751030267,
           -1.4126290413749385,
           -1.4015349926618703,
           -1.3901389780388305,
           -1.378444672196308,
           -1.3664558778525204,
           -1.354176528414254,
           -1.3416106909118855,
           -1.3287625692369736,
           -1.3156365077139374,
           -1.3022369950408537,
           -1.2885686686383468,
           -1.2746363194499737,
           -1.260444897242488,
           -1.245999516459968,
           -1.231305462692115,
           -1.2163681998241431,
           -1.2011933779437163,
           -1.1857868420894668,
           -1.1701546419358768,
           -1.1543030425208989,
           -1.1382385361358023,
           -1.121967855511578,
           -1.105497988453013,
           -1.0888361940905718,
           -1.0719900209417115,
           -1.0549673269975992,
           -1.0377763020786848,
           -1.020425492733636,
           -1.002923829991118,
           -0.9852806603132738,
           -0.967505780143893,
           -0.9496094744936043,
           -0.9316025600592805,
           -0.9134964334355029,
           -0.8953031250424074,
           -0.8770353594663353,
           -0.8587066229867907,
           -0.840331239143952,
           -0.8219244532832125,
           -0.8035025270934048,
           -0.7850828442281256,
           -0.7666840281570318,
           -0.748326073424726,
           -0.730030491482822,
           -0.7118204721836744,
           -0.6937210618515792,
           -0.675759358538112,
           -0.6579647245686393,
           -0.6403690157271247,
           -0.6230068253181332,
           -0.6059157397809684,
           -0.5891366003855592,
           -0.5727137626755475,
           -0.5566953416059313,
           -0.5411334256451215,
           -0.5260842374442484,
           -0.5116082121349049,
           -0.4977699572575078,
           -0.4846380514665671,
           -0.4722846337164748,
           -0.46078473239182793,
           -0.4502152871597973,
           -0.44065382786685064,
           -0.4321767970319126,
           -0.42485753670602694,
           -0.4187640056255593,
           -0.41395634414656846,
           -0.4104844539298284,
           -0.40838579522348095,
           -0.4076836149416835,
           -0.4083857952234824,
           -0.41048445392983124,
           -0.41395634414657273,
           -0.418764005625565,
           -0.4248575367060339,
           -0.4321767970319208,
           -0.44065382786685997,
           -0.45021528715980763,
           -0.4607847323918393,
           -0.4722846337164871,
           -0.4846380514665801,
           -0.4977699572575217,
           -0.5116082121349194,
           -0.5260842374442636,
           -0.5411334256451371,
           -0.5566953416059475,
           -0.5727137626755643,
           -0.5891366003855762,
           -0.6059157397809859,
           -0.6230068253181509,
           -0.6403690157271426,
           -0.6579647245686575,
           -0.6757593585381304,
           -0.6937210618515978,
           -0.7118204721836929,
           -0.7300304914828407,
           -0.7483260734247448,
           -0.7666840281570508,
           -0.7850828442281444,
           -0.8035025270934237,
           -0.8219244532832315,
           -0.8403312391439709,
           -0.8587066229868096,
           -0.8770353594663539,
           -0.895303125042426,
           -0.9134964334355217,
           -0.9316025600592992,
           -0.9496094744936227,
           -0.9675057801439114,
           -0.9852806603132919,
           -1.0029238299911363,
           -1.0204254927336538,
           -1.0377763020787025,
           -1.0549673269976165,
           -1.0719900209417288,
           -1.0888361940905888,
           -1.1054979884530298,
           -1.1219678555115946,
           -1.1382385361358192,
           -1.1543030425209153,
           -1.170154641935893,
           -1.1857868420894828,
           -1.201193377943732,
           -1.2163681998241587,
           -1.2313054626921305,
           -1.2459995164599829,
           -1.2604448972425029,
           -1.2746363194499883,
           -1.2885686686383608,
           -1.3022369950408674,
           -1.315636507713951,
           -1.3287625692369867,
           -1.3416106909118983,
           -1.354176528414267,
           -1.3664558778525326,
           -1.3784446721963197,
           -1.390138978038842,
           -1.401534992661882,
           -1.41262904137495,
           -1.4234175751030376,
           -1.4338971681998787,
           -1.4440645164658656,
           -1.4539164353517797,
           -1.4634498583312823,
           -1.4726618354267442,
           -1.4815495318744252,
           -1.490110226916329,
           -1.4983413127072467,
           -1.506240293326543,
           -1.5138047838852238,
           -1.521032509719676,
           -1.527921305664266,
           -1.5344691153956993,
           -1.5406739908426863,
           -1.5465340916550687,
           -1.5520476847270794,
           -1.5572131437699257,
           -1.5620289489293206,
           -1.5664936864440178,
           -1.5706060483417856,
           -1.5743648321695976,
           -1.577768940755173,
           -1.5808173819972786,
           -1.5835092686825043,
           -1.585843818326491,
           -1.587820353037835,
           -1.5894382994031389,
           -1.5906971883919057,
           -1.5915966552801737,
           -1.5921364395920312
          ],
          [
           -1.620911596159626,
           -1.6207262911103784,
           -1.6201704281408038,
           -1.6192441637909225,
           -1.6179477589792188,
           -1.616281579030623,
           -1.614246093716285,
           -1.6118418773057541,
           -1.609069608632345,
           -1.6059300711726845,
           -1.6024241531415957,
           -1.598552847603704,
           -1.5943172526033595,
           -1.5897185713146904,
           -1.58475811221385,
           -1.5794372892757838,
           -1.5737576221981024,
           -1.567720736654969,
           -1.5613283645842106,
           -1.5545823445112252,
           -1.5474846219136376,
           -1.5400372496310617,
           -1.5322423883247924,
           -1.524102306992739,
           -1.5156193835454659,
           -1.5067961054497903,
           -1.497635070447077,
           -1.4881389873540667,
           -1.4783106769549121,
           -1.4681530729939725,
           -1.4576692232799209,
           -1.446862290912816,
           -1.435735555647024,
           -1.424292415404244,
           -1.4125363879524087,
           -1.4004711127679599,
           -1.3881003531008826,
           -1.3754279982640418,
           -1.3624580661707564,
           -1.3491947061472427,
           -1.335642202049594,
           -1.3218049757183792,
           -1.3076875908077923,
           -1.2932947570306321,
           -1.2786313348653158,
           -1.263702340776678,
           -1.2485129530086303,
           -1.2330685180138936,
           -1.2173745575941533,
           -1.2014367768332233,
           -1.1852610729163273,
           -1.1688535449405995,
           -1.152220504835583,
           -1.1353684895281395,
           -1.1183042745040321,
           -1.1010348889388744,
           -1.08356763259453,
           -1.065910094703822,
           -1.0480701750970915,
           -1.0300561078593158,
           -1.0118764878467652,
           -0.9935403004383274,
           -0.9750569549494152,
           -0.9564363221967332,
           -0.9376887767710256,
           -0.9188252446532893,
           -0.8998572568988061,
           -0.8807970102136671,
           -0.8616574353610125,
           -0.8424522744594518,
           -0.8231961683739127,
           -0.803904755548495,
           -0.7845947837892684,
           -0.7652842366677127,
           -0.7459924763747872,
           -0.726740404998892,
           -0.7075506463090253,
           -0.6884477501686225,
           -0.6694584216442319,
           -0.6506117766469597,
           -0.6319396254704814,
           -0.6134767847537376,
           -0.5952614170471328,
           -0.5773353951004331,
           -0.5597446849707286,
           -0.5425397377744368,
           -0.5257758740529511,
           -0.509513636974885,
           -0.4938190807453283,
           -0.4787639486659961,
           -0.46442568179319194,
           -0.4508871853572941,
           -0.4382362684606097,
           -0.4265646669225387,
           -0.4159665648275677,
           -0.40653655359967167,
           -0.3983670139171446,
           -0.39154497788263265,
           -0.3861486223205051,
           -0.382243645165008,
           -0.37987986231779436,
           -0.3790884038403738,
           -0.379879862317796,
           -0.3822436451650112,
           -0.38614862232050995,
           -0.39154497788263887,
           -0.3983670139171523,
           -0.4065365535996808,
           -0.41596656482757804,
           -0.4265646669225501,
           -0.4382362684606223,
           -0.45088718535730754,
           -0.46442568179320637,
           -0.4787639486660112,
           -0.49381908074534414,
           -0.5095136369749015,
           -0.5257758740529681,
           -0.5425397377744543,
           -0.5597446849707466,
           -0.5773353951004515,
           -0.5952614170471514,
           -0.6134767847537566,
           -0.6319396254705004,
           -0.650611776646979,
           -0.6694584216442514,
           -0.688447750168642,
           -0.707550646309045,
           -0.7267404049989118,
           -0.7459924763748069,
           -0.7652842366677325,
           -0.7845947837892882,
           -0.8039047555485148,
           -0.8231961683739326,
           -0.8424522744594717,
           -0.8616574353610322,
           -0.8807970102136867,
           -0.8998572568988258,
           -0.9188252446533086,
           -0.9376887767710449,
           -0.9564363221967525,
           -0.9750569549494342,
           -0.9935403004383464,
           -1.011876487846784,
           -1.0300561078593344,
           -1.04807017509711,
           -1.0659100947038402,
           -1.083567632594548,
           -1.101034888938892,
           -1.11830427450405,
           -1.1353684895281568,
           -1.1522205048356,
           -1.1688535449406166,
           -1.185261072916344,
           -1.2014367768332397,
           -1.2173745575941695,
           -1.2330685180139096,
           -1.248512953008646,
           -1.2637023407766936,
           -1.278631334865331,
           -1.2932947570306472,
           -1.307687590807807,
           -1.3218049757183938,
           -1.335642202049608,
           -1.3491947061472567,
           -1.36245806617077,
           -1.375427998264055,
           -1.3881003531008953,
           -1.4004711127679725,
           -1.412536387952421,
           -1.4242924154042556,
           -1.4357355556470357,
           -1.446862290912827,
           -1.4576692232799318,
           -1.4681530729939833,
           -1.4783106769549226,
           -1.4881389873540765,
           -1.4976350704470867,
           -1.5067961054497998,
           -1.5156193835454748,
           -1.5241023069927475,
           -1.5322423883248004,
           -1.5400372496310692,
           -1.5474846219136449,
           -1.5545823445112321,
           -1.5613283645842173,
           -1.5677207366549752,
           -1.5737576221981082,
           -1.5794372892757895,
           -1.5847581122138554,
           -1.5897185713146953,
           -1.5943172526033642,
           -1.5985528476037083,
           -1.6024241531415997,
           -1.6059300711726883,
           -1.609069608632348,
           -1.611841877305757,
           -1.614246093716288,
           -1.6162815790306249,
           -1.6179477589792204,
           -1.6192441637909234,
           -1.6201704281408045,
           -1.6207262911103786
          ],
          [
           -1.649873550808615,
           -1.6496830068133812,
           -1.6491114271445872,
           -1.6481589687558702,
           -1.646825893246419,
           -1.645112566875921,
           -1.6430194605860307,
           -1.6405471500288773,
           -1.637696315603318,
           -1.6344677424997978,
           -1.6308623207548438,
           -1.626881045316417,
           -1.6225250161215152,
           -1.617795438187644,
           -1.6126936217199632,
           -1.6072209822361716,
           -1.6013790407114146,
           -1.5951694237457796,
           -1.5885938637572306,
           -1.5816541992031377,
           -1.5743523748339086,
           -1.5666904419825842,
           -1.5586705588946907,
           -1.5502949911030606,
           -1.5415661118528492,
           -1.5324864025824934,
           -1.5230584534669802,
           -1.5132849640304287,
           -1.503168743835744,
           -1.4927127132599045,
           -1.4819199043643465,
           -1.470793461870932,
           -1.4593366442550915,
           -1.4475528249690095,
           -1.435445493809111,
           -1.4230182584436957,
           -1.4102748461183252,
           -1.3972191055585683,
           -1.38385500909193,
           -1.3701866550133353,
           -1.3562182702213645,
           -1.341954213155671,
           -1.327398977069647,
           -1.3125571936765468,
           -1.2974336372119573,
           -1.2820332289608516,
           -1.2663610423035356,
           -1.2504223083417314,
           -1.2342224221739568,
           -1.2177669498984318,
           -1.2010616364321023,
           -1.1841124142463058,
           -1.1669254131332665,
           -1.1495069711333747,
           -1.1318636467713372,
           -1.1140022327702386,
           -1.0959297714367409,
           -1.0776535719386477,
           -1.0591812297284742,
           -1.040520648404264,
           -1.021680064342512,
           -1.0026680744887337,
           -0.9834936677500995,
           -0.964166260503006,
           -0.9446957368080425,
           -0.9250924940172793,
           -0.9053674945661834,
           -0.8855323248669664,
           -0.8655992623641828,
           -0.8455813519794921,
           -0.8254924933631421,
           -0.8053475405872573,
           -0.7851624161620532,
           -0.7649542415311192,
           -0.7447414865042794,
           -0.7245441404110243,
           -0.7043839080934119,
           -0.6842844341851351,
           -0.6642715594107146,
           -0.6443736128334979,
           -0.6246217440031983,
           -0.605050298682692,
           -0.5856972410932666,
           -0.5666046241552029,
           -0.5478191066654604,
           -0.5293925122736205,
           -0.5113824188813901,
           -0.49385275796023975,
           -0.4768743904430562,
           -0.46052560856163444,
           -0.4448924909136486,
           -0.4300690116984874,
           -0.41615677671858753,
           -0.4032642334010131,
           -0.39150518848837546,
           -0.3809964779584966,
           -0.37185468450472736,
           -0.36419190190657397,
           -0.3581107060543971,
           -0.35369869231075335,
           -0.35102313472527163,
           -0.3501264491913849,
           -0.3510231347252735,
           -0.353698692310757,
           -0.3581107060544025,
           -0.364191901906581,
           -0.37185468450473597,
           -0.38099647795850683,
           -0.3915051884883869,
           -0.40326423340102574,
           -0.4161567767186014,
           -0.4300690116985022,
           -0.44489249091366423,
           -0.46052560856165087,
           -0.47687439044307334,
           -0.49385275796025757,
           -0.5113824188814086,
           -0.5293925122736393,
           -0.5478191066654796,
           -0.5666046241552223,
           -0.5856972410932865,
           -0.605050298682712,
           -0.6246217440032185,
           -0.6443736128335182,
           -0.6642715594107349,
           -0.6842844341851555,
           -0.7043839080934327,
           -0.7245441404110452,
           -0.7447414865043,
           -0.7649542415311401,
           -0.7851624161620738,
           -0.805347540587278,
           -0.8254924933631628,
           -0.8455813519795127,
           -0.8655992623642034,
           -0.8855323248669867,
           -0.9053674945662039,
           -0.9250924940172996,
           -0.9446957368080627,
           -0.9641662605030261,
           -0.9834936677501193,
           -1.0026680744887535,
           -1.0216800643425314,
           -1.040520648404283,
           -1.0591812297284933,
           -1.0776535719386666,
           -1.0959297714367597,
           -1.114002232770257,
           -1.1318636467713554,
           -1.1495069711333927,
           -1.1669254131332842,
           -1.184112414246323,
           -1.2010616364321194,
           -1.217766949898449,
           -1.2342224221739737,
           -1.2504223083417478,
           -1.266361042303552,
           -1.2820332289608676,
           -1.297433637211973,
           -1.312557193676562,
           -1.327398977069662,
           -1.3419542131556856,
           -1.3562182702213792,
           -1.3701866550133495,
           -1.383855009091944,
           -1.3972191055585819,
           -1.4102748461183388,
           -1.4230182584437083,
           -1.4354454938091237,
           -1.4475528249690217,
           -1.4593366442551037,
           -1.4707934618709435,
           -1.4819199043643578,
           -1.4927127132599154,
           -1.5031687438357548,
           -1.5132849640304389,
           -1.5230584534669904,
           -1.5324864025825031,
           -1.5415661118528583,
           -1.5502949911030695,
           -1.5586705588946992,
           -1.5666904419825924,
           -1.5743523748339163,
           -1.5816541992031452,
           -1.588593863757237,
           -1.5951694237457856,
           -1.6013790407114206,
           -1.6072209822361774,
           -1.6126936217199683,
           -1.6177954381876491,
           -1.6225250161215201,
           -1.626881045316421,
           -1.6308623207548478,
           -1.634467742499801,
           -1.6376963156033213,
           -1.6405471500288804,
           -1.6430194605860338,
           -1.645112566875923,
           -1.6468258932464204,
           -1.6481589687558713,
           -1.6491114271445881,
           -1.6496830068133819
          ],
          [
           -1.6791742301846384,
           -1.6789785698787945,
           -1.6783916414713393,
           -1.6774136024929234,
           -1.6760447154960907,
           -1.6742853480577007,
           -1.6721359727827725,
           -1.6695971673102232,
           -1.6666696143210884,
           -1.6633541015499844,
           -1.6596515218006913,
           -1.6555628729669136,
           -1.651089258059432,
           -1.6462318852410287,
           -1.6409920678707677,
           -1.6353712245593979,
           -1.6293708792378674,
           -1.6229926612411694,
           -1.616238305409985,
           -1.6091096522128647,
           -1.601608647891989,
           -1.5937373446358656,
           -1.5854979007826835,
           -1.5768925810584347,
           -1.5679237568543445,
           -1.558593906548622,
           -1.5489056158780783,
           -1.538861578365739,
           -1.5284645958112215,
           -1.5177175788513775,
           -1.5066235475994936,
           -1.4951856323722499,
           -1.4834070745146324,
           -1.4712912273341188,
           -1.4588415571567153,
           -1.4460616445188428,
           -1.432955185510652,
           -1.4195259932881512,
           -1.405777999773547,
           -1.3917152575654892,
           -1.377341942083512,
           -1.362662353973888,
           -1.3476809218074637,
           -1.3324022051038449,
           -1.3168308977206273,
           -1.300971831651323,
           -1.284829981281283,
           -1.2684104681574109,
           -1.2517185663348889,
           -1.2347597083727087,
           -1.21753949205964,
           -1.2000636879636533,
           -1.1823382479109412,
           -1.1643693145159317,
           -1.1461632319013153,
           -1.127726557767666,
           -1.1090660769961243,
           -1.0901888169955045,
           -1.0711020650377736,
           -1.0518133878640052,
           -1.0323306538876553,
           -1.0126620583745551,
           -0.9928161520408478,
           -0.9728018735829295,
           -0.9526285867393752,
           -0.9323061225863025,
           -0.9118448278875266,
           -0.8912556204626949,
           -0.8705500527042863,
           -0.8497403845726724,
           -0.828839667632631,
           -0.8078618419708234,
           -0.7868218481583288,
           -0.7657357568021849,
           -0.7446209186716978,
           -0.7234961388944159,
           -0.7023818792959302,
           -0.6813004936043535,
           -0.6602765009423297,
           -0.6393369037584826,
           -0.618511557051927,
           -0.597833596322065,
           -0.5773399319717752,
           -0.5570718176494316,
           -0.5370754988370705,
           -0.5174029452809491,
           -0.4981126657462926,
           -0.4792705948407481,
           -0.46095102766948287,
           -0.44323755686374217,
           -0.4262239359155283,
           -0.4100147510498077,
           -0.3947257310470527,
           -0.38048346428272134,
           -0.36742423546013664,
           -0.35569166200460534,
           -0.34543283453240736,
           -0.3367927872615716,
           -0.3299073749789531,
           -0.3248950103232337,
           -0.3218481501912821,
           -0.32082576981536165,
           -0.3218481501912842,
           -0.3248950103232378,
           -0.32990737497895917,
           -0.3367927872615795,
           -0.34543283453241713,
           -0.3556916620046167,
           -0.3674242354601494,
           -0.38048346428273544,
           -0.39472573104706804,
           -0.4100147510498239,
           -0.42622393591554536,
           -0.44323755686376004,
           -0.46095102766950136,
           -0.47927059484076723,
           -0.4981126657463122,
           -0.5174029452809692,
           -0.537075498837091,
           -0.5570718176494523,
           -0.5773399319717962,
           -0.5978335963220862,
           -0.6185115570519482,
           -0.639336903758504,
           -0.6602765009423511,
           -0.6813004936043752,
           -0.7023818792959519,
           -0.7234961388944375,
           -0.7446209186717194,
           -0.7657357568022067,
           -0.7868218481583504,
           -0.8078618419708451,
           -0.8288396676326524,
           -0.849740384572694,
           -0.8705500527043077,
           -0.8912556204627161,
           -0.911844827887548,
           -0.9323061225863235,
           -0.9526285867393961,
           -0.97280187358295,
           -0.9928161520408685,
           -1.0126620583745756,
           -1.0323306538876753,
           -1.0518133878640252,
           -1.0711020650377934,
           -1.090188816995524,
           -1.1090660769961436,
           -1.127726557767685,
           -1.1461632319013344,
           -1.1643693145159504,
           -1.1823382479109594,
           -1.2000636879636712,
           -1.2175394920596578,
           -1.234759708372726,
           -1.2517185663349062,
           -1.2684104681574275,
           -1.2848299812812998,
           -1.3009718316513392,
           -1.3168308977206435,
           -1.3324022051038606,
           -1.3476809218074792,
           -1.3626623539739033,
           -1.377341942083527,
           -1.3917152575655036,
           -1.4057779997735609,
           -1.4195259932881654,
           -1.4329551855106655,
           -1.4460616445188559,
           -1.4588415571567284,
           -1.4712912273341314,
           -1.4834070745146448,
           -1.4951856323722617,
           -1.5066235475995051,
           -1.5177175788513886,
           -1.5284645958112322,
           -1.5388615783657493,
           -1.5489056158780885,
           -1.5585939065486316,
           -1.567923756854354,
           -1.5768925810584435,
           -1.585497900782692,
           -1.593737344635874,
           -1.6016086478919969,
           -1.6091096522128723,
           -1.616238305409992,
           -1.622992661241176,
           -1.6293708792378738,
           -1.6353712245594039,
           -1.6409920678707735,
           -1.646231885241034,
           -1.6510892580594367,
           -1.655562872966918,
           -1.659651521800695,
           -1.663354101549988,
           -1.6666696143210917,
           -1.6695971673102261,
           -1.6721359727827751,
           -1.6742853480577027,
           -1.6760447154960922,
           -1.6774136024929245,
           -1.6783916414713402,
           -1.6789785698787951
          ],
          [
           -1.708785287772754,
           -1.7085846352226353,
           -1.7079827303353938,
           -1.7069797313984303,
           -1.7055759022176598,
           -1.7037716121080715,
           -1.7015673358809056,
           -1.6989636538278279,
           -1.6959612517026164,
           -1.6925609207009913,
           -1.6887635574393314,
           -1.6845701639331756,
           -1.6799818475765347,
           -1.6749998211231742,
           -1.6696254026712192,
           -1.6638600156525638,
           -1.6577051888287808,
           -1.6511625562953975,
           -1.6442338574966375,
           -1.6369209372529483,
           -1.629225745803886,
           -1.621150338869212,
           -1.6126968777313588,
           -1.6038676293427514,
           -1.5946649664618393,
           -1.5850913678221146,
           -1.5751494183388235,
           -1.5648418093585912,
           -1.5541713389577403,
           -1.5431409122956923,
           -1.5317535420305437,
           -1.520012348804679,
           -1.5079205618091538,
           -1.4954815194365472,
           -1.4826986700330884,
           -1.4695755727620825,
           -1.4561158985920555,
           -1.4423234314246098,
           -1.428202069378746,
           -1.4137558262504322,
           -1.3989888331684777,
           -1.383905340470367,
           -1.3685097198246752,
           -1.3528064666300599,
           -1.336800202724695,
           -1.3204956794444314,
           -1.3038977810730636,
           -1.2870115287339186,
           -1.2698420847787182,
           -1.252394757737453,
           -1.234675007901999,
           -1.216688453626641,
           -1.1984408784407912,
           -1.1799382390833124,
           -1.161186674584311,
           -1.1421925165395412,
           -1.1229623007451226,
           -1.1035027803868027,
           -1.0838209410092063,
           -1.0639240175273699,
           -1.0438195135864188,
           -1.0235152236269334,
           -1.0030192580749124,
           -0.9823400721483667,
           -0.9614864988598277,
           -0.9404677868984358,
           -0.9192936442003659,
           -0.8979742881665947,
           -0.8765205036677396,
           -0.8549437101934595,
           -0.8332560397665745,
           -0.8114704275591791,
           -0.7896007175309633,
           -0.7676617858722022,
           -0.7456696855910968,
           -0.7236418162551561,
           -0.701597123698503,
           -0.6795563354612016,
           -0.6575422388506001,
           -0.6355800098191601,
           -0.6136976023339489,
           -0.5919262095362652,
           -0.5703008096690096,
           -0.5488608113064065,
           -0.5276508135256205,
           -0.5067214967379385,
           -0.48613065799109095,
           -0.4659443991305957,
           -0.44623846490809965,
           -0.42709970749174814,
           -0.40862761912572393,
           -0.3909358200409114,
           -0.3741533082066993,
           -0.35842516799117147,
           -0.3439123017546822,
           -0.33078961560085923,
           -0.3192420118043222,
           -0.3094576063059774,
           -0.30161791213578837,
           -0.29588538524615204,
           -0.29238965885842294,
           -0.2912147122272459,
           -0.2923896588584253,
           -0.2958853852461567,
           -0.30161791213579536,
           -0.3094576063059865,
           -0.3192420118043332,
           -0.33078961560087194,
           -0.34391230175469645,
           -0.358425167991187,
           -0.3741533082067161,
           -0.3909358200409291,
           -0.4086276191257425,
           -0.4270997074917675,
           -0.4462384649081196,
           -0.4659443991306162,
           -0.48613065799111194,
           -0.5067214967379601,
           -0.5276508135256421,
           -0.5488608113064285,
           -0.5703008096690318,
           -0.5919262095362875,
           -0.6136976023339714,
           -0.6355800098191826,
           -0.6575422388506227,
           -0.6795563354612243,
           -0.7015971236985258,
           -0.7236418162551786,
           -0.7456696855911195,
           -0.7676617858722248,
           -0.7896007175309857,
           -0.8114704275592014,
           -0.8332560397665968,
           -0.8549437101934819,
           -0.8765205036677619,
           -0.8979742881666167,
           -0.9192936442003878,
           -0.9404677868984576,
           -0.9614864988598493,
           -0.982340072148388,
           -1.0030192580749338,
           -1.0235152236269545,
           -1.0438195135864394,
           -1.0639240175273905,
           -1.0838209410092268,
           -1.1035027803868227,
           -1.1229623007451424,
           -1.1421925165395608,
           -1.1611866745843304,
           -1.1799382390833315,
           -1.1984408784408103,
           -1.2166884536266596,
           -1.2346750079020175,
           -1.252394757737471,
           -1.269842084778736,
           -1.287011528733936,
           -1.3038977810730807,
           -1.3204956794444482,
           -1.3368002027247117,
           -1.352806466630076,
           -1.3685097198246912,
           -1.3839053404703827,
           -1.3989888331684932,
           -1.4137558262504473,
           -1.4282020693787607,
           -1.442323431424624,
           -1.4561158985920695,
           -1.469575572762096,
           -1.4826986700331017,
           -1.4954815194365603,
           -1.5079205618091664,
           -1.5200123488046913,
           -1.5317535420305555,
           -1.5431409122957036,
           -1.5541713389577514,
           -1.564841809358602,
           -1.575149418338834,
           -1.585091367822125,
           -1.5946649664618489,
           -1.6038676293427605,
           -1.6126968777313677,
           -1.6211503388692203,
           -1.629225745803894,
           -1.636920937252956,
           -1.6442338574966446,
           -1.6511625562954042,
           -1.6577051888287875,
           -1.66386001565257,
           -1.6696254026712245,
           -1.6749998211231796,
           -1.6799818475765391,
           -1.68457016393318,
           -1.688763557439335,
           -1.692560920700995,
           -1.69596125170262,
           -1.6989636538278305,
           -1.701567335880908,
           -1.7037716121080735,
           -1.705575902217661,
           -1.7069797313984314,
           -1.7079827303353943,
           -1.7085846352226361
          ],
          [
           -1.7386780767871457,
           -1.7384725569786033,
           -1.7378560506330987,
           -1.7368287169868584,
           -1.735390821419838,
           -1.733542735435247,
           -1.7312849366312055,
           -1.7286180086648517,
           -1.7255426412093173,
           -1.722059629904099,
           -1.7181698762994355,
           -1.7138743877954328,
           -1.709174277576776,
           -1.7040707645440043,
           -1.6985651732424376,
           -1.692658933790004,
           -1.686353581805348,
           -1.67965075833777,
           -1.6725522098007322,
           -1.6650597879108335,
           -1.657175449634397,
           -1.6489012571440098,
           -1.6402393777876392,
           -1.631192084073194,
           -1.6217617536717381,
           -1.6119508694428726,
           -1.6017620194862001,
           -1.5911978972231904,
           -1.5802613015142353,
           -1.5689551368161994,
           -1.5572824133863472,
           -1.5452462475391848,
           -1.5328498619634718,
           -1.5200965861074844,
           -1.506989856641524,
           -1.493533218007709,
           -1.4797303230682577,
           -1.4655849338647913,
           -1.4511009225027005,
           -1.4362822721763175,
           -1.4211330783525835,
           -1.4056575501331199,
           -1.389860011817138,
           -1.3737449046905212,
           -1.3573167890697377,
           -1.3405803466330541,
           -1.32354038307592,
           -1.3062018311324626,
           -1.2885697540108894,
           -1.270649349297399,
           -1.2524459533910854,
           -1.2339650465415073,
           -1.2152122585713105,
           -1.1961933753788327,
           -1.1769143463303056,
           -1.1573812926685554,
           -1.137600517085453,
           -1.1175785146294224,
           -1.0973219851478053,
           -1.0768378474977347,
           -1.056133255799497,
           -1.0352156180545193,
           -1.0140926175078513,
           -0.9927722372043358,
           -0.9712627882712417,
           -0.9495729425611291,
           -0.9277117704111707,
           -0.9056887844240157,
           -0.8835139903568381,
           -0.861197946427218,
           -0.8387518326167529,
           -0.8161875318880385,
           -0.7935177256431991,
           -0.7707560062616634,
           -0.7479170101852156,
           -0.7250165757990535,
           -0.7020719313248908,
           -0.6791019191398775,
           -0.6561272644151036,
           -0.6331708977888328,
           -0.6102583440157144,
           -0.587418191224049,
           -0.5646826586094434,
           -0.5420882840853399,
           -0.5196767574822397,
           -0.4974959290126656,
           -0.47560102618979677,
           -0.4540561138227194,
           -0.43293582859162394,
           -0.4123274076772114,
           -0.39233300283144096,
           -0.37307221610445296,
           -0.3546846956191704,
           -0.3373324704505623,
           -0.3212014669509931,
           -0.3065013384078275,
           -0.2934624110028237,
           -0.2823283534887884,
           -0.2733433922773581,
           -0.26673385523746246,
           -0.26268568838859196,
           -0.26132192321285425,
           -0.2626856883885948,
           -0.266733855237468,
           -0.2733433922773661,
           -0.2823283534887987,
           -0.29346241100283615,
           -0.30650133840784183,
           -0.32120146695100904,
           -0.33733247045057957,
           -0.35468469561918886,
           -0.37307221610447233,
           -0.3923330028314612,
           -0.4123274076772322,
           -0.4329358285916454,
           -0.4540561138227413,
           -0.47560102618981914,
           -0.49749592901268824,
           -0.5196767574822627,
           -0.5420882840853631,
           -0.5646826586094669,
           -0.5874181912240726,
           -0.610258344015738,
           -0.6331708977888564,
           -0.656127264415127,
           -0.6791019191399011,
           -0.7020719313249143,
           -0.7250165757990771,
           -0.7479170101852393,
           -0.7707560062616868,
           -0.7935177256432224,
           -0.8161875318880617,
           -0.8387518326167761,
           -0.861197946427241,
           -0.883513990356861,
           -0.9056887844240383,
           -0.9277117704111933,
           -0.9495729425611515,
           -0.9712627882712639,
           -0.9927722372043579,
           -1.014092617507873,
           -1.0352156180545409,
           -1.0561332557995182,
           -1.076837847497756,
           -1.0973219851478262,
           -1.1175785146294432,
           -1.1376005170854733,
           -1.1573812926685754,
           -1.1769143463303253,
           -1.1961933753788525,
           -1.2152122585713299,
           -1.2339650465415262,
           -1.252445953391104,
           -1.2706493492974176,
           -1.2885697540109076,
           -1.3062018311324806,
           -1.3235403830759378,
           -1.3405803466330712,
           -1.3573167890697548,
           -1.3737449046905381,
           -1.3898600118171545,
           -1.4056575501331359,
           -1.421133078352599,
           -1.4362822721763329,
           -1.4511009225027156,
           -1.465584933864806,
           -1.479730323068272,
           -1.493533218007723,
           -1.5069898566415376,
           -1.520096586107498,
           -1.5328498619634852,
           -1.5452462475391975,
           -1.5572824133863592,
           -1.5689551368162111,
           -1.5802613015142468,
           -1.5911978972232013,
           -1.601762019486211,
           -1.6119508694428832,
           -1.6217617536717484,
           -1.6311920840732033,
           -1.640239377787648,
           -1.6489012571440183,
           -1.657175449634405,
           -1.6650597879108415,
           -1.6725522098007397,
           -1.679650758337777,
           -1.6863535818053546,
           -1.6926589337900106,
           -1.6985651732424434,
           -1.70407076454401,
           -1.709174277576781,
           -1.7138743877954374,
           -1.71816987629944,
           -1.7220596299041027,
           -1.7255426412093209,
           -1.7286180086648548,
           -1.7312849366312084,
           -1.733542735435249,
           -1.7353908214198395,
           -1.7368287169868593,
           -1.7378560506330996,
           -1.7384725569786041
          ],
          [
           -1.768823677885037,
           -1.7686134162648677,
           -1.7679826848683293,
           -1.766931644081184,
           -1.7654605611925678,
           -1.7635698103644257,
           -1.7612598725889683,
           -1.758531335634421,
           -1.7553848939793926,
           -1.751821348736289,
           -1.747841607564263,
           -1.7434466845722905,
           -1.7386377002130564,
           -1.7334158811684204,
           -1.7277825602273496,
           -1.7217391761573064,
           -1.7152872735702116,
           -1.7084285027842157,
           -1.7011646196826746,
           -1.6934974855718592,
           -1.6854290670391043,
           -1.6769614358132952,
           -1.6680967686297696,
           -1.658837347101961,
           -1.6491855576023353,
           -1.6391438911554537,
           -1.6287149433462988,
           -1.6179014142473267,
           -1.606706108368095,
           -1.5951319346317188,
           -1.583181906382893,
           -1.570859141432718,
           -1.5581668621461848,
           -1.545108395578803,
           -1.5316871736696285,
           -1.5179067334987744,
           -1.5037707176184465,
           -1.489282874467621,
           -1.4744470588817098,
           -1.4592672327099563,
           -1.4437474655548885,
           -1.4278919356499786,
           -1.4117049308937302,
           -1.3951908500608075,
           -1.3783542042135575,
           -1.3611996183404202,
           -1.3437318332513943,
           -1.3259557077649038,
           -1.3078762212253308,
           -1.2894984763961372,
           -1.2708277027801307,
           -1.2518692604261443,
           -1.2326286442904717,
           -1.2131114892319979,
           -1.1933235757324996,
           -1.173270836448334,
           -1.1529593637172215,
           -1.1323954181645814,
           -1.111585438578577,
           -1.0905360532525534,
           -1.0692540930289134,
           -1.047746606320995,
           -1.026020876440803,
           -1.0040844416225179,
           -0.9819451182071164,
           -0.9596110275453436,
           -0.9370906272887426,
           -0.9143927478765754,
           -0.8915266351967428,
           -0.8685020006095792,
           -0.8453290797852597,
           -0.8220187021322324,
           -0.7985823730031862,
           -0.7750323713794043,
           -0.7513818663834202,
           -0.7276450567919742,
           -0.7038373387659189,
           -0.6799755083451225,
           -0.6560780069572989,
           -0.632165220365891,
           -0.6082598442675192,
           -0.5843873333098775,
           -0.5605764548347775,
           -0.5368599743818097,
           -0.5132755071380486,
           -0.489866578244943,
           -0.4666839451261408,
           -0.44378724624257254,
           -0.42124705134451595,
           -0.3991473947693952,
           -0.3775888682247264,
           -0.3566923187013075,
           -0.3366031156497392,
           -0.31749577846374727,
           -0.2995784320427041,
           -0.28309602003778994,
           -0.2683304293674694,
           -0.25559480086060293,
           -0.24521880127329798,
           -0.23752246495673277,
           -0.23277946464682847,
           -0.231176322114963,
           -0.23277946464683177,
           -0.2375224649567392,
           -0.24521880127330728,
           -0.2555948008606148,
           -0.26833042936748364,
           -0.2830960200378061,
           -0.2995784320427219,
           -0.31749577846376636,
           -0.3366031156497594,
           -0.35669231870132856,
           -0.3775888682247482,
           -0.3991473947694177,
           -0.42124705134453894,
           -0.4437872462425959,
           -0.4666839451261645,
           -0.489866578244967,
           -0.5132755071380728,
           -0.536859974381834,
           -0.560576454834802,
           -0.5843873333099021,
           -0.6082598442675438,
           -0.6321652203659154,
           -0.6560780069573234,
           -0.679975508345147,
           -0.7038373387659435,
           -0.7276450567919986,
           -0.7513818663834444,
           -0.7750323713794288,
           -0.7985823730032106,
           -0.8220187021322565,
           -0.8453290797852836,
           -0.868502000609603,
           -0.8915266351967664,
           -0.9143927478765989,
           -0.9370906272887658,
           -0.9596110275453665,
           -0.9819451182071394,
           -1.0040844416225405,
           -1.0260208764408254,
           -1.0477466063210177,
           -1.0692540930289351,
           -1.090536053252575,
           -1.1115854385785986,
           -1.1323954181646028,
           -1.1529593637172424,
           -1.1732708364483546,
           -1.1933235757325202,
           -1.2131114892320178,
           -1.2326286442904915,
           -1.2518692604261639,
           -1.2708277027801498,
           -1.2894984763961563,
           -1.3078762212253494,
           -1.3259557077649222,
           -1.3437318332514123,
           -1.361199618340438,
           -1.3783542042135748,
           -1.3951908500608246,
           -1.4117049308937468,
           -1.4278919356499948,
           -1.4437474655549047,
           -1.459267232709972,
           -1.474447058881725,
           -1.4892828744676363,
           -1.5037707176184614,
           -1.5179067334987886,
           -1.5316871736696422,
           -1.5451083955788167,
           -1.5581668621461984,
           -1.570859141432731,
           -1.5831819063829053,
           -1.595131934631731,
           -1.6067061083681067,
           -1.617901414247338,
           -1.62871494334631,
           -1.6391438911554643,
           -1.6491855576023455,
           -1.6588373471019706,
           -1.6680967686297792,
           -1.676961435813304,
           -1.685429067039113,
           -1.6934974855718674,
           -1.7011646196826824,
           -1.7084285027842228,
           -1.7152872735702183,
           -1.7217391761573129,
           -1.727782560227355,
           -1.7334158811684262,
           -1.7386377002130615,
           -1.7434466845722953,
           -1.7478416075642673,
           -1.751821348736293,
           -1.755384893979396,
           -1.7585313356344237,
           -1.761259872588971,
           -1.763569810364428,
           -1.7654605611925696,
           -1.7669316440811849,
           -1.7679826848683302,
           -1.768613416264868
          ],
          [
           -1.7991929271442884,
           -1.7989780492112952,
           -1.7983334693287212,
           -1.7972593492378275,
           -1.7957559584808982,
           -1.7938236743616065,
           -1.7914629818897365,
           -1.7886744737104472,
           -1.7854588500183495,
           -1.7818169184567185,
           -1.7777495940022263,
           -1.7732578988356555,
           -1.7683429621991196,
           -1.763006020240395,
           -1.7572484158450437,
           -1.751071598457109,
           -1.7444771238892354,
           -1.7374666541231825,
           -1.730041957101811,
           -1.7222049065137204,
           -1.7139574815718717,
           -1.705301766787651,
           -1.6962399517419933,
           -1.6867743308553593,
           -1.6769073031585426,
           -1.6666413720664999,
           -1.655979145157619,
           -1.6449233339611211,
           -1.633476753755547,
           -1.6216423233816435,
           -1.60942306507328,
           -1.596822104310475,
           -1.5838426696990324,
           -1.5704880928818203,
           -1.5567618084872927,
           -1.5426673541215146,
           -1.5282083704106855,
           -1.5133886011020017,
           -1.4982118932316433,
           -1.4826821973697715,
           -1.466803567953655,
           -1.450580163721469,
           -1.434016248260935,
           -1.4171161906888483,
           -1.3998844664796881,
           -1.3823256584639942,
           -1.3644444580200716,
           -1.346245666485915,
           -1.3277341968221295,
           -1.308915075561126,
           -1.2897934450831607,
           -1.270374566265949,
           -1.2506638215618524,
           -1.230666718565177,
           -1.210388894142201,
           -1.1898361192085232,
           -1.169014304252506,
           -1.1479295057205237,
           -1.1265879333999698,
           -1.1049959589602665,
           -1.0831601258413655,
           -1.061087160714573,
           -1.0387839867834092,
           -1.0162577392444023,
           -0.9935157832915462,
           -0.9705657351264805,
           -0.9474154865330282,
           -0.9240732336943122,
           -0.9005475110794057,
           -0.8768472314123661,
           -0.852981732969914,
           -0.8289608357486017,
           -0.8047949084159745,
           -0.7804949484366512,
           -0.7560726783749847,
           -0.7315406621630366,
           -0.7069124461425113,
           -0.6822027310180144,
           -0.6574275825992926,
           -0.6326046915011108,
           -0.6077536949997192,
           -0.5828965782698535,
           -0.5580581775899044,
           -0.5332668152643985,
           -0.508555105573518,
           -0.48396098378076063,
           -0.45952902701762494,
           -0.4353121576581401,
           -0.4113738472375535,
           -0.3877909715758536,
           -0.36465750206441583,
           -0.34208924364823806,
           -0.3202298216848459,
           -0.2992580232609614,
           -0.27939630758397865,
           -0.26091963152212355,
           -0.24416243547018726,
           -0.22951951371345325,
           -0.217433900696578,
           -0.20836363091248816,
           -0.20272308218560967,
           -0.20080707285571164,
           -0.2027230821856136,
           -0.20836363091249577,
           -0.21743390069658897,
           -0.22951951371346707,
           -0.24416243547020344,
           -0.2609196315221418,
           -0.27939630758399847,
           -0.2992580232609824,
           -0.32022982168486797,
           -0.342089243648261,
           -0.36465750206443936,
           -0.38779097157587755,
           -0.41137384723757797,
           -0.43531215765816483,
           -0.45952902701764997,
           -0.4839609837807859,
           -0.5085551055735436,
           -0.5332668152644239,
           -0.55805817758993,
           -0.5828965782698791,
           -0.6077536949997446,
           -0.6326046915011362,
           -0.6574275825993181,
           -0.6822027310180397,
           -0.7069124461425365,
           -0.7315406621630618,
           -0.7560726783750098,
           -0.7804949484366763,
           -0.8047949084159993,
           -0.8289608357486264,
           -0.8529817329699385,
           -0.8768472314123906,
           -0.9005475110794298,
           -0.9240732336943361,
           -0.9474154865330522,
           -0.970565735126504,
           -0.9935157832915695,
           -1.0162577392444254,
           -1.0387839867834323,
           -1.061087160714596,
           -1.083160125841388,
           -1.104995958960289,
           -1.1265879333999917,
           -1.1479295057205454,
           -1.1690143042525276,
           -1.1898361192085447,
           -1.210388894142222,
           -1.2306667185651978,
           -1.2506638215618728,
           -1.2703745662659687,
           -1.2897934450831803,
           -1.3089150755611454,
           -1.3277341968221488,
           -1.346245666485934,
           -1.36444445802009,
           -1.3823256584640122,
           -1.3998844664797059,
           -1.4171161906888656,
           -1.434016248260952,
           -1.450580163721486,
           -1.4668035679536715,
           -1.4826821973697875,
           -1.4982118932316588,
           -1.513388601102017,
           -1.5282083704107003,
           -1.5426673541215292,
           -1.5567618084873072,
           -1.5704880928818343,
           -1.5838426696990462,
           -1.596822104310488,
           -1.6094230650732924,
           -1.621642323381656,
           -1.6334767537555592,
           -1.6449233339611324,
           -1.6559791451576302,
           -1.6666413720665108,
           -1.6769073031585533,
           -1.6867743308553693,
           -1.6962399517420028,
           -1.70530176678766,
           -1.7139574815718803,
           -1.7222049065137286,
           -1.7300419571018189,
           -1.7374666541231896,
           -1.744477123889242,
           -1.7510715984571157,
           -1.7572484158450494,
           -1.7630060202404008,
           -1.768342962199125,
           -1.7732578988356602,
           -1.7777495940022308,
           -1.7818169184567225,
           -1.7854588500183532,
           -1.78867447371045,
           -1.7914629818897392,
           -1.7938236743616087,
           -1.7957559584808995,
           -1.7972593492378286,
           -1.7983334693287218,
           -1.7989780492112961
          ],
          [
           -1.8297564442776084,
           -1.8295370752200042,
           -1.8288790224853526,
           -1.8277824493785917,
           -1.8262476280428452,
           -1.824274939411828,
           -1.8218648731433733,
           -1.8190180275342203,
           -1.8157351094162615,
           -1.812016934034499,
           -1.8078644249069917,
           -1.803278613667141,
           -1.7982606398887075,
           -1.7928117508940102,
           -1.7869333015458229,
           -1.7806267540235374,
           -1.773893677584246,
           -1.7667357483094492,
           -1.7591547488382058,
           -1.7511525680875912,
           -1.7427312009614657,
           -1.733892748048622,
           -1.7246394153115228,
           -1.714973513766955,
           -1.7048974591600574,
           -1.6944137716333552,
           -1.6835250753925783,
           -1.6722340983712563,
           -1.6605436718962716,
           -1.6484567303568076,
           -1.635976310879381,
           -1.6231055530119478,
           -1.609847698420412,
           -1.5962060906012316,
           -1.5821841746142464,
           -1.567785496840335,
           -1.5530137047690484,
           -1.5378725468219807,
           -1.5223658722183524,
           -1.506497630890071,
           -1.4902718734544587,
           -1.4736927512538807,
           -1.4567645164727168,
           -1.4394915223434952,
           -1.4218782234556235,
           -1.4039291761819743,
           -1.3856490392407441,
           -1.3670425744124755,
           -1.3481146474350274,
           -1.3288702291026666,
           -1.3093143965993863,
           -1.2894523351012233,
           -1.2692893396877798,
           -1.2488308176096332,
           -1.228082290965929,
           -1.2070493998555385,
           -1.185737906075966,
           -1.1641536974571245,
           -1.1423027929326008,
           -1.1201913484697272,
           -1.0978256640023412,
           -1.0752121915375368,
           -1.0523575446410873,
           -1.0292685095470813,
           -1.005952058187511,
           -0.9824153634995385,
           -0.9586658174450154,
           -0.9347110522726542,
           -0.9105589656732556,
           -0.886217750629561,
           -0.8616959309537192,
           -0.8370024037491824,
           -0.8121464903462684,
           -0.7871379976634759,
           -0.7619872924694291,
           -0.7367053917033822,
           -0.7113040729109102,
           -0.6857960100423461,
           -0.6601949414515732,
           -0.6345158790718725,
           -0.6087753706457103,
           -0.5829918308482815,
           -0.5571859626019476,
           -0.5313812974507247,
           -0.5056048944441466,
           -0.47988825185356104,
           -0.4542685070484503,
           -0.42879002957971685,
           -0.40350655446570244,
           -0.37848406131234397,
           -0.353804685004515,
           -0.3295720479593858,
           -0.3059185257754867,
           -0.283015063333298,
           -0.2610841418890634,
           -0.24041609273655937,
           -0.22138757660358271,
           -0.20447766310362459,
           -0.19027041647096177,
           -0.17942417549889914,
           -0.17258506318876615,
           -0.17024355572239155,
           -0.17258506318877093,
           -0.17942417549890832,
           -0.19027041647097476,
           -0.20447766310364068,
           -0.22138757660360128,
           -0.24041609273657988,
           -0.26108414188908535,
           -0.28301506333332105,
           -0.30591852577551076,
           -0.3295720479594104,
           -0.3538046850045402,
           -0.37848406131236956,
           -0.4035065544657283,
           -0.42879002957974294,
           -0.4542685070484766,
           -0.4798882518535874,
           -0.5056048944441731,
           -0.5313812974507512,
           -0.5571859626019743,
           -0.5829918308483081,
           -0.6087753706457365,
           -0.6345158790718989,
           -0.6601949414515995,
           -0.6857960100423726,
           -0.7113040729109364,
           -0.7367053917034083,
           -0.7619872924694551,
           -0.7871379976635018,
           -0.8121464903462939,
           -0.8370024037492079,
           -0.8616959309537447,
           -0.8862177506295861,
           -0.9105589656732804,
           -0.9347110522726788,
           -0.95866581744504,
           -0.9824153634995628,
           -1.0059520581875352,
           -1.0292685095471052,
           -1.052357544641111,
           -1.07521219153756,
           -1.0978256640023645,
           -1.12019134846975,
           -1.1423027929326235,
           -1.164153697457147,
           -1.1857379060759883,
           -1.2070493998555603,
           -1.2280822909659506,
           -1.248830817609654,
           -1.2692893396878007,
           -1.2894523351012437,
           -1.3093143965994067,
           -1.3288702291026864,
           -1.3481146474350472,
           -1.3670425744124948,
           -1.3856490392407632,
           -1.4039291761819928,
           -1.4218782234556415,
           -1.4394915223435132,
           -1.4567645164727343,
           -1.4736927512538982,
           -1.4902718734544753,
           -1.5064976308900875,
           -1.5223658722183686,
           -1.5378725468219965,
           -1.5530137047690638,
           -1.56778549684035,
           -1.5821841746142609,
           -1.596206090601246,
           -1.6098476984204262,
           -1.6231055530119611,
           -1.6359763108793939,
           -1.6484567303568205,
           -1.6605436718962838,
           -1.6722340983712682,
           -1.6835250753925897,
           -1.6944137716333663,
           -1.7048974591600683,
           -1.7149735137669653,
           -1.7246394153115328,
           -1.733892748048631,
           -1.7427312009614746,
           -1.7511525680875997,
           -1.7591547488382135,
           -1.766735748309457,
           -1.7738936775842529,
           -1.7806267540235443,
           -1.7869333015458289,
           -1.7928117508940162,
           -1.7982606398887129,
           -1.803278613667146,
           -1.8078644249069962,
           -1.8120169340345031,
           -1.815735109416265,
           -1.8190180275342236,
           -1.8218648731433764,
           -1.82427493941183,
           -1.8262476280428466,
           -1.8277824493785928,
           -1.8288790224853535,
           -1.829537075220005
          ],
          [
           -1.8604846610560841,
           -1.8602609254319462,
           -1.8595897735885951,
           -1.8584713706023206,
           -1.8569059915639674,
           -1.8548940215245266,
           -1.8524359554190786,
           -1.8495323979691858,
           -1.8461840635638809,
           -1.842391776119428,
           -1.838156468918058,
           -1.8334791844259333,
           -1.8283610740906138,
           -1.8228033981183556,
           -1.8168075252316038,
           -1.810374932407092,
           -1.8035072045950018,
           -1.7962060344197004,
           -1.7884732218626198,
           -1.7803106739279033,
           -1.771720404291516,
           -1.7627045329345852,
           -1.7532652857618145,
           -1.743404994205906,
           -1.733126094819019,
           -1.7224311288523948,
           -1.7113227418254062,
           -1.699803683085407,
           -1.687876805359911,
           -1.6755450643027898,
           -1.6628115180363574,
           -1.6496793266914147,
           -1.636151751947552,
           -1.6222321565762738,
           -1.6079240039897849,
           -1.5932308577986172,
           -1.578156381381646,
           -1.562704337472457,
           -1.5468785877665239,
           -1.5306830925541846,
           -1.514121910385046,
           -1.4971991977701622,
           -1.4799192089291489,
           -1.4622862955903595,
           -1.4443049068533371,
           -1.4259795891240286,
           -1.4073149861347187,
           -1.3883158390623582,
           -1.368986986760947,
           -1.3493333661259814,
           -1.3293600126116976,
           -1.309072060925069,
           -1.2884747459243076,
           -1.2675734037541035,
           -1.246373473255172,
           -1.224880497692006,
           -1.2031001268503165,
           -1.1810381195647135,
           -1.1587003467481163,
           -1.136092795007566,
           -1.1132215709471156,
           -1.0900929062779559,
           -1.066713163879747,
           -1.043088844986383,
           -1.0192265977055108,
           -0.9951332271258819,
           -0.9708157073223864,
           -0.9462811956385072,
           -0.921537049713942,
           -0.8965908478367048,
           -0.8714504133411989,
           -0.8461238439561963,
           -0.8206195472422931,
           -0.7949462835648758,
           -0.7691132184502305,
           -0.7431299867027039,
           -0.717006771366807,
           -0.6907544015661182,
           -0.664384474535261,
           -0.6379095089181023,
           -0.611343138832405,
           -0.5847003615893345,
           -0.5579978567377899,
           -0.5312544009285324,
           -0.5044914129495652,
           -0.47773367769031944,
           -0.45101031910324685,
           -0.42435612413091334,
           -0.39781336784197374,
           -0.37143436375194916,
           -0.3452850765706691,
           -0.3194503084992961,
           -0.29404123369537816,
           -0.26920643987162796,
           -0.2451481443697971,
           -0.22214575147008286,
           -0.20058881508741594,
           -0.18101890044811622,
           -0.16417024236181552,
           -0.1509754211463707,
           -0.14246751607536998,
           -0.1395153389439158,
           -0.14246751607537597,
           -0.15097542114638204,
           -0.16417024236183111,
           -0.18101890044813504,
           -0.20058881508743717,
           -0.22214575147010587,
           -0.24514814436982135,
           -0.2692064398716531,
           -0.294041233695404,
           -0.31945030849932243,
           -0.34528507657069585,
           -0.37143436375197614,
           -0.3978133678420009,
           -0.4243561241309407,
           -0.45101031910327427,
           -0.47773367769034697,
           -0.5044914129495929,
           -0.5312544009285598,
           -0.5579978567378174,
           -0.5847003615893618,
           -0.6113431388324322,
           -0.6379095089181294,
           -0.6643844745352881,
           -0.6907544015661453,
           -0.7170067713668341,
           -0.7431299867027308,
           -0.7691132184502572,
           -0.7949462835649022,
           -0.8206195472423194,
           -0.8461238439562225,
           -0.8714504133412247,
           -0.8965908478367307,
           -0.9215370497139674,
           -0.9462811956385325,
           -0.9708157073224116,
           -0.9951332271259068,
           -1.0192265977055357,
           -1.0430888449864073,
           -1.066713163879771,
           -1.0900929062779798,
           -1.1132215709471394,
           -1.1360927950075894,
           -1.1587003467481394,
           -1.1810381195647361,
           -1.2031001268503387,
           -1.2248804976920282,
           -1.2463734732551937,
           -1.2675734037541249,
           -1.2884747459243289,
           -1.3090720609250903,
           -1.3293600126117182,
           -1.3493333661260016,
           -1.368986986760967,
           -1.388315839062378,
           -1.4073149861347383,
           -1.4259795891240474,
           -1.4443049068533558,
           -1.4622862955903777,
           -1.4799192089291666,
           -1.4971991977701797,
           -1.5141219103850632,
           -1.5306830925542012,
           -1.5468785877665403,
           -1.5627043374724732,
           -1.5781563813816617,
           -1.5932308577986325,
           -1.6079240039897995,
           -1.622232156576288,
           -1.6361517519475661,
           -1.649679326691428,
           -1.6628115180363707,
           -1.6755450643028025,
           -1.6878768053599236,
           -1.699803683085419,
           -1.7113227418254182,
           -1.7224311288524063,
           -1.7331260948190295,
           -1.7434049942059164,
           -1.753265285761824,
           -1.7627045329345945,
           -1.7717204042915253,
           -1.7803106739279118,
           -1.788473221862628,
           -1.7962060344197077,
           -1.8035072045950085,
           -1.8103749324070988,
           -1.81680752523161,
           -1.8228033981183613,
           -1.828361074090619,
           -1.8334791844259384,
           -1.8381564689180627,
           -1.8423917761194322,
           -1.8461840635638849,
           -1.8495323979691891,
           -1.8524359554190815,
           -1.8548940215245286,
           -1.8569059915639687,
           -1.858471370602322,
           -1.859589773588596,
           -1.860260925431947
          ],
          [
           -1.8913478499145329,
           -1.8911198713720723,
           -1.8904359914328355,
           -1.88929637714924,
           -1.887701306901918,
           -1.8856511703396643,
           -1.883146468295431,
           -1.8801878126784557,
           -1.876775926342604,
           -1.8729116429310653,
           -1.8685959066975297,
           -1.863829772304019,
           -1.8586144045955646,
           -1.8529510783519556,
           -1.8468411780167941,
           -1.8402861974041478,
           -1.8332877393831026,
           -1.8258475155405562,
           -1.8179673458226422,
           -1.809649158155192,
           -1.8008949880437055,
           -1.7917069781533348,
           -1.7820873778694377,
           -1.772038542839321,
           -1.7615629344958401,
           -1.7506631195636027,
           -1.7393417695485849,
           -1.7276016602120627,
           -1.7154456710298371,
           -1.70287678463785,
           -1.6898980862653794,
           -1.676512763157148,
           -1.6627241039858096,
           -1.6485354982564349,
           -1.6339504357048036,
           -1.6189725056915116,
           -1.603605396594121,
           -1.587852895199857,
           -1.5717188861016334,
           -1.5552073511005413,
           -1.5383223686183125,
           -1.5210681131237123,
           -1.5034488545773272,
           -1.4854689578997953,
           -1.4671328824692056,
           -1.448445181654169,
           -1.4294105023899795,
           -1.4100335848063354,
           -1.3903192619163185,
           -1.3702724593777855,
           -1.3498981953400064,
           -1.329201580390381,
           -1.3081878176184212,
           -1.2868622028169745,
           -1.26523012484397,
           -1.2432970661719263,
           -1.2210686036571878,
           -1.1985504095665285,
           -1.1757482529056078,
           -1.1526680011020591,
           -1.129315622106045,
           -1.1056971869834156,
           -1.0818188730916707,
           -1.057686967947481,
           -1.033307873917511,
           -1.008688113892846,
           -0.9838343381430862,
           -0.9587533325911199,
           -0.9334520288064646,
           -0.9079375160874691,
           -0.8822170560954273,
           -0.8562981006233209,
           -0.8301883132373978,
           -0.803895595733358,
           -0.7774281206176071,
           -0.750794371181682,
           -0.7240031912183369,
           -0.697063847079237,
           -0.669986105666676,
           -0.6427803331877345,
           -0.6154576212308607,
           -0.5880299491807931,
           -0.5605103955170775,
           -0.532913415685029,
           -0.5052552118374298,
           -0.4775542311843775,
           -0.4498318471810215,
           -0.4221133050213526,
           -0.394429056141703,
           -0.3668166764534911,
           -0.3393236787606508,
           -0.3120117250485135,
           -0.28496307983275804,
           -0.2582907303705947,
           -0.23215462121163874,
           -0.20678819608710633,
           -0.18254216743309326,
           -0.15995547822850043,
           -0.1398612826527609,
           -0.12350603786807961,
           -0.1125504828785645,
           -0.10865215008546714,
           -0.11255048287857237,
           -0.12350603786809393,
           -0.13986128265277983,
           -0.15995547822852252,
           -0.18254216743311746,
           -0.20678819608713195,
           -0.23215462121166525,
           -0.2582907303706219,
           -0.2849630798327857,
           -0.31201172504854147,
           -0.339323678760679,
           -0.3668166764535195,
           -0.39442905614173135,
           -0.4221133050213811,
           -0.44983184718104996,
           -0.477554231184406,
           -0.5052552118374583,
           -0.5329134156850575,
           -0.560510395517106,
           -0.5880299491808214,
           -0.6154576212308888,
           -0.6427803331877625,
           -0.6699861056667038,
           -0.6970638470792646,
           -0.7240031912183644,
           -0.7507943711817094,
           -0.7774281206176343,
           -0.8038955957333851,
           -0.8301883132374247,
           -0.8562981006233477,
           -0.8822170560954538,
           -0.9079375160874956,
           -0.9334520288064907,
           -0.9587533325911457,
           -0.983834338143112,
           -1.0086881138928714,
           -1.033307873917536,
           -1.0576869679475058,
           -1.0818188730916953,
           -1.1056971869834402,
           -1.1293156221060692,
           -1.152668001102083,
           -1.1757482529056316,
           -1.1985504095665518,
           -1.2210686036572111,
           -1.2432970661719491,
           -1.2652301248439923,
           -1.2868622028169967,
           -1.3081878176184432,
           -1.3292015803904023,
           -1.3498981953400273,
           -1.3702724593778062,
           -1.3903192619163387,
           -1.4100335848063557,
           -1.4294105023899994,
           -1.4484451816541881,
           -1.4671328824692247,
           -1.4854689578998141,
           -1.5034488545773455,
           -1.5210681131237302,
           -1.53832236861833,
           -1.5552073511005584,
           -1.57171888610165,
           -1.5878528951998736,
           -1.603605396594137,
           -1.618972505691527,
           -1.633950435704819,
           -1.6485354982564495,
           -1.6627241039858245,
           -1.6765127631571621,
           -1.6898980862653925,
           -1.7028767846378634,
           -1.71544567102985,
           -1.7276016602120747,
           -1.7393417695485969,
           -1.7506631195636142,
           -1.7615629344958514,
           -1.7720385428393315,
           -1.782087377869448,
           -1.7917069781533446,
           -1.8008949880437148,
           -1.8096491581552006,
           -1.8179673458226502,
           -1.8258475155405638,
           -1.8332877393831095,
           -1.8402861974041549,
           -1.8468411780168004,
           -1.8529510783519616,
           -1.8586144045955701,
           -1.863829772304024,
           -1.8685959066975342,
           -1.8729116429310695,
           -1.8767759263426078,
           -1.880187812678459,
           -1.8831464682954344,
           -1.8856511703396663,
           -1.8877013069019197,
           -1.889296377149241,
           -1.8904359914328366,
           -1.8911198713720725
          ],
          [
           -1.9223161527110013,
           -1.922084053745497,
           -1.9213878132627347,
           -1.920227600491053,
           -1.9186036974346452,
           -1.9165164988090209,
           -1.9139665119507128,
           -1.9109543567012592,
           -1.9074807652655374,
           -1.90354658204453,
           -1.899152763442606,
           -1.8943003776494334,
           -1.888990604396654,
           -1.88322473468945,
           -1.8770041705131741,
           -1.870330424515217,
           -1.8632051196623074,
           -1.8556299888734686,
           -1.847606874628867,
           -1.8391377285548176,
           -1.8302246109852365,
           -1.820869690499848,
           -1.8110752434395005,
           -1.8008436533989571,
           -1.790177410697572,
           -1.779079111828303,
           -1.7675514588855354,
           -1.7555972589722642,
           -1.7432194235871967,
           -1.7304209679924243,
           -1.7172050105623486,
           -1.7035747721146306,
           -1.6895335752239913,
           -1.6750848435197938,
           -1.6602321009684131,
           -1.644978971141521,
           -1.6293291764715214,
           -1.6132865374955176,
           -1.5968549720893375,
           -1.5800384946933246,
           -1.5628412155318028,
           -1.5452673398283459,
           -1.5273211670192561,
           -1.5090070899679453,
           -1.4903295941832795,
           -1.4712932570453308,
           -1.45190274704247,
           -1.4321628230242662,
           -1.4120783334752995,
           -1.391654215815744,
           -1.3708954957354462,
           -1.349807286569265,
           -1.3283947887226462,
           -1.3066632891578598,
           -1.284618160953044,
           -1.262264862948243,
           -1.2396089394950973,
           -1.2166560203297885,
           -1.19341182059241,
           -1.1698821410202636,
           -1.1460728683478398,
           -1.1219899759526801,
           -1.0976395247942157,
           -1.0730276647024437,
           -1.0481606360853963,
           -1.0230447721394471,
           -0.9976865016654296,
           -0.9720923526173988,
           -0.9462689565411563,
           -0.9202230540983304,
           -0.8939615019215347,
           -0.8674912811105284,
           -0.8408195077633394,
           -0.8139534460468516,
           -0.7869005244580134,
           -0.7596683561231438,
           -0.7322647642481797,
           -0.704697814195107,
           -0.6769758541601936,
           -0.649107567128732,
           -0.6211020377701366,
           -0.5929688393559723,
           -0.564718147848513,
           -0.5363608933613458,
           -0.5079089637884748,
           -0.4793754824429374,
           -0.45077519256937953,
           -0.4221249992352799,
           -0.39344474803596774,
           -0.3647583687928208,
           -0.33609559702627756,
           -0.3074946376956036,
           -0.27900641764988904,
           -0.25070161795496776,
           -0.2226827737112088,
           -0.1951060281858607,
           -0.16822211773739454,
           -0.14245709281517907,
           -0.11857543344055704,
           -0.09799511288167106,
           -0.08322896995952223,
           -0.07768384728899864,
           -0.08322896995953323,
           -0.09799511288168976,
           -0.1185754334405802,
           -0.14245709281520474,
           -0.1682221177374217,
           -0.19510602818588874,
           -0.22268277371123743,
           -0.25070161795499674,
           -0.27900641764991824,
           -0.30749463769563296,
           -0.3360955970263071,
           -0.36475836879285034,
           -0.39344474803599716,
           -0.4221249992353094,
           -0.4507751925694089,
           -0.4793754824429667,
           -0.5079089637885041,
           -0.5363608933613752,
           -0.5647181478485422,
           -0.5929688393560012,
           -0.6211020377701655,
           -0.6491075671287606,
           -0.676975854160222,
           -0.7046978141951354,
           -0.7322647642482079,
           -0.7596683561231717,
           -0.7869005244580412,
           -0.8139534460468794,
           -0.8408195077633669,
           -0.8674912811105557,
           -0.8939615019215618,
           -0.9202230540983573,
           -0.9462689565411829,
           -0.9720923526174252,
           -0.9976865016654558,
           -1.0230447721394729,
           -1.0481606360854219,
           -1.0730276647024692,
           -1.0976395247942408,
           -1.121989975952705,
           -1.1460728683478645,
           -1.1698821410202878,
           -1.193411820592434,
           -1.2166560203298122,
           -1.2396089394951206,
           -1.262264862948266,
           -1.284618160953067,
           -1.3066632891578824,
           -1.3283947887226681,
           -1.349807286569287,
           -1.3708954957354673,
           -1.391654215815765,
           -1.4120783334753204,
           -1.4321628230242869,
           -1.45190274704249,
           -1.47129325704535,
           -1.490329594183299,
           -1.5090070899679644,
           -1.5273211670192743,
           -1.545267339828364,
           -1.5628412155318203,
           -1.5800384946933423,
           -1.5968549720893546,
           -1.6132865374955345,
           -1.6293291764715379,
           -1.6449789711415366,
           -1.6602321009684287,
           -1.675084843519809,
           -1.6895335752240062,
           -1.703574772114645,
           -1.7172050105623624,
           -1.7304209679924376,
           -1.7432194235872098,
           -1.7555972589722766,
           -1.7675514588855477,
           -1.779079111828315,
           -1.7901774106975836,
           -1.8008436533989678,
           -1.811075243439511,
           -1.8208696904998574,
           -1.8302246109852458,
           -1.8391377285548267,
           -1.8476068746288752,
           -1.8556299888734766,
           -1.8632051196623152,
           -1.8703304245152241,
           -1.8770041705131806,
           -1.8832247346894564,
           -1.8889906043966596,
           -1.894300377649439,
           -1.8991527634426109,
           -1.9035465820445348,
           -1.9074807652655412,
           -1.9109543567012623,
           -1.913966511950716,
           -1.9165164988090233,
           -1.9186036974346468,
           -1.9202276004910546,
           -1.9213878132627358,
           -1.9220840537454977
          ],
          [
           -1.9533596096125903,
           -1.9531235113569507,
           -1.9524152737936546,
           -1.951235068519992,
           -1.9495831814861981,
           -1.9474600129275967,
           -1.944866077269632,
           -1.9418020030058256,
           -1.938268532548698,
           -1.934266522053705,
           -1.929796941216255,
           -1.9248608730418764,
           -1.919459513589615,
           -1.913594171688756,
           -1.9072662686289712,
           -1.9004773378240092,
           -1.8932290244490406,
           -1.8855230850518137,
           -1.8773613871377495,
           -1.8687459087291491,
           -1.8596787378986814,
           -1.8501620722773373,
           -1.8401982185370604,
           -1.8297895918482596,
           -1.818938715312445,
           -1.8076482193702357,
           -1.7959208411850056,
           -1.783759424002463,
           -1.7711669164864656,
           -1.758146372031416,
           -1.7447009480515845,
           -1.7308339052477604,
           -1.7165486068516416,
           -1.7018485178484155,
           -1.6867372041780249,
           -1.671218331915646,
           -1.6552956664319647,
           -1.6389730715338724,
           -1.6222545085862785,
           -1.6051440356157927,
           -1.5876458063971115,
           -1.5697640695230255,
           -1.5515031674590634,
           -1.5328675355839008,
           -1.5138617012167943,
           -1.4944902826334427,
           -1.4747579880718564,
           -1.4546696147300147,
           -1.4342300477573178,
           -1.4134442592421217,
           -1.3923173071979547,
           -1.3708543345513946,
           -1.3490605681350265,
           -1.326941317689427,
           -1.304501974878743,
           -1.281748012325184,
           -1.2586849826686277,
           -1.2353185176586257,
           -1.2116543272873865,
           -1.1876981989738826,
           -1.1634559968111478,
           -1.1389336608911766,
           -1.1141372067247193,
           -1.0890727247768188,
           -1.0637463801433764,
           -1.0381644123995346,
           -1.012333135657625,
           -0.9862589388811717,
           -0.9599482865125939,
           -0.9334077194865077,
           -0.9066438567188898,
           -0.8796633971862303,
           -0.8524731227399998,
           -0.8250799018429315,
           -0.7974906944684178,
           -0.7697125584779424,
           -0.7417526578913863,
           -0.7136182736020933,
           -0.6853168172787685,
           -0.6568558494634507,
           -0.628243103255222,
           -0.5994865155188154,
           -0.5705942683635976,
           -0.5415748448419198,
           -0.5124371046460406,
           -0.4831903884237157,
           -0.4538446638429222,
           -0.4244107338786899,
           -0.3949005400859227,
           -0.3653276148495324,
           -0.33570777458050577,
           -0.30606021654850457,
           -0.2764093199289719,
           -0.2467877351345683,
           -0.21724196556811293,
           -0.18784310465696927,
           -0.15870913183991997,
           -0.13005579167223102,
           -0.10232691659148421,
           -0.0765747291120776,
           -0.05565644496403768,
           -0.04664039038740978,
           -0.05565644496405471,
           -0.07657472911210234,
           -0.10232691659151197,
           -0.1300557916722601,
           -0.15870913183994975,
           -0.18784310465699938,
           -0.21724196556814324,
           -0.24678773513459876,
           -0.2764093199290024,
           -0.30606021654853505,
           -0.3357077745805363,
           -0.3653276148495628,
           -0.394900540085953,
           -0.42441073387872014,
           -0.45384466384295236,
           -0.4831903884237459,
           -0.5124371046460707,
           -0.5415748448419496,
           -0.5705942683636275,
           -0.5994865155188449,
           -0.6282431032552515,
           -0.6568558494634799,
           -0.6853168172787976,
           -0.7136182736021224,
           -0.7417526578914151,
           -0.769712558477971,
           -0.7974906944684461,
           -0.8250799018429597,
           -0.8524731227400278,
           -0.8796633971862581,
           -0.9066438567189173,
           -0.9334077194865351,
           -0.9599482865126211,
           -0.9862589388811986,
           -1.012333135657652,
           -1.038164412399561,
           -1.0637463801434026,
           -1.0890727247768448,
           -1.1141372067247448,
           -1.138933660891202,
           -1.1634559968111728,
           -1.1876981989739075,
           -1.2116543272874112,
           -1.2353185176586496,
           -1.2586849826686515,
           -1.2817480123252076,
           -1.3045019748787665,
           -1.3269413176894496,
           -1.3490605681350492,
           -1.3708543345514168,
           -1.3923173071979766,
           -1.4134442592421432,
           -1.4342300477573389,
           -1.4546696147300355,
           -1.474757988071877,
           -1.4944902826334625,
           -1.513861701216814,
           -1.53286753558392,
           -1.551503167459082,
           -1.5697640695230441,
           -1.5876458063971295,
           -1.6051440356158104,
           -1.6222545085862958,
           -1.6389730715338895,
           -1.6552956664319811,
           -1.671218331915662,
           -1.6867372041780406,
           -1.7018485178484313,
           -1.7165486068516567,
           -1.7308339052477746,
           -1.744700948051598,
           -1.7581463720314294,
           -1.7711669164864792,
           -1.783759424002476,
           -1.795920841185018,
           -1.8076482193702477,
           -1.8189387153124565,
           -1.8297895918482703,
           -1.8401982185370709,
           -1.8501620722773469,
           -1.859678737898691,
           -1.8687459087291587,
           -1.8773613871377581,
           -1.8855230850518216,
           -1.8932290244490482,
           -1.900477337824016,
           -1.9072662686289779,
           -1.9135941716887623,
           -1.9194595135896209,
           -1.9248608730418817,
           -1.9297969412162599,
           -1.9342665220537092,
           -1.9382685325487021,
           -1.9418020030058294,
           -1.9448660772696351,
           -1.9474600129275992,
           -1.9495831814862004,
           -1.9512350685199933,
           -1.9524152737936553,
           -1.9531235113569514
          ],
          [
           -1.984448188079657,
           -1.984208210125703,
           -1.9834883343188423,
           -1.9822887348100686,
           -1.9806097018043312,
           -1.9784516414904794,
           -1.9758150759432274,
           -1.9727006429971317,
           -1.96910909609264,
           -1.96504130409424,
           -1.9604982510807496,
           -1.9554810361078139,
           -1.9499908729426565,
           -1.9440290897711627,
           -1.9375971288773617,
           -1.9306965462953927,
           -1.9233290114340484,
           -1.9154963066739787,
           -1.9072003269376776,
           -1.8984430792323401,
           -1.8892266821657335,
           -1.879553365435184,
           -1.8694254692898258,
           -1.8588454439662498,
           -1.8478158490977,
           -1.8363393530969647,
           -1.8244187325131433,
           -1.8120568713624399,
           -1.7992567604331753,
           -1.7860214965652033,
           -1.772354281903919,
           -1.7582584231290745,
           -1.7437373306586041,
           -1.7287945178276924,
           -1.7134336000433041,
           -1.6976582939144287,
           -1.6814724163582873,
           -1.6648798836827627,
           -1.6478847106453323,
           -1.6304910094887877,
           -1.6127029889540438,
           -1.594524953270353,
           -1.5759613011232514,
           -1.5570165246005927,
           -1.5376952081170343,
           -1.5180020273173593,
           -1.4979417479590564,
           -1.477519224774593,
           -1.4567394003138456,
           -1.435607303767206,
           -1.4141280497698905,
           -1.3923068371880583,
           -1.370148947887368,
           -1.3476597454846921,
           -1.324844674083756,
           -1.301709256995576,
           -1.2782590954446582,
           -1.254499867262057,
           -1.2304373255665237,
           -1.206077297435168,
           -1.1814256825652587,
           -1.1564884519290723,
           -1.1312716464239896,
           -1.105781375520478,
           -1.0800238159110571,
           -1.0540052101639883,
           -1.0277318653861824,
           -1.0012101519008159,
           -0.974446501946376,
           -0.9474474084054578,
           -0.9202194235736794,
           -0.892769157981758,
           -0.8651032792872801,
           -0.8372285112573088,
           -0.8091516328691315,
           -0.780879477564721,
           -0.7524189327057356,
           -0.7237769392913571,
           -0.6949604920227721,
           -0.6659766398284065,
           -0.6368324870072932,
           -0.6075351952106766,
           -0.5780919865743277,
           -0.548510148452551,
           -0.5187970404165477,
           -0.4889601045103276,
           -0.45900688028576075,
           -0.42894502700559567,
           -0.39878235686917146,
           -0.3685268856772386,
           -0.33818691200184,
           -0.3077711447422449,
           -0.2772889165297433,
           -0.2467505576728371,
           -0.2161680900256445,
           -0.18555661050496494,
           -0.15493731735854227,
           -0.12434500048331583,
           -0.09385010320576291,
           -0.06364352007629748,
           -0.0345579064237627,
           -0.015551811920342959,
           -0.03455790642379102,
           -0.06364352007632823,
           -0.09385010320579418,
           -0.12434500048334725,
           -0.15493731735857375,
           -0.1855566105049964,
           -0.21616809002567594,
           -0.24675055767286846,
           -0.2772889165297747,
           -0.3077711447422761,
           -0.33818691200187123,
           -0.3685268856772697,
           -0.39878235686920255,
           -0.42894502700562653,
           -0.45900688028579156,
           -0.48896010451035843,
           -0.5187970404165784,
           -0.5485101484525814,
           -0.5780919865743581,
           -0.6075351952107068,
           -0.6368324870073231,
           -0.6659766398284364,
           -0.6949604920228019,
           -0.7237769392913866,
           -0.7524189327057648,
           -0.7808794775647503,
           -0.8091516328691605,
           -0.8372285112573374,
           -0.8651032792873088,
           -0.8927691579817865,
           -0.9202194235737075,
           -0.9474474084054857,
           -0.9744465019464037,
           -1.0012101519008432,
           -1.0277318653862098,
           -1.0540052101640152,
           -1.080023815911084,
           -1.1057813755205042,
           -1.1312716464240158,
           -1.156488451929098,
           -1.1814256825652842,
           -1.206077297435193,
           -1.2304373255665488,
           -1.2544998672620817,
           -1.2782590954446826,
           -1.3017092569955997,
           -1.3248446740837798,
           -1.3476597454847152,
           -1.370148947887391,
           -1.3923068371880807,
           -1.4141280497699127,
           -1.4356073037672277,
           -1.456739400313867,
           -1.477519224774614,
           -1.4979417479590773,
           -1.5180020273173793,
           -1.5376952081170545,
           -1.5570165246006125,
           -1.5759613011232703,
           -1.5945249532703716,
           -1.6127029889540623,
           -1.6304910094888057,
           -1.6478847106453498,
           -1.6648798836827798,
           -1.6814724163583041,
           -1.697658293914445,
           -1.71343360004332,
           -1.7287945178277078,
           -1.7437373306586195,
           -1.758258423129089,
           -1.7723542819039333,
           -1.786021496565217,
           -1.799256760433189,
           -1.8120568713624527,
           -1.8244187325131562,
           -1.836339353096977,
           -1.847815849097711,
           -1.858845443966261,
           -1.869425469289836,
           -1.8795533654351941,
           -1.889226682165743,
           -1.898443079232349,
           -1.9072003269376858,
           -1.9154963066739872,
           -1.9233290114340562,
           -1.9306965462954004,
           -1.9375971288773681,
           -1.9440290897711694,
           -1.949990872942662,
           -1.955481036107819,
           -1.9604982510807545,
           -1.9650413040942447,
           -1.9691090960926443,
           -1.9727006429971352,
           -1.9758150759432307,
           -1.9784516414904822,
           -1.9806097018043327,
           -1.9822887348100704,
           -1.983488334318843,
           -1.9842082101257037
          ],
          [
           -2.015551811920359,
           -2.01530807216807,
           -2.01457691187592,
           -2.0133585079238236,
           -2.011653155064198,
           -2.009461265850807,
           -2.0067833705391784,
           -2.003620116958603,
           -1.9999722703557572,
           -1.9958407132099947,
           -1.9912264450203332,
           -1.9861305820642159,
           -1.980554357128086,
           -1.9744991192098615,
           -1.9679663331933719,
           -1.9609575794948437,
           -1.953474553681534,
           -1.9455190660625934,
           -1.9370930412522762,
           -1.928198517705603,
           -1.918837647226601,
           -1.9090126944492405,
           -1.8987260362912115,
           -1.8879801613806755,
           -1.8767776694561464,
           -1.8651212707396543,
           -1.8530137852833628,
           -1.8404581422898028,
           -1.827457379405921,
           -1.8140146419911116,
           -1.8001331823594484,
           -1.7858163589963103,
           -1.771067635749623,
           -1.7558905809959402,
           -1.7402888667815963,
           -1.7242662679391776,
           -1.707826661179566,
           -1.690974024159822,
           -1.6737124345271803,
           -1.656046068939457,
           -1.6379792020621606,
           -1.619516205542635,
           -1.6006615469615613,
           -1.5814197887621726,
           -1.5617955871575535,
           -1.5417936910164094,
           -1.5214189407277265,
           -1.500676267044762,
           -1.4795706899088326,
           -1.4581073172534105,
           -1.4362913437890732,
           -1.4141280497698903,
           -1.3916227997418977,
           -1.3687810412743588,
           -1.3456083036745923,
           -1.322110196687227,
           -1.2982924091788464,
           -1.2741607078091088,
           -1.249720935689573,
           -1.2249790110316334,
           -1.199940925785183,
           -1.1746127442698822,
           -1.14900060180123,
           -1.123110703314022,
           -1.096949321986279,
           -1.0705227978673202,
           -1.043837536514433,
           -1.016900007643548,
           -0.9897167438005483,
           -0.9622943390614236,
           -0.9346394477714836,
           -0.9067587833364877,
           -0.8786591170819784,
           -0.8503472772016545,
           -0.8218301478216721,
           -0.79311466821592,
           -0.7642078322183837,
           -0.7351166878939576,
           -0.7058483375502316,
           -0.6764099382026356,
           -0.6468087026479155,
           -0.6170519013626908,
           -0.5871468655348042,
           -0.5571009916715634,
           -0.5269217484374376,
           -0.4966166866992735,
           -0.4661934542774682,
           -0.4356598177556318,
           -0.4050236951450074,
           -0.3742932057229879,
           -0.3434767479447449,
           -0.3125831250101714,
           -0.2816217549886015,
           -0.2506030390826852,
           -0.21953904506542016,
           -0.18844487023226536,
           -0.15734162333824564,
           -0.12626380760020947,
           -0.09528107871030649,
           -0.06458197524022186,
           -0.0349905650663745,
           -0.015551811920358946,
           -0.03499056506640336,
           -0.06458197524025314,
           -0.09528107871033827,
           -0.12626380760024136,
           -0.15734162333827767,
           -0.1884448702322973,
           -0.21953904506545208,
           -0.2506030390827171,
           -0.28162175498863334,
           -0.31258312501020313,
           -0.3434767479447767,
           -0.3742932057230195,
           -0.405023695145039,
           -0.4356598177556632,
           -0.46619345427749953,
           -0.4966166866993048,
           -0.5269217484374686,
           -0.5571009916715943,
           -0.5871468655348352,
           -0.6170519013627215,
           -0.646808702647946,
           -0.6764099382026659,
           -0.7058483375502617,
           -0.7351166878939874,
           -0.7642078322184135,
           -0.7931146682159494,
           -0.8218301478217016,
           -0.8503472772016837,
           -0.8786591170820074,
           -0.9067587833365163,
           -0.934639447771512,
           -0.9622943390614519,
           -0.9897167438005762,
           -1.0169000076435757,
           -1.0438375365144605,
           -1.0705227978673473,
           -1.0969493219863062,
           -1.1231107033140488,
           -1.1490006018012564,
           -1.1746127442699088,
           -1.199940925785209,
           -1.224979011031659,
           -1.2497209356895982,
           -1.2741607078091337,
           -1.2982924091788712,
           -1.3221101966872513,
           -1.3456083036746163,
           -1.3687810412743822,
           -1.391622799741921,
           -1.4141280497699136,
           -1.4362913437890958,
           -1.4581073172534327,
           -1.4795706899088543,
           -1.5006762670447835,
           -1.5214189407277476,
           -1.54179369101643,
           -1.561795587157574,
           -1.5814197887621926,
           -1.6006615469615806,
           -1.6195162055426544,
           -1.6379792020621797,
           -1.6560460689394754,
           -1.673712434527198,
           -1.6909740241598392,
           -1.7078266611795831,
           -1.724266267939194,
           -1.7402888667816123,
           -1.755890580995956,
           -1.7710676357496384,
           -1.7858163589963247,
           -1.8001331823594626,
           -1.8140146419911256,
           -1.8274573794059346,
           -1.840458142289816,
           -1.8530137852833755,
           -1.865121270739667,
           -1.876777669456158,
           -1.8879801613806868,
           -1.8987260362912222,
           -1.909012694449251,
           -1.9188376472266109,
           -1.9281985177056125,
           -1.937093041252285,
           -1.945519066062602,
           -1.953474553681542,
           -1.9609575794948513,
           -1.9679663331933783,
           -1.9744991192098686,
           -1.9805543571280917,
           -1.986130582064221,
           -1.9912264450203383,
           -1.995840713209999,
           -1.9999722703557614,
           -2.003620116958606,
           -2.0067833705391815,
           -2.0094612658508098,
           -2.0116531550642,
           -2.0133585079238245,
           -2.014576911875921,
           -2.0153080721680703
          ],
          [
           -2.046640390387426,
           -2.0463930049195564,
           -2.0456509084451997,
           -2.0444142807378602,
           -2.0426834213725593,
           -2.0404587496546256,
           -2.0377408045200283,
           -2.034530244407302,
           -2.030827847101084,
           -2.026634509547345,
           -2.021951247640345,
           -2.01677919598142,
           -2.011119607609651,
           -2.004973853704534,
           -1.9983434232607389,
           -1.991229922735085,
           -1.983635075665846,
           -1.9755607222645375,
           -1.967008818980324,
           -1.9579814380372171,
           -1.9484807669442366,
           -1.9385091079787253,
           -1.9280688776430206,
           -1.9171626060947038,
           -1.9057929365506576,
           -1.8939626246651935,
           -1.8816745378825086,
           -1.8689316547637682,
           -1.855737064289129,
           -1.8420939651350277,
           -1.8280056649271041,
           -1.8134755794691404,
           -1.7985072319484319,
           -1.7831042521180482,
           -1.7672703754564554,
           -1.751009442305039,
           -1.734325396984098,
           -1.717222286887922,
           -1.6997042615596436,
           -1.6817755717466025,
           -1.663440568437038,
           -1.6447037018790087,
           -1.625569520582535,
           -1.6060426703060573,
           -1.5861278930284468,
           -1.56583002590792,
           -1.5451540002294046,
           -1.5241048403420663,
           -1.5026876625889534,
           -1.4809076742309577,
           -1.4587701723676083,
           -1.436280542857568,
           -1.413444259242121,
           -1.3902668816754573,
           -1.3667540558661373,
           -1.3429115120348478,
           -1.3187450638944038,
           -1.2942606076589804,
           -1.2694641210908018,
           -1.244361662594007,
           -1.2189593703672563,
           -1.1932634616288718,
           -1.167280231931066,
           -1.1410160545832133,
           -1.1144773802083516,
           -1.0876707364623757,
           -1.0606027279520132,
           -1.0332800363960666,
           -1.0057094210850335,
           -0.9778977197078674,
           -0.9498518496322071,
           -0.9215788097472046,
           -0.8930856830079468,
           -0.864379639859839,
           -0.8354679427737629,
           -0.8063579521932612,
           -0.7770571342906473,
           -0.7475730710601368,
           -0.7179134734582071,
           -0.6880861985573076,
           -0.6580992720435055,
           -0.6279609179153314,
           -0.5976795980141689,
           -0.5672640651709738,
           -0.5367234355105874,
           -0.5060672881829283,
           -0.4753058051245524,
           -0.44444997051549323,
           -0.4135118614282585,
           -0.3825050816246454,
           -0.35144542711096977,
           -0.3203519404441438,
           -0.28924864440904763,
           -0.25816752123273295,
           -0.22715390855682865,
           -0.19627691452319856,
           -0.16565115314589401,
           -0.13548672861345973,
           -0.10621893567429927,
           -0.07889597174768917,
           -0.056461340729673556,
           -0.04664039038742575,
           -0.05646134072969199,
           -0.07889597174771555,
           -0.10621893567432865,
           -0.1354867286134904,
           -0.16565115314592535,
           -0.19627691452323018,
           -0.2271539085568605,
           -0.2581675212327649,
           -0.28924864440907955,
           -0.32035194044417575,
           -0.3514454271110017,
           -0.3825050816246772,
           -0.41351186142829033,
           -0.444449970515525,
           -0.4753058051245839,
           -0.50606728818296,
           -0.536723435510619,
           -0.5672640651710052,
           -0.5976795980142001,
           -0.6279609179153623,
           -0.6580992720435362,
           -0.6880861985573383,
           -0.7179134734582377,
           -0.7475730710601671,
           -0.7770571342906775,
           -0.8063579521932913,
           -0.8354679427737927,
           -0.8643796398598685,
           -0.8930856830079759,
           -0.9215788097472337,
           -0.949851849632236,
           -0.9778977197078961,
           -1.005709421085062,
           -1.0332800363960948,
           -1.0606027279520411,
           -1.0876707364624034,
           -1.1144773802083792,
           -1.1410160545832402,
           -1.1672802319310929,
           -1.1932634616288986,
           -1.2189593703672825,
           -1.244361662594033,
           -1.2694641210908275,
           -1.294260607659006,
           -1.3187450638944287,
           -1.3429115120348727,
           -1.3667540558661617,
           -1.390266881675481,
           -1.4134442592421448,
           -1.4362805428575913,
           -1.4587701723676314,
           -1.4809076742309801,
           -1.5026876625889756,
           -1.5241048403420883,
           -1.545154000229426,
           -1.565830025907941,
           -1.5861278930284672,
           -1.6060426703060775,
           -1.6255695205825547,
           -1.6447037018790283,
           -1.6634405684370568,
           -1.6817755717466212,
           -1.6997042615596616,
           -1.7172222868879397,
           -1.7343253969841153,
           -1.7510094423050557,
           -1.7672703754564714,
           -1.7831042521180642,
           -1.7985072319484476,
           -1.813475579469155,
           -1.8280056649271188,
           -1.842093965135042,
           -1.8557370642891429,
           -1.8689316547637815,
           -1.8816745378825215,
           -1.8939626246652062,
           -1.9057929365506694,
           -1.9171626060947151,
           -1.928068877643032,
           -1.9385091079787358,
           -1.948480766944247,
           -1.9579814380372265,
           -1.9670088189803332,
           -1.975560722264546,
           -1.9836350756658538,
           -1.9912299227350923,
           -1.998343423260746,
           -2.0049738537045405,
           -2.011119607609657,
           -2.0167791959814254,
           -2.02195124764035,
           -2.0266345095473492,
           -2.030827847101088,
           -2.0345302444073052,
           -2.037740804520032,
           -2.040458749654628,
           -2.042683421372561,
           -2.0444142807378616,
           -2.045650908445201,
           -2.0463930049195573
          ],
          [
           -2.0776838472890145,
           -2.077432930268637,
           -2.0766802401523283,
           -2.0754259597604907,
           -2.073670393746924,
           -2.0714139685285375,
           -2.0686572321870003,
           -2.065400854342374,
           -2.0616456259987963,
           -2.057392459362284,
           -2.052642387630767,
           -2.0473965647564403,
           -2.041656265180577,
           -2.035422883540936,
           -2.028697934351919,
           -2.021483051657667,
           -2.01377998865828,
           -2.005590617309376,
           -1.9969169278952386,
           -1.9877610285757972,
           -1.9781251449077317,
           -1.9680116193400115,
           -1.9574229106841996,
           -1.9463615935598955,
           -1.934830357815709,
           -1.9228320079262076,
           -1.9103694623653003,
           -1.897445752956582,
           -1.884064024201193,
           -1.8702275325838142,
           -1.855939645857458,
           -1.8412038423077963,
           -1.8260237099978252,
           -1.8104029459937485,
           -1.7943453555730486,
           -1.7778548514158186,
           -1.7609354527805345,
           -1.7435912846655737,
           -1.7258265769579353,
           -1.707645663570777,
           -1.6890529815715698,
           -1.6700530703028857,
           -1.6506505704980805,
           -1.6308502233944133,
           -1.6106568698464703,
           -1.5900754494431357,
           -1.5691109996317891,
           -1.5477686548539196,
           -1.5260536456969305,
           -1.5039712980676136,
           -1.481527032393575,
           -1.4587263628598603,
           -1.435574896689158,
           -1.4120783334752987,
           -1.3882424645813707,
           -1.3640731726156767,
           -1.3395764310010387,
           -1.3147583036557102,
           -1.2896249448074673,
           -1.2641825989664754,
           -1.238437601087425,
           -1.212396376957413,
           -1.1860654438534126,
           -1.159451411522246,
           -1.1325609835472557,
           -1.1054009591799199,
           -1.0779782357322947,
           -1.050299811648419,
           -1.0223727904010511,
           -0.9942043853962087,
           -0.9658019261143994,
           -0.9371728657775844,
           -0.9083247909094713,
           -0.8792654332601068,
           -0.8500026847030003,
           -0.8205446158969006,
           -0.7908994997531285,
           -0.761075841089452,
           -0.7310824143215777,
           -0.7009283117009031,
           -0.6706230055388714,
           -0.6401764291967095,
           -0.6095990835709767,
           -0.5789021786975146,
           -0.5480978244582663,
           -0.5171992910810566,
           -0.4862213706493111,
           -0.4551808877485387,
           -0.42409743523533905,
           -0.3929944583123118,
           -0.3619008925642759,
           -0.3308537107495656,
           -0.29990201328851734,
           -0.2691138461977139,
           -0.238588055646308,
           -0.20847591020479123,
           -0.1790226812450133,
           -0.15065207437263334,
           -0.12414521725603232,
           -0.10101549176324748,
           -0.08412710413871463,
           -0.07768384728901459,
           -0.08412710413872737,
           -0.1010154917632687,
           -0.12414521725605818,
           -0.15065207437266173,
           -0.17902268124504317,
           -0.20847591020482187,
           -0.23858805564633917,
           -0.26911384619774537,
           -0.29990201328854904,
           -0.3308537107495974,
           -0.3619008925643079,
           -0.3929944583123437,
           -0.42409743523537086,
           -0.45518088774857063,
           -0.48622137064934284,
           -0.5171992910810884,
           -0.548097824458298,
           -0.5789021786975461,
           -0.6095990835710081,
           -0.6401764291967407,
           -0.6706230055389024,
           -0.7009283117009342,
           -0.7310824143216086,
           -0.7610758410894827,
           -0.7908994997531591,
           -0.8205446158969311,
           -0.8500026847030306,
           -0.8792654332601368,
           -0.908324790909501,
           -0.9371728657776138,
           -0.9658019261144286,
           -0.9942043853962379,
           -1.02237279040108,
           -1.0502998116484477,
           -1.077978235732323,
           -1.1054009591799476,
           -1.1325609835472834,
           -1.1594514115222734,
           -1.1860654438534397,
           -1.2123963769574402,
           -1.2384376010874516,
           -1.2641825989665016,
           -1.2896249448074932,
           -1.314758303655736,
           -1.339576431001064,
           -1.3640731726157018,
           -1.3882424645813956,
           -1.412078333475323,
           -1.435574896689182,
           -1.458726362859884,
           -1.481527032393598,
           -1.5039712980676367,
           -1.5260536456969531,
           -1.5477686548539416,
           -1.5691109996318109,
           -1.5900754494431568,
           -1.6106568698464914,
           -1.6308502233944338,
           -1.6506505704981005,
           -1.6700530703029053,
           -1.6890529815715891,
           -1.707645663570796,
           -1.7258265769579535,
           -1.7435912846655917,
           -1.7609354527805523,
           -1.7778548514158357,
           -1.7943453555730653,
           -1.8104029459937647,
           -1.8260237099978414,
           -1.8412038423078116,
           -1.8559396458574728,
           -1.8702275325838287,
           -1.8840640242012074,
           -1.8974457529565956,
           -1.9103694623653136,
           -1.9228320079262202,
           -1.9348303578157209,
           -1.9463615935599066,
           -1.9574229106842107,
           -1.9680116193400221,
           -1.978125144907742,
           -1.9877610285758067,
           -1.9969169278952474,
           -2.0055906173093843,
           -2.0137799886582877,
           -2.021483051657675,
           -2.0286979343519254,
           -2.0354228835409427,
           -2.0416562651805834,
           -2.047396564756446,
           -2.052642387630772,
           -2.0573924593622888,
           -2.0616456259988003,
           -2.065400854342378,
           -2.0686572321870034,
           -2.07141396852854,
           -2.073670393746926,
           -2.0754259597604916,
           -2.076680240152329,
           -2.0774329302686376
          ],
          [
           -2.108652150085483,
           -2.108397813674186,
           -2.1076348664477407,
           -2.1063634944147904,
           -2.1045840075440925,
           -2.102296839696083,
           -2.099502548527139,
           -2.0962018153666135,
           -2.092395445066725,
           -2.088084365825435,
           -2.083269628982434,
           -2.077952408788411,
           -2.072134002147777,
           -2.0658158283350723,
           -2.058999428685273,
           -2.051686466258282,
           -2.0438787254778887,
           -2.035578111745526,
           -2.026786651029194,
           -2.0175064894279373,
           -2.0077398927123267,
           -1.9974892458414142,
           -1.9867570524566995,
           -1.9755459343536823,
           -1.9638586309316368,
           -1.9516979986223018,
           -1.9390670102982563,
           -1.9259687546618123,
           -1.9124064356153516,
           -1.8983833716141185,
           -1.8839029950025827,
           -1.8689688513356082,
           -1.853584598685779,
           -1.837754006938397,
           -1.8214809570758057,
           -1.804769440452901,
           -1.7876235580658792,
           -1.770047519816517,
           -1.7520456437745489,
           -1.7336223554410037,
           -1.7147821870157232,
           -1.6955297766726738,
           -1.6758698678471349,
           -1.6558073085393663,
           -1.635347050639979,
           -1.6144941492829323,
           -1.5932537622329088,
           -1.5716311493147788,
           -1.5496316718939651,
           -1.5272607924178572,
           -1.504524074029921,
           -1.481427180269993,
           -1.4579758748763547,
           -1.4341760217077286,
           -1.4100335848063341,
           -1.3855546286267368,
           -1.3607453184595106,
           -1.335611921083896,
           -1.3101608056898641,
           -1.284398445117527,
           -1.2583314174710125,
           -1.2319664081751047,
           -1.205310212556702,
           -1.178369739050067,
           -1.1511520131458282,
           -1.1236641822298077,
           -1.0959135214904592,
           -1.067907441114868,
           -1.039653495045424,
           -1.011159391635749,
           -0.9824330066297433,
           -0.9534823989977994,
           -0.9243158303076461,
           -0.8949417884953678,
           -0.8653690171509089,
           -0.8356065517642165,
           -0.8056637648250075,
           -0.7755504222767353,
           -0.7452767546602687,
           -0.714853547443023,
           -0.6842922566610011,
           -0.6536051583255766,
           -0.6228055434037727,
           -0.5919079751010079,
           -0.5609286325022378,
           -0.529885775726424,
           -0.49880038487446643,
           -0.46769705200271816,
           -0.4366052486842019,
           -0.4055611629845139,
           -0.374610419754654,
           -0.34381220562642667,
           -0.3132456878772784,
           -0.2830202841535214,
           -0.2532925759512772,
           -0.2242949587181315,
           -0.1963852784253082,
           -0.17013328589071428,
           -0.14646504420863626,
           -0.12686390153286498,
           -0.11348056693655068,
           -0.10865215008548304,
           -0.11348056693656039,
           -0.12686390153288238,
           -0.1464650442086588,
           -0.17013328589074014,
           -0.1963852784253362,
           -0.2242949587181608,
           -0.2532925759513074,
           -0.2830202841535522,
           -0.31324568787730955,
           -0.3438122056264582,
           -0.3746104197546858,
           -0.40556116298454575,
           -0.4366052486842338,
           -0.46769705200275,
           -0.49880038487449835,
           -0.5298857757264561,
           -0.5609286325022698,
           -0.5919079751010398,
           -0.6228055434038045,
           -0.6536051583256082,
           -0.6842922566610327,
           -0.7148535474430544,
           -0.7452767546602997,
           -0.7755504222767663,
           -0.8056637648250382,
           -0.8356065517642474,
           -0.8653690171509393,
           -0.894941788495398,
           -0.9243158303076762,
           -0.9534823989978292,
           -0.9824330066297728,
           -1.0111593916357786,
           -1.039653495045453,
           -1.0679074411148968,
           -1.0959135214904878,
           -1.123664182229836,
           -1.1511520131458564,
           -1.178369739050095,
           -1.2053102125567297,
           -1.231966408175132,
           -1.2583314174710396,
           -1.2843984451175536,
           -1.3101608056898906,
           -1.3356119210839221,
           -1.3607453184595364,
           -1.3855546286267624,
           -1.4100335848063592,
           -1.4341760217077533,
           -1.4579758748763791,
           -1.481427180270017,
           -1.5045240740299446,
           -1.5272607924178805,
           -1.549631671893988,
           -1.5716311493148012,
           -1.593253762232931,
           -1.6144941492829537,
           -1.6353470506400005,
           -1.6558073085393872,
           -1.6758698678471553,
           -1.6955297766726938,
           -1.7147821870157425,
           -1.7336223554410228,
           -1.7520456437745675,
           -1.7700475198165355,
           -1.7876235580658972,
           -1.8047694404529186,
           -1.8214809570758226,
           -1.8377540069384135,
           -1.853584598685795,
           -1.868968851335624,
           -1.883902995002598,
           -1.8983833716141332,
           -1.9124064356153658,
           -1.9259687546618263,
           -1.9390670102982699,
           -1.9516979986223146,
           -1.9638586309316488,
           -1.975545934353694,
           -1.9867570524567109,
           -1.997489245841425,
           -2.0077398927123373,
           -2.017506489427947,
           -2.026786651029203,
           -2.0355781117455343,
           -2.0438787254778967,
           -2.05168646625829,
           -2.05899942868528,
           -2.0658158283350794,
           -2.072134002147783,
           -2.0779524087884162,
           -2.0832696289824395,
           -2.0880843658254395,
           -2.0923954450667295,
           -2.0962018153666175,
           -2.0995025485271426,
           -2.1022968396960855,
           -2.1045840075440947,
           -2.1063634944147918,
           -2.1076348664477416,
           -2.1083978136741863
          ],
          [
           -2.139515338943932,
           -2.1392576932385614,
           -2.1384848192354404,
           -2.1371969062603813,
           -2.1353942698125525,
           -2.133077351498753,
           -2.1302467189414935,
           -2.12690306566099,
           -2.1230472109312024,
           -2.118680099610069,
           -2.113802801944153,
           -2.108416513347898,
           -2.102522554157788,
           -2.0961223693616877,
           -2.0892175283037036,
           -2.081809724364961,
           -2.073900774620698,
           -2.0654926194741625,
           -2.0565873222678337,
           -2.0471870688725278,
           -2.0372941672550464,
           -2.0269110470250546,
           -2.016040258961965,
           -2.004684474522675,
           -1.992846485331105,
           -1.9805292026505468,
           -1.9677356568399824,
           -1.954468996795604,
           -1.9407324893789268,
           -1.9265295188330163,
           -1.9118635861885123,
           -1.896738308661319,
           -1.8811574190440237,
           -1.8651247650933434,
           -1.848644308916145,
           -1.831720126356888,
           -1.8143564063896522,
           -1.7965574505183024,
           -1.7783276721887502,
           -1.759671596217776,
           -1.7405938582434164,
           -1.7210992042025592,
           -1.7011924898421267,
           -1.680878680271063,
           -1.6601628495613112,
           -1.6390501804070994,
           -1.6175459638531482,
           -1.5956555991039418,
           -1.5733845934279664,
           -1.550738562172901,
           -1.5277232289101672,
           -1.5043444257301128,
           -1.4806080937124766,
           -1.4565202836007756,
           -1.4320871567140077,
           -1.4073149861347174,
           -1.3822101582192285,
           -1.3567791744839828,
           -1.3310286539316802,
           -1.3049653358927649,
           -1.2785960834721375,
           -1.2519278877085012,
           -1.2249678725751776,
           -1.197723300977615,
           -1.170201581935416,
           -1.1424102791772317,
           -1.1143571214274537,
           -1.0860500147271872,
           -1.0574970572122062,
           -1.0287065568725626,
           -0.9996870529488595,
           -0.9704473417879914,
           -0.9409965081986251,
           -0.911343963630666,
           -0.8814994928766353,
           -0.8514733114886828,
           -0.821276136768487,
           -0.790919276083498,
           -0.7604147374852279,
           -0.7297753692894531,
           -0.6990150376242135,
           -0.668148854257457,
           -0.6371934717321694,
           -0.6061674696519179,
           -0.575091865943825,
           -0.5439908017647548,
           -0.5128924711052755,
           -0.481830400458039,
           -0.45084523734707194,
           -0.41998729103962656,
           -0.38932020448326227,
           -0.35892635716821447,
           -0.3289149599718182,
           -0.29943439270438094,
           -0.27069127185574476,
           -0.24298010580292917,
           -0.21672892723415205,
           -0.19256616480762503,
           -0.1714053652837583,
           -0.15450920126830833,
           -0.14341177530675722,
           -0.13951533894393164,
           -0.14341177530676513,
           -0.154509201268323,
           -0.17140536528377814,
           -0.19256616480764854,
           -0.21672892723417814,
           -0.24298010580295695,
           -0.27069127185577385,
           -0.2994343927044109,
           -0.3289149599718488,
           -0.35892635716824556,
           -0.38932020448329374,
           -0.4199872910396582,
           -0.45084523734710363,
           -0.48183040045807085,
           -0.5128924711053073,
           -0.5439908017647868,
           -0.575091865943857,
           -0.6061674696519498,
           -0.6371934717322014,
           -0.6681488542574886,
           -0.699015037624245,
           -0.7297753692894847,
           -0.7604147374852593,
           -0.7909192760835294,
           -0.8212761367685181,
           -0.8514733114887137,
           -0.881499492876666,
           -0.9113439636306966,
           -0.9409965081986557,
           -0.9704473417880215,
           -0.9996870529488895,
           -1.0287065568725924,
           -1.0574970572122357,
           -1.0860500147272163,
           -1.1143571214274826,
           -1.1424102791772603,
           -1.1702015819354448,
           -1.1977233009776431,
           -1.2249678725752056,
           -1.2519278877085287,
           -1.2785960834721648,
           -1.3049653358927917,
           -1.3310286539317067,
           -1.3567791744840088,
           -1.3822101582192545,
           -1.407314986134743,
           -1.432087156714033,
           -1.4565202836008002,
           -1.4806080937125012,
           -1.504344425730137,
           -1.527723228910191,
           -1.5507385621729244,
           -1.5733845934279893,
           -1.5956555991039645,
           -1.6175459638531708,
           -1.6390501804071211,
           -1.6601628495613328,
           -1.680878680271084,
           -1.701192489842147,
           -1.7210992042025794,
           -1.7405938582434362,
           -1.7596715962177956,
           -1.7783276721887689,
           -1.7965574505183208,
           -1.8143564063896704,
           -1.8317201263569054,
           -1.8486443089161624,
           -1.86512476509336,
           -1.88115741904404,
           -1.8967383086613347,
           -1.9118635861885276,
           -1.9265295188330311,
           -1.9407324893789413,
           -1.9544689967956177,
           -1.9677356568399957,
           -1.9805292026505597,
           -1.9928464853311172,
           -2.004684474522687,
           -2.0160402589619766,
           -2.0269110470250657,
           -2.037294167255057,
           -2.0471870688725375,
           -2.056587322267843,
           -2.065492619474171,
           -2.073900774620706,
           -2.081809724364969,
           -2.0892175283037107,
           -2.0961223693616944,
           -2.1025225541577943,
           -2.108416513347904,
           -2.113802801944158,
           -2.118680099610074,
           -2.123047210931207,
           -2.1269030656609935,
           -2.1302467189414966,
           -2.133077351498756,
           -2.1353942698125548,
           -2.1371969062603826,
           -2.1384848192354418,
           -2.139257693238562
          ],
          [
           -2.1702435557224073,
           -2.1699827087084027,
           -2.1692002319236163,
           -2.167896318127263,
           -2.1660712885431685,
           -2.1637255927975416,
           -2.1608598088319857,
           -2.157474642791895,
           -2.1535709288903986,
           -2.149149629248086,
           -2.144211833708765,
           -2.1387587596315623,
           -2.1327917516597266,
           -2.1263122814665225,
           -2.119321947478699,
           -2.1118224745780205,
           -2.103815713781457,
           -2.09530364190066,
           -2.0862883611814462,
           -2.07677209892407,
           -2.0667572070851645,
           -2.056246161862308,
           -2.0452415632622825,
           -2.0337461346542023,
           -2.0217627223087966,
           -2.009294294925288,
           -1.9963439431474357,
           -1.9829148790704902,
           -1.9690104357409806,
           -1.954634066651477,
           -1.939789345232673,
           -1.9244799643454213,
           -1.9087097357756242,
           -1.8924825897352067,
           -1.8758025743727842,
           -1.8586738552980324,
           -1.8411007151242527,
           -1.8230875530341553,
           -1.8046388843744903,
           -1.785759340285862,
           -1.7664536673748443,
           -1.7467267274364362,
           -1.7265834972359373,
           -1.7060290683605333,
           -1.6850686471522682,
           -1.6637075547356925,
           -1.6419512271553356,
           -1.619805215640333,
           -1.5972751870160544,
           -1.5743669242855398,
           -1.5510863274070206,
           -1.5274394142978664,
           -1.5034323221000996,
           -1.4790713087483094,
           -1.4543627548875082,
           -1.4293131661965113,
           -1.4039291761819723,
           -1.3782175495196807,
           -1.3521851860335183,
           -1.3258391254191173,
           -1.2991865528394324,
           -1.2722348055439971,
           -1.2449913806936228,
           -1.2174639446091235,
           -1.1896603437080469,
           -1.1615886174496448,
           -1.1332570136783457,
           -1.1046740068436702,
           -1.0758483196848612,
           -1.0467889491081577,
           -1.0175051971624818,
           -0.9880067082471731,
           -0.9583035139793269,
           -0.9284060875299825,
           -0.8983254097377418,
           -0.868073049966514,
           -0.8376612655484968,
           -0.8071031248249164,
           -0.7764126603802339,
           -0.745605061224826,
           -0.7146969156545672,
           -0.6837065206513355,
           -0.6526542795003635,
           -0.6215632175559157,
           -0.5904596579424018,
           -0.5593741161922382,
           -0.528342498088878,
           -0.49740772245183973,
           -0.46662194665945983,
           -0.43604965711701776,
           -0.40577201421351555,
           -0.3758930321287321,
           -0.34654845335457957,
           -0.3179185645063572,
           -0.29024666256414144,
           -0.26386520421274223,
           -0.23923109850637794,
           -0.21696804457933114,
           -0.19790278742326556,
           -0.1830582236398312,
           -0.17353674920945947,
           -0.17024355572240732,
           -0.17353674920946616,
           -0.18305822363984392,
           -0.19790278742328318,
           -0.21696804457935256,
           -0.23923109850640223,
           -0.2638652042127685,
           -0.29024666256416937,
           -0.31791856450638617,
           -0.3465484533546094,
           -0.3758930321287625,
           -0.4057720142135466,
           -0.436049657117049,
           -0.4666219466594914,
           -0.4974077224518715,
           -0.5283424980889099,
           -0.5593741161922701,
           -0.5904596579424338,
           -0.6215632175559478,
           -0.6526542795003955,
           -0.6837065206513674,
           -0.7146969156545989,
           -0.7456050612248577,
           -0.7764126603802655,
           -0.807103124824948,
           -0.8376612655485282,
           -0.8680730499665451,
           -0.8983254097377726,
           -0.9284060875300135,
           -0.9583035139793574,
           -0.9880067082472034,
           -1.017505197162512,
           -1.0467889491081876,
           -1.075848319684891,
           -1.1046740068436998,
           -1.1332570136783748,
           -1.1615886174496737,
           -1.1896603437080755,
           -1.2174639446091517,
           -1.2449913806936512,
           -1.2722348055440253,
           -1.29918655283946,
           -1.3258391254191446,
           -1.3521851860335452,
           -1.3782175495197073,
           -1.4039291761819985,
           -1.4293131661965373,
           -1.4543627548875337,
           -1.4790713087483347,
           -1.5034323221001247,
           -1.5274394142978907,
           -1.5510863274070448,
           -1.5743669242855634,
           -1.5972751870160777,
           -1.6198052156403564,
           -1.6419512271553582,
           -1.6637075547357145,
           -1.68506864715229,
           -1.7060290683605546,
           -1.726583497235958,
           -1.7467267274364568,
           -1.7664536673748645,
           -1.7857593402858818,
           -1.8046388843745094,
           -1.823087553034174,
           -1.841100715124271,
           -1.8586738552980502,
           -1.8758025743728015,
           -1.8924825897352238,
           -1.9087097357756406,
           -1.924479964345437,
           -1.9397893452326882,
           -1.954634066651492,
           -1.9690104357409952,
           -1.9829148790705042,
           -1.9963439431474497,
           -2.0092942949253016,
           -2.0217627223088095,
           -2.0337461346542147,
           -2.0452415632622944,
           -2.056246161862319,
           -2.0667572070851747,
           -2.0767720989240797,
           -2.0862883611814556,
           -2.095303641900669,
           -2.103815713781465,
           -2.111822474578028,
           -2.119321947478706,
           -2.1263122814665296,
           -2.132791751659733,
           -2.1387587596315685,
           -2.14421183370877,
           -2.1491496292480905,
           -2.153570928890403,
           -2.1574746427918985,
           -2.1608598088319897,
           -2.1637255927975443,
           -2.1660712885431703,
           -2.167896318127265,
           -2.169200231923618,
           -2.1699827087084036
          ],
          [
           -2.2008070728557274,
           -2.2005431303752494,
           -2.199751368369691,
           -2.1984319831350527,
           -2.1965853017925996,
           -2.194211782230849,
           -2.1913120130245294,
           -2.187886713330676,
           -2.1839367327621106,
           -2.1794630512385673,
           -2.174466778815823,
           -2.168949155493216,
           -2.162911551000018,
           -2.1563554645611864,
           -2.1492825246430947,
           -2.141694488679898,
           -2.133593242781303,
           -2.12498080142256,
           -2.115859307117622,
           -2.1062310300764904,
           -2.0960983678478984,
           -2.0854638449485865,
           -2.074330112480579,
           -2.0626999477379866,
           -2.050576253805059,
           -2.0379620591473557,
           -2.024860517198119,
           -2.0112749059421606,
           -1.997208627499799,
           -1.9826652077136688,
           -1.967648295741541,
           -1.9521616636586212,
           -1.936209206073183,
           -1.919794939759848,
           -1.9029230033152824,
           -1.8855976568416777,
           -1.8678232816639773,
           -1.8496043800875548,
           -1.8309455752038502,
           -1.8118516107524074,
           -1.7923273510488196,
           -1.7723777809893082,
           -1.7520080061440513,
           -1.7312232529530045,
           -1.710028869039797,
           -1.688430323661433,
           -1.6664332083140254,
           -1.6440432375176637,
           -1.621266249806887,
           -1.5981082089571554,
           -1.5745752054823166,
           -1.5506734584434474,
           -1.5264093176158202,
           -1.5017892660682304,
           -1.476819923217817,
           -1.4515080484340641,
           -1.4258605452782507,
           -1.3998844664796857,
           -1.3735870197681177,
           -1.3469755747034873,
           -1.3200576706705123,
           -1.292841026237551,
           -1.2653335501181302,
           -1.2375433540212182,
           -1.2094787677349181,
           -1.1811483568606678,
           -1.1525609437048525,
           -1.1237256319467808,
           -1.0946518358423964,
           -1.0653493149000948,
           -1.035828215189301,
           -1.0060991187283967,
           -0.9761731027652644,
           -0.9460618112369922,
           -0.9157775413101168,
           -0.8853333487070386,
           -0.8547431765837754,
           -0.8240220141303641,
           -0.7931860929456351,
           -0.7622531317724875,
           -0.7312426436231101,
           -0.7001763240399063,
           -0.6690785457504861,
           -0.637976994040065,
           -0.6069034898780823,
           -0.5758950657877057,
           -0.5449953849334982,
           -0.5142566301998142,
           -0.48374204168934254,
           -0.4535293540570041,
           -0.42371548629467287,
           -0.39442297127196474,
           -0.3658087761748523,
           -0.33807632234900503,
           -0.3114915441416717,
           -0.286403411318822,
           -0.26326774804368874,
           -0.24266904291522431,
           -0.22532658069911576,
           -0.21205935441839774,
           -0.20367911969315064,
           -0.2008070728557273,
           -0.20367911969315652,
           -0.21205935441840904,
           -0.22532658069913167,
           -0.24266904291524397,
           -0.2632677480437114,
           -0.28640341131884683,
           -0.3114915441416983,
           -0.33807632234903295,
           -0.3658087761748812,
           -0.3944229712719945,
           -0.42371548629470335,
           -0.453529354057035,
           -0.4837420416893738,
           -0.5142566301998457,
           -0.5449953849335298,
           -0.5758950657877373,
           -0.6069034898781144,
           -0.637976994040097,
           -0.6690785457505181,
           -0.7001763240399381,
           -0.7312426436231418,
           -0.7622531317725193,
           -0.793186092945667,
           -0.8240220141303957,
           -0.8547431765838068,
           -0.88533334870707,
           -0.9157775413101479,
           -0.9460618112370232,
           -0.9761731027652952,
           -1.0060991187284274,
           -1.0358282151893314,
           -1.065349314900125,
           -1.0946518358424264,
           -1.1237256319468105,
           -1.1525609437048818,
           -1.1811483568606969,
           -1.209478767734947,
           -1.2375433540212468,
           -1.2653335501181586,
           -1.2928410262375791,
           -1.3200576706705403,
           -1.3469755747035148,
           -1.3735870197681448,
           -1.3998844664797125,
           -1.425860545278277,
           -1.4515080484340903,
           -1.476819923217843,
           -1.5017892660682557,
           -1.526409317615845,
           -1.550673458443472,
           -1.574575205482341,
           -1.5981082089571794,
           -1.6212662498069108,
           -1.6440432375176872,
           -1.6664332083140485,
           -1.6884303236614555,
           -1.710028869039819,
           -1.7312232529530258,
           -1.7520080061440721,
           -1.772377780989329,
           -1.79232735104884,
           -1.8118516107524272,
           -1.8309455752038697,
           -1.8496043800875743,
           -1.867823281663996,
           -1.8855976568416954,
           -1.9029230033153,
           -1.919794939759865,
           -1.9362092060732001,
           -1.9521616636586374,
           -1.967648295741557,
           -1.9826652077136842,
           -1.997208627499814,
           -2.011274905942175,
           -2.0248605171981326,
           -2.037962059147369,
           -2.050576253805072,
           -2.062699947737999,
           -2.0743301124805904,
           -2.0854638449485976,
           -2.0960983678479086,
           -2.1062310300765006,
           -2.1158593071176313,
           -2.124980801422569,
           -2.133593242781312,
           -2.141694488679906,
           -2.149282524643102,
           -2.156355464561194,
           -2.162911551000024,
           -2.168949155493222,
           -2.174466778815829,
           -2.1794630512385726,
           -2.183936732762115,
           -2.18788671333068,
           -2.1913120130245325,
           -2.194211782230852,
           -2.196585301792601,
           -2.1984319831350545,
           -2.199751368369693,
           -2.2005431303752503
          ],
          [
           -2.2311763221149787,
           -2.2309093878481794,
           -2.230108651692429,
           -2.228774313571006,
           -2.226906706653874,
           -2.224506297304524,
           -2.2215736850057923,
           -2.2181096022648474,
           -2.21411491449764,
           -2.209590619893182,
           -2.204537849258062,
           -2.198957865841707,
           -2.1928520651429633,
           -2.186221974698663,
           -2.179069253854907,
           -2.1713956935219314,
           -2.163203215913477,
           -2.154493874271728,
           -2.1452698525789877,
           -2.135533465257391,
           -2.1252871568580924,
           -2.1145335017415268,
           -2.1032752037505067,
           -2.0915150958781075,
           -2.079256139932492,
           -2.0665014262010653,
           -2.053254173116592,
           -2.0395177269281977,
           -2.0252955613804837,
           -2.0105912774043397,
           -1.9954086028234261,
           -1.9797513920807421,
           -1.96362362599019,
           -1.9470294115185924,
           -1.9299729816042686,
           -1.9124586950189606,
           -1.8944910362807261,
           -1.8760746156263206,
           -1.8572141690526225,
           -1.8379145584378556,
           -1.8181807717547045,
           -1.7980179233889717,
           -1.7774312545792015,
           -1.756426133994738,
           -1.735008058472036,
           -1.7131826539317712,
           -1.6909556765024194,
           -1.6683330138796586,
           -1.6453206869551564,
           -1.6219248517532867,
           -1.5981518017200957,
           -1.574007970415621,
           -1.5494999346686562,
           -1.524634418262458,
           -1.4994182962310103,
           -1.4738585998586624,
           -1.4479625224916512,
           -1.42173742628876,
           -1.395190850060805,
           -1.368330518375622,
           -1.3411643521377619,
           -1.313700480891501,
           -1.2859472571436497,
           -1.2579132730610927,
           -1.2296073799695768,
           -1.20103871116841,
           -1.1722167086846487,
           -1.1431511547256665,
           -1.1138522087578133,
           -1.0843304513506185,
           -1.0545969361929046,
           -1.0246632520254455,
           -0.9945415966658634,
           -0.9642448658539029,
           -0.9337867603573842,
           -0.9031819157027018,
           -0.8724460600988841,
           -0.8415962077066035,
           -0.8106508964943511,
           -0.7796304827040629,
           -0.7485575076677974,
           -0.7174571577224346,
           -0.686357844741989,
           -0.6552919440133831,
           -0.6242967387378472,
           -0.5934156375886158,
           -0.5626997551336975,
           -0.5322099765856829,
           -0.5020196705486704,
           -0.472218268040699,
           -0.44291599262840553,
           -0.41425009772088,
           -0.38639301850989055,
           -0.35956281464054446,
           -0.33403602292807294,
           -0.3101622710177808,
           -0.2883782334463595,
           -0.26921514098045224,
           -0.25328902747497034,
           -0.24125852092663153,
           -0.23373826277268167,
           -0.23117632211497857,
           -0.2337382627726869,
           -0.24125852092664166,
           -0.2532890274749849,
           -0.26921514098047045,
           -0.2883782334463807,
           -0.31016227101780436,
           -0.3340360229280984,
           -0.35956281464057144,
           -0.3863930185099187,
           -0.4142500977209091,
           -0.4429159926284354,
           -0.47221826804072936,
           -0.5020196705487011,
           -0.5322099765857142,
           -0.5626997551337289,
           -0.5934156375886475,
           -0.624296738737879,
           -0.655291944013415,
           -0.6863578447420211,
           -0.7174571577224665,
           -0.7485575076678292,
           -0.7796304827040949,
           -0.8106508964943829,
           -0.8415962077066352,
           -0.8724460600989158,
           -0.9031819157027333,
           -0.9337867603574155,
           -0.964244865853934,
           -0.9945415966658944,
           -1.0246632520254764,
           -1.0545969361929353,
           -1.084330451350649,
           -1.1138522087578437,
           -1.1431511547256965,
           -1.1722167086846784,
           -1.2010387111684395,
           -1.2296073799696061,
           -1.2579132730611213,
           -1.2859472571436783,
           -1.3137004808915294,
           -1.34116435213779,
           -1.3683305183756496,
           -1.3951908500608323,
           -1.4217374262887872,
           -1.447962522491678,
           -1.4738585998586888,
           -1.4994182962310363,
           -1.5246344182624838,
           -1.5494999346686815,
           -1.574007970415646,
           -1.5981518017201204,
           -1.621924851753311,
           -1.64532068695518,
           -1.6683330138796821,
           -1.6909556765024425,
           -1.7131826539317936,
           -1.7350080584720584,
           -1.7564261339947598,
           -1.7774312545792228,
           -1.7980179233889926,
           -1.8181807717547247,
           -1.8379145584378755,
           -1.8572141690526422,
           -1.87607461562634,
           -1.8944910362807448,
           -1.9124586950189784,
           -1.9299729816042868,
           -1.9470294115186098,
           -1.963623625990207,
           -1.9797513920807586,
           -1.995408602823442,
           -2.0105912774043553,
           -2.025295561380499,
           -2.0395177269282123,
           -2.053254173116606,
           -2.066501426201079,
           -2.079256139932505,
           -2.09151509587812,
           -2.103275203750519,
           -2.114533501741538,
           -2.1252871568581035,
           -2.135533465257401,
           -2.1452698525789975,
           -2.1544938742717368,
           -2.163203215913486,
           -2.1713956935219394,
           -2.1790692538549146,
           -2.1862219746986695,
           -2.19285206514297,
           -2.1989578658417126,
           -2.2045378492580676,
           -2.209590619893187,
           -2.214114914497644,
           -2.218109602264851,
           -2.221573685005796,
           -2.2245062973045266,
           -2.2269067066538755,
           -2.228774313571008,
           -2.23010865169243,
           -2.2309093878481803
          ],
          [
           -2.26132192321287,
           -2.2610520986708,
           -2.2602426929238604,
           -2.2588939096002845,
           -2.257006088048565,
           -2.254579703289752,
           -2.2516153659509284,
           -2.248113822180138,
           -2.2440759535431134,
           -2.239502776902242,
           -2.2343954442782725,
           -2.228755242695389,
           -2.2225835940103447,
           -2.2158820547264586,
           -2.208652315793405,
           -2.2008962023937984,
           -2.1926156737177496,
           -2.1838128227266633,
           -2.174489875907724,
           -2.1646491930206397,
           -2.1542932668384362,
           -2.1434247228842214,
           -2.1320463191661108,
           -2.1201609459126827,
           -2.1077716253116203,
           -2.0948815112544605,
           -2.0814938890906824,
           -2.06761217539472,
           -2.0532399177498717,
           -2.038380794553494,
           -2.023038614848374,
           -2.007217318185694,
           -1.9909209745256193,
           -1.9741537841822352,
           -1.9569200778203009,
           -1.9392243165122003,
           -1.9210710918644203,
           -1.9024651262240393,
           -1.883411272976958,
           -1.8639145169510738,
           -1.8439799749392438,
           -1.8236128963587956,
           -1.802818664066483,
           -1.7816027953503153,
           -1.7599709431225388,
           -1.7379288973413556,
           -1.715482586692818,
           -1.692638080568744,
           -1.6694015913816787,
           -1.6457794772639212,
           -1.6217782452046383,
           -1.5974045546873052,
           -1.572665221899333,
           -1.5475672245970777,
           -1.52211770772281,
           -1.4963239898860479,
           -1.470193570840467,
           -1.4437341401099948,
           -1.4169535869444445,
           -1.3898600118171351,
           -1.3624617397155303,
           -1.3347673355225063,
           -1.3067856218423253,
           -1.2785256996940266,
           -1.2499969725787887,
           -1.2212091745305684,
           -1.192172402885832,
           -1.162897156664585,
           -1.1333943816491023,
           -1.1036755234890137,
           -1.0737525904649647,
           -1.0436382279253487,
           -1.013345806894299,
           -0.982889529964224,
           -0.9522845583722898,
           -0.9215471651700423,
           -0.890694920699014,
           -0.8597469182765402,
           -0.8287240502009326,
           -0.7976493470724071,
           -0.766548397221922,
           -0.7354498680463402,
           -0.704386157664881,
           -0.6733942140600974,
           -0.6425165704084265,
           -0.6118026604404933,
           -0.5813104972760792,
           -0.5511088240041498,
           -0.52127987443988,
           -0.4919229163099357,
           -0.46315878067097943,
           -0.43513559558293374,
           -0.40803590553033586,
           -0.38208520343554303,
           -0.3575615058663722,
           -0.33480476664540315,
           -0.3142234069395718,
           -0.2962929402914186,
           -0.28153915025368004,
           -0.2704976100432627,
           -0.2636463446573747,
           -0.2613219232128697,
           -0.2636463446573794,
           -0.270497610043272,
           -0.28153915025369336,
           -0.29629294029143555,
           -0.31422340693959167,
           -0.33480476664542547,
           -0.3575615058663965,
           -0.38208520343556907,
           -0.4080359055303632,
           -0.43513559558296205,
           -0.4631587806710087,
           -0.49192291630996554,
           -0.5212798744399104,
           -0.5511088240041806,
           -0.5813104972761104,
           -0.6118026604405247,
           -0.6425165704084581,
           -0.6733942140601292,
           -0.704386157664913,
           -0.735449868046372,
           -0.766548397221954,
           -0.7976493470724391,
           -0.8287240502009644,
           -0.8597469182765721,
           -0.8906949206990459,
           -0.921547165170074,
           -0.9522845583723211,
           -0.9828895299642553,
           -1.0133458068943302,
           -1.0436382279253797,
           -1.0737525904649956,
           -1.1036755234890445,
           -1.1333943816491328,
           -1.1628971566646151,
           -1.1921724028858622,
           -1.221209174530598,
           -1.249996972578818,
           -1.278525699694056,
           -1.3067856218423541,
           -1.3347673355225351,
           -1.3624617397155585,
           -1.3898600118171631,
           -1.4169535869444718,
           -1.4437341401100223,
           -1.4701935708404943,
           -1.4963239898860747,
           -1.5221177077228365,
           -1.5475672245971042,
           -1.5726652218993586,
           -1.5974045546873306,
           -1.621778245204663,
           -1.6457794772639456,
           -1.6694015913817026,
           -1.6926380805687675,
           -1.7154825866928418,
           -1.7379288973413785,
           -1.7599709431225612,
           -1.7816027953503375,
           -1.8028186640665043,
           -1.8236128963588172,
           -1.8439799749392647,
           -1.8639145169510938,
           -1.8834112729769779,
           -1.902465126224059,
           -1.921071091864439,
           -1.9392243165122185,
           -1.956920077820319,
           -1.9741537841822525,
           -1.9909209745256364,
           -2.0072173181857105,
           -2.0230386148483905,
           -2.0383807945535097,
           -2.0532399177498872,
           -2.0676121753947347,
           -2.0814938890906967,
           -2.094881511254474,
           -2.107771625311633,
           -2.120160945912695,
           -2.132046319166123,
           -2.1434247228842334,
           -2.1542932668384474,
           -2.1646491930206504,
           -2.1744898759077333,
           -2.1838128227266727,
           -2.1926156737177585,
           -2.200896202393807,
           -2.2086523157934126,
           -2.2158820547264657,
           -2.222583594010351,
           -2.228755242695395,
           -2.234395444278278,
           -2.239502776902247,
           -2.2440759535431183,
           -2.2481138221801418,
           -2.251615365950932,
           -2.254579703289755,
           -2.2570060880485667,
           -2.258893909600286,
           -2.2602426929238617,
           -2.2610520986708007
          ],
          [
           -2.2912147122272613,
           -2.290942096755034,
           -2.290124319473878,
           -2.288761587781978,
           -2.286854247315029,
           -2.2844027819044856,
           -2.281407813519423,
           -2.2778701021923284,
           -2.2737905459292462,
           -2.2691701806047897,
           -2.264010179842625,
           -2.2583118548821752,
           -2.2520766544323556,
           -2.245306164513325,
           -2.2380021082873265,
           -2.2301663458798484,
           -2.22180087419248,
           -2.212907826709002,
           -2.2034894732964108,
           -2.193548220002782,
           -2.183086608854084,
           -2.172107317652262,
           -2.160613159777181,
           -2.1486070839952895,
           -2.1360921742781485,
           -2.123071649634343,
           -2.1095488639586177,
           -2.095527305902547,
           -2.0810105987714564,
           -2.066002500452881,
           -2.050506903382377,
           -2.0345278345531796,
           -2.018069455576916,
           -2.001136062803399,
           -1.9837320875084494,
           -1.9658620961597324,
           -1.9475307907717818,
           -1.9287430093627091,
           -1.9095037265266093,
           -1.8898180541374194,
           -1.8696912422019287,
           -1.8491286798819127,
           -1.8281358967079144,
           -1.8067185640101742,
           -1.7848824965955887,
           -1.7626336547034938,
           -1.7399781462776025,
           -1.7169222295966373,
           -1.6934723163122776,
           -1.6696349749501,
           -1.645416934937405,
           -1.6208250912314415,
           -1.5958665096328057,
           -1.5705484328820125,
           -1.5448782876528262,
           -1.5188636925743448,
           -1.4925124674356396,
           -1.465832643752661,
           -1.4388324769080072,
           -1.4115204601110707,
           -1.3839053404703636,
           -1.355996137523122,
           -1.3278021646316427,
           -1.2993330537338033,
           -1.270598784030073,
           -1.2416097153051187,
           -1.2123766267240081,
           -1.1829107621175787,
           -1.153223882987138,
           -1.1233283307260231,
           -1.0932370998884802,
           -1.0629639247525946,
           -1.032523381946708,
           -1.0019310125677765,
           -0.9712034680544751,
           -0.9403586851383525,
           -0.909416096549395,
           -0.8783968858846675,
           -0.8473242972731818,
           -0.8162240133332862,
           -0.7851246186088728,
           -0.7540581704260013,
           -0.7230609052264285,
           -0.6921741162569892,
           -0.6614452484025252,
           -0.6309292682874762,
           -0.6006903826840958,
           -0.5708041953645064,
           -0.5413604102099654,
           -0.5124662025002339,
           -0.48425038176843244,
           -0.45686844026832113,
           -0.4305084872546344,
           -0.40539785320969157,
           -0.381809721828243,
           -0.3600684026081358,
           -0.34055072481393606,
           -0.32367965286910666,
           -0.30990524428923755,
           -0.29966892981849,
           -0.2933516242666895,
           -0.29121471222726114,
           -0.2933516242666939,
           -0.29966892981849863,
           -0.30990524428925,
           -0.3236796528691226,
           -0.34055072481395493,
           -0.36006840260815703,
           -0.3818097218282664,
           -0.40539785320971666,
           -0.4305084872546609,
           -0.4568684402683488,
           -0.48425038176846114,
           -0.5124662025002632,
           -0.5413604102099954,
           -0.570804195364537,
           -0.6006903826841267,
           -0.6309292682875075,
           -0.6614452484025567,
           -0.6921741162570209,
           -0.7230609052264604,
           -0.7540581704260331,
           -0.7851246186089047,
           -0.8162240133333182,
           -0.8473242972732138,
           -0.8783968858846994,
           -0.9094160965494269,
           -0.9403586851383843,
           -0.9712034680545067,
           -1.0019310125678078,
           -1.0325233819467394,
           -1.0629639247526257,
           -1.0932370998885113,
           -1.1233283307260542,
           -1.1532238829871686,
           -1.1829107621176094,
           -1.2123766267240383,
           -1.2416097153051486,
           -1.2705987840301027,
           -1.2993330537338326,
           -1.3278021646316718,
           -1.355996137523151,
           -1.3839053404703923,
           -1.4115204601110989,
           -1.4388324769080352,
           -1.4658326437526885,
           -1.492512467435667,
           -1.5188636925743717,
           -1.5448782876528528,
           -1.5705484328820387,
           -1.5958665096328315,
           -1.6208250912314668,
           -1.6454169349374304,
           -1.669634974950125,
           -1.6934723163123018,
           -1.7169222295966613,
           -1.7399781462776265,
           -1.7626336547035169,
           -1.7848824965956116,
           -1.8067185640101961,
           -1.8281358967079355,
           -1.8491286798819337,
           -1.8696912422019498,
           -1.8898180541374399,
           -1.9095037265266295,
           -1.928743009362729,
           -1.947530790771801,
           -1.9658620961597504,
           -1.9837320875084674,
           -2.001136062803417,
           -2.0180694555769327,
           -2.034527834553196,
           -2.050506903382393,
           -2.066002500452897,
           -2.0810105987714715,
           -2.0955273059025616,
           -2.1095488639586324,
           -2.123071649634357,
           -2.1360921742781613,
           -2.1486070839953015,
           -2.1606131597771934,
           -2.172107317652274,
           -2.1830866088540954,
           -2.1935482200027923,
           -2.2034894732964205,
           -2.2129078267090114,
           -2.2218008741924886,
           -2.2301663458798564,
           -2.2380021082873345,
           -2.245306164513333,
           -2.2520766544323623,
           -2.2583118548821814,
           -2.264010179842631,
           -2.2691701806047946,
           -2.273790545929251,
           -2.277870102192332,
           -2.2814078135194267,
           -2.2844027819044888,
           -2.286854247315031,
           -2.28876158778198,
           -2.29012431947388,
           -2.290942096755035
          ],
          [
           -2.320825769815377,
           -2.320550460604341,
           -2.3197246033805023,
           -2.318348409364541,
           -2.316422230567226,
           -2.3139465597540583,
           -2.31092203039613,
           -2.3073494166075963,
           -2.3032296330702167,
           -2.298563734945596,
           -2.293352917775822,
           -2.2875985173733615,
           -2.281302009701192,
           -2.2744650107442883,
           -2.2670892763737416,
           -2.2591767022049347,
           -2.2507293234513996,
           -2.241749314776133,
           -2.2322389901423794,
           -2.222200802666105,
           -2.2116373444726176,
           -2.200551346560068,
           -2.188945678672853,
           -2.176823349188259,
           -2.164187505020045,
           -2.1510414315430615,
           -2.137388552543413,
           -2.1232324301992014,
           -2.108576765097376,
           -2.0934253962928553,
           -2.077782301416744,
           -2.0616515968412332,
           -2.045037537909592,
           -2.027944519240662,
           -2.010377075118281,
           -1.9923398799773204,
           -1.973837748999367,
           -1.9548756388326374,
           -1.9354586484524723,
           -1.9155920201807728,
           -1.8952811408850019,
           -1.8745315433800023,
           -1.8533489080588386,
           -1.831739064782304,
           -1.8097079950606445,
           -1.7872618345655604,
           -1.7644068760157574,
           -1.7411495724853303,
           -1.7174965411912206,
           -1.6934545678240864,
           -1.6690306114963276,
           -1.644231810391989,
           -1.6190654882161064,
           -1.5935391615560996,
           -1.5676605482855255,
           -1.5414375771613456,
           -1.5148783987905008,
           -1.4879913981708046,
           -1.460785209045866,
           -1.4332687303551404,
           -1.4054511451096803,
           -1.3773419420835082,
           -1.3489509407819367,
           -1.3202883202343552,
           -1.2913646522634166,
           -1.2621909400094102,
           -1.2327786626433332,
           -1.2031398273914777,
           -1.1732870302268277,
           -1.1432335268690308,
           -1.1129933160889711,
           -1.082581237753578,
           -1.0520130885938803,
           -1.02130575936309,
           -0.9904773979082644,
           -0.9595476037555971,
           -0.9285376611650779,
           -0.897470819320521,
           -0.8663726304804124,
           -0.8352713596407944,
           -0.8041984826952927,
           -0.7731892943845313,
           -0.7422836526873406,
           -0.7115268928894211,
           -0.6809709524770375,
           -0.650675757173072,
           -0.6207109283967724,
           -0.5911578819299743,
           -0.5621123938472904,
           -0.533687707325223,
           -0.5060182326042711,
           -0.4792638343813113,
           -0.45361457737787175,
           -0.42929556923405304,
           -0.4065711476449631,
           -0.3857470645987922,
           -0.36716855396278025,
           -0.35121144364999973,
           -0.3382633311691722,
           -0.3286931591742262,
           -0.32281107199993037,
           -0.3208257698153768,
           -0.3228110719999345,
           -0.32869315917423414,
           -0.3382633311691838,
           -0.35121144365001467,
           -0.3671685539627981,
           -0.38574706459881253,
           -0.40657114764498553,
           -0.42929556923407725,
           -0.4536145773778974,
           -0.47926383438133824,
           -0.5060182326042992,
           -0.5336877073252518,
           -0.5621123938473199,
           -0.5911578819300044,
           -0.620710928396803,
           -0.650675757173103,
           -0.6809709524770687,
           -0.7115268928894525,
           -0.7422836526873724,
           -0.7731892943845631,
           -0.8041984826953246,
           -0.8352713596408263,
           -0.8663726304804443,
           -0.897470819320553,
           -0.9285376611651098,
           -0.9595476037556291,
           -0.990477397908296,
           -1.0213057593631216,
           -1.0520130885939118,
           -1.0825812377536093,
           -1.1129933160890024,
           -1.1432335268690617,
           -1.1732870302268583,
           -1.2031398273915084,
           -1.2327786626433637,
           -1.2621909400094402,
           -1.2913646522634463,
           -1.3202883202343847,
           -1.3489509407819662,
           -1.3773419420835373,
           -1.405451145109709,
           -1.4332687303551688,
           -1.4607852090458942,
           -1.4879913981708324,
           -1.5148783987905283,
           -1.5414375771613729,
           -1.5676605482855526,
           -1.5935391615561258,
           -1.6190654882161326,
           -1.6442318103920148,
           -1.6690306114963527,
           -1.693454567824111,
           -1.7174965411912453,
           -1.7411495724853545,
           -1.7644068760157814,
           -1.7872618345655837,
           -1.8097079950606678,
           -1.8317390647823262,
           -1.8533489080588603,
           -1.874531543380024,
           -1.895281140885023,
           -1.9155920201807932,
           -1.9354586484524927,
           -1.9548756388326574,
           -1.9738377489993864,
           -1.9923398799773386,
           -2.010377075118299,
           -2.0279445192406804,
           -2.04503753790961,
           -2.06165159684125,
           -2.0777823014167605,
           -2.093425396292871,
           -2.1085767650973914,
           -2.1232324301992165,
           -2.1373885525434275,
           -2.1510414315430757,
           -2.1641875050200587,
           -2.1768233491882714,
           -2.1889456786728654,
           -2.20055134656008,
           -2.2116373444726287,
           -2.2222008026661153,
           -2.2322389901423896,
           -2.241749314776142,
           -2.2507293234514085,
           -2.259176702204943,
           -2.267089276373749,
           -2.2744650107442963,
           -2.2813020097011987,
           -2.2875985173733677,
           -2.2933529177758274,
           -2.298563734945601,
           -2.3032296330702215,
           -2.3073494166076,
           -2.3109220303961338,
           -2.313946559754061,
           -2.316422230567228,
           -2.3183484093645426,
           -2.3197246033805037,
           -2.3205504606043417
          ],
          [
           -2.3501264491914,
           -2.3498485412991874,
           -2.349014889318994,
           -2.347625708334373,
           -2.345681356798712,
           -2.343182336506647,
           -2.3401292925544617,
           -2.3365230132899097,
           -2.33236443025201,
           -2.327654618101516,
           -2.322394794542876,
           -2.3165863202386654,
           -2.3102306987176227,
           -2.3033295762775663,
           -2.29588474188467,
           -2.2878981270707315,
           -2.279371805830295,
           -2.2703079945196882,
           -2.2607090517602617,
           -2.2505774783484047,
           -2.239915917175157,
           -2.2287271531585513,
           -2.2170141131921692,
           -2.204779866113753,
           -2.1920276226981072,
           -2.178760735679019,
           -2.1649826998053676,
           -2.1506971519372087,
           -2.1359078711881847,
           -2.120618779121352,
           -2.1048339400062437,
           -2.0885575611458798,
           -2.0717939932833986,
           -2.0545477310990643,
           -2.0368234138096453,
           -2.018625825883527,
           -1.9999598978865014,
           -1.9808307074749312,
           -1.9612434805549912,
           -1.941203592628989,
           -1.9207165703523257,
           -1.899788093327651,
           -1.8784239961661093,
           -1.8566302708494717,
           -1.8344130694313587,
           -1.8117787071208666,
           -1.7887336657977746,
           -1.765284598015284,
           -1.74143833155407,
           -1.7172018746005042,
           -1.6925824216324556,
           -1.6675873601083466,
           -1.6422242780694805,
           -1.6165009727824133,
           -1.5904254605678094,
           -1.5640059879853299,
           -1.5372510445713654,
           -1.5101693773586238,
           -1.4827700074447592,
           -1.4550622489225877,
           -1.4270557305385108,
           -1.3987604205103579,
           -1.3701866550133313,
           -1.3413451709358255,
           -1.3122471436191736,
           -1.2829042304311458,
           -1.253328621187742,
           -1.2235330966382316,
           -1.1935310964729842,
           -1.1633367986130014,
           -1.1329652119075386,
           -1.1024322848184887,
           -1.0717550332282968,
           -1.0409516911983379,
           -1.0100418893597942,
           -0.9790468666799272,
           -0.9479897226635657,
           -0.9168957186838694,
           -0.8857926391609663,
           -0.8547112258061589,
           -0.8236857012150388,
           -0.7927544018154079,
           -0.7619605446237143,
           -0.7313531574428002,
           -0.7009882079124623,
           -0.6709299727976629,
           -0.6412526941530742,
           -0.6120425717166246,
           -0.5834001376905427,
           -0.5554430450685516,
           -0.528309264063598,
           -0.5021606076670052,
           -0.47718637495535,
           -0.45360668216810984,
           -0.4316747224230146,
           -0.41167675637677276,
           -0.39392816032317246,
           -0.3787635541855952,
           -0.3665192916885639,
           -0.3575079123180733,
           -0.35198677612438073,
           -0.3501264491913999,
           -0.35198677612438456,
           -0.35750791231808077,
           -0.3665192916885749,
           -0.37876355418560936,
           -0.3939281603231895,
           -0.41167675637679224,
           -0.43167472242303623,
           -0.45360668216813327,
           -0.477186374955375,
           -0.5021606076670315,
           -0.5283092640636254,
           -0.5554430450685799,
           -0.5834001376905718,
           -0.6120425717166542,
           -0.6412526941531044,
           -0.6709299727976936,
           -0.7009882079124933,
           -0.7313531574428316,
           -0.7619605446237459,
           -0.7927544018154397,
           -0.8236857012150706,
           -0.8547112258061909,
           -0.8857926391609983,
           -0.9168957186839014,
           -0.9479897226635976,
           -0.979046866679959,
           -1.010041889359826,
           -1.0409516911983694,
           -1.0717550332283283,
           -1.10243228481852,
           -1.13296521190757,
           -1.1633367986130327,
           -1.193531096473015,
           -1.2235330966382625,
           -1.2533286211877726,
           -1.282904230431176,
           -1.3122471436192036,
           -1.3413451709358553,
           -1.3701866550133608,
           -1.3987604205103872,
           -1.4270557305385398,
           -1.4550622489226164,
           -1.4827700074447874,
           -1.5101693773586518,
           -1.537251044571393,
           -1.5640059879853572,
           -1.5904254605678365,
           -1.61650097278244,
           -1.6422242780695064,
           -1.6675873601083724,
           -1.692582421632481,
           -1.7172018746005295,
           -1.7414383315540949,
           -1.7652845980153085,
           -1.7887336657977986,
           -1.81177870712089,
           -1.8344130694313818,
           -1.8566302708494942,
           -1.878423996166131,
           -1.8997880933276725,
           -1.920716570352347,
           -1.9412035926290094,
           -1.9612434805550116,
           -1.9808307074749512,
           -1.999959897886521,
           -2.0186258258835457,
           -2.0368234138096635,
           -2.0545477310990825,
           -2.0717939932834164,
           -2.0885575611458966,
           -2.10483394000626,
           -2.120618779121368,
           -2.1359078711882002,
           -2.1506971519372238,
           -2.1649826998053827,
           -2.1787607356790333,
           -2.1920276226981206,
           -2.204779866113766,
           -2.2170141131921817,
           -2.228727153158563,
           -2.2399159171751686,
           -2.2505774783484154,
           -2.2607090517602715,
           -2.2703079945196976,
           -2.2793718058303045,
           -2.2878981270707395,
           -2.2958847418846777,
           -2.3033295762775743,
           -2.3102306987176293,
           -2.3165863202386716,
           -2.3223947945428813,
           -2.3276546181015214,
           -2.332364430252015,
           -2.3365230132899133,
           -2.3401292925544657,
           -2.34318233650665,
           -2.345681356798714,
           -2.347625708334374,
           -2.3490148893189953,
           -2.3498485412991883
          ],
          [
           -2.3790884038403886,
           -2.378807990217812,
           -2.377966822343191,
           -2.376565119191491,
           -2.3746032457064876,
           -2.372081712779275,
           -2.3690011772186437,
           -2.365362441713837,
           -2.361166454790294,
           -2.356414310759198,
           -2.3511072496617227,
           -2.3452466572091293,
           -2.338834064719954,
           -2.3318711490557695,
           -2.3243597325571685,
           -2.3163017829818457,
           -2.307699413446863,
           -2.2985548823774473,
           -2.2888705934649187,
           -2.278649095636648,
           -2.2678930830412507,
           -2.2566053950525666,
           -2.2447890162963726,
           -2.232447076704166,
           -2.2195828515988403,
           -2.2061997618175706,
           -2.1923013738778017,
           -2.177891400192847,
           -2.1629736993443145,
           -2.147552276419362,
           -2.13163128342162,
           -2.1152150197656447,
           -2.0983079328658043,
           -2.0809146188317698,
           -2.06303982328412,
           -2.04468844230516,
           -2.0258655235417793,
           -2.006576267479171,
           -1.9868260289064752,
           -1.9666203185979574,
           -1.9459648052362335,
           -1.9248653176073516,
           -1.903327847101298,
           -1.881358550555811,
           -1.8589637534863122,
           -1.8361499537504122,
           -1.8129238257019684,
           -1.7892922248971566,
           -1.7652621934236743,
           -1.7408409659342123,
           -1.7160359764769308,
           -1.6908548662291754,
           -1.665305492256377,
           -1.6393959374364253,
           -1.6131345217112552,
           -1.5865298148525782,
           -1.5595906509582496,
           -1.5323261449306733,
           -1.5047457112298264,
           -1.4768590852423111,
           -1.4486763476658155,
           -1.4202079523773716,
           -1.3914647583362252,
           -1.3624580661707524,
           -1.3331996602172453,
           -1.3037018569208276,
           -1.2739775606806114,
           -1.2440403284290464,
           -1.2139044444873963,
           -1.1835850075454908,
           -1.1530980319868078,
           -1.1224605662348774,
           -1.0916908313529257,
           -1.0608083838086857,
           -1.0298343071485183,
           -0.9987914383431258,
           -0.967704635811012,
           -0.9366010976410354,
           -0.9055107403720049,
           -0.8744666508959609,
           -0.8435056266757709,
           -0.8126688225271637,
           -0.7820025256789912,
           -0.7515590845606146,
           -0.7213980204525368,
           -0.6915873541289226,
           -0.6622051807175503,
           -0.6333415230985651,
           -0.6051004837342058,
           -0.5776026912329811,
           -0.5509879926672183,
           -0.5254182636739393,
           -0.5010800806890082,
           -0.4781868086711316,
           -0.45697939837984863,
           -0.4377248834036417,
           -0.42071130138397445,
           -0.4062377095916518,
           -0.394598385014931,
           -0.386061449835492,
           -0.3808440584937032,
           -0.37908840384038855,
           -0.38084405849370684,
           -0.3860614498354991,
           -0.39459838501494143,
           -0.4062377095916653,
           -0.42071130138399077,
           -0.43772488340366034,
           -0.4569793983798695,
           -0.4781868086711544,
           -0.5010800806890326,
           -0.5254182636739649,
           -0.5509879926672453,
           -0.577602691233009,
           -0.6051004837342343,
           -0.6333415230985944,
           -0.6622051807175802,
           -0.6915873541289531,
           -0.7213980204525676,
           -0.7515590845606458,
           -0.7820025256790226,
           -0.8126688225271953,
           -0.8435056266758026,
           -0.8744666508959927,
           -0.9055107403720367,
           -0.9366010976410672,
           -0.9677046358110439,
           -0.9987914383431576,
           -1.0298343071485503,
           -1.0608083838087177,
           -1.0916908313529574,
           -1.122460566234909,
           -1.1530980319868396,
           -1.183585007545522,
           -1.2139044444874274,
           -1.2440403284290775,
           -1.2739775606806423,
           -1.303701856920858,
           -1.3331996602172755,
           -1.3624580661707824,
           -1.3914647583362547,
           -1.4202079523774012,
           -1.4486763476658446,
           -1.4768590852423402,
           -1.5047457112298548,
           -1.5323261449307017,
           -1.5595906509582773,
           -1.5865298148526057,
           -1.6131345217112825,
           -1.639395937436452,
           -1.6653054922564037,
           -1.6908548662292016,
           -1.7160359764769566,
           -1.7408409659342376,
           -1.7652621934236992,
           -1.7892922248971812,
           -1.8129238257019928,
           -1.836149953750436,
           -1.8589637534863355,
           -1.881358550555834,
           -1.9033278471013204,
           -1.924865317607374,
           -1.9459648052362553,
           -1.9666203185979783,
           -1.9868260289064956,
           -2.006576267479191,
           -2.025865523541799,
           -2.044688442305179,
           -2.0630398232841385,
           -2.080914618831788,
           -2.098307932865822,
           -2.115215019765661,
           -2.131631283421637,
           -2.147552276419378,
           -2.1629736993443305,
           -2.1778914001928618,
           -2.192301373877817,
           -2.2061997618175853,
           -2.219582851598854,
           -2.232447076704179,
           -2.244789016296385,
           -2.256605395052578,
           -2.2678930830412622,
           -2.278649095636659,
           -2.288870593464929,
           -2.2985548823774566,
           -2.3076994134468722,
           -2.3163017829818546,
           -2.324359732557176,
           -2.331871149055777,
           -2.3388340647199612,
           -2.3452466572091355,
           -2.3511072496617285,
           -2.3564143107592033,
           -2.361166454790299,
           -2.365362441713841,
           -2.369001177218648,
           -2.3720817127792775,
           -2.3746032457064894,
           -2.376565119191493,
           -2.377966822343193,
           -2.3788079902178123
          ],
          [
           -2.407683614941698,
           -2.407400786465576,
           -2.4065523753326565,
           -2.405138604426379,
           -2.4031598452095264,
           -2.400616617710072,
           -2.3975095905019073,
           -2.393839580680991,
           -2.3896075538376276,
           -2.384814624025757,
           -2.379462053730303,
           -2.3735512538338144,
           -2.3670837835838396,
           -2.3600613505626558,
           -2.3524858106612228,
           -2.34435916805945,
           -2.335683575215107,
           -2.326461332864022,
           -2.3166948900344577,
           -2.3063868440789177,
           -2.29553994072697,
           -2.2841570741630584,
           -2.272241287133707,
           -2.259795771088987,
           -2.2468238663636106,
           -2.233329062403616,
           -2.2193149980452156,
           -2.2047854618530756,
           -2.189744392526095,
           -2.1741958793795964,
           -2.1581441629138087,
           -2.1415936354796234,
           -2.124548842053792,
           -2.107014481137106,
           -2.088995405790621,
           -2.0704966248267094,
           -2.0515233041736702,
           -2.032080768434794,
           -2.012174502665293,
           -1.991810154393281,
           -1.9709935359142121,
           -1.9497306268917862,
           -1.9280275773024882,
           -1.9058907107656413,
           -1.8833265283062588,
           -1.860341712604159,
           -1.8369431327899355,
           -1.8131378498565196,
           -1.7889331227645262,
           -1.7643364153304235,
           -1.7393554039991856,
           -1.7139979866176733,
           -1.688272292341967,
           -1.6621866928316353,
           -1.6357498149070002,
           -1.6089705548724336,
           -1.58185809474037,
           -1.554421920627892,
           -1.5266718436415365,
           -1.4986180236176625,
           -1.4702709961468914,
           -1.441641703383681,
           -1.412741529228339,
           -1.3835823395715536,
           -1.3541765284142497,
           -1.3245370708224669,
           -1.2946775838531452,
           -1.2646123967984397,
           -1.2343566323510993,
           -1.2039263006008745,
           -1.1733384081431013,
           -1.1426110850292297,
           -1.1117637328314867,
           -1.0808171977495273,
           -1.0497939734785782,
           -1.0187184395122073,
           -0.987617141697129,
           -0.9565191232220615,
           -0.9254563158350347,
           -0.8944640029624333,
           -0.8635813685469855,
           -0.8328521477896573,
           -0.8023253984577065,
           -0.7720564137670652,
           -0.742107799608109,
           -0.7125507392607264,
           -0.6834664663948319,
           -0.6549479599084516,
           -0.6271018586569576,
           -0.6000505654068261,
           -0.5739344605219003,
           -0.5489140683278294,
           -0.5251719038405691,
           -0.502913569306688,
           -0.48236747559894755,
           -0.4637823659886404,
           -0.4474216963055106,
           -0.433554008081084,
           -0.4224388867618337,
           -0.41430904447211747,
           -0.40935042796555193,
           -0.4076836149416981,
           -0.4093504279655554,
           -0.4143090444721242,
           -0.42243888676184366,
           -0.43355400808109684,
           -0.44742169630552625,
           -0.46378236598865835,
           -0.4823674755989677,
           -0.5029135693067099,
           -0.5251719038405926,
           -0.5489140683278545,
           -0.5739344605219266,
           -0.6000505654068534,
           -0.6271018586569858,
           -0.6549479599084804,
           -0.6834664663948614,
           -0.7125507392607566,
           -0.7421077996081396,
           -0.7720564137670963,
           -0.8023253984577376,
           -0.8328521477896889,
           -0.8635813685470173,
           -0.8944640029624651,
           -0.9254563158350666,
           -0.9565191232220934,
           -0.9876171416971611,
           -1.0187184395122393,
           -1.04979397347861,
           -1.0808171977495593,
           -1.1117637328315184,
           -1.1426110850292612,
           -1.1733384081431326,
           -1.2039263006009058,
           -1.2343566323511304,
           -1.2646123967984708,
           -1.2946775838531763,
           -1.3245370708224973,
           -1.35417652841428,
           -1.3835823395715836,
           -1.4127415292283687,
           -1.4416417033837106,
           -1.4702709961469207,
           -1.4986180236176914,
           -1.5266718436415654,
           -1.5544219206279202,
           -1.5818580947403977,
           -1.6089705548724613,
           -1.6357498149070273,
           -1.6621866928316622,
           -1.6882722923419935,
           -1.7139979866176995,
           -1.7393554039992114,
           -1.764336415330449,
           -1.7889331227645513,
           -1.8131378498565442,
           -1.8369431327899597,
           -1.860341712604183,
           -1.8833265283062823,
           -1.9058907107656644,
           -1.9280275773025106,
           -1.9497306268918082,
           -1.9709935359142339,
           -1.991810154393302,
           -2.0121745026653133,
           -2.0320807684348146,
           -2.0515233041736898,
           -2.0704966248267285,
           -2.0889954057906395,
           -2.1070144811371243,
           -2.12454884205381,
           -2.1415936354796403,
           -2.158144162913825,
           -2.1741958793796132,
           -2.1897443925261113,
           -2.20478546185309,
           -2.2193149980452302,
           -2.2333290624036306,
           -2.246823866363624,
           -2.2597957710889998,
           -2.272241287133719,
           -2.28415707416307,
           -2.295539940726982,
           -2.306386844078929,
           -2.316694890034468,
           -2.3264613328640316,
           -2.3356835752151164,
           -2.344359168059459,
           -2.352485810661231,
           -2.360061350562663,
           -2.3670837835838463,
           -2.3735512538338206,
           -2.379462053730309,
           -2.384814624025762,
           -2.3896075538376316,
           -2.3938395806809956,
           -2.397509590501911,
           -2.4006166177100754,
           -2.403159845209529,
           -2.405138604426381,
           -2.406552375332658,
           -2.407400786465576
          ],
          [
           -2.4358844184753803,
           -2.435599263986462,
           -2.434743876119476,
           -2.4333184816723343,
           -2.431323458636951,
           -2.428759336192647,
           -2.425626794697497,
           -2.4219266656782485,
           -2.417659931819578,
           -2.4128277269536667,
           -2.4074313360512543,
           -2.4014721952155424,
           -2.394951891680537,
           -2.387872163815631,
           -2.380234901138495,
           -2.3720421443385824,
           -2.3632960853138494,
           -2.3539990672235853,
           -2.344153584560587,
           -2.333762283246245,
           -2.3228279607525306,
           -2.3113535662552733,
           -2.2993422008235904,
           -2.2867971176508592,
           -2.27372172233317,
           -2.2601195732018295,
           -2.245994381717198,
           -2.2313500129318657,
           -2.2161904860320907,
           -2.2005199749673183,
           -2.18434280917869,
           -2.167663474438636,
           -2.1504866138149716,
           -2.1328170287743906,
           -2.114659680441946,
           -2.096019691034975,
           -2.076902345492041,
           -2.0573130933198622,
           -2.037257550683902,
           -2.0167415027713456,
           -1.9957709064586735,
           -1.9743518933199748,
           -1.9524907730166348,
           -1.9301940371141504,
           -1.9074683633776774,
           -1.8843206206045817,
           -1.8607578740599597,
           -1.8367873915898711,
           -1.8124166504971668,
           -1.7876533452764725,
           -1.7625053963183606,
           -1.7369809597083599,
           -1.7110884382645317,
           -1.6848364939783762,
           -1.6582340620482965,
           -1.631290366723403,
           -1.604014939208822,
           -1.5764176379227688,
           -1.5485086714415568,
           -1.520298624522703,
           -1.4917984876599617,
           -1.4630196906992894,
           -1.4339741411337565,
           -1.4046742678009547,
           -1.3751330708318301,
           -1.3453641788491246,
           -1.3153819145914882,
           -1.2852013703517007,
           -1.2548384948712337,
           -1.2243101936369472,
           -1.193634444888947,
           -1.1628304340831794,
           -1.131918710071778,
           -1.1009213668839255,
           -1.0698622557271993,
           -1.0387672327020674,
           -1.0076644487480484,
           -0.9765846895333842,
           -0.9455617743672035,
           -0.9146330247440565,
           -0.8838398147853288,
           -0.853228217528566,
           -0.8228497625557228,
           -0.7927623215267533,
           -0.7630311382579532,
           -0.7337300181817398,
           -0.7049426869770062,
           -0.6767643177967955,
           -0.6493032078429932,
           -0.6226825539362444,
           -0.5970422280269547,
           -0.5725403816668492,
           -0.5493546090498836,
           -0.5276822723144149,
           -0.5077394533787926,
           -0.4897578782279066,
           -0.4739791274917155,
           -0.4606455968772624,
           -0.4499881033900844,
           -0.4422107915230808,
           -0.43747497266628754,
           -0.43588441847538034,
           -0.43747497266629076,
           -0.44221079152308734,
           -0.44998810339009393,
           -0.46064559687727485,
           -0.47397912749173055,
           -0.48975787822792394,
           -0.507739453378812,
           -0.5276822723144363,
           -0.5493546090499067,
           -0.5725403816668737,
           -0.5970422280269806,
           -0.6226825539362711,
           -0.649303207843021,
           -0.6767643177968239,
           -0.7049426869770353,
           -0.7337300181817696,
           -0.7630311382579834,
           -0.792762321526784,
           -0.8228497625557539,
           -0.8532282175285973,
           -0.8838398147853603,
           -0.9146330247440881,
           -0.9455617743672352,
           -0.976584689533416,
           -1.0076644487480804,
           -1.0387672327020994,
           -1.0698622557272315,
           -1.1009213668839575,
           -1.1319187100718098,
           -1.1628304340832114,
           -1.1936344448889786,
           -1.2243101936369787,
           -1.2548384948712648,
           -1.2852013703517318,
           -1.315381914591519,
           -1.3453641788491553,
           -1.3751330708318603,
           -1.4046742678009847,
           -1.4339741411337865,
           -1.463019690699319,
           -1.4917984876599912,
           -1.520298624522732,
           -1.5485086714415854,
           -1.5764176379227974,
           -1.6040149392088503,
           -1.6312903667234313,
           -1.658234062048324,
           -1.6848364939784035,
           -1.7110884382645584,
           -1.7369809597083863,
           -1.7625053963183865,
           -1.7876533452764978,
           -1.812416650497192,
           -1.836787391589896,
           -1.8607578740599842,
           -1.8843206206046055,
           -1.9074683633777008,
           -1.9301940371141735,
           -1.9524907730166572,
           -1.974351893319997,
           -1.9957709064586948,
           -2.0167415027713664,
           -2.0372575506839223,
           -2.057313093319883,
           -2.0769023454920608,
           -2.096019691034994,
           -2.1146596804419646,
           -2.132817028774409,
           -2.1504866138149903,
           -2.167663474438654,
           -2.1843428091787067,
           -2.200519974967335,
           -2.216190486032107,
           -2.2313500129318804,
           -2.245994381717213,
           -2.260119573201844,
           -2.2737217223331836,
           -2.2867971176508726,
           -2.2993422008236024,
           -2.3113535662552853,
           -2.3228279607525426,
           -2.3337622832462555,
           -2.3441535845605976,
           -2.3539990672235955,
           -2.3632960853138587,
           -2.3720421443385913,
           -2.3802349011385027,
           -2.3878721638156386,
           -2.394951891680544,
           -2.401472195215549,
           -2.40743133605126,
           -2.4128277269536724,
           -2.4176599318195824,
           -2.421926665678253,
           -2.4256267946975005,
           -2.4287593361926496,
           -2.4313234586369536,
           -2.4333184816723357,
           -2.4347438761194766,
           -2.435599263986462
          ],
          [
           -2.4636635319853366,
           -2.4633761383305792,
           -2.462514034268843,
           -2.4610774505078568,
           -2.4590667715610195,
           -2.456482535748495,
           -2.4533254351994076,
           -2.449596315855794,
           -2.4452961774791744,
           -2.4404261736608057,
           -2.4349876118369003,
           -2.4289819533103096,
           -2.4224108132804094,
           -2.415275960883181,
           -2.407579319243734,
           -2.3993229655438193,
           -2.3905091311071764,
           -2.3811402015058856,
           -2.371218716691274,
           -2.3607473711532942,
           -2.349729014112727,
           -2.338166649751035,
           -2.3260634374831857,
           -2.3134226922793424,
           -2.300247885041924,
           -2.2865426430452347,
           -2.2723107504456,
           -2.2575561488708034,
           -2.2422829380985387,
           -2.2264953768346154,
           -2.2101978836028473,
           -2.1933950377597977,
           -2.1760915806490173,
           -2.1582924169110416,
           -2.140002615967184,
           -2.1212274136972344,
           -2.101972214333445,
           -2.082242592595776,
           -2.0620442960962695,
           -2.0413832480437586,
           -2.020265550283805,
           -1.9986974867130438,
           -1.9766855271118986,
           -1.9542363314451308,
           -1.9313567546859502,
           -1.908053852226542,
           -1.8843348859460614,
           -1.860207331016514,
           -1.8356788835377065,
           -1.8107574691048531,
           -1.7854512524266777,
           -1.7597686481283674,
           -1.7337183328927803,
           -1.7073092591154344,
           -1.6805506702744646,
           -1.6534521182466029,
           -1.6260234828350382,
           -1.5982749938156728,
           -1.5702172558558294,
           -1.5418612767152209,
           -1.5132184992044266,
           -1.4843008374531128,
           -1.4551207181309227,
           -1.4256911273709942,
           -1.39602566427253,
           -1.3661386020084825,
           -1.3360449577416482,
           -1.305760572762537,
           -1.2753022045114772,
           -1.2446876324427756,
           -1.2139357800387294,
           -1.183066855695415,
           -1.1521025156910418,
           -1.121066053022626,
           -1.0899826165692597,
           -1.0588794658207807,
           -1.027786267306224,
           -0.9967354398674223,
           -0.9657625570369504,
           -0.9349068159615991,
           -0.9042115834911496,
           -0.8737250310963881,
           -0.8435008709659785,
           -0.813599205592374,
           -0.7840875018134568,
           -0.7550416967431474,
           -0.7265474359885744,
           -0.6987014321421134,
           -0.671612911212544,
           -0.6454050832072113,
           -0.6202165268842789,
           -0.5962023145949659,
           -0.5735346202617995,
           -0.5524024566684206,
           -0.5330100928437382,
           -0.5155736404542124,
           -0.5003153218623412,
           -0.48745510842747347,
           -0.47719980336262063,
           -0.46973024253987106,
           -0.46518799514938153,
           -0.46366353198533655,
           -0.4651879951493847,
           -0.4697302425398772,
           -0.47719980336262985,
           -0.48745510842748546,
           -0.5003153218623557,
           -0.5155736404542292,
           -0.5330100928437572,
           -0.5524024566684415,
           -0.5735346202618219,
           -0.5962023145949897,
           -0.6202165268843043,
           -0.6454050832072379,
           -0.6716129112125714,
           -0.6987014321421418,
           -0.7265474359886034,
           -0.755041696743177,
           -0.784087501813487,
           -0.8135992055924044,
           -0.8435008709660095,
           -0.8737250310964192,
           -0.9042115834911809,
           -0.9349068159616306,
           -0.9657625570369821,
           -0.9967354398674542,
           -1.0277862673062559,
           -1.0588794658208127,
           -1.0899826165692919,
           -1.121066053022658,
           -1.1521025156910738,
           -1.1830668556954465,
           -1.2139357800387611,
           -1.2446876324428071,
           -1.2753022045115088,
           -1.3057605727625683,
           -1.3360449577416793,
           -1.3661386020085133,
           -1.3960256642725608,
           -1.4256911273710247,
           -1.455120718130953,
           -1.4843008374531428,
           -1.5132184992044564,
           -1.54186127671525,
           -1.5702172558558585,
           -1.5982749938157015,
           -1.6260234828350666,
           -1.6534521182466306,
           -1.6805506702744923,
           -1.7073092591154615,
           -1.7337183328928072,
           -1.759768648128394,
           -1.7854512524267039,
           -1.810757469104879,
           -1.835678883537732,
           -1.8602073310165388,
           -1.8843348859460862,
           -1.908053852226566,
           -1.931356754685974,
           -1.954236331445154,
           -1.9766855271119215,
           -1.9986974867130662,
           -2.0202655502838267,
           -2.04138324804378,
           -2.0620442960962904,
           -2.0822425925957964,
           -2.1019722143334656,
           -2.121227413697253,
           -2.140002615967203,
           -2.1582924169110607,
           -2.1760915806490355,
           -2.193395037759815,
           -2.210197883602865,
           -2.2264953768346314,
           -2.2422829380985543,
           -2.2575561488708193,
           -2.272310750445615,
           -2.2865426430452493,
           -2.300247885041938,
           -2.3134226922793557,
           -2.3260634374831985,
           -2.3381666497510474,
           -2.349729014112739,
           -2.360747371153305,
           -2.371218716691285,
           -2.3811402015058953,
           -2.3905091311071858,
           -2.399322965543828,
           -2.407579319243742,
           -2.415275960883189,
           -2.422410813280417,
           -2.428981953310316,
           -2.4349876118369065,
           -2.440426173660811,
           -2.4452961774791793,
           -2.449596315855798,
           -2.453325435199411,
           -2.456482535748498,
           -2.4590667715610217,
           -2.4610774505078585,
           -2.462514034268844,
           -2.46337613833058
          ],
          [
           -2.4909940809733313,
           -2.4907045330518747,
           -2.4898359674878416,
           -2.488388618883923,
           -2.486362878250302,
           -2.4837592930135575,
           -2.480578567029841,
           -2.4768215606030535,
           -2.472489290508953,
           -2.467582930026355,
           -2.4621038089768197,
           -2.456053413774456,
           -2.449433387487738,
           -2.4422455299154966,
           -2.434491797679533,
           -2.426174304336628,
           -2.417295320513029,
           -2.407857274064881,
           -2.3978627502684398,
           -2.3873144920443345,
           -2.376215400220615,
           -2.364568533839808,
           -2.3523771105157776,
           -2.3396445068467777,
           -2.326374258891762,
           -2.312570062717753,
           -2.2982357750268836,
           -2.283375413872642,
           -2.2679931594758345,
           -2.252093355151921,
           -2.235680508362594,
           -2.2187592919058887,
           -2.2013345452606305,
           -2.1834112761027917,
           -2.16499466201324,
           -2.146090052398575,
           -2.1267029706491822,
           -2.1068391165614027,
           -2.086504369053839,
           -2.0657047892113334,
           -2.0444466236941334,
           -2.0227363085542955,
           -2.0005804735064707,
           -1.9779859467060674,
           -1.9549597600944126,
           -1.9315091553780914,
           -1.9076415907182989,
           -1.8833647482159221,
           -1.8586865422894134,
           -1.8336151290555323,
           -1.8081589168380061,
           -1.782326577946415,
           -1.7561270618875031,
           -1.7295696101941649,
           -1.7026637730839715,
           -1.6754194281900665,
           -1.6478468016431573,
           -1.6199564918251874,
           -1.591759496164001,
           -1.5632672413952764,
           -1.5344916177845718,
           -1.5054450178803043,
           -1.4761403804599122,
           -1.4465912404387822,
           -1.4168117856376492,
           -1.3868169214524748,
           -1.35662234464528,
           -1.3262446276796573,
           -1.2957013152660435,
           -1.2650110350653665,
           -1.2341936248321244,
           -1.203270278666664,
           -1.1722637154990099,
           -1.141198373450384,
           -1.1101006343196658,
           -1.0789990831235972,
           -1.0479248083792048,
           -1.0169117496424114,
           -0.9859970996796523,
           -0.9552217694946188,
           -0.9246309251640091,
           -0.8942746058954003,
           -0.8642084326538892,
           -0.8344944157213195,
           -0.8052018670667832,
           -0.7764084185664192,
           -0.7482011387131646,
           -0.7206777268835728,
           -0.6939477434236494,
           -0.6681338034071804,
           -0.6433726196239965,
           -0.619815724886712,
           -0.5976296365120741,
           -0.5769951536308955,
           -0.5581054165002001,
           -0.5411623340432979,
           -0.5263710415323061,
           -0.5139322296313852,
           -0.5040325191929363,
           -0.496833527450494,
           -0.49246078831706025,
           -0.4909940809733314,
           -0.49246078831706325,
           -0.4968335274504999,
           -0.5040325191929452,
           -0.5139322296313967,
           -0.5263710415323201,
           -0.5411623340433143,
           -0.5581054165002185,
           -0.5769951536309159,
           -0.5976296365120961,
           -0.6198157248867354,
           -0.6433726196240215,
           -0.6681338034072064,
           -0.6939477434236765,
           -0.7206777268836007,
           -0.7482011387131933,
           -0.7764084185664484,
           -0.8052018670668131,
           -0.8344944157213499,
           -0.86420843265392,
           -0.8942746058954312,
           -0.9246309251640403,
           -0.9552217694946504,
           -0.9859970996796841,
           -1.0169117496424434,
           -1.0479248083792367,
           -1.0789990831236291,
           -1.1101006343196977,
           -1.141198373450416,
           -1.1722637154990416,
           -1.2032702786666958,
           -1.234193624832156,
           -1.2650110350653982,
           -1.2957013152660752,
           -1.3262446276796889,
           -1.3566223446453114,
           -1.3868169214525057,
           -1.41681178563768,
           -1.4465912404388126,
           -1.4761403804599427,
           -1.5054450178803347,
           -1.5344916177846013,
           -1.5632672413953057,
           -1.5917594961640302,
           -1.6199564918252165,
           -1.6478468016431858,
           -1.6754194281900945,
           -1.7026637730839993,
           -1.7295696101941922,
           -1.7561270618875302,
           -1.782326577946442,
           -1.8081589168380325,
           -1.8336151290555582,
           -1.858686542289439,
           -1.8833647482159475,
           -1.9076415907183235,
           -1.9315091553781154,
           -1.9549597600944362,
           -1.9779859467060907,
           -2.000580473506494,
           -2.022736308554318,
           -2.0444466236941556,
           -2.0657047892113547,
           -2.08650436905386,
           -2.106839116561423,
           -2.1267029706492027,
           -2.146090052398595,
           -2.164994662013259,
           -2.1834112761028104,
           -2.201334545260649,
           -2.218759291905906,
           -2.2356805083626115,
           -2.2520933551519375,
           -2.267993159475851,
           -2.2833754138726574,
           -2.2982357750268987,
           -2.3125700627177674,
           -2.326374258891776,
           -2.339644506846791,
           -2.3523771105157896,
           -2.3645685338398197,
           -2.3762154002206266,
           -2.387314492044345,
           -2.3978627502684504,
           -2.407857274064891,
           -2.417295320513038,
           -2.426174304336637,
           -2.434491797679541,
           -2.4422455299155046,
           -2.449433387487745,
           -2.4560534137744625,
           -2.462103808976825,
           -2.46758293002636,
           -2.4724892905089577,
           -2.476821560603058,
           -2.4805785670298444,
           -2.48375929301356,
           -2.486362878250304,
           -2.4883886188839246,
           -2.489835967487842,
           -2.490704533051875
          ],
          [
           -2.5178496248983344,
           -2.5175580057105655,
           -2.5166832276371878,
           -2.5152255291512344,
           -2.5131853077186825,
           -2.510563119815218,
           -2.507359680950482,
           -2.50357586570057,
           -2.499212707749807,
           -2.4942713999430377,
           -2.4887532943499475,
           -2.4826599023431735,
           -2.475992894692248,
           -2.468754101675717,
           -2.4609455132140665,
           -2.4525692790264646,
           -2.4436277088146316,
           -2.434123272477582,
           -2.42405860036139,
           -2.4134364835485673,
           -2.4022598741921644,
           -2.3905318859002316,
           -2.3782557941768725,
           -2.3654350369267942,
           -2.3520732150309325,
           -2.338174093001573,
           -2.3237415997262385,
           -2.308779829310568,
           -2.293293042031524,
           -2.2772856654134217,
           -2.26076229544063,
           -2.243727697922251,
           -2.226186810025763,
           -2.2081447419984346,
           -2.1896067790974065,
           -2.1705783837516512,
           -2.151065197981628,
           -2.1310730461053833,
           -2.1106079377631586,
           -2.0896760712962843,
           -2.06828383752036,
           -2.046437823937492,
           -2.0241448194377543,
           -2.001411819546183,
           -1.978246032278585,
           -1.9546548846773943,
           -1.9306460301078465,
           -1.9062273564051226,
           -1.881406994974917,
           -1.8561933309634797,
           -1.8305950146287349,
           -1.804620974061978,
           -1.7782804294302634,
           -1.751582908933355,
           -1.7245382666965436,
           -1.6971567028523893,
           -1.6694487861012044,
           -1.6414254790827447,
           -1.6130981669411262,
           -1.5844786895226086,
           -1.555579377713,
           -1.5264130944996628,
           -1.4969932814343925,
           -1.4673340112800257,
           -1.4374500477481322,
           -1.407356913380627,
           -1.3770709667980274,
           -1.3466094907354051,
           -1.31599079251819,
           -1.2852343188988167,
           -1.2543607874868004,
           -1.2233923373644309,
           -1.192352701892582,
           -1.1612674071796691,
           -1.1301640002126494,
           -1.0990723112287637,
           -1.0680247555296956,
           -1.0370566805831058,
           -1.0062067648784374,
           -0.9755174755339502,
           -0.9450355919764529,
           -0.9148128029571114,
           -0.884906383458006,
           -0.8553799562895908,
           -0.8263043398113263,
           -0.7977584774362231,
           -0.7698304353450915,
           -0.7426184407887831,
           -0.7162319129076388,
           -0.6907924095135319,
           -0.6664343755430062,
           -0.643305531975513,
           -0.6215666907373779,
           -0.6013907290854216,
           -0.5829604208603348,
           -0.5664648249908523,
           -0.552094003799805,
           -0.5400320144907836,
           -0.53044840004841,
           -0.5234887767065259,
           -0.5192654961488097,
           -0.5178496248983345,
           -0.5192654961488126,
           -0.5234887767065317,
           -0.5304484000484185,
           -0.5400320144907949,
           -0.5520940037998187,
           -0.566464824990868,
           -0.5829604208603529,
           -0.6013907290854414,
           -0.6215666907373995,
           -0.643305531975536,
           -0.6664343755430306,
           -0.6907924095135575,
           -0.7162319129076654,
           -0.7426184407888108,
           -0.7698304353451197,
           -0.797758477436252,
           -0.8263043398113561,
           -0.8553799562896209,
           -0.8849063834580366,
           -0.9148128029571422,
           -0.9450355919764841,
           -0.9755174755339815,
           -1.0062067648784692,
           -1.0370566805831376,
           -1.0680247555297273,
           -1.0990723112287955,
           -1.1301640002126812,
           -1.1612674071797011,
           -1.1923527018926139,
           -1.2233923373644628,
           -1.2543607874868319,
           -1.2852343188988484,
           -1.3159907925182215,
           -1.3466094907354367,
           -1.3770709667980587,
           -1.4073569133806578,
           -1.437450047748163,
           -1.4673340112800564,
           -1.4969932814344231,
           -1.5264130944996932,
           -1.5555793777130302,
           -1.5844786895226384,
           -1.6130981669411553,
           -1.6414254790827738,
           -1.669448786101233,
           -1.6971567028524177,
           -1.7245382666965714,
           -1.7515829089333825,
           -1.778280429430291,
           -1.8046209740620052,
           -1.8305950146287615,
           -1.856193330963506,
           -1.8814069949749426,
           -1.9062273564051477,
           -1.9306460301078714,
           -1.9546548846774183,
           -1.9782460322786088,
           -2.001411819546206,
           -2.0241448194377774,
           -2.0464378239375147,
           -2.068283837520382,
           -2.0896760712963065,
           -2.11060793776318,
           -2.131073046105404,
           -2.1510651979816484,
           -2.1705783837516717,
           -2.189606779097426,
           -2.2081447419984532,
           -2.2261868100257813,
           -2.2437276979222687,
           -2.2607622954406463,
           -2.2772856654134386,
           -2.29329304203154,
           -2.3087798293105837,
           -2.3237415997262536,
           -2.3381740930015877,
           -2.3520732150309467,
           -2.365435036926808,
           -2.378255794176886,
           -2.3905318859002436,
           -2.4022598741921763,
           -2.4134364835485784,
           -2.4240586003614006,
           -2.4341232724775916,
           -2.443627708814641,
           -2.4525692790264744,
           -2.4609455132140745,
           -2.4687541016757244,
           -2.4759928946922556,
           -2.4826599023431806,
           -2.4887532943499533,
           -2.494271399943043,
           -2.499212707749812,
           -2.5035758657005744,
           -2.507359680950486,
           -2.510563119815221,
           -2.5131853077186856,
           -2.515225529151236,
           -2.5166832276371887,
           -2.517558005710566
          ],
          [
           -2.5442041827560367,
           -2.5439105734552343,
           -2.543029826321043,
           -2.5415621836629136,
           -2.539508049346089,
           -2.536867988816251,
           -2.5336427291348538,
           -2.529833159025979,
           -2.5254403289358107,
           -2.5204654511060474,
           -2.514909899662902,
           -2.5087752107235426,
           -2.502063082522209,
           -2.494775375558473,
           -2.486914112770503,
           -2.478481479736529,
           -2.469479824908085,
           -2.4599116598790256,
           -2.4497796596947707,
           -2.439086663206687,
           -2.427835673477097,
           -2.41602985824094,
           -2.4036725504307532,
           -2.390767248772361,
           -2.377317618459391,
           -2.363327491915613,
           -2.3488008696549882,
           -2.333741921250386,
           -2.318154986423052,
           -2.3020445762661588,
           -2.285415374617221,
           -2.2682722395956825,
           -2.250620205323768,
           -2.2324644838506393,
           -2.2138104673020553,
           -2.1946637302802405,
           -2.1750300325413723,
           -2.1549153219811994,
           -2.134325737962804,
           -2.113267615024408,
           -2.0917474870095702,
           -2.0697720916671125,
           -2.0473483757737765,
           -2.0244835008390174,
           -2.001184849458643,
           -1.977460032392259,
           -1.95331689644893,
           -1.9287635332761943,
           -1.9038082891598471,
           -1.8784597759559463,
           -1.8527268832925416,
           -1.8266187921970833,
           -1.8001449903266025,
           -1.773315289002123,
           -1.7461398422767747,
           -1.7186291682994175,
           -1.6907941732729133,
           -1.6626461783493256,
           -1.6341969498542779,
           -1.6054587332905534,
           -1.5764442916381072,
           -1.5471669485454946,
           -1.5176406370980848,
           -1.4878799549533435,
           -1.4579002267552794,
           -1.427717574881499,
           -1.397348999740169,
           -1.3668124710238376,
           -1.3361270315460025,
           -1.3053129155381993,
           -1.2743916835737847,
           -1.2433863766125413,
           -1.2123216920298003,
           -1.1812241849049567,
           -1.1501224982935496,
           -1.119047626685483,
           -1.0880332173414087,
           -1.0571159146683071,
           -1.026335753191851,
           -0.995736604925301,
           -0.9653666868971138,
           -0.9352791340955159,
           -0.9055326418466207,
           -0.8761921792781666,
           -0.84732977150202,
           -0.8190253417656805,
           -0.7913675951702105,
           -0.7644549115450553,
           -0.7383961955410765,
           -0.7133116059352447,
           -0.6893330531328852,
           -0.6666043149125254,
           -0.6452805791771903,
           -0.6255271865131439,
           -0.6075173277982274,
           -0.5914284717398701,
           -0.5774373761732585,
           -0.5657136938318644,
           -0.5564124213720216,
           -0.5496657334453733,
           -0.5455750272374409,
           -0.5442041827560364,
           -0.5455750272374437,
           -0.549665733445379,
           -0.5564124213720298,
           -0.5657136938318754,
           -0.5774373761732717,
           -0.5914284717398856,
           -0.6075173277982451,
           -0.6255271865131633,
           -0.6452805791772114,
           -0.6666043149125479,
           -0.6893330531329093,
           -0.7133116059352699,
           -0.7383961955411029,
           -0.7644549115450824,
           -0.7913675951702384,
           -0.8190253417657094,
           -0.8473297715020495,
           -0.8761921792781965,
           -0.9055326418466512,
           -0.9352791340955466,
           -0.9653666868971449,
           -0.9957366049253322,
           -1.0263357531918824,
           -1.0571159146683389,
           -1.0880332173414402,
           -1.1190476266855147,
           -1.1501224982935816,
           -1.1812241849049887,
           -1.2123216920298323,
           -1.2433863766125728,
           -1.2743916835738165,
           -1.305312915538231,
           -1.336127031546034,
           -1.3668124710238694,
           -1.3973489997402,
           -1.42771757488153,
           -1.4579002267553103,
           -1.4878799549533739,
           -1.5176406370981155,
           -1.5471669485455253,
           -1.5764442916381374,
           -1.605458733290583,
           -1.6341969498543072,
           -1.6626461783493547,
           -1.6907941732729421,
           -1.7186291682994461,
           -1.7461398422768026,
           -1.7733152890021506,
           -1.8001449903266298,
           -1.82661879219711,
           -1.8527268832925685,
           -1.8784597759559727,
           -1.9038082891598729,
           -1.9287635332762196,
           -1.953316896448955,
           -1.9774600323922833,
           -2.001184849458667,
           -2.0244835008390414,
           -2.0473483757737996,
           -2.0697720916671356,
           -2.091747487009592,
           -2.1132676150244296,
           -2.134325737962825,
           -2.1549153219812207,
           -2.1750300325413927,
           -2.1946637302802605,
           -2.2138104673020744,
           -2.2324644838506584,
           -2.250620205323787,
           -2.2682722395957,
           -2.285415374617238,
           -2.3020445762661756,
           -2.318154986423068,
           -2.333741921250402,
           -2.348800869655004,
           -2.363327491915629,
           -2.377317618459405,
           -2.3907672487723732,
           -2.403672550430766,
           -2.4160298582409525,
           -2.427835673477109,
           -2.439086663206698,
           -2.4497796596947814,
           -2.4599116598790363,
           -2.469479824908094,
           -2.4784814797365375,
           -2.4869141127705108,
           -2.4947753755584805,
           -2.5020630825222163,
           -2.508775210723549,
           -2.5149098996629076,
           -2.5204654511060527,
           -2.525440328935816,
           -2.529833159025984,
           -2.5336427291348578,
           -2.5368679888162546,
           -2.5395080493460918,
           -2.5415621836629145,
           -2.5430298263210442,
           -2.543910573455235
          ],
          [
           -2.570032258213792,
           -2.569736738159881,
           -2.5688502600303904,
           -2.567373069928419,
           -2.565305578047175,
           -2.562648358702486,
           -2.5594021503791935,
           -2.5555678557923223,
           -2.5511465419642,
           -2.546139440318935,
           -2.540547946796002,
           -2.534373621984928,
           -2.527618191283446,
           -2.5202835450817593,
           -2.5123717389759657,
           -2.5038849940140393,
           -2.494825696978191,
           -2.4851964007078626,
           -2.4749998244680986,
           -2.464238854368528,
           -2.4529165438387923,
           -2.441036114166836,
           -2.428600955107159,
           -2.415614625566879,
           -2.4020808543782426,
           -2.388003541167136,
           -2.3733867573281087,
           -2.358234747117537,
           -2.342551928877747,
           -2.326342896406244,
           -2.309612420485708,
           -2.2923654505920457,
           -2.274607116799637,
           -2.256342731904985,
           -2.2375777937922483,
           -2.2183179880667456,
           -2.1985691909853706,
           -2.178337472716109,
           -2.1576291009624953,
           -2.1364505449929214,
           -2.1148084801193416,
           -2.09270979267512,
           -2.0701615855476585,
           -2.047171184328103,
           -2.023746144147978,
           -1.9998942572811798,
           -1.9756235615994906,
           -1.9509423499808594,
           -1.9258591807823493,
           -1.9003828895040427,
           -1.874522601786685,
           -1.8482877479046986,
           -1.8216880789377785,
           -1.7947336848290567,
           -1.7674350145662807,
           -1.7398028987551122,
           -1.7118485748913381,
           -1.6835837156820985,
           -1.6550204608162464,
           -1.6261714526416189,
           -1.5970498762735639,
           -1.5676695047359535,
           -1.538044749824659,
           -1.508190719485942,
           -1.4781232826204131,
           -1.4478591423593956,
           -1.417415919017159,
           -1.3868122441021236,
           -1.3560678669754342,
           -1.325203775978697,
           -1.294242336116264,
           -1.2632074456722882,
           -1.2321247144684528,
           -1.201021666821588,
           -1.1699279726338903,
           -1.1388757104281957,
           -1.107899666502784,
           -1.0770376746861063,
           -1.046331001361975,
           -1.0158247804205023,
           -0.9855685024375732,
           -0.9556165615066127,
           -0.9260288614747682,
           -0.8968714805069076,
           -0.8682173884301418,
           -0.8401472045784946,
           -0.8127499741095585,
           -0.7861239271633046,
           -0.7603771669730068,
           -0.7356282095982857,
           -0.7120062695305268,
           -0.6896511536236288,
           -0.6687125945547623,
           -0.6493488315904554,
           -0.6317242421379895,
           -0.6160058573570131,
           -0.6023586749630505,
           -0.590939823420152,
           -0.5818918314172479,
           -0.5753354892630804,
           -0.5713630021406789,
           -0.5700322582137918,
           -0.5713630021406816,
           -0.5753354892630859,
           -0.5818918314172559,
           -0.5909398234201627,
           -0.6023586749630634,
           -0.6160058573570283,
           -0.6317242421380067,
           -0.6493488315904744,
           -0.668712594554783,
           -0.6896511536236511,
           -0.7120062695305505,
           -0.7356282095983104,
           -0.7603771669730328,
           -0.7861239271633315,
           -0.8127499741095864,
           -0.840147204578523,
           -0.868217388430171,
           -0.8968714805069373,
           -0.9260288614747983,
           -0.9556165615066432,
           -0.9855685024376041,
           -1.0158247804205334,
           -1.0463310013620066,
           -1.077037674686138,
           -1.1078996665028158,
           -1.1388757104282274,
           -1.1699279726339225,
           -1.20102166682162,
           -1.232124714468485,
           -1.26320744567232,
           -1.294242336116296,
           -1.3252037759787285,
           -1.3560678669754658,
           -1.3868122441021553,
           -1.41741591901719,
           -1.447859142359427,
           -1.4781232826204442,
           -1.508190719485973,
           -1.5380447498246896,
           -1.5676695047359839,
           -1.597049876273594,
           -1.6261714526416484,
           -1.655020460816276,
           -1.6835837156821276,
           -1.711848574891367,
           -1.7398028987551406,
           -1.7674350145663087,
           -1.794733684829085,
           -1.8216880789378058,
           -1.848287747904726,
           -1.8745226017867116,
           -1.900382889504069,
           -1.9258591807823755,
           -1.9509423499808851,
           -1.9756235615995157,
           -1.9998942572812046,
           -2.023746144148002,
           -2.0471711843281266,
           -2.070161585547682,
           -2.0927097926751426,
           -2.1148084801193643,
           -2.1364505449929436,
           -2.157629100962517,
           -2.17833747271613,
           -2.198569190985391,
           -2.2183179880667656,
           -2.2375777937922674,
           -2.2563427319050042,
           -2.2746071167996558,
           -2.292365450592063,
           -2.3096124204857253,
           -2.3263428964062602,
           -2.342551928877763,
           -2.3582347471175535,
           -2.373386757328124,
           -2.388003541167151,
           -2.402080854378257,
           -2.4156146255668918,
           -2.428600955107172,
           -2.4410361141668484,
           -2.4529165438388048,
           -2.4642388543685394,
           -2.474999824468109,
           -2.485196400707873,
           -2.4948256969782,
           -2.503884994014048,
           -2.512371738975974,
           -2.5202835450817673,
           -2.527618191283453,
           -2.534373621984935,
           -2.540547946796008,
           -2.5461394403189406,
           -2.551146541964205,
           -2.5555678557923267,
           -2.5594021503791975,
           -2.5626483587024897,
           -2.565305578047177,
           -2.5673730699284203,
           -2.568850260030392,
           -2.569736738159882
          ],
          [
           -2.595308864276675,
           -2.595011511091673,
           -2.594119534815882,
           -2.5926331852948787,
           -2.5905528789645222,
           -2.5878791988912653,
           -2.584612894829535,
           -2.5807548832971157,
           -2.5763062476697822,
           -2.571268238296686,
           -2.5656422726383403,
           -2.5594299354293284,
           -2.5526329788682323,
           -2.545253322837602,
           -2.5372930551571846,
           -2.5287544318740243,
           -2.519639877593478,
           -2.509951985855662,
           -2.4996935195623413,
           -2.488867411459828,
           -2.477476764684045,
           -2.4655248533745557,
           -2.453015123365074,
           -2.4399511929587554,
           -2.426336853797397,
           -2.4121760718346383,
           -2.3974729884242927,
           -2.3822319215360506,
           -2.3664573671121047,
           -2.3501540005796238,
           -2.3333266785355655,
           -2.3159804406220523,
           -2.298120511612476,
           -2.2797523037306093,
           -2.2608814192274567,
           -2.2415136532432203,
           -2.2216549969847716,
           -2.2013116412524116,
           -2.1804899803534576,
           -2.159196616444459,
           -2.137438364348643,
           -2.115222256900571,
           -2.092555550876087,
           -2.069445733572518,
           -2.0459005301118802,
           -2.0219279115486675,
           -1.9975361038738002,
           -1.9727335980177012,
           -1.947529160968391,
           -1.921931848135218,
           -1.8959510171056388,
           -1.8695963429616327,
           -1.8428778353442108,
           -1.8158058574795857,
           -1.7883911474091883,
           -1.7606448416986593,
           -1.7325785019386166,
           -1.7042041443933136,
           -1.6755342732030054,
           -1.6465819176029766,
           -1.6173606736878057,
           -1.5878847513248613,
           -1.5581690269076136,
           -1.5282291027387218,
           -1.4980813739467012,
           -1.4677431039701798,
           -1.4372325097922243,
           -1.4065688582758629,
           -1.3757725751425653,
           -1.3448653683493514,
           -1.3138703678580734,
           -1.2828122840515734,
           -1.2517175873331081,
           -1.2206147117417006,
           -1.1895342857160895,
           -1.158509393425588,
           -1.1275758703288428,
           -1.0967726367775528,
           -1.0661420734867282,
           -1.0357304424519282,
           -1.0055883562729906,
           -0.9757712976564308,
           -0.9463401888605888,
           -0.9173620076815238,
           -0.8889104418211431,
           -0.8610665666022372,
           -0.8339195213909587,
           -0.8075671471342598,
           -0.7821165306165028,
           -0.7576843802492857,
           -0.7343971340546438,
           -0.7123906749323897,
           -0.6918095052874825,
           -0.6728052192849756,
           -0.6555341159829494,
           -0.6401538321062754,
           -0.6268189505952749,
           -0.6156756663764523,
           -0.6068557583043898,
           -0.600470302318191,
           -0.5966037229025488,
           -0.595308864276675,
           -0.5966037229025514,
           -0.6004703023181963,
           -0.6068557583043975,
           -0.6156756663764626,
           -0.6268189505952875,
           -0.6401538321062902,
           -0.6555341159829662,
           -0.6728052192849944,
           -0.6918095052875027,
           -0.7123906749324117,
           -0.7343971340546671,
           -0.7576843802493103,
           -0.7821165306165282,
           -0.8075671471342865,
           -0.8339195213909862,
           -0.8610665666022655,
           -0.888910441821172,
           -0.9173620076815534,
           -0.9463401888606188,
           -0.9757712976564611,
           -1.0055883562730215,
           -1.0357304424519593,
           -1.0661420734867595,
           -1.0967726367775843,
           -1.1275758703288743,
           -1.1585093934256196,
           -1.1895342857161215,
           -1.2206147117417323,
           -1.25171758733314,
           -1.2828122840516056,
           -1.3138703678581056,
           -1.3448653683493834,
           -1.375772575142597,
           -1.4065688582758944,
           -1.4372325097922558,
           -1.4677431039702111,
           -1.498081373946732,
           -1.5282291027387527,
           -1.5581690269076445,
           -1.587884751324892,
           -1.6173606736878359,
           -1.6465819176030063,
           -1.6755342732030352,
           -1.7042041443933431,
           -1.7325785019386455,
           -1.7606448416986877,
           -1.7883911474092165,
           -1.8158058574796134,
           -1.8428778353442385,
           -1.8695963429616596,
           -1.8959510171056657,
           -1.921931848135244,
           -1.9475291609684169,
           -1.972733598017727,
           -1.9975361038738253,
           -2.0219279115486923,
           -2.0459005301119046,
           -2.069445733572542,
           -2.0925555508761104,
           -2.1152222569005947,
           -2.137438364348666,
           -2.1591966164444814,
           -2.180489980353479,
           -2.201311641252433,
           -2.221654996984792,
           -2.2415136532432407,
           -2.260881419227477,
           -2.279752303730628,
           -2.2981205116124945,
           -2.3159804406220705,
           -2.333326678535583,
           -2.3501540005796415,
           -2.3664573671121216,
           -2.382231921536066,
           -2.3974729884243082,
           -2.4121760718346534,
           -2.426336853797411,
           -2.439951192958769,
           -2.453015123365087,
           -2.4655248533745677,
           -2.477476764684057,
           -2.488867411459839,
           -2.4996935195623524,
           -2.5099519858556727,
           -2.5196398775934883,
           -2.5287544318740336,
           -2.537293055157193,
           -2.54525332283761,
           -2.55263297886824,
           -2.559429935429335,
           -2.565642272638346,
           -2.5712682382966916,
           -2.5763062476697867,
           -2.5807548832971205,
           -2.584612894829539,
           -2.5878791988912684,
           -2.5905528789645245,
           -2.5926331852948805,
           -2.5941195348158828,
           -2.595011511091673
          ],
          [
           -2.620009547460784,
           -2.619710437085586,
           -2.6188131904664824,
           -2.6173180611324107,
           -2.6152254716632934,
           -2.61253601373807,
           -2.609250448202936,
           -2.605369705160783,
           -2.6008948840831465,
           -2.595827253946261,
           -2.5901682533931565,
           -2.583919490924056,
           -2.5770827451176928,
           -2.5696599648865432,
           -2.5616532697693524,
           -2.5530649502647753,
           -2.5438974682103987,
           -2.5341534572118976,
           -2.523835723127621,
           -2.512947244614465,
           -2.5014911737415235,
           -2.4894708366786755,
           -2.4768897344680356,
           -2.463751543886976,
           -2.4500601184123565,
           -2.4358194892965517,
           -2.421033866766982,
           -2.405707641362017,
           -2.3898453854174666,
           -2.3734518547193395,
           -2.3565319903401596,
           -2.339090920677945,
           -2.3211339637189825,
           -2.302666629547713,
           -2.283694623129614,
           -2.264223847395684,
           -2.2442604066603016,
           -2.2238106104076847,
           -2.202880977486129,
           -2.1814782407535644,
           -2.159609352222938,
           -2.137281488761473,
           -2.114502058404146,
           -2.091278707348763,
           -2.0676193277080546,
           -2.043532066103194,
           -2.0190253331934285,
           -1.994107814248089,
           -1.9687884808804172,
           -1.9430766040776413,
           -1.9169817686787303,
           -1.890513889470665,
           -1.8636832290961458,
           -1.8365004179908908,
           -1.808976476597428,
           -1.7811228401352057,
           -1.752951386244396,
           -1.7244744658637976,
           -1.6957049377523863,
           -1.6666562071203432,
           -1.6373422688997186,
           -1.6077777562584203,
           -1.5779779950452009,
           -1.5479590649490367,
           -1.5177378682652485,
           -1.4873322072842632,
           -1.456760871458602,
           -1.4260437356606683,
           -1.3952018710192151,
           -1.3642576700163167,
           -1.3332349877385257,
           -1.3021593014034785,
           -1.2710578905216998,
           -1.23996004029444,
           -1.208897271078296,
           -1.177903596944786,
           -1.147015816495674,
           -1.1162738391153773,
           -1.0857210496820506,
           -1.0554047143229082,
           -1.025376428954036,
           -0.9956926109103215,
           -0.9664150317088019,
           -0.9376113855926866,
           -0.9093558835951673,
           -0.8817298559994922,
           -0.8548223367798037,
           -0.828730591451862,
           -0.8035605344885087,
           -0.779426964214625,
           -0.756453522796304,
           -0.7347722686944677,
           -0.714522732597071,
           -0.6958503213179472,
           -0.6789039454581123,
           -0.6638327848795629,
           -0.6507821791120075,
           -0.6398887404007706,
           -0.6312749279024634,
           -0.6250434714217471,
           -0.6212721573940321,
           -0.620009547460784,
           -0.6212721573940347,
           -0.6250434714217521,
           -0.6312749279024712,
           -0.6398887404007808,
           -0.6507821791120201,
           -0.6638327848795774,
           -0.6789039454581287,
           -0.6958503213179656,
           -0.7145227325970909,
           -0.7347722686944892,
           -0.756453522796327,
           -0.7794269642146493,
           -0.8035605344885342,
           -0.8287305914518882,
           -0.8548223367798309,
           -0.88172985599952,
           -0.909355883595196,
           -0.937611385592716,
           -0.9664150317088319,
           -0.9956926109103517,
           -1.0253764289540666,
           -1.0554047143229388,
           -1.085721049682082,
           -1.116273839115409,
           -1.1470158164957058,
           -1.177903596944818,
           -1.208897271078328,
           -1.2399600402944717,
           -1.2710578905217316,
           -1.3021593014035102,
           -1.3332349877385579,
           -1.3642576700163485,
           -1.3952018710192466,
           -1.4260437356606999,
           -1.4567608714586338,
           -1.4873322072842947,
           -1.5177378682652798,
           -1.5479590649490678,
           -1.5779779950452317,
           -1.6077777562584512,
           -1.6373422688997488,
           -1.6666562071203732,
           -1.6957049377524158,
           -1.7244744658638274,
           -1.752951386244425,
           -1.7811228401352341,
           -1.8089764765974565,
           -1.8365004179909186,
           -1.8636832290961736,
           -1.8905138894706925,
           -1.9169817686787574,
           -1.9430766040776677,
           -1.9687884808804432,
           -1.9941078142481148,
           -2.019025333193454,
           -2.043532066103218,
           -2.0676193277080785,
           -2.091278707348787,
           -2.114502058404169,
           -2.1372814887614964,
           -2.1596093522229607,
           -2.181478240753587,
           -2.2028809774861506,
           -2.2238106104077064,
           -2.2442604066603224,
           -2.2642238473957046,
           -2.283694623129634,
           -2.3026666295477325,
           -2.321133963719001,
           -2.3390909206779633,
           -2.3565319903401765,
           -2.373451854719357,
           -2.389845385417483,
           -2.405707641362033,
           -2.4210338667669977,
           -2.4358194892965663,
           -2.4500601184123707,
           -2.46375154388699,
           -2.476889734468049,
           -2.4894708366786884,
           -2.501491173741535,
           -2.5129472446144767,
           -2.5238357231276316,
           -2.534153457211908,
           -2.543897468210409,
           -2.5530649502647846,
           -2.5616532697693604,
           -2.5696599648865512,
           -2.5770827451177,
           -2.5839194909240626,
           -2.590168253393163,
           -2.595827253946267,
           -2.6008948840831514,
           -2.6053697051607876,
           -2.60925044820294,
           -2.6125360137380733,
           -2.6152254716632966,
           -2.6173180611324125,
           -2.6188131904664833,
           -2.619710437085587
          ],
          [
           -2.6441104114504066,
           -2.643809618202594,
           -2.642907324170722,
           -2.64140378650046,
           -2.639299433804676,
           -2.636594866219067,
           -2.6332908554810994,
           -2.629388345033296,
           -2.6248884501522336,
           -2.61979245810495,
           -2.614101828334783,
           -2.6078181926790203,
           -2.6009433556211086,
           -2.5934792945805745,
           -2.5854281602442013,
           -2.5767922769424834,
           -2.567574143075824,
           -2.5577764315954887,
           -2.547401990544846,
           -2.5364538436670654,
           -2.5249351910860613,
           -2.512849410068213,
           -2.5002000558731345,
           -2.486990862702666,
           -2.47322574475813,
           -2.458908797416987,
           -2.444044298541096,
           -2.428636709930079,
           -2.412690678934625,
           -2.3962110402461305,
           -2.3792028178807243,
           -2.361671227377627,
           -2.3436216782338612,
           -2.3250597765996597,
           -2.305991328261478,
           -2.2864223419424285,
           -2.2663590329531496,
           -2.2458078272297355,
           -2.224775365799382,
           -2.203268509718927,
           -2.1812943455365392,
           -2.1588601913325287,
           -2.1359736034016477,
           -2.1126423836465253,
           -2.088874587760006,
           -2.0646785342834044,
           -2.040062814638087,
           -2.015036304239604,
           -1.9896081748169303,
           -1.9637879080745275,
           -1.9375853108521268,
           -1.9110105319566564,
           -1.884074080862923,
           -1.8567868485049217,
           -1.829160130408378,
           -1.8012056524478608,
           -1.772935599549101,
           -1.7443626476996297,
           -1.7154999996792557,
           -1.686361424977036,
           -1.6569613044241187,
           -1.6273146801431861,
           -1.5974373114961793,
           -1.5673457378037008,
           -1.5370573487130712,
           -1.5065904632085216,
           -1.4759644183874163,
           -1.4451996692713667,
           -1.414317901080781,
           -1.3833421555752237,
           -1.352296973248059,
           -1.3212085533584876,
           -1.290104933980862,
           -1.2590161944396059,
           -1.2279746826621518,
           -1.1970152700980765,
           -1.1661756368851814,
           -1.1354965898428782,
           -1.1050224155702295,
           -1.0748012703245151,
           -1.0448856073269717,
           -1.0153326405146312,
           -0.9862048413112727,
           -0.9575704614530354,
           -0.929504069950139,
           -0.9020870855342477,
           -0.8754082770735037,
           -0.8495641931575928,
           -0.8246594683025682,
           -0.8008069373635798,
           -0.7781274728549046,
           -0.7567494441200319,
           -0.7368076862626092,
           -0.71844186566252,
           -0.7017941443773256,
           -0.6870060847757167,
           -0.6742148036838882,
           -0.6635484826277284,
           -0.6551214595327159,
           -0.6490292488971532,
           -0.6453439337118627,
           -0.6441104114504065,
           -0.6453439337118652,
           -0.6490292488971582,
           -0.6551214595327234,
           -0.6635484826277382,
           -0.6742148036839004,
           -0.6870060847757309,
           -0.7017941443773417,
           -0.7184418656625381,
           -0.7368076862626287,
           -0.7567494441200531,
           -0.7781274728549272,
           -0.8008069373636038,
           -0.8246594683025931,
           -0.8495641931576189,
           -0.8754082770735305,
           -0.9020870855342754,
           -0.9295040699501675,
           -0.9575704614530645,
           -0.9862048413113024,
           -1.0153326405146612,
           -1.044885607327002,
           -1.0748012703245458,
           -1.1050224155702606,
           -1.1354965898429097,
           -1.166175636885213,
           -1.1970152700981083,
           -1.2279746826621836,
           -1.2590161944396379,
           -1.2901049339808943,
           -1.3212085533585196,
           -1.352296973248091,
           -1.3833421555752554,
           -1.414317901080813,
           -1.4451996692713984,
           -1.4759644183874479,
           -1.5065904632085527,
           -1.5370573487131025,
           -1.5673457378037314,
           -1.5974373114962097,
           -1.6273146801432163,
           -1.656961304424149,
           -1.6863614249770662,
           -1.7154999996792855,
           -1.7443626476996588,
           -1.7729355995491303,
           -1.8012056524478897,
           -1.829160130408407,
           -1.85678684850495,
           -1.884074080862951,
           -1.9110105319566837,
           -1.937585310852154,
           -1.9637879080745542,
           -1.9896081748169567,
           -2.01503630423963,
           -2.040062814638113,
           -2.0646785342834293,
           -2.088874587760031,
           -2.1126423836465493,
           -2.1359736034016716,
           -2.1588601913325522,
           -2.181294345536562,
           -2.203268509718949,
           -2.2247753657994043,
           -2.245807827229757,
           -2.2663590329531704,
           -2.2864223419424485,
           -2.3059913282614977,
           -2.325059776599679,
           -2.34362167823388,
           -2.3616712273776446,
           -2.379202817880742,
           -2.396211040246148,
           -2.4126906789346414,
           -2.428636709930095,
           -2.444044298541112,
           -2.4589087974170023,
           -2.473225744758145,
           -2.48699086270268,
           -2.500200055873148,
           -2.5128494100682253,
           -2.524935191086074,
           -2.5364538436670765,
           -2.547401990544857,
           -2.557776431595499,
           -2.567574143075834,
           -2.5767922769424922,
           -2.5854281602442097,
           -2.5934792945805825,
           -2.6009433556211166,
           -2.607818192679027,
           -2.6141018283347894,
           -2.6197924581049556,
           -2.6248884501522385,
           -2.6293883450333,
           -2.6332908554811034,
           -2.6365948662190704,
           -2.6392994338046782,
           -2.6414037865004616,
           -2.642907324170723,
           -2.643809618202595
          ],
          [
           -2.667588140216162,
           -2.6672857368485547,
           -2.6663786136378094,
           -2.664867031272626,
           -2.6627514242758767,
           -2.66003240106771,
           -2.65671074405499,
           -2.6527874097481696,
           -2.6482635289070213,
           -2.643140406717019,
           -2.63741952299846,
           -2.631102532450843,
           -2.624191264935373,
           -2.6166877257988816,
           -2.608594096242887,
           -2.5999127337419834,
           -2.590646172516252,
           -2.5807971240629097,
           -2.570368477753002,
           -2.5593633014995727,
           -2.547784842504403,
           -2.5356365280911977,
           -2.522921966633839,
           -2.509644948589291,
           -2.495809447645631,
           -2.48141962199681,
           -2.466479815756877,
           -2.450994560527712,
           -2.4349685771357414,
           -2.418406777554666,
           -2.401314267032999,
           -2.3836963464471452,
           -2.365558514902885,
           -2.3469064726105415,
           -2.3277461240617443,
           -2.3080835815387015,
           -2.287925168990165,
           -2.2672774263120083,
           -2.246147114074446,
           -2.224541218742574,
           -2.202466958442109,
           -2.179931789328013,
           -2.156943412620291,
           -2.133509782378559,
           -2.10963911409535,
           -2.085339894197437,
           -2.0606208905550343,
           -2.035491164110673,
           -2.009960081753017,
           -1.9840373305761645,
           -1.9577329336822402,
           -1.9310572677046822,
           -1.9040210822518095,
           -1.8766355214954635,
           -1.848912148158079,
           -1.8208629701840067,
           -1.7925004704177252,
           -1.763837639653415,
           -1.7348880134677684,
           -1.705665713301724,
           -1.6761854923176942,
           -1.6464627866277184,
           -1.6165137725656553,
           -1.5863554307639207,
           -1.5560056178931816,
           -1.5254831470325958,
           -1.494807877759088,
           -1.4640008171769152,
           -1.4330842332528457,
           -1.4020817819762184,
           -1.3710186500240198,
           -1.3399217147740112,
           -1.3088197236658732,
           -1.2777434950492594,
           -1.2467261427606005,
           -1.2158033267116366,
           -1.1850135317152997,
           -1.154398376567626,
           -1.1240029549780628,
           -1.0938762092008423,
           -1.0640713360432101,
           -1.0346462231526183,
           -1.0056639109147627,
           -0.977193071686902,
           -0.9493084931716274,
           -0.9220915462176549,
           -0.8956306089596645,
           -0.8700214088319494,
           -0.8453672317003136,
           -0.8217789336652918,
           -0.799374677175816,
           -0.7782793010775473,
           -0.7586232274053906,
           -0.740540810651319,
           -0.7241680533279444,
           -0.7096396502464939,
           -0.6970853864837099,
           -0.686625999577632,
           -0.678368717155658,
           -0.6724027807156268,
           -0.6687953414785864,
           -0.6675881402161622,
           -0.668795341478589,
           -0.6724027807156318,
           -0.6783687171556656,
           -0.6866259995776417,
           -0.6970853864837216,
           -0.7096396502465077,
           -0.7241680533279602,
           -0.7405408106513367,
           -0.75862322740541,
           -0.7782793010775682,
           -0.7993746771758383,
           -0.8217789336653154,
           -0.8453672317003383,
           -0.8700214088319751,
           -0.8956306089596913,
           -0.9220915462176824,
           -0.9493084931716559,
           -0.9771930716869309,
           -1.0056639109147922,
           -1.0346462231526483,
           -1.0640713360432406,
           -1.0938762092008731,
           -1.1240029549780939,
           -1.1543983765676573,
           -1.185013531715331,
           -1.2158033267116684,
           -1.2467261427606322,
           -1.2777434950492914,
           -1.308819723665905,
           -1.3399217147740428,
           -1.371018650024052,
           -1.40208178197625,
           -1.4330842332528775,
           -1.4640008171769472,
           -1.49480787775912,
           -1.5254831470326276,
           -1.5560056178932131,
           -1.5863554307639518,
           -1.6165137725656864,
           -1.6464627866277497,
           -1.6761854923177248,
           -1.7056657133017539,
           -1.7348880134677982,
           -1.7638376396534448,
           -1.7925004704177547,
           -1.8208629701840353,
           -1.8489121481581077,
           -1.8766355214954917,
           -1.9040210822518377,
           -1.93105726770471,
           -1.9577329336822673,
           -1.9840373305761911,
           -2.009960081753043,
           -2.0354911641106983,
           -2.0606208905550596,
           -2.085339894197462,
           -2.109639114095375,
           -2.1335097823785834,
           -2.156943412620315,
           -2.1799317893280366,
           -2.2024669584421317,
           -2.224541218742597,
           -2.2461471140744678,
           -2.26727742631203,
           -2.2879251689901863,
           -2.308083581538722,
           -2.3277461240617647,
           -2.346906472610561,
           -2.365558514902904,
           -2.383696346447163,
           -2.4013142670330163,
           -2.418406777554683,
           -2.4349685771357588,
           -2.450994560527728,
           -2.4664798157568923,
           -2.4814196219968254,
           -2.495809447645646,
           -2.5096449485893046,
           -2.5229219666338523,
           -2.53563652809121,
           -2.547784842504416,
           -2.5593633014995842,
           -2.570368477753013,
           -2.5807971240629195,
           -2.5906461725162617,
           -2.599912733741993,
           -2.6085940962428955,
           -2.6166877257988896,
           -2.6241912649353805,
           -2.6311025324508495,
           -2.6374195229984663,
           -2.643140406717025,
           -2.648263528907027,
           -2.6527874097481736,
           -2.656710744054994,
           -2.660032401067713,
           -2.662751424275879,
           -2.6648670312726273,
           -2.6663786136378107,
           -2.6672857368485547
          ],
          [
           -2.6904200205717554,
           -2.6901160783314664,
           -2.689204339656411,
           -2.6876850686979488,
           -2.6855587057549006,
           -2.682825867343961,
           -2.6794873462994064,
           -2.675544111903253,
           -2.6709973100473654,
           -2.665848263429347,
           -2.660098471784443,
           -2.6537496121560316,
           -2.6468035392077356,
           -2.639262285580561,
           -2.631128062298944,
           -2.6224032592301,
           -2.6130904456015203,
           -2.603192370582098,
           -2.5927119639328935,
           -2.581652336734252,
           -2.5700167821966664,
           -2.557808776563556,
           -2.545031980114961,
           -2.5316902382820787,
           -2.5177875828835683,
           -2.503328233495653,
           -2.488316598969249,
           -2.4727572791087082,
           -2.456655066528211,
           -2.440014948703482,
           -2.4228421102383084,
           -2.4051419353673107,
           -2.3869200107186574,
           -2.368182128362851,
           -2.348934289176448,
           -2.3291827065526256,
           -2.308933810493901,
           -2.288194252126071,
           -2.266970908676715,
           -2.2452708889662842,
           -2.2231015394651408,
           -2.2004704509758293,
           -2.177385466006527,
           -2.153854686909117,
           -2.1298864848637415,
           -2.105489509801158,
           -2.0806727013649007,
           -2.0554453010272726,
           -2.0298168654867705,
           -2.003797281489855,
           -1.9773967822373035,
           -1.9506259655549372,
           -1.9234958140306515,
           -1.8960177173447075,
           -1.8682034970485624,
           -1.8400654340795766,
           -1.811616299335169,
           -1.7828693876709947,
           -1.7538385557340228,
           -1.7245382640936426,
           -1.6949836241928133,
           -1.6651904507074546,
           -1.6351753199764631,
           -1.604955635247606,
           -1.5745496995766084,
           -1.5439767973184355,
           -1.5132572852610897,
           -1.4824126945728424,
           -1.4514658448624882,
           -1.4204409717867281,
           -1.389363869775362,
           -1.358262051577516,
           -1.3271649264515422,
           -1.296103998913998,
           -1.265113090009934,
           -1.2342285830403121,
           -1.2034896955450518,
           -1.1729387790404526,
           -1.1426216474786495,
           -1.1125879345434728,
           -1.0828914786044057,
           -1.053590732270879,
           -1.024749190843386,
           -0.9964358303367237,
           -0.968725540926198,
           -0.9416995354175602,
           -0.9154457044953312,
           -0.8900588810200176,
           -0.8656409647259535,
           -0.842300846928821,
           -0.8201540635035117,
           -0.7993220954719585,
           -0.7799312330393903,
           -0.7621109247474102,
           -0.7459915530081082,
           -0.7317016146770365,
           -0.7193643426037595,
           -0.7090938794290086,
           -0.700991200656415,
           -0.6951400660821866,
           -0.6916033379055933,
           -0.6904200205717552,
           -0.6916033379055957,
           -0.6951400660821914,
           -0.7009912006564223,
           -0.709093879429018,
           -0.7193643426037712,
           -0.7317016146770501,
           -0.7459915530081238,
           -0.7621109247474276,
           -0.7799312330394094,
           -0.7993220954719791,
           -0.820154063503534,
           -0.8423008469288444,
           -0.8656409647259781,
           -0.8900588810200432,
           -0.9154457044953577,
           -0.9416995354175876,
           -0.9687255409262262,
           -0.9964358303367525,
           -1.0247491908434154,
           -1.0535907322709088,
           -1.082891478604436,
           -1.1125879345435037,
           -1.1426216474786806,
           -1.172938779040484,
           -1.2034896955450833,
           -1.2342285830403439,
           -1.2651130900099659,
           -1.29610399891403,
           -1.327164926451574,
           -1.3582620515775479,
           -1.389363869775394,
           -1.4204409717867599,
           -1.45146584486252,
           -1.4824126945728742,
           -1.5132572852611212,
           -1.5439767973184668,
           -1.5745496995766397,
           -1.6049556352476368,
           -1.6351753199764945,
           -1.6651904507074855,
           -1.694983624192844,
           -1.7245382640936726,
           -1.753838555734053,
           -1.7828693876710247,
           -1.811616299335198,
           -1.8400654340796057,
           -1.868203497048591,
           -1.8960177173447357,
           -1.92349581403068,
           -1.9506259655549647,
           -1.9773967822373306,
           -2.003797281489882,
           -2.0298168654867967,
           -2.055445301027299,
           -2.0806727013649264,
           -2.1054895098011834,
           -2.1298864848637664,
           -2.153854686909141,
           -2.177385466006551,
           -2.200470450975853,
           -2.223101539465164,
           -2.2452708889663064,
           -2.266970908676737,
           -2.2881942521260923,
           -2.308933810493922,
           -2.3291827065526465,
           -2.3489342891764675,
           -2.368182128362871,
           -2.386920010718677,
           -2.405141935367329,
           -2.4228421102383266,
           -2.4400149487035,
           -2.456655066528228,
           -2.472757279108725,
           -2.488316598969265,
           -2.503328233495669,
           -2.517787582883583,
           -2.5316902382820925,
           -2.5450319801149752,
           -2.557808776563569,
           -2.570016782196679,
           -2.581652336734263,
           -2.5927119639329046,
           -2.6031923705821085,
           -2.6130904456015305,
           -2.622403259230109,
           -2.631128062298953,
           -2.639262285580569,
           -2.646803539207743,
           -2.653749612156038,
           -2.6600984717844494,
           -2.665848263429353,
           -2.6709973100473703,
           -2.6755441119032572,
           -2.6794873462994104,
           -2.6828258673439644,
           -2.6855587057549037,
           -2.687685068697951,
           -2.689204339656413,
           -2.690116078331467
          ],
          [
           -2.712583964147515,
           -2.7122785528353126,
           -2.7113624080693883,
           -2.7098357973771328,
           -2.7076991666888173,
           -2.704953140415128,
           -2.701598521556883,
           -2.6976362918481525,
           -2.6930676119343073,
           -2.687893821586945,
           -2.6821164399579693,
           -2.675737165875537,
           -2.6687578781849943,
           -2.661180636138355,
           -2.653007679836369,
           -2.6442414307277065,
           -2.6348844921703383,
           -2.6249396500607554,
           -2.614409873537307,
           -2.6032983157646,
           -2.5916083148066336,
           -2.5793433945971462,
           -2.5665072660165014,
           -2.553103828085402,
           -2.5391371692867533,
           -2.524611569028112,
           -2.5095314992584474,
           -2.493901626254272,
           -2.4777268125917398,
           -2.4610121193229757,
           -2.443762808376742,
           -2.4259843452056,
           -2.407682401704003,
           -2.3888628594242403,
           -2.369531813119992,
           -2.349695574650329,
           -2.329360677280479,
           -2.3085338804195294,
           -2.2872221748395627,
           -2.265432788425507,
           -2.243173192510413,
           -2.220451108856857,
           -2.197274517351954,
           -2.173651664491022,
           -2.149591072733464,
           -2.125101550823975,
           -2.100192205182928,
           -2.0748724524819013,
           -2.049152033533887,
           -2.0230410286431004,
           -1.9965498745765538,
           -1.969689383339091,
           -1.9424707629555322,
           -1.914905640488407,
           -1.8870060875477117,
           -1.8587846485806938,
           -1.8302543722652107,
           -1.8014288463702852,
           -1.7723222364925042,
           -1.7429493291275338,
           -1.7133255795927218,
           -1.6834671653801343,
           -1.6533910455899459,
           -1.6231150271723085,
           -1.5926578387919776,
           -1.562039213224116,
           -1.5312799792915224,
           -1.5004021644621384,
           -1.4694291093393483,
           -1.438385595393403,
           -1.4072979873956142,
           -1.3761943921208992,
           -1.3451048349685704,
           -1.3140614562014854,
           -1.2830987284993671,
           -1.2522536974351668,
           -1.2215662462755805,
           -1.1910793861270756,
           -1.1608395718298299,
           -1.1308970430569287,
           -1.1013061886952562,
           -1.0721259306329283,
           -1.043420120396191,
           -1.0152579384870861,
           -0.9877142815861916,
           -0.9608701168371648,
           -0.9348127751231802,
           -0.9096361466210859,
           -0.8854407322642617,
           -0.862333494731557,
           -0.8404274434255248,
           -0.8198408815237308,
           -0.8006962422699059,
           -0.7831184495725202,
           -0.7672327583036139,
           -0.7531620654494517,
           -0.7410237355636886,
           -0.730926050447727,
           -0.7229644664600547,
           -0.7172179310492722,
           -0.7137455571420509,
           -0.7125839641475152,
           -0.7137455571420531,
           -0.717217931049277,
           -0.7229644664600617,
           -0.7309260504477363,
           -0.7410237355637002,
           -0.7531620654494652,
           -0.7672327583036292,
           -0.7831184495725375,
           -0.8006962422699248,
           -0.8198408815237513,
           -0.8404274434255468,
           -0.8623334947315803,
           -0.8854407322642861,
           -0.9096361466211113,
           -0.9348127751232065,
           -0.9608701168371921,
           -0.9877142815862195,
           -1.0152579384871148,
           -1.0434201203962203,
           -1.072125930632958,
           -1.1013061886952864,
           -1.1308970430569594,
           -1.1608395718298608,
           -1.191079386127107,
           -1.2215662462756118,
           -1.2522536974351983,
           -1.2830987284993989,
           -1.3140614562015174,
           -1.3451048349686021,
           -1.3761943921209312,
           -1.4072979873956464,
           -1.4383855953934348,
           -1.46942910933938,
           -1.5004021644621701,
           -1.5312799792915543,
           -1.5620392132241476,
           -1.592657838792009,
           -1.6231150271723398,
           -1.6533910455899772,
           -1.6834671653801656,
           -1.7133255795927522,
           -1.742949329127564,
           -1.7723222364925342,
           -1.8014288463703152,
           -1.8302543722652402,
           -1.8587846485807227,
           -1.8870060875477408,
           -1.9149056404884355,
           -1.9424707629555602,
           -1.9696893833391187,
           -1.9965498745765813,
           -2.0230410286431275,
           -2.0491520335339137,
           -2.074872452481927,
           -2.1001922051829536,
           -2.1251015508239997,
           -2.149591072733489,
           -2.173651664491046,
           -2.197274517351978,
           -2.2204511088568806,
           -2.243173192510436,
           -2.2654327884255303,
           -2.287222174839585,
           -2.3085338804195517,
           -2.3293606772805004,
           -2.34969557465035,
           -2.3695318131200125,
           -2.38886285942426,
           -2.407682401704022,
           -2.4259843452056185,
           -2.4437628083767597,
           -2.461012119322994,
           -2.477726812591757,
           -2.493901626254288,
           -2.509531499258463,
           -2.5246115690281266,
           -2.539137169286768,
           -2.5531038280854164,
           -2.5665072660165142,
           -2.579343394597159,
           -2.591608314806646,
           -2.603298315764611,
           -2.6144098735373182,
           -2.6249396500607656,
           -2.634884492170348,
           -2.6442414307277162,
           -2.6530076798363775,
           -2.661180636138363,
           -2.668757878185002,
           -2.675737165875544,
           -2.6821164399579756,
           -2.687893821586951,
           -2.693067611934312,
           -2.6976362918481573,
           -2.7015985215568876,
           -2.7049531404151312,
           -2.7076991666888195,
           -2.709835797377134,
           -2.7113624080693897,
           -2.712278552835313
          ],
          [
           -2.7340585287594683,
           -2.733751716789256,
           -2.7328313711433596,
           -2.7312977626327033,
           -2.729151342664725,
           -2.7263927433278123,
           -2.7230227775107645,
           -2.7190424390584873,
           -2.714452902965549,
           -2.709255525609578,
           -2.703451845026894,
           -2.697043581233163,
           -2.6900326365923175,
           -2.6824210962374297,
           -2.6742112285477218,
           -2.665405485686401,
           -2.6560065042045804,
           -2.646017105717128,
           -2.6354402976569475,
           -2.6242792741148535,
           -2.6125374167730024,
           -2.6002182959406275,
           -2.587325671701719,
           -2.5738634951852895,
           -2.5598359099698915,
           -2.5452472536352677,
           -2.530102059475248,
           -2.514405058387456,
           -2.498161180956926,
           -2.4813755597524425,
           -2.464053531856312,
           -2.446200641650373,
           -2.4278226438833554,
           -2.4089255070473015,
           -2.389515417093568,
           -2.3695987815221433,
           -2.3491822338815247,
           -2.328272638720321,
           -2.3068770970361383,
           -2.2850029522721913,
           -2.262657796917544,
           -2.239849479772967,
           -2.216586113951273,
           -2.192876085688575,
           -2.1687280640515523,
           -2.1441510116353637,
           -2.1191541963576843,
           -2.0937472044664247,
           -2.0679399548923376,
           -2.0417427150930085,
           -2.0151661185519467,
           -1.9882211841158741,
           -1.9609193373750684,
           -1.933272434316158,
           -1.9052927875042935,
           -1.876993195082621,
           -1.848386972911759,
           -1.8194879902109977,
           -1.7903107091066628,
           -1.7608702285419118,
           -1.7311823330566942,
           -1.7012635470070765,
           -1.6711311948600025,
           -1.6408034682730814,
           -1.6102995007492136,
           -1.5796394507425617,
           -1.5488445941848488,
           -1.5179374274979212,
           -1.4869417822577164,
           -1.4558829527726767,
           -1.424787837931024,
           -1.3936850987483829,
           -1.3626053330991004,
           -1.33158126912583,
           -1.3006479787715182,
           -1.269843112737149,
           -1.2392071578993527,
           -1.2087837177739797,
           -1.1786198159200594,
           -1.148766221160822,
           -1.119277792052754,
           -1.090213836037645,
           -1.0616384760256627,
           -1.0336210136276904,
           -1.006236273734568,
           -0.9795649095133225,
           -0.9536936401170545,
           -0.9287153855924658,
           -0.9047292549637526,
           -0.8818403349785432,
           -0.8601592197121867,
           -0.8398012169243184,
           -0.8208851681452504,
           -0.8035318288087878,
           -0.7878617752662991,
           -0.7739928394271197,
           -0.7620371194740723,
           -0.7520976739481566,
           -0.7442650698269309,
           -0.7386140123377072,
           -0.7352003218706407,
           -0.7340585287594683,
           -0.7352003218706431,
           -0.738614012337712,
           -0.7442650698269379,
           -0.7520976739481658,
           -0.7620371194740835,
           -0.7739928394271329,
           -0.7878617752663142,
           -0.8035318288088047,
           -0.820885168145269,
           -0.8398012169243386,
           -0.8601592197122082,
           -0.881840334978566,
           -0.9047292549637769,
           -0.9287153855924908,
           -0.9536936401170804,
           -0.9795649095133495,
           -1.0062362737345956,
           -1.033621013627719,
           -1.0616384760256918,
           -1.0902138360376745,
           -1.119277792052784,
           -1.1487662211608527,
           -1.1786198159200902,
           -1.208783717774011,
           -1.239207157899384,
           -1.2698431127371805,
           -1.30064797877155,
           -1.3315812691258617,
           -1.3626053330991323,
           -1.3936850987484146,
           -1.4247878379310557,
           -1.455882952772709,
           -1.4869417822577484,
           -1.5179374274979531,
           -1.5488445941848805,
           -1.5796394507425935,
           -1.610299500749245,
           -1.6408034682731127,
           -1.6711311948600336,
           -1.7012635470071076,
           -1.7311823330567246,
           -1.7608702285419424,
           -1.7903107091066928,
           -1.8194879902110275,
           -1.8483869729117883,
           -1.8769931950826504,
           -1.9052927875043224,
           -1.9332724343161862,
           -1.9609193373750966,
           -1.988221184115902,
           -2.0151661185519743,
           -2.0417427150930356,
           -2.0679399548923643,
           -2.093747204466451,
           -2.11915419635771,
           -2.144151011635389,
           -2.168728064051577,
           -2.1928760856886,
           -2.216586113951297,
           -2.2398494797729906,
           -2.262657796917567,
           -2.2850029522722144,
           -2.30687709703616,
           -2.3282726387203425,
           -2.3491822338815456,
           -2.3695987815221633,
           -2.389515417093588,
           -2.4089255070473214,
           -2.4278226438833754,
           -2.4462006416503916,
           -2.464053531856331,
           -2.4813755597524607,
           -2.4981611809569437,
           -2.514405058387472,
           -2.5301020594752637,
           -2.5452472536352833,
           -2.5598359099699057,
           -2.573863495185303,
           -2.5873256717017328,
           -2.600218295940641,
           -2.612537416773015,
           -2.6242792741148646,
           -2.6354402976569586,
           -2.6460171057171387,
           -2.6560065042045897,
           -2.6654054856864104,
           -2.6742112285477306,
           -2.682421096237438,
           -2.6900326365923246,
           -2.6970435812331703,
           -2.7034518450269003,
           -2.709255525609584,
           -2.714452902965554,
           -2.7190424390584913,
           -2.723022777510768,
           -2.7263927433278154,
           -2.729151342664727,
           -2.731297762632705,
           -2.732831371143361,
           -2.7337517167892575
          ],
          [
           -2.7548229391532653,
           -2.754514793611544,
           -2.7535904483125244,
           -2.752050177252688,
           -2.7498944371531833,
           -2.7471238675509713,
           -2.7437392909277083,
           -2.739741712877633,
           -2.7351323223161295,
           -2.72991249173102,
           -2.7240837774790516,
           -2.7176479201304713,
           -2.7106068448650293,
           -2.702962661923226,
           -2.6947176671171085,
           -2.685874342405494,
           -2.6764353565390016,
           -2.6664035657809695,
           -2.6557820147109354,
           -2.6445739371180843,
           -2.6327827569928743,
           -2.620412089625853,
           -2.607465742823609,
           -2.593947718252807,
           -2.579862212924343,
           -2.56521362083085,
           -2.5500065347521037,
           -2.534245748244325,
           -2.517936257830945,
           -2.501083265414188,
           -2.4836921809287142,
           -2.4657686252607434,
           -2.447318433458415,
           -2.4283476582617816,
           -2.4088625739837073,
           -2.3888696807762115,
           -2.368375709320337,
           -2.347387625981633,
           -2.3259126384777806,
           -2.3039582021098277,
           -2.281532026614027,
           -2.2586420836974317,
           -2.235296615327289,
           -2.2115041428519517,
           -2.1872734770397027,
           -2.1626137291314516,
           -2.137534323014149,
           -2.1120450086338374,
           -2.0861558767808632,
           -2.059877375395022,
           -2.0332203275555094,
           -2.006195951339753,
           -1.9788158817567307,
           -1.9510921949845474,
           -1.9230374351691246,
           -1.8946646440711865,
           -1.8659873938826885,
           -1.8370198235717548,
           -1.8077766791574688,
           -1.778273358362915,
           -1.7485259601469674,
           -1.7185513396728789,
           -1.6883671693348596,
           -1.6579920065326863,
           -1.627445368958745,
           -1.5967478182412984,
           -1.565921052871159,
           -1.5349880114246977,
           -1.5039729871814456,
           -1.4729017553155426,
           -1.4418017139110029,
           -1.4107020401029162,
           -1.3796338626686668,
           -1.3486304523690917,
           -1.317727431247649,
           -1.2869630019074103,
           -1.2563781974631876,
           -1.2260171523604717,
           -1.1959273935018069,
           -1.166160150047281,
           -1.1367706787649143,
           -1.107818599788781,
           -1.0793682349748546,
           -1.0514889375998693,
           -1.024255397812239,
           -0.9977479029418862,
           -0.972052525517443,
           -0.9472612047814005,
           -0.9234716800237547,
           -0.9007872268898107,
           -0.8793161421056205,
           -0.8591709194522656,
           -0.8404670624408342,
           -0.8233214894429569,
           -0.8078505073807455,
           -0.7941673620695527,
           -0.7823794168360968,
           -0.7725850633237592,
           -0.764870523317802,
           -0.7593067486326163,
           -0.7559466564064954,
           -0.754822939153265,
           -0.7559466564064977,
           -0.7593067486326209,
           -0.7648705233178089,
           -0.7725850633237682,
           -0.7823794168361079,
           -0.7941673620695658,
           -0.8078505073807605,
           -0.8233214894429736,
           -0.8404670624408528,
           -0.8591709194522855,
           -0.8793161421056419,
           -0.9007872268898334,
           -0.9234716800237786,
           -0.9472612047814254,
           -0.972052525517469,
           -0.9977479029419131,
           -1.0242553978122666,
           -1.0514889375998975,
           -1.0793682349748834,
           -1.1078185997888106,
           -1.1367706787649443,
           -1.1661601500473116,
           -1.1959273935018377,
           -1.2260171523605028,
           -1.2563781974632189,
           -1.2869630019074418,
           -1.3177274312476808,
           -1.3486304523691237,
           -1.3796338626686988,
           -1.410702040102948,
           -1.4418017139110348,
           -1.4729017553155745,
           -1.5039729871814775,
           -1.5349880114247298,
           -1.5659210528711907,
           -1.5967478182413302,
           -1.627445368958777,
           -1.6579920065327174,
           -1.6883671693348905,
           -1.71855133967291,
           -1.748525960146998,
           -1.7782733583629453,
           -1.8077766791574994,
           -1.8370198235717845,
           -1.8659873938827183,
           -1.8946646440712156,
           -1.9230374351691537,
           -1.951092194984576,
           -1.9788158817567592,
           -2.006195951339781,
           -2.033220327555537,
           -2.0598773753950494,
           -2.08615587678089,
           -2.1120450086338636,
           -2.137534323014175,
           -2.162613729131477,
           -2.187273477039728,
           -2.211504142851976,
           -2.2352966153273126,
           -2.258642083697456,
           -2.28153202661405,
           -2.3039582021098504,
           -2.3259126384778033,
           -2.3473876259816553,
           -2.3683757093203583,
           -2.3888696807762324,
           -2.408862573983727,
           -2.4283476582618015,
           -2.4473184334584355,
           -2.4657686252607616,
           -2.4836921809287325,
           -2.5010832654142052,
           -2.517936257830962,
           -2.5342457482443415,
           -2.55000653475212,
           -2.5652136208308653,
           -2.579862212924358,
           -2.593947718252821,
           -2.607465742823623,
           -2.620412089625866,
           -2.6327827569928868,
           -2.644573937118096,
           -2.6557820147109465,
           -2.6664035657809806,
           -2.676435356539011,
           -2.685874342405503,
           -2.6947176671171174,
           -2.7029626619232334,
           -2.710606844865037,
           -2.7176479201304784,
           -2.724083777479058,
           -2.7299124917310253,
           -2.7351323223161352,
           -2.739741712877638,
           -2.7437392909277127,
           -2.747123867550975,
           -2.749894437153186,
           -2.75205017725269,
           -2.753590448312526,
           -2.7545147936115444
          ],
          [
           -2.7748571071028976,
           -2.774547693808068,
           -2.773619546276774,
           -2.772072941587942,
           -2.769908341604422,
           -2.767126393070619,
           -2.763727927750464,
           -2.7597139626070786,
           -2.755085700025818,
           -2.749844528082842,
           -2.743992020861727,
           -2.737529938821121,
           -2.7304602292168716,
           -2.722785026582562,
           -2.7145066532729034,
           -2.7056276200749716,
           -2.6961506268928774,
           -2.6860785635120856,
           -2.6754145104502727,
           -2.664161739902354,
           -2.6523237167880978,
           -2.639904099911612,
           -2.6269067432429285,
           -2.6133356973329263,
           -2.599195210873955,
           -2.584489732419762,
           -2.5692239122796288,
           -2.5534026046031495,
           -2.5370308696736577,
           -2.5201139764301277,
           -2.502657405239328,
           -2.484666850942183,
           -2.466148226200722,
           -2.4471076651746193,
           -2.4275515275593147,
           -2.407486403020966,
           -2.38691911606709,
           -2.36585673139583,
           -2.344306559771231,
           -2.32227616447694,
           -2.2997733684062807,
           -2.2768062618528986,
           -2.253383211073059,
           -2.2295128676984506,
           -2.2052041790869716,
           -2.180466399708644,
           -2.1553091036746035,
           -2.1297421985292186,
           -2.103775940438909,
           -2.0774209509264034,
           -2.050688235316125,
           -2.023589203075395,
           -1.9961356902573815,
           -1.9683399842754956,
           -1.9402148512654998,
           -1.9117735663212454,
           -1.8830299469230172,
           -1.85399838991425,
           -1.8246939124232067,
           -1.7951321971713803,
           -1.7653296426601768,
           -1.7353034187820027,
           -1.7050715284613578,
           -1.6746528759957546,
           -1.6440673428349335,
           -1.613335871609127,
           -1.582480559291789,
           -1.5515247604571836,
           -1.520493201665469,
           -1.489412108072952,
           -1.4583093434166636,
           -1.4272145645515408,
           -1.3961593917131447,
           -1.3651775956227141,
           -1.3343053024226292,
           -1.303581217200466,
           -1.2730468664916144,
           -1.2427468595965907,
           -1.2127291677504606,
           -1.1830454190656114,
           -1.1537512056492778,
           -1.124906397275201,
           -1.0965754533582093,
           -1.0688277216368545,
           -1.0417377078267613,
           -1.0153852955269982,
           -0.9898558898924389,
           -0.965240452221336,
           -0.9416353860625185,
           -0.9191422294358271,
           -0.8978671033762968,
           -0.8779198657704981,
           -0.8594129232447981,
           -0.8424596647796068,
           -0.8271725006664928,
           -0.8136605205117472,
           -0.8020268237654599,
           -0.7923656229150573,
           -0.784759267408359,
           -0.7792753773723049,
           -0.7759643007585225,
           -0.7748571071028976,
           -0.7759643007585247,
           -0.7792753773723096,
           -0.7847592674083657,
           -0.7923656229150663,
           -0.8020268237654709,
           -0.8136605205117602,
           -0.8271725006665076,
           -0.8424596647796234,
           -0.8594129232448162,
           -0.877919865770518,
           -0.8978671033763183,
           -0.9191422294358497,
           -0.9416353860625419,
           -0.9652404522213608,
           -0.9898558898924645,
           -1.0153852955270248,
           -1.0417377078267887,
           -1.0688277216368827,
           -1.0965754533582381,
           -1.1249063972752302,
           -1.1537512056493078,
           -1.1830454190656416,
           -1.2127291677504914,
           -1.2427468595966218,
           -1.2730468664916457,
           -1.3035812172004977,
           -1.3343053024226608,
           -1.3651775956227459,
           -1.3961593917131767,
           -1.4272145645515726,
           -1.458309343416696,
           -1.4894121080729843,
           -1.5204932016655008,
           -1.5515247604572153,
           -1.582480559291821,
           -1.6133358716091586,
           -1.644067342834965,
           -1.674652875995786,
           -1.7050715284613889,
           -1.7353034187820338,
           -1.7653296426602076,
           -1.795132197171411,
           -1.8246939124232369,
           -1.8539983899142802,
           -1.883029946923047,
           -1.9117735663212747,
           -1.9402148512655288,
           -1.968339984275524,
           -1.99613569025741,
           -2.023589203075423,
           -2.0506882353161524,
           -2.077420950926431,
           -2.1037759404389362,
           -2.1297421985292453,
           -2.1553091036746297,
           -2.1804663997086693,
           -2.205204179086997,
           -2.2295128676984755,
           -2.2533832110730834,
           -2.2768062618529226,
           -2.299773368406304,
           -2.3222761644769627,
           -2.3443065597712542,
           -2.3658567313958527,
           -2.386919116067112,
           -2.407486403020987,
           -2.427551527559335,
           -2.447107665174639,
           -2.4661482262007417,
           -2.484666850942202,
           -2.5026574052393458,
           -2.5201139764301455,
           -2.537030869673674,
           -2.553402604603166,
           -2.569223912279645,
           -2.5844897324197778,
           -2.59919521087397,
           -2.6133356973329405,
           -2.6269067432429423,
           -2.639904099911625,
           -2.6523237167881097,
           -2.664161739902366,
           -2.6754145104502842,
           -2.6860785635120963,
           -2.6961506268928876,
           -2.705627620074981,
           -2.7145066532729123,
           -2.72278502658257,
           -2.730460229216879,
           -2.7375299388211283,
           -2.7439920208617337,
           -2.7498445280828476,
           -2.755085700025823,
           -2.7597139626070826,
           -2.7637279277504683,
           -2.767126393070622,
           -2.7699083416044243,
           -2.7720729415879433,
           -2.773619546276776,
           -2.774547693808069
          ],
          [
           -2.794141650844761,
           -2.7938310344061787,
           -2.792899278434728,
           -2.7913466629838823,
           -2.789173654878216,
           -2.7863809078172546,
           -2.7829692625222164,
           -2.7789397469269934,
           -2.7742935764151424,
           -2.769032154105068,
           -2.7631570711860025,
           -2.756670107307857,
           -2.749573231028471,
           -2.7418686003223125,
           -2.7335585631551873,
           -2.7246456581300977,
           -2.7151326152099746,
           -2.705022356523686,
           -2.6943179972623748,
           -2.683022846673976,
           -2.6711404091645403,
           -2.658674385515898,
           -2.645628674230136,
           -2.63200737301243,
           -2.61781478040489,
           -2.603055397585341,
           -2.5877339303463347,
           -2.571855291271175,
           -2.555424602125404,
           -2.538447196484009,
           -2.5209286226166077,
           -2.502874646655089,
           -2.484291256070631,
           -2.4651846634896932,
           -2.4455613108815966,
           -2.425427874153606,
           -2.404791268193098,
           -2.3836586524004706,
           -2.3620374367610077,
           -2.3399352885089058,
           -2.3173601394423167,
           -2.294320193954477,
           -2.2708239378529638,
           -2.246880148046861,
           -2.222497903190297,
           -2.1976865953804405,
           -2.1724559430188615,
           -2.146816004957181,
           -2.1207771960614057,
           -2.0943503043443776,
           -2.067546509832547,
           -2.0403774053520407,
           -2.012855019439921,
           -1.9849918416098828,
           -1.9568008502276266,
           -1.9282955432801012,
           -1.8994899723549474,
           -1.870398780182078,
           -1.8410372421286834,
           -1.8114213120822644,
           -1.781567673203733,
           -1.751493794084284,
           -1.7212179908955805,
           -1.6907594961825183,
           -1.6601385350109332,
           -1.6293764092480623,
           -1.5984955908198795,
           -1.5675198248542077,
           -1.5364742436783922,
           -1.5053854926904555,
           -1.4742818691563175,
           -1.4431934749936397,
           -1.4121523845726975,
           -1.3811928284798263,
           -1.3503513940276235,
           -1.319667243029923,
           -1.2891823469524046,
           -1.2589417389560116,
           -1.2289937815140064,
           -1.1993904471368726,
           -1.1701876082037261,
           -1.141445329886712,
           -1.1132281575747933,
           -1.0856053869707731,
           -1.058651301089714,
           -1.0324453537185128,
           -1.0070722735855213,
           -0.9826220577581447,
           -0.959189817063583,
           -0.9368754313160116,
           -0.9157829688671861,
           -0.8960198248625433,
           -0.8776955372588838,
           -0.8609202509254809,
           -0.8458028195396691,
           -0.8324485632448813,
           -0.8209567364626542,
           -0.8114178020756133,
           -0.8039106502843892,
           -0.7984999355733866,
           -0.7952337252536711,
           -0.7941416508447611,
           -0.7952337252536734,
           -0.7984999355733913,
           -0.8039106502843958,
           -0.8114178020756221,
           -0.8209567364626651,
           -0.832448563244894,
           -0.8458028195396836,
           -0.8609202509254974,
           -0.877695537258902,
           -0.8960198248625628,
           -0.915782968867207,
           -0.936875431316034,
           -0.9591898170636064,
           -0.9826220577581692,
           -1.0070722735855469,
           -1.0324453537185392,
           -1.0586513010897414,
           -1.0856053869708011,
           -1.113228157574822,
           -1.1414453298867413,
           -1.170187608203756,
           -1.1993904471369028,
           -1.228993781514037,
           -1.2589417389560424,
           -1.2891823469524357,
           -1.3196672430299545,
           -1.350351394027655,
           -1.381192828479858,
           -1.4121523845727293,
           -1.4431934749936717,
           -1.4742818691563497,
           -1.5053854926904875,
           -1.536474243678424,
           -1.56751982485424,
           -1.5984955908199112,
           -1.629376409248094,
           -1.660138535010965,
           -1.69075949618255,
           -1.721217990895612,
           -1.7514937940843156,
           -1.781567673203764,
           -1.811421312082295,
           -1.8410372421287138,
           -1.8703987801821085,
           -1.8994899723549776,
           -1.9282955432801305,
           -1.9568008502276557,
           -1.984991841609912,
           -2.0128550194399493,
           -2.0403774053520687,
           -2.0675465098325745,
           -2.094350304344405,
           -2.1207771960614323,
           -2.1468160049572074,
           -2.1724559430188877,
           -2.197686595380466,
           -2.222497903190322,
           -2.2468801480468863,
           -2.2708239378529878,
           -2.294320193954501,
           -2.31736013944234,
           -2.339935288508929,
           -2.36203743676103,
           -2.383658652400493,
           -2.4047912681931196,
           -2.4254278741536277,
           -2.445561310881617,
           -2.4651846634897128,
           -2.4842912560706507,
           -2.5028746466551075,
           -2.5209286226166254,
           -2.5384471964840274,
           -2.555424602125422,
           -2.5718552912711914,
           -2.587733930346351,
           -2.603055397585357,
           -2.6178147804049057,
           -2.6320073730124447,
           -2.645628674230149,
           -2.6586743855159107,
           -2.671140409164553,
           -2.683022846673988,
           -2.6943179972623863,
           -2.705022356523697,
           -2.715132615209985,
           -2.724645658130107,
           -2.733558563155196,
           -2.741868600322321,
           -2.7495732310284784,
           -2.7566701073078637,
           -2.763157071186009,
           -2.7690321541050738,
           -2.7742935764151473,
           -2.778939746926998,
           -2.782969262522221,
           -2.7863809078172577,
           -2.789173654878218,
           -2.791346662983884,
           -2.7928992784347293,
           -2.7938310344061787
          ],
          [
           -2.8126579138282577,
           -2.8123461577049422,
           -2.8114109836329657,
           -2.809852674528005,
           -2.8076717019889466,
           -2.804868726407715,
           -2.8014445971244144,
           -2.7974003526291744,
           -2.7927372208125156,
           -2.7874566192664663,
           -2.7815601556391116,
           -2.7750496280457235,
           -2.7679270255400947,
           -2.7601945286502225,
           -2.7518545099830316,
           -2.742909534903382,
           -2.733362362293263,
           -2.7232159453976936,
           -2.7124734327645954,
           -2.701138169286642,
           -2.689213697353947,
           -2.6767037581273283,
           -2.663612292942884,
           -2.649943444859667,
           -2.6357015603634126,
           -2.6208911912405637,
           -2.605517096638187,
           -2.5895842453269595,
           -2.5730978181860236,
           -2.556063210930414,
           -2.5384860371037337,
           -2.5203721313610434,
           -2.5017275530693786,
           -2.482558590256045,
           -2.4628717639378714,
           -2.442673832867934,
           -2.421971798739987,
           -2.400772911894942,
           -2.3790846775782826,
           -2.3569148628024124,
           -2.3342715038735165,
           -2.3111629146488317,
           -2.287597695597155,
           -2.2635847437432086,
           -2.2391332635851304,
           -2.214252779083978,
           -2.188953146834909,
           -2.163244570541659,
           -2.137137616929305,
           -2.1106432332452036,
           -2.0837727665145658,
           -2.0565379847356566,
           -2.02895110022016,
           -2.0010247953071683,
           -1.9727722507046772,
           -1.9442071767406661,
           -1.9153438478370517,
           -1.8861971405542335,
           -1.8567825755918106,
           -1.827116364172505,
           -1.7972154592814642,
           -1.7670976122819135,
           -1.7367814354804274,
           -1.7062864712704624,
           -1.6756332685405386,
           -1.6448434670924035,
           -1.613939890872844,
           -1.582946650878016,
           -1.5518892586374482,
           -1.5207947512211741,
           -1.4896918287306826,
           -1.458611005223036,
           -1.427584773964922,
           -1.3966477878028882,
           -1.365837055245896,
           -1.335192152558758,
           -1.3047554517249584,
           -1.2745723635110935,
           -1.244691593999762,
           -1.2151654117904838,
           -1.1860499215275147,
           -1.1574053374217277,
           -1.1292962479133624,
           -1.1017918595064333,
           -1.0749662040548715,
           -1.0488982894098882,
           -1.0236721684526293,
           -0.9993768963781611,
           -0.9761063411010975,
           -0.9539588075033251,
           -0.9330364339143966,
           -0.9134443199721182,
           -0.8952893503420941,
           -0.8786786902029626,
           -0.8637179471555405,
           -0.8505090207463055,
           -0.8391476942400402,
           -0.8297210609469349,
           -0.8223049146005594,
           -0.8169612636082183,
           -0.8137361454247116,
           -0.8126579138282576,
           -0.8137361454247138,
           -0.8169612636082227,
           -0.8223049146005661,
           -0.8297210609469438,
           -0.8391476942400509,
           -0.8505090207463182,
           -0.8637179471555548,
           -0.8786786902029788,
           -0.8952893503421119,
           -0.9134443199721375,
           -0.9330364339144174,
           -0.9539588075033473,
           -0.9761063411011209,
           -0.9993768963781854,
           -1.0236721684526549,
           -1.0488982894099146,
           -1.0749662040548988,
           -1.1017918595064613,
           -1.129296247913391,
           -1.157405337421757,
           -1.1860499215275446,
           -1.215165411790514,
           -1.2446915939997925,
           -1.2745723635111246,
           -1.3047554517249897,
           -1.3351921525587893,
           -1.3658370552459276,
           -1.39664778780292,
           -1.4275847739649539,
           -1.4586110052230683,
           -1.4896918287307146,
           -1.5207947512212063,
           -1.5518892586374804,
           -1.5829466508780479,
           -1.6139398908728755,
           -1.644843467092435,
           -1.67563326854057,
           -1.7062864712704933,
           -1.7367814354804585,
           -1.7670976122819444,
           -1.797215459281495,
           -1.8271163641725356,
           -1.8567825755918412,
           -1.8861971405542635,
           -1.9153438478370817,
           -1.9442071767406957,
           -1.9727722507047065,
           -2.001024795307197,
           -2.0289511002201883,
           -2.0565379847356846,
           -2.0837727665145938,
           -2.1106432332452307,
           -2.137137616929332,
           -2.1632445705416856,
           -2.188953146834936,
           -2.214252779084004,
           -2.2391332635851557,
           -2.2635847437432335,
           -2.287597695597179,
           -2.3111629146488557,
           -2.3342715038735395,
           -2.356914862802435,
           -2.3790846775783057,
           -2.4007729118949643,
           -2.421971798740009,
           -2.4426738328679547,
           -2.462871763937892,
           -2.4825585902560654,
           -2.501727553069398,
           -2.520372131361062,
           -2.5384860371037523,
           -2.5560632109304318,
           -2.573097818186041,
           -2.5895842453269764,
           -2.605517096638204,
           -2.6208911912405797,
           -2.6357015603634273,
           -2.649943444859681,
           -2.663612292942898,
           -2.676703758127341,
           -2.689213697353959,
           -2.701138169286654,
           -2.712473432764606,
           -2.7232159453977043,
           -2.733362362293273,
           -2.742909534903391,
           -2.7518545099830405,
           -2.7601945286502314,
           -2.767927025540102,
           -2.7750496280457306,
           -2.781560155639118,
           -2.787456619266472,
           -2.792737220812521,
           -2.797400352629179,
           -2.801444597124418,
           -2.8048687264077183,
           -2.8076717019889488,
           -2.8098526745280066,
           -2.8114109836329675,
           -2.8123461577049436
          ],
          [
           -2.8303879827648046,
           -2.830075149323747,
           -2.829136744213406,
           -2.827573053095184,
           -2.8253845521479772,
           -2.822571908183717,
           -2.8191359788105457,
           -2.815077812645051,
           -2.8103986495754114,
           -2.80509992107775,
           -2.799183250588425,
           -2.7926504539354964,
           -2.7855035398330643,
           -2.7777447104427333,
           -2.7693763620069856,
           -2.7604010855598506,
           -2.7508216677208837,
           -2.740641091579142,
           -2.729862537674571,
           -2.7184893850849945,
           -2.7065252126277515,
           -2.6939738001859412,
           -2.6808391301702277,
           -2.66712538912824,
           -2.6528369695147984,
           -2.6379784716374783,
           -2.6225547057934384,
           -2.606570694614996,
           -2.590031675643138,
           -2.5729431041500104,
           -2.555310656233512,
           -2.537140232209363,
           -2.518437960328533,
           -2.4992102008506816,
           -2.479463550507293,
           -2.459204847391581,
           -2.438441176315984,
           -2.417179874682179,
           -2.3954285389131593,
           -2.373195031502016,
           -2.350487488737692,
           -2.327314329174281,
           -2.3036842629174257,
           -2.2796063018091077,
           -2.255089770600797,
           -2.2301443192144856,
           -2.204779936201891,
           -2.1790069635239364,
           -2.1528361127859337,
           -2.126278483078583,
           -2.099345580591304,
           -2.0720493401826423,
           -2.0444021491126945,
           -2.01641687316495,
           -1.9881068854097756,
           -1.959486097889227,
           -1.930568996533126,
           -1.9013706796496077,
           -1.8719069003697182,
           -1.842194113465289,
           -1.8122495270021814,
           -1.7820911593370143,
           -1.751737902014371,
           -1.7212095891726649,
           -1.6905270741194933,
           -1.65971231379004,
           -1.6287884618529571,
           -1.5977799712743117,
           -1.5667127071877167,
           -1.5356140709422497,
           -1.5045131362019386,
           -1.4734407979416855,
           -1.4424299351117484,
           -1.4115155876095646,
           -1.380735147982361,
           -1.3501285679594628,
           -1.3197385794454801,
           -1.2896109289530402,
           -1.2597946235665236,
           -1.2303421853483367,
           -1.2013099095617676,
           -1.1727581201210642,
           -1.1447514132246346,
           -1.1173588771296987,
           -1.0906542724656065,
           -1.064716153393425,
           -1.0396279054255873,
           -1.0154776710772864,
           -0.9923581301662288,
           -0.9703660981696908,
           -0.9496019045018124,
           -0.9301685140472246,
           -0.9121703610999459,
           -0.8957118763108529,
           -0.8808957053211036,
           -0.8678206426880591,
           -0.8565793355152468,
           -0.847255845293019,
           -0.8399231895296114,
           -0.834641011118665,
           -0.8314535369338389,
           -0.8303879827648046,
           -0.8314535369338413,
           -0.8346410111186693,
           -0.839923189529618,
           -0.8472558452930276,
           -0.8565793355152574,
           -0.8678206426880716,
           -0.8808957053211179,
           -0.895711876310869,
           -0.9121703610999635,
           -0.9301685140472437,
           -0.9496019045018331,
           -0.9703660981697128,
           -0.992358130166252,
           -1.0154776710773106,
           -1.0396279054256126,
           -1.064716153393451,
           -1.0906542724656334,
           -1.1173588771297265,
           -1.1447514132246632,
           -1.1727581201210935,
           -1.2013099095617972,
           -1.2303421853483665,
           -1.2597946235665543,
           -1.289610928953071,
           -1.319738579445511,
           -1.3501285679594943,
           -1.3807351479823928,
           -1.4115155876095964,
           -1.4424299351117804,
           -1.473440797941717,
           -1.5045131362019706,
           -1.5356140709422819,
           -1.5667127071877485,
           -1.5977799712743435,
           -1.6287884618529889,
           -1.6597123137900716,
           -1.6905270741195246,
           -1.7212095891726964,
           -1.7517379020144022,
           -1.7820911593370456,
           -1.8122495270022125,
           -1.84219411346532,
           -1.8719069003697482,
           -1.9013706796496377,
           -1.930568996533156,
           -1.9594860978892565,
           -1.9881068854098045,
           -2.0164168731649785,
           -2.044402149112723,
           -2.0720493401826707,
           -2.0993455805913315,
           -2.12627848307861,
           -2.1528361127859608,
           -2.179006963523963,
           -2.2047799362019176,
           -2.230144319214512,
           -2.2550897706008217,
           -2.2796063018091326,
           -2.3036842629174497,
           -2.327314329174305,
           -2.350487488737716,
           -2.37319503150204,
           -2.395428538913182,
           -2.4171798746822013,
           -2.4384411763160054,
           -2.4592048473916015,
           -2.479463550507313,
           -2.499210200850702,
           -2.518437960328553,
           -2.5371402322093815,
           -2.5553106562335306,
           -2.5729431041500277,
           -2.5900316756431554,
           -2.606570694615013,
           -2.622554705793455,
           -2.637978471637494,
           -2.652836969514813,
           -2.667125389128254,
           -2.680839130170242,
           -2.693973800185955,
           -2.7065252126277644,
           -2.718489385085006,
           -2.729862537674583,
           -2.7406410915791524,
           -2.7508216677208934,
           -2.7604010855598604,
           -2.7693763620069944,
           -2.7777447104427417,
           -2.7855035398330714,
           -2.792650453935503,
           -2.799183250588432,
           -2.8050999210777556,
           -2.810398649575417,
           -2.815077812645055,
           -2.81913597881055,
           -2.82257190818372,
           -2.82538455214798,
           -2.8275730530951857,
           -2.829136744213407,
           -2.8300751493237475
          ],
          [
           -2.8473147049577845,
           -2.8470008555317854,
           -2.8460594033413966,
           -2.8444906366734384,
           -2.8422950360861194,
           -2.8394732745300293,
           -2.8360262175189646,
           -2.8319549233520633,
           -2.8272606433891245,
           -2.821944822381474,
           -2.816009098861153,
           -2.8094553055917504,
           -2.802285470084646,
           -2.7945018151850047,
           -2.786106759732427,
           -2.777102919301732,
           -2.76749310703003,
           -2.7572803345368997,
           -2.7464678129452382,
           -2.735058954011146,
           -2.723057371372066,
           -2.710466881923331,
           -2.697291507334291,
           -2.6835354757162784,
           -2.66920322345589,
           -2.6542993972283644,
           -2.638828856207265,
           -2.622796674488263,
           -2.6062081437465254,
           -2.589068776149115,
           -2.57138430754589,
           -2.5531607009646846,
           -2.5344041504390606,
           -2.5151210851997456,
           -2.4953181742639057,
           -2.4750023314598244,
           -2.45418072092833,
           -2.4328607631464454,
           -2.4110501415233694,
           -2.3887568096240073,
           -2.3659889990809138,
           -2.3427552282618316,
           -2.319064311766963,
           -2.294925370837867,
           -2.270347844768514,
           -2.2453415034185364,
           -2.2199164609394186,
           -2.194083190836116,
           -2.1678525424997406,
           -2.1412357593615265,
           -2.1142444988344278,
           -2.086890854226649,
           -2.0591873788312562,
           -2.031147112417976,
           -2.002783610377536,
           -1.9741109757956055,
           -1.9451438947627142,
           -1.9158976752586336,
           -1.886388289984634,
           -1.8566324235548888,
           -1.826647524499001,
           -1.7964518625709323,
           -1.766064591905237,
           -1.7355058206086826,
           -1.7047966874231584,
           -1.673959446142642,
           -1.6430175585108378,
           -1.611995796363852,
           -1.5809203538098093,
           -1.5498189702490244,
           -1.5187210650267564,
           -1.4876578844657888,
           -1.456662661935223,
           -1.4257707914583524,
           -1.3950200151251573,
           -1.3644506242273284,
           -1.3341056735430048,
           -1.3040312075250273,
           -1.274276496243536,
           -1.2448942777476335,
           -1.2159410019829542,
           -1.1874770694723975,
           -1.1595670555815025,
           -1.1322799083099118,
           -1.1056891041710535,
           -1.079872742895095,
           -1.054913557554506,
           -1.0308988125319494,
           -1.007920057958081,
           -0.9860727064770556,
           -0.9654553973068226,
           -0.9461691146078026,
           -0.9283160333318126,
           -0.911998077108406,
           -0.897315190113558,
           -0.8843633483199058,
           -0.8732323639995466,
           -0.8640035683645814,
           -0.8567474868265822,
           -0.8515216444451315,
           -0.8483686503565612,
           -0.8473147049577844,
           -0.8483686503565633,
           -0.8515216444451358,
           -0.8567474868265885,
           -0.8640035683645898,
           -0.8732323639995572,
           -0.8843633483199181,
           -0.8973151901135722,
           -0.911998077108422,
           -0.92831603333183,
           -0.9461691146078216,
           -0.9654553973068432,
           -0.9860727064770775,
           -1.0079200579581038,
           -1.0308988125319734,
           -1.0549135575545312,
           -1.079872742895121,
           -1.1056891041710806,
           -1.1322799083099395,
           -1.159567055581531,
           -1.1874770694724264,
           -1.2159410019829837,
           -1.2448942777476637,
           -1.2742764962435664,
           -1.304031207525058,
           -1.3341056735430359,
           -1.36445062422736,
           -1.395020015125189,
           -1.425770791458384,
           -1.456662661935255,
           -1.4876578844658208,
           -1.5187210650267884,
           -1.5498189702490563,
           -1.5809203538098413,
           -1.6119957963638838,
           -1.6430175585108693,
           -1.6739594461426734,
           -1.70479668742319,
           -1.7355058206087137,
           -1.766064591905268,
           -1.7964518625709633,
           -1.826647524499032,
           -1.8566324235549196,
           -1.8863882899846645,
           -1.9158976752586638,
           -1.945143894762744,
           -1.974110975795635,
           -2.002783610377566,
           -2.0311471124180054,
           -2.059187378831285,
           -2.0868908542266773,
           -2.1142444988344553,
           -2.1412357593615536,
           -2.1678525424997677,
           -2.1940831908361433,
           -2.2199164609394457,
           -2.245341503418562,
           -2.2703478447685397,
           -2.294925370837892,
           -2.3190643117669874,
           -2.342755228261856,
           -2.365988999080937,
           -2.3887568096240304,
           -2.411050141523392,
           -2.4328607631464676,
           -2.4541807209283517,
           -2.4750023314598453,
           -2.4953181742639257,
           -2.515121085199766,
           -2.53440415043908,
           -2.5531607009647033,
           -2.571384307545909,
           -2.5890687761491322,
           -2.606208143746543,
           -2.6227966744882805,
           -2.6388288562072817,
           -2.65429939722838,
           -2.669203223455904,
           -2.683535475716292,
           -2.697291507334305,
           -2.710466881923345,
           -2.7230573713720787,
           -2.7350589540111576,
           -2.7464678129452493,
           -2.75728033453691,
           -2.76749310703004,
           -2.777102919301741,
           -2.7861067597324363,
           -2.7945018151850136,
           -2.802285470084654,
           -2.8094553055917575,
           -2.8160090988611595,
           -2.8219448223814796,
           -2.82726064338913,
           -2.8319549233520673,
           -2.836026217518969,
           -2.839473274530033,
           -2.8422950360861217,
           -2.84449063667344,
           -2.846059403341398,
           -2.847000855531786
          ],
          [
           -2.86342170489667,
           -2.8631068998416827,
           -2.8621625815978384,
           -2.8605890409535215,
           -2.858386762639648,
           -2.8555564254558323,
           -2.8520989024484753,
           -2.8480152611422973,
           -2.8433067638272145,
           -2.8379748679029713,
           -2.832021226284373,
           -2.8254476878704837,
           -2.8182562980816477,
           -2.810449299468759,
           -2.8020291323997633,
           -2.792998435828997,
           -2.7833600481556227,
           -2.7731170081781022,
           -2.762272556152432,
           -2.75083013496264,
           -2.738793391412946,
           -2.7261661776519017,
           -2.7129525527399005,
           -2.699156784372512,
           -2.6847833507733525,
           -2.669836942771515,
           -2.6543224660800346,
           -2.638245043793462,
           -2.621610019124353,
           -2.6044229584004093,
           -2.5866896543460816,
           -2.5684161296747945,
           -2.5496086410204737,
           -2.530273683239873,
           -2.5104179941202935,
           -2.4900485595307207,
           -2.4691726190581593,
           -2.4477976721751635,
           -2.4259314849891345,
           -2.403582097629134,
           -2.3807578323316014,
           -2.3574673022926507,
           -2.3337194213616086,
           -2.30952341465819,
           -2.2848888302042645,
           -2.259825551670702,
           -2.234343812350335,
           -2.20845421047979,
           -2.1821677260459174,
           -2.155495739226946,
           -2.1284500506344255,
           -2.101042903539639,
           -2.073287008287672,
           -2.0451955691237833,
           -2.0167823136803964,
           -1.9880615253989846,
           -1.9590480791895264,
           -1.9297574806611721,
           -1.900205909291291,
           -1.8704102659362218,
           -1.8403882251256063,
           -1.8101582926229685,
           -1.779739868777654,
           -1.749153318236679,
           -1.718420046628245,
           -1.6875625848700957,
           -1.6566046817931421,
           -1.6255714058007462,
           -1.5944892563023754,
           -1.563386285661259,
           -1.532292232371595,
           -1.5012386661217223,
           -1.470259145292706,
           -1.4393893872704453,
           -1.4086674516929878,
           -1.3781339363874558,
           -1.3478321852413346,
           -1.3178085065631475,
           -1.288112399573821,
           -1.2587967854828859,
           -1.229918238090163,
           -1.2015372069614685,
           -1.1737182239112651,
           -1.1465300807598138,
           -1.1200459631253206,
           -1.0943435214278585,
           -1.0695048564718037,
           -1.0456163932069125,
           -1.022768612969505,
           -1.0010556122829193,
           -0.9805744559529087,
           -0.9614242946975926,
           -0.9437052239503197,
           -0.9275168717249421,
           -0.9129567201464613,
           -0.900118187357758,
           -0.8890885229255453,
           -0.8799465982242614,
           -0.8727606999267522,
           -0.8675864550932191,
           -0.8644650256887061,
           -0.8634217048966701,
           -0.8644650256887082,
           -0.8675864550932234,
           -0.8727606999267585,
           -0.8799465982242699,
           -0.8890885229255558,
           -0.9001181873577702,
           -0.9129567201464753,
           -0.9275168717249579,
           -0.9437052239503372,
           -0.9614242946976116,
           -0.9805744559529289,
           -1.001055612282941,
           -1.0227686129695277,
           -1.0456163932069364,
           -1.0695048564718288,
           -1.0943435214278847,
           -1.1200459631253474,
           -1.1465300807598413,
           -1.1737182239112933,
           -1.2015372069614971,
           -1.2299182380901923,
           -1.2587967854829154,
           -1.2881123995738515,
           -1.3178085065631782,
           -1.3478321852413655,
           -1.3781339363874867,
           -1.4086674516930193,
           -1.4393893872704768,
           -1.4702591452927378,
           -1.501238666121754,
           -1.5322922323716273,
           -1.563386285661291,
           -1.5944892563024071,
           -1.6255714058007784,
           -1.656604681793174,
           -1.6875625848701277,
           -1.7184200466282764,
           -1.7491533182367103,
           -1.7797398687776853,
           -1.8101582926229998,
           -1.8403882251256374,
           -1.8704102659362527,
           -1.9002059092913215,
           -1.9297574806612026,
           -1.9590480791895566,
           -1.988061525399014,
           -2.016782313680426,
           -2.0451955691238126,
           -2.073287008287701,
           -2.1010429035396676,
           -2.1284500506344535,
           -2.1554957392269745,
           -2.1821677260459444,
           -2.208454210479817,
           -2.2343438123503616,
           -2.2598255516707275,
           -2.2848888302042902,
           -2.309523414658215,
           -2.3337194213616326,
           -2.3574673022926746,
           -2.380757832331626,
           -2.403582097629157,
           -2.425931484989157,
           -2.447797672175186,
           -2.4691726190581815,
           -2.4900485595307416,
           -2.510417994120315,
           -2.5302736832398933,
           -2.5496086410204932,
           -2.568416129674813,
           -2.5866896543460998,
           -2.6044229584004275,
           -2.62161001912437,
           -2.6382450437934786,
           -2.654322466080051,
           -2.669836942771531,
           -2.684783350773368,
           -2.6991567843725264,
           -2.712952552739914,
           -2.726166177651914,
           -2.7387933914129583,
           -2.7508301349626523,
           -2.762272556152443,
           -2.773117008178113,
           -2.7833600481556333,
           -2.792998435829007,
           -2.8020291323997717,
           -2.810449299468767,
           -2.8182562980816552,
           -2.825447687870491,
           -2.8320212262843794,
           -2.837974867902977,
           -2.8433067638272194,
           -2.848015261142302,
           -2.8520989024484793,
           -2.8555564254558354,
           -2.8583867626396504,
           -2.860589040953523,
           -2.86216258159784,
           -2.8631068998416827
          ],
          [
           -2.878693400099275,
           -2.8783776988512155,
           -2.877430692819312,
           -2.875852675166386,
           -2.8736441345840045,
           -2.8708057554235262,
           -2.867338417881073,
           -2.863243198237932,
           -2.85852136915837,
           -2.853174400047279,
           -2.8472039574705668,
           -2.8406119056417185,
           -2.8334003069784504,
           -2.825571422733966,
           -2.81712771370788,
           -2.808071841042522,
           -2.7984066671109735,
           -2.788135256503928,
           -2.7772608771231866,
           -2.765787001390476,
           -2.753717307581104,
           -2.741055681292981,
           -2.7278062170625317,
           -2.7139732201401854,
           -2.6995612084393508,
           -2.684574914674121,
           -2.6690192887024358,
           -2.652899500093028,
           -2.636220940936238,
           -2.6189892289207215,
           -2.601210210700184,
           -2.582889965576621,
           -2.564034809529094,
           -2.5446512996199098,
           -2.5247462388131874,
           -2.5043266812442146,
           -2.483399937981826,
           -2.4619735833301877,
           -2.440055461721051,
           -2.4176536952526253,
           -2.394776691936923,
           -2.3714331547237104,
           -2.347632091376128,
           -2.3233828252807984,
           -2.298695007283727,
           -2.273578628652802,
           -2.2480440352781503,
           -2.222101943233231,
           -2.195763455832367,
           -2.169040082334657,
           -2.141943758459881,
           -2.1144868688993665,
           -2.0866822720238827,
           -2.0585433270116495,
           -2.0300839236426134,
           -2.001318515030383,
           -1.9722621535907277,
           -1.9429305305753874,
           -1.9133400195321548,
           -1.8835077240866416,
           -1.8534515304777315,
           -1.8231901653170302,
           -1.792743259082131,
           -1.7621314158933667,
           -1.7313762901626584,
           -1.7005006707393442,
           -1.6695285732090461,
           -1.6384853410243745,
           -1.6073977561561423,
           -1.5762941599448383,
           -1.5452045847966869,
           -1.514160897296653,
           -1.4831969531894096,
           -1.452348764492317,
           -1.4216546787315363,
           -1.3911555699085023,
           -1.3608950402788393,
           -1.3309196313236125,
           -1.3012790413723812,
           -1.2720263461532992,
           -1.2432182170498403,
           -1.21491512999114,
           -1.1871815556571774,
           -1.160086119024819,
           -1.1337017132354075,
           -1.1081055494049177,
           -1.0833791204823855,
           -1.0596080538633785,
           -1.0368818245982887,
           -1.015293299282306,
           -0.9949380808269711,
           -0.9759136271807439,
           -0.9583181236249185,
           -0.9422490993458632,
           -0.9278017950496512,
           -0.9150673092709656,
           -0.904130575625168,
           -0.8950682493106837,
           -0.8879466053155933,
           -0.8828195688670023,
           -0.8797270064679892,
           -0.8786934000992751,
           -0.8797270064679912,
           -0.8828195688670066,
           -0.8879466053155997,
           -0.8950682493106921,
           -0.9041305756251783,
           -0.9150673092709777,
           -0.9278017950496651,
           -0.9422490993458791,
           -0.9583181236249358,
           -0.9759136271807629,
           -0.9949380808269914,
           -1.0152932992823278,
           -1.0368818245983116,
           -1.0596080538634023,
           -1.0833791204824104,
           -1.1081055494049437,
           -1.1337017132354343,
           -1.1600861190248466,
           -1.1871815556572058,
           -1.2149151299911687,
           -1.2432182170498696,
           -1.272026346153329,
           -1.3012790413724113,
           -1.330919631323643,
           -1.3608950402788704,
           -1.3911555699085334,
           -1.4216546787315676,
           -1.4523487644923487,
           -1.4831969531894418,
           -1.5141608972966851,
           -1.5452045847967188,
           -1.5762941599448705,
           -1.6073977561561748,
           -1.6384853410244065,
           -1.6695285732090779,
           -1.7005006707393757,
           -1.7313762901626901,
           -1.7621314158933983,
           -1.7927432590821621,
           -1.8231901653170612,
           -1.8534515304777621,
           -1.883507724086672,
           -1.9133400195321852,
           -1.9429305305754174,
           -1.9722621535907576,
           -2.0013185150304134,
           -2.030083923642643,
           -2.0585433270116784,
           -2.0866822720239115,
           -2.114486868899395,
           -2.1419437584599095,
           -2.1690400823346847,
           -2.1957634558323944,
           -2.2221019432332576,
           -2.248044035278177,
           -2.2735786286528277,
           -2.298695007283753,
           -2.3233828252808233,
           -2.347632091376153,
           -2.371433154723734,
           -2.394776691936947,
           -2.4176536952526484,
           -2.440055461721074,
           -2.46197358333021,
           -2.483399937981847,
           -2.5043266812442364,
           -2.524746238813208,
           -2.54465129961993,
           -2.5640348095291134,
           -2.58288996557664,
           -2.601210210700202,
           -2.6189892289207393,
           -2.636220940936255,
           -2.652899500093045,
           -2.669019288702452,
           -2.684574914674137,
           -2.699561208439366,
           -2.7139732201402,
           -2.7278062170625454,
           -2.7410556812929943,
           -2.7537173075811174,
           -2.7657870013904877,
           -2.7772608771231986,
           -2.7881352565039386,
           -2.7984066671109837,
           -2.8080718410425307,
           -2.8171277137078894,
           -2.825571422733975,
           -2.8334003069784583,
           -2.8406119056417256,
           -2.8472039574705725,
           -2.8531744000472847,
           -2.8585213691583755,
           -2.8632431982379365,
           -2.8673384178810766,
           -2.87080575542353,
           -2.8736441345840067,
           -2.8758526751663878,
           -2.877430692819313,
           -2.878377698851216
          ],
          [
           -2.8931150161867976,
           -2.8927984773178146,
           -2.8918489591709386,
           -2.890266757153295,
           -2.888052363700023,
           -2.8852064684099203,
           -2.8817299582368845,
           -2.8776239177386813,
           -2.8728896293850457,
           -2.867528573927576,
           -2.8615424308344046,
           -2.8549330787930827,
           -2.847702596285721,
           -2.8398532622409225,
           -2.8313875567676803,
           -2.8223081619770363,
           -2.8126179628979573,
           -2.8023200484946202,
           -2.7914177127930606,
           -2.779914456125968,
           -2.7678139865053297,
           -2.755120221133568,
           -2.741837288064887,
           -2.7279695280296843,
           -2.71352149643613,
           -2.698497965564371,
           -2.6829039269703028,
           -2.6667445941174717,
           -2.650025405257454,
           -2.632752026580983,
           -2.6149303556642676,
           -2.596566525237258,
           -2.577666907303215,
           -2.5582381176417806,
           -2.538287020730868,
           -2.5178207351261492,
           -2.4968466393407245,
           -2.4753723782717567,
           -2.453405870225498,
           -2.430955314597265,
           -2.4080292002686012,
           -2.384636314790113,
           -2.360785754425436,
           -2.3364869351394377,
           -2.3117496046222796,
           -2.286583855450337,
           -2.26100013949539,
           -2.235009283704991,
           -2.2086225073895878,
           -2.1818514411660517,
           -2.154708147722695,
           -2.127205144587905,
           -2.099355429103285,
           -2.071172505822716,
           -2.0426704165812746,
           -2.0138637735024787,
           -1.9847677952389524,
           -1.9553983467704352,
           -1.9257719831139237,
           -1.8959059973336612,
           -1.8658184732733374,
           -1.8355283434688716,
           -1.8050554527368774,
           -1.774420627970406,
           -1.7436457547085216,
           -1.7127538610777537,
           -1.6817692097290409,
           -1.6507173984098664,
           -1.6196254698134576,
           -1.588522031329029,
           -1.55743738527144,
           -1.5264036700851369,
           -1.4954550128832216,
           -1.4646276934818268,
           -1.4339603198028423,
           -1.4034940141201753,
           -1.373272609087062,
           -1.3433428517704866,
           -1.3137546129948847,
           -1.2845610981190518,
           -1.255819053894612,
           -1.227588964242232,
           -1.1999352256041607,
           -1.172926289981175,
           -1.1466347608671885,
           -1.1211374241401433,
           -1.0965151927181198,
           -1.0728529407169454,
           -1.050239200355539,
           -1.0287656935043163,
           -1.0085266702655453,
           -0.9896180301299019,
           -0.9721362079115968,
           -0.956176817537278,
           -0.941833062215457,
           -0.9291939392957269,
           -0.9183422911253867,
           -0.9093527772820512,
           -0.9022898655744989,
           -0.8972059553780473,
           -0.8941397534231477,
           -0.8931150161867976,
           -0.8941397534231499,
           -0.8972059553780514,
           -0.9022898655745051,
           -0.9093527772820597,
           -0.9183422911253969,
           -0.929193939295739,
           -0.9418330622154709,
           -0.9561768175372936,
           -0.9721362079116138,
           -0.9896180301299206,
           -1.0085266702655655,
           -1.0287656935043379,
           -1.0502392003555616,
           -1.0728529407169693,
           -1.0965151927181447,
           -1.121137424140169,
           -1.146634760867215,
           -1.172926289981202,
           -1.1999352256041889,
           -1.2275889642422608,
           -1.2558190538946412,
           -1.2845610981190816,
           -1.3137546129949151,
           -1.3433428517705173,
           -1.373272609087093,
           -1.4034940141202068,
           -1.4339603198028739,
           -1.4646276934818585,
           -1.4954550128832533,
           -1.5264036700851684,
           -1.557437385271472,
           -1.5885220313290611,
           -1.6196254698134893,
           -1.6507173984098988,
           -1.6817692097290726,
           -1.7127538610777855,
           -1.7436457547085529,
           -1.7744206279704373,
           -1.8050554527369087,
           -1.8355283434689031,
           -1.8658184732733685,
           -1.8959059973336922,
           -1.9257719831139544,
           -1.9553983467704654,
           -1.9847677952389826,
           -2.013863773502509,
           -2.0426704165813043,
           -2.071172505822745,
           -2.099355429103314,
           -2.127205144587933,
           -2.1547081477227232,
           -2.1818514411660797,
           -2.2086225073896153,
           -2.2350092837050184,
           -2.2610001394954167,
           -2.286583855450363,
           -2.3117496046223054,
           -2.336486935139463,
           -2.3607857544254602,
           -2.384636314790137,
           -2.408029200268625,
           -2.4309553145972886,
           -2.4534058702255206,
           -2.475372378271779,
           -2.4968466393407462,
           -2.51782073512617,
           -2.538287020730889,
           -2.558238117641801,
           -2.577666907303235,
           -2.596566525237277,
           -2.614930355664286,
           -2.632752026581001,
           -2.650025405257472,
           -2.6667445941174894,
           -2.6829039269703188,
           -2.698497965564387,
           -2.7135214964361443,
           -2.727969528029699,
           -2.741837288064901,
           -2.7551202211335815,
           -2.767813986505342,
           -2.77991445612598,
           -2.791417712793072,
           -2.802320048494632,
           -2.812617962897967,
           -2.8223081619770456,
           -2.831387556767689,
           -2.839853262240931,
           -2.8477025962857287,
           -2.8549330787930893,
           -2.8615424308344104,
           -2.867528573927583,
           -2.8728896293850505,
           -2.877623917738686,
           -2.881729958236888,
           -2.885206468409923,
           -2.8880523637000257,
           -2.890266757153297,
           -2.8918489591709395,
           -2.8927984773178155
          ],
          [
           -2.9066726011770783,
           -2.9063552824512664,
           -2.9054034254374206,
           -2.9038173276540773,
           -2.901597485058263,
           -2.898744592185454,
           -2.895259542347079,
           -2.891143427887131,
           -2.8863975404998983,
           -2.8810233716113514,
           -2.8750226128271703,
           -2.868397156450947,
           -2.8611490960766157,
           -2.8532807272597602,
           -2.8447945482730232,
           -2.8356932609514938,
           -2.8259797716346395,
           -2.8156571922120595,
           -2.8047288412811366,
           -2.7931982454254913,
           -2.7810691406240613,
           -2.7683454738016002,
           -2.755031404532475,
           -2.74113130691076,
           -2.726649771600928,
           -2.7115916080847717,
           -2.6959618471217066,
           -2.679765743441235,
           -2.663008778688138,
           -2.64569666464292,
           -2.627835346742196,
           -2.6094310079260548,
           -2.5904900728420306,
           -2.571019212438187,
           -2.5510253489809256,
           -2.530515661536632,
           -2.509497591960059,
           -2.4879788514365697,
           -2.4659674276300065,
           -2.443471592493072,
           -2.4204999108027985,
           -2.3970612494898997,
           -2.3731647878377653,
           -2.34882002863445,
           -2.324036810369508,
           -2.2988253205768077,
           -2.273196110434813,
           -2.2471601107471724,
           -2.2207286494390264,
           -2.193913470718278,
           -2.1667267560663293,
           -2.139181147239511,
           -2.111289771480824,
           -2.0830662691617348,
           -2.0545248240956897,
           -2.0256801967888984,
           -1.9965477609197362,
           -1.9671435433659121,
           -1.9374842681282172,
           -1.9075874045310761,
           -1.877471220112999,
           -1.8471548386538468,
           -1.8166583038199682,
           -1.7860026489416316,
           -1.7552099734684288,
           -1.724303526675435,
           -1.6933077992132732,
           -1.6622486231052873,
           -1.6311532807901292,
           -1.6000506237821255,
           -1.5689712014669666,
           -1.5379474004565323,
           -1.5070135947814183,
           -1.4762063069871352,
           -1.4455643799006426,
           -1.4151291584243482,
           -1.3849446801670209,
           -1.3550578730029563,
           -1.325518756725984,
           -1.2963806447947726,
           -1.2677003407118286,
           -1.2395383218066482,
           -1.2119589010814897,
           -1.185030355326171,
           -1.1588250049525175,
           -1.133419228031064,
           -1.108893388001293,
           -1.0853316517428164,
           -1.0628216725334123,
           -1.0414541114128242,
           -1.0213219712817465,
           -1.0025197214474844,
           -0.9851421970395323,
           -0.9692832683766159,
           -0.9550342902449983,
           -0.9424823598385809,
           -0.9317084337035432,
           -0.9227853763808174,
           -0.9157760336319458,
           -0.9107314377000684,
           -0.9076892575801194,
           -0.9066726011770783,
           -0.9076892575801216,
           -0.9107314377000726,
           -0.9157760336319521,
           -0.9227853763808255,
           -0.9317084337035534,
           -0.9424823598385929,
           -0.9550342902450122,
           -0.9692832683766316,
           -0.9851421970395494,
           -1.002519721447503,
           -1.0213219712817667,
           -1.0414541114128455,
           -1.062821672533435,
           -1.0853316517428402,
           -1.1088933880013176,
           -1.1334192280310897,
           -1.158825004952544,
           -1.185030355326198,
           -1.2119589010815175,
           -1.239538321806677,
           -1.2677003407118574,
           -1.296380644794802,
           -1.3255187567260143,
           -1.355057873002987,
           -1.3849446801670517,
           -1.4151291584243795,
           -1.4455643799006739,
           -1.4762063069871667,
           -1.50701359478145,
           -1.5379474004565639,
           -1.5689712014669985,
           -1.6000506237821577,
           -1.631153280790161,
           -1.6622486231053195,
           -1.6933077992133052,
           -1.7243035266754667,
           -1.7552099734684605,
           -1.7860026489416632,
           -1.8166583038199997,
           -1.8471548386538785,
           -1.87747122011303,
           -1.9075874045311074,
           -1.9374842681282476,
           -1.9671435433659425,
           -1.9965477609197662,
           -2.0256801967889286,
           -2.054524824095719,
           -2.083066269161764,
           -2.1112897714808527,
           -2.1391811472395394,
           -2.1667267560663577,
           -2.193913470718306,
           -2.2207286494390535,
           -2.2471601107471995,
           -2.273196110434839,
           -2.2988253205768334,
           -2.3240368103695337,
           -2.348820028634475,
           -2.3731647878377897,
           -2.3970612494899237,
           -2.4204999108028225,
           -2.4434715924930956,
           -2.4659674276300287,
           -2.4879788514365924,
           -2.5094975919600806,
           -2.530515661536653,
           -2.5510253489809465,
           -2.5710192124382076,
           -2.590490072842051,
           -2.6094310079260734,
           -2.6278353467422146,
           -2.645696664642937,
           -2.663008778688156,
           -2.679765743441252,
           -2.6959618471217226,
           -2.7115916080847873,
           -2.7266497716009432,
           -2.741131306910775,
           -2.755031404532489,
           -2.7683454738016136,
           -2.781069140624074,
           -2.793198245425504,
           -2.804728841281148,
           -2.81565719221207,
           -2.8259797716346498,
           -2.8356932609515035,
           -2.844794548273032,
           -2.853280727259769,
           -2.861149096076623,
           -2.8683971564509543,
           -2.875022612827177,
           -2.881023371611357,
           -2.8863975404999036,
           -2.891143427887135,
           -2.8952595423470835,
           -2.898744592185457,
           -2.9015974850582658,
           -2.903817327654079,
           -2.9054034254374215,
           -2.906355282451267
          ],
          [
           -2.9193530389822415,
           -2.9190349974108027,
           -2.9180809725184713,
           -2.916491263799775,
           -2.914266370507734,
           -2.911406991797838,
           -2.9079140269312136,
           -2.9037885755385338,
           -2.899031937946737,
           -2.8936456155711245,
           -2.8876313113758325,
           -2.8809909304063086,
           -2.873726580397862,
           -2.865840572465013,
           -2.857335421876938,
           -2.848213848924962,
           -2.8384787798887454,
           -2.828133348108544,
           -2.817180895171708,
           -2.8056249722224558,
           -2.793469341404842,
           -2.7807179774498643,
           -2.7673750694187076,
           -2.7534450226153018,
           -2.738932460682622,
           -2.7238422278985652,
           -2.7081793916887196,
           -2.691949245375014,
           -2.6751573111810076,
           -2.657809343516581,
           -2.6399113325669337,
           -2.621469508213173,
           -2.6024903443143854,
           -2.582980563383933,
           -2.5629471416959078,
           -2.5423973148610948,
           -2.521338583915649,
           -2.4997787219699146,
           -2.4777257814694233,
           -2.455188102125265,
           -2.4321743195766685,
           -2.4086933748548764,
           -2.3847545247242783,
           -2.360367352984393,
           -2.3355417828246714,
           -2.3102880903333674,
           -2.284616919271949,
           -2.2585392972377876,
           -2.232066653350278,
           -2.205210837609219,
           -2.177984142089273,
           -2.1503993241508246,
           -2.1224696318655587,
           -2.0942088318747873,
           -2.0656312399199703,
           -2.0367517543080753,
           -2.007585892599486,
           -1.9781498318329753,
           -1.9484604526307745,
           -1.9185353875568094,
           -1.8883930741323167,
           -1.8580528129448972,
           -1.8275348313187405,
           -1.7968603530442793,
           -1.7660516746933366,
           -1.735132249068903,
           -1.7041267763543226,
           -1.6730613035311805,
           -1.6419633326239358,
           -1.610861938296102,
           -1.5797878952597606,
           -1.5487738158573576,
           -1.5178542980196241,
           -1.4870660835805136,
           -1.4564482266203556,
           -1.426042271089187,
           -1.3958924364066432,
           -1.3660458090121754,
           -1.3365525369156697,
           -1.3074660231380761,
           -1.2788431124996662,
           -1.2507442644809115,
           -1.2232337028313287,
           -1.1963795302412343,
           -1.1702537937631572,
           -1.1449324838705561,
           -1.1204954472432085,
           -1.0970261908396024,
           -1.0746115529409295,
           -1.05334121613821,
           -1.0333070383082201,
           -1.0146021811836423,
           -0.9973200228546129,
           -0.9815528509792532,
           -0.9673903478289495,
           -0.9549178961970571,
           -0.9442147555569073,
           -0.9353521787158074,
           -0.9283915578463188,
           -0.9233827019856842,
           -0.9203623527674555,
           -0.9193530389822417,
           -0.9203623527674575,
           -0.9233827019856884,
           -0.9283915578463249,
           -0.9353521787158156,
           -0.9442147555569173,
           -0.954917896197069,
           -0.9673903478289633,
           -0.9815528509792686,
           -0.99732002285463,
           -1.0146021811836607,
           -1.0333070383082401,
           -1.0533412161382312,
           -1.074611552940952,
           -1.0970261908396262,
           -1.1204954472432334,
           -1.1449324838705819,
           -1.1702537937631836,
           -1.1963795302412616,
           -1.2232337028313567,
           -1.2507442644809401,
           -1.278843112499695,
           -1.307466023138106,
           -1.3365525369156996,
           -1.3660458090122058,
           -1.3958924364066738,
           -1.4260422710892182,
           -1.456448226620387,
           -1.4870660835805452,
           -1.5178542980196557,
           -1.5487738158573896,
           -1.5797878952597924,
           -1.6108619382961338,
           -1.6419633326239678,
           -1.6730613035312125,
           -1.7041267763543544,
           -1.7351322490689347,
           -1.766051674693368,
           -1.796860353044311,
           -1.8275348313187716,
           -1.8580528129449283,
           -1.8883930741323478,
           -1.91853538755684,
           -1.9484604526308051,
           -1.9781498318330062,
           -2.0075858925995167,
           -2.0367517543081046,
           -2.0656312399199996,
           -2.0942088318748167,
           -2.122469631865587,
           -2.1503993241508534,
           -2.1779841420893016,
           -2.2052108376092465,
           -2.2320666533503055,
           -2.2585392972378147,
           -2.284616919271976,
           -2.310288090333393,
           -2.3355417828246967,
           -2.3603673529844182,
           -2.384754524724303,
           -2.4086933748549004,
           -2.432174319576692,
           -2.4551881021252884,
           -2.4777257814694456,
           -2.4997787219699372,
           -2.5213385839156706,
           -2.542397314861116,
           -2.562947141695929,
           -2.582980563383953,
           -2.6024903443144045,
           -2.621469508213193,
           -2.639911332566952,
           -2.657809343516599,
           -2.6751573111810254,
           -2.691949245375031,
           -2.708179391688736,
           -2.7238422278985803,
           -2.7389324606826375,
           -2.753445022615317,
           -2.767375069418722,
           -2.780717977449877,
           -2.7934693414048546,
           -2.8056249722224678,
           -2.81718089517172,
           -2.8281333481085547,
           -2.838478779888756,
           -2.848213848924972,
           -2.857335421876947,
           -2.8658405724650216,
           -2.8737265803978698,
           -2.8809909304063153,
           -2.887631311375839,
           -2.8936456155711303,
           -2.899031937946743,
           -2.9037885755385378,
           -2.907914026931218,
           -2.9114069917978407,
           -2.914266370507736,
           -2.9164912637997777,
           -2.918080972518472,
           -2.9190349974108036
          ],
          [
           -2.9311440620976645,
           -2.9308253539935265,
           -2.9298693301156065,
           -2.928276291796699,
           -2.926046741356086,
           -2.923181382247236,
           -2.9196811192662198,
           -2.915547058822383,
           -2.910780509273404,
           -2.905382981327298,
           -2.8993561885144468,
           -2.892702047733278,
           -2.885422679873757,
           -2.8775204105234495,
           -2.868997770761518,
           -2.859857498046682,
           -2.850102537205861,
           -2.8397360415309607,
           -2.8287613739920796,
           -2.8171821085762376,
           -2.8050020317617,
           -2.792225144138922,
           -2.7788556621902654,
           -2.7648980202417768,
           -2.7503568726016296,
           -2.735237095901195,
           -2.719543791656242,
           -2.7032822890674124,
           -2.686458148080944,
           -2.6690771627325667,
           -2.6511453647997176,
           -2.632669027789553,
           -2.6136546712928777,
           -2.5941090657369936,
           -2.574039237573606,
           -2.553452474941415,
           -2.5323563338468507,
           -2.510758644910608,
           -2.488667520732311,
           -2.4660913639307105,
           -2.443038875922519,
           -2.419519066509152,
           -2.3955412643475706,
           -2.3711151283889285,
           -2.3462506603771285,
           -2.320958218508564,
           -2.2952485323644676,
           -2.269132719238444,
           -2.2426223019940674,
           -2.2157292286008676,
           -2.1884658935118746,
           -2.160845161062066,
           -2.1328803910847602,
           -2.104585466962295,
           -2.075974826348243,
           -2.0470634948210167,
           -2.017867122753039,
           -1.9884020257055577,
           -1.9586852286866392,
           -1.9287345146385797,
           -1.8985684775505878,
           -1.8682065806225268,
           -1.8376692199349818,
           -1.8069777941087635,
           -1.776154780461637,
           -1.7452238181894666,
           -1.714209799110261,
           -1.683138966509174,
           -1.6520390226054662,
           -1.6209392451227171,
           -1.5898706133732063,
           -1.5588659441565387,
           -1.527960037608825,
           -1.497189832906835,
           -1.466594573413027,
           -1.4362159804201047,
           -1.4060984340920408,
           -1.376289159473066,
           -1.34683841451497,
           -1.317799675923165,
           -1.289229817211995,
           -1.261189271664978,
           -1.233742170904459,
           -1.2069564474994732,
           -1.1809038875286062,
           -1.1556601163676208,
           -1.1313044983629654,
           -1.1079199287473582,
           -1.0855924945259479,
           -1.0644109805992514,
           -1.0444661986822825,
           -1.0258501202773718,
           -1.0086548016858008,
           -0.9929710992693522,
           -0.9788871870355021,
           -0.9664869057315154,
           -0.955847991907325,
           -0.9470402549784054,
           -0.9401237876213427,
           -0.9351473068977227,
           -0.9321467274731243,
           -0.9311440620976645,
           -0.9321467274731263,
           -0.9351473068977268,
           -0.940123787621349,
           -0.9470402549784136,
           -0.9558479919073348,
           -0.9664869057315273,
           -0.9788871870355156,
           -0.9929710992693673,
           -1.0086548016858177,
           -1.0258501202773902,
           -1.0444661986823025,
           -1.0644109805992725,
           -1.0855924945259703,
           -1.1079199287473815,
           -1.1313044983629899,
           -1.155660116367646,
           -1.1809038875286326,
           -1.2069564474995,
           -1.233742170904487,
           -1.2611892716650064,
           -1.2892298172120238,
           -1.3177996759231942,
           -1.3468384145150003,
           -1.3762891594730966,
           -1.4060984340920717,
           -1.436215980420136,
           -1.4665945734130583,
           -1.4971898329068665,
           -1.5279600376088565,
           -1.5588659441565704,
           -1.589870613373238,
           -1.6209392451227491,
           -1.6520390226054982,
           -1.683138966509206,
           -1.714209799110293,
           -1.7452238181894981,
           -1.7761547804616689,
           -1.806977794108795,
           -1.8376692199350133,
           -1.868206580622558,
           -1.8985684775506189,
           -1.9287345146386108,
           -1.9586852286866696,
           -1.9884020257055883,
           -2.0178671227530693,
           -2.0470634948210464,
           -2.075974826348273,
           -2.104585466962325,
           -2.132880391084789,
           -2.1608451610620945,
           -2.188465893511903,
           -2.2157292286008956,
           -2.242622301994095,
           -2.2691327192384714,
           -2.2952485323644938,
           -2.32095821850859,
           -2.3462506603771542,
           -2.3711151283889533,
           -2.395541264347596,
           -2.419519066509177,
           -2.4430388759225425,
           -2.4660913639307345,
           -2.4886675207323337,
           -2.5107586449106307,
           -2.532356333846872,
           -2.5534524749414365,
           -2.5740392375736265,
           -2.594109065737014,
           -2.6136546712928976,
           -2.6326690277895723,
           -2.6511453647997363,
           -2.669077162732584,
           -2.6864581480809617,
           -2.70328228906743,
           -2.7195437916562586,
           -2.735237095901211,
           -2.7503568726016447,
           -2.764898020241791,
           -2.7788556621902796,
           -2.792225144138936,
           -2.8050020317617124,
           -2.8171821085762496,
           -2.8287613739920903,
           -2.8397360415309714,
           -2.850102537205871,
           -2.8598574980466918,
           -2.8689977707615273,
           -2.8775204105234584,
           -2.8854226798737646,
           -2.892702047733285,
           -2.8993561885144534,
           -2.9053829813273038,
           -2.910780509273409,
           -2.915547058822387,
           -2.919681119266224,
           -2.9231813822472392,
           -2.9260467413560884,
           -2.928276291796702,
           -2.929869330115608,
           -2.930825353993527
          ],
          [
           -2.942034263469994,
           -2.9417149445018995,
           -2.940757088598037,
           -2.939160998789659,
           -2.936927180229092,
           -2.934056340340877,
           -2.9305493890349976,
           -2.926407438983799,
           -2.921631805964707,
           -2.916224009271363,
           -2.9101857721962783,
           -2.9035190225886787,
           -2.8962258934917373,
           -2.8883087238640144,
           -2.879770059390526,
           -2.8706126533895255,
           -2.8608394678217954,
           -2.850453674409993,
           -2.8394586558763946,
           -2.827858007308247,
           -2.8156555376608927,
           -2.8028552714098,
           -2.789461450363768,
           -2.7754785356527143,
           -2.7609112099047888,
           -2.745764379628903,
           -2.7300431778203453,
           -2.713752966808768,
           -2.696899341369693,
           -2.67948813212265,
           -2.6615254092412517,
           -2.6430174865029,
           -2.6239709257084396,
           -2.6043925415049642,
           -2.5842894066481272,
           -2.5636688577438123,
           -2.5425385015128383,
           -2.5209062216265714,
           -2.4987801861659933,
           -2.4761688557618506,
           -2.453080992479168,
           -2.429525669515589,
           -2.405512281789872,
           -2.381050557504378,
           -2.3561505707737056,
           -2.3308227554207415,
           -2.305077920051483,
           -2.2789272645310037,
           -2.252382397995121,
           -2.2254553585456107,
           -2.1981586347914326,
           -2.170505189414364,
           -2.1425084849548313,
           -2.1141825120326216,
           -2.085541820237623,
           -2.0566015519477645,
           -2.0273774793549633,
           -1.9978860450049614,
           -1.9681444061833753,
           -1.9381704835078117,
           -1.907983014114028,
           -1.8776016098523785,
           -1.8470468209381896,
           -1.81634020552513,
           -1.7855044056924843,
           -1.7545632303532632,
           -1.7235417455975248,
           -1.6924663729803024,
           -1.6613649962413861,
           -1.630267076898636,
           -1.5992037790796783,
           -1.5682081038389066,
           -1.5373150330354235,
           -1.5065616826079677,
           -1.4759874647568814,
           -1.4456342581093697,
           -1.415546584377902,
           -1.3857717892946584,
           -1.3563602246873456,
           -1.3273654274227988,
           -1.2988442895563501,
           -1.2708572123658886,
           -1.2434682350126516,
           -1.216745126372598,
           -1.1907594261753374,
           -1.165586419076664,
           -1.1413050228500718,
           -1.117997569774076,
           -1.09574945887912,
           -1.0746486564691033,
           -1.0547850238074798,
           -1.0362494546629273,
           -1.0191328121163223,
           -1.0035246640507993,
           -0.9895118301683672,
           -0.9771767697860372,
           -0.966595857992562,
           -0.9578376162035364,
           -0.9509609793133736,
           -0.9460136927356172,
           -0.94303093601274,
           -0.9420342634699939,
           -0.9430309360127421,
           -0.9460136927356213,
           -0.9509609793133798,
           -0.9578376162035444,
           -0.966595857992572,
           -0.9771767697860488,
           -0.9895118301683807,
           -1.0035246640508146,
           -1.0191328121163392,
           -1.0362494546629457,
           -1.0547850238074998,
           -1.0746486564691242,
           -1.0957494588791423,
           -1.1179975697740991,
           -1.1413050228500963,
           -1.1655864190766891,
           -1.1907594261753636,
           -1.2167451263726248,
           -1.2434682350126793,
           -1.2708572123659172,
           -1.2988442895563792,
           -1.3273654274228284,
           -1.3563602246873758,
           -1.3857717892946888,
           -1.4155465843779327,
           -1.4456342581094004,
           -1.4759874647569127,
           -1.5065616826079995,
           -1.5373150330354552,
           -1.5682081038389384,
           -1.5992037790797102,
           -1.6302670768986678,
           -1.6613649962414183,
           -1.6924663729803344,
           -1.7235417455975568,
           -1.754563230353295,
           -1.785504405692516,
           -1.8163402055251616,
           -1.8470468209382207,
           -1.8776016098524098,
           -1.9079830141140588,
           -1.938170483507843,
           -1.9681444061834061,
           -1.9978860450049916,
           -2.027377479354994,
           -2.0566015519477943,
           -2.0855418202376526,
           -2.114182512032651,
           -2.14250848495486,
           -2.170505189414393,
           -2.198158634791461,
           -2.225455358545639,
           -2.252382397995149,
           -2.2789272645310312,
           -2.3050779200515095,
           -2.3308227554207672,
           -2.356150570773731,
           -2.3810505575044036,
           -2.405512281789897,
           -2.4295256695156136,
           -2.453080992479192,
           -2.4761688557618746,
           -2.4987801861660155,
           -2.5209062216265936,
           -2.54253850151286,
           -2.5636688577438336,
           -2.5842894066481477,
           -2.6043925415049847,
           -2.62397092570846,
           -2.6430174865029192,
           -2.661525409241271,
           -2.6794881321226685,
           -2.696899341369711,
           -2.713752966808785,
           -2.7300431778203618,
           -2.7457643796289193,
           -2.7609112099048034,
           -2.7754785356527285,
           -2.7894614503637816,
           -2.802855271409814,
           -2.8156555376609056,
           -2.8278580073082593,
           -2.839458655876406,
           -2.8504536744100046,
           -2.8608394678218056,
           -2.870612653389535,
           -2.8797700593905358,
           -2.8883087238640237,
           -2.896225893491745,
           -2.9035190225886853,
           -2.910185772196285,
           -2.916224009271369,
           -2.921631805964713,
           -2.9264074389838033,
           -2.9305493890350016,
           -2.9340563403408795,
           -2.9369271802290946,
           -2.939160998789661,
           -2.940757088598038,
           -2.941714944501901
          ],
          [
           -2.9520131075327343,
           -2.951693232778823,
           -2.950733710036222,
           -2.949134843892949,
           -2.9468971420980243,
           -2.944021315715746,
           -2.9405082793433315,
           -2.9363591513935257,
           -2.9315752544443257,
           -2.9261581156584557,
           -2.920109467275725,
           -2.9134312471819763,
           -2.9061255995588713,
           -2.8981948756193665,
           -2.8896416344343616,
           -2.8804686438566645,
           -2.870678881549128,
           -2.860275536124569,
           -2.8492620084059,
           -2.837641912815762,
           -2.825419078905906,
           -2.8125975530375618,
           -2.7991816002251557,
           -2.785175706156916,
           -2.770584579407189,
           -2.7554131538567366,
           -2.7396665913387577,
           -2.723350284530114,
           -2.7064698601090216,
           -2.6890311822024917,
           -2.6710403561489935,
           -2.65250373260419,
           -2.6334279120202617,
           -2.6138197495321798,
           -2.5936863602874984,
           -2.5730351252596897,
           -2.5518736975888903,
           -2.5302100094981426,
           -2.5080522798378317,
           -2.4854090223161576,
           -2.46228905447905,
           -2.438701507509174,
           -2.414655836920432,
           -2.390161834231907,
           -2.365229639713417,
           -2.3398697563039224,
           -2.3140930648140303,
           -2.2879108405347646,
           -2.261334771386801,
           -2.234376977757544,
           -2.207050034187804,
           -2.1793669930855497,
           -2.151341410661312,
           -2.1229873752983424,
           -2.0943195385906725,
           -2.0653531493037085,
           -2.036104090535001,
           -2.006588920377136,
           -1.9768249164102283,
           -1.9468301243778903,
           -1.9166234114274059,
           -1.8862245243214846,
           -1.8556541530545472,
           -1.8249340003297105,
           -1.794086857371893,
           -1.763136686565494,
           -1.7321087114090157,
           -1.7010295142700311,
           -1.6699271423971416,
           -1.6388312225948576,
           -1.607773084884801,
           -1.5767858953525082,
           -1.5459047982013068,
           -1.515167066788547,
           -1.4846122630872014,
           -1.454282404576714,
           -1.424222136997045,
           -1.394478910672459,
           -1.365103157198198,
           -1.3361484621553466,
           -1.30767172815133,
           -1.2797333208577752,
           -1.252397188830473,
           -1.2257309457682581,
           -1.1998059015551141,
           -1.1746970260399152,
           -1.1504828272154797,
           -1.1272451235213614,
           -1.1050686887668222,
           -1.084040748103027,
           -1.0642503050987842,
           -1.0457872838612383,
           -1.0287414768178365,
           -1.0132012986020473,
           -0.9992523595101913,
           -0.9869758877867836,
           -0.976447047499516,
           -0.9677332162603991,
           -0.9608923022356392,
           -0.9559711901595545,
           -0.9530044089755835,
           -0.9520131075327342,
           -0.9530044089755856,
           -0.9559711901595583,
           -0.9608923022356451,
           -0.9677332162604071,
           -0.976447047499526,
           -0.9869758877867952,
           -0.9992523595102046,
           -1.0132012986020624,
           -1.0287414768178533,
           -1.0457872838612567,
           -1.064250305098804,
           -1.0840407481030478,
           -1.1050686887668444,
           -1.1272451235213847,
           -1.150482827215504,
           -1.1746970260399403,
           -1.1998059015551406,
           -1.2257309457682852,
           -1.2523971888305008,
           -1.2797333208578032,
           -1.307671728151359,
           -1.336148462155376,
           -1.3651031571982275,
           -1.3944789106724895,
           -1.424222136997076,
           -1.454282404576745,
           -1.4846122630872332,
           -1.5151670667885784,
           -1.5459047982013383,
           -1.57678589535254,
           -1.6077730848848328,
           -1.6388312225948896,
           -1.6699271423971738,
           -1.7010295142700629,
           -1.7321087114090479,
           -1.7631366865655258,
           -1.7940868573719249,
           -1.824934000329742,
           -1.8556541530545783,
           -1.8862245243215159,
           -1.9166234114274372,
           -1.9468301243779214,
           -1.9768249164102587,
           -2.0065889203771663,
           -2.0361040905350314,
           -2.0653531493037387,
           -2.0943195385907023,
           -2.122987375298372,
           -2.151341410661341,
           -2.1793669930855786,
           -2.2070500341878323,
           -2.234376977757572,
           -2.2613347713868284,
           -2.2879108405347917,
           -2.3140930648140574,
           -2.3398697563039486,
           -2.365229639713443,
           -2.390161834231933,
           -2.4146558369204563,
           -2.4387015075091982,
           -2.462289054479074,
           -2.4854090223161807,
           -2.508052279837855,
           -2.530210009498165,
           -2.5518736975889125,
           -2.573035125259711,
           -2.5936863602875193,
           -2.6138197495322,
           -2.6334279120202813,
           -2.6525037326042096,
           -2.6710403561490126,
           -2.68903118220251,
           -2.706469860109039,
           -2.7233502845301314,
           -2.739666591338774,
           -2.755413153856753,
           -2.770584579407205,
           -2.7851757061569304,
           -2.7991816002251704,
           -2.812597553037575,
           -2.825419078905919,
           -2.837641912815774,
           -2.8492620084059115,
           -2.8602755361245804,
           -2.8706788815491384,
           -2.8804686438566742,
           -2.8896416344343705,
           -2.898194875619375,
           -2.9061255995588793,
           -2.913431247181984,
           -2.9201094672757315,
           -2.9261581156584615,
           -2.9315752544443314,
           -2.93635915139353,
           -2.940508279343336,
           -2.9440213157157498,
           -2.9468971420980266,
           -2.949134843892951,
           -2.950733710036223,
           -2.9516932327788243
          ],
          [
           -2.9610709403987285,
           -2.9607505643996306,
           -2.9597895383924087,
           -2.958188168378462,
           -2.9559469644643337,
           -2.953066641018828,
           -2.9495481168946363,
           -2.945392515716104,
           -2.9406011662352896,
           -2.9351756027589877,
           -2.929117565649867,
           -2.9224290019054666,
           -2.9151120658193315,
           -2.9071691197291902,
           -2.8986027348576964,
           -2.889415692251924,
           -2.8796109838285466,
           -2.869191813532357,
           -2.858161598616633,
           -2.8465239710547103,
           -2.8342827790930847,
           -2.82144208895738,
           -2.808006186723624,
           -2.7939795803684686,
           -2.7793670020132977,
           -2.764173410378581,
           -2.748403993466359,
           -2.7320641714904506,
           -2.715159600075772,
           -2.69769617375021,
           -2.679680029754638,
           -2.661117552199107,
           -2.6420153765958485,
           -2.6223803948026516,
           -2.6022197604133015,
           -2.581540894635306,
           -2.560351492698928,
           -2.538659530845764,
           -2.5164732739497437,
           -2.4938012838285224,
           -2.4706524283088194,
           -2.447035891115456,
           -2.4229611826605946,
           -2.3984381518171722,
           -2.373476998768702,
           -2.348088289036641,
           -2.322282968796425,
           -2.2960723816041284,
           -2.2694682866676077,
           -2.2424828788090125,
           -2.215128810279758,
           -2.1874192146045597,
           -2.1593677326479357,
           -2.130988541114812,
           -2.1022963837164794,
           -2.0733066052542024,
           -2.0440351888951485,
           -2.01449879693897,
           -1.984714815398039,
           -1.9547014027397178,
           -1.9244775431647503,
           -1.8940631048210563,
           -1.8634789033761185,
           -1.8327467713924108,
           -1.8018896339672457,
           -1.7709315911087642,
           -1.7398980073205996,
           -1.708815608855207,
           -1.6777125890650466,
           -1.6466187222255637,
           -1.6155654861163908,
           -1.5845861935176755,
           -1.5537161325950544,
           -1.5229927158949355,
           -1.4924556373342752,
           -1.462147036125584,
           -1.4321116660053816,
           -1.4023970674071868,
           -1.3730537393112845,
           -1.344135306386421,
           -1.3156986756900244,
           -1.2878041755985468,
           -1.2605156677977452,
           -1.2339006210979417,
           -1.208030133610739,
           -1.182978887540547,
           -1.1588250186809979,
           -1.1356498809176023,
           -1.113537684968805,
           -1.0925749906835844,
           -1.0728500339630438,
           -1.0544518733228574,
           -1.037469347750141,
           -1.0219898471552187,
           -1.0080979093898845,
           -0.9958736730509532,
           -0.9853912320771245,
           -0.9767169548168967,
           -0.9699078446009081,
           -0.9650100284326358,
           -0.9620574629199502,
           -0.9610709403987284,
           -0.9620574629199521,
           -0.9650100284326398,
           -0.9699078446009142,
           -0.9767169548169046,
           -0.9853912320771345,
           -0.9958736730509649,
           -1.0080979093898979,
           -1.0219898471552338,
           -1.0374693477501575,
           -1.0544518733228756,
           -1.0728500339630636,
           -1.0925749906836055,
           -1.1135376849688268,
           -1.1356498809176256,
           -1.1588250186810223,
           -1.182978887540572,
           -1.2080301336107653,
           -1.2339006210979686,
           -1.260515667797773,
           -1.2878041755985752,
           -1.3156986756900533,
           -1.34413530638645,
           -1.3730537393113145,
           -1.402397067407217,
           -1.4321116660054123,
           -1.462147036125615,
           -1.4924556373343065,
           -1.5229927158949672,
           -1.5537161325950866,
           -1.5845861935177072,
           -1.6155654861164226,
           -1.646618722225596,
           -1.6777125890650786,
           -1.708815608855239,
           -1.7398980073206314,
           -1.7709315911087957,
           -1.8018896339672774,
           -1.8327467713924424,
           -1.8634789033761496,
           -1.8940631048210874,
           -1.9244775431647811,
           -1.9547014027397487,
           -1.9847148153980696,
           -2.0144987969390007,
           -2.044035188895178,
           -2.0733066052542326,
           -2.1022963837165096,
           -2.1309885411148413,
           -2.1593677326479646,
           -2.187419214604588,
           -2.215128810279786,
           -2.24248287880904,
           -2.2694682866676357,
           -2.296072381604156,
           -2.3222829687964515,
           -2.348088289036667,
           -2.3734769987687283,
           -2.3984381518171976,
           -2.422961182660619,
           -2.44703589111548,
           -2.4706524283088434,
           -2.493801283828546,
           -2.516473273949767,
           -2.538659530845787,
           -2.5603514926989503,
           -2.5815408946353275,
           -2.6022197604133224,
           -2.622380394802672,
           -2.642015376595869,
           -2.661117552199126,
           -2.6796800297546572,
           -2.697696173750228,
           -2.71515960007579,
           -2.732064171490467,
           -2.748403993466376,
           -2.7641734103785964,
           -2.7793670020133123,
           -2.7939795803684833,
           -2.8080061867236386,
           -2.8214420889573932,
           -2.8342827790930976,
           -2.846523971054722,
           -2.858161598616645,
           -2.8691918135323675,
           -2.879610983828556,
           -2.8894156922519336,
           -2.8986027348577053,
           -2.907169119729199,
           -2.915112065819339,
           -2.9224290019054737,
           -2.929117565649874,
           -2.9351756027589935,
           -2.940601166235294,
           -2.945392515716108,
           -2.9495481168946402,
           -2.9530666410188315,
           -2.955946964464336,
           -2.9581881683784643,
           -2.95978953839241,
           -2.960750564399632
          ],
          [
           -2.9691989991996697,
           -2.968878176011151,
           -2.9679158088583253,
           -2.966312205011093,
           -2.964067876691841,
           -2.9611835412351186,
           -2.9576601213128226,
           -2.9534987452265793,
           -2.9487007472694797,
           -2.9432676681598444,
           -2.9372012555502254,
           -2.9305034646153856,
           -2.9231764587235975,
           -2.9152226101961696,
           -2.9066445011607946,
           -2.8974449245049385,
           -2.8876268849362527,
           -2.877193600157719,
           -2.8661485021661055,
           -2.85449523868314,
           -2.8422376747298137,
           -2.8293798943552098,
           -2.8159262025323915,
           -2.8018811272350694,
           -2.787249421710083,
           -2.772036066962148,
           -2.7562462744688774,
           -2.7398854891457427,
           -2.7229593925825237,
           -2.705473906574773,
           -2.687435196976026,
           -2.668849677898922,
           -2.6497240162960085,
           -2.630065136953908,
           -2.6098802279377145,
           -2.5891767465259576,
           -2.567962425680294,
           -2.54624528109833,
           -2.524033618902551,
           -2.501336044023473,
           -2.478161469340674,
           -2.454519125651541,
           -2.430418572544317,
           -2.4058697102594464,
           -2.380882792631411,
           -2.355468441212158,
           -2.3296376606871085,
           -2.303401855705463,
           -2.2767728492583386,
           -2.2497629027511588,
           -2.222384737930753,
           -2.1946515608429404,
           -2.166577088012928,
           -2.138175575058785,
           -2.1094618479675167,
           -2.0804513372838582,
           -2.0511601154837877,
           -2.021604937827753,
           -1.9918032870125573,
           -1.961773421965327,
           -1.9315344311476033,
           -1.9011062907615588,
           -1.8705099282727433,
           -1.83976729168327,
           -1.8089014250042454,
           -1.777936550384204,
           -1.7468981573483793,
           -1.7158130995879732,
           -1.684709699704234,
           -1.6536178622529625,
           -1.6225691953432146,
           -1.5915971409098282,
           -1.5607371135911865,
           -1.5300266478870637,
           -1.4995055529295347,
           -1.469216073753057,
           -1.4392030573754835,
           -1.4095141212753872,
           -1.3801998209468997,
           -1.3513138121063613,
           -1.322913001794308,
           -1.2950576810491445,
           -1.2678116300275877,
           -1.2412421844382002,
           -1.2154202499997233,
           -1.1904202494460876,
           -1.166319984549053,
           -1.1432003939684647,
           -1.121145186806316,
           -1.1002403319557543,
           -1.0805733851873092,
           -1.0622326399109212,
           -1.0453060941479568,
           -1.0298802357314942,
           -1.0160386601123834,
           -1.003860549924026,
           -0.9934190616332043,
           -0.9847796805689468,
           -0.9779986192731485,
           -0.9731213431154347,
           -0.9701813092936102,
           -0.9691989991996697,
           -0.9701813092936123,
           -0.9731213431154386,
           -0.9779986192731545,
           -0.9847796805689547,
           -0.9934190616332139,
           -1.0038605499240378,
           -1.0160386601123967,
           -1.0298802357315093,
           -1.0453060941479735,
           -1.0622326399109394,
           -1.0805733851873287,
           -1.1002403319557748,
           -1.1211451868063382,
           -1.1432003939684878,
           -1.1663199845490773,
           -1.1904202494461127,
           -1.2154202499997493,
           -1.2412421844382273,
           -1.2678116300276152,
           -1.2950576810491727,
           -1.3229130017943367,
           -1.3513138121063906,
           -1.38019982094693,
           -1.4095141212754176,
           -1.4392030573755141,
           -1.469216073753088,
           -1.4995055529295658,
           -1.530026647887095,
           -1.5607371135912183,
           -1.59159714090986,
           -1.6225691953432468,
           -1.653617862252995,
           -1.684709699704266,
           -1.7158130995880054,
           -1.7468981573484113,
           -1.7779365503842357,
           -1.8089014250042774,
           -1.8397672916833017,
           -1.870509928272775,
           -1.9011062907615903,
           -1.9315344311476343,
           -1.9617734219653582,
           -1.991803287012588,
           -2.0216049378277834,
           -2.051160115483818,
           -2.0804513372838884,
           -2.1094618479675464,
           -2.1381755750588143,
           -2.166577088012957,
           -2.1946515608429693,
           -2.2223847379307813,
           -2.2497629027511867,
           -2.276772849258366,
           -2.3034018557054896,
           -2.329637660687135,
           -2.3554684412121842,
           -2.3808827926314367,
           -2.4058697102594717,
           -2.4304185725443412,
           -2.4545191256515655,
           -2.4781614693406975,
           -2.5013360440234966,
           -2.5240336189025743,
           -2.546245281098353,
           -2.5679624256803164,
           -2.589176746525979,
           -2.609880227937736,
           -2.630065136953928,
           -2.649724016296029,
           -2.668849677898942,
           -2.6874351969760446,
           -2.7054739065747913,
           -2.7229593925825415,
           -2.739885489145759,
           -2.7562462744688943,
           -2.7720360669621646,
           -2.7872494217100985,
           -2.8018811272350845,
           -2.815926202532406,
           -2.829379894355223,
           -2.842237674729826,
           -2.8544952386831524,
           -2.866148502166118,
           -2.8771936001577307,
           -2.887626884936263,
           -2.8974449245049487,
           -2.9066445011608026,
           -2.915222610196178,
           -2.923176458723605,
           -2.930503464615393,
           -2.9372012555502316,
           -2.94326766815985,
           -2.948700747269485,
           -2.9534987452265846,
           -2.9576601213128266,
           -2.9611835412351217,
           -2.964067876691843,
           -2.966312205011094,
           -2.967915808858327,
           -2.968878176011151
          ],
          [
           -2.97638942056361,
           -2.976068203808789,
           -2.975104656331007,
           -2.973499086522444,
           -2.9712520084774585,
           -2.9683641421544857,
           -2.964836413604386,
           -2.960669955266891,
           -2.9558661063373415,
           -2.950426413206417,
           -2.9443526299760543,
           -2.937646719055373,
           -2.930310851840917,
           -2.9223474094862083,
           -2.913758983766206,
           -2.9045483780429446,
           -2.8947186083393808,
           -2.8842729045291957,
           -2.873214711651187,
           -2.8615476913577313,
           -2.8492757235077564,
           -2.8364029079157174,
           -2.8229335662691577,
           -2.8088722442286707,
           -2.7942237137253567,
           -2.7789929754723337,
           -2.7631852617083728,
           -2.7468060391934546,
           -2.729861012477856,
           -2.7123561274684342,
           -2.694297575317921,
           -2.675691796665519,
           -2.656545486259684,
           -2.636865597996893,
           -2.616659350413385,
           -2.595934232670323,
           -2.5746980110766837,
           -2.552958736198356,
           -2.5307247506065695,
           -2.5080046973238455,
           -2.484807529031228,
           -2.461142518106697,
           -2.437019267571392,
           -2.4124477230276717,
           -2.3874381856811526,
           -2.362001326547785,
           -2.336148201956795,
           -2.3098902704709974,
           -2.283239411357704,
           -2.2562079447562073,
           -2.228808653701722,
           -2.201054808180791,
           -2.172960191409505,
           -2.1445391285435638,
           -2.1158065180481143,
           -2.0867778659755563,
           -2.0574693234208783,
           -2.0278977274465673,
           -1.9980806457923723,
           -1.9680364257089498,
           -1.9377842472780327,
           -1.9073441816046701,
           -1.8767372542881415,
           -1.8459855145961421,
           -1.8151121107799266,
           -1.7841413719739914,
           -1.753098897119558,
           -1.722011651332729,
           -1.690908070100784,
           -1.659818171627474,
           -1.6287736775526298,
           -1.5978081421332928,
           -1.5669570897813099,
           -1.5362581605917824,
           -1.5057512631513361,
           -1.4754787334655517,
           -1.4454854982693206,
           -1.4158192402585714,
           -1.3865305618821668,
           -1.3576731432352853,
           -1.3293038882809116,
           -1.301483052083598,
           -1.2742743399742174,
           -1.24774496760463,
           -1.2219656687608755,
           -1.1970106356942753,
           -1.1729573747752273,
           -1.1498864587224376,
           -1.1278811558407866,
           -1.107026917023639,
           -1.087410703209558,
           -1.0691201400144876,
           -1.052242492814954,
           -1.0368634648967192,
           -1.023065833371175,
           -1.010927951931785,
           -1.0005221651732557,
           -0.9919131945640142,
           -0.9851565692222263,
           -0.9802971831588023,
           -0.9773680625587519,
           -0.9763894205636101,
           -0.977368062558754,
           -0.9802971831588063,
           -0.9851565692222322,
           -0.9919131945640222,
           -1.0005221651732656,
           -1.0109279519317966,
           -1.0230658333711884,
           -1.0368634648967343,
           -1.0522424928149705,
           -1.0691201400145056,
           -1.0874107032095774,
           -1.10702691702366,
           -1.1278811558408086,
           -1.1498864587224606,
           -1.1729573747752517,
           -1.1970106356943002,
           -1.2219656687609015,
           -1.2477449676046568,
           -1.2742743399742449,
           -1.3014830520836262,
           -1.3293038882809405,
           -1.357673143235315,
           -1.3865305618821966,
           -1.4158192402586016,
           -1.4454854982693512,
           -1.4754787334655828,
           -1.5057512631513672,
           -1.536258160591814,
           -1.5669570897813416,
           -1.5978081421333248,
           -1.6287736775526618,
           -1.6598181716275058,
           -1.690908070100816,
           -1.7220116513327612,
           -1.7530988971195895,
           -1.7841413719740231,
           -1.8151121107799584,
           -1.8459855145961737,
           -1.876737254288173,
           -1.9073441816047016,
           -1.9377842472780642,
           -1.9680364257089809,
           -1.9980806457924034,
           -2.027897727446598,
           -2.057469323420909,
           -2.0867778659755865,
           -2.115806518048144,
           -2.144539128543593,
           -2.1729601914095342,
           -2.2010548081808197,
           -2.2288086537017504,
           -2.2562079447562358,
           -2.283239411357731,
           -2.309890270471024,
           -2.3361482019568216,
           -2.362001326547811,
           -2.387438185681178,
           -2.4124477230276975,
           -2.4370192675714173,
           -2.4611425181067212,
           -2.4848075290312517,
           -2.508004697323869,
           -2.530724750606592,
           -2.5529587361983785,
           -2.574698011076706,
           -2.5959342326703445,
           -2.6166593504134057,
           -2.6368655979969136,
           -2.656545486259704,
           -2.675691796665539,
           -2.69429757531794,
           -2.7123561274684524,
           -2.729861012477875,
           -2.7468060391934714,
           -2.7631852617083896,
           -2.7789929754723497,
           -2.794223713725372,
           -2.808872244228685,
           -2.8229335662691715,
           -2.8364029079157307,
           -2.8492757235077693,
           -2.8615476913577433,
           -2.8732147116511983,
           -2.884272904529206,
           -2.894718608339391,
           -2.904548378042955,
           -2.913758983766215,
           -2.9223474094862167,
           -2.9303108518409244,
           -2.93764671905538,
           -2.944352629976061,
           -2.950426413206422,
           -2.9558661063373473,
           -2.9606699552668956,
           -2.9648364136043903,
           -2.9683641421544884,
           -2.971252008477461,
           -2.973499086522447,
           -2.975104656331008,
           -2.9760682038087904
          ],
          [
           -2.9826352482222664,
           -2.9823136911434576,
           -2.9813491230185547,
           -2.9797418532146627,
           -2.977492397452301,
           -2.974601477969253,
           -2.9710700237516376,
           -2.966899170833888,
           -2.962090262669821,
           -2.9566448505775313,
           -2.950564694261317,
           -2.9438517624144684,
           -2.936508233407278,
           -2.9285364960652696,
           -2.9199391505432835,
           -2.9107190093017272,
           -2.9008790981920507,
           -2.8904226576592467,
           -2.8793531440700426,
           -2.867674231176321,
           -2.855389811724257,
           -2.842503999220725,
           -2.829021129869625,
           -2.8149457646919798,
           -2.8002826918450077,
           -2.7850369291567674,
           -2.769213726894537,
           -2.7528185707868116,
           -2.7358571853206017,
           -2.7183355373377824,
           -2.7002598399564284,
           -2.6816365568454863,
           -2.6624724068837846,
           -2.642774369237288,
           -2.622549688891664,
           -2.601805882680726,
           -2.580550745855159,
           -2.5587923592400923,
           -2.5365390970347472,
           -2.5137996353124192,
           -2.4905829612846317,
           -2.466898383399416,
           -2.4427555423503686,
           -2.4181644230805293,
           -2.3931353678731813,
           -2.3676790906305643,
           -2.34180669245118,
           -2.315529678627016,
           -2.288859977193611,
           -2.2618099591785374,
           -2.2343924607076886,
           -2.206620807143654,
           -2.1785088394467103,
           -2.150070942966286,
           -2.121322078889516,
           -2.0922778185932995,
           -2.0629543811673337,
           -2.033368674397529,
           -2.003538339521928,
           -1.9734818000942476,
           -1.9432183153130336,
           -1.912768038196307,
           -1.8821520790015411,
           -1.8513925743074657,
           -1.8205127621857529,
           -1.7895370638947548,
           -1.758491172521104,
           -1.7274021489742675,
           -1.696298525699157,
           -1.6652104184063787,
           -1.634169646021051,
           -1.6032098589096704,
           -1.5723666752488727,
           -1.5416778251360825,
           -1.5111833016937235,
           -1.4809255179669094,
           -1.4509494678381243,
           -1.4213028884583214,
           -1.392036420798457,
           -1.3632037638364582,
           -1.3348618165940924,
           -1.307070800717396,
           -1.2798943545597803,
           -1.253399587809355,
           -1.2276570836665925,
           -1.202740833537791,
           -1.1787280873366333,
           -1.155699101025556,
           -1.1337367623044001,
           -1.1129260757651345,
           -1.0933534908326517,
           -1.0751060598682067,
           -1.0582704203274735,
           -1.0429316040773475,
           -1.0291716888313198,
           -1.017068320689994,
           -1.006693151983196,
           -0.9981102534792825,
           -0.9913745725948272,
           -0.9865305173501867,
           -0.9836107475038185,
           -0.9826352482222663,
           -0.9836107475038204,
           -0.9865305173501907,
           -0.9913745725948331,
           -0.9981102534792903,
           -1.0066931519832059,
           -1.0170683206900053,
           -1.0291716888313331,
           -1.0429316040773622,
           -1.05827042032749,
           -1.0751060598682247,
           -1.0933534908326712,
           -1.1129260757651553,
           -1.1337367623044219,
           -1.155699101025579,
           -1.1787280873366575,
           -1.2027408335378162,
           -1.227657083666619,
           -1.2533995878093818,
           -1.2798943545598076,
           -1.3070708007174239,
           -1.3348618165941213,
           -1.3632037638364876,
           -1.3920364207984868,
           -1.4213028884583514,
           -1.4509494678381551,
           -1.4809255179669405,
           -1.511183301693755,
           -1.5416778251361143,
           -1.5723666752489047,
           -1.6032098589097024,
           -1.6341696460210826,
           -1.665210418406411,
           -1.696298525699189,
           -1.7274021489742997,
           -1.7584911725211356,
           -1.7895370638947865,
           -1.8205127621857844,
           -1.851392574307497,
           -1.8821520790015727,
           -1.9127680381963386,
           -1.9432183153130649,
           -1.9734818000942786,
           -2.003538339521959,
           -2.0333686743975594,
           -2.062954381167364,
           -2.0922778185933297,
           -2.1213220788895457,
           -2.1500709429663156,
           -2.1785088394467396,
           -2.206620807143683,
           -2.2343924607077166,
           -2.2618099591785654,
           -2.2888599771936384,
           -2.3155296786270436,
           -2.341806692451207,
           -2.367679090630591,
           -2.3931353678732075,
           -2.4181644230805546,
           -2.4427555423503935,
           -2.4668983833994402,
           -2.4905829612846557,
           -2.5137996353124428,
           -2.5365390970347708,
           -2.5587923592401154,
           -2.5805507458551813,
           -2.6018058826807478,
           -2.622549688891685,
           -2.642774369237309,
           -2.6624724068838055,
           -2.6816365568455054,
           -2.700259839956448,
           -2.718335537337801,
           -2.7358571853206195,
           -2.752818570786829,
           -2.7692137268945536,
           -2.7850369291567834,
           -2.8002826918450237,
           -2.8149457646919944,
           -2.829021129869639,
           -2.8425039992207384,
           -2.8553898117242698,
           -2.8676742311763332,
           -2.879353144070054,
           -2.890422657659257,
           -2.900879098192061,
           -2.910719009301737,
           -2.9199391505432923,
           -2.9285364960652784,
           -2.9365082334072854,
           -2.943851762414475,
           -2.9505646942613235,
           -2.956644850577537,
           -2.9620902626698267,
           -2.966899170833892,
           -2.971070023751642,
           -2.9746014779692564,
           -2.9774923974523033,
           -2.979741853214665,
           -2.981349123018556,
           -2.9823136911434585
          ],
          [
           -2.987930439740759,
           -2.987608595250959,
           -2.9866431651684984,
           -2.9850344596870553,
           -2.9827829959058634,
           -2.979889497995208,
           -2.9763548974298066,
           -2.9721803332917665,
           -2.9673671526453345,
           -2.9619169109861416,
           -2.955831372768227,
           -2.9491125120126225,
           -2.941762513001938,
           -2.933783771065926,
           -2.925178893463706,
           -2.9159507003689975,
           -2.90610222596542,
           -2.8956367196597297,
           -2.8845576474216865,
           -2.872868693260103,
           -2.86057376084566,
           -2.847676975292037,
           -2.834182685108086,
           -2.8200954643349525,
           -2.805420114883397,
           -2.790161669087978,
           -2.774325392496329,
           -2.757916786913467,
           -2.7409415937229045,
           -2.723405797508371,
           -2.7053156300021706,
           -2.68667757438859,
           -2.6674983699934605,
           -2.647785017393841,
           -2.6275447839849813,
           -2.606785210045231,
           -2.5855141153433387,
           -2.5637396063368314,
           -2.541470084014746,
           -2.518714252443037,
           -2.4954811280765736,
           -2.47178004990769,
           -2.4476206905279967,
           -2.4230130681874558,
           -2.397967559942817,
           -2.372494915996318,
           -2.346606275335214,
           -2.320313182793274,
           -2.29362760766691,
           -2.2665619640311925,
           -2.239129132914632,
           -2.211342486506484,
           -2.1832159145862726,
           -2.154763853382518,
           -2.1260013170860126,
           -2.0969439322626404,
           -2.067607975431352,
           -2.038010414094493,
           -2.008168951529857,
           -1.9781020756763201,
           -1.947829112467018,
           -1.917370283985174,
           -1.8867467718366517,
           -1.8559807861488746,
           -1.8250956406160155,
           -1.7941158340129746,
           -1.7630671385926175,
           -1.731976695758069,
           -1.7008731193597073,
           -1.6697866068986034,
           -1.6387490588168665,
           -1.6077942059112174,
           -1.5769577447076752,
           -1.5462774803687311,
           -1.515793476353763,
           -1.4855482096000185,
           -1.4555867294146096,
           -1.425956817545103,
           -1.3967091460046943,
           -1.3678974281462977,
           -1.339578557191526,
           -1.3118127249181015,
           -1.2846635115008627,
           -1.2581979356193553,
           -1.23248645195555,
           -1.2076028812215454,
           -1.1836242560514276,
           -1.160630564706183,
           -1.1387043738942715,
           -1.1179303124937052,
           -1.0983944000159294,
           -1.0801832077267528,
           -1.0633828468195585,
           -1.048077787140478,
           -1.0343495216267093,
           -1.0222751053612562,
           -1.0119256129941716,
           -1.0033645727404419,
           -0.9966464473305362,
           -0.9918152400765299,
           -0.9889033057272915,
           -0.987930439740759,
           -0.9889033057272933,
           -0.9918152400765339,
           -0.9966464473305423,
           -1.0033645727404499,
           -1.0119256129941814,
           -1.0222751053612675,
           -1.0343495216267224,
           -1.0480777871404932,
           -1.063382846819575,
           -1.0801832077267708,
           -1.0983944000159487,
           -1.1179303124937259,
           -1.1387043738942935,
           -1.1606305647062058,
           -1.1836242560514516,
           -1.2076028812215704,
           -1.232486451955576,
           -1.2581979356193822,
           -1.2846635115008902,
           -1.31181272491813,
           -1.3395785571915548,
           -1.3678974281463272,
           -1.396709146004724,
           -1.4259568175451334,
           -1.45558672941464,
           -1.4855482096000494,
           -1.5157934763537941,
           -1.5462774803687624,
           -1.5769577447077066,
           -1.6077942059112493,
           -1.6387490588168983,
           -1.6697866068986353,
           -1.7008731193597388,
           -1.731976695758101,
           -1.7630671385926493,
           -1.7941158340130066,
           -1.8250956406160472,
           -1.8559807861489066,
           -1.8867467718366835,
           -1.917370283985206,
           -1.9478291124670493,
           -1.978102075676351,
           -2.008168951529888,
           -2.0380104140945234,
           -2.0676079754313825,
           -2.0969439322626706,
           -2.1260013170860423,
           -2.1547638533825477,
           -2.183215914586302,
           -2.2113424865065126,
           -2.2391291329146608,
           -2.2665619640312205,
           -2.2936276076669375,
           -2.3203131827933006,
           -2.346606275335241,
           -2.372494915996344,
           -2.3979675599428427,
           -2.423013068187481,
           -2.4476206905280216,
           -2.4717800499077143,
           -2.495481128076597,
           -2.5187142524430612,
           -2.5414700840147693,
           -2.5637396063368545,
           -2.5855141153433605,
           -2.6067852100452527,
           -2.627544783985002,
           -2.6477850173938604,
           -2.667498369993481,
           -2.6866775743886095,
           -2.705315630002189,
           -2.72340579750839,
           -2.740941593722922,
           -2.757916786913484,
           -2.7743253924963454,
           -2.7901616690879942,
           -2.805420114883413,
           -2.820095464334967,
           -2.8341826851081,
           -2.84767697529205,
           -2.8605737608456727,
           -2.872868693260115,
           -2.884557647421698,
           -2.8956367196597412,
           -2.90610222596543,
           -2.915950700369008,
           -2.9251788934637153,
           -2.9337837710659342,
           -2.941762513001946,
           -2.949112512012629,
           -2.955831372768233,
           -2.9619169109861474,
           -2.96736715264534,
           -2.972180333291772,
           -2.976354897429811,
           -2.9798894979952117,
           -2.982782995905866,
           -2.9850344596870566,
           -2.9866431651684993,
           -2.987608595250959
          ],
          [
           -2.9922698723632783,
           -2.9919477930973577,
           -2.9909816589122444,
           -2.989371780679016,
           -2.9871186766267956,
           -2.984223072509598,
           -2.980685901841596,
           -2.976508306202524,
           -2.971691635615422,
           -2.9662374489994625,
           -2.9601475147011156,
           -2.9534238111075037,
           -2.946068527346343,
           -2.9380840640775165,
           -2.9294730343819597,
           -2.920238264754224,
           -2.9103827962058255,
           -2.8999098854872556,
           -2.888823006437381,
           -2.8771258514698372,
           -2.864822333207003,
           -2.85191658627318,
           -2.838412969259705,
           -2.8243160668759884,
           -2.8096306923017393,
           -2.79436188975711,
           -2.778514937309035,
           -2.7620953499337655,
           -2.7451088828574113,
           -2.7275615351983835,
           -2.709459553937793,
           -2.690809438246311,
           -2.671617944198646,
           -2.651892089909673,
           -2.6316391611294407,
           -2.6108667173377893,
           -2.589582598383089,
           -2.5677949317138484,
           -2.545512140256517,
           -2.5227429509978716,
           -2.49949640433592,
           -2.4757818642693383,
           -2.4516090295021336,
           -2.4269879455475616,
           -2.4019290179233392,
           -2.3764430265389977,
           -2.3505411413858344,
           -2.3242349396504505,
           -2.2975364243843184,
           -2.270458044874336,
           -2.2430127188728806,
           -2.2152138568605992,
           -2.1870753885310243,
           -2.158611791703188,
           -2.1298381238866,
           -2.1007700567423604,
           -2.0714239137045056,
           -2.0418167110469407,
           -2.011966202703105,
           -1.9818909291674789,
           -1.9516102708296463,
           -1.9211445061120545,
           -1.8905148748008507,
           -1.859743646973801,
           -1.8288541979385347,
           -1.7978710895957524,
           -1.7668201586326002,
           -1.7357286119271829,
           -1.7046251295012753,
           -1.6735399752884694,
           -1.6425051158816242,
           -1.611554347277173,
           -1.5807234294331733,
           -1.5500502281894197,
           -1.519574863745452,
           -1.4893398644377,
           -1.4593903239797825,
           -1.4297740596082968,
           -1.4005417676880947,
           -1.3717471722555348,
           -1.3434471606999223,
           -1.3157018992960114,
           -1.2885749196134146,
           -1.2621331649754097,
           -1.2364469841873718,
           -1.211590057817378,
           -1.1876392405600265,
           -1.1646743018894659,
           -1.1427775466233605,
           -1.1220332975594423,
           -1.1025272244420972,
           -1.0843455076042767,
           -1.0675738310795801,
           -1.052296208995408,
           -1.0385936605622792,
           -1.026542762487529,
           -1.0162141221977552,
           -1.007670829388329,
           -1.0009669552651335,
           -0.996146176373397,
           -0.9932406012807955,
           -0.9922698723632783,
           -0.9932406012807976,
           -0.996146176373401,
           -1.0009669552651392,
           -1.007670829388337,
           -1.0162141221977652,
           -1.02654276248754,
           -1.0385936605622927,
           -1.0522962089954226,
           -1.0675738310795966,
           -1.0843455076042945,
           -1.1025272244421163,
           -1.122033297559463,
           -1.1427775466233827,
           -1.1646743018894887,
           -1.1876392405600504,
           -1.2115900578174028,
           -1.2364469841873977,
           -1.2621331649754366,
           -1.2885749196134422,
           -1.3157018992960394,
           -1.3434471606999507,
           -1.3717471722555636,
           -1.4005417676881247,
           -1.429774059608327,
           -1.459390323979813,
           -1.4893398644377311,
           -1.5195748637454831,
           -1.5500502281894515,
           -1.5807234294332049,
           -1.6115543472772043,
           -1.6425051158816564,
           -1.6735399752885014,
           -1.7046251295013073,
           -1.7357286119272148,
           -1.7668201586326322,
           -1.7978710895957843,
           -1.828854197938566,
           -1.8597436469738324,
           -1.8905148748008824,
           -1.9211445061120862,
           -1.9516102708296772,
           -1.9818909291675102,
           -2.0119662027031358,
           -2.0418167110469714,
           -2.0714239137045363,
           -2.1007700567423906,
           -2.1298381238866297,
           -2.158611791703217,
           -2.1870753885310537,
           -2.215213856860628,
           -2.243012718872909,
           -2.270458044874364,
           -2.2975364243843455,
           -2.3242349396504776,
           -2.3505411413858615,
           -2.3764430265390244,
           -2.401929017923365,
           -2.4269879455475873,
           -2.4516090295021584,
           -2.475781864269363,
           -2.4994964043359444,
           -2.522742950997895,
           -2.5455121402565397,
           -2.5677949317138715,
           -2.589582598383111,
           -2.610866717337811,
           -2.631639161129462,
           -2.651892089909693,
           -2.6716179441986667,
           -2.69080943824633,
           -2.709459553937811,
           -2.727561535198402,
           -2.745108882857429,
           -2.7620953499337824,
           -2.778514937309052,
           -2.794361889757126,
           -2.8096306923017558,
           -2.824316066876003,
           -2.8384129692597186,
           -2.8519165862731928,
           -2.864822333207016,
           -2.877125851469849,
           -2.8888230064373928,
           -2.8999098854872667,
           -2.9103827962058357,
           -2.920238264754234,
           -2.9294730343819686,
           -2.9380840640775245,
           -2.9460685273463505,
           -2.9534238111075113,
           -2.9601475147011223,
           -2.966237448999468,
           -2.9716916356154277,
           -2.9765083062025286,
           -2.9806859018416,
           -2.9842230725096006,
           -2.987118676626798,
           -2.9893717806790177,
           -2.990981658912246,
           -2.9919477930973586
          ],
          [
           -2.99564934796902,
           -2.9953270863346497,
           -2.9943604052199713,
           -2.9927496160236116,
           -2.990495237854647,
           -2.9875979977004854,
           -2.9840588306636056,
           -2.97987888026886,
           -2.975059498843553,
           -2.9696022479730426,
           -2.9635088990351424,
           -2.9567814338171656,
           -2.949422045220048,
           -2.941433138054585,
           -2.932817329935496,
           -2.9235774522796887,
           -2.913716551415862,
           -2.903237889813341,
           -2.892144947438885,
           -2.880441423251118,
           -2.86813123684318,
           -2.8552185302452617,
           -2.8417076698997823,
           -2.827603248823229,
           -2.8129100889699608,
           -2.7976332438147544,
           -2.781778001172396,
           -2.7653498862743566,
           -2.7483546651244355,
           -2.730798348157272,
           -2.7126871942258606,
           -2.6940277149466088,
           -2.6748266794331395,
           -2.655091119452936,
           -2.634828335044102,
           -2.614045900633005,
           -2.5927516716973904,
           -2.570953792023735,
           -2.548660701612219,
           -2.525881145287752,
           -2.50262418208099,
           -2.478899195449414,
           -2.4547159044151443,
           -2.4300843757035224,
           -2.4050150369744703,
           -2.3795186912474153,
           -2.3536065326301627,
           -2.327290163472566,
           -2.3005816130772683,
           -2.273493358112243,
           -2.2460383448833445,
           -2.218230013639697,
           -2.1900823251005432,
           -2.16160978940906,
           -2.132827497736777,
           -2.103751156781359,
           -2.0743971264207044,
           -2.0447824608072556,
           -2.0149249532079123,
           -1.9848431849165384,
           -1.954556578587209,
           -1.9240854563562768,
           -1.8934511031389545,
           -1.862675835500047,
           -1.8317830765068959,
           -1.8007974369730422,
           -1.769744803490626,
           -1.7386524336241043,
           -1.7075490585925923,
           -1.67646499369685,
           -1.6454322566419592,
           -1.6144846937587625,
           -1.5836581139247867,
           -1.5529904297152166,
           -1.5225218049606726,
           -1.4922948074330395,
           -1.4623545648032277,
           -1.4327489212940667,
           -1.4035285915657822,
           -1.3747473073008933,
           -1.3464619506849782,
           -1.318732667504192,
           -1.291622950909974,
           -1.2651996850703229,
           -1.2395331360034292,
           -1.2146968749871612,
           -1.1907676182278923,
           -1.1678249651931367,
           -1.1459510174753014,
           -1.125229860636624,
           -1.1057468936119312,
           -1.0875879943424585,
           -1.0708385167390009,
           -1.055582123019843,
           -1.0418994668517394,
           -1.029866756059681,
           -1.0195542380052116,
           -1.0110246646185324,
           -1.0043318056742327,
           -0.9995190862355928,
           -0.99661842546098,
           -0.9956493479690199,
           -0.9966184254609819,
           -0.9995190862355966,
           -1.0043318056742387,
           -1.0110246646185401,
           -1.0195542380052218,
           -1.0298667560596924,
           -1.0418994668517525,
           -1.0555821230198579,
           -1.0708385167390173,
           -1.0875879943424764,
           -1.1057468936119508,
           -1.1252298606366447,
           -1.1459510174753231,
           -1.1678249651931598,
           -1.1907676182279163,
           -1.2146968749871863,
           -1.2395331360034552,
           -1.2651996850703497,
           -1.2916229509100017,
           -1.3187326675042201,
           -1.346461950685007,
           -1.3747473073009226,
           -1.403528591565812,
           -1.4327489212940974,
           -1.4623545648032583,
           -1.4922948074330704,
           -1.5225218049607039,
           -1.552990429715248,
           -1.5836581139248185,
           -1.6144846937587944,
           -1.6454322566419912,
           -1.676464993696882,
           -1.7075490585926245,
           -1.738652433624136,
           -1.769744803490658,
           -1.8007974369730737,
           -1.8317830765069276,
           -1.8626758355000785,
           -1.8934511031389858,
           -1.9240854563563086,
           -1.9545565785872399,
           -1.984843184916569,
           -2.0149249532079434,
           -2.0447824608072858,
           -2.0743971264207346,
           -2.1037511567813887,
           -2.132827497736807,
           -2.161609789409089,
           -2.190082325100572,
           -2.218230013639726,
           -2.246038344883373,
           -2.273493358112271,
           -2.300581613077296,
           -2.3272901634725933,
           -2.3536065326301903,
           -2.379518691247441,
           -2.4050150369744965,
           -2.4300843757035477,
           -2.454715904415169,
           -2.4788991954494386,
           -2.5026241820810142,
           -2.5258811452877756,
           -2.5486607016122425,
           -2.5709537920237575,
           -2.5927516716974126,
           -2.614045900633026,
           -2.634828335044123,
           -2.655091119452957,
           -2.67482667943316,
           -2.6940277149466283,
           -2.7126871942258792,
           -2.7307983481572906,
           -2.748354665124453,
           -2.765349886274374,
           -2.7817780011724125,
           -2.797633243814771,
           -2.8129100889699763,
           -2.827603248823244,
           -2.841707669899797,
           -2.8552185302452755,
           -2.8681312368431926,
           -2.8804414232511295,
           -2.8921449474388967,
           -2.9032378898133517,
           -2.913716551415872,
           -2.923577452279698,
           -2.932817329935505,
           -2.941433138054594,
           -2.949422045220056,
           -2.9567814338171727,
           -2.963508899035149,
           -2.969602247973049,
           -2.9750594988435584,
           -2.9798788802688647,
           -2.9840588306636096,
           -2.9875979977004894,
           -2.9904952378546494,
           -2.9927496160236142,
           -2.994360405219973,
           -2.995327086334651
          ],
          [
           -2.9980655971335954,
           -2.997743205361963,
           -2.996776133961177,
           -2.9951646947070567,
           -2.992909407337824,
           -2.9900109997227386,
           -2.986470408099886,
           -2.9822887773848334,
           -2.977467461552377,
           -2.9720080240941265,
           -2.965912238555217,
           -2.9591820891539893,
           -2.951819771489098,
           -2.943827693339079,
           -2.935208475560109,
           -2.92596495308835,
           -2.916100176054008,
           -2.9056174110150397,
           -2.894520142319258,
           -2.8828120736044935,
           -2.8704971294474397,
           -2.8575794571728688,
           -2.8440634288359874,
           -2.82995364339199,
           -2.815254929068126,
           -2.7999723459550885,
           -2.7841111888360657,
           -2.767676990273505,
           -2.7506755239755245,
           -2.7331128084658904,
           -2.7149951110837334,
           -2.6963289523415876,
           -2.677121110672966,
           -2.6573786276036344,
           -2.637108813383865,
           -2.6163192531225006,
           -2.5950178134674244,
           -2.573212649881254,
           -2.550912214565665,
           -2.528125265092798,
           -2.5048608738077216,
           -2.4811284380720133,
           -2.456937691425164,
           -2.4322987157477995,
           -2.4072219545187403,
           -2.3817182272666186,
           -2.3557987453263856,
           -2.3294751290214637,
           -2.3027594264036977,
           -2.2756641336956465,
           -2.248202217593224,
           -2.2203871396012245,
           -2.192232882589995,
           -2.163753979778318,
           -2.1349655463655686,
           -2.1058833140552267,
           -2.076523668731843,
           -2.0469036915743186,
           -2.017041203909629,
           -1.986954816132462,
           -1.9566639810370938,
           -1.926189051927359,
           -1.8955513458878055,
           -1.864773212612541,
           -1.833878109196109,
           -1.8028906812905625,
           -1.7718368510215954,
           -1.7407439120303565,
           -1.7096406319612993,
           -1.67855736264411,
           -1.6475261581116478,
           -1.6165809004466916,
           -1.5857574332467457,
           -1.555093702224913,
           -1.524629902110084,
           -1.4944086285535976,
           -1.4644750331720822,
           -1.4348769791362739,
           -1.4056651938317397,
           -1.3768934140503784,
           -1.3486185179068382,
           -1.3209006362068387,
           -1.2938032343358041,
           -1.2673931539209635,
           -1.241740601616894,
           -1.2169190704871937,
           -1.1930051777743136,
           -1.1700784016029575,
           -1.1482206986583867,
           -1.1275159854936365,
           -1.1080494682674913,
           -1.0899068098172549,
           -1.0731731293774398,
           -1.0579318391533965,
           -1.0442633332556117,
           -1.0322435577136568,
           -1.0219425044662152,
           -1.0134226859343587,
           -1.0067376582198766,
           -1.0019306681693896,
           -0.9990335007415136,
           -0.9980655971335952,
           -0.9990335007415155,
           -1.0019306681693936,
           -1.0067376582198824,
           -1.0134226859343665,
           -1.0219425044662247,
           -1.0322435577136684,
           -1.0442633332556248,
           -1.0579318391534116,
           -1.0731731293774562,
           -1.0899068098172728,
           -1.1080494682675108,
           -1.1275159854936576,
           -1.1482206986584085,
           -1.1700784016029806,
           -1.1930051777743373,
           -1.216919070487219,
           -1.24174060161692,
           -1.2673931539209902,
           -1.2938032343358317,
           -1.3209006362068667,
           -1.348618517906867,
           -1.3768934140504083,
           -1.4056651938317695,
           -1.4348769791363043,
           -1.4644750331721126,
           -1.4944086285536282,
           -1.5246299021101155,
           -1.5550937022249443,
           -1.585757433246777,
           -1.6165809004467233,
           -1.64752615811168,
           -1.6785573626441417,
           -1.7096406319613315,
           -1.7407439120303887,
           -1.7718368510216274,
           -1.8028906812905945,
           -1.8338781091961411,
           -1.8647732126125722,
           -1.8955513458878372,
           -1.9261890519273905,
           -1.9566639810371251,
           -1.9869548161324928,
           -2.0170412039096592,
           -2.0469036915743493,
           -2.0765236687318733,
           -2.105883314055257,
           -2.1349655463655983,
           -2.1637539797783476,
           -2.1922328825900244,
           -2.220387139601253,
           -2.2482022175932523,
           -2.275664133695675,
           -2.302759426403725,
           -2.3294751290214912,
           -2.355798745326412,
           -2.3817182272666453,
           -2.4072219545187665,
           -2.432298715747825,
           -2.456937691425188,
           -2.4811284380720386,
           -2.504860873807746,
           -2.5281252650928216,
           -2.5509122145656886,
           -2.5732126498812766,
           -2.595017813467447,
           -2.6163192531225223,
           -2.637108813383886,
           -2.6573786276036553,
           -2.677121110672987,
           -2.6963289523416063,
           -2.7149951110837525,
           -2.733112808465908,
           -2.7506755239755423,
           -2.767676990273522,
           -2.784111188836083,
           -2.7999723459551054,
           -2.815254929068141,
           -2.8299536433920043,
           -2.8440634288360016,
           -2.8575794571728825,
           -2.870497129447453,
           -2.8828120736045055,
           -2.8945201423192697,
           -2.9056174110150503,
           -2.916100176054018,
           -2.92596495308836,
           -2.9352084755601178,
           -2.9438276933390872,
           -2.951819771489106,
           -2.959182089153997,
           -2.9659122385552235,
           -2.9720080240941322,
           -2.9774674615523824,
           -2.9822887773848388,
           -2.9864704080998905,
           -2.990010999722742,
           -2.9929094073378266,
           -2.995164694707058,
           -2.9967761339611787,
           -2.9977432053619633
          ],
          [
           -2.9995162822919883,
           -2.99919381248834,
           -2.9982265070669647,
           -2.9966146780301406,
           -2.9943588454938235,
           -2.9914597378567254,
           -2.9879182920387337,
           -2.9837356537903816,
           -2.978913178075594,
           -2.973452429530464,
           -2.967355183001345,
           -2.960623424166123,
           -2.953259350243103,
           -2.9452653707925838,
           -2.936644108616832,
           -2.927398400764866,
           -2.917531299649202,
           -2.9070460742824737,
           -2.895946211642714,
           -2.8842354181769543,
           -2.8719176214537945,
           -2.858996971976608,
           -2.84547784517022,
           -2.831364843555071,
           -2.816662799124249,
           -2.8013767759401778,
           -2.7855120729693343,
           -2.769074227175071,
           -2.7520690168904713,
           -2.7345024654952086,
           -2.716380845422573,
           -2.697710682525281,
           -2.67849876083132,
           -2.658752127723974,
           -2.6384780995833665,
           -2.6176842679303594,
           -2.5963785061174174,
           -2.5745689766152857,
           -2.552264138948904,
           -2.52947275834101,
           -2.5062039151274442,
           -2.4824670150141936,
           -2.4582718002529123,
           -2.4336283618188848,
           -2.4085471526834494,
           -2.3830390022815795,
           -2.3571151322849007,
           -2.330787173800865,
           -2.3040671861301374,
           -2.2769676772266525,
           -2.249501626018197,
           -2.2216825067599046,
           -2.1935243156086845,
           -2.1650415996233967,
           -2.1362494884134815,
           -2.107163728677727,
           -2.0778007218947394,
           -2.048177565447374,
           -2.018312097484485,
           -1.9882229458445537,
           -1.9579295813864206,
           -1.9274523760916529,
           -1.8968126663200582,
           -1.8660328216129798,
           -1.8351363194464896,
           -1.8041478263360182,
           -1.7730932856822252,
           -1.7420000127211368,
           -1.7108967968947564,
           -1.6798140118854155,
           -1.6487837334503515,
           -1.6178398650431534,
           -1.587018271004504,
           -1.5563569168327083,
           -1.525896015689237,
           -1.4956781798380243,
           -1.4657485751398567,
           -1.4361550760036526,
           -1.4069484173138251,
           -1.3781823387879242,
           -1.3499137159574668,
           -1.3222026705027836,
           -1.2951126510211852,
           -1.268710473502024,
           -1.2430663088911926,
           -1.218253603265246,
           -1.1943489144721593,
           -1.1714316478683584,
           -1.1495836732972278,
           -1.1288888060846423,
           -1.1094321369873812,
           -1.0912992001355921,
           -1.074574974406585,
           -1.0593427225355803,
           -1.0456826835142758,
           -1.0336706469673362,
           -1.0233764522812274,
           -1.0148624688668106,
           -1.008182125270955,
           -1.0033785619707922,
           -1.0004834838382897,
           -0.9995162822919884,
           -1.0004834838382919,
           -1.003378561970796,
           -1.008182125270961,
           -1.0148624688668184,
           -1.0233764522812367,
           -1.0336706469673478,
           -1.045682683514289,
           -1.0593427225355954,
           -1.0745749744066013,
           -1.0912992001356099,
           -1.1094321369874003,
           -1.1288888060846627,
           -1.1495836732972495,
           -1.1714316478683813,
           -1.194348914472183,
           -1.218253603265271,
           -1.2430663088912186,
           -1.268710473502051,
           -1.2951126510212128,
           -1.3222026705028118,
           -1.3499137159574954,
           -1.3781823387879535,
           -1.4069484173138551,
           -1.4361550760036828,
           -1.465748575139887,
           -1.4956781798380554,
           -1.525896015689268,
           -1.55635691683274,
           -1.5870182710045353,
           -1.6178398650431849,
           -1.648783733450383,
           -1.6798140118854474,
           -1.7108967968947881,
           -1.7420000127211688,
           -1.7730932856822574,
           -1.8041478263360502,
           -1.8351363194465218,
           -1.8660328216130115,
           -1.89681266632009,
           -1.9274523760916846,
           -1.9579295813864523,
           -1.9882229458445848,
           -2.0183120974845155,
           -2.048177565447405,
           -2.0778007218947696,
           -2.1071637286777567,
           -2.1362494884135113,
           -2.165041599623426,
           -2.193524315608714,
           -2.2216825067599335,
           -2.249501626018225,
           -2.2769676772266805,
           -2.304067186130165,
           -2.330787173800892,
           -2.3571151322849273,
           -2.3830390022816057,
           -2.408547152683475,
           -2.43362836181891,
           -2.4582718002529367,
           -2.482467015014218,
           -2.506203915127468,
           -2.5294727583410346,
           -2.552264138948927,
           -2.5745689766153084,
           -2.5963785061174396,
           -2.6176842679303816,
           -2.6384780995833874,
           -2.658752127723994,
           -2.678498760831341,
           -2.6977106825253006,
           -2.7163808454225915,
           -2.734502465495227,
           -2.7520690168904887,
           -2.7690742271750874,
           -2.7855120729693503,
           -2.8013767759401937,
           -2.8166627991242645,
           -2.8313648435550856,
           -2.8454778451702336,
           -2.8589969719766217,
           -2.8719176214538074,
           -2.8842354181769667,
           -2.8959462116427255,
           -2.907046074282485,
           -2.9175312996492124,
           -2.9273984007648757,
           -2.9366441086168407,
           -2.9452653707925927,
           -2.9532593502431106,
           -2.9606234241661307,
           -2.9673551830013514,
           -2.97345242953047,
           -2.9789131780755995,
           -2.983735653790386,
           -2.9879182920387377,
           -2.991459737856729,
           -2.994358845493826,
           -2.996614678030142,
           -2.9982265070669656,
           -2.999193812488341
          ],
          [
           -3,
           -2.999677504194068,
           -2.9987101207910003,
           -2.997098161868588,
           -2.9948421476687392,
           -2.991942806766705,
           -2.988401076309713,
           -2.9842181023267096,
           -2.9793952401114328,
           -2.9739340546815924,
           -2.96783632131742,
           -2.96110402618347,
           -2.9537393670380996,
           -2.9457447540357156,
           -2.9371228106274834,
           -2.927876374566925,
           -2.918008499027559,
           -2.907522453840494,
           -2.8964217268607664,
           -2.8847100254720894,
           -2.872391278240657,
           -2.8594696367296866,
           -2.845949477487531,
           -2.831835404223384,
           -2.817132250185963,
           -2.8018450807619644,
           -2.7859791963126668,
           -2.769540135268778,
           -2.7525336775054314,
           -2.73496584802134,
           -2.716842920948255,
           -2.6981714239193764,
           -2.678958142827934,
           -2.659210127010139,
           -2.6389346948898282,
           -2.6181394401256193,
           -2.596832238305251,
           -2.5750212542359208,
           -2.5527149498840433,
           -2.5299220930229334,
           -2.5066517666523693,
           -2.4829133792601352,
           -2.4587166760022225,
           -2.4340717508857153,
           -2.4089890600463186,
           -2.3834794362212492,
           -2.3575541045277544,
           -2.3312246996679384,
           -2.3045032846919513,
           -2.2774023714639533,
           -2.2499349429886575,
           -2.2221144777707926,
           -2.193954976395436,
           -2.1654709905339162,
           -2.1366776545979196,
           -2.1075907202832984,
           -2.078226594265017,
           -2.0486023793252537,
           -2.0187359192177876,
           -1.9886458475929094,
           -1.958351641327715,
           -1.9278736786258825,
           -1.8972333022679102,
           -1.8664528884058247,
           -1.8355559213037362,
           -1.8045670744249098,
           -1.7735122982541318,
           -1.742418915217197,
           -1.711315722012353,
           -1.6802330995953667,
           -1.649203130952895,
           -1.6182597266487537,
           -1.5874387579232352,
           -1.5567781968534804,
           -1.5263182627274532,
           -1.4961015733274858,
           -1.4661732992419205,
           -1.4365813186040413,
           -1.4073763687752252,
           -1.378612190424997,
           -1.350345658200505,
           -1.3226368907175428,
           -1.295549330956093,
           -1.2691497863407857,
           -1.2435084158996748,
           -1.2186986500373664,
           -1.1947970268011252,
           -1.1718829272976403,
           -1.1500381924401608,
           -1.1293466038419477,
           -1.109893213836369,
           -1.091763513710301,
           -1.0750424356299084,
           -1.0598131925963747,
           -1.0461559719972728,
           -1.034146511433914,
           -1.023854599558435,
           -1.015342558226969,
           -1.0086637735756747,
           -1.003861350718125,
           -1.0009669679025603,
           -0.9999999999999999,
           -1.0009669679025626,
           -1.0038613507181289,
           -1.0086637735756805,
           -1.015342558226977,
           -1.023854599558445,
           -1.0341465114339252,
           -1.0461559719972862,
           -1.0598131925963896,
           -1.0750424356299246,
           -1.0917635137103192,
           -1.1098932138363884,
           -1.1293466038419684,
           -1.1500381924401826,
           -1.1718829272976632,
           -1.1947970268011494,
           -1.2186986500373913,
           -1.2435084158997007,
           -1.2691497863408125,
           -1.2955493309561206,
           -1.3226368907175707,
           -1.350345658200534,
           -1.3786121904250266,
           -1.4073763687752552,
           -1.4365813186040717,
           -1.4661732992419512,
           -1.4961015733275167,
           -1.5263182627274845,
           -1.5567781968535117,
           -1.5874387579232667,
           -1.6182597266487855,
           -1.649203130952927,
           -1.6802330995953987,
           -1.7113157220123851,
           -1.742418915217229,
           -1.773512298254164,
           -1.8045670744249418,
           -1.835555921303768,
           -1.8664528884058562,
           -1.8972333022679417,
           -1.9278736786259139,
           -1.9583516413277464,
           -1.9886458475929405,
           -2.0187359192178183,
           -2.0486023793252843,
           -2.078226594265047,
           -2.1075907202833286,
           -2.1366776545979493,
           -2.165470990533946,
           -2.1939549763954647,
           -2.2221144777708215,
           -2.2499349429886855,
           -2.2774023714639813,
           -2.3045032846919793,
           -2.331224699667965,
           -2.3575541045277815,
           -2.3834794362212763,
           -2.408989060046345,
           -2.4340717508857406,
           -2.4587166760022474,
           -2.4829133792601596,
           -2.5066517666523938,
           -2.529922093022957,
           -2.5527149498840664,
           -2.5750212542359434,
           -2.5968322383052733,
           -2.61813944012564,
           -2.638934694889849,
           -2.6592101270101605,
           -2.678958142827954,
           -2.698171423919396,
           -2.7168429209482743,
           -2.734965848021358,
           -2.752533677505449,
           -2.7695401352687954,
           -2.7859791963126836,
           -2.80184508076198,
           -2.8171322501859786,
           -2.8318354042233986,
           -2.8459494774875456,
           -2.8594696367297003,
           -2.87239127824067,
           -2.884710025472102,
           -2.8964217268607775,
           -2.9075224538405053,
           -2.9180084990275703,
           -2.927876374566935,
           -2.9371228106274923,
           -2.945744754035725,
           -2.9537393670381076,
           -2.9611040261834765,
           -2.9678363213174266,
           -2.9739340546815987,
           -2.979395240111438,
           -2.9842181023267145,
           -2.9884010763097173,
           -2.9919428067667075,
           -2.9948421476687415,
           -2.997098161868591,
           -2.998710120791002,
           -2.9996775041940684
          ],
          [
           -2.9995162822919874,
           -2.9991938124883393,
           -2.9982265070669634,
           -2.9966146780301397,
           -2.9943588454938226,
           -2.9914597378567245,
           -2.987918292038733,
           -2.9837356537903807,
           -2.9789131780755933,
           -2.973452429530463,
           -2.9673551830013443,
           -2.9606234241661222,
           -2.953259350243102,
           -2.945265370792583,
           -2.936644108616831,
           -2.927398400764865,
           -2.9175312996492013,
           -2.907046074282473,
           -2.895946211642713,
           -2.8842354181769534,
           -2.8719176214537936,
           -2.858996971976607,
           -2.845477845170219,
           -2.83136484355507,
           -2.8166627991242477,
           -2.801376775940177,
           -2.785512072969333,
           -2.76907422717507,
           -2.7520690168904705,
           -2.7345024654952077,
           -2.716380845422572,
           -2.69771068252528,
           -2.678498760831319,
           -2.658752127723973,
           -2.6384780995833657,
           -2.6176842679303585,
           -2.5963785061174165,
           -2.5745689766152853,
           -2.5522641389489027,
           -2.5294727583410097,
           -2.506203915127443,
           -2.482467015014193,
           -2.458271800252911,
           -2.4336283618188834,
           -2.4085471526834485,
           -2.383039002281578,
           -2.3571151322848993,
           -2.3307871738008643,
           -2.3040671861301365,
           -2.2769676772266516,
           -2.249501626018196,
           -2.2216825067599033,
           -2.1935243156086837,
           -2.165041599623396,
           -2.1362494884134806,
           -2.1071637286777256,
           -2.0778007218947385,
           -2.0481775654473737,
           -2.018312097484484,
           -1.9882229458445528,
           -1.95792958138642,
           -1.9274523760916522,
           -1.8968126663200575,
           -1.8660328216129791,
           -1.835136319446489,
           -1.8041478263360171,
           -1.7730932856822246,
           -1.742000012721136,
           -1.7108967968947555,
           -1.6798140118854143,
           -1.6487837334503503,
           -1.6178398650431522,
           -1.5870182710045027,
           -1.5563569168327078,
           -1.5258960156892358,
           -1.4956781798380234,
           -1.4657485751398558,
           -1.4361550760036517,
           -1.4069484173138243,
           -1.3781823387879233,
           -1.349913715957466,
           -1.322202670502783,
           -1.2951126510211846,
           -1.2687104735020232,
           -1.2430663088911917,
           -1.2182536032652451,
           -1.1943489144721584,
           -1.1714316478683575,
           -1.1495836732972267,
           -1.1288888060846414,
           -1.1094321369873803,
           -1.091299200135591,
           -1.074574974406584,
           -1.0593427225355796,
           -1.0456826835142747,
           -1.0336706469673353,
           -1.0233764522812263,
           -1.0148624688668098,
           -1.0081821252709542,
           -1.0033785619707911,
           -1.0004834838382888,
           -0.9995162822919874,
           -1.0004834838382908,
           -1.0033785619707951,
           -1.0081821252709602,
           -1.0148624688668175,
           -1.0233764522812359,
           -1.0336706469673467,
           -1.0456826835142883,
           -1.0593427225355945,
           -1.0745749744066007,
           -1.091299200135609,
           -1.1094321369873994,
           -1.128888806084662,
           -1.1495836732972486,
           -1.1714316478683806,
           -1.1943489144721824,
           -1.2182536032652702,
           -1.2430663088912177,
           -1.2687104735020498,
           -1.295112651021212,
           -1.3222026705028112,
           -1.3499137159574945,
           -1.3781823387879526,
           -1.4069484173138542,
           -1.436155076003682,
           -1.4657485751398864,
           -1.4956781798380545,
           -1.5258960156892671,
           -1.556356916832739,
           -1.5870182710045346,
           -1.617839865043184,
           -1.648783733450382,
           -1.6798140118854465,
           -1.7108967968947875,
           -1.742000012721168,
           -1.7730932856822563,
           -1.804147826336049,
           -1.835136319446521,
           -1.8660328216130109,
           -1.896812666320089,
           -1.9274523760916837,
           -1.9579295813864512,
           -1.988222945844584,
           -2.0183120974845146,
           -2.048177565447404,
           -2.0778007218947687,
           -2.107163728677756,
           -2.1362494884135104,
           -2.1650415996234247,
           -2.193524315608713,
           -2.221682506759932,
           -2.2495016260182243,
           -2.2769676772266796,
           -2.304067186130164,
           -2.3307871738008914,
           -2.357115132284927,
           -2.3830390022816044,
           -2.4085471526834747,
           -2.433628361818909,
           -2.458271800252936,
           -2.4824670150142176,
           -2.5062039151274673,
           -2.529472758341033,
           -2.5522641389489262,
           -2.5745689766153075,
           -2.596378506117439,
           -2.6176842679303807,
           -2.638478099583387,
           -2.6587521277239934,
           -2.67849876083134,
           -2.6977106825252997,
           -2.7163808454225906,
           -2.7345024654952264,
           -2.752069016890488,
           -2.7690742271750866,
           -2.7855120729693494,
           -2.801376775940193,
           -2.8166627991242636,
           -2.8313648435550847,
           -2.8454778451702327,
           -2.8589969719766204,
           -2.8719176214538065,
           -2.884235418176966,
           -2.8959462116427246,
           -2.907046074282484,
           -2.9175312996492115,
           -2.927398400764875,
           -2.9366441086168398,
           -2.9452653707925918,
           -2.9532593502431097,
           -2.96062342416613,
           -2.9673551830013505,
           -2.973452429530469,
           -2.9789131780755986,
           -2.983735653790385,
           -2.987918292038737,
           -2.991459737856728,
           -2.994358845493825,
           -2.996614678030141,
           -2.9982265070669647,
           -2.99919381248834
          ],
          [
           -2.998065597133593,
           -2.997743205361961,
           -2.9967761339611747,
           -2.995164694707055,
           -2.992909407337822,
           -2.990010999722737,
           -2.986470408099884,
           -2.9822887773848317,
           -2.977467461552375,
           -2.9720080240941247,
           -2.9659122385552146,
           -2.959182089153987,
           -2.951819771489096,
           -2.943827693339077,
           -2.935208475560107,
           -2.925964953088348,
           -2.9161001760540057,
           -2.905617411015038,
           -2.8945201423192564,
           -2.8828120736044913,
           -2.8704971294474384,
           -2.8575794571728665,
           -2.8440634288359856,
           -2.829953643391988,
           -2.8152549290681237,
           -2.7999723459550867,
           -2.7841111888360635,
           -2.7676769902735034,
           -2.7506755239755223,
           -2.7331128084658878,
           -2.714995111083731,
           -2.6963289523415854,
           -2.6771211106729647,
           -2.6573786276036326,
           -2.6371088133838625,
           -2.616319253122499,
           -2.5950178134674227,
           -2.5732126498812526,
           -2.5509122145656633,
           -2.5281252650927963,
           -2.5048608738077194,
           -2.4811284380720116,
           -2.456937691425162,
           -2.4322987157477978,
           -2.4072219545187385,
           -2.381718227266617,
           -2.3557987453263833,
           -2.3294751290214624,
           -2.302759426403696,
           -2.275664133695645,
           -2.2482022175932217,
           -2.2203871396012227,
           -2.1922328825899933,
           -2.1637539797783165,
           -2.134965546365567,
           -2.105883314055225,
           -2.0765236687318414,
           -2.0469036915743173,
           -2.017041203909627,
           -1.9869548161324602,
           -1.9566639810370923,
           -1.926189051927357,
           -1.8955513458878037,
           -1.864773212612539,
           -1.8338781091961076,
           -1.8028906812905607,
           -1.7718368510215938,
           -1.7407439120303547,
           -1.7096406319612978,
           -1.678557362644108,
           -1.647526158111646,
           -1.6165809004466898,
           -1.585757433246744,
           -1.555093702224911,
           -1.5246299021100826,
           -1.4944086285535954,
           -1.4644750331720802,
           -1.434876979136272,
           -1.4056651938317377,
           -1.376893414050377,
           -1.3486185179068364,
           -1.320900636206837,
           -1.2938032343358024,
           -1.2673931539209615,
           -1.2417406016168921,
           -1.2169190704871917,
           -1.1930051777743116,
           -1.170078401602956,
           -1.1482206986583847,
           -1.127515985493635,
           -1.1080494682674895,
           -1.0899068098172529,
           -1.073173129377438,
           -1.057931839153395,
           -1.0442633332556095,
           -1.0322435577136548,
           -1.0219425044662132,
           -1.013422685934357,
           -1.0067376582198746,
           -1.0019306681693876,
           -0.9990335007415116,
           -0.9980655971335932,
           -0.9990335007415135,
           -1.0019306681693916,
           -1.0067376582198806,
           -1.0134226859343647,
           -1.021942504466223,
           -1.0322435577136662,
           -1.044263333255623,
           -1.0579318391534096,
           -1.0731731293774545,
           -1.0899068098172708,
           -1.1080494682675088,
           -1.1275159854936554,
           -1.1482206986584067,
           -1.1700784016029786,
           -1.1930051777743358,
           -1.2169190704872168,
           -1.2417406016169181,
           -1.2673931539209884,
           -1.2938032343358299,
           -1.3209006362068652,
           -1.3486185179068648,
           -1.376893414050406,
           -1.4056651938317677,
           -1.4348769791363025,
           -1.4644750331721108,
           -1.4944086285536264,
           -1.5246299021101137,
           -1.5550937022249425,
           -1.5857574332467756,
           -1.6165809004467215,
           -1.647526158111678,
           -1.6785573626441401,
           -1.7096406319613295,
           -1.7407439120303867,
           -1.7718368510216258,
           -1.8028906812905925,
           -1.8338781091961394,
           -1.8647732126125705,
           -1.8955513458878352,
           -1.9261890519273885,
           -1.9566639810371236,
           -1.9869548161324915,
           -2.0170412039096575,
           -2.0469036915743475,
           -2.076523668731872,
           -2.105883314055255,
           -2.1349655463655965,
           -2.163753979778346,
           -2.192232882590022,
           -2.220387139601251,
           -2.24820221759325,
           -2.2756641336956736,
           -2.3027594264037234,
           -2.3294751290214895,
           -2.3557987453264104,
           -2.381718227266643,
           -2.4072219545187648,
           -2.432298715747823,
           -2.456937691425187,
           -2.481128438072036,
           -2.5048608738077434,
           -2.5281252650928194,
           -2.550912214565686,
           -2.573212649881275,
           -2.5950178134674453,
           -2.616319253122521,
           -2.637108813383884,
           -2.6573786276036526,
           -2.6771211106729846,
           -2.696328952341605,
           -2.7149951110837502,
           -2.7331128084659064,
           -2.75067552397554,
           -2.7676769902735208,
           -2.7841111888360803,
           -2.7999723459551036,
           -2.8152549290681397,
           -2.8299536433920025,
           -2.8440634288359994,
           -2.8575794571728803,
           -2.870497129447451,
           -2.8828120736045033,
           -2.894520142319268,
           -2.905617411015049,
           -2.916100176054016,
           -2.925964953088358,
           -2.935208475560116,
           -2.9438276933390854,
           -2.951819771489104,
           -2.9591820891539946,
           -2.9659122385552212,
           -2.9720080240941305,
           -2.977467461552381,
           -2.982288777384837,
           -2.9864704080998883,
           -2.99001099972274,
           -2.9929094073378244,
           -2.9951646947070563,
           -2.9967761339611765,
           -2.9977432053619615
          ],
          [
           -2.995649347969017,
           -2.995327086334647,
           -2.994360405219968,
           -2.992749616023609,
           -2.990495237854644,
           -2.9875979977004823,
           -2.9840588306636024,
           -2.9798788802688576,
           -2.97505949884355,
           -2.9696022479730395,
           -2.9635088990351393,
           -2.9567814338171625,
           -2.949422045220045,
           -2.9414331380545824,
           -2.9328173299354927,
           -2.9235774522796856,
           -2.9137165514158587,
           -2.903237889813338,
           -2.892144947438882,
           -2.880441423251115,
           -2.8681312368431775,
           -2.8552185302452586,
           -2.8417076698997796,
           -2.827603248823226,
           -2.8129100889699576,
           -2.797633243814752,
           -2.7817780011723925,
           -2.765349886274354,
           -2.7483546651244324,
           -2.7307983481572693,
           -2.7126871942258584,
           -2.694027714946606,
           -2.674826679433137,
           -2.655091119452934,
           -2.634828335044099,
           -2.6140459006330024,
           -2.5927516716973877,
           -2.570953792023732,
           -2.5486607016122163,
           -2.5258811452877494,
           -2.5026241820809876,
           -2.478899195449411,
           -2.4547159044151416,
           -2.4300843757035198,
           -2.405015036974467,
           -2.379518691247412,
           -2.35360653263016,
           -2.3272901634725636,
           -2.3005816130772656,
           -2.2734933581122405,
           -2.246038344883342,
           -2.218230013639695,
           -2.1900823251005406,
           -2.161609789409057,
           -2.1328274977367743,
           -2.1037511567813567,
           -2.0743971264207017,
           -2.044782460807253,
           -2.0149249532079097,
           -1.984843184916535,
           -1.954556578587206,
           -1.9240854563562744,
           -1.893451103138952,
           -1.8626758355000446,
           -1.8317830765068936,
           -1.8007974369730397,
           -1.7697448034906236,
           -1.7386524336241016,
           -1.7075490585925897,
           -1.6764649936968472,
           -1.6454322566419566,
           -1.6144846937587598,
           -1.583658113924784,
           -1.552990429715214,
           -1.52252180496067,
           -1.4922948074330369,
           -1.462354564803225,
           -1.4327489212940643,
           -1.4035285915657796,
           -1.3747473073008907,
           -1.3464619506849758,
           -1.3187326675041893,
           -1.2916229509099717,
           -1.2651996850703202,
           -1.2395331360034265,
           -1.2146968749871583,
           -1.1907676182278895,
           -1.167824965193134,
           -1.1459510174752985,
           -1.1252298606366211,
           -1.1057468936119286,
           -1.0875879943424553,
           -1.070838516738998,
           -1.0555821230198403,
           -1.0418994668517363,
           -1.029866756059678,
           -1.019554238005209,
           -1.0110246646185297,
           -1.0043318056742299,
           -0.9995190862355898,
           -0.996618425460977,
           -0.9956493479690169,
           -0.9966184254609789,
           -0.9995190862355938,
           -1.0043318056742356,
           -1.0110246646185372,
           -1.019554238005219,
           -1.0298667560596892,
           -1.0418994668517496,
           -1.0555821230198552,
           -1.0708385167390144,
           -1.0875879943424736,
           -1.105746893611948,
           -1.125229860636642,
           -1.1459510174753205,
           -1.1678249651931571,
           -1.1907676182279134,
           -1.2146968749871834,
           -1.2395331360034523,
           -1.2651996850703469,
           -1.291622950909999,
           -1.3187326675042175,
           -1.3464619506850044,
           -1.37474730730092,
           -1.4035285915658096,
           -1.4327489212940945,
           -1.4623545648032557,
           -1.4922948074330677,
           -1.5225218049607012,
           -1.552990429715245,
           -1.5836581139248158,
           -1.6144846937587916,
           -1.6454322566419888,
           -1.6764649936968794,
           -1.7075490585926216,
           -1.7386524336241336,
           -1.7697448034906553,
           -1.8007974369730715,
           -1.831783076506925,
           -1.8626758355000763,
           -1.8934511031389836,
           -1.9240854563563061,
           -1.9545565785872374,
           -1.9848431849165666,
           -2.0149249532079407,
           -2.044782460807283,
           -2.074397126420732,
           -2.103751156781387,
           -2.132827497736804,
           -2.1616097894090864,
           -2.1900823251005694,
           -2.2182300136397237,
           -2.24603834488337,
           -2.2734933581122685,
           -2.3005816130772927,
           -2.3272901634725907,
           -2.353606532630187,
           -2.379518691247439,
           -2.4050150369744934,
           -2.4300843757035455,
           -2.4547159044151665,
           -2.478899195449436,
           -2.5026241820810116,
           -2.5258811452877725,
           -2.54866070161224,
           -2.570953792023755,
           -2.5927516716974104,
           -2.6140459006330237,
           -2.63482833504412,
           -2.6550911194529534,
           -2.6748266794331568,
           -2.6940277149466247,
           -2.7126871942258766,
           -2.7307983481572875,
           -2.74835466512445,
           -2.765349886274371,
           -2.78177800117241,
           -2.7976332438147677,
           -2.812910088969974,
           -2.8276032488232405,
           -2.841707669899794,
           -2.8552185302452724,
           -2.8681312368431904,
           -2.8804414232511264,
           -2.8921449474388936,
           -2.903237889813349,
           -2.91371655141587,
           -2.9235774522796953,
           -2.932817329935502,
           -2.941433138054591,
           -2.949422045220053,
           -2.9567814338171696,
           -2.963508899035146,
           -2.9696022479730457,
           -2.9750594988435553,
           -2.979878880268862,
           -2.9840588306636064,
           -2.9875979977004863,
           -2.9904952378546463,
           -2.992749616023611,
           -2.99436040521997,
           -2.995327086334648
          ],
          [
           -2.9922698723632744,
           -2.9919477930973533,
           -2.990981658912241,
           -2.9893717806790114,
           -2.9871186766267916,
           -2.984223072509594,
           -2.980685901841592,
           -2.97650830620252,
           -2.971691635615418,
           -2.9662374489994585,
           -2.9601475147011116,
           -2.9534238111074997,
           -2.946068527346339,
           -2.938084064077512,
           -2.9294730343819557,
           -2.92023826475422,
           -2.9103827962058215,
           -2.8999098854872516,
           -2.888823006437377,
           -2.8771258514698332,
           -2.8648223332069995,
           -2.8519165862731755,
           -2.8384129692597004,
           -2.8243160668759844,
           -2.8096306923017362,
           -2.794361889757106,
           -2.7785149373090317,
           -2.762095349933761,
           -2.7451088828574077,
           -2.72756153519838,
           -2.709459553937789,
           -2.6908094382463066,
           -2.6716179441986423,
           -2.6518920899096687,
           -2.631639161129437,
           -2.6108667173377857,
           -2.5895825983830854,
           -2.567794931713845,
           -2.5455121402565135,
           -2.522742950997868,
           -2.499496404335917,
           -2.4757818642693348,
           -2.45160902950213,
           -2.426987945547557,
           -2.401929017923336,
           -2.376443026538994,
           -2.3505411413858313,
           -2.3242349396504465,
           -2.297536424384314,
           -2.270458044874332,
           -2.243012718872877,
           -2.2152138568605957,
           -2.187075388531021,
           -2.158611791703184,
           -2.1298381238865964,
           -2.1007700567423573,
           -2.071423913704502,
           -2.041816711046937,
           -2.0119662027031016,
           -1.9818909291674753,
           -1.9516102708296423,
           -1.9211445061120511,
           -1.8905148748008473,
           -1.8597436469737973,
           -1.828854197938531,
           -1.7978710895957488,
           -1.7668201586325967,
           -1.7357286119271793,
           -1.704625129501272,
           -1.673539975288466,
           -1.6425051158816208,
           -1.6115543472771692,
           -1.58072342943317,
           -1.5500502281894164,
           -1.5195748637454487,
           -1.4893398644376967,
           -1.4593903239797792,
           -1.4297740596082933,
           -1.4005417676880911,
           -1.371747172255531,
           -1.3434471606999185,
           -1.3157018992960077,
           -1.288574919613411,
           -1.2621331649754062,
           -1.236446984187368,
           -1.2115900578173744,
           -1.1876392405600227,
           -1.1646743018894623,
           -1.1427775466233567,
           -1.1220332975594385,
           -1.1025272244420932,
           -1.0843455076042727,
           -1.0675738310795764,
           -1.0522962089954042,
           -1.0385936605622754,
           -1.026542762487525,
           -1.0162141221977512,
           -1.007670829388325,
           -1.0009669552651295,
           -0.9961461763733932,
           -0.9932406012807915,
           -0.9922698723632744,
           -0.9932406012807936,
           -0.9961461763733972,
           -1.0009669552651355,
           -1.0076708293883327,
           -1.0162141221977612,
           -1.0265427624875363,
           -1.0385936605622887,
           -1.0522962089954186,
           -1.0675738310795928,
           -1.084345507604291,
           -1.1025272244421125,
           -1.1220332975594591,
           -1.142777546623379,
           -1.1646743018894852,
           -1.1876392405600467,
           -1.2115900578173993,
           -1.2364469841873942,
           -1.2621331649754328,
           -1.2885749196134386,
           -1.3157018992960359,
           -1.3434471606999472,
           -1.3717471722555603,
           -1.400541767688121,
           -1.4297740596083237,
           -1.4593903239798096,
           -1.4893398644377276,
           -1.5195748637454798,
           -1.5500502281894477,
           -1.5807234294332015,
           -1.6115543472772007,
           -1.6425051158816528,
           -1.673539975288498,
           -1.704625129501304,
           -1.7357286119272113,
           -1.7668201586326289,
           -1.7978710895957808,
           -1.8288541979385624,
           -1.8597436469738293,
           -1.8905148748008793,
           -1.9211445061120827,
           -1.9516102708296739,
           -1.9818909291675064,
           -2.0119662027031326,
           -2.041816711046968,
           -2.0714239137045323,
           -2.1007700567423875,
           -2.1298381238866257,
           -2.1586117917032137,
           -2.1870753885310505,
           -2.215213856860624,
           -2.2430127188729054,
           -2.27045804487436,
           -2.297536424384342,
           -2.3242349396504736,
           -2.350541141385858,
           -2.376443026539021,
           -2.401929017923362,
           -2.426987945547583,
           -2.451609029502155,
           -2.475781864269359,
           -2.4994964043359413,
           -2.522742950997892,
           -2.545512140256536,
           -2.5677949317138675,
           -2.5895825983831076,
           -2.6108667173378066,
           -2.6316391611294576,
           -2.6518920899096896,
           -2.671617944198663,
           -2.690809438246326,
           -2.7094595539378075,
           -2.727561535198398,
           -2.745108882857426,
           -2.7620953499337784,
           -2.7785149373090485,
           -2.7943618897571225,
           -2.809630692301751,
           -2.824316066875999,
           -2.8384129692597146,
           -2.851916586273189,
           -2.8648223332070124,
           -2.877125851469845,
           -2.8888230064373888,
           -2.8999098854872627,
           -2.9103827962058317,
           -2.92023826475423,
           -2.9294730343819646,
           -2.9380840640775205,
           -2.9460685273463465,
           -2.9534238111075073,
           -2.9601475147011183,
           -2.966237448999464,
           -2.9716916356154237,
           -2.976508306202524,
           -2.980685901841596,
           -2.9842230725095966,
           -2.9871186766267943,
           -2.9893717806790137,
           -2.990981658912242,
           -2.9919477930973546
          ],
          [
           -2.987930439740754,
           -2.987608595250954,
           -2.986643165168493,
           -2.9850344596870504,
           -2.9827829959058585,
           -2.9798894979952033,
           -2.9763548974298017,
           -2.9721803332917616,
           -2.9673671526453296,
           -2.9619169109861367,
           -2.9558313727682215,
           -2.9491125120126176,
           -2.941762513001933,
           -2.9337837710659214,
           -2.925178893463702,
           -2.9159507003689926,
           -2.9061022259654146,
           -2.895636719659725,
           -2.884557647421681,
           -2.872868693260098,
           -2.860573760845655,
           -2.847676975292033,
           -2.8341826851080807,
           -2.8200954643349476,
           -2.805420114883392,
           -2.790161669087973,
           -2.7743253924963236,
           -2.757916786913462,
           -2.7409415937228996,
           -2.7234057975083665,
           -2.705315630002166,
           -2.686677574388585,
           -2.667498369993456,
           -2.647785017393836,
           -2.6275447839849764,
           -2.6067852100452265,
           -2.5855141153433334,
           -2.5637396063368274,
           -2.541470084014741,
           -2.518714252443033,
           -2.4954811280765683,
           -2.4717800499076854,
           -2.4476206905279922,
           -2.4230130681874513,
           -2.397967559942812,
           -2.3724949159963136,
           -2.3466062753352093,
           -2.320313182793269,
           -2.293627607666906,
           -2.266561964031188,
           -2.239129132914628,
           -2.2113424865064792,
           -2.183215914586268,
           -2.1547638533825135,
           -2.126001317086008,
           -2.096943932262636,
           -2.067607975431348,
           -2.0380104140944884,
           -2.0081689515298526,
           -1.9781020756763155,
           -1.947829112467014,
           -1.9173702839851698,
           -1.8867467718366475,
           -1.8559807861488704,
           -1.825095640616011,
           -1.7941158340129704,
           -1.7630671385926133,
           -1.7319766957580647,
           -1.7008731193597029,
           -1.669786606898599,
           -1.6387490588168618,
           -1.6077942059112134,
           -1.5769577447076704,
           -1.5462774803687267,
           -1.5157934763537586,
           -1.485548209600014,
           -1.4555867294146057,
           -1.4259568175450985,
           -1.3967091460046899,
           -1.3678974281462934,
           -1.3395785571915217,
           -1.311812724918097,
           -1.2846635115008584,
           -1.258197935619351,
           -1.2324864519555456,
           -1.2076028812215407,
           -1.1836242560514232,
           -1.160630564706178,
           -1.1387043738942668,
           -1.1179303124937006,
           -1.0983944000159247,
           -1.0801832077267481,
           -1.0633828468195539,
           -1.0480777871404732,
           -1.0343495216267045,
           -1.022275105361251,
           -1.0119256129941667,
           -1.003364572740437,
           -0.9966464473305312,
           -0.9918152400765249,
           -0.9889033057272865,
           -0.987930439740754,
           -0.9889033057272884,
           -0.9918152400765288,
           -0.9966464473305373,
           -1.0033645727404448,
           -1.0119256129941765,
           -1.0222751053612626,
           -1.034349521626718,
           -1.0480777871404883,
           -1.0633828468195705,
           -1.0801832077267661,
           -1.098394400015944,
           -1.1179303124937212,
           -1.1387043738942888,
           -1.1606305647062014,
           -1.1836242560514474,
           -1.2076028812215658,
           -1.2324864519555714,
           -1.2581979356193775,
           -1.2846635115008858,
           -1.3118127249181255,
           -1.3395785571915504,
           -1.3678974281463225,
           -1.3967091460047198,
           -1.4259568175451292,
           -1.455586729414636,
           -1.4855482096000452,
           -1.5157934763537897,
           -1.546277480368758,
           -1.5769577447077021,
           -1.6077942059112447,
           -1.6387490588168938,
           -1.6697866068986313,
           -1.7008731193597348,
           -1.7319766957580964,
           -1.763067138592645,
           -1.794115834013002,
           -1.8250956406160426,
           -1.855980786148902,
           -1.886746771836679,
           -1.9173702839852016,
           -1.9478291124670453,
           -1.9781020756763468,
           -2.0081689515298833,
           -2.038010414094519,
           -2.0676079754313785,
           -2.096943932262666,
           -2.126001317086038,
           -2.154763853382543,
           -2.183215914586297,
           -2.211342486506508,
           -2.239129132914656,
           -2.266561964031216,
           -2.293627607666933,
           -2.320313182793296,
           -2.3466062753352364,
           -2.3724949159963393,
           -2.397967559942838,
           -2.423013068187476,
           -2.447620690528017,
           -2.4717800499077103,
           -2.4954811280765923,
           -2.518714252443056,
           -2.5414700840147644,
           -2.5637396063368496,
           -2.585514115343356,
           -2.6067852100452478,
           -2.6275447839849972,
           -2.647785017393856,
           -2.667498369993476,
           -2.686677574388604,
           -2.7053156300021843,
           -2.7234057975083847,
           -2.740941593722917,
           -2.7579167869134795,
           -2.774325392496341,
           -2.790161669087989,
           -2.8054201148834084,
           -2.8200954643349623,
           -2.8341826851080953,
           -2.847676975292046,
           -2.8605737608456674,
           -2.87286869326011,
           -2.8845576474216927,
           -2.895636719659736,
           -2.906102225965425,
           -2.915950700369003,
           -2.9251788934637104,
           -2.9337837710659294,
           -2.941762513001941,
           -2.9491125120126243,
           -2.955831372768228,
           -2.9619169109861425,
           -2.967367152645335,
           -2.972180333291767,
           -2.976354897429806,
           -2.979889497995207,
           -2.9827829959058607,
           -2.9850344596870517,
           -2.9866431651684944,
           -2.987608595250954
          ],
          [
           -2.9826352482222607,
           -2.982313691143452,
           -2.981349123018549,
           -2.979741853214657,
           -2.977492397452295,
           -2.9746014779692467,
           -2.971070023751632,
           -2.966899170833882,
           -2.962090262669815,
           -2.956644850577525,
           -2.950564694261311,
           -2.9438517624144627,
           -2.936508233407271,
           -2.9285364960652633,
           -2.9199391505432772,
           -2.910719009301722,
           -2.900879098192045,
           -2.89042265765924,
           -2.8793531440700373,
           -2.8676742311763155,
           -2.8553898117242507,
           -2.8425039992207193,
           -2.829021129869619,
           -2.8149457646919744,
           -2.8002826918450023,
           -2.7850369291567607,
           -2.769213726894531,
           -2.7528185707868063,
           -2.7358571853205964,
           -2.718335537337777,
           -2.700259839956423,
           -2.681636556845481,
           -2.6624724068837784,
           -2.6427743692372827,
           -2.622549688891658,
           -2.6018058826807207,
           -2.5805507458551538,
           -2.558792359240087,
           -2.5365390970347423,
           -2.5137996353124143,
           -2.4905829612846264,
           -2.46689838339941,
           -2.4427555423503633,
           -2.4181644230805235,
           -2.3931353678731764,
           -2.3676790906305594,
           -2.3418066924511747,
           -2.315529678627011,
           -2.2888599771936056,
           -2.2618099591785326,
           -2.2343924607076824,
           -2.2066208071436493,
           -2.178508839446705,
           -2.1500709429662805,
           -2.1213220788895106,
           -2.092277818593294,
           -2.0629543811673283,
           -2.033368674397524,
           -2.0035383395219233,
           -1.9734818000942425,
           -1.943218315313028,
           -1.9127680381963017,
           -1.882152079001536,
           -1.8513925743074606,
           -1.8205127621857473,
           -1.7895370638947494,
           -1.7584911725210988,
           -1.7274021489742626,
           -1.6962985256991518,
           -1.665210418406374,
           -1.634169646021046,
           -1.6032098589096653,
           -1.5723666752488679,
           -1.5416778251360774,
           -1.5111833016937184,
           -1.480925517966904,
           -1.4509494678381194,
           -1.4213028884583159,
           -1.392036420798452,
           -1.3632037638364527,
           -1.3348618165940873,
           -1.3070708007173903,
           -1.2798943545597747,
           -1.2533995878093496,
           -1.227657083666587,
           -1.2027408335377856,
           -1.1787280873366277,
           -1.1556991010255504,
           -1.1337367623043946,
           -1.112926075765129,
           -1.0933534908326457,
           -1.075106059868201,
           -1.0582704203274678,
           -1.0429316040773415,
           -1.0291716888313143,
           -1.0170683206899882,
           -1.0066931519831903,
           -0.9981102534792766,
           -0.9913745725948213,
           -0.9865305173501808,
           -0.9836107475038126,
           -0.9826352482222604,
           -0.9836107475038147,
           -0.9865305173501848,
           -0.9913745725948274,
           -0.9981102534792846,
           -1.0066931519832,
           -1.0170683206899995,
           -1.0291716888313276,
           -1.0429316040773564,
           -1.0582704203274842,
           -1.075106059868219,
           -1.0933534908326654,
           -1.1129260757651498,
           -1.1337367623044166,
           -1.1556991010255737,
           -1.1787280873366517,
           -1.2027408335378107,
           -1.2276570836666132,
           -1.2533995878093764,
           -1.2798943545598023,
           -1.3070708007174185,
           -1.3348618165941162,
           -1.3632037638364825,
           -1.3920364207984814,
           -1.4213028884583463,
           -1.4509494678381496,
           -1.4809255179669352,
           -1.5111833016937495,
           -1.5416778251361087,
           -1.5723666752488996,
           -1.6032098589096972,
           -1.634169646021078,
           -1.6652104184064058,
           -1.6962985256991838,
           -1.727402148974295,
           -1.7584911725211307,
           -1.7895370638947814,
           -1.8205127621857793,
           -1.8513925743074922,
           -1.8821520790015678,
           -1.9127680381963335,
           -1.9432183153130596,
           -1.9734818000942733,
           -2.003538339521954,
           -2.0333686743975545,
           -2.0629543811673585,
           -2.0922778185933244,
           -2.1213220788895404,
           -2.1500709429663103,
           -2.1785088394467342,
           -2.2066208071436777,
           -2.2343924607077112,
           -2.2618099591785605,
           -2.2888599771936335,
           -2.3155296786270387,
           -2.3418066924512013,
           -2.3676790906305856,
           -2.393135367873202,
           -2.4181644230805492,
           -2.4427555423503877,
           -2.466898383399435,
           -2.4905829612846504,
           -2.5137996353124374,
           -2.536539097034765,
           -2.558792359240109,
           -2.5805507458551755,
           -2.601805882680742,
           -2.622549688891679,
           -2.642774369237303,
           -2.6624724068837997,
           -2.6816365568455,
           -2.7002598399564426,
           -2.7183355373377953,
           -2.7358571853206137,
           -2.752818570786823,
           -2.7692137268945483,
           -2.7850369291567776,
           -2.8002826918450174,
           -2.814945764691988,
           -2.8290211298696337,
           -2.842503999220733,
           -2.8553898117242635,
           -2.8676742311763275,
           -2.879353144070049,
           -2.8904226576592515,
           -2.900879098192055,
           -2.910719009301731,
           -2.919939150543286,
           -2.928536496065272,
           -2.936508233407279,
           -2.9438517624144693,
           -2.9505646942613177,
           -2.9566448505775305,
           -2.962090262669821,
           -2.9668991708338863,
           -2.9710700237516363,
           -2.9746014779692507,
           -2.9774923974522975,
           -2.9797418532146587,
           -2.9813491230185503,
           -2.9823136911434522
          ],
          [
           -2.9763894205636032,
           -2.9760682038087825,
           -2.9751046563309997,
           -2.9734990865224376,
           -2.9712520084774514,
           -2.9683641421544786,
           -2.964836413604379,
           -2.960669955266884,
           -2.955866106337335,
           -2.9504264132064097,
           -2.9443526299760476,
           -2.9376467190553663,
           -2.93031085184091,
           -2.9223474094862016,
           -2.913758983766199,
           -2.9045483780429384,
           -2.894718608339374,
           -2.884272904529188,
           -2.87321471165118,
           -2.8615476913577247,
           -2.84927572350775,
           -2.8364029079157107,
           -2.8229335662691515,
           -2.8088722442286636,
           -2.7942237137253496,
           -2.778992975472327,
           -2.763185261708366,
           -2.7468060391934483,
           -2.72986101247785,
           -2.712356127468428,
           -2.6942975753179144,
           -2.675691796665513,
           -2.656545486259678,
           -2.636865597996887,
           -2.616659350413378,
           -2.5959342326703165,
           -2.574698011076677,
           -2.5529587361983492,
           -2.530724750606563,
           -2.508004697323839,
           -2.4848075290312215,
           -2.46114251810669,
           -2.437019267571386,
           -2.412447723027666,
           -2.3874381856811455,
           -2.3620013265477784,
           -2.3361482019567883,
           -2.309890270470991,
           -2.283239411357698,
           -2.2562079447562016,
           -2.228808653701716,
           -2.2010548081807846,
           -2.1729601914094987,
           -2.1445391285435575,
           -2.115806518048108,
           -2.0867778659755505,
           -2.057469323420872,
           -2.0278977274465606,
           -1.998080645792366,
           -1.9680364257089435,
           -1.9377842472780267,
           -1.9073441816046641,
           -1.8767372542881353,
           -1.8459855145961364,
           -1.815112110779921,
           -1.7841413719739856,
           -1.753098897119552,
           -1.722011651332723,
           -1.6909080701007777,
           -1.659818171627468,
           -1.6287736775526238,
           -1.597808142133287,
           -1.566957089781304,
           -1.5362581605917767,
           -1.5057512631513301,
           -1.4754787334655453,
           -1.4454854982693146,
           -1.4158192402585656,
           -1.3865305618821604,
           -1.3576731432352795,
           -1.3293038882809054,
           -1.3014830520835918,
           -1.2742743399742111,
           -1.2477449676046235,
           -1.2219656687608693,
           -1.1970106356942687,
           -1.1729573747752213,
           -1.1498864587224313,
           -1.12788115584078,
           -1.1070269170236327,
           -1.0874107032095515,
           -1.069120140014481,
           -1.0522424928149472,
           -1.0368634648967128,
           -1.0230658333711684,
           -1.0109279519317784,
           -1.000522165173249,
           -0.9919131945640075,
           -0.9851565692222194,
           -0.9802971831587954,
           -0.977368062558745,
           -0.9763894205636032,
           -0.9773680625587471,
           -0.9802971831587997,
           -0.9851565692222255,
           -0.9919131945640154,
           -1.0005221651732588,
           -1.0109279519317897,
           -1.0230658333711817,
           -1.0368634648967276,
           -1.0522424928149638,
           -1.069120140014499,
           -1.0874107032095712,
           -1.1070269170236535,
           -1.127881155840802,
           -1.1498864587224542,
           -1.1729573747752455,
           -1.1970106356942938,
           -1.2219656687608953,
           -1.2477449676046504,
           -1.274274339974239,
           -1.30148305208362,
           -1.3293038882809343,
           -1.3576731432353086,
           -1.3865305618821904,
           -1.415819240258596,
           -1.445485498269345,
           -1.4754787334655763,
           -1.5057512631513614,
           -1.536258160591808,
           -1.5669570897813356,
           -1.5978081421333188,
           -1.6287736775526556,
           -1.6598181716275,
           -1.6909080701008101,
           -1.7220116513327552,
           -1.753098897119584,
           -1.7841413719740171,
           -1.8151121107799526,
           -1.8459855145961679,
           -1.876737254288167,
           -1.9073441816046954,
           -1.9377842472780578,
           -1.968036425708975,
           -1.9980806457923972,
           -2.0278977274465912,
           -2.057469323420903,
           -2.0867778659755802,
           -2.115806518048138,
           -2.1445391285435864,
           -2.172960191409528,
           -2.2010548081808134,
           -2.2288086537017446,
           -2.2562079447562295,
           -2.2832394113577257,
           -2.3098902704710182,
           -2.336148201956815,
           -2.3620013265478046,
           -2.3874381856811717,
           -2.4124477230276913,
           -2.4370192675714106,
           -2.461142518106715,
           -2.4848075290312455,
           -2.5080046973238623,
           -2.530724750606586,
           -2.5529587361983723,
           -2.5746980110766993,
           -2.5959342326703383,
           -2.6166593504133995,
           -2.636865597996907,
           -2.6565454862596978,
           -2.675691796665532,
           -2.6942975753179335,
           -2.7123561274684462,
           -2.7298610124778677,
           -2.746806039193465,
           -2.7631852617083834,
           -2.7789929754723426,
           -2.794223713725365,
           -2.808872244228678,
           -2.8229335662691653,
           -2.836402907915724,
           -2.849275723507763,
           -2.861547691357737,
           -2.8732147116511917,
           -2.8842729045291997,
           -2.8947186083393843,
           -2.904548378042948,
           -2.9137589837662077,
           -2.9223474094862096,
           -2.9303108518409173,
           -2.9376467190553734,
           -2.9443526299760543,
           -2.950426413206416,
           -2.9558661063373406,
           -2.960669955266889,
           -2.9648364136043837,
           -2.9683641421544817,
           -2.9712520084774536,
           -2.9734990865224393,
           -2.9751046563310015,
           -2.9760682038087833
          ],
          [
           -2.9691989991996617,
           -2.968878176011143,
           -2.9679158088583177,
           -2.966312205011085,
           -2.964067876691833,
           -2.9611835412351106,
           -2.9576601213128146,
           -2.953498745226572,
           -2.9487007472694717,
           -2.9432676681598364,
           -2.937201255550217,
           -2.9305034646153776,
           -2.923176458723589,
           -2.915222610196162,
           -2.906644501160786,
           -2.897444924504931,
           -2.887626884936245,
           -2.877193600157712,
           -2.8661485021660984,
           -2.8544952386831324,
           -2.8422376747298057,
           -2.829379894355202,
           -2.815926202532384,
           -2.801881127235062,
           -2.7872494217100754,
           -2.7720360669621407,
           -2.7562462744688703,
           -2.7398854891457347,
           -2.722959392582516,
           -2.705473906574765,
           -2.6874351969760184,
           -2.668849677898915,
           -2.649724016296001,
           -2.6300651369539,
           -2.6098802279377074,
           -2.58917674652595,
           -2.567962425680287,
           -2.5462452810983223,
           -2.524033618902544,
           -2.501336044023466,
           -2.4781614693406664,
           -2.4545191256515335,
           -2.430418572544309,
           -2.4058697102594393,
           -2.380882792631404,
           -2.355468441212151,
           -2.3296376606871014,
           -2.303401855705456,
           -2.2767728492583315,
           -2.2497629027511516,
           -2.2223847379307458,
           -2.194651560842934,
           -2.166577088012921,
           -2.138175575058778,
           -2.1094618479675096,
           -2.0804513372838516,
           -2.05116011548378,
           -2.021604937827746,
           -1.9918032870125504,
           -1.96177342196532,
           -1.9315344311475962,
           -1.901106290761552,
           -1.8705099282727362,
           -1.8397672916832628,
           -1.8089014250042386,
           -1.777936550384197,
           -1.7468981573483724,
           -1.7158130995879668,
           -1.6847096997042275,
           -1.6536178622529556,
           -1.622569195343208,
           -1.5915971409098215,
           -1.5607371135911796,
           -1.5300266478870563,
           -1.4995055529295278,
           -1.4692160737530502,
           -1.4392030573754768,
           -1.4095141212753801,
           -1.380199820946893,
           -1.3513138121063542,
           -1.322913001794301,
           -1.2950576810491374,
           -1.2678116300275806,
           -1.2412421844381931,
           -1.2154202499997158,
           -1.1904202494460803,
           -1.1663199845490455,
           -1.1432003939684574,
           -1.1211451868063087,
           -1.1002403319557468,
           -1.0805733851873016,
           -1.0622326399109137,
           -1.045306094147949,
           -1.0298802357314867,
           -1.0160386601123756,
           -1.0038605499240185,
           -0.9934190616331963,
           -0.9847796805689388,
           -0.9779986192731406,
           -0.9731213431154269,
           -0.9701813092936024,
           -0.9691989991996618,
           -0.9701813092936045,
           -0.9731213431154307,
           -0.9779986192731466,
           -0.984779680568947,
           -0.9934190616332061,
           -1.00386054992403,
           -1.0160386601123892,
           -1.0298802357315018,
           -1.045306094147966,
           -1.0622326399109316,
           -1.0805733851873212,
           -1.1002403319557674,
           -1.121145186806331,
           -1.1432003939684805,
           -1.1663199845490697,
           -1.1904202494461054,
           -1.215420249999742,
           -1.2412421844382202,
           -1.267811630027608,
           -1.2950576810491656,
           -1.3229130017943298,
           -1.3513138121063837,
           -1.380199820946923,
           -1.4095141212754103,
           -1.4392030573755072,
           -1.4692160737530813,
           -1.499505552929559,
           -1.5300266478870879,
           -1.5607371135912114,
           -1.5915971409098533,
           -1.62256919534324,
           -1.6536178622529878,
           -1.6847096997042594,
           -1.7158130995879985,
           -1.7468981573484044,
           -1.7779365503842288,
           -1.8089014250042703,
           -1.8397672916832948,
           -1.8705099282727682,
           -1.9011062907615834,
           -1.9315344311476275,
           -1.9617734219653513,
           -1.9918032870125815,
           -2.0216049378277767,
           -2.051160115483811,
           -2.0804513372838813,
           -2.109461847967539,
           -2.138175575058807,
           -2.16657708801295,
           -2.194651560842962,
           -2.2223847379307746,
           -2.2497629027511796,
           -2.276772849258359,
           -2.3034018557054825,
           -2.329637660687128,
           -2.355468441212177,
           -2.3808827926314295,
           -2.4058697102594646,
           -2.4304185725443337,
           -2.4545191256515584,
           -2.478161469340691,
           -2.50133604402349,
           -2.524033618902567,
           -2.5462452810983454,
           -2.567962425680309,
           -2.589176746525972,
           -2.6098802279377282,
           -2.6300651369539203,
           -2.649724016296021,
           -2.668849677898934,
           -2.6874351969760366,
           -2.7054739065747837,
           -2.7229593925825344,
           -2.7398854891457516,
           -2.7562462744688863,
           -2.7720360669621567,
           -2.787249421710091,
           -2.8018811272350765,
           -2.8159262025323977,
           -2.829379894355215,
           -2.8422376747298186,
           -2.8544952386831444,
           -2.86614850216611,
           -2.877193600157723,
           -2.887626884936255,
           -2.8974449245049407,
           -2.9066445011607955,
           -2.91522261019617,
           -2.923176458723597,
           -2.930503464615385,
           -2.9372012555502236,
           -2.943267668159842,
           -2.948700747269477,
           -2.9534987452265766,
           -2.9576601213128186,
           -2.9611835412351137,
           -2.9640678766918356,
           -2.966312205011086,
           -2.967915808858319,
           -2.968878176011143
          ],
          [
           -2.9610709403987197,
           -2.960750564399622,
           -2.9597895383923998,
           -2.9581881683784537,
           -2.955946964464325,
           -2.953066641018819,
           -2.949548116894628,
           -2.945392515716095,
           -2.9406011662352802,
           -2.935175602758979,
           -2.9291175656498583,
           -2.9224290019054573,
           -2.915112065819322,
           -2.9071691197291822,
           -2.8986027348576875,
           -2.8894156922519145,
           -2.8796109838285373,
           -2.869191813532348,
           -2.858161598616624,
           -2.846523971054702,
           -2.8342827790930754,
           -2.821442088957372,
           -2.808006186723616,
           -2.79397958036846,
           -2.779367002013289,
           -2.764173410378572,
           -2.7484039934663507,
           -2.732064171490442,
           -2.715159600075763,
           -2.697696173750202,
           -2.6796800297546306,
           -2.661117552199098,
           -2.6420153765958405,
           -2.622380394802644,
           -2.602219760413293,
           -2.5815408946352982,
           -2.5603514926989197,
           -2.538659530845756,
           -2.5164732739497353,
           -2.4938012838285144,
           -2.4706524283088114,
           -2.4470358911154477,
           -2.422961182660586,
           -2.3984381518171647,
           -2.373476998768694,
           -2.3480882890366326,
           -2.322282968796417,
           -2.296072381604121,
           -2.2694682866676,
           -2.242482878809005,
           -2.21512881027975,
           -2.1874192146045517,
           -2.1593677326479277,
           -2.130988541114804,
           -2.1022963837164723,
           -2.0733066052541953,
           -2.0440351888951405,
           -2.0144987969389625,
           -1.9847148153980312,
           -1.9547014027397098,
           -1.9244775431647427,
           -1.8940631048210486,
           -1.8634789033761108,
           -1.832746771392403,
           -1.8018896339672383,
           -1.7709315911087564,
           -1.7398980073205919,
           -1.7088156088551993,
           -1.6777125890650386,
           -1.6466187222255564,
           -1.615565486116383,
           -1.5845861935176684,
           -1.553716132595047,
           -1.5229927158949277,
           -1.492455637334268,
           -1.4621470361255762,
           -1.4321116660053739,
           -1.402397067407179,
           -1.373053739311277,
           -1.3441353063864132,
           -1.3156986756900166,
           -1.287804175598539,
           -1.2605156677977374,
           -1.2339006210979337,
           -1.2080301336107313,
           -1.1829788875405385,
           -1.1588250186809899,
           -1.1356498809175943,
           -1.1135376849687966,
           -1.0925749906835762,
           -1.0728500339630356,
           -1.0544518733228487,
           -1.0374693477501329,
           -1.0219898471552102,
           -1.0080979093898759,
           -0.9958736730509448,
           -0.9853912320771159,
           -0.976716954816888,
           -0.9699078446008993,
           -0.9650100284326271,
           -0.9620574629199414,
           -0.9610709403987197,
           -0.9620574629199433,
           -0.9650100284326311,
           -0.9699078446009053,
           -0.976716954816896,
           -0.9853912320771259,
           -0.9958736730509564,
           -1.0080979093898892,
           -1.0219898471552253,
           -1.0374693477501493,
           -1.0544518733228672,
           -1.072850033963055,
           -1.092574990683597,
           -1.1135376849688188,
           -1.1356498809176174,
           -1.158825018681014,
           -1.182978887540564,
           -1.2080301336107573,
           -1.2339006210979606,
           -1.2605156677977651,
           -1.2878041755985674,
           -1.3156986756900455,
           -1.3441353063864425,
           -1.3730537393113071,
           -1.4023970674072097,
           -1.4321116660054047,
           -1.4621470361256073,
           -1.492455637334299,
           -1.5229927158949594,
           -1.5537161325950786,
           -1.5845861935176997,
           -1.6155654861164148,
           -1.6466187222255888,
           -1.6777125890650708,
           -1.7088156088552315,
           -1.739898007320624,
           -1.7709315911087884,
           -1.80188963396727,
           -1.8327467713924348,
           -1.863478903376142,
           -1.89406310482108,
           -1.9244775431647736,
           -1.954701402739741,
           -1.9847148153980623,
           -2.014498796938993,
           -2.0440351888951707,
           -2.073306605254225,
           -2.1022963837165016,
           -2.1309885411148333,
           -2.159367732647957,
           -2.18741921460458,
           -2.215128810279778,
           -2.2424828788090325,
           -2.2694682866676277,
           -2.2960723816041475,
           -2.3222829687964435,
           -2.3480882890366592,
           -2.3734769987687203,
           -2.3984381518171896,
           -2.422961182660611,
           -2.447035891115472,
           -2.4706524283088354,
           -2.493801283828538,
           -2.5164732739497584,
           -2.5386595308457784,
           -2.5603514926989424,
           -2.581540894635319,
           -2.6022197604133144,
           -2.6223803948026636,
           -2.64201537659586,
           -2.6611175521991175,
           -2.6796800297546484,
           -2.6976961737502196,
           -2.715159600075781,
           -2.732064171490459,
           -2.748403993466367,
           -2.764173410378588,
           -2.7793670020133043,
           -2.793979580368475,
           -2.8080061867236297,
           -2.8214420889573844,
           -2.8342827790930882,
           -2.8465239710547134,
           -2.8581615986166358,
           -2.869191813532359,
           -2.8796109838285475,
           -2.889415692251925,
           -2.8986027348576964,
           -2.9071691197291902,
           -2.91511206581933,
           -2.922429001905465,
           -2.929117565649865,
           -2.9351756027589846,
           -2.940601166235286,
           -2.9453925157160996,
           -2.9495481168946314,
           -2.9530666410188227,
           -2.955946964464327,
           -2.9581881683784554,
           -2.959789538392401,
           -2.960750564399623
          ],
          [
           -2.9520131075327245,
           -2.9516932327788132,
           -2.950733710036212,
           -2.9491348438929395,
           -2.9468971420980146,
           -2.9440213157157364,
           -2.9405082793433217,
           -2.9363591513935154,
           -2.931575254444316,
           -2.926158115658446,
           -2.9201094672757155,
           -2.9134312471819666,
           -2.9061255995588615,
           -2.8981948756193563,
           -2.8896416344343523,
           -2.880468643856655,
           -2.870678881549119,
           -2.8602755361245595,
           -2.84926200840589,
           -2.8376419128157524,
           -2.825419078905896,
           -2.8125975530375524,
           -2.7991816002251464,
           -2.785175706156906,
           -2.77058457940718,
           -2.7554131538567277,
           -2.7396665913387483,
           -2.7233502845301047,
           -2.706469860109012,
           -2.689031182202483,
           -2.671040356148984,
           -2.6525037326041807,
           -2.6334279120202524,
           -2.61381974953217,
           -2.593686360287489,
           -2.5730351252596804,
           -2.5518736975888814,
           -2.5302100094981332,
           -2.508052279837823,
           -2.4854090223161482,
           -2.4622890544790406,
           -2.4387015075091645,
           -2.414655836920423,
           -2.390161834231898,
           -2.365229639713408,
           -2.339869756303914,
           -2.3140930648140214,
           -2.2879108405347557,
           -2.261334771386792,
           -2.234376977757535,
           -2.207050034187796,
           -2.1793669930855417,
           -2.151341410661303,
           -2.122987375298334,
           -2.094319538590664,
           -2.0653531493037005,
           -2.0361040905349927,
           -2.0065889203771277,
           -1.9768249164102198,
           -1.946830124377882,
           -1.9166234114273977,
           -1.8862245243214761,
           -1.8556541530545385,
           -1.824934000329702,
           -1.794086857371885,
           -1.7631366865654858,
           -1.7321087114090072,
           -1.7010295142700225,
           -1.6699271423971331,
           -1.6388312225948494,
           -1.6077730848847929,
           -1.5767858953525,
           -1.5459047982012983,
           -1.5151670667885386,
           -1.484612263087193,
           -1.4542824045767055,
           -1.4242221369970363,
           -1.3944789106724507,
           -1.365103157198189,
           -1.336148462155338,
           -1.3076717281513213,
           -1.2797333208577666,
           -1.2523971888304641,
           -1.2257309457682493,
           -1.1998059015551052,
           -1.1746970260399063,
           -1.1504828272154708,
           -1.1272451235213523,
           -1.105068688766813,
           -1.0840407481030179,
           -1.0642503050987748,
           -1.0457872838612288,
           -1.028741476817827,
           -1.0132012986020378,
           -0.9992523595101818,
           -0.9869758877867739,
           -0.9764470474995063,
           -0.9677332162603894,
           -0.9608923022356295,
           -0.9559711901595447,
           -0.9530044089755739,
           -0.9520131075327244,
           -0.9530044089755758,
           -0.9559711901595486,
           -0.9608923022356355,
           -0.9677332162603975,
           -0.9764470474995163,
           -0.9869758877867857,
           -0.9992523595101953,
           -1.013201298602053,
           -1.0287414768178438,
           -1.0457872838612472,
           -1.0642503050987948,
           -1.084040748103039,
           -1.1050686887668353,
           -1.1272451235213756,
           -1.1504828272154952,
           -1.1746970260399314,
           -1.1998059015551317,
           -1.2257309457682763,
           -1.252397188830492,
           -1.2797333208577946,
           -1.3076717281513506,
           -1.3361484621553676,
           -1.365103157198219,
           -1.3944789106724809,
           -1.4242221369970673,
           -1.4542824045767366,
           -1.4846122630872245,
           -1.5151670667885702,
           -1.54590479820133,
           -1.5767858953525318,
           -1.6077730848848246,
           -1.6388312225948813,
           -1.6699271423971656,
           -1.7010295142700549,
           -1.7321087114090394,
           -1.7631366865655174,
           -1.7940868573719166,
           -1.8249340003297336,
           -1.8556541530545698,
           -1.8862245243215074,
           -1.916623411427429,
           -1.9468301243779131,
           -1.9768249164102505,
           -2.006588920377158,
           -2.036104090535023,
           -2.06535314930373,
           -2.094319538590694,
           -2.1229873752983632,
           -2.1513414106613324,
           -2.17936699308557,
           -2.207050034187824,
           -2.2343769777575635,
           -2.2613347713868195,
           -2.287910840534783,
           -2.3140930648140485,
           -2.3398697563039397,
           -2.365229639713434,
           -2.3901618342319235,
           -2.4146558369204474,
           -2.438701507509189,
           -2.4622890544790645,
           -2.4854090223161713,
           -2.5080522798378455,
           -2.5302100094981554,
           -2.551873697588903,
           -2.573035125259702,
           -2.59368636028751,
           -2.613819749532191,
           -2.633427912020272,
           -2.6525037326042007,
           -2.671040356149003,
           -2.6890311822025006,
           -2.7064698601090296,
           -2.723350284530122,
           -2.7396665913387652,
           -2.7554131538567437,
           -2.770584579407195,
           -2.785175706156921,
           -2.7991816002251606,
           -2.8125975530375658,
           -2.8254190789059095,
           -2.837641912815765,
           -2.8492620084059017,
           -2.86027553612457,
           -2.8706788815491286,
           -2.8804686438566645,
           -2.8896416344343607,
           -2.898194875619365,
           -2.9061255995588695,
           -2.913431247181974,
           -2.9201094672757217,
           -2.9261581156584517,
           -2.9315752544443217,
           -2.9363591513935203,
           -2.940508279343326,
           -2.94402131571574,
           -2.946897142098017,
           -2.9491348438929412,
           -2.9507337100362134,
           -2.9516932327788146
          ],
          [
           -2.942034263469983,
           -2.941714944501889,
           -2.940757088598026,
           -2.9391609987896485,
           -2.9369271802290813,
           -2.934056340340866,
           -2.9305493890349865,
           -2.9264074389837886,
           -2.9216318059646964,
           -2.9162240092713527,
           -2.9101857721962676,
           -2.9035190225886676,
           -2.8962258934917267,
           -2.888308723864004,
           -2.8797700593905162,
           -2.870612653389515,
           -2.860839467821785,
           -2.850453674409983,
           -2.8394586558763844,
           -2.8278580073082367,
           -2.8156555376608816,
           -2.8028552714097894,
           -2.789461450363757,
           -2.775478535652704,
           -2.7609112099047777,
           -2.7457643796288926,
           -2.730043177820335,
           -2.7137529668087574,
           -2.6968993413696825,
           -2.6794881321226396,
           -2.6615254092412415,
           -2.64301748650289,
           -2.62397092570843,
           -2.604392541504954,
           -2.584289406648117,
           -2.5636688577438025,
           -2.542538501512828,
           -2.520906221626561,
           -2.4987801861659826,
           -2.4761688557618404,
           -2.4530809924791583,
           -2.42952566951558,
           -2.4055122817898624,
           -2.381050557504368,
           -2.356150570773695,
           -2.3308227554207317,
           -2.3050779200514726,
           -2.2789272645309944,
           -2.252382397995112,
           -2.2254553585456014,
           -2.1981586347914233,
           -2.1705051894143543,
           -2.142508484954822,
           -2.114182512032612,
           -2.0855418202376135,
           -2.0566015519477547,
           -2.0273774793549544,
           -1.9978860450049518,
           -1.9681444061833662,
           -1.9381704835078029,
           -1.9079830141140184,
           -1.8776016098523693,
           -1.8470468209381803,
           -1.816340205525121,
           -1.785504405692475,
           -1.754563230353254,
           -1.7235417455975155,
           -1.6924663729802933,
           -1.6613649962413772,
           -1.6302670768986267,
           -1.5992037790796692,
           -1.5682081038388975,
           -1.537315033035414,
           -1.5065616826079589,
           -1.4759874647568718,
           -1.4456342581093604,
           -1.4155465843778925,
           -1.3857717892946488,
           -1.3563602246873363,
           -1.3273654274227893,
           -1.2988442895563406,
           -1.270857212365879,
           -1.2434682350126418,
           -1.2167451263725884,
           -1.1907594261753276,
           -1.1655864190766543,
           -1.1413050228500619,
           -1.117997569774066,
           -1.09574945887911,
           -1.0746486564690931,
           -1.0547850238074696,
           -1.0362494546629168,
           -1.019132812116312,
           -1.003524664050789,
           -0.9895118301683569,
           -0.9771767697860266,
           -0.9665958579925513,
           -0.9578376162035257,
           -0.950960979313363,
           -0.9460136927356064,
           -0.9430309360127292,
           -0.9420342634699831,
           -0.9430309360127312,
           -0.9460136927356105,
           -0.950960979313369,
           -0.9578376162035337,
           -0.9665958579925614,
           -0.9771767697860383,
           -0.9895118301683703,
           -1.0035246640508042,
           -1.0191328121163288,
           -1.0362494546629353,
           -1.0547850238074894,
           -1.0746486564691142,
           -1.095749458879132,
           -1.1179975697740896,
           -1.1413050228500865,
           -1.1655864190766796,
           -1.190759426175354,
           -1.2167451263726154,
           -1.2434682350126696,
           -1.2708572123659074,
           -1.2988442895563697,
           -1.3273654274228188,
           -1.3563602246873663,
           -1.3857717892946793,
           -1.4155465843779234,
           -1.4456342581093915,
           -1.4759874647569033,
           -1.5065616826079904,
           -1.5373150330354461,
           -1.5682081038389293,
           -1.599203779079701,
           -1.6302670768986587,
           -1.6613649962414094,
           -1.6924663729803253,
           -1.7235417455975475,
           -1.7545632303532857,
           -1.7855044056925065,
           -1.8163402055251525,
           -1.8470468209382116,
           -1.8776016098524002,
           -1.90798301411405,
           -1.9381704835078335,
           -1.968144406183397,
           -1.997886045004982,
           -2.027377479354984,
           -2.0566015519477845,
           -2.085541820237643,
           -2.1141825120326416,
           -2.142508484954851,
           -2.170505189414383,
           -2.1981586347914512,
           -2.225455358545629,
           -2.252382397995139,
           -2.2789272645310215,
           -2.3050779200514997,
           -2.330822755420758,
           -2.356150570773721,
           -2.381050557504394,
           -2.4055122817898873,
           -2.429525669515604,
           -2.453080992479182,
           -2.476168855761864,
           -2.4987801861660057,
           -2.520906221626584,
           -2.5425385015128503,
           -2.563668857743824,
           -2.584289406648138,
           -2.6043925415049745,
           -2.62397092570845,
           -2.643017486502909,
           -2.6615254092412606,
           -2.679488132122658,
           -2.6968993413697,
           -2.7137529668087748,
           -2.730043177820352,
           -2.745764379628909,
           -2.760911209904793,
           -2.7754785356527183,
           -2.789461450363771,
           -2.8028552714098036,
           -2.815655537660895,
           -2.827858007308249,
           -2.839458655876396,
           -2.8504536744099935,
           -2.8608394678217954,
           -2.8706126533895246,
           -2.879770059390525,
           -2.888308723864013,
           -2.896225893491734,
           -2.903519022588675,
           -2.9101857721962743,
           -2.9162240092713585,
           -2.921631805964702,
           -2.9264074389837926,
           -2.930549389034991,
           -2.934056340340869,
           -2.9369271802290835,
           -2.9391609987896503,
           -2.940757088598027,
           -2.94171494450189
          ],
          [
           -2.931144062097653,
           -2.930825353993515,
           -2.9298693301155945,
           -2.9282762917966876,
           -2.9260467413560742,
           -2.9231813822472246,
           -2.919681119266208,
           -2.9155470588223715,
           -2.910780509273392,
           -2.9053829813272865,
           -2.899356188514435,
           -2.8927020477332666,
           -2.8854226798737455,
           -2.877520410523438,
           -2.8689977707615064,
           -2.859857498046671,
           -2.850102537205849,
           -2.8397360415309496,
           -2.8287613739920676,
           -2.8171821085762256,
           -2.805002031761689,
           -2.7922251441389108,
           -2.7788556621902543,
           -2.7648980202417657,
           -2.7503568726016185,
           -2.7352370959011836,
           -2.71954379165623,
           -2.7032822890674018,
           -2.6864581480809324,
           -2.6690771627325556,
           -2.6511453647997065,
           -2.6326690277895426,
           -2.6136546712928665,
           -2.5941090657369825,
           -2.5740392375735954,
           -2.5534524749414045,
           -2.5323563338468396,
           -2.5107586449105974,
           -2.4886675207323,
           -2.4660913639307003,
           -2.443038875922508,
           -2.419519066509142,
           -2.3955412643475604,
           -2.371115128388918,
           -2.3462506603771174,
           -2.320958218508553,
           -2.2952485323644565,
           -2.2691327192384336,
           -2.242622301994057,
           -2.215729228600857,
           -2.1884658935118644,
           -2.160845161062056,
           -2.13288039108475,
           -2.104585466962285,
           -2.075974826348233,
           -2.0470634948210065,
           -2.017867122753029,
           -1.988402025705548,
           -1.9586852286866292,
           -1.9287345146385697,
           -1.8985684775505778,
           -1.868206580622517,
           -1.8376692199349722,
           -1.8069777941087535,
           -1.7761547804616271,
           -1.7452238181894566,
           -1.714209799110251,
           -1.683138966509164,
           -1.6520390226054564,
           -1.6209392451227074,
           -1.5898706133731961,
           -1.558865944156529,
           -1.527960037608815,
           -1.4971898329068247,
           -1.466594573413017,
           -1.4362159804200947,
           -1.4060984340920306,
           -1.3762891594730557,
           -1.3468384145149601,
           -1.3177996759231547,
           -1.2892298172119847,
           -1.2611892716649675,
           -1.2337421709044485,
           -1.2069564474994627,
           -1.1809038875285955,
           -1.1556601163676103,
           -1.1313044983629545,
           -1.1079199287473473,
           -1.0855924945259372,
           -1.0644109805992406,
           -1.0444661986822714,
           -1.0258501202773607,
           -1.0086548016857897,
           -0.9929710992693408,
           -0.9788871870354906,
           -0.9664869057315042,
           -0.9558479919073133,
           -0.9470402549783938,
           -0.9401237876213311,
           -0.9351473068977111,
           -0.9321467274731127,
           -0.9311440620976529,
           -0.9321467274731147,
           -0.9351473068977152,
           -0.9401237876213374,
           -0.947040254978402,
           -0.9558479919073234,
           -0.9664869057315159,
           -0.9788871870355043,
           -0.9929710992693562,
           -1.0086548016858066,
           -1.0258501202773789,
           -1.0444661986822912,
           -1.0644109805992616,
           -1.0855924945259592,
           -1.1079199287473707,
           -1.1313044983629792,
           -1.1556601163676357,
           -1.180903887528622,
           -1.2069564474994896,
           -1.2337421709044767,
           -1.2611892716649962,
           -1.2892298172120136,
           -1.3177996759231843,
           -1.3468384145149903,
           -1.3762891594730862,
           -1.4060984340920617,
           -1.4362159804201258,
           -1.466594573413048,
           -1.4971898329068565,
           -1.527960037608847,
           -1.5588659441565607,
           -1.5898706133732279,
           -1.620939245122739,
           -1.6520390226054884,
           -1.683138966509196,
           -1.714209799110283,
           -1.745223818189488,
           -1.7761547804616586,
           -1.806977794108785,
           -1.8376692199350033,
           -1.868206580622548,
           -1.8985684775506093,
           -1.9287345146386004,
           -1.9586852286866598,
           -1.9884020257055783,
           -2.017867122753059,
           -2.0470634948210362,
           -2.0759748263482622,
           -2.1045854669623147,
           -2.1328803910847784,
           -2.1608451610620842,
           -2.1884658935118924,
           -2.215729228600885,
           -2.2426223019940847,
           -2.2691327192384607,
           -2.295248532364483,
           -2.3209582185085798,
           -2.346250660377143,
           -2.3711151283889427,
           -2.3955412643475853,
           -2.4195190665091664,
           -2.443038875922532,
           -2.4660913639307234,
           -2.488667520732323,
           -2.51075864491062,
           -2.5323563338468613,
           -2.553452474941426,
           -2.574039237573616,
           -2.5941090657370034,
           -2.613654671292887,
           -2.6326690277895617,
           -2.651145364799726,
           -2.669077162732573,
           -2.6864581480809497,
           -2.7032822890674186,
           -2.719543791656247,
           -2.7352370959012,
           -2.750356872601633,
           -2.76489802024178,
           -2.7788556621902685,
           -2.7922251441389245,
           -2.8050020317617013,
           -2.8171821085762385,
           -2.828761373992079,
           -2.8397360415309603,
           -2.85010253720586,
           -2.85985749804668,
           -2.8689977707615153,
           -2.8775204105234464,
           -2.8854226798737534,
           -2.892702047733273,
           -2.899356188514442,
           -2.9053829813272922,
           -2.9107805092733976,
           -2.9155470588223755,
           -2.9196811192662127,
           -2.9231813822472277,
           -2.9260467413560765,
           -2.9282762917966902,
           -2.9298693301155962,
           -2.9308253539935154
          ],
          [
           -2.919353038982229,
           -2.9190349974107903,
           -2.918080972518459,
           -2.9164912637997635,
           -2.914266370507721,
           -2.911406991797825,
           -2.907914026931201,
           -2.903788575538521,
           -2.8990319379467246,
           -2.8936456155711117,
           -2.8876313113758196,
           -2.880990930406296,
           -2.8737265803978493,
           -2.8658405724650007,
           -2.857335421876926,
           -2.8482138489249493,
           -2.8384787798887334,
           -2.8281333481085316,
           -2.8171808951716955,
           -2.805624972222443,
           -2.7934693414048293,
           -2.7807179774498523,
           -2.7673750694186956,
           -2.75344502261529,
           -2.73893246068261,
           -2.7238422278985523,
           -2.7081793916887076,
           -2.6919492453750022,
           -2.6751573111809956,
           -2.657809343516569,
           -2.639911332566922,
           -2.621469508213162,
           -2.6024903443143725,
           -2.5829805633839213,
           -2.562947141695896,
           -2.542397314861083,
           -2.521338583915637,
           -2.4997787219699026,
           -2.477725781469412,
           -2.455188102125253,
           -2.432174319576657,
           -2.4086933748548645,
           -2.384754524724267,
           -2.360367352984382,
           -2.33554178282466,
           -2.3102880903333562,
           -2.284616919271938,
           -2.2585392972377765,
           -2.232066653350267,
           -2.205210837609208,
           -2.177984142089262,
           -2.1503993241508135,
           -2.1224696318655476,
           -2.0942088318747762,
           -2.0656312399199592,
           -2.036751754308064,
           -2.0075858925994754,
           -1.9781498318329642,
           -1.9484604526307638,
           -1.9185353875567985,
           -1.8883930741323058,
           -1.8580528129448861,
           -1.8275348313187292,
           -1.7968603530442686,
           -1.7660516746933257,
           -1.7351322490688923,
           -1.7041267763543118,
           -1.67306130353117,
           -1.6419633326239254,
           -1.6108619382960914,
           -1.57978789525975,
           -1.5487738158573472,
           -1.5178542980196137,
           -1.4870660835805027,
           -1.456448226620345,
           -1.4260422710891758,
           -1.3958924364066323,
           -1.3660458090121645,
           -1.3365525369156588,
           -1.3074660231380653,
           -1.278843112499655,
           -1.2507442644809004,
           -1.2232337028313178,
           -1.196379530241223,
           -1.170253793763146,
           -1.1449324838705446,
           -1.1204954472431972,
           -1.097026190839591,
           -1.074611552940918,
           -1.053341216138198,
           -1.0333070383082084,
           -1.01460218118363,
           -0.9973200228546009,
           -0.9815528509792409,
           -0.9673903478289373,
           -0.9549178961970448,
           -0.9442147555568947,
           -0.935352178715795,
           -0.9283915578463061,
           -0.9233827019856715,
           -0.9203623527674429,
           -0.9193530389822292,
           -0.9203623527674449,
           -0.9233827019856758,
           -0.9283915578463124,
           -0.9353521787158031,
           -0.9442147555569049,
           -0.9549178961970566,
           -0.9673903478289511,
           -0.9815528509792563,
           -0.9973200228546177,
           -1.0146021811836488,
           -1.0333070383082281,
           -1.0533412161382194,
           -1.0746115529409401,
           -1.0970261908396144,
           -1.1204954472432216,
           -1.1449324838705701,
           -1.170253793763172,
           -1.1963795302412503,
           -1.2232337028313456,
           -1.250744264480929,
           -1.278843112499684,
           -1.307466023138095,
           -1.336552536915689,
           -1.366045809012195,
           -1.395892436406663,
           -1.426042271089207,
           -1.456448226620376,
           -1.4870660835805343,
           -1.517854298019645,
           -1.5487738158573787,
           -1.5797878952597817,
           -1.6108619382961236,
           -1.641963332623957,
           -1.673061303531202,
           -1.7041267763543437,
           -1.735132249068924,
           -1.7660516746933574,
           -1.7968603530443004,
           -1.8275348313187614,
           -1.8580528129449179,
           -1.8883930741323367,
           -1.918535387556829,
           -1.9484604526307943,
           -1.9781498318329953,
           -2.0075858925995056,
           -2.036751754308094,
           -2.0656312399199885,
           -2.0942088318748056,
           -2.1224696318655765,
           -2.1503993241508423,
           -2.17798414208929,
           -2.2052108376092354,
           -2.232066653350294,
           -2.258539297237803,
           -2.284616919271964,
           -2.3102880903333816,
           -2.3355417828246856,
           -2.3603673529844067,
           -2.3847545247242916,
           -2.408693374854889,
           -2.4321743195766805,
           -2.4551881021252764,
           -2.4777257814694345,
           -2.499778721969925,
           -2.521338583915659,
           -2.542397314861104,
           -2.5629471416959175,
           -2.5829805633839413,
           -2.602490344314393,
           -2.6214695082131807,
           -2.6399113325669403,
           -2.657809343516587,
           -2.675157311181014,
           -2.691949245375019,
           -2.708179391688724,
           -2.723842227898568,
           -2.738932460682625,
           -2.753445022615304,
           -2.7673750694187094,
           -2.780717977449865,
           -2.793469341404842,
           -2.8056249722224553,
           -2.8171808951717066,
           -2.8281333481085422,
           -2.838478779888744,
           -2.8482138489249595,
           -2.8573354218769342,
           -2.8658405724650087,
           -2.873726580397857,
           -2.880990930406303,
           -2.8876313113758263,
           -2.8936456155711174,
           -2.8990319379467304,
           -2.9037885755385258,
           -2.907914026931205,
           -2.9114069917978287,
           -2.9142663705077236,
           -2.916491263799765,
           -2.9180809725184598,
           -2.9190349974107908
          ],
          [
           -2.906672601177065,
           -2.906355282451253,
           -2.905403425437407,
           -2.903817327654064,
           -2.9015974850582498,
           -2.8987445921854404,
           -2.8952595423470657,
           -2.8911434278871178,
           -2.886397540499885,
           -2.881023371611338,
           -2.875022612827157,
           -2.868397156450934,
           -2.8611490960766024,
           -2.853280727259747,
           -2.8447945482730104,
           -2.835693260951481,
           -2.8259797716346267,
           -2.815657192212046,
           -2.8047288412811238,
           -2.7931982454254785,
           -2.781069140624048,
           -2.768345473801587,
           -2.7550314045324624,
           -2.7411313069107472,
           -2.7266497716009153,
           -2.711591608084759,
           -2.6959618471216937,
           -2.679765743441222,
           -2.663008778688125,
           -2.645696664642907,
           -2.627835346742183,
           -2.609431007926042,
           -2.590490072842018,
           -2.5710192124381748,
           -2.551025348980913,
           -2.5305156615366196,
           -2.5094975919600464,
           -2.4879788514365573,
           -2.4659674276299937,
           -2.4434715924930597,
           -2.4204999108027856,
           -2.3970612494898877,
           -2.3731647878377533,
           -2.3488200286344374,
           -2.324036810369496,
           -2.2988253205767952,
           -2.2731961104348,
           -2.247160110747161,
           -2.220728649439014,
           -2.193913470718266,
           -2.1667267560663177,
           -2.1391811472394995,
           -2.1112897714808123,
           -2.0830662691617228,
           -2.0545248240956777,
           -2.0256801967888864,
           -1.9965477609197242,
           -1.9671435433659006,
           -1.9374842681282054,
           -1.9075874045310646,
           -1.8774712201129875,
           -1.8471548386538352,
           -1.8166583038199566,
           -1.78600264894162,
           -1.7552099734684172,
           -1.7243035266754236,
           -1.6933077992132621,
           -1.6622486231052758,
           -1.6311532807901177,
           -1.6000506237821142,
           -1.568971201466955,
           -1.5379474004565208,
           -1.5070135947814067,
           -1.4762063069871239,
           -1.4455643799006308,
           -1.4151291584243368,
           -1.3849446801670091,
           -1.3550578730029448,
           -1.3255187567259725,
           -1.2963806447947608,
           -1.2677003407118166,
           -1.2395383218066365,
           -1.2119589010814775,
           -1.1850303553261587,
           -1.1588250049525053,
           -1.133419228031052,
           -1.1088933880012808,
           -1.0853316517428042,
           -1.0628216725333999,
           -1.0414541114128117,
           -1.021321971281734,
           -1.0025197214474715,
           -0.9851421970395193,
           -0.9692832683766032,
           -0.9550342902449852,
           -0.9424823598385675,
           -0.93170843370353,
           -0.922785376380804,
           -0.9157760336319325,
           -0.910731437700055,
           -0.907689257580106,
           -0.9066726011770648,
           -0.9076892575801082,
           -0.910731437700059,
           -0.9157760336319388,
           -0.9227853763808122,
           -0.9317084337035402,
           -0.9424823598385798,
           -0.9550342902449991,
           -0.9692832683766186,
           -0.9851421970395364,
           -1.0025197214474901,
           -1.021321971281754,
           -1.0414541114128328,
           -1.0628216725334225,
           -1.0853316517428278,
           -1.1088933880013054,
           -1.1334192280310775,
           -1.158825004952532,
           -1.185030355326186,
           -1.2119589010815055,
           -1.239538321806665,
           -1.2677003407118457,
           -1.2963806447947905,
           -1.3255187567260027,
           -1.3550578730029752,
           -1.3849446801670402,
           -1.415129158424368,
           -1.4455643799006623,
           -1.4762063069871554,
           -1.5070135947814387,
           -1.5379474004565523,
           -1.568971201466987,
           -1.600050623782146,
           -1.6311532807901497,
           -1.662248623105308,
           -1.6933077992132939,
           -1.7243035266754554,
           -1.7552099734684485,
           -1.7860026489416516,
           -1.816658303819988,
           -1.8471548386538665,
           -1.8774712201130184,
           -1.9075874045310952,
           -1.9374842681282363,
           -1.9671435433659308,
           -1.9965477609197548,
           -2.0256801967889166,
           -2.0545248240957075,
           -2.083066269161752,
           -2.111289771480841,
           -2.1391811472395275,
           -2.1667267560663457,
           -2.1939134707182935,
           -2.2207286494390415,
           -2.247160110747188,
           -2.2731961104348275,
           -2.2988253205768214,
           -2.3240368103695217,
           -2.348820028634463,
           -2.3731647878377773,
           -2.3970612494899117,
           -2.4204999108028096,
           -2.443471592493083,
           -2.4659674276300168,
           -2.48797885143658,
           -2.5094975919600677,
           -2.530515661536641,
           -2.551025348980934,
           -2.571019212438195,
           -2.590490072842038,
           -2.6094310079260605,
           -2.6278353467422018,
           -2.645696664642925,
           -2.663008778688143,
           -2.679765743441239,
           -2.6959618471217097,
           -2.711591608084775,
           -2.7266497716009304,
           -2.7411313069107615,
           -2.755031404532476,
           -2.768345473801601,
           -2.7810691406240613,
           -2.793198245425491,
           -2.8047288412811353,
           -2.8156571922120572,
           -2.8259797716346364,
           -2.8356932609514907,
           -2.844794548273019,
           -2.8532807272597553,
           -2.86114909607661,
           -2.868397156450941,
           -2.8750226128271636,
           -2.881023371611344,
           -2.8863975404998903,
           -2.8911434278871218,
           -2.89525954234707,
           -2.8987445921854436,
           -2.901597485058252,
           -2.9038173276540657,
           -2.905403425437408,
           -2.9063552824512535
          ],
          [
           -2.8931150161867834,
           -2.8927984773178004,
           -2.891848959170924,
           -2.890266757153281,
           -2.888052363700009,
           -2.885206468409906,
           -2.8817299582368703,
           -2.877623917738668,
           -2.8728896293850315,
           -2.867528573927563,
           -2.86154243083439,
           -2.854933078793069,
           -2.8477025962857074,
           -2.8398532622409087,
           -2.8313875567676665,
           -2.8223081619770216,
           -2.8126179628979435,
           -2.8023200484946065,
           -2.791417712793047,
           -2.779914456125954,
           -2.767813986505316,
           -2.7551202211335544,
           -2.741837288064873,
           -2.7279695280296705,
           -2.713521496436116,
           -2.6984979655643566,
           -2.682903926970289,
           -2.6667445941174583,
           -2.650025405257441,
           -2.6327520265809694,
           -2.614930355664254,
           -2.5965665252372445,
           -2.5776669073032017,
           -2.5582381176417677,
           -2.5382870207308543,
           -2.517820735126136,
           -2.4968466393407107,
           -2.4753723782717434,
           -2.453405870225484,
           -2.4309553145972522,
           -2.408029200268588,
           -2.3846363147900997,
           -2.360785754425423,
           -2.336486935139425,
           -2.3117496046222668,
           -2.2865838554503233,
           -2.2610001394953776,
           -2.2350092837049784,
           -2.2086225073895753,
           -2.1818514411660392,
           -2.1547081477226824,
           -2.1272051445878923,
           -2.0993554291032726,
           -2.071172505822703,
           -2.042670416581262,
           -2.0138637735024663,
           -1.9847677952389402,
           -1.955398346770423,
           -1.9257719831139113,
           -1.895905997333649,
           -1.8658184732733252,
           -1.8355283434688594,
           -1.8050554527368647,
           -1.7744206279703938,
           -1.7436457547085091,
           -1.7127538610777417,
           -1.6817692097290289,
           -1.6507173984098544,
           -1.6196254698134454,
           -1.5885220313290167,
           -1.557437385271428,
           -1.5264036700851247,
           -1.4954550128832091,
           -1.4646276934818148,
           -1.4339603198028301,
           -1.4034940141201633,
           -1.37327260908705,
           -1.343342851770474,
           -1.3137546129948723,
           -1.2845610981190392,
           -1.2558190538945995,
           -1.2275889642422197,
           -1.199935225604148,
           -1.172926289981162,
           -1.1466347608671756,
           -1.1211374241401304,
           -1.096515192718107,
           -1.0728529407169323,
           -1.0502392003555259,
           -1.028765693504303,
           -1.0085266702655318,
           -0.9896180301298881,
           -0.9721362079115831,
           -0.9561768175372642,
           -0.9418330622154432,
           -0.9291939392957129,
           -0.9183422911253725,
           -0.9093527772820371,
           -0.9022898655744847,
           -0.897205955378033,
           -0.8941397534231333,
           -0.8931150161867832,
           -0.8941397534231356,
           -0.8972059553780373,
           -0.9022898655744909,
           -0.9093527772820453,
           -0.9183422911253828,
           -0.929193939295725,
           -0.9418330622154569,
           -0.9561768175372798,
           -0.9721362079116003,
           -0.989618030129907,
           -1.0085266702655518,
           -1.0287656935043243,
           -1.0502392003555483,
           -1.072852940716956,
           -1.0965151927181316,
           -1.1211374241401562,
           -1.1466347608672023,
           -1.1729262899811894,
           -1.1999352256041758,
           -1.227588964242248,
           -1.2558190538946288,
           -1.2845610981190692,
           -1.3137546129949025,
           -1.3433428517705048,
           -1.3732726090870808,
           -1.4034940141201944,
           -1.4339603198028616,
           -1.4646276934818463,
           -1.4954550128832411,
           -1.5264036700851566,
           -1.5574373852714598,
           -1.588522031329049,
           -1.6196254698134775,
           -1.6507173984098864,
           -1.6817692097290604,
           -1.7127538610777735,
           -1.7436457547085407,
           -1.774420627970425,
           -1.8050554527368963,
           -1.835528343468891,
           -1.8658184732733567,
           -1.8959059973336798,
           -1.925771983113942,
           -1.955398346770453,
           -1.9847677952389704,
           -2.013863773502496,
           -2.042670416581292,
           -2.0711725058227324,
           -2.099355429103301,
           -2.1272051445879208,
           -2.1547081477227104,
           -2.1818514411660668,
           -2.2086225073896024,
           -2.235009283705005,
           -2.261000139495404,
           -2.2865838554503495,
           -2.3117496046222925,
           -2.33648693513945,
           -2.3607857544254474,
           -2.384636314790124,
           -2.408029200268612,
           -2.430955314597275,
           -2.453405870225507,
           -2.475372378271766,
           -2.496846639340733,
           -2.5178207351261563,
           -2.538287020730875,
           -2.5582381176417877,
           -2.5776669073032217,
           -2.5965665252372636,
           -2.614930355664273,
           -2.632752026580987,
           -2.650025405257458,
           -2.666744594117475,
           -2.6829039269703054,
           -2.6984979655643735,
           -2.713521496436131,
           -2.7279695280296847,
           -2.7418372880648874,
           -2.7551202211335677,
           -2.7678139865053284,
           -2.779914456125966,
           -2.7914177127930584,
           -2.802320048494617,
           -2.8126179628979533,
           -2.822308161977031,
           -2.831387556767675,
           -2.8398532622409176,
           -2.8477025962857145,
           -2.8549330787930756,
           -2.8615424308343966,
           -2.8675285739275687,
           -2.872889629385037,
           -2.877623917738672,
           -2.8817299582368743,
           -2.885206468409909,
           -2.888052363700011,
           -2.8902667571532827,
           -2.8918489591709253,
           -2.8927984773178013
          ],
          [
           -2.8786934000992597,
           -2.8783776988512004,
           -2.877430692819297,
           -2.875852675166371,
           -2.8736441345839894,
           -2.870805755423511,
           -2.8673384178810575,
           -2.8632431982379174,
           -2.8585213691583546,
           -2.853174400047264,
           -2.847203957470551,
           -2.840611905641703,
           -2.8334003069784357,
           -2.825571422733951,
           -2.8171277137078654,
           -2.8080718410425063,
           -2.7984066671109584,
           -2.7881352565039124,
           -2.777260877123172,
           -2.7657870013904606,
           -2.7537173075810895,
           -2.7410556812929667,
           -2.7278062170625166,
           -2.7139732201401707,
           -2.6995612084393366,
           -2.6845749146741067,
           -2.669019288702421,
           -2.6528995000930133,
           -2.636220940936223,
           -2.618989228920707,
           -2.6012102107001693,
           -2.5828899655766064,
           -2.5640348095290793,
           -2.5446512996198956,
           -2.5247462388131727,
           -2.5043266812442013,
           -2.4833999379818117,
           -2.461973583330174,
           -2.440055461721037,
           -2.4176536952526106,
           -2.394776691936909,
           -2.371433154723696,
           -2.3476320913761137,
           -2.323382825280784,
           -2.2986950072837136,
           -2.273578628652788,
           -2.2480440352781366,
           -2.2221019432332176,
           -2.1957634558323536,
           -2.1690400823346434,
           -2.1419437584598677,
           -2.1144868688993532,
           -2.08668227202387,
           -2.0585433270116362,
           -2.0300839236426005,
           -2.0013185150303703,
           -1.9722621535907146,
           -1.9429305305753741,
           -1.9133400195321415,
           -1.8835077240866285,
           -1.8534515304777182,
           -1.823190165317017,
           -1.792743259082118,
           -1.7621314158933539,
           -1.7313762901626453,
           -1.7005006707393313,
           -1.669528573209033,
           -1.6384853410243616,
           -1.6073977561561297,
           -1.5762941599448255,
           -1.5452045847966742,
           -1.5141608972966403,
           -1.483196953189397,
           -1.4523487644923043,
           -1.4216546787315234,
           -1.3911555699084892,
           -1.3608950402788262,
           -1.3309196313235994,
           -1.301279041372368,
           -1.272026346153286,
           -1.243218217049827,
           -1.2149151299911265,
           -1.187181555657164,
           -1.1600861190248055,
           -1.133701713235394,
           -1.1081055494049044,
           -1.0833791204823715,
           -1.0596080538633645,
           -1.0368818245982747,
           -1.0152932992822918,
           -0.9949380808269568,
           -0.9759136271807296,
           -0.9583181236249039,
           -0.9422490993458487,
           -0.9278017950496363,
           -0.9150673092709508,
           -0.9041305756251529,
           -0.8950682493106685,
           -0.887946605315578,
           -0.8828195688669873,
           -0.879727006467974,
           -0.8786934000992599,
           -0.8797270064679761,
           -0.8828195688669914,
           -0.8879466053155843,
           -0.8950682493106772,
           -0.9041305756251633,
           -0.915067309270963,
           -0.9278017950496504,
           -0.9422490993458643,
           -0.9583181236249212,
           -0.9759136271807484,
           -0.994938080826977,
           -1.0152932992823136,
           -1.0368818245982974,
           -1.0596080538633883,
           -1.0833791204823962,
           -1.10810554940493,
           -1.1337017132354206,
           -1.160086119024833,
           -1.1871815556571923,
           -1.2149151299911551,
           -1.2432182170498565,
           -1.272026346153316,
           -1.3012790413723982,
           -1.3309196313236298,
           -1.360895040278857,
           -1.3911555699085207,
           -1.4216546787315547,
           -1.4523487644923356,
           -1.4831969531894287,
           -1.514160897296672,
           -1.545204584796706,
           -1.5762941599448574,
           -1.6073977561561617,
           -1.6384853410243936,
           -1.6695285732090648,
           -1.700500670739363,
           -1.7313762901626772,
           -1.7621314158933856,
           -1.7927432590821493,
           -1.8231901653170481,
           -1.8534515304777492,
           -1.883507724086659,
           -1.9133400195321721,
           -1.9429305305754043,
           -1.9722621535907443,
           -2.0013185150304,
           -2.03008392364263,
           -2.058543327011665,
           -2.086682272023898,
           -2.1144868688993816,
           -2.1419437584598957,
           -2.169040082334671,
           -2.1957634558323806,
           -2.2221019432332443,
           -2.2480440352781637,
           -2.273578628652814,
           -2.298695007283739,
           -2.3233828252808095,
           -2.347632091376139,
           -2.37143315472372,
           -2.3947766919369333,
           -2.4176536952526346,
           -2.4400554617210597,
           -2.461973583330196,
           -2.4833999379818334,
           -2.5043266812442218,
           -2.5247462388131936,
           -2.544651299619915,
           -2.564034809529099,
           -2.5828899655766255,
           -2.6012102107001875,
           -2.6189892289207246,
           -2.636220940936241,
           -2.6528995000930298,
           -2.669019288702437,
           -2.6845749146741222,
           -2.699561208439351,
           -2.7139732201401854,
           -2.7278062170625303,
           -2.7410556812929796,
           -2.753717307581102,
           -2.765787001390472,
           -2.7772608771231835,
           -2.788135256503924,
           -2.7984066671109686,
           -2.808071841042516,
           -2.8171277137078743,
           -2.8255714227339594,
           -2.8334003069784433,
           -2.84061190564171,
           -2.847203957470558,
           -2.8531744000472696,
           -2.85852136915836,
           -2.8632431982379214,
           -2.867338417881061,
           -2.8708057554235142,
           -2.8736441345839916,
           -2.8758526751663727,
           -2.8774306928192974,
           -2.878377698851201
          ],
          [
           -2.863421704896654,
           -2.863106899841666,
           -2.8621625815978224,
           -2.860589040953505,
           -2.858386762639632,
           -2.8555564254558163,
           -2.8520989024484593,
           -2.8480152611422813,
           -2.8433067638271985,
           -2.8379748679029553,
           -2.832021226284357,
           -2.8254476878704677,
           -2.8182562980816317,
           -2.810449299468743,
           -2.802029132399747,
           -2.7929984358289817,
           -2.783360048155607,
           -2.7731170081780867,
           -2.762272556152416,
           -2.7508301349626243,
           -2.73879339141293,
           -2.7261661776518857,
           -2.7129525527398846,
           -2.699156784372496,
           -2.6847833507733374,
           -2.6698369427715,
           -2.6543224660800195,
           -2.638245043793446,
           -2.621610019124338,
           -2.604422958400394,
           -2.5866896543460656,
           -2.568416129674779,
           -2.5496086410204586,
           -2.5302736832398582,
           -2.510417994120279,
           -2.4900485595307056,
           -2.4691726190581447,
           -2.447797672175149,
           -2.4259314849891194,
           -2.4035820976291196,
           -2.380757832331587,
           -2.357467302292636,
           -2.3337194213615935,
           -2.3095234146581753,
           -2.2848888302042503,
           -2.2598255516706875,
           -2.2343438123503203,
           -2.208454210479776,
           -2.182167726045903,
           -2.155495739226932,
           -2.1284500506344113,
           -2.101042903539625,
           -2.073287008287658,
           -2.045195569123769,
           -2.016782313680382,
           -1.9880615253989706,
           -1.9590480791895128,
           -1.9297574806611584,
           -1.9002059092912773,
           -1.870410265936208,
           -1.840388225125593,
           -1.810158292622955,
           -1.7797398687776402,
           -1.7491533182366654,
           -1.7184200466282311,
           -1.6875625848700821,
           -1.6566046817931284,
           -1.6255714058007324,
           -1.5944892563023614,
           -1.5633862856612453,
           -1.5322922323715817,
           -1.5012386661217088,
           -1.4702591452926923,
           -1.4393893872704318,
           -1.408667451692974,
           -1.378133936387442,
           -1.3478321852413209,
           -1.3178085065631335,
           -1.2881123995738073,
           -1.2587967854828717,
           -1.2299182380901488,
           -1.2015372069614543,
           -1.173718223911251,
           -1.1465300807597996,
           -1.1200459631253061,
           -1.094343521427844,
           -1.069504856471789,
           -1.0456163932068978,
           -1.02276861296949,
           -1.0010556122829044,
           -0.9805744559528936,
           -0.9614242946975774,
           -0.9437052239503043,
           -0.9275168717249267,
           -0.9129567201464455,
           -0.9001181873577423,
           -0.8890885229255295,
           -0.8799465982242454,
           -0.872760699926736,
           -0.867586455093203,
           -0.86446502568869,
           -0.863421704896654,
           -0.8644650256886921,
           -0.8675864550932072,
           -0.8727606999267425,
           -0.8799465982242538,
           -0.8890885229255401,
           -0.9001181873577545,
           -0.9129567201464597,
           -0.9275168717249423,
           -0.9437052239503217,
           -0.9614242946975963,
           -0.9805744559529138,
           -1.001055612282926,
           -1.0227686129695128,
           -1.0456163932069218,
           -1.0695048564718141,
           -1.09434352142787,
           -1.120045963125333,
           -1.146530080759827,
           -1.1737182239112791,
           -1.2015372069614831,
           -1.2299182380901783,
           -1.2587967854829016,
           -1.2881123995738375,
           -1.3178085065631644,
           -1.347832185241352,
           -1.3781339363874732,
           -1.4086674516930056,
           -1.4393893872704635,
           -1.4702591452927245,
           -1.5012386661217405,
           -1.5322922323716135,
           -1.5633862856612775,
           -1.5944892563023934,
           -1.6255714058007646,
           -1.6566046817931601,
           -1.687562584870114,
           -1.7184200466282629,
           -1.7491533182366965,
           -1.7797398687776715,
           -1.8101582926229862,
           -1.8403882251256238,
           -1.8704102659362387,
           -1.9002059092913077,
           -1.9297574806611881,
           -1.9590480791895428,
           -1.9880615253990004,
           -2.016782313680412,
           -2.0451955691237984,
           -2.073287008287687,
           -2.1010429035396534,
           -2.1284500506344393,
           -2.1554957392269594,
           -2.18216772604593,
           -2.2084542104798026,
           -2.2343438123503474,
           -2.2598255516707138,
           -2.284888830204276,
           -2.3095234146582,
           -2.3337194213616184,
           -2.35746730229266,
           -2.3807578323316108,
           -2.403582097629142,
           -2.425931484989142,
           -2.4477976721751715,
           -2.469172619058167,
           -2.4900485595307265,
           -2.5104179941202993,
           -2.5302736832398782,
           -2.5496086410204786,
           -2.568416129674798,
           -2.5866896543460847,
           -2.604422958400412,
           -2.621610019124355,
           -2.638245043793463,
           -2.654322466080036,
           -2.669836942771516,
           -2.684783350773352,
           -2.699156784372511,
           -2.7129525527398988,
           -2.726166177651899,
           -2.738793391412943,
           -2.7508301349626363,
           -2.7622725561524275,
           -2.773117008178097,
           -2.783360048155617,
           -2.792998435828991,
           -2.802029132399756,
           -2.8104492994687518,
           -2.8182562980816392,
           -2.825447687870475,
           -2.8320212262843634,
           -2.837974867902961,
           -2.8433067638272043,
           -2.8480152611422858,
           -2.8520989024484633,
           -2.8555564254558194,
           -2.8583867626396344,
           -2.860589040953507,
           -2.862162581597824,
           -2.8631068998416667
          ],
          [
           -2.8473147049577676,
           -2.8470008555317685,
           -2.8460594033413797,
           -2.8444906366734215,
           -2.842295036086103,
           -2.839473274530012,
           -2.8360262175189477,
           -2.8319549233520456,
           -2.8272606433891077,
           -2.8219448223814565,
           -2.8160090988611355,
           -2.809455305591734,
           -2.802285470084629,
           -2.7945018151849883,
           -2.7861067597324096,
           -2.7771029193017154,
           -2.7674931070300133,
           -2.757280334536883,
           -2.746467812945221,
           -2.7350589540111296,
           -2.7230573713720494,
           -2.7104668819233146,
           -2.697291507334274,
           -2.6835354757162615,
           -2.669203223455873,
           -2.654299397228347,
           -2.6388288562072484,
           -2.622796674488247,
           -2.6062081437465094,
           -2.589068776149099,
           -2.571384307545874,
           -2.5531607009646686,
           -2.534404150439044,
           -2.5151210851997297,
           -2.4953181742638897,
           -2.4750023314598084,
           -2.4541807209283144,
           -2.432860763146429,
           -2.411050141523354,
           -2.388756809623992,
           -2.365988999080898,
           -2.342755228261816,
           -2.319064311766947,
           -2.2949253708378516,
           -2.270347844768499,
           -2.2453415034185213,
           -2.219916460939404,
           -2.194083190836101,
           -2.1678525424997255,
           -2.1412357593615114,
           -2.1142444988344127,
           -2.0868908542266342,
           -2.059187378831241,
           -2.0311471124179614,
           -2.0027836103775214,
           -1.9741109757955908,
           -1.945143894762699,
           -1.9158976752586192,
           -1.8863882899846192,
           -1.8566324235548743,
           -1.8266475244989862,
           -1.7964518625709178,
           -1.7660645919052225,
           -1.735505820608668,
           -1.7047966874231437,
           -1.6739594461426275,
           -1.6430175585108233,
           -1.6119957963638376,
           -1.5809203538097951,
           -1.5498189702490102,
           -1.5187210650267422,
           -1.4876578844657746,
           -1.456662661935209,
           -1.4257707914583377,
           -1.395020015125143,
           -1.3644506242273142,
           -1.3341056735429901,
           -1.3040312075250124,
           -1.2742764962435218,
           -1.2448942777476188,
           -1.2159410019829395,
           -1.1874770694723824,
           -1.1595670555814879,
           -1.1322799083098969,
           -1.1056891041710384,
           -1.0798727428950796,
           -1.0549135575544906,
           -1.0308988125319338,
           -1.0079200579580652,
           -0.9860727064770397,
           -0.9654553973068067,
           -0.9461691146077864,
           -0.9283160333317962,
           -0.9119980771083898,
           -0.8973151901135414,
           -0.8843633483198894,
           -0.87323236399953,
           -0.8640035683645646,
           -0.8567474868265652,
           -0.8515216444451146,
           -0.8483686503565442,
           -0.8473147049577674,
           -0.8483686503565465,
           -0.8515216444451189,
           -0.8567474868265719,
           -0.864003568364573,
           -0.8732323639995405,
           -0.8843633483199016,
           -0.8973151901135556,
           -0.9119980771084057,
           -0.9283160333318138,
           -0.9461691146078055,
           -0.9654553973068274,
           -0.9860727064770617,
           -1.0079200579580883,
           -1.0308988125319578,
           -1.0549135575545159,
           -1.0798727428951058,
           -1.1056891041710653,
           -1.1322799083099244,
           -1.1595670555815163,
           -1.1874770694724115,
           -1.2159410019829688,
           -1.244894277747649,
           -1.2742764962435518,
           -1.3040312075250435,
           -1.3341056735430215,
           -1.3644506242273455,
           -1.3950200151251746,
           -1.4257707914583695,
           -1.4566626619352407,
           -1.4876578844658066,
           -1.518721065026774,
           -1.5498189702490421,
           -1.5809203538098273,
           -1.6119957963638698,
           -1.6430175585108548,
           -1.6739594461426592,
           -1.7047966874231757,
           -1.7355058206086995,
           -1.7660645919052538,
           -1.796451862570949,
           -1.8266475244990172,
           -1.8566324235549048,
           -1.8863882899846498,
           -1.9158976752586494,
           -1.9451438947627293,
           -1.9741109757956201,
           -2.002783610377551,
           -2.0311471124179907,
           -2.05918737883127,
           -2.0868908542266618,
           -2.1142444988344407,
           -2.141235759361539,
           -2.1678525424997526,
           -2.194083190836128,
           -2.21991646093943,
           -2.245341503418547,
           -2.2703478447685246,
           -2.294925370837877,
           -2.3190643117669714,
           -2.3427552282618405,
           -2.3659889990809213,
           -2.388756809624015,
           -2.411050141523377,
           -2.4328607631464516,
           -2.4541807209283357,
           -2.4750023314598293,
           -2.4953181742639106,
           -2.51512108519975,
           -2.534404150439064,
           -2.5531607009646873,
           -2.571384307545893,
           -2.5890687761491167,
           -2.6062081437465268,
           -2.6227966744882636,
           -2.6388288562072653,
           -2.6542993972283635,
           -2.6692032234558876,
           -2.6835354757162757,
           -2.6972915073342887,
           -2.710466881923328,
           -2.723057371372062,
           -2.735058954011141,
           -2.7464678129452325,
           -2.757280334536893,
           -2.7674931070300235,
           -2.7771029193017247,
           -2.786106759732419,
           -2.7945018151849967,
           -2.8022854700846365,
           -2.809455305591741,
           -2.816009098861142,
           -2.8219448223814623,
           -2.827260643389113,
           -2.8319549233520505,
           -2.836026217518952,
           -2.839473274530016,
           -2.842295036086105,
           -2.844490636673423,
           -2.846059403341381,
           -2.8470008555317685
          ],
          [
           -2.830387982764787,
           -2.8300751493237293,
           -2.8291367442133883,
           -2.827573053095166,
           -2.8253845521479595,
           -2.8225719081836993,
           -2.819135978810528,
           -2.815077812645033,
           -2.8103986495753936,
           -2.805099921077732,
           -2.799183250588408,
           -2.7926504539354786,
           -2.785503539833046,
           -2.7777447104427155,
           -2.7693763620069682,
           -2.760401085559833,
           -2.7508216677208663,
           -2.7406410915791244,
           -2.729862537674554,
           -2.7184893850849767,
           -2.7065252126277337,
           -2.6939738001859244,
           -2.680839130170211,
           -2.667125389128223,
           -2.652836969514781,
           -2.637978471637461,
           -2.6225547057934215,
           -2.606570694614979,
           -2.590031675643121,
           -2.572943104149994,
           -2.5553106562334955,
           -2.5371402322093464,
           -2.5184379603285167,
           -2.4992102008506656,
           -2.4794635505072766,
           -2.459204847391564,
           -2.4384411763159677,
           -2.417179874682162,
           -2.395428538913143,
           -2.373195031502,
           -2.350487488737676,
           -2.3273143291742646,
           -2.3036842629174092,
           -2.2796063018090917,
           -2.255089770600781,
           -2.23014431921447,
           -2.204779936201875,
           -2.1790069635239204,
           -2.152836112785918,
           -2.126278483078567,
           -2.0993455805912884,
           -2.0720493401826268,
           -2.044402149112679,
           -2.0164168731649346,
           -1.98810688540976,
           -1.9594860978892112,
           -1.930568996533111,
           -1.9013706796495924,
           -1.8719069003697029,
           -1.8421941134652742,
           -1.8122495270021668,
           -1.7820911593369995,
           -1.751737902014356,
           -1.72120958917265,
           -1.6905270741194782,
           -1.659712313790025,
           -1.628788461852942,
           -1.5977799712742966,
           -1.5667127071877016,
           -1.535614070942235,
           -1.5045131362019237,
           -1.4734407979416706,
           -1.4424299351117333,
           -1.4115155876095498,
           -1.3807351479823462,
           -1.350128567959448,
           -1.319738579445465,
           -1.2896109289530253,
           -1.2597946235665083,
           -1.2303421853483214,
           -1.2013099095617523,
           -1.1727581201210489,
           -1.144751413224619,
           -1.1173588771296832,
           -1.0906542724655908,
           -1.064716153393409,
           -1.0396279054255713,
           -1.0154776710772702,
           -0.9923581301662124,
           -0.9703660981696743,
           -0.9496019045017957,
           -0.9301685140472077,
           -0.912170361099929,
           -0.8957118763108358,
           -0.8808957053210865,
           -0.8678206426880417,
           -0.8565793355152292,
           -0.8472558452930014,
           -0.8399231895295937,
           -0.8346410111186471,
           -0.8314535369338212,
           -0.8303879827647869,
           -0.8314535369338235,
           -0.8346410111186515,
           -0.8399231895296002,
           -0.8472558452930099,
           -0.85657933551524,
           -0.8678206426880541,
           -0.8808957053211008,
           -0.895711876310852,
           -0.9121703610999466,
           -0.930168514047227,
           -0.9496019045018166,
           -0.9703660981696963,
           -0.9923581301662356,
           -1.0154776710772946,
           -1.0396279054255966,
           -1.0647161533934353,
           -1.0906542724656176,
           -1.117358877129711,
           -1.1447514132246475,
           -1.172758120121078,
           -1.2013099095617819,
           -1.2303421853483512,
           -1.259794623566539,
           -1.2896109289530562,
           -1.319738579445496,
           -1.3501285679594792,
           -1.380735147982378,
           -1.4115155876095815,
           -1.4424299351117655,
           -1.4734407979417021,
           -1.504513136201956,
           -1.535614070942267,
           -1.5667127071877338,
           -1.5977799712743288,
           -1.628788461852974,
           -1.6597123137900567,
           -1.6905270741195095,
           -1.721209589172681,
           -1.751737902014387,
           -1.7820911593370308,
           -1.8122495270021977,
           -1.842194113465305,
           -1.871906900369733,
           -1.9013706796496224,
           -1.9305689965331405,
           -1.959486097889241,
           -1.9881068854097894,
           -2.0164168731649634,
           -2.044402149112708,
           -2.072049340182655,
           -2.099345580591316,
           -2.1262784830785946,
           -2.152836112785945,
           -2.1790069635239466,
           -2.2047799362019016,
           -2.230144319214496,
           -2.255089770600806,
           -2.279606301809117,
           -2.3036842629174337,
           -2.3273143291742886,
           -2.3504874887376994,
           -2.3731950315020236,
           -2.3954285389131655,
           -2.4171798746821844,
           -2.438441176315989,
           -2.459204847391585,
           -2.4794635505072966,
           -2.499210200850685,
           -2.5184379603285363,
           -2.537140232209365,
           -2.555310656233514,
           -2.5729431041500113,
           -2.590031675643139,
           -2.606570694614996,
           -2.622554705793438,
           -2.637978471637477,
           -2.6528369695147958,
           -2.6671253891282367,
           -2.6808391301702246,
           -2.6939738001859372,
           -2.7065252126277466,
           -2.718489385084989,
           -2.729862537674565,
           -2.740641091579135,
           -2.750821667720876,
           -2.760401085559842,
           -2.7693763620069767,
           -2.7777447104427244,
           -2.785503539833054,
           -2.7926504539354857,
           -2.7991832505884138,
           -2.805099921077738,
           -2.810398649575399,
           -2.815077812645037,
           -2.8191359788105324,
           -2.8225719081837033,
           -2.825384552147962,
           -2.827573053095168,
           -2.8291367442133892,
           -2.8300751493237297
          ],
          [
           -2.812657913828239,
           -2.812346157704924,
           -2.811410983632947,
           -2.8098526745279866,
           -2.807671701988928,
           -2.804868726407697,
           -2.8014445971243958,
           -2.7974003526291558,
           -2.7927372208124974,
           -2.7874566192664476,
           -2.781560155639093,
           -2.7750496280457053,
           -2.7679270255400756,
           -2.7601945286502048,
           -2.7518545099830134,
           -2.7429095349033634,
           -2.7333623622932444,
           -2.723215945397675,
           -2.712473432764577,
           -2.701138169286623,
           -2.6892136973539285,
           -2.6767037581273105,
           -2.663612292942866,
           -2.649943444859648,
           -2.6357015603633944,
           -2.6208911912405455,
           -2.6055170966381693,
           -2.5895842453269418,
           -2.573097818186006,
           -2.5560632109303967,
           -2.5384860371037163,
           -2.5203721313610257,
           -2.5017275530693612,
           -2.482558590256028,
           -2.462871763937854,
           -2.442673832867917,
           -2.4219717987399703,
           -2.400772911894925,
           -2.3790846775782653,
           -2.3569148628023955,
           -2.334271503873499,
           -2.3111629146488144,
           -2.287597695597138,
           -2.2635847437431917,
           -2.2391332635851136,
           -2.214252779083962,
           -2.188953146834893,
           -2.1632445705416425,
           -2.137137616929289,
           -2.110643233245187,
           -2.0837727665145493,
           -2.0565379847356406,
           -2.0289511002201435,
           -2.0010247953071523,
           -1.972772250704661,
           -1.9442071767406504,
           -1.915343847837036,
           -1.886197140554218,
           -1.8567825755917946,
           -1.8271163641724892,
           -1.7972154592814482,
           -1.7670976122818978,
           -1.7367814354804116,
           -1.7062864712704464,
           -1.675633268540523,
           -1.644843467092388,
           -1.6139398908728284,
           -1.5829466508780006,
           -1.5518892586374327,
           -1.5207947512211588,
           -1.489691828730667,
           -1.4586110052230208,
           -1.4275847739649064,
           -1.3966477878028727,
           -1.3658370552458803,
           -1.3351921525587422,
           -1.304755451724943,
           -1.274572363511078,
           -1.244691593999746,
           -1.2151654117904682,
           -1.1860499215274989,
           -1.157405337421712,
           -1.1292962479133464,
           -1.1017918595064171,
           -1.074966204054855,
           -1.0488982894098717,
           -1.0236721684526127,
           -0.9993768963781441,
           -0.9761063411010806,
           -0.9539588075033081,
           -0.9330364339143793,
           -0.9134443199721006,
           -0.8952893503420766,
           -0.8786786902029448,
           -0.8637179471555226,
           -0.8505090207462875,
           -0.8391476942400219,
           -0.8297210609469168,
           -0.822304914600541,
           -0.8169612636081998,
           -0.8137361454246931,
           -0.812657913828239,
           -0.8137361454246953,
           -0.8169612636082043,
           -0.8223049146005476,
           -0.8297210609469255,
           -0.8391476942400327,
           -0.8505090207463002,
           -0.863717947155537,
           -0.8786786902029611,
           -0.8952893503420942,
           -0.91344431997212,
           -0.9330364339144003,
           -0.9539588075033302,
           -0.9761063411011038,
           -0.9993768963781685,
           -1.0236721684526382,
           -1.0488982894098982,
           -1.0749662040548822,
           -1.101791859506445,
           -1.129296247913375,
           -1.1574053374217408,
           -1.1860499215275286,
           -1.215165411790498,
           -1.2446915939997767,
           -1.2745723635111086,
           -1.304755451724974,
           -1.3351921525587738,
           -1.365837055245912,
           -1.3966477878029044,
           -1.4275847739649383,
           -1.4586110052230528,
           -1.489691828730699,
           -1.5207947512211906,
           -1.5518892586374646,
           -1.5829466508780325,
           -1.6139398908728604,
           -1.6448434670924197,
           -1.6756332685405546,
           -1.7062864712704777,
           -1.736781435480443,
           -1.7670976122819289,
           -1.797215459281479,
           -1.82711636417252,
           -1.8567825755918252,
           -1.8861971405542481,
           -1.9153438478370657,
           -1.9442071767406797,
           -1.9727722507046903,
           -2.001024795307181,
           -2.0289511002201723,
           -2.056537984735668,
           -2.0837727665145773,
           -2.1106432332452147,
           -2.1371376169293157,
           -2.163244570541669,
           -2.1889531468349186,
           -2.214252779083987,
           -2.239133263585139,
           -2.263584743743217,
           -2.287597695597162,
           -2.311162914648839,
           -2.3342715038735227,
           -2.356914862802418,
           -2.3790846775782883,
           -2.400772911894947,
           -2.421971798739992,
           -2.442673832867938,
           -2.462871763937875,
           -2.4825585902560476,
           -2.5017275530693803,
           -2.5203721313610448,
           -2.538486037103734,
           -2.5560632109304144,
           -2.573097818186023,
           -2.5895842453269586,
           -2.605517096638186,
           -2.6208911912405615,
           -2.63570156036341,
           -2.649943444859663,
           -2.66361229294288,
           -2.6767037581273234,
           -2.6892136973539413,
           -2.7011381692866356,
           -2.7124734327645883,
           -2.723215945397686,
           -2.7333623622932546,
           -2.742909534903373,
           -2.7518545099830223,
           -2.760194528650213,
           -2.767927025540083,
           -2.7750496280457115,
           -2.7815601556390996,
           -2.7874566192664534,
           -2.7927372208125023,
           -2.7974003526291606,
           -2.8014445971244,
           -2.8048687264076997,
           -2.80767170198893,
           -2.809852674527988,
           -2.811410983632949,
           -2.812346157704925
          ],
          [
           -2.7941416508447414,
           -2.793831034406159,
           -2.7928992784347084,
           -2.791346662983863,
           -2.789173654878197,
           -2.7863809078172355,
           -2.782969262522197,
           -2.7789397469269748,
           -2.774293576415123,
           -2.769032154105049,
           -2.763157071185983,
           -2.7566701073078375,
           -2.7495732310284517,
           -2.7418686003222934,
           -2.7335585631551687,
           -2.7246456581300778,
           -2.7151326152099555,
           -2.7050223565236675,
           -2.6943179972623565,
           -2.6830228466739574,
           -2.6711404091645217,
           -2.6586743855158788,
           -2.645628674230117,
           -2.6320073730124114,
           -2.6178147804048715,
           -2.603055397585323,
           -2.587733930346316,
           -2.5718552912711563,
           -2.555424602125386,
           -2.5384471964839905,
           -2.520928622616589,
           -2.50287464665507,
           -2.484291256070613,
           -2.465184663489675,
           -2.4455613108815784,
           -2.4254278741535886,
           -2.4047912681930796,
           -2.3836586524004533,
           -2.36203743676099,
           -2.3399352885088875,
           -2.317360139442299,
           -2.2943201939544595,
           -2.270823937852946,
           -2.2468801480468437,
           -2.222497903190279,
           -2.197686595380423,
           -2.1724559430188446,
           -2.1468160049571634,
           -2.1207771960613884,
           -2.0943503043443608,
           -2.06754650983253,
           -2.0403774053520234,
           -2.012855019439904,
           -1.9849918416098662,
           -1.9568008502276097,
           -1.9282955432800846,
           -1.899489972354931,
           -1.8703987801820618,
           -1.841037242128667,
           -1.811421312082248,
           -1.7815676732037167,
           -1.751493794084268,
           -1.721217990895564,
           -1.6907594961825023,
           -1.660138535010917,
           -1.629376409248046,
           -1.5984955908198633,
           -1.5675198248541917,
           -1.536474243678376,
           -1.5053854926904395,
           -1.4742818691563013,
           -1.4431934749936237,
           -1.4121523845726813,
           -1.38119282847981,
           -1.350351394027607,
           -1.319667243029907,
           -1.2891823469523882,
           -1.2589417389559951,
           -1.22899378151399,
           -1.199390447136856,
           -1.1701876082037095,
           -1.1414453298866953,
           -1.1132281575747764,
           -1.0856053869707563,
           -1.058651301089697,
           -1.0324453537184954,
           -1.007072273585504,
           -0.982622057758127,
           -0.9591898170635653,
           -0.9368754313159937,
           -0.9157829688671679,
           -0.8960198248625251,
           -0.8776955372588654,
           -0.8609202509254623,
           -0.8458028195396502,
           -0.8324485632448624,
           -0.8209567364626352,
           -0.8114178020755941,
           -0.8039106502843698,
           -0.7984999355733673,
           -0.7952337252536517,
           -0.7941416508447416,
           -0.7952337252536541,
           -0.7984999355733717,
           -0.8039106502843766,
           -0.8114178020756029,
           -0.820956736462646,
           -0.8324485632448752,
           -0.8458028195396647,
           -0.8609202509254787,
           -0.8776955372588836,
           -0.8960198248625446,
           -0.915782968867189,
           -0.9368754313160161,
           -0.9591898170635887,
           -0.9826220577581516,
           -1.0070722735855293,
           -1.032445353718522,
           -1.0586513010897243,
           -1.0856053869707845,
           -1.113228157574805,
           -1.1414453298867246,
           -1.1701876082037392,
           -1.1993904471368864,
           -1.2289937815140204,
           -1.2589417389560258,
           -1.2891823469524195,
           -1.3196672430299385,
           -1.3503513940276388,
           -1.3811928284798418,
           -1.412152384572713,
           -1.4431934749936555,
           -1.4742818691563335,
           -1.5053854926904713,
           -1.5364742436784082,
           -1.5675198248542235,
           -1.5984955908198952,
           -1.6293764092480778,
           -1.6601385350109488,
           -1.6907594961825336,
           -1.7212179908955958,
           -1.751493794084299,
           -1.7815676732037475,
           -1.8114213120822784,
           -1.8410372421286973,
           -1.8703987801820918,
           -1.8994899723549608,
           -1.928295543280114,
           -1.9568008502276388,
           -1.9849918416098948,
           -2.012855019439933,
           -2.0403774053520514,
           -2.0675465098325576,
           -2.0943503043443883,
           -2.120777196061415,
           -2.14681600495719,
           -2.172455943018871,
           -2.1976865953804485,
           -2.222497903190305,
           -2.2468801480468685,
           -2.2708239378529704,
           -2.2943201939544835,
           -2.3173601394423224,
           -2.3399352885089106,
           -2.362037436761012,
           -2.383658652400475,
           -2.4047912681931014,
           -2.425427874153609,
           -2.445561310881599,
           -2.4651846634896946,
           -2.4842912560706325,
           -2.5028746466550897,
           -2.5209286226166068,
           -2.5384471964840087,
           -2.555424602125403,
           -2.5718552912711727,
           -2.5877339303463325,
           -2.6030553975853374,
           -2.6178147804048866,
           -2.632007373012426,
           -2.64562867423013,
           -2.6586743855158916,
           -2.6711404091645345,
           -2.683022846673969,
           -2.694317997262368,
           -2.7050223565236777,
           -2.7151326152099653,
           -2.724645658130088,
           -2.7335585631551775,
           -2.7418686003223014,
           -2.7495732310284597,
           -2.7566701073078446,
           -2.7631570711859896,
           -2.7690321541050547,
           -2.774293576415128,
           -2.7789397469269788,
           -2.7829692625222013,
           -2.786380907817238,
           -2.789173654878199,
           -2.791346662983865,
           -2.7928992784347098,
           -2.7938310344061597
          ],
          [
           -2.7748571071028776,
           -2.7745476938080476,
           -2.773619546276754,
           -2.7720729415879215,
           -2.7699083416044017,
           -2.7671263930705985,
           -2.763727927750444,
           -2.759713962607058,
           -2.755085700025798,
           -2.749844528082822,
           -2.7439920208617075,
           -2.7375299388211016,
           -2.730460229216851,
           -2.722785026582542,
           -2.7145066532728834,
           -2.705627620074952,
           -2.6961506268928583,
           -2.6860785635120656,
           -2.675414510450253,
           -2.6641617399023345,
           -2.652323716788078,
           -2.639904099911592,
           -2.626906743242909,
           -2.6133356973329067,
           -2.599195210873936,
           -2.5844897324197427,
           -2.5692239122796097,
           -2.55340260460313,
           -2.537030869673638,
           -2.520113976430108,
           -2.502657405239308,
           -2.4846668509421646,
           -2.466148226200703,
           -2.4471076651746,
           -2.427551527559296,
           -2.407486403020947,
           -2.3869191160670713,
           -2.3658567313958114,
           -2.344306559771213,
           -2.322276164476922,
           -2.2997733684062625,
           -2.2768062618528804,
           -2.2533832110730407,
           -2.2295128676984324,
           -2.2052041790869534,
           -2.180466399708626,
           -2.1553091036745857,
           -2.129742198529201,
           -2.1037759404388914,
           -2.0774209509263857,
           -2.050688235316107,
           -2.0235892030753777,
           -1.9961356902573646,
           -1.9683399842754783,
           -1.9402148512654824,
           -1.9117735663212279,
           -1.8830299469229999,
           -1.853998389914233,
           -1.8246939124231898,
           -1.7951321971713634,
           -1.7653296426601597,
           -1.7353034187819856,
           -1.705071528461341,
           -1.6746528759957378,
           -1.6440673428349164,
           -1.6133358716091102,
           -1.5824805592917723,
           -1.5515247604571667,
           -1.5204932016654522,
           -1.4894121080729354,
           -1.4583093434166472,
           -1.4272145645515242,
           -1.396159391713128,
           -1.3651775956226977,
           -1.3343053024226124,
           -1.3035812172004495,
           -1.2730468664915977,
           -1.2427468595965734,
           -1.212729167750444,
           -1.1830454190655944,
           -1.1537512056492607,
           -1.1249063972751834,
           -1.096575453358192,
           -1.068827721636837,
           -1.0417377078267436,
           -1.0153852955269802,
           -0.9898558898924207,
           -0.9652404522213179,
           -0.9416353860625001,
           -0.9191422294358086,
           -0.8978671033762783,
           -0.8779198657704792,
           -0.8594129232447789,
           -0.8424596647795874,
           -0.8271725006664733,
           -0.8136605205117275,
           -0.8020268237654401,
           -0.7923656229150374,
           -0.7847592674083388,
           -0.7792753773722848,
           -0.7759643007585023,
           -0.7748571071028774,
           -0.7759643007585045,
           -0.7792753773722895,
           -0.7847592674083456,
           -0.7923656229150463,
           -0.8020268237654512,
           -0.8136605205117404,
           -0.8271725006664882,
           -0.8424596647796041,
           -0.859412923244797,
           -0.877919865770499,
           -0.8978671033762995,
           -0.919142229435831,
           -0.9416353860625237,
           -0.9652404522213427,
           -0.9898558898924465,
           -1.0153852955270068,
           -1.041737707826771,
           -1.0688277216368651,
           -1.0965754533582206,
           -1.1249063972752127,
           -1.1537512056492905,
           -1.1830454190656245,
           -1.2127291677504743,
           -1.2427468595966045,
           -1.2730468664916288,
           -1.303581217200481,
           -1.334305302422644,
           -1.3651775956227294,
           -1.39615939171316,
           -1.4272145645515564,
           -1.4583093434166792,
           -1.4894121080729672,
           -1.5204932016654842,
           -1.5515247604571987,
           -1.5824805592918039,
           -1.613335871609142,
           -1.6440673428349482,
           -1.6746528759957693,
           -1.705071528461372,
           -1.7353034187820167,
           -1.7653296426601905,
           -1.7951321971713936,
           -1.82469391242322,
           -1.8539983899142631,
           -1.8830299469230296,
           -1.9117735663212574,
           -1.9402148512655113,
           -1.968339984275507,
           -1.9961356902573926,
           -2.0235892030754057,
           -2.050688235316135,
           -2.077420950926413,
           -2.1037759404389185,
           -2.1297421985292275,
           -2.155309103674612,
           -2.1804663997086515,
           -2.2052041790869787,
           -2.2295128676984572,
           -2.2533832110730647,
           -2.2768062618529044,
           -2.299773368406286,
           -2.3222761644769445,
           -2.3443065597712356,
           -2.3658567313958336,
           -2.386919116067093,
           -2.407486403020968,
           -2.4275515275593165,
           -2.4471076651746198,
           -2.466148226200723,
           -2.4846668509421823,
           -2.5026574052393267,
           -2.520113976430126,
           -2.537030869673655,
           -2.5534026046031464,
           -2.569223912279626,
           -2.5844897324197587,
           -2.5991952108739507,
           -2.6133356973329205,
           -2.6269067432429227,
           -2.6399040999116052,
           -2.6523237167880906,
           -2.664161739902346,
           -2.6754145104502642,
           -2.686078563512076,
           -2.6961506268928677,
           -2.705627620074961,
           -2.714506653272892,
           -2.72278502658255,
           -2.7304602292168583,
           -2.7375299388211087,
           -2.7439920208617137,
           -2.749844528082827,
           -2.755085700025803,
           -2.7597139626070626,
           -2.7637279277504483,
           -2.7671263930706016,
           -2.7699083416044044,
           -2.772072941587923,
           -2.7736195462767554,
           -2.7745476938080484
          ],
          [
           -2.754822939153244,
           -2.754514793611523,
           -2.7535904483125035,
           -2.7520501772526673,
           -2.7498944371531624,
           -2.747123867550951,
           -2.743739290927688,
           -2.7397417128776125,
           -2.7351323223161086,
           -2.7299124917309987,
           -2.7240837774790303,
           -2.7176479201304504,
           -2.710606844865009,
           -2.702962661923205,
           -2.694717667117088,
           -2.6858743424054725,
           -2.6764353565389802,
           -2.6664035657809495,
           -2.655782014710915,
           -2.644573937118063,
           -2.632782756992853,
           -2.620412089625833,
           -2.607465742823589,
           -2.593947718252787,
           -2.579862212924323,
           -2.5652136208308294,
           -2.550006534752084,
           -2.5342457482443046,
           -2.517936257830925,
           -2.501083265414168,
           -2.4836921809286943,
           -2.4657686252607234,
           -2.4473184334583955,
           -2.4283476582617625,
           -2.4088625739836873,
           -2.388869680776192,
           -2.368375709320318,
           -2.347387625981614,
           -2.325912638477762,
           -2.3039582021098086,
           -2.2815320266140073,
           -2.258642083697413,
           -2.2352966153272695,
           -2.211504142851933,
           -2.187273477039684,
           -2.1626137291314333,
           -2.13753432301413,
           -2.1120450086338187,
           -2.0861558767808446,
           -2.0598773753950037,
           -2.0332203275554908,
           -2.0061959513397354,
           -1.9788158817567125,
           -1.9510921949845295,
           -1.9230374351691066,
           -1.8946646440711685,
           -1.8659873938826708,
           -1.8370198235717368,
           -1.8077766791574512,
           -1.7782733583628973,
           -1.7485259601469496,
           -1.7185513396728611,
           -1.6883671693348419,
           -1.6579920065326685,
           -1.6274453689587278,
           -1.596747818241281,
           -1.5659210528711414,
           -1.5349880114246806,
           -1.5039729871814285,
           -1.4729017553155253,
           -1.4418017139109855,
           -1.410702040102899,
           -1.3796338626686497,
           -1.3486304523690744,
           -1.3177274312476317,
           -1.286963001907393,
           -1.2563781974631703,
           -1.2260171523604542,
           -1.1959273935017896,
           -1.1661601500472636,
           -1.1367706787648968,
           -1.1078185997887633,
           -1.0793682349748366,
           -1.051488937599851,
           -1.0242553978122206,
           -0.9977479029418678,
           -0.9720525255174246,
           -0.9472612047813816,
           -0.9234716800237357,
           -0.9007872268897914,
           -0.879316142105601,
           -0.8591709194522459,
           -0.8404670624408146,
           -0.8233214894429368,
           -0.8078505073807252,
           -0.7941673620695323,
           -0.782379416836076,
           -0.7725850633237384,
           -0.7648705233177812,
           -0.7593067486325954,
           -0.7559466564064744,
           -0.754822939153244,
           -0.7559466564064767,
           -0.7593067486326001,
           -0.7648705233177882,
           -0.7725850633237474,
           -0.7823794168360872,
           -0.7941673620695454,
           -0.8078505073807403,
           -0.8233214894429536,
           -0.8404670624408328,
           -0.859170919452266,
           -0.8793161421056224,
           -0.9007872268898143,
           -0.9234716800237596,
           -0.9472612047814066,
           -0.9720525255174505,
           -0.9977479029418946,
           -1.0242553978122482,
           -1.0514889375998795,
           -1.0793682349748657,
           -1.1078185997887928,
           -1.1367706787649265,
           -1.166160150047294,
           -1.1959273935018202,
           -1.2260171523604853,
           -1.2563781974632013,
           -1.2869630019074243,
           -1.3177274312476632,
           -1.3486304523691062,
           -1.3796338626686813,
           -1.4107020401029309,
           -1.4418017139110177,
           -1.4729017553155574,
           -1.50397298718146,
           -1.5349880114247125,
           -1.5659210528711733,
           -1.5967478182413126,
           -1.6274453689587594,
           -1.6579920065327,
           -1.6883671693348732,
           -1.7185513396728924,
           -1.7485259601469805,
           -1.7782733583629278,
           -1.8077766791574814,
           -1.8370198235717672,
           -1.8659873938827005,
           -1.8946646440711978,
           -1.9230374351691355,
           -1.9510921949845583,
           -1.9788158817567407,
           -2.006195951339763,
           -2.0332203275555187,
           -2.059877375395031,
           -2.086155876780871,
           -2.112045008633845,
           -2.1375343230141564,
           -2.162613729131458,
           -2.187273477039709,
           -2.211504142851958,
           -2.235296615327294,
           -2.258642083697437,
           -2.281532026614031,
           -2.3039582021098313,
           -2.3259126384777837,
           -2.347387625981636,
           -2.3683757093203393,
           -2.388869680776213,
           -2.4088625739837077,
           -2.4283476582617816,
           -2.447318433458415,
           -2.465768625260742,
           -2.483692180928712,
           -2.501083265414186,
           -2.5179362578309425,
           -2.534245748244321,
           -2.5500065347520997,
           -2.5652136208308454,
           -2.5798622129243376,
           -2.5939477182528012,
           -2.607465742823602,
           -2.6204120896258454,
           -2.632782756992866,
           -2.644573937118075,
           -2.655782014710926,
           -2.6664035657809597,
           -2.6764353565389905,
           -2.6858743424054827,
           -2.6947176671170965,
           -2.702962661923213,
           -2.7106068448650165,
           -2.717647920130457,
           -2.7240837774790365,
           -2.729912491731005,
           -2.7351323223161135,
           -2.7397417128776165,
           -2.7437392909276914,
           -2.747123867550954,
           -2.749894437153165,
           -2.752050177252669,
           -2.753590448312505,
           -2.7545147936115235
          ],
          [
           -2.7340585287594465,
           -2.733751716789235,
           -2.7328313711433374,
           -2.731297762632682,
           -2.729151342664703,
           -2.7263927433277906,
           -2.7230227775107423,
           -2.7190424390584655,
           -2.7144529029655273,
           -2.709255525609557,
           -2.7034518450268727,
           -2.6970435812331415,
           -2.6900326365922953,
           -2.6824210962374084,
           -2.6742112285477004,
           -2.66540548568638,
           -2.6560065042045586,
           -2.6460171057171067,
           -2.6354402976569267,
           -2.6242792741148318,
           -2.612537416772981,
           -2.6002182959406066,
           -2.5873256717016986,
           -2.5738634951852677,
           -2.55983590996987,
           -2.545247253635247,
           -2.530102059475227,
           -2.5144050583874353,
           -2.4981611809569055,
           -2.4813755597524225,
           -2.4640535318562926,
           -2.446200641650352,
           -2.4278226438833355,
           -2.408925507047282,
           -2.3895154170935475,
           -2.369598781522123,
           -2.3491822338815043,
           -2.3282726387203008,
           -2.306877097036118,
           -2.2850029522721718,
           -2.2626577969175234,
           -2.239849479772947,
           -2.2165861139512533,
           -2.1928760856885554,
           -2.1687280640515327,
           -2.144151011635344,
           -2.1191541963576648,
           -2.0937472044664056,
           -2.0679399548923185,
           -2.0417427150929894,
           -2.015166118551928,
           -1.9882211841158552,
           -1.9609193373750495,
           -1.9332724343161394,
           -1.9052927875042749,
           -1.8769931950826027,
           -1.8483869729117401,
           -1.8194879902109795,
           -1.7903107091066444,
           -1.7608702285418936,
           -1.7311823330566758,
           -1.7012635470070585,
           -1.6711311948599845,
           -1.6408034682730634,
           -1.6102995007491958,
           -1.579639450742544,
           -1.548844594184831,
           -1.5179374274979034,
           -1.4869417822576987,
           -1.4558829527726591,
           -1.424787837931006,
           -1.393685098748365,
           -1.3626053330990824,
           -1.3315812691258122,
           -1.3006479787715004,
           -1.269843112737131,
           -1.2392071578993347,
           -1.2087837177739618,
           -1.1786198159200414,
           -1.1487662211608038,
           -1.1192777920527357,
           -1.0902138360376266,
           -1.061638476025644,
           -1.0336210136276718,
           -1.006236273734549,
           -0.9795649095133035,
           -0.9536936401170352,
           -0.9287153855924464,
           -0.9047292549637331,
           -0.8818403349785232,
           -0.8601592197121666,
           -0.8398012169242983,
           -0.8208851681452298,
           -0.803531828808767,
           -0.7878617752662782,
           -0.7739928394270986,
           -0.7620371194740508,
           -0.7520976739481352,
           -0.7442650698269092,
           -0.7386140123376855,
           -0.735200321870619,
           -0.7340585287594465,
           -0.7352003218706213,
           -0.7386140123376903,
           -0.7442650698269162,
           -0.7520976739481444,
           -0.762037119474062,
           -0.7739928394271118,
           -0.7878617752662932,
           -0.8035318288087839,
           -0.8208851681452485,
           -0.8398012169243185,
           -0.8601592197121882,
           -0.8818403349785462,
           -0.9047292549637572,
           -0.9287153855924716,
           -0.9536936401170614,
           -0.9795649095133304,
           -1.006236273734577,
           -1.0336210136277002,
           -1.0616384760256732,
           -1.090213836037656,
           -1.119277792052766,
           -1.1487662211608343,
           -1.178619815920072,
           -1.2087837177739928,
           -1.2392071578993662,
           -1.2698431127371628,
           -1.3006479787715322,
           -1.331581269125844,
           -1.3626053330991144,
           -1.3936850987483969,
           -1.424787837931038,
           -1.4558829527726913,
           -1.4869417822577304,
           -1.5179374274979351,
           -1.5488445941848628,
           -1.5796394507425755,
           -1.610299500749227,
           -1.6408034682730948,
           -1.6711311948600158,
           -1.7012635470070894,
           -1.7311823330567067,
           -1.7608702285419242,
           -1.7903107091066748,
           -1.819487990211009,
           -1.84838697291177,
           -1.8769931950826317,
           -1.9052927875043038,
           -1.933272434316168,
           -1.960919337375078,
           -1.988221184115883,
           -2.0151661185519556,
           -2.0417427150930165,
           -2.0679399548923456,
           -2.093747204466432,
           -2.1191541963576905,
           -2.1441510116353695,
           -2.168728064051558,
           -2.1928760856885803,
           -2.2165861139512772,
           -2.239849479772971,
           -2.2626577969175465,
           -2.2850029522721944,
           -2.30687709703614,
           -2.3282726387203225,
           -2.3491822338815265,
           -2.3695987815221438,
           -2.389515417093568,
           -2.4089255070473015,
           -2.4278226438833546,
           -2.4462006416503708,
           -2.4640535318563104,
           -2.4813755597524403,
           -2.4981611809569224,
           -2.5144050583874513,
           -2.5301020594752432,
           -2.5452472536352624,
           -2.5598359099698853,
           -2.5738634951852823,
           -2.587325671701712,
           -2.6002182959406195,
           -2.6125374167729936,
           -2.6242792741148437,
           -2.6354402976569373,
           -2.646017105717117,
           -2.6560065042045684,
           -2.665405485686389,
           -2.6742112285477093,
           -2.682421096237417,
           -2.690032636592303,
           -2.697043581233149,
           -2.703451845026879,
           -2.7092555256095623,
           -2.714452902965532,
           -2.7190424390584704,
           -2.7230227775107467,
           -2.7263927433277937,
           -2.7291513426647054,
           -2.7312977626326833,
           -2.732831371143339,
           -2.733751716789236
          ],
          [
           -2.712583964147493,
           -2.71227855283529,
           -2.7113624080693657,
           -2.70983579737711,
           -2.707699166688795,
           -2.704953140415106,
           -2.701598521556862,
           -2.6976362918481303,
           -2.6930676119342847,
           -2.6878938215869232,
           -2.682116439957947,
           -2.6757371658755154,
           -2.6687578781849726,
           -2.661180636138333,
           -2.6530076798363473,
           -2.6442414307276847,
           -2.634884492170317,
           -2.6249396500607336,
           -2.6144098735372854,
           -2.603298315764578,
           -2.591608314806612,
           -2.5793433945971245,
           -2.566507266016479,
           -2.553103828085381,
           -2.5391371692867315,
           -2.52461156902809,
           -2.5095314992584257,
           -2.49390162625425,
           -2.477726812591719,
           -2.4610121193229553,
           -2.4437628083767207,
           -2.425984345205579,
           -2.4076824017039815,
           -2.3888628594242194,
           -2.3695318131199716,
           -2.3496955746503088,
           -2.329360677280458,
           -2.308533880419509,
           -2.2872221748395423,
           -2.265432788425487,
           -2.2431731925103926,
           -2.2204511088568366,
           -2.197274517351934,
           -2.173651664491002,
           -2.1495910727334437,
           -2.1251015508239544,
           -2.100192205182908,
           -2.074872452481881,
           -2.0491520335338675,
           -2.023041028643081,
           -1.9965498745765342,
           -1.9696893833390714,
           -1.9424707629555131,
           -1.9149056404883875,
           -1.8870060875476926,
           -1.8587846485806743,
           -1.8302543722651918,
           -1.8014288463702666,
           -1.7723222364924853,
           -1.742949329127515,
           -1.7133255795927032,
           -1.683467165380116,
           -1.6533910455899277,
           -1.6231150271722903,
           -1.592657838791959,
           -1.5620392132240977,
           -1.5312799792915044,
           -1.50040216446212,
           -1.4694291093393301,
           -1.4383855953933846,
           -1.407297987395596,
           -1.3761943921208808,
           -1.345104834968552,
           -1.3140614562014674,
           -1.283098728499349,
           -1.2522536974351486,
           -1.221566246275562,
           -1.1910793861270572,
           -1.1608395718298115,
           -1.1308970430569103,
           -1.1013061886952378,
           -1.0721259306329096,
           -1.0434201203961722,
           -1.015257938487067,
           -0.9877142815861722,
           -0.9608701168371454,
           -0.9348127751231604,
           -0.9096361466210662,
           -0.8854407322642416,
           -0.8623334947315368,
           -0.8404274434255042,
           -0.81984088152371,
           -0.8006962422698848,
           -0.7831184495724989,
           -0.7672327583035924,
           -0.7531620654494301,
           -0.7410237355636666,
           -0.7309260504477049,
           -0.7229644664600324,
           -0.7172179310492498,
           -0.7137455571420285,
           -0.7125839641474928,
           -0.7137455571420308,
           -0.7172179310492547,
           -0.7229644664600395,
           -0.7309260504477142,
           -0.7410237355636782,
           -0.7531620654494435,
           -0.7672327583036077,
           -0.7831184495725162,
           -0.8006962422699039,
           -0.8198408815237305,
           -0.8404274434255262,
           -0.8623334947315601,
           -0.885440732264266,
           -0.9096361466210915,
           -0.9348127751231867,
           -0.9608701168371726,
           -0.9877142815862002,
           -1.0152579384870957,
           -1.0434201203962015,
           -1.0721259306329394,
           -1.1013061886952678,
           -1.130897043056941,
           -1.1608395718298423,
           -1.1910793861270885,
           -1.2215662462755936,
           -1.25225369743518,
           -1.283098728499381,
           -1.3140614562014994,
           -1.345104834968584,
           -1.376194392120913,
           -1.407297987395628,
           -1.4383855953934164,
           -1.469429109339362,
           -1.5004021644621517,
           -1.531279979291536,
           -1.562039213224129,
           -1.5926578387919903,
           -1.6231150271723211,
           -1.6533910455899583,
           -1.6834671653801467,
           -1.7133255795927338,
           -1.7429493291275453,
           -1.7723222364925155,
           -1.801428846370296,
           -1.8302543722652214,
           -1.8587846485807038,
           -1.8870060875477217,
           -1.9149056404884162,
           -1.942470762955541,
           -1.9696893833390992,
           -1.9965498745765617,
           -2.0230410286431075,
           -2.049152033533894,
           -2.0748724524819075,
           -2.1001922051829336,
           -2.12510155082398,
           -2.149591072733469,
           -2.173651664491026,
           -2.197274517351958,
           -2.2204511088568606,
           -2.2431731925104157,
           -2.2654327884255094,
           -2.2872221748395645,
           -2.3085338804195312,
           -2.329360677280479,
           -2.3496955746503287,
           -2.369531813119991,
           -2.388862859424239,
           -2.4076824017040015,
           -2.4259843452055976,
           -2.4437628083767384,
           -2.4610121193229726,
           -2.4777268125917353,
           -2.493901626254267,
           -2.509531499258442,
           -2.5246115690281057,
           -2.5391371692867466,
           -2.553103828085395,
           -2.566507266016493,
           -2.5793433945971374,
           -2.5916083148066242,
           -2.6032983157645897,
           -2.614409873537296,
           -2.6249396500607443,
           -2.6348844921703267,
           -2.6442414307276936,
           -2.6530076798363558,
           -2.6611806361383414,
           -2.66875787818498,
           -2.675737165875522,
           -2.6821164399579533,
           -2.6878938215869286,
           -2.69306761193429,
           -2.6976362918481347,
           -2.7015985215568654,
           -2.704953140415109,
           -2.707699166688797,
           -2.709835797377112,
           -2.7113624080693675,
           -2.712278552835291
          ],
          [
           -2.6904200205717324,
           -2.6901160783314433,
           -2.689204339656389,
           -2.687685068697926,
           -2.6855587057548775,
           -2.682825867343938,
           -2.6794873462993833,
           -2.6755441119032293,
           -2.6709973100473423,
           -2.6658482634293246,
           -2.6600984717844205,
           -2.6537496121560085,
           -2.646803539207713,
           -2.6392622855805383,
           -2.631128062298921,
           -2.622403259230077,
           -2.613090445601498,
           -2.6031923705820756,
           -2.592711963932871,
           -2.5816523367342294,
           -2.570016782196644,
           -2.557808776563534,
           -2.545031980114939,
           -2.5316902382820565,
           -2.5177875828835465,
           -2.5033282334956306,
           -2.488316598969227,
           -2.472757279108686,
           -2.456655066528189,
           -2.440014948703461,
           -2.422842110238287,
           -2.405141935367289,
           -2.3869200107186357,
           -2.3681821283628297,
           -2.3489342891764267,
           -2.3291827065526043,
           -2.3089338104938797,
           -2.2881942521260497,
           -2.2669709086766936,
           -2.2452708889662634,
           -2.22310153946512,
           -2.2004704509758084,
           -2.1773854660065064,
           -2.153854686909096,
           -2.129886484863721,
           -2.1054895098011377,
           -2.08067270136488,
           -2.055445301027252,
           -2.02981686548675,
           -2.003797281489835,
           -1.9773967822372835,
           -1.9506259655549174,
           -1.9234958140306317,
           -1.896017717344688,
           -1.8682034970485428,
           -1.840065434079557,
           -1.8116162993351494,
           -1.7828693876709754,
           -1.753838555734004,
           -1.7245382640936233,
           -1.694983624192794,
           -1.6651904507074355,
           -1.6351753199764445,
           -1.604955635247587,
           -1.5745496995765893,
           -1.5439767973184164,
           -1.5132572852610708,
           -1.4824126945728235,
           -1.4514658448624695,
           -1.4204409717867095,
           -1.3893638697753434,
           -1.3582620515774972,
           -1.3271649264515235,
           -1.2961039989139795,
           -1.2651130900099155,
           -1.2342285830402935,
           -1.203489695545033,
           -1.1729387790404338,
           -1.1426216474786304,
           -1.112587934543454,
           -1.0828914786043864,
           -1.05359073227086,
           -1.0247491908433666,
           -0.996435830336704,
           -0.9687255409261782,
           -0.9416995354175403,
           -0.9154457044953112,
           -0.8900588810199973,
           -0.8656409647259329,
           -0.8423008469288003,
           -0.8201540635034907,
           -0.7993220954719371,
           -0.7799312330393686,
           -0.7621109247473883,
           -0.7459915530080861,
           -0.7317016146770142,
           -0.7193643426037368,
           -0.7090938794289857,
           -0.7009912006563921,
           -0.6951400660821635,
           -0.6916033379055702,
           -0.6904200205717321,
           -0.6916033379055727,
           -0.6951400660821683,
           -0.7009912006563993,
           -0.7090938794289952,
           -0.7193643426037486,
           -0.7317016146770278,
           -0.7459915530081017,
           -0.7621109247474058,
           -0.7799312330393877,
           -0.7993220954719579,
           -0.8201540635035128,
           -0.8423008469288237,
           -0.8656409647259574,
           -0.8900588810200228,
           -0.9154457044953375,
           -0.9416995354175677,
           -0.9687255409262063,
           -0.9964358303367329,
           -1.0247491908433959,
           -1.0535907322708895,
           -1.0828914786044168,
           -1.1125879345434846,
           -1.1426216474786615,
           -1.1729387790404648,
           -1.2034896955450647,
           -1.234228583040325,
           -1.2651130900099472,
           -1.2961039989140113,
           -1.3271649264515553,
           -1.3582620515775292,
           -1.3893638697753754,
           -1.4204409717867412,
           -1.451465844862501,
           -1.4824126945728555,
           -1.5132572852611024,
           -1.5439767973184482,
           -1.5745496995766208,
           -1.6049556352476182,
           -1.6351753199764756,
           -1.6651904507074666,
           -1.6949836241928247,
           -1.7245382640936533,
           -1.7538385557340337,
           -1.7828693876710053,
           -1.811616299335179,
           -1.8400654340795861,
           -1.8682034970485715,
           -1.8960177173447161,
           -1.9234958140306602,
           -1.950625965554945,
           -1.9773967822373106,
           -2.0037972814898617,
           -2.0298168654867768,
           -2.0554453010272784,
           -2.080672701364906,
           -2.105489509801163,
           -2.129886484863746,
           -2.1538546869091206,
           -2.1773854660065304,
           -2.200470450975832,
           -2.2231015394651426,
           -2.2452708889662856,
           -2.2669709086767162,
           -2.2881942521260714,
           -2.3089338104939006,
           -2.329182706552625,
           -2.3489342891764466,
           -2.3681821283628497,
           -2.3869200107186552,
           -2.405141935367307,
           -2.422842110238305,
           -2.4400149487034777,
           -2.4566550665282056,
           -2.4727572791087025,
           -2.4883165989692433,
           -2.503328233495646,
           -2.517787582883561,
           -2.5316902382820703,
           -2.545031980114953,
           -2.5578087765635473,
           -2.5700167821966566,
           -2.581652336734241,
           -2.5927119639328815,
           -2.6031923705820854,
           -2.613090445601508,
           -2.622403259230086,
           -2.63112806229893,
           -2.6392622855805463,
           -2.6468035392077205,
           -2.653749612156015,
           -2.6600984717844263,
           -2.66584826342933,
           -2.6709973100473476,
           -2.675544111903234,
           -2.6794873462993873,
           -2.6828258673439414,
           -2.6855587057548806,
           -2.687685068697928,
           -2.68920433965639,
           -2.6901160783314437
          ],
          [
           -2.6675881402161385,
           -2.6672857368485308,
           -2.666378613637786,
           -2.664867031272602,
           -2.662751424275853,
           -2.6600324010676863,
           -2.6567107440549664,
           -2.6527874097481456,
           -2.648263528906998,
           -2.643140406716996,
           -2.637419522998437,
           -2.6311025324508193,
           -2.6241912649353494,
           -2.616687725798858,
           -2.608594096242864,
           -2.59991273374196,
           -2.590646172516229,
           -2.580797124062886,
           -2.570368477752979,
           -2.559363301499549,
           -2.547784842504381,
           -2.5356365280911746,
           -2.522921966633816,
           -2.509644948589268,
           -2.495809447645608,
           -2.4814196219967872,
           -2.4664798157568537,
           -2.4509945605276893,
           -2.4349685771357192,
           -2.4184067775546434,
           -2.4013142670329763,
           -2.383696346447123,
           -2.365558514902863,
           -2.3469064726105193,
           -2.327746124061723,
           -2.3080835815386798,
           -2.287925168990143,
           -2.267277426311987,
           -2.2461471140744242,
           -2.224541218742553,
           -2.2024669584420873,
           -2.179931789327992,
           -2.1569434126202705,
           -2.1335097823785376,
           -2.109639114095329,
           -2.085339894197416,
           -2.0606208905550134,
           -2.0354911641106517,
           -2.009960081752996,
           -1.9840373305761436,
           -1.95773293368222,
           -1.9310572677046618,
           -1.9040210822517896,
           -1.8766355214954433,
           -1.8489121481580588,
           -1.8208629701839865,
           -1.7925004704177057,
           -1.7638376396533955,
           -1.7348880134677487,
           -1.7056657133017041,
           -1.676185492317675,
           -1.6464627866276993,
           -1.6165137725656364,
           -1.5863554307639014,
           -1.5560056178931625,
           -1.525483147032577,
           -1.4948078777590694,
           -1.4640008171768961,
           -1.4330842332528266,
           -1.4020817819761993,
           -1.371018650024001,
           -1.339921714773992,
           -1.3088197236658539,
           -1.2777434950492408,
           -1.2467261427605816,
           -1.2158033267116177,
           -1.1850135317152806,
           -1.1543983765676067,
           -1.1240029549780435,
           -1.0938762092008232,
           -1.0640713360431908,
           -1.0346462231525986,
           -1.005663910914743,
           -0.977193071686882,
           -0.9493084931716074,
           -0.9220915462176346,
           -0.895630608959644,
           -0.8700214088319286,
           -0.8453672317002925,
           -0.8217789336652706,
           -0.7993746771757945,
           -0.7782793010775254,
           -0.7586232274053685,
           -0.7405408106512965,
           -0.7241680533279217,
           -0.7096396502464709,
           -0.6970853864836866,
           -0.6866259995776086,
           -0.6783687171556345,
           -0.6724027807156032,
           -0.6687953414785627,
           -0.6675881402161384,
           -0.6687953414785652,
           -0.6724027807156082,
           -0.6783687171556421,
           -0.6866259995776184,
           -0.6970853864836986,
           -0.7096396502464848,
           -0.7241680533279377,
           -0.7405408106513144,
           -0.7586232274053878,
           -0.7782793010775463,
           -0.7993746771758168,
           -0.8217789336652942,
           -0.8453672317003174,
           -0.8700214088319543,
           -0.8956306089596706,
           -0.9220915462176622,
           -0.9493084931716357,
           -0.9771930716869109,
           -1.0056639109147725,
           -1.0346462231526286,
           -1.064071336043221,
           -1.0938762092008538,
           -1.1240029549780746,
           -1.1543983765676382,
           -1.185013531715312,
           -1.2158033267116493,
           -1.246726142760613,
           -1.2777434950492725,
           -1.308819723665886,
           -1.3399217147740239,
           -1.371018650024033,
           -1.4020817819762312,
           -1.4330842332528586,
           -1.4640008171769276,
           -1.4948078777591007,
           -1.5254831470326082,
           -1.5560056178931936,
           -1.5863554307639323,
           -1.616513772565667,
           -1.64646278662773,
           -1.6761854923177057,
           -1.7056657133017343,
           -1.7348880134677784,
           -1.763837639653425,
           -1.7925004704177347,
           -1.8208629701840156,
           -1.8489121481580877,
           -1.8766355214954715,
           -1.9040210822518173,
           -1.9310572677046893,
           -1.957732933682247,
           -1.9840373305761703,
           -2.0099600817530225,
           -2.035491164110678,
           -2.060620890555039,
           -2.085339894197441,
           -2.1096391140953537,
           -2.133509782378562,
           -2.156943412620294,
           -2.1799317893280157,
           -2.20246695844211,
           -2.2245412187425755,
           -2.2461471140744464,
           -2.267277426312009,
           -2.2879251689901645,
           -2.3080835815386997,
           -2.3277461240617425,
           -2.3469064726105393,
           -2.365558514902882,
           -2.383696346447141,
           -2.401314267032994,
           -2.4184067775546607,
           -2.434968577135736,
           -2.4509945605277057,
           -2.4664798157568697,
           -2.4814196219968023,
           -2.4958094476456227,
           -2.509644948589282,
           -2.522921966633829,
           -2.5356365280911874,
           -2.547784842504393,
           -2.559363301499561,
           -2.5703684777529903,
           -2.580797124062897,
           -2.5906461725162386,
           -2.599912733741969,
           -2.608594096242872,
           -2.6166877257988665,
           -2.6241912649353565,
           -2.631102532450826,
           -2.6374195229984427,
           -2.6431404067170017,
           -2.648263528907003,
           -2.6527874097481496,
           -2.656710744054971,
           -2.6600324010676895,
           -2.6627514242758554,
           -2.6648670312726037,
           -2.666378613637787,
           -2.667285736848531
          ],
          [
           -2.644110411450382,
           -2.6438096182025697,
           -2.6429073241706975,
           -2.6414037865004354,
           -2.6392994338046516,
           -2.6365948662190424,
           -2.633290855481075,
           -2.629388345033272,
           -2.624888450152209,
           -2.6197924581049254,
           -2.6141018283347592,
           -2.6078181926789963,
           -2.6009433556210846,
           -2.5934792945805505,
           -2.5854281602441773,
           -2.576792276942459,
           -2.5675741430758,
           -2.5577764315954648,
           -2.547401990544822,
           -2.5364538436670414,
           -2.5249351910860374,
           -2.5128494100681884,
           -2.500200055873111,
           -2.4869908627026422,
           -2.4732257447581065,
           -2.4589087974169637,
           -2.4440442985410726,
           -2.428636709930055,
           -2.412690678934602,
           -2.3962110402461074,
           -2.3792028178807016,
           -2.361671227377604,
           -2.343621678233838,
           -2.3250597765996366,
           -2.3059913282614555,
           -2.2864223419424063,
           -2.266359032953127,
           -2.2458078272297133,
           -2.22477536579936,
           -2.2032685097189044,
           -2.1812943455365175,
           -2.1588601913325065,
           -2.135973603401626,
           -2.1126423836465036,
           -2.088874587759985,
           -2.064678534283383,
           -2.0400628146380653,
           -2.015036304239583,
           -1.9896081748169092,
           -1.9637879080745062,
           -1.9375853108521062,
           -1.9110105319566357,
           -1.8840740808629024,
           -1.8567868485049013,
           -1.8291601304083576,
           -1.8012056524478404,
           -1.7729355995490808,
           -1.7443626476996095,
           -1.7154999996792357,
           -1.686361424977016,
           -1.6569613044240987,
           -1.6273146801431664,
           -1.597437311496159,
           -1.5673457378036812,
           -1.5370573487130517,
           -1.5065904632085019,
           -1.4759644183873968,
           -1.4451996692713474,
           -1.4143179010807614,
           -1.3833421555752041,
           -1.3522969732480397,
           -1.3212085533584685,
           -1.2901049339808428,
           -1.2590161944395866,
           -1.2279746826621323,
           -1.1970152700980572,
           -1.166175636885162,
           -1.1354965898428586,
           -1.1050224155702097,
           -1.0748012703244954,
           -1.0448856073269517,
           -1.0153326405146113,
           -0.9862048413112525,
           -0.957570461453015,
           -0.9295040699501186,
           -0.9020870855342268,
           -0.8754082770734827,
           -0.8495641931575716,
           -0.8246594683025467,
           -0.800806937363558,
           -0.7781274728548825,
           -0.7567494441200094,
           -0.7368076862625865,
           -0.7184418656624971,
           -0.7017941443773023,
           -0.6870060847756931,
           -0.6742148036838644,
           -0.6635484826277044,
           -0.6551214595326919,
           -0.6490292488971289,
           -0.6453439337118383,
           -0.6441104114503821,
           -0.6453439337118408,
           -0.6490292488971339,
           -0.6551214595326992,
           -0.6635484826277143,
           -0.6742148036838768,
           -0.6870060847757072,
           -0.7017941443773186,
           -0.7184418656625151,
           -0.7368076862626062,
           -0.7567494441200309,
           -0.7781274728549051,
           -0.8008069373635819,
           -0.8246594683025718,
           -0.8495641931575977,
           -0.8754082770735095,
           -0.9020870855342547,
           -0.9295040699501469,
           -0.9575704614530444,
           -0.9862048413112822,
           -1.0153326405146414,
           -1.0448856073269823,
           -1.0748012703245262,
           -1.105022415570241,
           -1.1354965898428901,
           -1.1661756368851937,
           -1.197015270098089,
           -1.227974682662164,
           -1.2590161944396183,
           -1.290104933980875,
           -1.3212085533585003,
           -1.3522969732480714,
           -1.383342155575236,
           -1.4143179010807936,
           -1.445199669271379,
           -1.4759644183874283,
           -1.5065904632085332,
           -1.5370573487130827,
           -1.567345737803712,
           -1.5974373114961897,
           -1.6273146801431966,
           -1.656961304424129,
           -1.686361424977046,
           -1.7154999996792653,
           -1.7443626476996386,
           -1.77293559954911,
           -1.8012056524478692,
           -1.8291601304083864,
           -1.8567868485049297,
           -1.8840740808629302,
           -1.911010531956663,
           -1.9375853108521333,
           -1.9637879080745333,
           -1.9896081748169359,
           -2.015036304239609,
           -2.040062814638091,
           -2.064678534283408,
           -2.0888745877600097,
           -2.1126423836465276,
           -2.13597360340165,
           -2.15886019133253,
           -2.18129434553654,
           -2.2032685097189266,
           -2.2247753657993816,
           -2.2458078272297346,
           -2.266359032953148,
           -2.2864223419424263,
           -2.305991328261475,
           -2.325059776599656,
           -2.3436216782338573,
           -2.3616712273776215,
           -2.379202817880719,
           -2.3962110402461247,
           -2.4126906789346183,
           -2.428636709930072,
           -2.444044298541089,
           -2.458908797416979,
           -2.473225744758121,
           -2.486990862702656,
           -2.5002000558731243,
           -2.5128494100682017,
           -2.5249351910860502,
           -2.5364538436670525,
           -2.547401990544833,
           -2.557776431595475,
           -2.5675741430758094,
           -2.576792276942468,
           -2.5854281602441858,
           -2.5934792945805585,
           -2.600943355621092,
           -2.607818192679003,
           -2.6141018283347655,
           -2.6197924581049308,
           -2.624888450152214,
           -2.6293883450332762,
           -2.6332908554810786,
           -2.6365948662190455,
           -2.639299433804654,
           -2.641403786500438,
           -2.6429073241706984,
           -2.6438096182025705
          ],
          [
           -2.620009547460759,
           -2.6197104370855606,
           -2.618813190466457,
           -2.6173180611323854,
           -2.6152254716632686,
           -2.6125360137380453,
           -2.609250448202911,
           -2.6053697051607583,
           -2.6008948840831216,
           -2.5958272539462364,
           -2.590168253393132,
           -2.5839194909240315,
           -2.5770827451176674,
           -2.569659964886518,
           -2.5616532697693275,
           -2.5530649502647504,
           -2.5438974682103748,
           -2.5341534572118736,
           -2.523835723127597,
           -2.512947244614441,
           -2.501491173741499,
           -2.489470836678651,
           -2.476889734468011,
           -2.463751543886952,
           -2.4500601184123316,
           -2.4358194892965277,
           -2.4210338667669578,
           -2.405707641361993,
           -2.3898453854174426,
           -2.373451854719316,
           -2.3565319903401356,
           -2.339090920677922,
           -2.3211339637189594,
           -2.3026666295476894,
           -2.2836946231295907,
           -2.2642238473956615,
           -2.2442604066602785,
           -2.223810610407662,
           -2.2028809774861062,
           -2.1814782407535422,
           -2.1596093522229154,
           -2.1372814887614506,
           -2.1145020584041236,
           -2.091278707348741,
           -2.0676193277080324,
           -2.0435320661031713,
           -2.0190253331934067,
           -1.994107814248067,
           -1.9687884808803955,
           -1.9430766040776195,
           -1.9169817686787092,
           -1.890513889470644,
           -1.863683229096125,
           -1.8365004179908693,
           -1.8089764765974068,
           -1.7811228401351844,
           -1.7529513862443755,
           -1.7244744658637774,
           -1.6957049377523654,
           -1.6666562071203226,
           -1.6373422688996984,
           -1.6077777562584004,
           -1.5779779950451809,
           -1.5479590649490167,
           -1.5177378682652283,
           -1.4873322072842432,
           -1.4567608714585822,
           -1.4260437356606481,
           -1.3952018710191951,
           -1.3642576700162967,
           -1.333234987738506,
           -1.3021593014034587,
           -1.2710578905216803,
           -1.2399600402944202,
           -1.2088972710782762,
           -1.1779035969447662,
           -1.1470158164956545,
           -1.1162738391153575,
           -1.0857210496820306,
           -1.055404714322888,
           -1.0253764289540157,
           -0.9956926109103011,
           -0.9664150317087814,
           -0.937611385592666,
           -0.9093558835951464,
           -0.8817298559994712,
           -0.8548223367797825,
           -0.8287305914518402,
           -0.803560534488487,
           -0.7794269642146028,
           -0.7564535227962815,
           -0.7347722686944448,
           -0.7145227325970478,
           -0.6958503213179239,
           -0.6789039454580885,
           -0.6638327848795388,
           -0.6507821791119833,
           -0.6398887404007461,
           -0.6312749279024387,
           -0.625043471421722,
           -0.6212721573940071,
           -0.6200095474607589,
           -0.6212721573940095,
           -0.6250434714217272,
           -0.6312749279024464,
           -0.639888740400756,
           -0.6507821791119957,
           -0.6638327848795532,
           -0.678903945458105,
           -0.6958503213179423,
           -0.7145227325970678,
           -0.7347722686944663,
           -0.7564535227963045,
           -0.779426964214627,
           -0.8035605344885122,
           -0.8287305914518667,
           -0.8548223367798097,
           -0.8817298559994992,
           -0.9093558835951752,
           -0.9376113855926953,
           -0.9664150317088114,
           -0.9956926109103313,
           -1.0253764289540463,
           -1.0554047143229188,
           -1.085721049682062,
           -1.1162738391153888,
           -1.147015816495686,
           -1.1779035969447982,
           -1.2088972710783081,
           -1.239960040294452,
           -1.271057890521712,
           -1.3021593014034905,
           -1.3332349877385377,
           -1.3642576700163287,
           -1.3952018710192269,
           -1.4260437356606799,
           -1.4567608714586138,
           -1.487332207284274,
           -1.5177378682652596,
           -1.5479590649490476,
           -1.5779779950452113,
           -1.6077777562584308,
           -1.6373422688997288,
           -1.6666562071203526,
           -1.6957049377523954,
           -1.7244744658638065,
           -1.7529513862444046,
           -1.7811228401352135,
           -1.8089764765974354,
           -1.8365004179908977,
           -1.8636832290961527,
           -1.8905138894706712,
           -1.916981768678736,
           -1.943076604077646,
           -1.9687884808804215,
           -1.9941078142480932,
           -2.0190253331934325,
           -2.0435320661031966,
           -2.067619327708057,
           -2.091278707348765,
           -2.114502058404147,
           -2.1372814887614746,
           -2.159609352222938,
           -2.181478240753564,
           -2.202880977486128,
           -2.223810610407684,
           -2.2442604066602994,
           -2.264223847395681,
           -2.2836946231296107,
           -2.302666629547709,
           -2.3211339637189785,
           -2.33909092067794,
           -2.3565319903401534,
           -2.373451854719333,
           -2.389845385417459,
           -2.4057076413620093,
           -2.4210338667669737,
           -2.4358194892965424,
           -2.4500601184123467,
           -2.463751543886966,
           -2.476889734468025,
           -2.4894708366786644,
           -2.5014911737415115,
           -2.5129472446144527,
           -2.523835723127608,
           -2.534153457211884,
           -2.543897468210384,
           -2.5530649502647593,
           -2.561653269769336,
           -2.5696599648865264,
           -2.5770827451176754,
           -2.5839194909240377,
           -2.590168253393138,
           -2.595827253946242,
           -2.6008948840831265,
           -2.605369705160762,
           -2.6092504482029146,
           -2.6125360137380484,
           -2.6152254716632712,
           -2.6173180611323876,
           -2.6188131904664584,
           -2.619710437085562
          ],
          [
           -2.5953088642766495,
           -2.595011511091647,
           -2.594119534815856,
           -2.592633185294853,
           -2.5905528789644965,
           -2.5878791988912404,
           -2.5846128948295095,
           -2.5807548832970904,
           -2.5763062476697565,
           -2.5712682382966605,
           -2.5656422726383155,
           -2.559429935429303,
           -2.552632978868207,
           -2.5452533228375764,
           -2.537293055157159,
           -2.5287544318739994,
           -2.5196398775934536,
           -2.509951985855637,
           -2.499693519562316,
           -2.488867411459803,
           -2.4774767646840203,
           -2.4655248533745304,
           -2.4530151233650495,
           -2.4399511929587314,
           -2.426336853797372,
           -2.4121760718346135,
           -2.3974729884242683,
           -2.3822319215360257,
           -2.3664573671120803,
           -2.3501540005796,
           -2.333326678535541,
           -2.315980440622029,
           -2.298120511612452,
           -2.2797523037305853,
           -2.2608814192274336,
           -2.2415136532431967,
           -2.221654996984748,
           -2.201311641252388,
           -2.1804899803534346,
           -2.159196616444436,
           -2.1374383643486206,
           -2.1152222569005485,
           -2.0925555508760643,
           -2.069445733572495,
           -2.0459005301118576,
           -2.0219279115486453,
           -1.9975361038737778,
           -1.9727335980176792,
           -1.9475291609683687,
           -1.921931848135196,
           -1.8959510171056175,
           -1.869596342961611,
           -1.8428778353441893,
           -1.8158058574795644,
           -1.7883911474091667,
           -1.7606448416986378,
           -1.7325785019385957,
           -1.704204144393293,
           -1.6755342732029848,
           -1.6465819176029557,
           -1.6173606736877852,
           -1.5878847513248406,
           -1.5581690269075934,
           -1.5282291027387016,
           -1.4980813739466805,
           -1.4677431039701596,
           -1.4372325097922043,
           -1.4065688582758427,
           -1.3757725751425454,
           -1.3448653683493317,
           -1.3138703678580534,
           -1.2828122840515535,
           -1.2517175873330884,
           -1.2206147117416806,
           -1.1895342857160696,
           -1.1585093934255677,
           -1.1275758703288228,
           -1.0967726367775326,
           -1.066142073486708,
           -1.035730442451908,
           -1.0055883562729702,
           -0.9757712976564104,
           -0.9463401888605681,
           -0.917362007681503,
           -0.8889104418211219,
           -0.8610665666022159,
           -0.8339195213909372,
           -0.807567147134238,
           -0.7821165306164805,
           -0.7576843802492633,
           -0.7343971340546209,
           -0.7123906749323666,
           -0.691809505287459,
           -0.6728052192849518,
           -0.6555341159829252,
           -0.640153832106251,
           -0.6268189505952501,
           -0.6156756663764271,
           -0.6068557583043644,
           -0.6004703023181654,
           -0.5966037229025231,
           -0.5953088642766493,
           -0.5966037229025258,
           -0.6004703023181708,
           -0.6068557583043722,
           -0.6156756663764376,
           -0.6268189505952626,
           -0.6401538321062656,
           -0.655534115982942,
           -0.6728052192849705,
           -0.6918095052874793,
           -0.7123906749323884,
           -0.7343971340546444,
           -0.7576843802492879,
           -0.7821165306165061,
           -0.8075671471342647,
           -0.8339195213909646,
           -0.8610665666022441,
           -0.8889104418211509,
           -0.9173620076815325,
           -0.9463401888605981,
           -0.9757712976564406,
           -1.005588356273001,
           -1.0357304424519391,
           -1.0661420734867393,
           -1.0967726367775643,
           -1.1275758703288543,
           -1.1585093934255997,
           -1.1895342857161015,
           -1.2206147117417125,
           -1.25171758733312,
           -1.2828122840515854,
           -1.3138703678580852,
           -1.3448653683493634,
           -1.375772575142577,
           -1.4065688582758742,
           -1.4372325097922354,
           -1.467743103970191,
           -1.4980813739467116,
           -1.5282291027387325,
           -1.558169026907624,
           -1.5878847513248713,
           -1.6173606736878154,
           -1.6465819176029854,
           -1.6755342732030145,
           -1.7042041443933222,
           -1.7325785019386246,
           -1.7606448416986666,
           -1.7883911474091951,
           -1.8158058574795921,
           -1.842877835344217,
           -1.8695963429616378,
           -1.8959510171056444,
           -1.9219318481352223,
           -1.947529160968395,
           -1.9727335980177045,
           -1.9975361038738033,
           -2.02192791154867,
           -2.045900530111882,
           -2.0694457335725187,
           -2.092555550876088,
           -2.115222256900571,
           -2.1374383643486428,
           -2.159196616444458,
           -2.1804899803534563,
           -2.2013116412524094,
           -2.221654996984768,
           -2.2415136532432167,
           -2.2608814192274527,
           -2.279752303730605,
           -2.298120511612471,
           -2.3159804406220466,
           -2.3333266785355584,
           -2.350154000579617,
           -2.3664573671120968,
           -2.382231921536042,
           -2.397472988424284,
           -2.412176071834629,
           -2.426336853797386,
           -2.4399511929587447,
           -2.4530151233650628,
           -2.465524853374543,
           -2.4774767646840328,
           -2.488867411459815,
           -2.499693519562327,
           -2.5099519858556474,
           -2.519639877593463,
           -2.5287544318740083,
           -2.5372930551571677,
           -2.545253322837585,
           -2.552632978868214,
           -2.55942993542931,
           -2.5656422726383212,
           -2.571268238296666,
           -2.576306247669762,
           -2.580754883297095,
           -2.5846128948295135,
           -2.587879198891243,
           -2.590552878964499,
           -2.5926331852948548,
           -2.5941195348158574,
           -2.595011511091647
          ],
          [
           -2.5700322582137654,
           -2.569736738159855,
           -2.568850260030364,
           -2.5673730699283928,
           -2.5653055780471488,
           -2.56264835870246,
           -2.559402150379167,
           -2.555567855792296,
           -2.5511465419641737,
           -2.546139440318909,
           -2.5405479467959755,
           -2.534373621984902,
           -2.52761819128342,
           -2.5202835450817336,
           -2.5123717389759395,
           -2.503884994014013,
           -2.4948256969781646,
           -2.485196400707837,
           -2.474999824468073,
           -2.4642388543685017,
           -2.4529165438387666,
           -2.4410361141668107,
           -2.4286009551071333,
           -2.4156146255668527,
           -2.4020808543782173,
           -2.3880035411671106,
           -2.373386757328083,
           -2.3582347471175122,
           -2.342551928877722,
           -2.326342896406219,
           -2.309612420485683,
           -2.292365450592021,
           -2.2746071167996127,
           -2.2563427319049607,
           -2.237577793792224,
           -2.2183179880667216,
           -2.1985691909853466,
           -2.178337472716085,
           -2.1576291009624717,
           -2.136450544992898,
           -2.114808480119318,
           -2.0927097926750964,
           -2.0701615855476354,
           -2.04717118432808,
           -2.0237461441479545,
           -1.999894257281157,
           -1.9756235615994677,
           -1.9509423499808367,
           -1.925859180782327,
           -1.9003828895040202,
           -1.8745226017866625,
           -1.8482877479046769,
           -1.8216880789377563,
           -1.794733684829035,
           -1.7674350145662587,
           -1.7398028987550909,
           -1.7118485748913164,
           -1.6835837156820765,
           -1.6550204608162251,
           -1.6261714526415976,
           -1.5970498762735428,
           -1.5676695047359326,
           -1.5380447498246381,
           -1.5081907194859214,
           -1.4781232826203925,
           -1.4478591423593747,
           -1.4174159190171383,
           -1.3868122441021034,
           -1.356067866975414,
           -1.3252037759786766,
           -1.2942423361162438,
           -1.2632074456722677,
           -1.2321247144684326,
           -1.2010216668215676,
           -1.16992797263387,
           -1.1388757104281753,
           -1.1078996665027636,
           -1.077037674686086,
           -1.0463310013619547,
           -1.0158247804204816,
           -0.9855685024375523,
           -0.9556165615065918,
           -0.9260288614747472,
           -0.8968714805068865,
           -0.8682173884301205,
           -0.8401472045784729,
           -0.8127499741095368,
           -0.7861239271632824,
           -0.7603771669729843,
           -0.7356282095982628,
           -0.7120062695305037,
           -0.6896511536236052,
           -0.6687125945547384,
           -0.649348831590431,
           -0.6317242421379647,
           -0.6160058573569881,
           -0.6023586749630251,
           -0.5909398234201264,
           -0.5818918314172218,
           -0.5753354892630542,
           -0.5713630021406526,
           -0.5700322582137655,
           -0.5713630021406554,
           -0.5753354892630597,
           -0.58189183141723,
           -0.590939823420137,
           -0.602358674963038,
           -0.6160058573570032,
           -0.631724242137982,
           -0.6493488315904502,
           -0.6687125945547591,
           -0.6896511536236275,
           -0.7120062695305274,
           -0.7356282095982877,
           -0.7603771669730103,
           -0.7861239271633093,
           -0.8127499741095644,
           -0.8401472045785013,
           -0.8682173884301495,
           -0.8968714805069162,
           -0.9260288614747773,
           -0.9556165615066224,
           -0.9855685024375834,
           -1.015824780420513,
           -1.046331001361986,
           -1.0770376746861174,
           -1.1078996665027956,
           -1.138875710428207,
           -1.169927972633902,
           -1.2010216668215998,
           -1.2321247144684646,
           -1.2632074456722997,
           -1.2942423361162756,
           -1.3252037759787085,
           -1.3560678669754453,
           -1.386812244102135,
           -1.4174159190171698,
           -1.4478591423594065,
           -1.4781232826204236,
           -1.5081907194859525,
           -1.5380447498246692,
           -1.567669504735963,
           -1.5970498762735728,
           -1.6261714526416275,
           -1.6550204608162546,
           -1.6835837156821063,
           -1.7118485748913455,
           -1.739802898755119,
           -1.7674350145662872,
           -1.794733684829063,
           -1.8216880789377836,
           -1.848287747904704,
           -1.8745226017866894,
           -1.9003828895040467,
           -1.925859180782353,
           -1.9509423499808622,
           -1.9756235615994928,
           -1.9998942572811815,
           -2.023746144147979,
           -2.0471711843281035,
           -2.0701615855476585,
           -2.092709792675119,
           -2.1148084801193403,
           -2.13645054499292,
           -2.157629100962493,
           -2.1783374727161062,
           -2.198569190985367,
           -2.2183179880667416,
           -2.237577793792244,
           -2.2563427319049794,
           -2.2746071167996313,
           -2.2923654505920386,
           -2.3096124204857,
           -2.326342896406236,
           -2.3425519288777386,
           -2.358234747117528,
           -2.373386757328099,
           -2.3880035411671257,
           -2.4020808543782315,
           -2.415614625566867,
           -2.428600955107146,
           -2.4410361141668226,
           -2.4529165438387786,
           -2.4642388543685136,
           -2.474999824468083,
           -2.485196400707847,
           -2.4948256969781744,
           -2.503884994014023,
           -2.5123717389759483,
           -2.5202835450817416,
           -2.5276181912834272,
           -2.5343736219849085,
           -2.5405479467959813,
           -2.546139440318915,
           -2.551146541964178,
           -2.5555678557923005,
           -2.5594021503791704,
           -2.562648358702463,
           -2.565305578047151,
           -2.5673730699283945,
           -2.5688502600303655,
           -2.5697367381598557
          ],
          [
           -2.5442041827560096,
           -2.5439105734552077,
           -2.543029826321016,
           -2.541562183662887,
           -2.5395080493460624,
           -2.536867988816225,
           -2.5336427291348267,
           -2.529833159025953,
           -2.525440328935784,
           -2.520465451106021,
           -2.5149098996628743,
           -2.508775210723516,
           -2.502063082522183,
           -2.494775375558447,
           -2.4869141127704766,
           -2.4784814797365025,
           -2.4694798249080585,
           -2.4599116598790003,
           -2.4497796596947445,
           -2.4390866632066603,
           -2.427835673477071,
           -2.416029858240914,
           -2.403672550430727,
           -2.390767248772334,
           -2.377317618459365,
           -2.3633274919155878,
           -2.3488008696549625,
           -2.333741921250361,
           -2.318154986423026,
           -2.3020445762661335,
           -2.285415374617196,
           -2.268272239595657,
           -2.250620205323743,
           -2.2324644838506145,
           -2.2138104673020305,
           -2.1946637302802166,
           -2.175030032541348,
           -2.154915321981175,
           -2.13432573796278,
           -2.113267615024384,
           -2.091747487009546,
           -2.069772091667089,
           -2.047348375773753,
           -2.024483500838994,
           -2.0011848494586193,
           -1.9774600323922356,
           -1.9533168964489067,
           -1.928763533276171,
           -1.9038082891598243,
           -1.8784597759559234,
           -1.852726883292519,
           -1.8266187921970607,
           -1.80014499032658,
           -1.7733152890021007,
           -1.7461398422767525,
           -1.7186291682993955,
           -1.6907941732728915,
           -1.662646178349304,
           -1.6341969498542561,
           -1.6054587332905317,
           -1.5764442916380859,
           -1.5471669485454735,
           -1.5176406370980637,
           -1.4878799549533224,
           -1.4579002267552583,
           -1.427717574881478,
           -1.397348999740148,
           -1.366812471023817,
           -1.336127031545982,
           -1.3053129155381786,
           -1.2743916835737643,
           -1.2433863766125206,
           -1.21232169202978,
           -1.1812241849049363,
           -1.1501224982935292,
           -1.1190476266854623,
           -1.088033217341388,
           -1.0571159146682865,
           -1.0263357531918302,
           -0.9957366049252803,
           -0.9653666868970929,
           -0.9352791340954949,
           -0.9055326418465997,
           -0.8761921792781453,
           -0.8473297715019986,
           -0.8190253417656588,
           -0.7913675951701882,
           -0.7644549115450329,
           -0.738396195541054,
           -0.7133116059352216,
           -0.6893330531328616,
           -0.6666043149125014,
           -0.6452805791771662,
           -0.6255271865131192,
           -0.6075173277982023,
           -0.5914284717398446,
           -0.5774373761732325,
           -0.5657136938318382,
           -0.5564124213719951,
           -0.5496657334453466,
           -0.5455750272374141,
           -0.5442041827560096,
           -0.5455750272374169,
           -0.5496657334453523,
           -0.5564124213720033,
           -0.5657136938318491,
           -0.5774373761732459,
           -0.5914284717398601,
           -0.60751732779822,
           -0.6255271865131387,
           -0.6452805791771872,
           -0.6666043149125241,
           -0.6893330531328857,
           -0.7133116059352468,
           -0.7383961955410802,
           -0.7644549115450601,
           -0.7913675951702163,
           -0.8190253417656875,
           -0.847329771502028,
           -0.8761921792781753,
           -0.90553264184663,
           -0.9352791340955255,
           -0.9653666868971241,
           -0.9957366049253115,
           -1.0263357531918618,
           -1.0571159146683182,
           -1.0880332173414198,
           -1.1190476266854943,
           -1.1501224982935612,
           -1.1812241849049683,
           -1.2123216920298119,
           -1.2433863766125524,
           -1.2743916835737958,
           -1.3053129155382104,
           -1.3361270315460136,
           -1.3668124710238487,
           -1.3973489997401796,
           -1.4277175748815092,
           -1.4579002267552894,
           -1.487879954953353,
           -1.5176406370980942,
           -1.5471669485455037,
           -1.576444291638116,
           -1.6054587332905614,
           -1.6341969498542854,
           -1.662646178349333,
           -1.6907941732729204,
           -1.7186291682994241,
           -1.7461398422767804,
           -1.7733152890021284,
           -1.8001449903266074,
           -1.8266187921970878,
           -1.8527268832925456,
           -1.8784597759559498,
           -1.90380828915985,
           -1.9287635332761965,
           -1.953316896448932,
           -1.97746003239226,
           -2.0011848494586433,
           -2.024483500839018,
           -2.047348375773776,
           -2.069772091667112,
           -2.0917474870095685,
           -2.1132676150244056,
           -2.134325737962801,
           -2.1549153219811963,
           -2.1750300325413687,
           -2.1946637302802365,
           -2.21381046730205,
           -2.2324644838506336,
           -2.250620205323762,
           -2.268272239595675,
           -2.2854153746172132,
           -2.3020445762661508,
           -2.318154986423042,
           -2.3337419212503767,
           -2.348800869654978,
           -2.3633274919156024,
           -2.37731761845938,
           -2.390767248772348,
           -2.40367255043074,
           -2.416029858240926,
           -2.4278356734770834,
           -2.439086663206672,
           -2.449779659694755,
           -2.4599116598790096,
           -2.4694798249080674,
           -2.4784814797365113,
           -2.4869141127704846,
           -2.4947753755584547,
           -2.50206308252219,
           -2.508775210723522,
           -2.5149098996628805,
           -2.5204654511060265,
           -2.5254403289357885,
           -2.5298331590259573,
           -2.5336427291348307,
           -2.5368679888162275,
           -2.5395080493460647,
           -2.541562183662888,
           -2.543029826321017,
           -2.5439105734552085
          ],
          [
           -2.5178496248983073,
           -2.517558005710538,
           -2.5166832276371602,
           -2.515225529151207,
           -2.513185307718656,
           -2.5105631198151914,
           -2.507359680950455,
           -2.503575865700543,
           -2.49921270774978,
           -2.4942713999430106,
           -2.488753294349921,
           -2.482659902343147,
           -2.4759928946922214,
           -2.4687541016756893,
           -2.4609455132140394,
           -2.4525692790264384,
           -2.443627708814605,
           -2.4341232724775552,
           -2.4240586003613633,
           -2.4134364835485407,
           -2.402259874192138,
           -2.3905318859002045,
           -2.3782557941768467,
           -2.3654350369267685,
           -2.3520732150309063,
           -2.3381740930015473,
           -2.3237415997262123,
           -2.3087798293105424,
           -2.293293042031498,
           -2.277285665413396,
           -2.260762295440604,
           -2.2437276979222256,
           -2.226186810025738,
           -2.2081447419984097,
           -2.1896067790973817,
           -2.170578383751627,
           -2.151065197981603,
           -2.1310730461053584,
           -2.110607937763134,
           -2.08967607129626,
           -2.0682838375203354,
           -2.046437823937468,
           -2.0241448194377307,
           -2.0014118195461585,
           -1.978246032278561,
           -1.9546548846773701,
           -1.9306460301078228,
           -1.906227356405099,
           -1.881406994974894,
           -1.8561933309634568,
           -1.8305950146287124,
           -1.804620974061955,
           -1.7782804294302412,
           -1.7515829089333326,
           -1.7245382666965212,
           -1.697156702852367,
           -1.6694487861011824,
           -1.641425479082723,
           -1.6130981669411042,
           -1.584478689522587,
           -1.5555793777129787,
           -1.5264130944996412,
           -1.4969932814343714,
           -1.4673340112800046,
           -1.4374500477481111,
           -1.4073569133806059,
           -1.3770709667980068,
           -1.3466094907353843,
           -1.315990792518169,
           -1.285234318898796,
           -1.2543607874867795,
           -1.2233923373644102,
           -1.1923527018925615,
           -1.1612674071796487,
           -1.1301640002126287,
           -1.099072311228743,
           -1.068024755529675,
           -1.0370566805830852,
           -1.0062067648784168,
           -0.9755174755339293,
           -0.945035591976432,
           -0.9148128029570904,
           -0.8849063834579849,
           -0.8553799562895695,
           -0.8263043398113048,
           -0.797758477436201,
           -0.7698304353450692,
           -0.7426184407887607,
           -0.716231912907616,
           -0.6907924095135087,
           -0.6664343755429825,
           -0.6433055319754889,
           -0.6215666907373535,
           -0.6013907290853966,
           -0.5829604208603095,
           -0.5664648249908265,
           -0.5520940037997788,
           -0.540032014490757,
           -0.5304484000483831,
           -0.5234887767064987,
           -0.5192654961487824,
           -0.5178496248983072,
           -0.5192654961487854,
           -0.5234887767065046,
           -0.5304484000483916,
           -0.5400320144907682,
           -0.5520940037997925,
           -0.5664648249908422,
           -0.5829604208603275,
           -0.6013907290854165,
           -0.621566690737375,
           -0.643305531975512,
           -0.666434375543007,
           -0.6907924095135344,
           -0.7162319129076425,
           -0.7426184407887881,
           -0.7698304353450977,
           -0.7977584774362301,
           -0.8263043398113344,
           -0.8553799562895995,
           -0.8849063834580154,
           -0.9148128029571212,
           -0.9450355919764633,
           -0.9755174755339608,
           -1.0062067648784483,
           -1.037056680583117,
           -1.0680247555297067,
           -1.099072311228775,
           -1.1301640002126607,
           -1.1612674071796807,
           -1.1923527018925935,
           -1.2233923373644422,
           -1.2543607874868115,
           -1.2852343188988278,
           -1.3159907925182008,
           -1.3466094907354158,
           -1.3770709667980379,
           -1.4073569133806367,
           -1.437450047748142,
           -1.4673340112800348,
           -1.4969932814344016,
           -1.5264130944996717,
           -1.5555793777130087,
           -1.5844786895226164,
           -1.6130981669411333,
           -1.6414254790827516,
           -1.6694487861012115,
           -1.6971567028523955,
           -1.7245382666965494,
           -1.75158290893336,
           -1.778280429430268,
           -1.804620974061982,
           -1.8305950146287386,
           -1.8561933309634826,
           -1.8814069949749195,
           -1.9062273564051246,
           -1.9306460301078479,
           -1.9546548846773948,
           -1.978246032278585,
           -2.001411819546182,
           -2.0241448194377534,
           -2.0464378239374907,
           -2.0682838375203576,
           -2.0896760712962816,
           -2.1106079377631555,
           -2.1310730461053797,
           -2.151065197981623,
           -2.1705783837516464,
           -2.189606779097401,
           -2.208144741998429,
           -2.2261868100257565,
           -2.243727697922243,
           -2.2607622954406215,
           -2.2772856654134124,
           -2.293293042031514,
           -2.308779829310558,
           -2.323741599726228,
           -2.338174093001562,
           -2.35207321503092,
           -2.365435036926782,
           -2.3782557941768596,
           -2.390531885900217,
           -2.4022598741921497,
           -2.4134364835485522,
           -2.424058600361374,
           -2.434123272477566,
           -2.4436277088146143,
           -2.4525692790264473,
           -2.4609455132140483,
           -2.4687541016756978,
           -2.4759928946922285,
           -2.4826599023431535,
           -2.4887532943499266,
           -2.494271399943016,
           -2.4992127077497845,
           -2.503575865700547,
           -2.507359680950459,
           -2.510563119815194,
           -2.5131853077186577,
           -2.515225529151209,
           -2.5166832276371616,
           -2.517558005710539
          ],
          [
           -2.4909940809733033,
           -2.4907045330518467,
           -2.4898359674878137,
           -2.488388618883895,
           -2.4863628782502745,
           -2.48375929301353,
           -2.480578567029813,
           -2.4768215606030264,
           -2.472489290508925,
           -2.4675829300263272,
           -2.462103808976792,
           -2.4560534137744283,
           -2.449433387487711,
           -2.4422455299154695,
           -2.434491797679506,
           -2.4261743043366004,
           -2.4172953205130017,
           -2.407857274064854,
           -2.397862750268413,
           -2.387314492044307,
           -2.3762154002205875,
           -2.3645685338397806,
           -2.3523771105157505,
           -2.3396445068467506,
           -2.3263742588917355,
           -2.3125700627177266,
           -2.298235775026857,
           -2.2833754138726157,
           -2.2679931594758083,
           -2.252093355151895,
           -2.2356805083625684,
           -2.2187592919058625,
           -2.201334545260605,
           -2.1834112761027664,
           -2.1649946620132146,
           -2.1460900523985496,
           -2.1267029706491565,
           -2.106839116561377,
           -2.086504369053814,
           -2.065704789211308,
           -2.044446623694109,
           -2.022736308554271,
           -2.0005804735064467,
           -1.9779859467060428,
           -1.9549597600943882,
           -1.9315091553780674,
           -1.9076415907182749,
           -1.8833647482158984,
           -1.8586865422893897,
           -1.833615129055509,
           -1.8081589168379832,
           -1.7823265779463917,
           -1.7561270618874802,
           -1.729569610194142,
           -1.7026637730839491,
           -1.6754194281900439,
           -1.647846801643135,
           -1.6199564918251654,
           -1.591759496163979,
           -1.5632672413952544,
           -1.5344916177845498,
           -1.5054450178802827,
           -1.476140380459891,
           -1.4465912404387606,
           -1.4168117856376277,
           -1.3868169214524535,
           -1.356622344645259,
           -1.3262446276796367,
           -1.2957013152660226,
           -1.2650110350653456,
           -1.2341936248321035,
           -1.2032702786666434,
           -1.1722637154989892,
           -1.1411983734503635,
           -1.1101006343196451,
           -1.0789990831235765,
           -1.0479248083791841,
           -1.0169117496423905,
           -0.9859970996796316,
           -0.9552217694945979,
           -0.9246309251639879,
           -0.8942746058953791,
           -0.8642084326538679,
           -0.834494415721298,
           -0.8052018670667613,
           -0.7764084185663972,
           -0.7482011387131424,
           -0.7206777268835503,
           -0.6939477434236265,
           -0.6681338034071571,
           -0.6433726196239726,
           -0.6198157248866877,
           -0.5976296365120494,
           -0.5769951536308704,
           -0.5581054165001744,
           -0.5411623340432717,
           -0.5263710415322794,
           -0.5139322296313581,
           -0.504032519192909,
           -0.49683352745046633,
           -0.49246078831703244,
           -0.49099408097330355,
           -0.49246078831703544,
           -0.49683352745047227,
           -0.5040325191929179,
           -0.5139322296313696,
           -0.5263710415322934,
           -0.5411623340432881,
           -0.5581054165001929,
           -0.5769951536308908,
           -0.5976296365120715,
           -0.6198157248867111,
           -0.6433726196239977,
           -0.6681338034071831,
           -0.6939477434236535,
           -0.7206777268835781,
           -0.748201138713171,
           -0.7764084185664264,
           -0.8052018670667912,
           -0.8344944157213283,
           -0.8642084326538987,
           -0.8942746058954101,
           -0.9246309251640193,
           -0.9552217694946296,
           -0.9859970996796632,
           -1.0169117496424225,
           -1.0479248083792159,
           -1.0789990831236083,
           -1.1101006343196769,
           -1.1411983734503954,
           -1.172263715499021,
           -1.2032702786666751,
           -1.2341936248321355,
           -1.2650110350653774,
           -1.2957013152660541,
           -1.3262446276796678,
           -1.35662234464529,
           -1.3868169214524844,
           -1.4168117856376585,
           -1.4465912404387913,
           -1.476140380459921,
           -1.505445017880313,
           -1.5344916177845798,
           -1.5632672413952835,
           -1.5917594961640082,
           -1.619956491825194,
           -1.6478468016431636,
           -1.675419428190072,
           -1.7026637730839769,
           -1.7295696101941695,
           -1.7561270618875076,
           -1.7823265779464186,
           -1.8081589168380097,
           -1.8336151290555347,
           -1.8586865422894154,
           -1.8833647482159237,
           -1.9076415907182998,
           -1.9315091553780916,
           -1.954959760094412,
           -1.9779859467060663,
           -2.0005804735064694,
           -2.022736308554294,
           -2.0444466236941308,
           -2.06570478921133,
           -2.086504369053835,
           -2.106839116561398,
           -2.126702970649177,
           -2.146090052398569,
           -2.1649946620132337,
           -2.1834112761027846,
           -2.201334545260623,
           -2.2187592919058807,
           -2.235680508362585,
           -2.252093355151912,
           -2.2679931594758247,
           -2.2833754138726308,
           -2.298235775026872,
           -2.3125700627177403,
           -2.3263742588917493,
           -2.3396445068467644,
           -2.3523771105157634,
           -2.3645685338397926,
           -2.376215400220599,
           -2.387314492044318,
           -2.3978627502684233,
           -2.407857274064864,
           -2.4172953205130105,
           -2.4261743043366093,
           -2.4344917976795144,
           -2.442245529915477,
           -2.4494333874877174,
           -2.456053413774435,
           -2.4621038089767975,
           -2.467582930026333,
           -2.47248929050893,
           -2.4768215606030304,
           -2.480578567029817,
           -2.4837592930135326,
           -2.4863628782502762,
           -2.488388618883897,
           -2.489835967487814,
           -2.4907045330518476
          ],
          [
           -2.463663531985308,
           -2.4633761383305512,
           -2.462514034268815,
           -2.461077450507829,
           -2.459066771560991,
           -2.4564825357484668,
           -2.453325435199379,
           -2.449596315855766,
           -2.4452961774791464,
           -2.4404261736607777,
           -2.4349876118368723,
           -2.428981953310281,
           -2.422410813280382,
           -2.4152759608831538,
           -2.407579319243706,
           -2.3993229655437913,
           -2.390509131107149,
           -2.3811402015058576,
           -2.3712187166912466,
           -2.3607473711532667,
           -2.3497290141127,
           -2.3381666497510083,
           -2.3260634374831586,
           -2.3134226922793153,
           -2.3002478850418973,
           -2.2865426430452076,
           -2.2723107504455733,
           -2.2575561488707776,
           -2.2422829380985116,
           -2.226495376834589,
           -2.2101978836028215,
           -2.193395037759771,
           -2.176091580648991,
           -2.1582924169110154,
           -2.140002615967158,
           -2.1212274136972082,
           -2.10197221433342,
           -2.0822425925957506,
           -2.0620442960962446,
           -2.0413832480437333,
           -2.020265550283779,
           -1.998697486713019,
           -1.9766855271118742,
           -1.9542363314451061,
           -1.9313567546859258,
           -1.9080538522265176,
           -1.8843348859460372,
           -1.86020733101649,
           -1.8356788835376827,
           -1.8107574691048294,
           -1.7854512524266541,
           -1.759768648128344,
           -1.733718332892757,
           -1.7073092591154113,
           -1.6805506702744417,
           -1.65345211824658,
           -1.6260234828350155,
           -1.5982749938156504,
           -1.5702172558558074,
           -1.5418612767151987,
           -1.5132184992044047,
           -1.4843008374530908,
           -1.455120718130901,
           -1.425691127370973,
           -1.3960256642725086,
           -1.3661386020084612,
           -1.336044957741627,
           -1.305760572762516,
           -1.2753022045114564,
           -1.2446876324427547,
           -1.2139357800387085,
           -1.1830668556953938,
           -1.1521025156910212,
           -1.121066053022605,
           -1.089982616569239,
           -1.0588794658207603,
           -1.0277862673062033,
           -0.9967354398674017,
           -0.9657625570369296,
           -0.9349068159615782,
           -0.9042115834911286,
           -0.873725031096367,
           -0.8435008709659574,
           -0.8135992055923523,
           -0.7840875018134352,
           -0.7550416967431254,
           -0.7265474359885522,
           -0.698701432142091,
           -0.6716129112125211,
           -0.6454050832071881,
           -0.6202165268842551,
           -0.5962023145949414,
           -0.5735346202617746,
           -0.5524024566683953,
           -0.5330100928437123,
           -0.515573640454186,
           -0.5003153218623142,
           -0.4874551084274461,
           -0.47719980336259293,
           -0.469730242539843,
           -0.4651879951493533,
           -0.46366353198530824,
           -0.46518799514935644,
           -0.4697302425398492,
           -0.4771998033626021,
           -0.48745510842745804,
           -0.5003153218623287,
           -0.5155736404542027,
           -0.5330100928437312,
           -0.5524024566684161,
           -0.5735346202617971,
           -0.5962023145949655,
           -0.6202165268842804,
           -0.6454050832072145,
           -0.6716129112125484,
           -0.6987014321421191,
           -0.7265474359885811,
           -0.755041696743155,
           -0.7840875018134652,
           -0.8135992055923831,
           -0.8435008709659882,
           -0.8737250310963981,
           -0.90421158349116,
           -0.93490681596161,
           -0.9657625570369611,
           -0.9967354398674334,
           -1.027786267306235,
           -1.058879465820792,
           -1.089982616569271,
           -1.121066053022637,
           -1.152102515691053,
           -1.1830668556954256,
           -1.2139357800387403,
           -1.2446876324427862,
           -1.275302204511488,
           -1.3057605727625472,
           -1.336044957741658,
           -1.3661386020084918,
           -1.396025664272539,
           -1.4256911273710031,
           -1.4551207181309311,
           -1.4843008374531212,
           -1.5132184992044342,
           -1.541861276715228,
           -1.5702172558558363,
           -1.598274993815679,
           -1.626023482835044,
           -1.6534521182466082,
           -1.6805506702744692,
           -1.7073092591154384,
           -1.7337183328927839,
           -1.7597686481283707,
           -1.7854512524266803,
           -1.810757469104855,
           -1.835678883537708,
           -1.860207331016515,
           -1.884334885946062,
           -1.9080538522265418,
           -1.9313567546859496,
           -1.9542363314451296,
           -1.9766855271118966,
           -1.9986974867130414,
           -2.0202655502838014,
           -2.0413832480437546,
           -2.062044296096265,
           -2.082242592595771,
           -2.10197221433344,
           -2.121227413697228,
           -2.1400026159671772,
           -2.1582924169110345,
           -2.1760915806490093,
           -2.1933950377597884,
           -2.210197883602838,
           -2.226495376834605,
           -2.242282938098528,
           -2.2575561488707927,
           -2.272310750445588,
           -2.2865426430452223,
           -2.300247885041911,
           -2.3134226922793286,
           -2.3260634374831715,
           -2.33816664975102,
           -2.3497290141127114,
           -2.360747371153278,
           -2.3712187166912573,
           -2.3811402015058674,
           -2.390509131107158,
           -2.3993229655438006,
           -2.4075793192437134,
           -2.415275960883161,
           -2.4224108132803885,
           -2.428981953310288,
           -2.4349876118368785,
           -2.440426173660783,
           -2.4452961774791513,
           -2.44959631585577,
           -2.453325435199383,
           -2.4564825357484694,
           -2.4590667715609937,
           -2.46107745050783,
           -2.4625140342688154,
           -2.4633761383305517
          ],
          [
           -2.4358844184753514,
           -2.435599263986433,
           -2.4347438761194473,
           -2.4333184816723055,
           -2.431323458636922,
           -2.428759336192618,
           -2.425626794697468,
           -2.4219266656782192,
           -2.417659931819549,
           -2.4128277269536382,
           -2.407431336051226,
           -2.4014721952155136,
           -2.3949518916805084,
           -2.387872163815602,
           -2.3802349011384667,
           -2.372042144338554,
           -2.363296085313821,
           -2.3539990672235573,
           -2.344153584560559,
           -2.3337622832462173,
           -2.322827960752503,
           -2.311353566255246,
           -2.2993422008235624,
           -2.2867971176508317,
           -2.2737217223331423,
           -2.260119573201802,
           -2.245994381717171,
           -2.2313500129318387,
           -2.216190486032064,
           -2.2005199749672912,
           -2.1843428091786627,
           -2.1676634744386094,
           -2.1504866138149454,
           -2.1328170287743644,
           -2.1146596804419198,
           -2.096019691034949,
           -2.0769023454920155,
           -2.057313093319837,
           -2.037257550683876,
           -2.01674150277132,
           -1.995770906458648,
           -1.9743518933199498,
           -1.95249077301661,
           -1.9301940371141257,
           -1.9074683633776528,
           -1.8843206206045573,
           -1.8607578740599355,
           -1.8367873915898472,
           -1.8124166504971428,
           -1.7876533452764485,
           -1.7625053963183368,
           -1.7369809597083363,
           -1.7110884382645082,
           -1.6848364939783531,
           -1.6582340620482736,
           -1.6312903667233802,
           -1.6040149392087995,
           -1.5764176379227466,
           -1.548508671441534,
           -1.5202986245226806,
           -1.4917984876599395,
           -1.4630196906992674,
           -1.4339741411337348,
           -1.404674267800933,
           -1.3751330708318084,
           -1.3453641788491033,
           -1.315381914591467,
           -1.2852013703516796,
           -1.2548384948712126,
           -1.224310193636926,
           -1.1936344448889258,
           -1.1628304340831588,
           -1.1319187100717574,
           -1.1009213668839049,
           -1.0698622557271786,
           -1.0387672327020465,
           -1.0076644487480277,
           -0.9765846895333633,
           -0.9455617743671828,
           -0.9146330247440355,
           -0.8838398147853079,
           -0.853228217528545,
           -0.8228497625557016,
           -0.792762321526732,
           -0.7630311382579315,
           -0.733730018181718,
           -0.7049426869769839,
           -0.6767643177967729,
           -0.6493032078429702,
           -0.622682553936221,
           -0.597042228026931,
           -0.5725403816668249,
           -0.5493546090498588,
           -0.5276822723143895,
           -0.5077394533787666,
           -0.48975787822788,
           -0.47397912749168836,
           -0.4606455968772346,
           -0.4499881033900563,
           -0.4422107915230523,
           -0.43747497266625884,
           -0.4358844184753516,
           -0.4374749726662622,
           -0.4422107915230588,
           -0.4499881033900658,
           -0.46064559687724704,
           -0.4739791274917034,
           -0.4897578782278973,
           -0.5077394533787861,
           -0.5276822723144109,
           -0.549354609049882,
           -0.5725403816668494,
           -0.5970422280269568,
           -0.6226825539362479,
           -0.6493032078429981,
           -0.6767643177968016,
           -0.7049426869770133,
           -0.7337300181817478,
           -0.763031138257962,
           -0.7927623215267627,
           -0.8228497625557327,
           -0.8532282175285762,
           -0.8838398147853395,
           -0.9146330247440673,
           -0.9455617743672147,
           -0.9765846895333953,
           -1.00766444874806,
           -1.0387672327020787,
           -1.0698622557272106,
           -1.1009213668839368,
           -1.1319187100717891,
           -1.1628304340831905,
           -1.1936344448889578,
           -1.2243101936369576,
           -1.254838494871244,
           -1.2852013703517107,
           -1.3153819145914978,
           -1.345364178849134,
           -1.375133070831839,
           -1.4046742678009634,
           -1.4339741411337648,
           -1.4630196906992972,
           -1.491798487659969,
           -1.5202986245227097,
           -1.548508671441563,
           -1.576417637922775,
           -1.6040149392088277,
           -1.6312903667234082,
           -1.658234062048301,
           -1.68483649397838,
           -1.7110884382645353,
           -1.736980959708363,
           -1.7625053963183628,
           -1.7876533452764742,
           -1.8124166504971682,
           -1.8367873915898718,
           -1.8607578740599597,
           -1.8843206206045808,
           -1.9074683633776761,
           -1.9301940371141488,
           -1.9524907730166323,
           -1.9743518933199717,
           -1.9957709064586697,
           -2.0167415027713416,
           -2.0372575506838975,
           -2.0573130933198573,
           -2.076902345492035,
           -2.0960196910349684,
           -2.114659680441939,
           -2.132817028774383,
           -2.1504866138149636,
           -2.167663474438627,
           -2.1843428091786796,
           -2.200519974967308,
           -2.21619048603208,
           -2.2313500129318533,
           -2.245994381717185,
           -2.2601195732018167,
           -2.273721722333156,
           -2.2867971176508446,
           -2.299342200823575,
           -2.3113535662552573,
           -2.3228279607525146,
           -2.333762283246228,
           -2.3441535845605697,
           -2.353999067223567,
           -2.3632960853138303,
           -2.372042144338563,
           -2.3802349011384747,
           -2.3878721638156097,
           -2.394951891680515,
           -2.4014721952155202,
           -2.407431336051231,
           -2.412827726953643,
           -2.417659931819554,
           -2.4219266656782237,
           -2.4256267946974717,
           -2.428759336192621,
           -2.431323458636925,
           -2.4333184816723064,
           -2.4347438761194478,
           -2.435599263986433
          ],
          [
           -2.4076836149416687,
           -2.407400786465547,
           -2.4065523753326272,
           -2.4051386044263503,
           -2.403159845209497,
           -2.400616617710043,
           -2.3975095905018775,
           -2.3938395806809614,
           -2.389607553837598,
           -2.384814624025728,
           -2.379462053730274,
           -2.3735512538337855,
           -2.3670837835838103,
           -2.360061350562627,
           -2.352485810661194,
           -2.3443591680594213,
           -2.335683575215078,
           -2.3264613328639934,
           -2.3166948900344293,
           -2.3063868440788897,
           -2.295539940726942,
           -2.28415707416303,
           -2.2722412871336792,
           -2.2597957710889585,
           -2.2468238663635822,
           -2.233329062403588,
           -2.2193149980451876,
           -2.204785461853048,
           -2.189744392526068,
           -2.174195879379569,
           -2.1581441629137816,
           -2.1415936354795964,
           -2.1245488420537653,
           -2.1070144811370795,
           -2.088995405790594,
           -2.070496624826683,
           -2.0515233041736436,
           -2.032080768434768,
           -2.0121745026652667,
           -1.9918101543932554,
           -1.9709935359141866,
           -1.9497306268917607,
           -1.928027577302463,
           -1.9058907107656167,
           -1.8833265283062337,
           -1.8603417126041346,
           -1.8369431327899108,
           -1.8131378498564954,
           -1.788933122764502,
           -1.7643364153303995,
           -1.7393554039991617,
           -1.7139979866176496,
           -1.688272292341943,
           -1.6621866928316118,
           -1.6357498149069771,
           -1.6089705548724107,
           -1.5818580947403473,
           -1.554421920627869,
           -1.5266718436415139,
           -1.4986180236176398,
           -1.4702709961468692,
           -1.441641703383659,
           -1.412741529228317,
           -1.383582339571532,
           -1.354176528414228,
           -1.3245370708224453,
           -1.2946775838531241,
           -1.2646123967984186,
           -1.2343566323510782,
           -1.2039263006008534,
           -1.1733384081430804,
           -1.142611085029209,
           -1.111763732831466,
           -1.080817197749507,
           -1.0497939734785577,
           -1.0187184395121867,
           -0.9876171416971087,
           -0.9565191232220408,
           -0.9254563158350141,
           -0.8944640029624126,
           -0.8635813685469649,
           -0.8328521477896366,
           -0.8023253984576852,
           -0.7720564137670443,
           -0.7421077996080876,
           -0.7125507392607048,
           -0.6834664663948098,
           -0.6549479599084291,
           -0.6271018586569348,
           -0.600050565406803,
           -0.5739344605218766,
           -0.5489140683278052,
           -0.5251719038405442,
           -0.5029135693066624,
           -0.4823674755989215,
           -0.46378236598861367,
           -0.4474216963054832,
           -0.43355400808105604,
           -0.42243888676180524,
           -0.41430904447208855,
           -0.40935042796552285,
           -0.4076836149416689,
           -0.4093504279655262,
           -0.4143090444720953,
           -0.4224388867618152,
           -0.433554008081069,
           -0.44742169630549883,
           -0.4637823659886316,
           -0.48236747559894166,
           -0.5029135693066845,
           -0.5251719038405679,
           -0.5489140683278303,
           -0.5739344605219029,
           -0.6000505654068302,
           -0.627101858656963,
           -0.654947959908458,
           -0.6834664663948394,
           -0.7125507392607348,
           -0.7421077996081182,
           -0.7720564137670751,
           -0.8023253984577166,
           -0.8328521477896679,
           -0.8635813685469964,
           -0.8944640029624443,
           -0.9254563158350461,
           -0.9565191232220728,
           -0.9876171416971407,
           -1.0187184395122186,
           -1.0497939734785895,
           -1.0808171977495387,
           -1.1117637328314978,
           -1.1426110850292406,
           -1.173338408143112,
           -1.2039263006008847,
           -1.2343566323511095,
           -1.26461239679845,
           -1.2946775838531548,
           -1.324537070822476,
           -1.3541765284142584,
           -1.3835823395715618,
           -1.412741529228347,
           -1.4416417033836888,
           -1.4702709961468987,
           -1.498618023617669,
           -1.5266718436415427,
           -1.5544219206278977,
           -1.5818580947403753,
           -1.6089705548724382,
           -1.6357498149070044,
           -1.6621866928316387,
           -1.6882722923419697,
           -1.713997986617676,
           -1.7393554039991876,
           -1.764336415330425,
           -1.788933122764527,
           -1.81313784985652,
           -1.836943132789935,
           -1.8603417126041581,
           -1.883326528306257,
           -1.9058907107656393,
           -1.9280275773024853,
           -1.9497306268917831,
           -1.9709935359142083,
           -1.9918101543932765,
           -2.0121745026652875,
           -2.0320807684347884,
           -2.0515233041736636,
           -2.0704966248267023,
           -2.088995405790613,
           -2.1070144811370977,
           -2.124548842053783,
           -2.1415936354796137,
           -2.158144162913798,
           -2.1741958793795857,
           -2.1897443925260838,
           -2.2047854618530627,
           -2.2193149980452023,
           -2.233329062403602,
           -2.246823866363596,
           -2.259795771088972,
           -2.2722412871336912,
           -2.2841570741630415,
           -2.2955399407269534,
           -2.3063868440789004,
           -2.316694890034439,
           -2.326461332864003,
           -2.3356835752150875,
           -2.3443591680594302,
           -2.3524858106612023,
           -2.360061350562634,
           -2.3670837835838174,
           -2.373551253833792,
           -2.3794620537302795,
           -2.3848146240257333,
           -2.3896075538376027,
           -2.393839580680966,
           -2.397509590501882,
           -2.400616617710046,
           -2.4031598452094998,
           -2.4051386044263516,
           -2.4065523753326286,
           -2.407400786465547
          ],
          [
           -2.379088403840359,
           -2.378807990217782,
           -2.3779668223431627,
           -2.3765651191914614,
           -2.3746032457064574,
           -2.372081712779245,
           -2.3690011772186144,
           -2.365362441713807,
           -2.361166454790265,
           -2.3564143107591686,
           -2.3511072496616934,
           -2.3452466572091,
           -2.3388340647199244,
           -2.3318711490557402,
           -2.3243597325571397,
           -2.3163017829818164,
           -2.307699413446834,
           -2.2985548823774185,
           -2.28887059346489,
           -2.2786490956366197,
           -2.267893083041222,
           -2.256605395052538,
           -2.244789016296344,
           -2.2324470767041373,
           -2.2195828515988123,
           -2.206199761817543,
           -2.192301373877774,
           -2.177891400192819,
           -2.162973699344287,
           -2.1475522764193347,
           -2.131631283421593,
           -2.115215019765617,
           -2.098307932865777,
           -2.0809146188317427,
           -2.0630398232840927,
           -2.0446884423051332,
           -2.0258655235417526,
           -2.0065762674791445,
           -1.9868260289064492,
           -1.966620318597931,
           -1.945964805236208,
           -1.924865317607326,
           -1.9033278471012725,
           -1.881358550555786,
           -1.8589637534862873,
           -1.8361499537503876,
           -1.8129238257019435,
           -1.789292224897132,
           -1.76526219342365,
           -1.7408409659341881,
           -1.7160359764769069,
           -1.6908548662291516,
           -1.6653054922563537,
           -1.6393959374364016,
           -1.613134521711232,
           -1.586529814852555,
           -1.5595906509582265,
           -1.5323261449306507,
           -1.5047457112298037,
           -1.4768590852422887,
           -1.4486763476657936,
           -1.4202079523773496,
           -1.3914647583362032,
           -1.3624580661707308,
           -1.3331996602172238,
           -1.303701856920806,
           -1.27397756068059,
           -1.2440403284290256,
           -1.2139044444873752,
           -1.18358500754547,
           -1.1530980319867874,
           -1.122460566234857,
           -1.091690831352905,
           -1.0608083838086655,
           -1.029834307148498,
           -0.9987914383431054,
           -0.9677046358109918,
           -0.9366010976410148,
           -0.9055107403719844,
           -0.8744666508959403,
           -0.8435056266757504,
           -0.8126688225271431,
           -0.7820025256789703,
           -0.7515590845605936,
           -0.7213980204525156,
           -0.6915873541289014,
           -0.6622051807175285,
           -0.6333415230985431,
           -0.6051004837341832,
           -0.5776026912329583,
           -0.5509879926671949,
           -0.5254182636739153,
           -0.5010800806889836,
           -0.4781868086711063,
           -0.4569793983798226,
           -0.4377248834036149,
           -0.42071130138394697,
           -0.40623770959162353,
           -0.3945983850149023,
           -0.38606144983546276,
           -0.3808440584936737,
           -0.37908840384035897,
           -0.3808440584936773,
           -0.38606144983546997,
           -0.3945983850149127,
           -0.406237709591637,
           -0.4207113013839632,
           -0.43772488340363347,
           -0.45697939837984336,
           -0.47818680867112895,
           -0.5010800806890079,
           -0.5254182636739408,
           -0.5509879926672218,
           -0.5776026912329861,
           -0.605100483734212,
           -0.6333415230985723,
           -0.6622051807175584,
           -0.6915873541289317,
           -0.7213980204525465,
           -0.7515590845606248,
           -0.7820025256790017,
           -0.8126688225271745,
           -0.843505626675782,
           -0.8744666508959722,
           -0.9055107403720164,
           -0.9366010976410469,
           -0.9677046358110236,
           -0.9987914383431373,
           -1.0298343071485299,
           -1.0608083838086972,
           -1.0916908313529368,
           -1.1224605662348883,
           -1.153098031986819,
           -1.1835850075455012,
           -1.2139044444874063,
           -1.2440403284290564,
           -1.273977560680621,
           -1.3037018569208367,
           -1.333199660217254,
           -1.3624580661707606,
           -1.3914647583362327,
           -1.4202079523773792,
           -1.4486763476658229,
           -1.4768590852423176,
           -1.5047457112298321,
           -1.532326144930679,
           -1.5595906509582547,
           -1.5865298148525824,
           -1.613134521711259,
           -1.6393959374364284,
           -1.6653054922563801,
           -1.6908548662291776,
           -1.7160359764769326,
           -1.7408409659342137,
           -1.765262193423675,
           -1.7892922248971566,
           -1.812923825701968,
           -1.836149953750411,
           -1.8589637534863102,
           -1.8813585505558086,
           -1.9033278471012944,
           -1.924865317607348,
           -1.9459648052362293,
           -1.966620318597952,
           -1.9868260289064696,
           -2.006576267479165,
           -2.0258655235417726,
           -2.0446884423051523,
           -2.0630398232841114,
           -2.080914618831761,
           -2.098307932865795,
           -2.115215019765634,
           -2.1316312834216093,
           -2.147552276419351,
           -2.1629736993443034,
           -2.177891400192834,
           -2.192301373877789,
           -2.206199761817557,
           -2.2195828515988256,
           -2.23244707670415,
           -2.244789016296356,
           -2.2566053950525498,
           -2.2678930830412334,
           -2.2786490956366303,
           -2.2888705934648996,
           -2.2985548823774278,
           -2.307699413446843,
           -2.3163017829818253,
           -2.324359732557147,
           -2.3318711490557478,
           -2.3388340647199315,
           -2.345246657209106,
           -2.3511072496616987,
           -2.356414310759173,
           -2.3611664547902698,
           -2.3653624417138115,
           -2.369001177218618,
           -2.3720817127792477,
           -2.37460324570646,
           -2.3765651191914627,
           -2.377966822343163,
           -2.378807990217783
          ],
          [
           -2.35012644919137,
           -2.3498485412991577,
           -2.349014889318964,
           -2.347625708334343,
           -2.3456813567986816,
           -2.343182336506617,
           -2.340129292554432,
           -2.3365230132898795,
           -2.3323644302519804,
           -2.3276546181014863,
           -2.3223947945428463,
           -2.316586320238635,
           -2.3102306987175925,
           -2.303329576277537,
           -2.2958847418846404,
           -2.2878981270707017,
           -2.279371805830266,
           -2.270307994519659,
           -2.260709051760232,
           -2.2505774783483754,
           -2.2399159171751277,
           -2.228727153158522,
           -2.217014113192141,
           -2.204779866113724,
           -2.192027622698079,
           -2.1787607356789906,
           -2.1649826998053396,
           -2.1506971519371807,
           -2.1359078711881563,
           -2.1206187791213242,
           -2.104833940006216,
           -2.0885575611458522,
           -2.071793993283371,
           -2.054547731099037,
           -2.036823413809618,
           -2.0186258258835,
           -1.9999598978864748,
           -1.9808307074749045,
           -1.9612434805549648,
           -1.9412035926289626,
           -1.9207165703523,
           -1.8997880933276248,
           -1.8784239961660834,
           -1.8566302708494462,
           -1.8344130694313334,
           -1.8117787071208415,
           -1.7887336657977497,
           -1.7652845980152594,
           -1.7414383315540456,
           -1.71720187460048,
           -1.6925824216324312,
           -1.6675873601083224,
           -1.6422242780694565,
           -1.61650097278239,
           -1.590425460567786,
           -1.5640059879853068,
           -1.5372510445713423,
           -1.5101693773586011,
           -1.4827700074447365,
           -1.4550622489225653,
           -1.4270557305384883,
           -1.3987604205103359,
           -1.3701866550133093,
           -1.341345170935804,
           -1.312247143619152,
           -1.2829042304311244,
           -1.2533286211877208,
           -1.2235330966382105,
           -1.1935310964729633,
           -1.1633367986129806,
           -1.132965211907518,
           -1.102432284818468,
           -1.0717550332282764,
           -1.0409516911983174,
           -1.0100418893597738,
           -0.9790468666799069,
           -0.9479897226635456,
           -0.9168957186838492,
           -0.8857926391609461,
           -0.8547112258061387,
           -0.8236857012150184,
           -0.7927544018153876,
           -0.7619605446236938,
           -0.7313531574427795,
           -0.7009882079124414,
           -0.6709299727976419,
           -0.6412526941530529,
           -0.6120425717166029,
           -0.5834001376905206,
           -0.5554430450685289,
           -0.5283092640635748,
           -0.5021606076669815,
           -0.47718637495532557,
           -0.45360668216808464,
           -0.4316747224229887,
           -0.41167675637674606,
           -0.39392816032314487,
           -0.3787635541855669,
           -0.366519291688535,
           -0.35750791231804374,
           -0.35198677612435086,
           -0.3501264491913699,
           -0.35198677612435475,
           -0.3575079123180513,
           -0.3665192916885459,
           -0.37876355418558105,
           -0.39392816032316197,
           -0.41167675637676543,
           -0.43167472242301025,
           -0.4536066821681082,
           -0.4771863749553505,
           -0.5021606076670078,
           -0.5283092640636023,
           -0.5554430450685572,
           -0.5834001376905495,
           -0.6120425717166326,
           -0.641252694153083,
           -0.6709299727976725,
           -0.7009882079124725,
           -0.7313531574428109,
           -0.7619605446237254,
           -0.7927544018154192,
           -0.8236857012150502,
           -0.8547112258061706,
           -0.8857926391609781,
           -0.9168957186838813,
           -0.9479897226635775,
           -0.979046866679939,
           -1.0100418893598058,
           -1.040951691198349,
           -1.071755033228308,
           -1.1024322848184995,
           -1.1329652119075493,
           -1.1633367986130119,
           -1.1935310964729942,
           -1.2235330966382414,
           -1.2533286211877515,
           -1.2829042304311546,
           -1.3122471436191823,
           -1.3413451709358335,
           -1.370186655013339,
           -1.3987604205103654,
           -1.4270557305385174,
           -1.455062248922594,
           -1.4827700074447647,
           -1.510169377358629,
           -1.5372510445713696,
           -1.564005987985334,
           -1.590425460567813,
           -1.6165009727824164,
           -1.6422242780694827,
           -1.6675873601083484,
           -1.692582421632457,
           -1.717201874600505,
           -1.74143833155407,
           -1.7652845980152834,
           -1.7887336657977733,
           -1.8117787071208649,
           -1.8344130694313565,
           -1.8566302708494686,
           -1.8784239961661056,
           -1.8997880933276468,
           -1.9207165703523212,
           -1.9412035926289835,
           -1.961243480554985,
           -1.9808307074749243,
           -1.9999598978864943,
           -2.018625825883519,
           -2.036823413809637,
           -2.054547731099055,
           -2.071793993283389,
           -2.088557561145869,
           -2.104833940006232,
           -2.1206187791213402,
           -2.1359078711881723,
           -2.1506971519371954,
           -2.1649826998053543,
           -2.1787607356790044,
           -2.1920276226980926,
           -2.2047798661137366,
           -2.2170141131921532,
           -2.228727153158534,
           -2.2399159171751397,
           -2.250577478348386,
           -2.260709051760242,
           -2.2703079945196687,
           -2.279371805830275,
           -2.28789812707071,
           -2.295884741884648,
           -2.3033295762775445,
           -2.3102306987175996,
           -2.316586320238642,
           -2.322394794542852,
           -2.3276546181014917,
           -2.332364430251985,
           -2.336523013289884,
           -2.3401292925544355,
           -2.34318233650662,
           -2.3456813567986843,
           -2.347625708334344,
           -2.349014889318965,
           -2.349848541299158
          ],
          [
           -2.3208257698153467,
           -2.3205504606043106,
           -2.319724603380472,
           -2.3183484093645106,
           -2.3164222305671953,
           -2.313946559754027,
           -2.3109220303961,
           -2.3073494166075657,
           -2.303229633070187,
           -2.298563734945566,
           -2.293352917775792,
           -2.2875985173733313,
           -2.281302009701162,
           -2.274465010744259,
           -2.2670892763737114,
           -2.259176702204905,
           -2.2507293234513703,
           -2.241749314776103,
           -2.2322389901423496,
           -2.222200802666076,
           -2.2116373444725888,
           -2.200551346560039,
           -2.188945678672824,
           -2.17682334918823,
           -2.164187505020017,
           -2.151041431543032,
           -2.1373885525433844,
           -2.123232430199173,
           -2.108576765097348,
           -2.093425396292827,
           -2.0777823014167165,
           -2.0616515968412052,
           -2.0450375379095647,
           -2.0279445192406347,
           -2.0103770751182535,
           -1.9923398799772931,
           -1.9738377489993402,
           -1.9548756388326103,
           -1.9354586484524454,
           -1.9155920201807461,
           -1.8952811408849757,
           -1.8745315433799763,
           -1.8533489080588128,
           -1.8317390647822782,
           -1.8097079950606194,
           -1.787261834565535,
           -1.764406876015732,
           -1.7411495724853054,
           -1.7174965411911962,
           -1.693454567824062,
           -1.6690306114963032,
           -1.644231810391965,
           -1.6190654882160829,
           -1.5935391615560761,
           -1.5676605482855022,
           -1.5414375771613225,
           -1.5148783987904777,
           -1.4879913981707817,
           -1.4607852090458433,
           -1.433268730355118,
           -1.4054511451096579,
           -1.3773419420834863,
           -1.348950940781915,
           -1.3202883202343336,
           -1.291364652263395,
           -1.262190940009389,
           -1.232778662643312,
           -1.2031398273914566,
           -1.173287030226807,
           -1.1432335268690101,
           -1.1129933160889505,
           -1.0825812377535575,
           -1.0520130885938603,
           -1.0213057593630699,
           -0.9904773979082444,
           -0.9595476037555775,
           -0.928537661165058,
           -0.8974708193205012,
           -0.8663726304803927,
           -0.8352713596407747,
           -0.8041984826952728,
           -0.7731892943845113,
           -0.7422836526873205,
           -0.7115268928894009,
           -0.6809709524770171,
           -0.6506757571730515,
           -0.6207109283967516,
           -0.5911578819299531,
           -0.5621123938472687,
           -0.5336877073252008,
           -0.5060182326042485,
           -0.479263834381288,
           -0.45361457737784777,
           -0.42929556923402823,
           -0.4065711476449374,
           -0.3857470645987657,
           -0.3671685539627527,
           -0.3512114436499713,
           -0.33826333116914303,
           -0.32869315917419645,
           -0.3228110719999002,
           -0.3208257698153465,
           -0.3228110719999043,
           -0.32869315917420444,
           -0.33826333116915464,
           -0.35121144364998635,
           -0.36716855396277065,
           -0.38574706459878594,
           -0.4065711476449598,
           -0.42929556923405243,
           -0.45361457737787336,
           -0.4792638343813149,
           -0.5060182326042765,
           -0.5336877073252296,
           -0.5621123938472983,
           -0.5911578819299832,
           -0.6207109283967821,
           -0.6506757571730823,
           -0.6809709524770484,
           -0.7115268928894323,
           -0.7422836526873523,
           -0.7731892943845431,
           -0.8041984826953047,
           -0.8352713596408066,
           -0.8663726304804246,
           -0.8974708193205331,
           -0.9285376611650901,
           -0.9595476037556091,
           -0.990477397908276,
           -1.0213057593631016,
           -1.0520130885938916,
           -1.0825812377535888,
           -1.1129933160889818,
           -1.1432335268690412,
           -1.1732870302268377,
           -1.2031398273914875,
           -1.2327786626433426,
           -1.262190940009419,
           -1.291364652263425,
           -1.3202883202343632,
           -1.3489509407819442,
           -1.3773419420835156,
           -1.4054511451096867,
           -1.4332687303551461,
           -1.4607852090458715,
           -1.4879913981708095,
           -1.514878398790505,
           -1.5414375771613493,
           -1.5676605482855288,
           -1.5935391615561023,
           -1.619065488216109,
           -1.6442318103919908,
           -1.6690306114963285,
           -1.6934545678240867,
           -1.7174965411912206,
           -1.7411495724853296,
           -1.7644068760157559,
           -1.7872618345655582,
           -1.809707995060642,
           -1.8317390647823009,
           -1.8533489080588346,
           -1.8745315433799976,
           -1.8952811408849968,
           -1.9155920201807668,
           -1.9354586484524658,
           -1.9548756388326303,
           -1.9738377489993593,
           -1.9923398799773115,
           -2.010377075118272,
           -2.0279445192406524,
           -2.045037537909582,
           -2.061651596841222,
           -2.077782301416733,
           -2.0934253962928424,
           -2.1085767650973635,
           -2.123232430199188,
           -2.137388552543399,
           -2.151041431543047,
           -2.16418750502003,
           -2.176823349188242,
           -2.188945678672836,
           -2.2005513465600504,
           -2.2116373444725994,
           -2.2222008026660864,
           -2.23223899014236,
           -2.2417493147761127,
           -2.2507293234513788,
           -2.259176702204913,
           -2.267089276373719,
           -2.274465010744266,
           -2.2813020097011685,
           -2.287598517373338,
           -2.2933529177757976,
           -2.2985637349455708,
           -2.3032296330701914,
           -2.3073494166075696,
           -2.3109220303961036,
           -2.3139465597540307,
           -2.316422230567198,
           -2.318348409364512,
           -2.3197246033804735,
           -2.320550460604311
          ],
          [
           -2.2912147122272306,
           -2.2909420967550034,
           -2.2901243194738483,
           -2.288761587781947,
           -2.286854247314998,
           -2.2844027819044554,
           -2.281407813519393,
           -2.277870102192298,
           -2.273790545929216,
           -2.269170180604759,
           -2.264010179842595,
           -2.258311854882145,
           -2.2520766544323254,
           -2.245306164513295,
           -2.2380021082872963,
           -2.2301663458798178,
           -2.2218008741924504,
           -2.212907826708972,
           -2.2034894732963806,
           -2.1935482200027523,
           -2.1830866088540546,
           -2.1721073176522325,
           -2.1606131597771516,
           -2.14860708399526,
           -2.136092174278119,
           -2.1230716496343143,
           -2.1095488639585893,
           -2.0955273059025186,
           -2.081010598771428,
           -2.066002500452853,
           -2.050506903382349,
           -2.0345278345531512,
           -2.018069455576888,
           -2.0011360628033716,
           -1.9837320875084221,
           -1.965862096159705,
           -1.9475307907717547,
           -1.9287430093626823,
           -1.9095037265265826,
           -1.8898180541373928,
           -1.8696912422019023,
           -1.8491286798818865,
           -1.8281358967078882,
           -1.8067185640101484,
           -1.7848824965955632,
           -1.7626336547034689,
           -1.7399781462775776,
           -1.7169222295966124,
           -1.693472316312253,
           -1.6696349749500758,
           -1.6454169349373806,
           -1.6208250912314177,
           -1.595866509632782,
           -1.570548432881989,
           -1.5448782876528027,
           -1.5188636925743215,
           -1.4925124674356167,
           -1.465832643752638,
           -1.4388324769079848,
           -1.4115204601110483,
           -1.3839053404703416,
           -1.3559961375231002,
           -1.3278021646316212,
           -1.299333053733782,
           -1.2705987840300517,
           -1.2416097153050978,
           -1.2123766267239873,
           -1.182910762117558,
           -1.1532238829871175,
           -1.123328330726003,
           -1.09323709988846,
           -1.0629639247525746,
           -1.0325233819466881,
           -1.0019310125677567,
           -0.9712034680544555,
           -0.9403586851383329,
           -0.9094160965493756,
           -0.878396885884648,
           -0.8473242972731624,
           -0.8162240133332669,
           -0.7851246186088534,
           -0.7540581704259819,
           -0.723060905226409,
           -0.6921741162569697,
           -0.6614452484025054,
           -0.6309292682874562,
           -0.6006903826840755,
           -0.5708041953644859,
           -0.5413604102099444,
           -0.5124662025002124,
           -0.48425038176841045,
           -0.4568684402682984,
           -0.43050848725461094,
           -0.4053978532096673,
           -0.3818097218282178,
           -0.3600684026081096,
           -0.3405507248139088,
           -0.3236796528690784,
           -0.3099052442892084,
           -0.29966892981846016,
           -0.2933516242666591,
           -0.29121471222723055,
           -0.2933516242666635,
           -0.2996689298184687,
           -0.30990524428922084,
           -0.3236796528690943,
           -0.3405507248139276,
           -0.3600684026081308,
           -0.3818097218282411,
           -0.40539785320969235,
           -0.4305084872546374,
           -0.4568684402683261,
           -0.484250381768439,
           -0.5124662025002417,
           -0.5413604102099744,
           -0.5708041953645163,
           -0.6006903826841065,
           -0.6309292682874875,
           -0.6614452484025369,
           -0.6921741162570013,
           -0.7230609052264408,
           -0.7540581704260138,
           -0.7851246186088854,
           -0.8162240133332989,
           -0.8473242972731944,
           -0.8783968858846798,
           -0.9094160965494075,
           -0.9403586851383646,
           -0.9712034680544871,
           -1.0019310125677883,
           -1.0325233819467194,
           -1.0629639247526057,
           -1.0932370998884908,
           -1.1233283307260336,
           -1.1532238829871482,
           -1.1829107621175887,
           -1.2123766267240175,
           -1.2416097153051278,
           -1.2705987840300814,
           -1.2993330537338112,
           -1.3278021646316502,
           -1.3559961375231293,
           -1.3839053404703703,
           -1.4115204601110767,
           -1.4388324769080125,
           -1.465832643752666,
           -1.492512467435644,
           -1.5188636925743486,
           -1.5448782876528293,
           -1.570548432882015,
           -1.595866509632808,
           -1.620825091231443,
           -1.645416934937406,
           -1.6696349749501003,
           -1.693472316312277,
           -1.7169222295966362,
           -1.7399781462776012,
           -1.7626336547034915,
           -1.7848824965955858,
           -1.8067185640101708,
           -1.8281358967079098,
           -1.8491286798819078,
           -1.8696912422019234,
           -1.8898180541374137,
           -1.9095037265266026,
           -1.928743009362702,
           -1.9475307907717738,
           -1.9658620961597233,
           -1.9837320875084403,
           -2.0011360628033894,
           -2.018069455576905,
           -2.034527834553168,
           -2.0505069033823653,
           -2.066002500452869,
           -2.081010598771443,
           -2.0955273059025328,
           -2.1095488639586035,
           -2.1230716496343276,
           -2.1360921742781325,
           -2.1486070839952722,
           -2.160613159777164,
           -2.172107317652244,
           -2.1830866088540657,
           -2.1935482200027625,
           -2.2034894732963903,
           -2.2129078267089817,
           -2.2218008741924584,
           -2.230166345879826,
           -2.2380021082873043,
           -2.245306164513303,
           -2.2520766544323316,
           -2.2583118548821512,
           -2.2640101798426007,
           -2.2691701806047644,
           -2.2737905459292205,
           -2.277870102192302,
           -2.281407813519396,
           -2.284402781904458,
           -2.2868542473150004,
           -2.2887615877819494,
           -2.290124319473849,
           -2.2909420967550043
          ],
          [
           -2.2613219232128388,
           -2.261052098670769,
           -2.2602426929238297,
           -2.2588939096002534,
           -2.257006088048534,
           -2.2545797032897212,
           -2.2516153659508977,
           -2.248113822180107,
           -2.2440759535430828,
           -2.2395027769022113,
           -2.234395444278242,
           -2.228755242695358,
           -2.2225835940103136,
           -2.2158820547264284,
           -2.208652315793375,
           -2.200896202393768,
           -2.1926156737177194,
           -2.1838128227266336,
           -2.174489875907694,
           -2.16464919302061,
           -2.1542932668384065,
           -2.1434247228841925,
           -2.1320463191660814,
           -2.1201609459126534,
           -2.107771625311591,
           -2.0948815112544312,
           -2.0814938890906536,
           -2.0676121753946917,
           -2.053239917749843,
           -2.0383807945534658,
           -2.023038614848346,
           -2.0072173181856656,
           -1.9909209745255914,
           -1.9741537841822072,
           -1.9569200778202733,
           -1.9392243165121728,
           -1.921071091864393,
           -1.9024651262240122,
           -1.8834112729769314,
           -1.863914516951047,
           -1.8439799749392176,
           -1.8236128963587694,
           -1.802818664066457,
           -1.7816027953502895,
           -1.759970943122513,
           -1.7379288973413303,
           -1.715482586692793,
           -1.692638080568719,
           -1.669401591381654,
           -1.6457794772638967,
           -1.6217782452046139,
           -1.5974045546872813,
           -1.5726652218993094,
           -1.5475672245970542,
           -1.5221177077227868,
           -1.4963239898860248,
           -1.4701935708404443,
           -1.4437341401099724,
           -1.4169535869444219,
           -1.389860011817113,
           -1.3624617397155083,
           -1.3347673355224845,
           -1.3067856218423037,
           -1.2785256996940053,
           -1.2499969725787676,
           -1.2212091745305476,
           -1.1921724028858114,
           -1.1628971566645645,
           -1.1333943816490821,
           -1.1036755234889934,
           -1.073752590464945,
           -1.0436382279253291,
           -1.0133458068942793,
           -0.9828895299642044,
           -0.9522845583722703,
           -0.9215471651700232,
           -0.890694920698995,
           -0.8597469182765212,
           -0.8287240502009137,
           -0.7976493470723883,
           -0.7665483972219032,
           -0.7354498680463213,
           -0.7043861576648622,
           -0.6733942140600785,
           -0.6425165704084074,
           -0.611802660440474,
           -0.5813104972760597,
           -0.55110882400413,
           -0.5212798744398598,
           -0.4919229163099149,
           -0.4631587806709582,
           -0.43513559558291176,
           -0.40803590553031316,
           -0.38208520343551944,
           -0.35756150586634755,
           -0.33480476664537745,
           -0.3142234069395449,
           -0.29629294029139064,
           -0.2815391502536509,
           -0.27049761004323264,
           -0.26364634465734405,
           -0.2613219232128388,
           -0.2636463446573488,
           -0.27049761004324197,
           -0.28153915025366427,
           -0.29629294029140757,
           -0.3142234069395648,
           -0.33480476664539977,
           -0.35756150586637186,
           -0.3820852034355455,
           -0.4080359055303404,
           -0.4351355955829401,
           -0.4631587806709874,
           -0.4919229163099449,
           -0.5212798744398902,
           -0.5511088240041608,
           -0.5813104972760909,
           -0.6118026604405054,
           -0.642516570408439,
           -0.6733942140601102,
           -0.704386157664894,
           -0.7354498680463533,
           -0.766548397221935,
           -0.7976493470724203,
           -0.8287240502009455,
           -0.8597469182765531,
           -0.8906949206990269,
           -0.9215471651700549,
           -0.952284558372302,
           -0.9828895299642358,
           -1.0133458068943106,
           -1.04363822792536,
           -1.0737525904649756,
           -1.1036755234890243,
           -1.1333943816491125,
           -1.1628971566645947,
           -1.1921724028858414,
           -1.221209174530577,
           -1.249996972578797,
           -1.2785256996940344,
           -1.3067856218423328,
           -1.3347673355225131,
           -1.3624617397155367,
           -1.389860011817141,
           -1.4169535869444496,
           -1.4437341401099997,
           -1.4701935708404714,
           -1.4963239898860514,
           -1.5221177077228132,
           -1.5475672245970802,
           -1.5726652218993347,
           -1.5974045546873064,
           -1.6217782452046385,
           -1.6457794772639212,
           -1.669401591381678,
           -1.6926380805687427,
           -1.7154825866928163,
           -1.737928897341353,
           -1.7599709431225354,
           -1.7816027953503117,
           -1.8028186640664783,
           -1.8236128963587905,
           -1.843979974939238,
           -1.863914516951067,
           -1.8834112729769512,
           -1.902465126224032,
           -1.921071091864412,
           -1.9392243165121907,
           -1.956920077820291,
           -1.9741537841822245,
           -1.9909209745256082,
           -2.007217318185682,
           -2.023038614848362,
           -2.0383807945534813,
           -2.053239917749858,
           -2.067612175394706,
           -2.0814938890906673,
           -2.0948815112544454,
           -2.107771625311604,
           -2.1201609459126654,
           -2.1320463191660934,
           -2.1434247228842036,
           -2.1542932668384176,
           -2.1646491930206206,
           -2.174489875907703,
           -2.183812822726643,
           -2.1926156737177283,
           -2.2008962023937766,
           -2.208652315793382,
           -2.215882054726435,
           -2.2225835940103202,
           -2.2287552426953647,
           -2.234395444278247,
           -2.239502776902216,
           -2.244075953543087,
           -2.248113822180111,
           -2.2516153659509013,
           -2.254579703289724,
           -2.257006088048536,
           -2.2588939096002547,
           -2.2602426929238306,
           -2.2610520986707696
          ],
          [
           -2.2311763221149477,
           -2.2309093878481483,
           -2.230108651692398,
           -2.228774313570975,
           -2.2269067066538426,
           -2.224506297304493,
           -2.2215736850057617,
           -2.2181096022648163,
           -2.2141149144976087,
           -2.209590619893151,
           -2.204537849258031,
           -2.1989578658416757,
           -2.192852065142933,
           -2.186221974698632,
           -2.179069253854877,
           -2.171395693521901,
           -2.1632032159134473,
           -2.1544938742716977,
           -2.1452698525789575,
           -2.135533465257361,
           -2.1252871568580627,
           -2.114533501741497,
           -2.103275203750477,
           -2.091515095878078,
           -2.079256139932463,
           -2.066501426201036,
           -2.0532541731165628,
           -2.039517726928169,
           -2.025295561380455,
           -2.0105912774043113,
           -1.9954086028233975,
           -1.979751392080714,
           -1.9636236259901618,
           -1.947029411518565,
           -1.929972981604241,
           -1.912458695018933,
           -1.8944910362806988,
           -1.8760746156262935,
           -1.8572141690525956,
           -1.837914558437829,
           -1.818180771754678,
           -1.7980179233889453,
           -1.7774312545791757,
           -1.756426133994712,
           -1.7350080584720105,
           -1.7131826539317456,
           -1.690955676502394,
           -1.6683330138796337,
           -1.6453206869551316,
           -1.6219248517532623,
           -1.5981518017200715,
           -1.574007970415597,
           -1.5494999346686325,
           -1.5246344182624345,
           -1.499418296230987,
           -1.4738585998586393,
           -1.4479625224916284,
           -1.4217374262887374,
           -1.3951908500607826,
           -1.3683305183755996,
           -1.34116435213774,
           -1.3137004808914792,
           -1.2859472571436283,
           -1.2579132730610714,
           -1.229607379969556,
           -1.2010387111683893,
           -1.1722167086846282,
           -1.1431511547256463,
           -1.1138522087577936,
           -1.0843304513505987,
           -1.054596936192885,
           -1.0246632520254264,
           -0.9945415966658442,
           -0.9642448658538839,
           -0.9337867603573654,
           -0.9031819157026831,
           -0.8724460600988658,
           -0.8415962077065852,
           -0.8106508964943328,
           -0.7796304827040447,
           -0.7485575076677792,
           -0.7174571577224165,
           -0.6863578447419709,
           -0.6552919440133649,
           -0.6242967387378288,
           -0.5934156375885974,
           -0.5626997551336788,
           -0.532209976585664,
           -0.5020196705486509,
           -0.47221826804067923,
           -0.44291599262838516,
           -0.4142500977208591,
           -0.3863930185098688,
           -0.3595628146405218,
           -0.33403602292804924,
           -0.3101622710177559,
           -0.28837823344633323,
           -0.2692151409804246,
           -0.2532890274749414,
           -0.24125852092660144,
           -0.23373826277265083,
           -0.23117632211494746,
           -0.23373826277265605,
           -0.24125852092661162,
           -0.25328902747495596,
           -0.2692151409804428,
           -0.28837823344635444,
           -0.31016227101777943,
           -0.3340360229280747,
           -0.3595628146405488,
           -0.38639301850989693,
           -0.4142500977208881,
           -0.4429159926284151,
           -0.4722182680407096,
           -0.5020196705486818,
           -0.5322099765856951,
           -0.5626997551337102,
           -0.5934156375886289,
           -0.6242967387378606,
           -0.6552919440133967,
           -0.6863578447420029,
           -0.7174571577224483,
           -0.748557507667811,
           -0.7796304827040765,
           -0.8106508964943645,
           -0.8415962077066169,
           -0.8724460600988974,
           -0.9031819157027146,
           -0.9337867603573968,
           -0.9642448658539151,
           -0.9945415966658752,
           -1.024663252025457,
           -1.0545969361929157,
           -1.0843304513506293,
           -1.1138522087578238,
           -1.1431511547256765,
           -1.172216708684658,
           -1.2010387111684186,
           -1.2296073799695855,
           -1.2579132730611002,
           -1.2859472571436572,
           -1.3137004808915078,
           -1.3411643521377683,
           -1.3683305183756276,
           -1.3951908500608101,
           -1.4217374262887645,
           -1.447962522491655,
           -1.4738585998586657,
           -1.4994182962310132,
           -1.5246344182624605,
           -1.549499934668658,
           -1.5740079704156218,
           -1.5981518017200962,
           -1.6219248517532865,
           -1.645320686955155,
           -1.6683330138796575,
           -1.6909556765024174,
           -1.713182653931768,
           -1.7350080584720329,
           -1.7564261339947338,
           -1.7774312545791968,
           -1.7980179233889664,
           -1.8181807717546983,
           -1.837914558437849,
           -1.8572141690526154,
           -1.8760746156263128,
           -1.8944910362807177,
           -1.9124586950189513,
           -1.9299729816042588,
           -1.947029411518582,
           -1.9636236259901787,
           -1.9797513920807304,
           -1.995408602823413,
           -2.010591277404327,
           -2.02529556138047,
           -2.039517726928183,
           -2.0532541731165765,
           -2.0665014262010493,
           -2.0792561399324754,
           -2.09151509587809,
           -2.103275203750489,
           -2.114533501741508,
           -2.1252871568580733,
           -2.1355334652573714,
           -2.1452698525789673,
           -2.1544938742717066,
           -2.1632032159134553,
           -2.171395693521909,
           -2.179069253854884,
           -2.1862219746986393,
           -2.1928520651429393,
           -2.1989578658416815,
           -2.2045378492580365,
           -2.209590619893156,
           -2.2141149144976136,
           -2.21810960226482,
           -2.221573685005765,
           -2.2245062973044956,
           -2.226906706653845,
           -2.228774313570977,
           -2.230108651692399,
           -2.230909387848149
          ],
          [
           -2.200807072855696,
           -2.2005431303752183,
           -2.1997513683696606,
           -2.1984319831350216,
           -2.1965853017925676,
           -2.1942117822308176,
           -2.1913120130244974,
           -2.187886713330645,
           -2.183936732762079,
           -2.1794630512385362,
           -2.1744667788157925,
           -2.168949155493185,
           -2.1629115509999868,
           -2.1563554645611562,
           -2.149282524643064,
           -2.1416944886798674,
           -2.1335932427812723,
           -2.1249808014225295,
           -2.1158593071175913,
           -2.1062310300764597,
           -2.0960983678478677,
           -2.0854638449485567,
           -2.074330112480549,
           -2.062699947737957,
           -2.0505762538050303,
           -2.037962059147326,
           -2.0248605171980896,
           -2.0112749059421318,
           -1.9972086274997702,
           -1.9826652077136402,
           -1.9676482957415127,
           -1.9521616636585928,
           -1.936209206073155,
           -1.9197949397598202,
           -1.9029230033152544,
           -1.8855976568416501,
           -1.86782328166395,
           -1.8496043800875275,
           -1.830945575203823,
           -1.8118516107523803,
           -1.7923273510487934,
           -1.7723777809892816,
           -1.7520080061440249,
           -1.7312232529529785,
           -1.7100288690397718,
           -1.6884303236614076,
           -1.6664332083140003,
           -1.644043237517639,
           -1.6212662498068624,
           -1.5981082089571315,
           -1.5745752054822924,
           -1.5506734584434236,
           -1.5264093176157965,
           -1.501789266068207,
           -1.476819923217794,
           -1.4515080484340415,
           -1.4258605452782278,
           -1.3998844664796635,
           -1.3735870197680957,
           -1.3469755747034653,
           -1.320057670670491,
           -1.2928410262375296,
           -1.265333550118109,
           -1.2375433540211975,
           -1.2094787677348977,
           -1.1811483568606473,
           -1.1525609437048325,
           -1.123725631946761,
           -1.094651835842377,
           -1.0653493149000752,
           -1.035828215189282,
           -1.006099118728378,
           -0.9761731027652457,
           -0.9460618112369736,
           -0.9157775413100986,
           -0.8853333487070206,
           -0.8547431765837574,
           -0.8240220141303465,
           -0.7931860929456176,
           -0.76225313177247,
           -0.7312426436230927,
           -0.7001763240398889,
           -0.6690785457504688,
           -0.6379769940400476,
           -0.606903489878065,
           -0.575895065787688,
           -0.5449953849334804,
           -0.5142566301997963,
           -0.4837420416893244,
           -0.45352935405698547,
           -0.42371548629465383,
           -0.39442297127194503,
           -0.3658087761748317,
           -0.33807632234898355,
           -0.3114915441416491,
           -0.2864034113187981,
           -0.26326774804366343,
           -0.24266904291519736,
           -0.2253265806990873,
           -0.2120593544183678,
           -0.20367911969311972,
           -0.200807072855696,
           -0.20367911969312558,
           -0.21205935441837906,
           -0.22532658069910316,
           -0.24266904291521701,
           -0.263267748043686,
           -0.286403411318823,
           -0.31149154414167574,
           -0.33807632234901147,
           -0.3658087761748607,
           -0.3944229712719748,
           -0.42371548629468425,
           -0.45352935405701633,
           -0.48374204168935553,
           -0.5142566301998278,
           -0.5449953849335122,
           -0.5758950657877199,
           -0.6069034898780968,
           -0.6379769940400796,
           -0.6690785457505007,
           -0.7001763240399208,
           -0.7312426436231244,
           -0.7622531317725019,
           -0.7931860929456493,
           -0.8240220141303781,
           -0.854743176583789,
           -0.8853333487070518,
           -0.9157775413101298,
           -0.9460618112370048,
           -0.9761731027652766,
           -1.0060991187284085,
           -1.0358282151893123,
           -1.0653493149001056,
           -1.0946518358424069,
           -1.1237256319467908,
           -1.152560943704862,
           -1.1811483568606767,
           -1.2094787677349266,
           -1.2375433540212262,
           -1.2653335501181378,
           -1.2928410262375578,
           -1.3200576706705187,
           -1.3469755747034928,
           -1.3735870197681228,
           -1.3998844664796901,
           -1.4258605452782545,
           -1.4515080484340674,
           -1.4768199232178199,
           -1.5017892660682322,
           -1.5264093176158215,
           -1.5506734584434483,
           -1.5745752054823166,
           -1.5981082089571552,
           -1.621266249806886,
           -1.644043237517662,
           -1.666433208314023,
           -1.68843032366143,
           -1.7100288690397936,
           -1.7312232529530003,
           -1.7520080061440457,
           -1.7723777809893024,
           -1.7923273510488136,
           -1.8118516107524005,
           -1.8309455752038424,
           -1.8496043800875466,
           -1.8678232816639688,
           -1.8855976568416684,
           -1.9029230033152724,
           -1.9197949397598366,
           -1.9362092060731715,
           -1.9521616636586085,
           -1.967648295741528,
           -1.9826652077136553,
           -1.9972086274997853,
           -2.011274905942146,
           -2.0248605171981033,
           -2.0379620591473393,
           -2.050576253805043,
           -2.0626999477379693,
           -2.0743301124805607,
           -2.0854638449485674,
           -2.0960983678478784,
           -2.10623103007647,
           -2.115859307117601,
           -2.1249808014225384,
           -2.1335932427812807,
           -2.1416944886798754,
           -2.149282524643071,
           -2.1563554645611633,
           -2.162911550999993,
           -2.1689491554931912,
           -2.1744667788157974,
           -2.179463051238541,
           -2.183936732762084,
           -2.1878867133306494,
           -2.1913120130245014,
           -2.1942117822308203,
           -2.19658530179257,
           -2.198431983135023,
           -2.1997513683696615,
           -2.2005431303752188
          ],
          [
           -2.170243555722376,
           -2.169982708708371,
           -2.1692002319235852,
           -2.1678963181272315,
           -2.166071288543137,
           -2.16372559279751,
           -2.1608598088319546,
           -2.157474642791864,
           -2.153570928890367,
           -2.1491496292480545,
           -2.1442118337087335,
           -2.1387587596315316,
           -2.1327917516596955,
           -2.1263122814664914,
           -2.1193219474786678,
           -2.1118224745779894,
           -2.103815713781426,
           -2.0953036419006295,
           -2.0862883611814156,
           -2.0767720989240397,
           -2.066757207085134,
           -2.056246161862277,
           -2.045241563262253,
           -2.0337461346541725,
           -2.021762722308767,
           -2.0092942949252586,
           -1.9963439431474064,
           -1.9829148790704607,
           -1.9690104357409517,
           -1.9546340666514481,
           -1.9397893452326442,
           -1.9244799643453931,
           -1.908709735775596,
           -1.892482589735179,
           -1.8758025743727562,
           -1.8586738552980044,
           -1.8411007151242254,
           -1.823087553034128,
           -1.8046388843744632,
           -1.7857593402858352,
           -1.766453667374818,
           -1.7467267274364098,
           -1.7265834972359113,
           -1.7060290683605073,
           -1.685068647152243,
           -1.6637075547356672,
           -1.6419512271553103,
           -1.6198052156403082,
           -1.59727518701603,
           -1.5743669242855154,
           -1.5510863274069966,
           -1.5274394142978427,
           -1.503432322100076,
           -1.479071308748286,
           -1.4543627548874851,
           -1.4293131661964886,
           -1.40392917618195,
           -1.3782175495196585,
           -1.3521851860334966,
           -1.3258391254190958,
           -1.299186552839411,
           -1.2722348055439763,
           -1.2449913806936024,
           -1.217463944609103,
           -1.1896603437080266,
           -1.1615886174496248,
           -1.133257013678326,
           -1.104674006843651,
           -1.075848319684842,
           -1.0467889491081388,
           -1.0175051971624631,
           -0.9880067082471549,
           -0.9583035139793088,
           -0.9284060875299647,
           -0.8983254097377241,
           -0.8680730499664965,
           -0.8376612655484796,
           -0.8071031248248994,
           -0.7764126603802171,
           -0.7456050612248093,
           -0.7146969156545505,
           -0.683706520651319,
           -0.652654279500347,
           -0.6215632175558994,
           -0.5904596579423854,
           -0.5593741161922218,
           -0.5283424980888615,
           -0.49740772245182296,
           -0.46662194665944295,
           -0.4360496571170005,
           -0.40577201421349784,
           -0.37589303212871383,
           -0.3465484533545605,
           -0.3179185645063372,
           -0.29024666256412046,
           -0.2638652042127198,
           -0.23923109850635393,
           -0.2169680445793053,
           -0.19790278742323775,
           -0.18305822363980156,
           -0.17353674920942846,
           -0.17024355572237582,
           -0.17353674920943515,
           -0.1830582236398143,
           -0.19790278742325537,
           -0.21696804457932672,
           -0.23923109850637822,
           -0.2638652042127461,
           -0.2902466625641483,
           -0.31791856450636624,
           -0.34654845335459034,
           -0.37589303212874425,
           -0.4057720142135289,
           -0.4360496571170317,
           -0.4666219466594744,
           -0.49740772245185483,
           -0.5283424980888932,
           -0.5593741161922536,
           -0.5904596579424174,
           -0.6215632175559314,
           -0.652654279500379,
           -0.6837065206513507,
           -0.7146969156545823,
           -0.745605061224841,
           -0.7764126603802486,
           -0.8071031248249309,
           -0.8376612655485111,
           -0.8680730499665278,
           -0.8983254097377549,
           -0.9284060875299958,
           -0.9583035139793393,
           -0.9880067082471852,
           -1.0175051971624933,
           -1.0467889491081688,
           -1.0758483196848716,
           -1.1046740068436804,
           -1.1332570136783553,
           -1.161588617449654,
           -1.1896603437080553,
           -1.217463944609131,
           -1.2449913806936304,
           -1.2722348055440043,
           -1.2991865528394388,
           -1.3258391254191229,
           -1.3521851860335234,
           -1.3782175495196851,
           -1.403929176181976,
           -1.4293131661965146,
           -1.4543627548875107,
           -1.4790713087483114,
           -1.503432322100101,
           -1.527439414297867,
           -1.5510863274070208,
           -1.5743669242855391,
           -1.597275187016053,
           -1.619805215640331,
           -1.641951227155333,
           -1.6637075547356894,
           -1.6850686471522645,
           -1.7060290683605286,
           -1.7265834972359317,
           -1.7467267274364306,
           -1.7664536673748379,
           -1.7857593402858547,
           -1.8046388843744823,
           -1.8230875530341466,
           -1.8411007151242436,
           -1.858673855298022,
           -1.8758025743727735,
           -1.8924825897351956,
           -1.9087097357756124,
           -1.924479964345409,
           -1.9397893452326593,
           -1.9546340666514632,
           -1.9690104357409663,
           -1.982914879070475,
           -1.9963439431474204,
           -2.0092942949252715,
           -2.0217627223087797,
           -2.0337461346541845,
           -2.0452415632622643,
           -2.0562461618622883,
           -2.0667572070851445,
           -2.0767720989240495,
           -2.086288361181425,
           -2.0953036419006383,
           -2.103815713781435,
           -2.1118224745779974,
           -2.119321947478675,
           -2.1263122814664985,
           -2.1327917516597017,
           -2.138758759631537,
           -2.144211833708739,
           -2.1491496292480594,
           -2.1535709288903715,
           -2.1574746427918674,
           -2.1608598088319577,
           -2.1637255927975128,
           -2.1660712885431392,
           -2.1678963181272337,
           -2.1692002319235866,
           -2.169982708708372
          ],
          [
           -2.1395153389439,
           -2.13925769323853,
           -2.138484819235409,
           -2.1371969062603497,
           -2.135394269812521,
           -2.1330773514987214,
           -2.1302467189414616,
           -2.1269030656609584,
           -2.1230472109311704,
           -2.1186800996100383,
           -2.1138028019441215,
           -2.108416513347866,
           -2.102522554157757,
           -2.096122369361656,
           -2.089217528303673,
           -2.08180972436493,
           -2.073900774620667,
           -2.065492619474132,
           -2.056587322267803,
           -2.047187068872497,
           -2.037294167255016,
           -2.0269110470250244,
           -2.0160402589619344,
           -2.0046844745226453,
           -1.9928464853310748,
           -1.980529202650517,
           -1.9677356568399529,
           -1.9544689967955746,
           -1.9407324893788973,
           -1.9265295188329872,
           -1.9118635861884834,
           -1.8967383086612906,
           -1.8811574190439952,
           -1.8651247650933154,
           -1.8486443089161169,
           -1.83172012635686,
           -1.8143564063896247,
           -1.796557450518275,
           -1.7783276721887231,
           -1.7596715962177492,
           -1.7405938582433897,
           -1.7210992042025328,
           -1.7011924898421007,
           -1.6808786802710372,
           -1.6601628495612857,
           -1.6390501804070743,
           -1.617545963853123,
           -1.5956555991039172,
           -1.5733845934279418,
           -1.5507385621728766,
           -1.5277232289101432,
           -1.504344425730089,
           -1.480608093712453,
           -1.4565202836007523,
           -1.432087156713985,
           -1.4073149861346947,
           -1.3822101582192066,
           -1.3567791744839608,
           -1.3310286539316587,
           -1.3049653358927438,
           -1.2785960834721166,
           -1.2519278877084805,
           -1.2249678725751572,
           -1.1977233009775947,
           -1.1702015819353964,
           -1.1424102791772122,
           -1.1143571214274344,
           -1.0860500147271683,
           -1.0574970572121878,
           -1.0287065568725442,
           -0.9996870529488414,
           -0.9704473417879738,
           -0.9409965081986077,
           -0.9113439636306487,
           -0.8814994928766182,
           -0.851473311488666,
           -0.8212761367684706,
           -0.7909192760834819,
           -0.7604147374852119,
           -0.7297753692894374,
           -0.6990150376241978,
           -0.6681488542574414,
           -0.6371934717321541,
           -0.6061674696519027,
           -0.5750918659438099,
           -0.5439908017647396,
           -0.5128924711052603,
           -0.4818304004580236,
           -0.45084523734705645,
           -0.4199872910396109,
           -0.38932020448324617,
           -0.358926357168198,
           -0.32891495997180104,
           -0.2994343927043629,
           -0.27069127185572567,
           -0.24298010580290869,
           -0.21672892723412993,
           -0.19256616480760083,
           -0.17140536528373174,
           -0.15450920126827933,
           -0.1434117753067263,
           -0.13951533894389997,
           -0.1434117753067342,
           -0.15450920126829398,
           -0.17140536528375155,
           -0.19256616480762437,
           -0.216728927234156,
           -0.2429801058029365,
           -0.27069127185575476,
           -0.29943439270439287,
           -0.3289149599718316,
           -0.358926357168229,
           -0.38932020448327764,
           -0.4199872910396425,
           -0.4508452373470882,
           -0.4818304004580555,
           -0.5128924711052921,
           -0.5439908017647715,
           -0.5750918659438419,
           -0.6061674696519346,
           -0.6371934717321861,
           -0.6681488542574733,
           -0.6990150376242293,
           -0.729775369289469,
           -0.7604147374852434,
           -0.7909192760835131,
           -0.8212761367685016,
           -0.851473311488697,
           -0.881499492876649,
           -0.9113439636306794,
           -0.940996508198638,
           -0.9704473417880038,
           -0.9996870529488714,
           -1.0287065568725742,
           -1.057497057212217,
           -1.0860500147271974,
           -1.1143571214274632,
           -1.1424102791772408,
           -1.1702015819354248,
           -1.197723300977623,
           -1.2249678725751851,
           -1.2519278877085083,
           -1.2785960834721437,
           -1.3049653358927706,
           -1.3310286539316853,
           -1.356779174483987,
           -1.3822101582192325,
           -1.4073149861347205,
           -1.4320871567140103,
           -1.4565202836007771,
           -1.4806080937124777,
           -1.5043444257301133,
           -1.527723228910167,
           -1.5507385621729004,
           -1.5733845934279649,
           -1.5956555991039396,
           -1.6175459638531453,
           -1.639050180407096,
           -1.660162849561307,
           -1.6808786802710582,
           -1.7011924898421213,
           -1.721099204202553,
           -1.7405938582434095,
           -1.7596715962177687,
           -1.7783276721887418,
           -1.7965574505182937,
           -1.814356406389643,
           -1.8317201263568776,
           -1.8486443089161344,
           -1.865124765093332,
           -1.8811574190440117,
           -1.8967383086613063,
           -1.9118635861884985,
           -1.9265295188330018,
           -1.940732489378912,
           -1.9544689967955882,
           -1.9677356568399662,
           -1.9805292026505301,
           -1.9928464853310872,
           -2.004684474522657,
           -2.016040258961946,
           -2.026911047025035,
           -2.0372941672550264,
           -2.047187068872507,
           -2.0565873222678124,
           -2.0654926194741408,
           -2.073900774620675,
           -2.081809724364938,
           -2.0892175283036796,
           -2.0961223693616633,
           -2.1025225541577632,
           -2.1084165133478723,
           -2.113802801944127,
           -2.1186800996100428,
           -2.123047210931175,
           -2.1269030656609624,
           -2.130246718941465,
           -2.133077351498724,
           -2.1353942698125232,
           -2.1371969062603506,
           -2.13848481923541,
           -2.1392576932385303
          ],
          [
           -2.1086521500854514,
           -2.108397813674154,
           -2.1076348664477087,
           -2.1063634944147585,
           -2.104584007544061,
           -2.1022968396960513,
           -2.099502548527108,
           -2.0962018153665825,
           -2.092395445066694,
           -2.0880843658254036,
           -2.0832696289824026,
           -2.0779524087883794,
           -2.072134002147746,
           -2.065815828335041,
           -2.058999428685242,
           -2.0516864662582512,
           -2.0438787254778576,
           -2.035578111745495,
           -2.026786651029163,
           -2.0175064894279067,
           -2.007739892712297,
           -1.997489245841384,
           -1.9867570524566691,
           -1.9755459343536523,
           -1.9638586309316068,
           -1.9516979986222724,
           -1.9390670102982268,
           -1.9259687546617827,
           -1.9124064356153225,
           -1.8983833716140894,
           -1.883902995002554,
           -1.8689688513355796,
           -1.8535845986857509,
           -1.8377540069383684,
           -1.821480957075778,
           -1.8047694404528736,
           -1.7876235580658515,
           -1.7700475198164898,
           -1.7520456437745213,
           -1.7336223554409769,
           -1.7147821870156965,
           -1.6955297766726476,
           -1.6758698678471091,
           -1.6558073085393403,
           -1.6353470506399537,
           -1.614494149282907,
           -1.593253762232884,
           -1.571631149314754,
           -1.5496316718939407,
           -1.5272607924178327,
           -1.5045240740298973,
           -1.4814271802699694,
           -1.4579758748763316,
           -1.4341760217077058,
           -1.4100335848063117,
           -1.3855546286267149,
           -1.3607453184594887,
           -1.3356119210838744,
           -1.3101608056898426,
           -1.2843984451175061,
           -1.258331417470992,
           -1.2319664081750843,
           -1.205310212556682,
           -1.1783697390500474,
           -1.1511520131458088,
           -1.1236641822297886,
           -1.0959135214904405,
           -1.0679074411148495,
           -1.0396534950454057,
           -1.0111593916357313,
           -0.982433006629726,
           -0.9534823989977822,
           -0.9243158303076293,
           -0.8949417884953512,
           -0.8653690171508925,
           -0.8356065517642006,
           -0.8056637648249919,
           -0.7755504222767199,
           -0.7452767546602534,
           -0.7148535474430082,
           -0.6842922566609866,
           -0.6536051583255622,
           -0.6228055434037586,
           -0.5919079751009939,
           -0.5609286325022239,
           -0.5298857757264104,
           -0.4988003848744527,
           -0.4676970520027044,
           -0.4366052486841881,
           -0.40556116298449996,
           -0.3746104197546398,
           -0.3438122056264122,
           -0.3132456878772634,
           -0.2830202841535057,
           -0.2532925759512606,
           -0.2242949587181136,
           -0.19638527842528866,
           -0.17013328589069254,
           -0.14646504420861173,
           -0.1268639015328373,
           -0.1134805669365201,
           -0.10865215008545126,
           -0.11348056693652982,
           -0.12686390153285465,
           -0.1464650442086343,
           -0.1701332858907184,
           -0.19638527842531667,
           -0.2242949587181429,
           -0.2532925759512908,
           -0.2830202841535365,
           -0.3132456878772947,
           -0.3438122056264437,
           -0.37461041975467163,
           -0.4055611629845318,
           -0.43660524868422007,
           -0.46769705200273637,
           -0.4988003848744847,
           -0.5298857757264422,
           -0.5609286325022559,
           -0.5919079751010258,
           -0.6228055434037904,
           -0.6536051583255938,
           -0.6842922566610181,
           -0.7148535474430396,
           -0.7452767546602846,
           -0.7755504222767509,
           -0.8056637648250227,
           -0.8356065517642313,
           -0.8653690171509231,
           -0.8949417884953815,
           -0.9243158303076594,
           -0.9534823989978121,
           -0.9824330066297555,
           -1.0111593916357609,
           -1.039653495045435,
           -1.0679074411148783,
           -1.0959135214904692,
           -1.123664182229817,
           -1.1511520131458368,
           -1.1783697390500751,
           -1.2053102125567094,
           -1.2319664081751118,
           -1.258331417471019,
           -1.284398445117533,
           -1.310160805689869,
           -1.3356119210839006,
           -1.3607453184595144,
           -1.38555462862674,
           -1.4100335848063366,
           -1.4341760217077306,
           -1.457975874876356,
           -1.4814271802699934,
           -1.5045240740299208,
           -1.527260792417856,
           -1.5496316718939636,
           -1.5716311493147763,
           -1.5932537622329062,
           -1.6144941492829286,
           -1.635347050639975,
           -1.6558073085393612,
           -1.675869867847129,
           -1.6955297766726674,
           -1.7147821870157158,
           -1.7336223554409957,
           -1.7520456437745402,
           -1.7700475198165082,
           -1.7876235580658695,
           -1.8047694404528907,
           -1.8214809570757944,
           -1.837754006938385,
           -1.8535845986857669,
           -1.8689688513355953,
           -1.883902995002569,
           -1.8983833716141036,
           -1.9124064356153367,
           -1.925968754661797,
           -1.9390670102982406,
           -1.9516979986222855,
           -1.9638586309316188,
           -1.975545934353664,
           -1.9867570524566807,
           -1.9974892458413949,
           -2.0077398927123067,
           -2.017506489427917,
           -2.0267866510291723,
           -2.035578111745504,
           -2.0438787254778656,
           -2.051686466258259,
           -2.0589994286852495,
           -2.065815828335048,
           -2.072134002147752,
           -2.077952408788385,
           -2.083269628982408,
           -2.0880843658254085,
           -2.092395445066698,
           -2.096201815366586,
           -2.0995025485271115,
           -2.102296839696054,
           -2.1045840075440627,
           -2.1063634944147602,
           -2.10763486644771,
           -2.108397813674155
          ],
          [
           -2.077683847288983,
           -2.077432930268605,
           -2.0766802401522964,
           -2.0754259597604587,
           -2.0736703937468923,
           -2.0714139685285065,
           -2.0686572321869687,
           -2.065400854342343,
           -2.0616456259987648,
           -2.057392459362253,
           -2.0526423876307356,
           -2.047396564756409,
           -2.041656265180546,
           -2.0354228835409045,
           -2.0286979343518876,
           -2.021483051657636,
           -2.013779988658248,
           -2.0055906173093447,
           -1.9969169278952075,
           -1.9877610285757663,
           -1.9781251449077013,
           -1.9680116193399813,
           -1.9574229106841696,
           -1.9463615935598653,
           -1.934830357815679,
           -1.922832007926178,
           -1.9103694623652707,
           -1.8974457529565523,
           -1.8840640242011641,
           -1.8702275325837854,
           -1.855939645857429,
           -1.841203842307768,
           -1.8260237099977967,
           -1.8104029459937203,
           -1.7943453555730204,
           -1.777854851415791,
           -1.760935452780507,
           -1.7435912846655464,
           -1.725826576957908,
           -1.7076456635707502,
           -1.6890529815715434,
           -1.6700530703028593,
           -1.6506505704980547,
           -1.6308502233943878,
           -1.6106568698464452,
           -1.5900754494431104,
           -1.569110999631764,
           -1.547768654853895,
           -1.5260536456969063,
           -1.50397129806759,
           -1.4815270323935512,
           -1.458726362859837,
           -1.435574896689135,
           -1.4120783334752762,
           -1.3882424645813483,
           -1.3640731726156547,
           -1.3395764310010172,
           -1.314758303655689,
           -1.2896249448074462,
           -1.2641825989664548,
           -1.2384376010874047,
           -1.2123963769573933,
           -1.186065443853393,
           -1.1594514115222267,
           -1.1325609835472368,
           -1.1054009591799012,
           -1.0779782357322767,
           -1.050299811648401,
           -1.0223727904010336,
           -0.9942043853961917,
           -0.9658019261143826,
           -0.937172865777568,
           -0.9083247909094553,
           -0.8792654332600911,
           -0.8500026847029849,
           -0.8205446158968858,
           -0.7908994997531138,
           -0.7610758410894376,
           -0.7310824143215636,
           -0.7009283117008893,
           -0.6706230055388579,
           -0.6401764291966963,
           -0.6095990835709638,
           -0.5789021786975019,
           -0.5480978244582538,
           -0.5171992910810442,
           -0.48622137064929893,
           -0.4551808877485268,
           -0.4240974352353271,
           -0.3929944583122999,
           -0.361900892564264,
           -0.3308537107495535,
           -0.2999020132885049,
           -0.269113846197701,
           -0.23858805564629446,
           -0.2084759102047767,
           -0.17902268124499734,
           -0.15065207437261527,
           -0.12414521725601123,
           -0.10101549176322236,
           -0.08412710413868502,
           -0.07768384728898271,
           -0.08412710413869776,
           -0.10101549176324356,
           -0.12414521725603711,
           -0.15065207437264366,
           -0.1790226812450272,
           -0.20847591020480738,
           -0.23858805564632565,
           -0.26911384619773254,
           -0.29990201328853666,
           -0.3308537107495853,
           -0.361900892564296,
           -0.3929944583123319,
           -0.424097435235359,
           -0.45518088774855864,
           -0.48622137064933074,
           -0.5171992910810761,
           -0.5480978244582856,
           -0.5789021786975336,
           -0.6095990835709953,
           -0.6401764291967276,
           -0.6706230055388891,
           -0.7009283117009204,
           -0.7310824143215946,
           -0.7610758410894684,
           -0.7908994997531442,
           -0.8205446158969161,
           -0.8500026847030151,
           -0.879265433260121,
           -0.9083247909094849,
           -0.9371728657775974,
           -0.9658019261144121,
           -0.9942043853962208,
           -1.0223727904010622,
           -1.05029981164843,
           -1.077978235732305,
           -1.1054009591799292,
           -1.1325609835472645,
           -1.1594514115222543,
           -1.1860654438534204,
           -1.2123963769574204,
           -1.2384376010874314,
           -1.2641825989664812,
           -1.2896249448074724,
           -1.3147583036557147,
           -1.3395764310010425,
           -1.36407317261568,
           -1.3882424645813731,
           -1.4120783334753004,
           -1.4355748966891593,
           -1.4587263628598606,
           -1.4815270323935747,
           -1.5039712980676125,
           -1.526053645696929,
           -1.5477686548539171,
           -1.5691109996317858,
           -1.5900754494431317,
           -1.610656869846466,
           -1.6308502233944082,
           -1.6506505704980747,
           -1.6700530703028793,
           -1.6890529815715627,
           -1.707645663570769,
           -1.7258265769579266,
           -1.7435912846655646,
           -1.7609354527805248,
           -1.7778548514158081,
           -1.794345355573037,
           -1.8104029459937365,
           -1.8260237099978132,
           -1.841203842307783,
           -1.8559396458574442,
           -1.8702275325837998,
           -1.8840640242011781,
           -1.897445752956566,
           -1.9103694623652843,
           -1.9228320079261907,
           -1.934830357815691,
           -1.9463615935598768,
           -1.9574229106841807,
           -1.968011619339992,
           -1.9781251449077115,
           -1.9877610285757759,
           -1.996916927895217,
           -2.005590617309353,
           -2.0137799886582566,
           -2.021483051657644,
           -2.0286979343518947,
           -2.035422883540911,
           -2.041656265180552,
           -2.047396564756415,
           -2.052642387630741,
           -2.0573924593622577,
           -2.0616456259987688,
           -2.0654008543423465,
           -2.068657232186972,
           -2.0714139685285087,
           -2.073670393746894,
           -2.0754259597604605,
           -2.0766802401522977,
           -2.077432930268606
          ],
          [
           -2.046640390387394,
           -2.0463930049195245,
           -2.0456509084451677,
           -2.0444142807378283,
           -2.042683421372528,
           -2.0404587496545936,
           -2.0377408045199967,
           -2.0345302444072697,
           -2.0308278471010524,
           -2.026634509547313,
           -2.0219512476403136,
           -2.0167791959813886,
           -2.01111960760962,
           -2.0049738537045023,
           -1.9983434232607078,
           -1.9912299227350538,
           -1.9836350756658152,
           -1.9755607222645064,
           -1.9670088189802934,
           -1.9579814380371863,
           -1.9484807669442064,
           -1.938509107978695,
           -1.9280688776429904,
           -1.9171626060946738,
           -1.9057929365506276,
           -1.8939626246651637,
           -1.8816745378824788,
           -1.8689316547637391,
           -1.8557370642891,
           -1.842093965134999,
           -1.8280056649270755,
           -1.8134755794691115,
           -1.7985072319484035,
           -1.7831042521180203,
           -1.7672703754564274,
           -1.7510094423050115,
           -1.7343253969840706,
           -1.7172222868878948,
           -1.6997042615596165,
           -1.6817755717465759,
           -1.6634405684370117,
           -1.6447037018789827,
           -1.6255695205825091,
           -1.606042670306032,
           -1.5861278930284215,
           -1.5658300259078952,
           -1.54515400022938,
           -1.524104840342042,
           -1.5026876625889296,
           -1.4809076742309342,
           -1.458770172367585,
           -1.436280542857545,
           -1.4134442592420986,
           -1.3902668816754349,
           -1.3667540558661153,
           -1.3429115120348263,
           -1.3187450638943825,
           -1.2942606076589596,
           -1.2694641210907813,
           -1.2443616625939868,
           -1.2189593703672366,
           -1.1932634616288522,
           -1.1672802319310467,
           -1.1410160545831944,
           -1.1144773802083334,
           -1.0876707364623577,
           -1.0606027279519956,
           -1.0332800363960497,
           -1.0057094210850166,
           -0.977897719707851,
           -0.949851849632191,
           -0.9215788097471891,
           -0.8930856830079315,
           -0.8643796398598242,
           -0.8354679427737486,
           -0.8063579521932471,
           -0.7770571342906336,
           -0.7475730710601234,
           -0.7179134734581942,
           -0.6880861985572949,
           -0.6580992720434933,
           -0.6279609179153195,
           -0.5976795980141573,
           -0.5672640651709626,
           -0.5367234355105766,
           -0.5060672881829178,
           -0.475305805124542,
           -0.44444997051548324,
           -0.41351186142824875,
           -0.38250508162463576,
           -0.3514454271109602,
           -0.3203519404441344,
           -0.2892486444090381,
           -0.25816752123272335,
           -0.22715390855681877,
           -0.19627691452318813,
           -0.1656511531458827,
           -0.1354867286134469,
           -0.10621893567428393,
           -0.0788959717476695,
           -0.0564613407296469,
           -0.04664039038739381,
           -0.056461340729665334,
           -0.07889597174769589,
           -0.1062189356743133,
           -0.13548672861347758,
           -0.16565115314591403,
           -0.19627691452321977,
           -0.2271539085568506,
           -0.25816752123275527,
           -0.2892486444090701,
           -0.3203519404441663,
           -0.35144542711099214,
           -0.3825050816246676,
           -0.4135118614282805,
           -0.4444499705155149,
           -0.47530580512457365,
           -0.5060672881829494,
           -0.536723435510608,
           -0.567264065170994,
           -0.5976795980141886,
           -0.6279609179153505,
           -0.6580992720435241,
           -0.6880861985573257,
           -0.7179134734582248,
           -0.7475730710601537,
           -0.7770571342906638,
           -0.8063579521932772,
           -0.8354679427737782,
           -0.8643796398598538,
           -0.8930856830079607,
           -0.9215788097472182,
           -0.9498518496322201,
           -0.9778977197078798,
           -1.005709421085045,
           -1.033280036396078,
           -1.0606027279520236,
           -1.0876707364623854,
           -1.114477380208361,
           -1.1410160545832215,
           -1.1672802319310736,
           -1.1932634616288789,
           -1.2189593703672628,
           -1.2443616625940128,
           -1.2694641210908069,
           -1.2942606076589849,
           -1.3187450638944076,
           -1.3429115120348512,
           -1.36675405586614,
           -1.390266881675459,
           -1.413444259242122,
           -1.4362805428575682,
           -1.4587701723676079,
           -1.4809076742309566,
           -1.5026876625889516,
           -1.524104840342064,
           -1.5451540002294015,
           -1.5658300259079163,
           -1.5861278930284424,
           -1.6060426703060522,
           -1.6255695205825287,
           -1.6447037018790023,
           -1.6634405684370306,
           -1.6817755717465945,
           -1.6997042615596345,
           -1.7172222868879126,
           -1.734325396984088,
           -1.7510094423050284,
           -1.7672703754564436,
           -1.783104252118036,
           -1.7985072319484192,
           -1.8134755794691266,
           -1.8280056649270902,
           -1.842093965135013,
           -1.8557370642891138,
           -1.868931654763752,
           -1.881674537882492,
           -1.8939626246651764,
           -1.9057929365506396,
           -1.9171626060946851,
           -1.9280688776430017,
           -1.9385091079787056,
           -1.9484807669442163,
           -1.957981438037196,
           -1.967008818980302,
           -1.9755607222645148,
           -1.983635075665823,
           -1.9912299227350612,
           -1.9983434232607147,
           -2.0049738537045094,
           -2.0111196076096256,
           -2.016779195981394,
           -2.021951247640318,
           -2.0266345095473173,
           -2.030827847101057,
           -2.0345302444072733,
           -2.03774080452,
           -2.0404587496545963,
           -2.042683421372529,
           -2.0444142807378296,
           -2.045650908445169,
           -2.0463930049195254
          ],
          [
           -2.015551811920327,
           -2.015308072168038,
           -2.014576911875888,
           -2.0133585079237917,
           -2.011653155064166,
           -2.0094612658507756,
           -2.006783370539147,
           -2.003620116958571,
           -1.9999722703557254,
           -1.9958407132099627,
           -1.9912264450203017,
           -1.9861305820641844,
           -1.9805543571280546,
           -1.9744991192098302,
           -1.9679663331933404,
           -1.9609575794948124,
           -1.9534745536815032,
           -1.9455190660625628,
           -1.9370930412522451,
           -1.9281985177055725,
           -1.9188376472265702,
           -1.90901269444921,
           -1.898726036291181,
           -1.8879801613806457,
           -1.8767776694561167,
           -1.8651212707396247,
           -1.8530137852833333,
           -1.840458142289774,
           -1.8274573794058917,
           -1.8140146419910828,
           -1.80013318235942,
           -1.7858163589962819,
           -1.7710676357495947,
           -1.7558905809959124,
           -1.7402888667815686,
           -1.7242662679391503,
           -1.7078266611795387,
           -1.6909740241597948,
           -1.6737124345271537,
           -1.656046068939431,
           -1.6379792020621349,
           -1.6195162055426096,
           -1.600661546961536,
           -1.5814197887621475,
           -1.5617955871575286,
           -1.5417936910163845,
           -1.5214189407277023,
           -1.500676267044738,
           -1.4795706899088086,
           -1.4581073172533872,
           -1.4362913437890503,
           -1.4141280497698678,
           -1.3916227997418753,
           -1.3687810412743369,
           -1.3456083036745705,
           -1.322110196687206,
           -1.2982924091788255,
           -1.2741607078090882,
           -1.2497209356895531,
           -1.2249790110316137,
           -1.1999409257851636,
           -1.1746127442698635,
           -1.1490006018012116,
           -1.123110703314004,
           -1.0969493219862612,
           -1.0705227978673026,
           -1.0438375365144161,
           -1.0169000076435313,
           -0.9897167438005322,
           -0.9622943390614079,
           -0.9346394477714682,
           -0.9067587833364728,
           -0.8786591170819642,
           -0.8503472772016405,
           -0.8218301478216588,
           -0.7931146682159068,
           -0.7642078322183711,
           -0.7351166878939451,
           -0.7058483375502198,
           -0.6764099382026242,
           -0.6468087026479046,
           -0.6170519013626804,
           -0.5871468655347942,
           -0.5571009916715537,
           -0.5269217484374283,
           -0.4966166866992647,
           -0.46619345427745984,
           -0.4356598177556238,
           -0.4050236951449999,
           -0.37429320572298064,
           -0.34347674794473804,
           -0.3125831250101649,
           -0.2816217549885953,
           -0.2506030390826793,
           -0.21953904506541447,
           -0.18844487023225975,
           -0.15734162333824003,
           -0.12626380760020356,
           -0.09528107871029981,
           -0.06458197524021321,
           -0.03499056506635985,
           -0.015551811920326975,
           -0.0349905650663887,
           -0.06458197524024448,
           -0.09528107871033158,
           -0.1262638076002355,
           -0.15734162333827206,
           -0.18844487023229173,
           -0.21953904506544644,
           -0.2506030390827112,
           -0.2816217549886272,
           -0.31258312501019664,
           -0.3434767479447698,
           -0.3742932057230123,
           -0.4050236951450314,
           -0.4356598177556552,
           -0.46619345427749115,
           -0.496616686699296,
           -0.5269217484374595,
           -0.5571009916715846,
           -0.5871468655348251,
           -0.617051901362711,
           -0.646808702647935,
           -0.6764099382026545,
           -0.7058483375502499,
           -0.7351166878939752,
           -0.7642078322184009,
           -0.7931146682159365,
           -0.8218301478216881,
           -0.8503472772016698,
           -0.8786591170819931,
           -0.9067587833365015,
           -0.9346394477714969,
           -0.9622943390614362,
           -0.9897167438005603,
           -1.0169000076435593,
           -1.0438375365144437,
           -1.07052279786733,
           -1.0969493219862883,
           -1.1231107033140306,
           -1.149000601801238,
           -1.1746127442698895,
           -1.1999409257851896,
           -1.2249790110316394,
           -1.2497209356895784,
           -1.2741607078091133,
           -1.2982924091788504,
           -1.3221101966872302,
           -1.3456083036745947,
           -1.3687810412743604,
           -1.3916227997418986,
           -1.4141280497698907,
           -1.436291343789073,
           -1.4581073172534094,
           -1.4795706899088306,
           -1.5006762670447595,
           -1.5214189407277234,
           -1.5417936910164052,
           -1.561795587157549,
           -1.5814197887621673,
           -1.600661546961555,
           -1.6195162055426287,
           -1.6379792020621535,
           -1.6560460689394492,
           -1.6737124345271717,
           -1.6909740241598124,
           -1.7078266611795558,
           -1.7242662679391667,
           -1.7402888667815848,
           -1.755890580995928,
           -1.7710676357496105,
           -1.7858163589962968,
           -1.8001331823594342,
           -1.8140146419910967,
           -1.8274573794059055,
           -1.8404581422897868,
           -1.8530137852833461,
           -1.8651212707396374,
           -1.8767776694561285,
           -1.8879801613806566,
           -1.8987260362911917,
           -1.9090126944492203,
           -1.9188376472265805,
           -1.928198517705582,
           -1.937093041252254,
           -1.945519066062571,
           -1.9534745536815108,
           -1.9609575794948202,
           -1.9679663331933472,
           -1.9744991192098367,
           -1.9805543571280604,
           -1.9861305820641895,
           -1.9912264450203068,
           -1.9958407132099674,
           -1.9999722703557297,
           -2.0036201169585746,
           -2.00678337053915,
           -2.009461265850778,
           -2.011653155064168,
           -2.013358507923793,
           -2.014576911875889,
           -2.0153080721680383
          ],
          [
           -1.984448188079625,
           -1.984208210125671,
           -1.9834883343188103,
           -1.9822887348100366,
           -1.980609701804299,
           -1.9784516414904478,
           -1.9758150759431954,
           -1.9727006429971,
           -1.9691090960926088,
           -1.9650413040942085,
           -1.960498251080718,
           -1.9554810361077821,
           -1.949990872942625,
           -1.9440290897711314,
           -1.9375971288773306,
           -1.9306965462953618,
           -1.9233290114340176,
           -1.915496306673948,
           -1.9072003269376467,
           -1.8984430792323095,
           -1.889226682165703,
           -1.8795533654351537,
           -1.8694254692897954,
           -1.8588454439662199,
           -1.8478158490976702,
           -1.8363393530969352,
           -1.824418732513114,
           -1.8120568713624106,
           -1.7992567604331464,
           -1.7860214965651744,
           -1.7723542819038907,
           -1.7582584231290463,
           -1.7437373306585762,
           -1.7287945178276645,
           -1.7134336000432764,
           -1.6976582939144014,
           -1.6814724163582602,
           -1.6648798836827359,
           -1.6478847106453056,
           -1.6304910094887612,
           -1.612702988954018,
           -1.5945249532703274,
           -1.575961301123226,
           -1.5570165246005678,
           -1.5376952081170097,
           -1.518002027317335,
           -1.4979417479590322,
           -1.4775192247745692,
           -1.4567394003138223,
           -1.4356073037671828,
           -1.414128049769868,
           -1.392306837188036,
           -1.370148947887346,
           -1.3476597454846706,
           -1.324844674083735,
           -1.3017092569955553,
           -1.2782590954446378,
           -1.254499867262037,
           -1.2304373255665044,
           -1.2060772974351486,
           -1.18142568256524,
           -1.1564884519290537,
           -1.1312716464239716,
           -1.1057813755204604,
           -1.08002381591104,
           -1.0540052101639719,
           -1.0277318653861662,
           -1.0012101519008,
           -0.9744465019463607,
           -0.9474474084054428,
           -0.920219423573665,
           -0.8927691579817442,
           -0.8651032792872667,
           -0.8372285112572957,
           -0.809151632869119,
           -0.7808794775647089,
           -0.752418932705724,
           -0.7237769392913461,
           -0.6949604920227617,
           -0.6659766398283963,
           -0.6368324870072837,
           -0.6075351952106676,
           -0.5780919865743191,
           -0.548510148452543,
           -0.5187970404165403,
           -0.48896010451032074,
           -0.4590068802857543,
           -0.42894502700558984,
           -0.3987823568691663,
           -0.36852688567723396,
           -0.33818691200183604,
           -0.3077711447422415,
           -0.2772889165297407,
           -0.24675055767283513,
           -0.2161680900256433,
           -0.1855566105049646,
           -0.154937317358543,
           -0.12434500048331784,
           -0.09385010320576674,
           -0.06364352007630433,
           -0.03455790642377664,
           -0.01555181192037493,
           -0.03455790642380496,
           -0.06364352007633506,
           -0.09385010320579798,
           -0.12434500048334926,
           -0.15493731735857447,
           -0.18555661050499606,
           -0.21616809002567472,
           -0.2467505576728665,
           -0.277288916529772,
           -0.3077711447422728,
           -0.33818691200186723,
           -0.36852688567726516,
           -0.39878235686919733,
           -0.4289450270056207,
           -0.4590068802857852,
           -0.48896010451035143,
           -0.5187970404165709,
           -0.5485101484525734,
           -0.5780919865743497,
           -0.6075351952106978,
           -0.6368324870073137,
           -0.6659766398284263,
           -0.6949604920227914,
           -0.7237769392913757,
           -0.7524189327057532,
           -0.7808794775647382,
           -0.8091516328691479,
           -0.8372285112573244,
           -0.8651032792872951,
           -0.8927691579817724,
           -0.920219423573693,
           -0.9474474084054709,
           -0.9744465019463883,
           -1.0012101519008274,
           -1.0277318653861933,
           -1.0540052101639987,
           -1.0800238159110667,
           -1.1057813755204866,
           -1.1312716464239976,
           -1.15648845192908,
           -1.1814256825652656,
           -1.2060772974351737,
           -1.230437325566529,
           -1.2544998672620618,
           -1.278259095444662,
           -1.301709256995579,
           -1.324844674083759,
           -1.347659745484694,
           -1.370148947887369,
           -1.3923068371880583,
           -1.41412804976989,
           -1.4356073037672048,
           -1.4567394003138436,
           -1.4775192247745905,
           -1.4979417479590533,
           -1.5180020273173553,
           -1.5376952081170299,
           -1.5570165246005876,
           -1.575961301123245,
           -1.5945249532703465,
           -1.6127029889540365,
           -1.6304910094887797,
           -1.6478847106453232,
           -1.6648798836827534,
           -1.6814724163582773,
           -1.6976582939144178,
           -1.7134336000432926,
           -1.7287945178276802,
           -1.7437373306585915,
           -1.7582584231290608,
           -1.7723542819039049,
           -1.7860214965651884,
           -1.79925676043316,
           -1.8120568713624234,
           -1.8244187325131265,
           -1.8363393530969472,
           -1.8478158490976817,
           -1.858845443966231,
           -1.8694254692898058,
           -1.8795533654351637,
           -1.8892266821657127,
           -1.8984430792323184,
           -1.9072003269376554,
           -1.9154963066739565,
           -1.9233290114340251,
           -1.9306965462953691,
           -1.937597128877337,
           -1.944029089771138,
           -1.9499908729426307,
           -1.9554810361077875,
           -1.960498251080723,
           -1.9650413040942127,
           -1.9691090960926123,
           -1.9727006429971035,
           -1.975815075943199,
           -1.97845164149045,
           -1.9806097018043007,
           -1.9822887348100382,
           -1.9834883343188114,
           -1.9842082101256717
          ],
          [
           -1.9533596096125583,
           -1.9531235113569188,
           -1.9524152737936227,
           -1.95123506851996,
           -1.9495831814861666,
           -1.9474600129275648,
           -1.9448660772696003,
           -1.9418020030057939,
           -1.938268532548666,
           -1.934266522053673,
           -1.9297969412162235,
           -1.9248608730418448,
           -1.9194595135895838,
           -1.9135941716887246,
           -1.90726626862894,
           -1.9004773378239779,
           -1.8932290244490095,
           -1.8855230850517828,
           -1.8773613871377188,
           -1.868745908729119,
           -1.859678737898651,
           -1.850162072277307,
           -1.8401982185370303,
           -1.8297895918482296,
           -1.8189387153124155,
           -1.8076482193702061,
           -1.7959208411849763,
           -1.783759424002434,
           -1.771166916486437,
           -1.7581463720313872,
           -1.7447009480515558,
           -1.7308339052477322,
           -1.7165486068516136,
           -1.701848517848388,
           -1.6867372041779973,
           -1.6712183319156189,
           -1.6552956664319376,
           -1.638973071533846,
           -1.6222545085862523,
           -1.6051440356157665,
           -1.5876458063970857,
           -1.569764069523,
           -1.5515031674590385,
           -1.5328675355838763,
           -1.51386170121677,
           -1.4944902826334185,
           -1.474757988071833,
           -1.4546696147299916,
           -1.434230047757295,
           -1.413444259242099,
           -1.3923173071979322,
           -1.3708543345513726,
           -1.3490605681350047,
           -1.3269413176894056,
           -1.3045019748787223,
           -1.2817480123251639,
           -1.2586849826686077,
           -1.2353185176586061,
           -1.2116543272873677,
           -1.1876981989738642,
           -1.1634559968111293,
           -1.1389336608911587,
           -1.1141372067247017,
           -1.0890727247768022,
           -1.06374638014336,
           -1.0381644123995188,
           -1.0123331356576097,
           -0.9862589388811568,
           -0.9599482865125795,
           -0.9334077194864937,
           -0.9066438567188763,
           -0.8796633971862173,
           -0.8524731227399873,
           -0.8250799018429193,
           -0.7974906944684063,
           -0.7697125584779316,
           -0.7417526578913759,
           -0.7136182736020836,
           -0.6853168172787591,
           -0.656855849463442,
           -0.628243103255214,
           -0.5994865155188078,
           -0.5705942683635906,
           -0.5415748448419135,
           -0.512437104646035,
           -0.4831903884237107,
           -0.453844663842918,
           -0.4244107338786864,
           -0.39490054008591996,
           -0.36532761484953047,
           -0.3357077745805047,
           -0.3060602165485044,
           -0.27640931992897283,
           -0.2467877351345704,
           -0.21724196556811634,
           -0.18784310465697424,
           -0.15870913183992696,
           -0.13005579167224057,
           -0.10232691659149741,
           -0.07657472911209624,
           -0.055656444964064175,
           -0.04664039038744172,
           -0.0556564449640812,
           -0.07657472911212099,
           -0.10232691659152518,
           -0.13005579167226966,
           -0.15870913183995675,
           -0.18784310465700435,
           -0.21724196556814662,
           -0.24678773513460078,
           -0.27640931992900325,
           -0.30606021654853494,
           -0.33570777458053525,
           -0.3653276148495609,
           -0.3949005400859503,
           -0.4244107338787167,
           -0.4538446638429482,
           -0.4831903884237409,
           -0.5124371046460651,
           -0.5415748448419434,
           -0.5705942683636206,
           -0.5994865155188375,
           -0.6282431032552434,
           -0.6568558494634712,
           -0.6853168172787882,
           -0.7136182736021125,
           -0.7417526578914048,
           -0.7697125584779603,
           -0.7974906944684347,
           -0.8250799018429478,
           -0.8524731227400153,
           -0.8796633971862452,
           -0.9066438567189039,
           -0.9334077194865211,
           -0.9599482865126067,
           -0.9862589388811835,
           -1.0123331356576364,
           -1.0381644123995453,
           -1.0637463801433864,
           -1.089072724776828,
           -1.1141372067247275,
           -1.1389336608911844,
           -1.1634559968111546,
           -1.1876981989738888,
           -1.211654327287392,
           -1.2353185176586303,
           -1.2586849826686315,
           -1.2817480123251874,
           -1.3045019748787456,
           -1.3269413176894285,
           -1.3490605681350276,
           -1.3708543345513948,
           -1.3923173071979542,
           -1.4134442592421206,
           -1.434230047757316,
           -1.4546696147300122,
           -1.4747579880718533,
           -1.4944902826334385,
           -1.5138617012167899,
           -1.5328675355838954,
           -1.5515031674590571,
           -1.5697640695230188,
           -1.5876458063971037,
           -1.6051440356157842,
           -1.6222545085862696,
           -1.638973071533863,
           -1.6552956664319545,
           -1.6712183319156348,
           -1.686737204178013,
           -1.7018485178484033,
           -1.7165486068516291,
           -1.7308339052477468,
           -1.7447009480515698,
           -1.758146372031401,
           -1.7711669164864505,
           -1.7837594240024468,
           -1.795920841184989,
           -1.8076482193702181,
           -1.8189387153124268,
           -1.8297895918482405,
           -1.8401982185370407,
           -1.8501620722773169,
           -1.8596787378986603,
           -1.868745908729128,
           -1.8773613871377277,
           -1.885523085051791,
           -1.893229024449017,
           -1.900477337823985,
           -1.9072662686289468,
           -1.9135941716887308,
           -1.919459513589589,
           -1.9248608730418506,
           -1.9297969412162284,
           -1.9342665220536779,
           -1.9382685325486702,
           -1.9418020030057976,
           -1.944866077269603,
           -1.947460012927567,
           -1.9495831814861682,
           -1.951235068519961,
           -1.9524152737936238,
           -1.9531235113569194
          ],
          [
           -1.9223161527109696,
           -1.9220840537454653,
           -1.921387813262703,
           -1.9202276004910215,
           -1.9186036974346135,
           -1.9165164988089893,
           -1.9139665119506812,
           -1.9109543567012277,
           -1.9074807652655057,
           -1.9035465820444988,
           -1.8991527634425747,
           -1.8943003776494018,
           -1.8889906043966227,
           -1.8832247346894186,
           -1.8770041705131433,
           -1.870330424515186,
           -1.8632051196622768,
           -1.855629988873438,
           -1.8476068746288365,
           -1.8391377285547874,
           -1.8302246109852065,
           -1.820869690499818,
           -1.8110752434394708,
           -1.8008436533989276,
           -1.790177410697543,
           -1.7790791118282738,
           -1.7675514588855066,
           -1.7555972589722355,
           -1.7432194235871683,
           -1.7304209679923959,
           -1.7172050105623207,
           -1.7035747721146026,
           -1.6895335752239637,
           -1.6750848435197665,
           -1.6602321009683862,
           -1.6449789711414942,
           -1.629329176471495,
           -1.6132865374954914,
           -1.5968549720893115,
           -1.580038494693299,
           -1.5628412155317772,
           -1.5452673398283208,
           -1.5273211670192315,
           -1.509007089967921,
           -1.4903295941832557,
           -1.4712932570453072,
           -1.4519027470424468,
           -1.4321628230242434,
           -1.412078333475277,
           -1.3916542158157217,
           -1.3708954957354242,
           -1.3498072865692436,
           -1.328394788722625,
           -1.3066632891578394,
           -1.2846181609530238,
           -1.2622648629482232,
           -1.2396089394950778,
           -1.2166560203297696,
           -1.1934118205923914,
           -1.1698821410202456,
           -1.1460728683478223,
           -1.121989975952663,
           -1.097639524794199,
           -1.0730276647024277,
           -1.0481606360853806,
           -1.023044772139432,
           -0.9976865016654148,
           -0.9720923526173847,
           -0.9462689565411426,
           -0.9202230540983172,
           -0.8939615019215221,
           -0.8674912811105163,
           -0.840819507763328,
           -0.8139534460468405,
           -0.7869005244580032,
           -0.7596683561231339,
           -0.7322647642481706,
           -0.7046978141950985,
           -0.6769758541601857,
           -0.6491075671287246,
           -0.6211020377701301,
           -0.5929688393559663,
           -0.5647181478485078,
           -0.5363608933613414,
           -0.5079089637884712,
           -0.4793754824429344,
           -0.4507751925693774,
           -0.4221249992352788,
           -0.39344474803596746,
           -0.36475836879282164,
           -0.3360955970262795,
           -0.30749463769560664,
           -0.2790064176498935,
           -0.25070161795497375,
           -0.2226827737112165,
           -0.19510602818587053,
           -0.16822211773740697,
           -0.14245709281519472,
           -0.11857543344057674,
           -0.0979951128816957,
           -0.08322896995955179,
           -0.07768384728903052,
           -0.08322896995956279,
           -0.09799511288171439,
           -0.11857543344059991,
           -0.1424570928152204,
           -0.16822211773743417,
           -0.1951060281858986,
           -0.22268277371124515,
           -0.2507016179550027,
           -0.2790064176499227,
           -0.307494637695636,
           -0.3360955970263089,
           -0.36475836879285106,
           -0.39344474803599694,
           -0.42212499923530816,
           -0.4507751925694069,
           -0.4793754824429638,
           -0.5079089637885005,
           -0.5363608933613706,
           -0.564718147848537,
           -0.5929688393559953,
           -0.6211020377701589,
           -0.6491075671287535,
           -0.6769758541602141,
           -0.7046978141951269,
           -0.7322647642481986,
           -0.7596683561231621,
           -0.7869005244580309,
           -0.8139534460468685,
           -0.8408195077633556,
           -0.8674912811105436,
           -0.8939615019215492,
           -0.920223054098344,
           -0.9462689565411693,
           -0.9720923526174111,
           -0.997686501665441,
           -1.0230447721394578,
           -1.0481606360854063,
           -1.073027664702453,
           -1.097639524794224,
           -1.1219899759526881,
           -1.1460728683478472,
           -1.1698821410202698,
           -1.1934118205924156,
           -1.2166560203297931,
           -1.2396089394951013,
           -1.2622648629482462,
           -1.2846181609530465,
           -1.3066632891578618,
           -1.3283947887226473,
           -1.3498072865692656,
           -1.3708954957354458,
           -1.3916542158157428,
           -1.4120783334752978,
           -1.4321628230242638,
           -1.4519027470424668,
           -1.4712932570453268,
           -1.490329594183275,
           -1.50900708996794,
           -1.5273211670192497,
           -1.5452673398283392,
           -1.562841215531795,
           -1.5800384946933164,
           -1.5968549720893286,
           -1.6132865374955083,
           -1.6293291764715112,
           -1.64497897114151,
           -1.6602321009684016,
           -1.6750848435197816,
           -1.6895335752239786,
           -1.703574772114617,
           -1.7172050105623342,
           -1.7304209679924092,
           -1.743219423587181,
           -1.755597258972248,
           -1.7675514588855186,
           -1.7790791118282854,
           -1.790177410697554,
           -1.800843653398938,
           -1.8110752434394812,
           -1.8208696904998276,
           -1.8302246109852158,
           -1.8391377285547963,
           -1.8476068746288448,
           -1.855629988873446,
           -1.8632051196622843,
           -1.870330424515193,
           -1.8770041705131495,
           -1.883224734689425,
           -1.8889906043966285,
           -1.8943003776494074,
           -1.899152763442579,
           -1.9035465820445032,
           -1.9074807652655097,
           -1.9109543567012308,
           -1.9139665119506846,
           -1.9165164988089918,
           -1.918603697434615,
           -1.9202276004910228,
           -1.921387813262704,
           -1.922084053745466
          ],
          [
           -1.8913478499145011,
           -1.8911198713720405,
           -1.8904359914328037,
           -1.8892963771492082,
           -1.8877013069018866,
           -1.8856511703396326,
           -1.8831464682953998,
           -1.8801878126784242,
           -1.8767759263425723,
           -1.872911642931034,
           -1.8685959066974984,
           -1.8638297723039874,
           -1.8586144045955333,
           -1.8529510783519247,
           -1.8468411780167633,
           -1.8402861974041171,
           -1.8332877393830715,
           -1.8258475155405254,
           -1.8179673458226115,
           -1.8096491581551615,
           -1.8008949880436758,
           -1.7917069781533048,
           -1.782087377869408,
           -1.7720385428392917,
           -1.761562934495811,
           -1.7506631195635738,
           -1.739341769548556,
           -1.727601660212034,
           -1.7154456710298085,
           -1.7028767846378219,
           -1.6898980862653512,
           -1.6765127631571202,
           -1.6627241039857823,
           -1.6485354982564078,
           -1.6339504357047767,
           -1.6189725056914852,
           -1.6036053965940948,
           -1.587852895199831,
           -1.5717188861016076,
           -1.5552073511005162,
           -1.5383223686182876,
           -1.5210681131236876,
           -1.503448854577303,
           -1.4854689578997713,
           -1.4671328824691818,
           -1.4484451816541457,
           -1.4294105023899566,
           -1.4100335848063128,
           -1.3903192619162963,
           -1.3702724593777638,
           -1.3498981953399851,
           -1.32920158039036,
           -1.3081878176184008,
           -1.2868622028169545,
           -1.2652301248439504,
           -1.243297066171907,
           -1.2210686036571694,
           -1.1985504095665103,
           -1.17574825290559,
           -1.1526680011020418,
           -1.1293156221060279,
           -1.1056971869833991,
           -1.0818188730916547,
           -1.0576869679474656,
           -1.0333078739174961,
           -1.0086881138928316,
           -0.9838343381430724,
           -0.9587533325911066,
           -0.9334520288064518,
           -0.907937516087457,
           -0.8822170560954158,
           -0.85629810062331,
           -0.8301883132373874,
           -0.8038955957333481,
           -0.777428120617598,
           -0.7507943711816735,
           -0.7240031912183291,
           -0.6970638470792297,
           -0.6699861056666695,
           -0.6427803331877288,
           -0.6154576212308556,
           -0.5880299491807888,
           -0.560510395517074,
           -0.5329134156850264,
           -0.5052552118374279,
           -0.4775542311843767,
           -0.4498318471810216,
           -0.4221133050213538,
           -0.39442905614170526,
           -0.3668166764534946,
           -0.3393236787606555,
           -0.3120117250485197,
           -0.2849630798327658,
           -0.25829073037060424,
           -0.23215462121165034,
           -0.20678819608712037,
           -0.18254216743311008,
           -0.15995547822852046,
           -0.13986128265278458,
           -0.12350603786810706,
           -0.11255048287859502,
           -0.10865215008549892,
           -0.11255048287860289,
           -0.12350603786812141,
           -0.13986128265280354,
           -0.15995547822854256,
           -0.18254216743313428,
           -0.206788196087146,
           -0.2321546212116769,
           -0.25829073037063144,
           -0.2849630798327935,
           -0.31201172504854763,
           -0.33932367876068376,
           -0.3668166764535229,
           -0.3944290561417336,
           -0.4221133050213822,
           -0.4498318471810501,
           -0.47755423118440515,
           -0.5052552118374565,
           -0.5329134156850549,
           -0.5605103955171026,
           -0.588029949180817,
           -0.6154576212308837,
           -0.6427803331877567,
           -0.6699861056666975,
           -0.6970638470792575,
           -0.7240031912183567,
           -0.7507943711817009,
           -0.7774281206176252,
           -0.8038955957333753,
           -0.8301883132374144,
           -0.8562981006233367,
           -0.8822170560954423,
           -0.9079375160874833,
           -0.9334520288064779,
           -0.9587533325911325,
           -0.9838343381430981,
           -1.0086881138928572,
           -1.0333078739175212,
           -1.0576869679474905,
           -1.0818188730916793,
           -1.1056971869834238,
           -1.1293156221060523,
           -1.1526680011020654,
           -1.1757482529056136,
           -1.1985504095665336,
           -1.2210686036571923,
           -1.2432970661719296,
           -1.2652301248439726,
           -1.2868622028169765,
           -1.3081878176184225,
           -1.3292015803903816,
           -1.349898195340006,
           -1.3702724593777844,
           -1.3903192619163165,
           -1.410033584806333,
           -1.4294105023899764,
           -1.4484451816541648,
           -1.467132882469201,
           -1.48546895789979,
           -1.503448854577321,
           -1.5210681131237054,
           -1.5383223686183052,
           -1.555207351100533,
           -1.5717188861016245,
           -1.5878528951998476,
           -1.6036053965941108,
           -1.6189725056915005,
           -1.6339504357047918,
           -1.6485354982564224,
           -1.662724103985797,
           -1.6765127631571344,
           -1.6898980862653648,
           -1.702876784637835,
           -1.7154456710298214,
           -1.727601660212046,
           -1.7393417695485682,
           -1.7506631195635853,
           -1.761562934495822,
           -1.772038542839302,
           -1.782087377869418,
           -1.7917069781533144,
           -1.8008949880436849,
           -1.8096491581551704,
           -1.81796734582262,
           -1.8258475155405332,
           -1.833287739383079,
           -1.840286197404124,
           -1.8468411780167697,
           -1.8529510783519307,
           -1.858614404595539,
           -1.8638297723039925,
           -1.8685959066975033,
           -1.8729116429310382,
           -1.8767759263425763,
           -1.8801878126784275,
           -1.8831464682954027,
           -1.885651170339635,
           -1.8877013069018882,
           -1.8892963771492093,
           -1.8904359914328048,
           -1.8911198713720407
          ],
          [
           -1.8604846610560526,
           -1.8602609254319147,
           -1.8595897735885636,
           -1.858471370602289,
           -1.8569059915639357,
           -1.8548940215244951,
           -1.8524359554190473,
           -1.8495323979691545,
           -1.84618406356385,
           -1.8423917761193969,
           -1.8381564689180272,
           -1.8334791844259024,
           -1.8283610740905827,
           -1.822803398118325,
           -1.8168075252315734,
           -1.8103749324070615,
           -1.8035072045949714,
           -1.7962060344196702,
           -1.7884732218625898,
           -1.7803106739278733,
           -1.7717204042914865,
           -1.7627045329345554,
           -1.753265285761785,
           -1.743404994205877,
           -1.73312609481899,
           -1.7224311288523664,
           -1.711322741825378,
           -1.6998036830853789,
           -1.6878768053598827,
           -1.675545064302762,
           -1.6628115180363299,
           -1.6496793266913872,
           -1.6361517519475248,
           -1.622232156576247,
           -1.607924003989758,
           -1.5932308577985914,
           -1.5781563813816202,
           -1.5627043374724316,
           -1.5468785877664986,
           -1.5306830925541595,
           -1.5141219103850214,
           -1.4971991977701378,
           -1.479919208929125,
           -1.462286295590336,
           -1.444304906853314,
           -1.4259795891240057,
           -1.4073149861346965,
           -1.3883158390623362,
           -1.3689869867609255,
           -1.34933336612596,
           -1.3293600126116767,
           -1.3090720609250488,
           -1.2884747459242876,
           -1.267573403754084,
           -1.2463734732551526,
           -1.2248804976919876,
           -1.2031001268502983,
           -1.1810381195646957,
           -1.1587003467480992,
           -1.1360927950075494,
           -1.1132215709470994,
           -1.0900929062779403,
           -1.0667131638797318,
           -1.0430888449863682,
           -1.0192265977054968,
           -0.9951332271258683,
           -0.9708157073223734,
           -0.9462811956384949,
           -0.9215370497139302,
           -0.8965908478366936,
           -0.8714504133411883,
           -0.8461238439561864,
           -0.8206195472422839,
           -0.7949462835648672,
           -0.7691132184502225,
           -0.7431299867026967,
           -0.7170067713668007,
           -0.6907544015661125,
           -0.6643844745352561,
           -0.637909508918098,
           -0.6113431388324015,
           -0.5847003615893318,
           -0.5579978567377881,
           -0.5312544009285315,
           -0.5044914129495655,
           -0.4777336776903207,
           -0.4510103191032491,
           -0.4243561241309168,
           -0.39781336784197835,
           -0.37143436375195515,
           -0.3452850765706766,
           -0.3194503084993052,
           -0.294041233695389,
           -0.2692064398716408,
           -0.24514814436981208,
           -0.2221457514701003,
           -0.20058881508743606,
           -0.18101890044813926,
           -0.16417024236184158,
           -0.15097542114639959,
           -0.14246751607540087,
           -0.13951533894394746,
           -0.1424675160754069,
           -0.1509754211464109,
           -0.16417024236185718,
           -0.1810189004481581,
           -0.2005888150874573,
           -0.2221457514701233,
           -0.24514814436983634,
           -0.2692064398716659,
           -0.29404123369541485,
           -0.31945030849933154,
           -0.3452850765707034,
           -0.37143436375198213,
           -0.3978133678420056,
           -0.42435612413094415,
           -0.45101031910327655,
           -0.47773367769034825,
           -0.504491412949593,
           -0.5312544009285589,
           -0.5579978567378158,
           -0.5847003615893592,
           -0.6113431388324289,
           -0.6379095089181251,
           -0.664384474535283,
           -0.6907544015661394,
           -0.7170067713668276,
           -0.7431299867027236,
           -0.7691132184502492,
           -0.7949462835648937,
           -0.8206195472423101,
           -0.8461238439562125,
           -0.8714504133412142,
           -0.8965908478367196,
           -0.9215370497139558,
           -0.9462811956385202,
           -0.9708157073223986,
           -0.9951332271258932,
           -1.0192265977055217,
           -1.0430888449863929,
           -1.066713163879756,
           -1.090092906277964,
           -1.1132215709471234,
           -1.1360927950075728,
           -1.1587003467481223,
           -1.1810381195647186,
           -1.203100126850321,
           -1.2248804976920098,
           -1.2463734732551748,
           -1.2675734037541055,
           -1.2884747459243087,
           -1.3090720609250697,
           -1.3293600126116973,
           -1.3493333661259805,
           -1.3689869867609454,
           -1.388315839062356,
           -1.4073149861347158,
           -1.4259795891240246,
           -1.4443049068533325,
           -1.4622862955903542,
           -1.4799192089291429,
           -1.4971991977701555,
           -1.5141219103850387,
           -1.5306830925541766,
           -1.5468785877665154,
           -1.5627043374724476,
           -1.5781563813816357,
           -1.5932308577986065,
           -1.607924003989773,
           -1.6222321565762614,
           -1.6361517519475393,
           -1.649679326691401,
           -1.6628115180363432,
           -1.675545064302775,
           -1.6878768053598951,
           -1.6998036830853906,
           -1.7113227418253896,
           -1.7224311288523775,
           -1.7331260948190008,
           -1.743404994205887,
           -1.7532652857617947,
           -1.762704532934565,
           -1.7717204042914954,
           -1.780310673927882,
           -1.7884732218625976,
           -1.7962060344196775,
           -1.8035072045949785,
           -1.8103749324070686,
           -1.8168075252315796,
           -1.8228033981183307,
           -1.8283610740905882,
           -1.8334791844259075,
           -1.8381564689180314,
           -1.842391776119401,
           -1.8461840635638536,
           -1.8495323979691578,
           -1.8524359554190502,
           -1.8548940215244976,
           -1.8569059915639374,
           -1.8584713706022904,
           -1.8595897735885645,
           -1.8602609254319156
          ],
          [
           -1.8297564442775769,
           -1.829537075219973,
           -1.828879022485321,
           -1.82778244937856,
           -1.8262476280428137,
           -1.8242749394117967,
           -1.821864873143342,
           -1.819018027534189,
           -1.81573510941623,
           -1.8120169340344674,
           -1.8078644249069606,
           -1.8032786136671102,
           -1.798260639888677,
           -1.7928117508939796,
           -1.7869333015457922,
           -1.7806267540235072,
           -1.7738936775842156,
           -1.766735748309419,
           -1.7591547488381758,
           -1.7511525680875613,
           -1.742731200961436,
           -1.7338927480485922,
           -1.7246394153114937,
           -1.7149735137669262,
           -1.7048974591600285,
           -1.6944137716333263,
           -1.68352507539255,
           -1.672234098371228,
           -1.6605436718962436,
           -1.6484567303567803,
           -1.6359763108793535,
           -1.6231055530119205,
           -1.6098476984203856,
           -1.5962060906012052,
           -1.5821841746142202,
           -1.567785496840309,
           -1.553013704769023,
           -1.5378725468219554,
           -1.5223658722183273,
           -1.5064976308900462,
           -1.4902718734544342,
           -1.473692751253857,
           -1.4567645164726932,
           -1.4394915223434719,
           -1.4218782234556007,
           -1.403929176181952,
           -1.3856490392407221,
           -1.3670425744124537,
           -1.348114647435006,
           -1.3288702291026457,
           -1.309314396599366,
           -1.2894523351012035,
           -1.2692893396877605,
           -1.2488308176096141,
           -1.2280822909659104,
           -1.2070493998555205,
           -1.1857379060759485,
           -1.1641536974571074,
           -1.1423027929325844,
           -1.1201913484697112,
           -1.0978256640023258,
           -1.075212191537522,
           -1.0523575446410731,
           -1.0292685095470675,
           -1.0059520581874979,
           -0.982415363499526,
           -0.9586658174450035,
           -0.934711052272643,
           -0.9105589656732448,
           -0.8862177506295507,
           -0.8616959309537098,
           -0.8370024037491737,
           -0.8121464903462602,
           -0.7871379976634685,
           -0.7619872924694223,
           -0.7367053917033763,
           -0.7113040729109051,
           -0.6857960100423418,
           -0.6601949414515695,
           -0.6345158790718697,
           -0.6087753706457084,
           -0.5829918308482807,
           -0.5571859626019477,
           -0.5313812974507258,
           -0.5056048944441487,
           -0.4798882518535642,
           -0.4542685070484547,
           -0.42879002957972256,
           -0.40350655446570943,
           -0.3784840613123524,
           -0.353804685004525,
           -0.3295720479593975,
           -0.30591852577550027,
           -0.28301506333331355,
           -0.26108414188908113,
           -0.2404160927365794,
           -0.22138757660360522,
           -0.20447766310364965,
           -0.19027041647098925,
           -0.17942417549892867,
           -0.17258506318879716,
           -0.17024355572242306,
           -0.1725850631888019,
           -0.17942417549893785,
           -0.1902704164710022,
           -0.20447766310366572,
           -0.22138757660362376,
           -0.24041609273659992,
           -0.26108414188910306,
           -0.28301506333333654,
           -0.30591852577552425,
           -0.32957204795942213,
           -0.35380468500455015,
           -0.37848406131237794,
           -0.4035065544657353,
           -0.42879002957974865,
           -0.4542685070484809,
           -0.4798882518535907,
           -0.5056048944441752,
           -0.5313812974507522,
           -0.5571859626019743,
           -0.5829918308483072,
           -0.6087753706457348,
           -0.6345158790718961,
           -0.660194941451596,
           -0.6857960100423681,
           -0.7113040729109311,
           -0.7367053917034023,
           -0.7619872924694483,
           -0.7871379976634945,
           -0.8121464903462858,
           -0.837002403749199,
           -0.8616959309537352,
           -0.8862177506295759,
           -0.9105589656732698,
           -0.9347110522726676,
           -0.958665817445028,
           -0.98241536349955,
           -1.005952058187522,
           -1.0292685095470913,
           -1.0523575446410967,
           -1.0752121915375454,
           -1.097825664002349,
           -1.1201913484697341,
           -1.142302792932607,
           -1.1641536974571296,
           -1.1857379060759707,
           -1.2070493998555423,
           -1.2280822909659321,
           -1.2488308176096354,
           -1.2692893396877811,
           -1.289452335101224,
           -1.3093143965993863,
           -1.3288702291026657,
           -1.3481146474350258,
           -1.367042574412473,
           -1.3856490392407412,
           -1.4039291761819703,
           -1.4218782234556189,
           -1.4394915223434899,
           -1.4567645164727105,
           -1.473692751253874,
           -1.4902718734544511,
           -1.5064976308900628,
           -1.5223658722183437,
           -1.5378725468219714,
           -1.553013704769038,
           -1.5677854968403242,
           -1.5821841746142347,
           -1.5962060906012197,
           -1.6098476984203995,
           -1.6231055530119338,
           -1.6359763108793663,
           -1.6484567303567927,
           -1.6605436718962558,
           -1.6722340983712398,
           -1.6835250753925615,
           -1.6944137716333374,
           -1.704897459160039,
           -1.7149735137669357,
           -1.7246394153115032,
           -1.7338927480486013,
           -1.7427312009614448,
           -1.7511525680875697,
           -1.7591547488381833,
           -1.7667357483094266,
           -1.7738936775842225,
           -1.7806267540235137,
           -1.7869333015457982,
           -1.7928117508939854,
           -1.798260639888682,
           -1.803278613667115,
           -1.807864424906965,
           -1.8120169340344716,
           -1.8157351094162337,
           -1.8190180275341923,
           -1.821864873143345,
           -1.824274939411799,
           -1.8262476280428153,
           -1.8277824493785613,
           -1.828879022485322,
           -1.8295370752199736
          ],
          [
           -1.799192927144257,
           -1.798978049211264,
           -1.7983334693286899,
           -1.7972593492377964,
           -1.7957559584808667,
           -1.7938236743615752,
           -1.791462981889705,
           -1.7886744737104159,
           -1.7854588500183186,
           -1.7818169184566877,
           -1.7777495940021952,
           -1.7732578988356247,
           -1.7683429621990892,
           -1.7630060202403643,
           -1.7572484158450132,
           -1.751071598457079,
           -1.744477123889205,
           -1.7374666541231523,
           -1.730041957101781,
           -1.7222049065136904,
           -1.7139574815718424,
           -1.7053017667876218,
           -1.6962399517419644,
           -1.6867743308553307,
           -1.6769073031585142,
           -1.6666413720664714,
           -1.6559791451575911,
           -1.6449233339610931,
           -1.6334767537555195,
           -1.621642323381616,
           -1.6094230650732528,
           -1.596822104310448,
           -1.5838426696990056,
           -1.5704880928817941,
           -1.556761808487267,
           -1.542667354121489,
           -1.5282083704106602,
           -1.5133886011019766,
           -1.4982118932316184,
           -1.482682197369747,
           -1.466803567953631,
           -1.4505801637214455,
           -1.434016248260912,
           -1.4171161906888254,
           -1.3998844664796657,
           -1.3823256584639725,
           -1.36444445802005,
           -1.346245666485894,
           -1.3277341968221088,
           -1.3089150755611059,
           -1.289793445083141,
           -1.2703745662659296,
           -1.2506638215618338,
           -1.2306667185651587,
           -1.210388894142183,
           -1.1898361192085058,
           -1.1690143042524892,
           -1.1479295057205074,
           -1.126587933399954,
           -1.1049959589602514,
           -1.0831601258413508,
           -1.061087160714559,
           -1.0387839867833955,
           -1.0162577392443892,
           -0.9935157832915338,
           -0.9705657351264687,
           -0.9474154865330172,
           -0.9240732336943017,
           -0.9005475110793958,
           -0.8768472314123571,
           -0.8529817329699055,
           -0.828960835748594,
           -0.8047949084159676,
           -0.7804949484366451,
           -0.7560726783749793,
           -0.7315406621630317,
           -0.7069124461425075,
           -0.6822027310180113,
           -0.6574275825992906,
           -0.6326046915011094,
           -0.6077536949997189,
           -0.5828965782698543,
           -0.5580581775899062,
           -0.5332668152644012,
           -0.5085551055735221,
           -0.48396098378076574,
           -0.4595290270176313,
           -0.4353121576581478,
           -0.41137384723756265,
           -0.38779097157586423,
           -0.36465750206442804,
           -0.3420892436482521,
           -0.3202298216848617,
           -0.29925802326097917,
           -0.2793963075839985,
           -0.2609196315221456,
           -0.24416243547021146,
           -0.22951951371347962,
           -0.21743390069660629,
           -0.20836363091251806,
           -0.20272308218564059,
           -0.20080707285574295,
           -0.20272308218564453,
           -0.20836363091252566,
           -0.21743390069661725,
           -0.22951951371349338,
           -0.24416243547022765,
           -0.2609196315221638,
           -0.2793963075840183,
           -0.2992580232610002,
           -0.3202298216848838,
           -0.3420892436482749,
           -0.36465750206445163,
           -0.38779097157588827,
           -0.4113738472375871,
           -0.4353121576581725,
           -0.45952902701765636,
           -0.48396098378079094,
           -0.5085551055735476,
           -0.5332668152644267,
           -0.5580581775899318,
           -0.5828965782698797,
           -0.6077536949997444,
           -0.632604691501135,
           -0.657427582599316,
           -0.6822027310180367,
           -0.7069124461425328,
           -0.7315406621630571,
           -0.7560726783750044,
           -0.7804949484366701,
           -0.8047949084159923,
           -0.8289608357486188,
           -0.8529817329699301,
           -0.8768472314123816,
           -0.9005475110794201,
           -0.9240732336943257,
           -0.9474154865330412,
           -0.9705657351264925,
           -0.9935157832915574,
           -1.0162577392444125,
           -1.0387839867834188,
           -1.061087160714582,
           -1.0831601258413734,
           -1.1049959589602738,
           -1.126587933399976,
           -1.147929505720529,
           -1.1690143042525107,
           -1.1898361192085272,
           -1.210388894142204,
           -1.2306667185651794,
           -1.2506638215618542,
           -1.2703745662659496,
           -1.2897934450831605,
           -1.3089150755611254,
           -1.327734196822128,
           -1.346245666485913,
           -1.3644444580200685,
           -1.3823256584639905,
           -1.3998844664796837,
           -1.417116190688843,
           -1.434016248260929,
           -1.4505801637214624,
           -1.4668035679536475,
           -1.4826821973697633,
           -1.4982118932316342,
           -1.5133886011019921,
           -1.5282083704106753,
           -1.5426673541215035,
           -1.5567618084872812,
           -1.570488092881808,
           -1.5838426696990198,
           -1.596822104310461,
           -1.6094230650732655,
           -1.6216423233816286,
           -1.6334767537555317,
           -1.6449233339611045,
           -1.6559791451576025,
           -1.6666413720664823,
           -1.6769073031585244,
           -1.6867743308553405,
           -1.696239951741974,
           -1.7053017667876307,
           -1.713957481571851,
           -1.7222049065136988,
           -1.7300419571017889,
           -1.7374666541231598,
           -1.744477123889212,
           -1.7510715984570853,
           -1.7572484158450195,
           -1.7630060202403701,
           -1.768342962199094,
           -1.7732578988356293,
           -1.7777495940021997,
           -1.7818169184566914,
           -1.785458850018322,
           -1.788674473710419,
           -1.791462981889708,
           -1.7938236743615772,
           -1.7957559584808684,
           -1.7972593492377977,
           -1.7983334693286905,
           -1.7989780492112648
          ],
          [
           -1.768823677885006,
           -1.7686134162648366,
           -1.7679826848682982,
           -1.7669316440811527,
           -1.765460561192537,
           -1.7635698103643949,
           -1.7612598725889375,
           -1.7585313356343901,
           -1.755384893979362,
           -1.7518213487362584,
           -1.7478416075642327,
           -1.74344668457226,
           -1.7386377002130258,
           -1.7334158811683902,
           -1.7277825602273194,
           -1.7217391761572765,
           -1.7152872735701818,
           -1.7084285027841861,
           -1.7011646196826453,
           -1.6934974855718299,
           -1.6854290670390755,
           -1.6769614358132663,
           -1.6680967686297408,
           -1.6588373471019326,
           -1.649185557602307,
           -1.6391438911554255,
           -1.6287149433462709,
           -1.6179014142472992,
           -1.6067061083680676,
           -1.5951319346316921,
           -1.5831819063828663,
           -1.5708591414326913,
           -1.5581668621461584,
           -1.5451083955787774,
           -1.531687173669603,
           -1.5179067334987493,
           -1.5037707176184216,
           -1.4892828744675963,
           -1.4744470588816854,
           -1.4592672327099323,
           -1.4437474655548652,
           -1.4278919356499555,
           -1.4117049308937075,
           -1.3951908500607852,
           -1.3783542042135355,
           -1.361199618340399,
           -1.3437318332513732,
           -1.3259557077648831,
           -1.3078762212253106,
           -1.289498476396118,
           -1.2708277027801114,
           -1.2518692604261257,
           -1.2326286442904533,
           -1.2131114892319799,
           -1.1933235757324825,
           -1.173270836448317,
           -1.1529593637172053,
           -1.132395418164566,
           -1.111585438578562,
           -1.0905360532525388,
           -1.0692540930288994,
           -1.0477466063209817,
           -1.0260208764407903,
           -1.0040844416225059,
           -0.9819451182071051,
           -0.9596110275453328,
           -0.9370906272887325,
           -0.914392747876566,
           -0.891526635196734,
           -0.8685020006095711,
           -0.8453290797852525,
           -0.8220187021322258,
           -0.7985823730031807,
           -0.7750323713793994,
           -0.751381866383416,
           -0.727645056791971,
           -0.7038373387659164,
           -0.6799755083451209,
           -0.6560780069572982,
           -0.6321652203658912,
           -0.6082598442675206,
           -0.5843873333098799,
           -0.5605764548347808,
           -0.5368599743818142,
           -0.5132755071380543,
           -0.48986657824495,
           -0.46668394512614897,
           -0.4437872462425822,
           -0.42124705134452706,
           -0.39914739476940786,
           -0.37758886822474064,
           -0.3566923187013234,
           -0.336603115649757,
           -0.317495778463767,
           -0.2995784320427257,
           -0.2830960200378134,
           -0.2683304293674949,
           -0.25559480086063013,
           -0.24521880127332674,
           -0.23752246495676277,
           -0.2327794646468593,
           -0.23117632211499411,
           -0.2327794646468626,
           -0.2375224649567692,
           -0.2452188012733361,
           -0.25559480086064207,
           -0.268330429367509,
           -0.2830960200378296,
           -0.2995784320427435,
           -0.317495778463786,
           -0.33660311564977724,
           -0.35669231870134455,
           -0.3775888682247625,
           -0.3991473947694303,
           -0.42124705134455004,
           -0.44378724624260557,
           -0.4666839451261728,
           -0.48986657824497404,
           -0.5132755071380786,
           -0.5368599743818385,
           -0.5605764548348053,
           -0.5843873333099044,
           -0.608259844267545,
           -0.6321652203659157,
           -0.6560780069573228,
           -0.6799755083451454,
           -0.7038373387659409,
           -0.7276450567919953,
           -0.7513818663834403,
           -0.7750323713794237,
           -0.7985823730032047,
           -0.8220187021322499,
           -0.8453290797852763,
           -0.8685020006095948,
           -0.8915266351967576,
           -0.9143927478765894,
           -0.9370906272887557,
           -0.9596110275453558,
           -0.9819451182071278,
           -1.0040844416225285,
           -1.0260208764408127,
           -1.0477466063210041,
           -1.0692540930289214,
           -1.0905360532525605,
           -1.1115854385785833,
           -1.1323954181645872,
           -1.1529593637172262,
           -1.173270836448338,
           -1.193323575732503,
           -1.213111489232,
           -1.2326286442904733,
           -1.2518692604261452,
           -1.2708277027801307,
           -1.2894984763961368,
           -1.3078762212253292,
           -1.3259557077649016,
           -1.3437318332513912,
           -1.3611996183404165,
           -1.3783542042135528,
           -1.3951908500608026,
           -1.4117049308937237,
           -1.4278919356499722,
           -1.4437474655548812,
           -1.4592672327099483,
           -1.474447058881701,
           -1.4892828744676114,
           -1.5037707176184365,
           -1.5179067334987635,
           -1.5316871736696167,
           -1.5451083955787908,
           -1.558166862146172,
           -1.5708591414327042,
           -1.5831819063828783,
           -1.5951319346317039,
           -1.6067061083680794,
           -1.6179014142473105,
           -1.628714943346282,
           -1.6391438911554361,
           -1.649185557602317,
           -1.6588373471019422,
           -1.6680967686297503,
           -1.6769614358132752,
           -1.6854290670390837,
           -1.6934974855718379,
           -1.7011646196826529,
           -1.708428502784193,
           -1.7152872735701885,
           -1.721739176157283,
           -1.7277825602273253,
           -1.7334158811683957,
           -1.738637700213031,
           -1.7434466845722647,
           -1.747841607564237,
           -1.7518213487362628,
           -1.7553848939793653,
           -1.7585313356343932,
           -1.7612598725889401,
           -1.7635698103643966,
           -1.7654605611925382,
           -1.7669316440811538,
           -1.7679826848682991,
           -1.7686134162648368
          ],
          [
           -1.7386780767871148,
           -1.7384725569785728,
           -1.737856050633068,
           -1.7368287169868275,
           -1.735390821419807,
           -1.7335427354352166,
           -1.7312849366311749,
           -1.728618008664821,
           -1.725542641209287,
           -1.7220596299040685,
           -1.7181698762994049,
           -1.7138743877954024,
           -1.709174277576746,
           -1.7040707645439745,
           -1.6985651732424076,
           -1.6926589337899745,
           -1.6863535818053181,
           -1.6796507583377405,
           -1.6725522098007028,
           -1.6650597879108044,
           -1.657175449634368,
           -1.6489012571439814,
           -1.6402393777876105,
           -1.6311920840731657,
           -1.62176175367171,
           -1.611950869442845,
           -1.6017620194861726,
           -1.5911978972231633,
           -1.5802613015142084,
           -1.5689551368161725,
           -1.557282413386321,
           -1.5452462475391588,
           -1.532849861963446,
           -1.5200965861074591,
           -1.5069898566414988,
           -1.4935332180076843,
           -1.4797303230682328,
           -1.465584933864767,
           -1.4511009225026767,
           -1.436282272176294,
           -1.4211330783525604,
           -1.4056575501330972,
           -1.3898600118171158,
           -1.3737449046904995,
           -1.3573167890697162,
           -1.340580346633033,
           -1.3235403830758994,
           -1.3062018311324426,
           -1.2885697540108698,
           -1.2706493492973798,
           -1.252445953391067,
           -1.233965046541489,
           -1.215212258571293,
           -1.1961933753788156,
           -1.176914346330289,
           -1.1573812926685392,
           -1.1376005170854375,
           -1.1175785146294077,
           -1.097321985147791,
           -1.0768378474977212,
           -1.0561332557994838,
           -1.0352156180545067,
           -1.0140926175078395,
           -0.9927722372043247,
           -0.9712627882712311,
           -0.9495729425611193,
           -0.9277117704111617,
           -0.9056887844240074,
           -0.8835139903568305,
           -0.8611979464272111,
           -0.8387518326167467,
           -0.816187531888033,
           -0.7935177256431943,
           -0.7707560062616595,
           -0.7479170101852128,
           -0.7250165757990514,
           -0.7020719313248897,
           -0.6791019191398774,
           -0.6561272644151043,
           -0.6331708977888345,
           -0.6102583440157172,
           -0.5874181912240529,
           -0.5646826586094486,
           -0.542088284085346,
           -0.5196767574822472,
           -0.4974959290126743,
           -0.47560102618980676,
           -0.4540561138227307,
           -0.43293582859163676,
           -0.41232740767722575,
           -0.392333002831457,
           -0.3730722161044706,
           -0.35468469561918975,
           -0.3373324704505834,
           -0.321201466951016,
           -0.30650133840785204,
           -0.2934624110028499,
           -0.28232835348881613,
           -0.2733433922773871,
           -0.2667338552374925,
           -0.26268568838862255,
           -0.2613219232128851,
           -0.2626856883886254,
           -0.266733855237498,
           -0.2733433922773951,
           -0.28232835348882646,
           -0.29346241100286236,
           -0.3065013384078664,
           -0.32120146695103186,
           -0.33733247045060066,
           -0.3546846956192082,
           -0.37307221610449004,
           -0.3923330028314772,
           -0.4123274076772466,
           -0.43293582859165824,
           -0.45405611382275274,
           -0.47560102618982913,
           -0.49749592901269696,
           -0.5196767574822702,
           -0.5420882840853692,
           -0.5646826586094719,
           -0.5874181912240765,
           -0.6102583440157406,
           -0.6331708977888582,
           -0.6561272644151278,
           -0.6791019191399009,
           -0.7020719313249132,
           -0.725016575799075,
           -0.7479170101852363,
           -0.7707560062616831,
           -0.7935177256432177,
           -0.8161875318880564,
           -0.8387518326167699,
           -0.861197946427234,
           -0.8835139903568533,
           -0.90568878442403,
           -0.9277117704111844,
           -0.9495729425611418,
           -0.9712627882712533,
           -0.9927722372043468,
           -1.014092617507861,
           -1.0352156180545284,
           -1.0561332557995053,
           -1.0768378474977423,
           -1.097321985147812,
           -1.1175785146294284,
           -1.137600517085458,
           -1.1573812926685596,
           -1.176914346330309,
           -1.1961933753788354,
           -1.2152122585713123,
           -1.2339650465415082,
           -1.2524459533910854,
           -1.2706493492973985,
           -1.288569754010888,
           -1.3062018311324606,
           -1.3235403830759171,
           -1.3405803466330504,
           -1.3573167890697335,
           -1.3737449046905161,
           -1.389860011817132,
           -1.4056575501331132,
           -1.4211330783525762,
           -1.4362822721763095,
           -1.4511009225026916,
           -1.4655849338647817,
           -1.4797303230682473,
           -1.493533218007698,
           -1.5069898566415123,
           -1.5200965861074722,
           -1.5328498619634594,
           -1.545246247539171,
           -1.557282413386333,
           -1.5689551368161843,
           -1.58026130151422,
           -1.5911978972231742,
           -1.6017620194861835,
           -1.6119508694428555,
           -1.6217617536717202,
           -1.6311920840731753,
           -1.6402393777876196,
           -1.6489012571439896,
           -1.6571754496343762,
           -1.6650597879108122,
           -1.6725522098007104,
           -1.6796507583377476,
           -1.686353581805325,
           -1.692658933789981,
           -1.6985651732424134,
           -1.7040707645439799,
           -1.709174277576751,
           -1.713874387795407,
           -1.7181698762994093,
           -1.7220596299040722,
           -1.7255426412092905,
           -1.7286180086648242,
           -1.7312849366311778,
           -1.7335427354352184,
           -1.7353908214198086,
           -1.7368287169868288,
           -1.737856050633069,
           -1.7384725569785733
          ],
          [
           -1.7087852877727236,
           -1.7085846352226046,
           -1.7079827303353632,
           -1.7069797313983996,
           -1.7055759022176296,
           -1.7037716121080413,
           -1.7015673358808754,
           -1.698963653827798,
           -1.6959612517025864,
           -1.6925609207009615,
           -1.6887635574393012,
           -1.6845701639331458,
           -1.6799818475765047,
           -1.6749998211231445,
           -1.6696254026711894,
           -1.6638600156525345,
           -1.657705188828752,
           -1.6511625562953685,
           -1.6442338574966089,
           -1.6369209372529197,
           -1.6292257458038573,
           -1.6211503388691835,
           -1.6126968777313309,
           -1.6038676293427234,
           -1.5946649664618113,
           -1.5850913678220875,
           -1.5751494183387962,
           -1.5648418093585643,
           -1.5541713389577136,
           -1.543140912295666,
           -1.5317535420305177,
           -1.5200123488046535,
           -1.5079205618091285,
           -1.495481519436522,
           -1.482698670033064,
           -1.4695755727620583,
           -1.4561158985920313,
           -1.442323431424586,
           -1.4282020693787227,
           -1.4137558262504095,
           -1.398988833168455,
           -1.3839053404703447,
           -1.3685097198246534,
           -1.3528064666300388,
           -1.3368002027246744,
           -1.320495679444411,
           -1.3038977810730439,
           -1.2870115287338992,
           -1.269842084778699,
           -1.2523947577374346,
           -1.2346750079019813,
           -1.2166884536266238,
           -1.1984408784407743,
           -1.179938239083296,
           -1.1611866745842951,
           -1.142192516539526,
           -1.122962300745108,
           -1.1035027803867885,
           -1.083820941009193,
           -1.063924017527357,
           -1.0438195135864063,
           -1.0235152236269216,
           -1.0030192580749016,
           -0.9823400721483564,
           -0.9614864988598182,
           -0.940467786898427,
           -0.9192936442003578,
           -0.8979742881665874,
           -0.8765205036677329,
           -0.8549437101934537,
           -0.8332560397665694,
           -0.8114704275591748,
           -0.78960071753096,
           -0.7676617858721997,
           -0.7456696855910951,
           -0.7236418162551552,
           -0.7015971236985031,
           -0.6795563354612029,
           -0.6575422388506024,
           -0.6355800098191632,
           -0.6136976023339532,
           -0.5919262095362706,
           -0.5703008096690161,
           -0.5488608113064143,
           -0.5276508135256294,
           -0.5067214967379489,
           -0.48613065799110267,
           -0.4659443991306087,
           -0.4462384649081141,
           -0.4270997074917641,
           -0.40862761912574136,
           -0.3909358200409304,
           -0.37415330820672,
           -0.35842516799119367,
           -0.343912301754706,
           -0.33078961560088455,
           -0.31924201180434897,
           -0.30945760630600544,
           -0.30161791213581746,
           -0.2958853852461819,
           -0.29238965885845336,
           -0.29121471222727646,
           -0.29238965885845575,
           -0.2958853852461867,
           -0.30161791213582445,
           -0.3094576063060145,
           -0.3192420118043599,
           -0.33078961560089726,
           -0.34391230175472026,
           -0.35842516799120927,
           -0.3741533082067367,
           -0.3909358200409482,
           -0.40862761912575996,
           -0.4270997074917834,
           -0.446238464908134,
           -0.4659443991306292,
           -0.4861306579911236,
           -0.5067214967379703,
           -0.5276508135256511,
           -0.5488608113064362,
           -0.5703008096690384,
           -0.5919262095362928,
           -0.6136976023339755,
           -0.6355800098191857,
           -0.6575422388506249,
           -0.6795563354612254,
           -0.7015971236985259,
           -0.7236418162551779,
           -0.7456696855911177,
           -0.7676617858722222,
           -0.7896007175309823,
           -0.8114704275591972,
           -0.8332560397665917,
           -0.854943710193476,
           -0.876520503667755,
           -0.8979742881666093,
           -0.9192936442003797,
           -0.9404677868984486,
           -0.9614864988598397,
           -0.9823400721483777,
           -1.0030192580749226,
           -1.023515223626943,
           -1.0438195135864272,
           -1.0639240175273774,
           -1.0838209410092132,
           -1.1035027803868085,
           -1.122962300745128,
           -1.1421925165395457,
           -1.1611866745843147,
           -1.179938239083315,
           -1.1984408784407932,
           -1.2166884536266422,
           -1.2346750079019995,
           -1.2523947577374526,
           -1.2698420847787169,
           -1.2870115287339168,
           -1.303897781073061,
           -1.3204956794444278,
           -1.3368002027246908,
           -1.352806466630055,
           -1.3685097198246694,
           -1.3839053404703605,
           -1.3989888331684706,
           -1.4137558262504244,
           -1.4282020693787374,
           -1.4423234314246007,
           -1.4561158985920455,
           -1.4695755727620714,
           -1.4826986700330769,
           -1.4954815194365352,
           -1.5079205618091414,
           -1.520012348804666,
           -1.5317535420305297,
           -1.5431409122956776,
           -1.554171338957725,
           -1.564841809358575,
           -1.5751494183388068,
           -1.5850913678220977,
           -1.594664966461821,
           -1.6038676293427327,
           -1.61269687773134,
           -1.621150338869192,
           -1.6292257458038655,
           -1.6369209372529272,
           -1.644233857496616,
           -1.6511625562953753,
           -1.6577051888287582,
           -1.6638600156525407,
           -1.6696254026711952,
           -1.67499982112315,
           -1.6799818475765096,
           -1.6845701639331503,
           -1.6887635574393052,
           -1.692560920700965,
           -1.69596125170259,
           -1.6989636538278006,
           -1.7015673358808778,
           -1.7037716121080433,
           -1.7055759022176304,
           -1.706979731398401,
           -1.7079827303353643,
           -1.7085846352226057
          ],
          [
           -1.679174230184608,
           -1.6789785698787643,
           -1.6783916414713091,
           -1.6774136024928932,
           -1.6760447154960607,
           -1.6742853480576705,
           -1.6721359727827423,
           -1.6695971673101933,
           -1.6666696143210584,
           -1.6633541015499547,
           -1.6596515218006613,
           -1.6555628729668836,
           -1.6510892580594023,
           -1.6462318852409994,
           -1.6409920678707384,
           -1.6353712245593688,
           -1.6293708792378385,
           -1.6229926612411405,
           -1.616238305409956,
           -1.6091096522128363,
           -1.6016086478919607,
           -1.5937373446358378,
           -1.5854979007826555,
           -1.576892581058407,
           -1.5679237568543174,
           -1.5585939065485948,
           -1.5489056158780514,
           -1.5388615783657125,
           -1.528464595811195,
           -1.5177175788513515,
           -1.5066235475994678,
           -1.4951856323722243,
           -1.4834070745146075,
           -1.4712912273340941,
           -1.4588415571566908,
           -1.4460616445188186,
           -1.4329551855106286,
           -1.4195259932881283,
           -1.4057779997735242,
           -1.3917152575654665,
           -1.37734194208349,
           -1.3626623539738663,
           -1.3476809218074426,
           -1.3324022051038242,
           -1.3168308977206071,
           -1.300971831651303,
           -1.2848299812812636,
           -1.268410468157392,
           -1.2517185663348704,
           -1.234759708372691,
           -1.2175394920596228,
           -1.2000636879636364,
           -1.182338247910925,
           -1.1643693145159164,
           -1.1461632319013004,
           -1.1277265577676514,
           -1.1090660769961103,
           -1.0901888169954912,
           -1.071102065037761,
           -1.0518133878639933,
           -1.0323306538876438,
           -1.0126620583745445,
           -0.9928161520408378,
           -0.97280187358292,
           -0.9526285867393666,
           -0.9323061225862945,
           -0.9118448278875196,
           -0.8912556204626885,
           -0.8705500527042809,
           -0.8497403845726678,
           -0.8288396676326268,
           -0.8078618419708204,
           -0.7868218481583263,
           -0.7657357568021835,
           -0.7446209186716973,
           -0.7234961388944164,
           -0.7023818792959315,
           -0.6813004936043561,
           -0.6602765009423331,
           -0.6393369037584871,
           -0.6185115570519325,
           -0.5978335963220719,
           -0.5773399319717831,
           -0.5570718176494407,
           -0.537075498837081,
           -0.5174029452809608,
           -0.4981126657463056,
           -0.4792705948407624,
           -0.4609510276694986,
           -0.44323755686375943,
           -0.4262239359155469,
           -0.41001475104982776,
           -0.39472573104707437,
           -0.3804834642827445,
           -0.3674242354601611,
           -0.3556916620046311,
           -0.3454328345324344,
           -0.33679278726159967,
           -0.3299073749789821,
           -0.32489501032326334,
           -0.3218481501913122,
           -0.3208257698153919,
           -0.32184815019131435,
           -0.32489501032326756,
           -0.3299073749789882,
           -0.33679278726160766,
           -0.34543283453244417,
           -0.35569166200464253,
           -0.36742423546017394,
           -0.3804834642827585,
           -0.39472573104708963,
           -0.4100147510498441,
           -0.426223935915564,
           -0.4432375568637772,
           -0.4609510276695172,
           -0.47927059484078155,
           -0.4981126657463252,
           -0.5174029452809809,
           -0.5370754988371013,
           -0.5570718176494613,
           -0.5773399319718042,
           -0.597833596322093,
           -0.6185115570519538,
           -0.6393369037585085,
           -0.6602765009423547,
           -0.6813004936043776,
           -0.7023818792959533,
           -0.723496138894438,
           -0.744620918671719,
           -0.7657357568022052,
           -0.7868218481583481,
           -0.8078618419708419,
           -0.8288396676326484,
           -0.8497403845726892,
           -0.8705500527043021,
           -0.8912556204627097,
           -0.9118448278875406,
           -0.9323061225863155,
           -0.9526285867393876,
           -0.9728018735829406,
           -0.9928161520408585,
           -1.0126620583745647,
           -1.0323306538876642,
           -1.051813387864013,
           -1.0711020650377805,
           -1.0901888169955107,
           -1.1090660769961296,
           -1.1277265577676705,
           -1.1461632319013193,
           -1.1643693145159348,
           -1.1823382479109432,
           -1.2000636879636544,
           -1.2175394920596405,
           -1.2347597083727082,
           -1.2517185663348878,
           -1.268410468157409,
           -1.2848299812812805,
           -1.3009718316513195,
           -1.3168308977206233,
           -1.3324022051038398,
           -1.347680921807458,
           -1.3626623539738816,
           -1.377341942083505,
           -1.3917152575654814,
           -1.4057779997735382,
           -1.419525993288142,
           -1.4329551855106422,
           -1.446061644518832,
           -1.4588415571567042,
           -1.4712912273341068,
           -1.48340707451462,
           -1.4951856323722363,
           -1.5066235475994794,
           -1.5177175788513628,
           -1.5284645958112062,
           -1.5388615783657227,
           -1.5489056158780616,
           -1.5585939065486047,
           -1.5679237568543267,
           -1.5768925810584158,
           -1.5854979007826642,
           -1.5937373446358458,
           -1.6016086478919684,
           -1.6091096522128434,
           -1.6162383054099632,
           -1.6229926612411472,
           -1.6293708792378445,
           -1.635371224559375,
           -1.6409920678707437,
           -1.6462318852410045,
           -1.651089258059407,
           -1.655562872966888,
           -1.659651521800665,
           -1.6633541015499582,
           -1.6666696143210618,
           -1.669597167310196,
           -1.672135972782745,
           -1.6742853480576725,
           -1.676044715496062,
           -1.677413602492894,
           -1.6783916414713098,
           -1.6789785698787647
          ],
          [
           -1.649873550808585,
           -1.6496830068133512,
           -1.6491114271445573,
           -1.6481589687558407,
           -1.646825893246389,
           -1.6451125668758912,
           -1.643019460586001,
           -1.6405471500288478,
           -1.6376963156032884,
           -1.6344677424997682,
           -1.6308623207548145,
           -1.6268810453163878,
           -1.6225250161214861,
           -1.617795438187615,
           -1.6126936217199344,
           -1.6072209822361427,
           -1.601379040711386,
           -1.595169423745751,
           -1.588593863757202,
           -1.58165419920311,
           -1.5743523748338808,
           -1.566690441982557,
           -1.5586705588946634,
           -1.5502949911030335,
           -1.541566111852822,
           -1.532486402582467,
           -1.523058453466954,
           -1.5132849640304027,
           -1.5031687438357184,
           -1.492712713259879,
           -1.4819199043643214,
           -1.4707934618709073,
           -1.459336644255067,
           -1.4475528249689853,
           -1.4354454938090873,
           -1.4230182584436721,
           -1.4102748461183023,
           -1.3972191055585454,
           -1.3838550090919077,
           -1.3701866550133135,
           -1.3562182702213432,
           -1.3419542131556499,
           -1.3273989770696266,
           -1.3125571936765266,
           -1.2974336372119375,
           -1.2820332289608325,
           -1.266361042303517,
           -1.2504223083417132,
           -1.234222422173939,
           -1.2177669498984145,
           -1.2010616364320856,
           -1.1841124142462898,
           -1.1669254131332512,
           -1.1495069711333599,
           -1.131863646771323,
           -1.114002232770225,
           -1.0959297714367278,
           -1.077653571938635,
           -1.0591812297284622,
           -1.0405206484042526,
           -1.0216800643425012,
           -1.0026680744887237,
           -0.9834936677500904,
           -0.9641662605029976,
           -0.944695736808035,
           -0.9250924940172726,
           -0.9053674945661773,
           -0.885532324866961,
           -0.8655992623641783,
           -0.8455813519794882,
           -0.8254924933631391,
           -0.8053475405872554,
           -0.785162416162052,
           -0.764954241531119,
           -0.7447414865042801,
           -0.724544140411026,
           -0.7043839080934146,
           -0.6842844341851387,
           -0.6642715594107192,
           -0.6443736128335037,
           -0.6246217440032052,
           -0.6050502986827,
           -0.5856972410932758,
           -0.5666046241552133,
           -0.5478191066654721,
           -0.5293925122736334,
           -0.5113824188814045,
           -0.4938527579602553,
           -0.47687439044307317,
           -0.4605256085616527,
           -0.4448924909136683,
           -0.4300690116985085,
           -0.41615677671860996,
           -0.4032642334010368,
           -0.39150518848840044,
           -0.3809964779585228,
           -0.3718546845047546,
           -0.36419190190660217,
           -0.358110706054426,
           -0.35369869231078294,
           -0.3510231347253015,
           -0.3501264491914149,
           -0.35102313472530333,
           -0.35369869231078654,
           -0.35811070605443146,
           -0.3641919019066092,
           -0.37185468450476333,
           -0.3809964779585329,
           -0.39150518848841187,
           -0.4032642334010495,
           -0.41615677671862383,
           -0.43006901169852324,
           -0.4448924909136839,
           -0.4605256085616692,
           -0.4768743904430903,
           -0.4938527579602731,
           -0.5113824188814228,
           -0.5293925122736524,
           -0.5478191066654912,
           -0.5666046241552327,
           -0.5856972410932958,
           -0.6050502986827202,
           -0.6246217440032253,
           -0.644373612833524,
           -0.6642715594107397,
           -0.6842844341851593,
           -0.7043839080934352,
           -0.7245441404110468,
           -0.7447414865043007,
           -0.7649542415311399,
           -0.7851624161620726,
           -0.8053475405872761,
           -0.8254924933631598,
           -0.8455813519795089,
           -0.8655992623641988,
           -0.8855323248669814,
           -0.9053674945661978,
           -0.9250924940172927,
           -0.9446957368080551,
           -0.9641662605030175,
           -0.9834936677501103,
           -1.0026680744887435,
           -1.0216800643425208,
           -1.040520648404272,
           -1.0591812297284815,
           -1.077653571938654,
           -1.0959297714367466,
           -1.1140022327702435,
           -1.1318636467713412,
           -1.1495069711333779,
           -1.1669254131332687,
           -1.184112414246307,
           -1.201061636432103,
           -1.2177669498984316,
           -1.234222422173956,
           -1.2504223083417296,
           -1.2663610423035334,
           -1.2820332289608483,
           -1.2974336372119535,
           -1.3125571936765421,
           -1.3273989770696415,
           -1.3419542131556648,
           -1.3562182702213577,
           -1.3701866550133277,
           -1.3838550090919215,
           -1.3972191055585592,
           -1.4102748461183157,
           -1.4230182584436848,
           -1.4354454938091,
           -1.4475528249689975,
           -1.4593366442550793,
           -1.4707934618709189,
           -1.4819199043643325,
           -1.4927127132598899,
           -1.5031687438357288,
           -1.5132849640304127,
           -1.5230584534669638,
           -1.5324864025824767,
           -1.5415661118528314,
           -1.5502949911030421,
           -1.5586705588946719,
           -1.5666904419825647,
           -1.5743523748338886,
           -1.581654199203117,
           -1.588593863757209,
           -1.5951694237457574,
           -1.601379040711392,
           -1.6072209822361485,
           -1.6126936217199395,
           -1.6177954381876198,
           -1.6225250161214906,
           -1.6268810453163915,
           -1.6308623207548183,
           -1.6344677424997718,
           -1.6376963156032918,
           -1.6405471500288504,
           -1.6430194605860036,
           -1.6451125668758932,
           -1.6468258932463902,
           -1.6481589687558418,
           -1.6491114271445582,
           -1.649683006813352
          ],
          [
           -1.6209115961595966,
           -1.6207262911103486,
           -1.620170428140774,
           -1.6192441637908928,
           -1.617947758979189,
           -1.6162815790305933,
           -1.6142460937162562,
           -1.611841877305725,
           -1.609069608632316,
           -1.6059300711726556,
           -1.6024241531415666,
           -1.5985528476036752,
           -1.594317252603331,
           -1.5897185713146618,
           -1.5847581122138215,
           -1.579437289275755,
           -1.5737576221980742,
           -1.567720736654941,
           -1.561328364584183,
           -1.5545823445111975,
           -1.5474846219136102,
           -1.5400372496310346,
           -1.5322423883247653,
           -1.5241023069927127,
           -1.5156193835454395,
           -1.5067961054497643,
           -1.497635070447051,
           -1.4881389873540412,
           -1.4783106769548868,
           -1.4681530729939474,
           -1.4576692232798962,
           -1.4468622909127915,
           -1.435735555647,
           -1.42429241540422,
           -1.4125363879523853,
           -1.4004711127679368,
           -1.38810035310086,
           -1.3754279982640196,
           -1.3624580661707346,
           -1.3491947061472214,
           -1.3356422020495733,
           -1.3218049757183588,
           -1.3076875908077723,
           -1.2932947570306126,
           -1.278631334865297,
           -1.2637023407766597,
           -1.2485129530086123,
           -1.2330685180138763,
           -1.2173745575941362,
           -1.2014367768332068,
           -1.1852610729163116,
           -1.1688535449405841,
           -1.152220504835568,
           -1.1353684895281253,
           -1.1183042745040184,
           -1.1010348889388613,
           -1.0835676325945178,
           -1.0659100947038105,
           -1.0480701750970807,
           -1.0300561078593053,
           -1.0118764878467557,
           -0.9935403004383183,
           -0.9750569549494069,
           -0.9564363221967258,
           -0.9376887767710189,
           -0.9188252446532834,
           -0.899857256898801,
           -0.8807970102136626,
           -0.8616574353610089,
           -0.8424522744594491,
           -0.823196168373911,
           -0.8039047555484942,
           -0.7845947837892684,
           -0.7652842366677135,
           -0.7459924763747889,
           -0.7267404049988947,
           -0.7075506463090292,
           -0.6884477501686274,
           -0.6694584216442379,
           -0.6506117766469667,
           -0.6319396254704895,
           -0.6134767847537469,
           -0.5952614170471432,
           -0.5773353951004447,
           -0.5597446849707415,
           -0.5425397377744509,
           -0.5257758740529664,
           -0.5095136369749016,
           -0.49381908074534625,
           -0.4787639486660153,
           -0.4644256817932125,
           -0.4508871853573158,
           -0.4382362684606327,
           -0.4265646669225628,
           -0.41596656482759303,
           -0.40653655359969804,
           -0.3983670139171719,
           -0.3915449778826607,
           -0.3861486223205339,
           -0.38224364516503717,
           -0.3798798623178239,
           -0.3790884038404034,
           -0.37987986231782545,
           -0.38224364516504034,
           -0.3861486223205386,
           -0.39154497788266696,
           -0.3983670139171796,
           -0.40653655359970714,
           -0.41596656482760336,
           -0.4265646669225742,
           -0.43823626846064523,
           -0.4508871853573293,
           -0.46442568179322674,
           -0.4787639486660304,
           -0.493819080745362,
           -0.509513636974918,
           -0.5257758740529835,
           -0.5425397377744684,
           -0.5597446849707594,
           -0.5773353951004631,
           -0.5952614170471618,
           -0.6134767847537658,
           -0.6319396254705085,
           -0.6506117766469859,
           -0.6694584216442573,
           -0.6884477501686469,
           -0.7075506463090487,
           -0.7267404049989146,
           -0.7459924763748088,
           -0.7652842366677334,
           -0.7845947837892882,
           -0.8039047555485139,
           -0.8231961683739308,
           -0.8424522744594689,
           -0.8616574353610286,
           -0.8807970102136823,
           -0.8998572568988207,
           -0.9188252446533026,
           -0.9376887767710382,
           -0.9564363221967451,
           -0.9750569549494261,
           -0.9935403004383374,
           -1.0118764878467743,
           -1.030056107859324,
           -1.0480701750970989,
           -1.0659100947038285,
           -1.0835676325945358,
           -1.101034888938879,
           -1.1183042745040361,
           -1.135368489528143,
           -1.1522205048355854,
           -1.1688535449406012,
           -1.1852610729163282,
           -1.201436776833223,
           -1.2173745575941524,
           -1.2330685180138923,
           -1.248512953008628,
           -1.263702340776675,
           -1.278631334865312,
           -1.2932947570306275,
           -1.3076875908077867,
           -1.3218049757183734,
           -1.3356422020495873,
           -1.3491947061472354,
           -1.3624580661707484,
           -1.375427998264033,
           -1.3881003531008727,
           -1.4004711127679494,
           -1.4125363879523973,
           -1.424292415404232,
           -1.4357355556470117,
           -1.4468622909128028,
           -1.457669223279907,
           -1.4681530729939583,
           -1.478310676954897,
           -1.488138987354051,
           -1.4976350704470607,
           -1.5067961054497736,
           -1.5156193835454481,
           -1.524102306992721,
           -1.5322423883247736,
           -1.5400372496310422,
           -1.5474846219136176,
           -1.5545823445112046,
           -1.5613283645841893,
           -1.5677207366549475,
           -1.5737576221980802,
           -1.5794372892757609,
           -1.5847581122138268,
           -1.5897185713146667,
           -1.5943172526033353,
           -1.5985528476036794,
           -1.6024241531415706,
           -1.605930071172659,
           -1.6090696086323186,
           -1.6118418773057277,
           -1.6142460937162584,
           -1.6162815790305955,
           -1.6179477589791904,
           -1.6192441637908939,
           -1.620170428140775,
           -1.620726291110349
          ],
          [
           -1.5923163850582873,
           -1.5921364395920017,
           -1.5915966552801437,
           -1.5906971883918752,
           -1.5894382994031087,
           -1.5878203530378037,
           -1.5858438183264594,
           -1.5835092686824728,
           -1.5808173819972469,
           -1.577768940755141,
           -1.574364832169565,
           -1.5706060483417528,
           -1.5664936864439853,
           -1.5620289489292876,
           -1.5572131437698926,
           -1.5520476847270461,
           -1.5465340916550352,
           -1.5406739908426523,
           -1.5344691153956656,
           -1.5279213056642322,
           -1.5210325097196415,
           -1.5138047838851891,
           -1.5062402933265087,
           -1.4983413127072123,
           -1.4901102269162942,
           -1.48154953187439,
           -1.4726618354267091,
           -1.4634498583312474,
           -1.4539164353517449,
           -1.444064516465831,
           -1.4338971681998438,
           -1.423417575103003,
           -1.412629041374915,
           -1.4015349926618472,
           -1.3901389780388074,
           -1.3784446721962855,
           -1.3664558778524984,
           -1.3541765284142324,
           -1.3416106909118644,
           -1.328762569236953,
           -1.3156365077139172,
           -1.302236995040834,
           -1.2885686686383275,
           -1.2746363194499548,
           -1.2604448972424698,
           -1.2459995164599502,
           -1.2313054626920976,
           -1.2163681998241265,
           -1.2011933779437,
           -1.1857868420894513,
           -1.1701546419358617,
           -1.1543030425208842,
           -1.1382385361357885,
           -1.1219678555115644,
           -1.105497988453,
           -1.0888361940905598,
           -1.0719900209417,
           -1.054967326997588,
           -1.0377763020786746,
           -1.0204254927336267,
           -1.0029238299911094,
           -0.9852806603132656,
           -0.9675057801438857,
           -0.949609474493598,
           -0.9316025600592747,
           -0.9134964334354979,
           -0.8953031250424031,
           -0.8770353594663318,
           -0.8587066229867882,
           -0.8403312391439504,
           -0.8219244532832118,
           -0.8035025270934049,
           -0.7850828442281266,
           -0.7666840281570338,
           -0.7483260734247288,
           -0.7300304914828258,
           -0.7118204721836794,
           -0.6937210618515853,
           -0.6757593585381191,
           -0.6579647245686475,
           -0.640369015727134,
           -0.6230068253181434,
           -0.6059157397809799,
           -0.5891366003855718,
           -0.5727137626755613,
           -0.5566953416059462,
           -0.5411334256451377,
           -0.5260842374442658,
           -0.5116082121349236,
           -0.4977699572575277,
           -0.4846380514665881,
           -0.47228463371649704,
           -0.4607847323918513,
           -0.4502152871598218,
           -0.4406538278668761,
           -0.432176797031939,
           -0.4248575367060542,
           -0.41876400562558724,
           -0.4139563441465969,
           -0.4104844539298572,
           -0.40838579522351004,
           -0.4076836149417127,
           -0.4083857952235115,
           -0.41048445392986005,
           -0.41395634414660115,
           -0.41876400562559285,
           -0.424857536706061,
           -0.43217679703194717,
           -0.44065382786688545,
           -0.4502152871598321,
           -0.4607847323918627,
           -0.4722846337165093,
           -0.4846380514666012,
           -0.4977699572575416,
           -0.5116082121349381,
           -0.526084237444281,
           -0.5411334256451533,
           -0.5566953416059626,
           -0.572713762675578,
           -0.5891366003855888,
           -0.6059157397809973,
           -0.6230068253181612,
           -0.6403690157271519,
           -0.6579647245686657,
           -0.6757593585381374,
           -0.6937210618516038,
           -0.7118204721836979,
           -0.7300304914828446,
           -0.7483260734247477,
           -0.7666840281570527,
           -0.7850828442281454,
           -0.8035025270934237,
           -0.8219244532832306,
           -0.8403312391439692,
           -0.8587066229868071,
           -0.8770353594663507,
           -0.8953031250424218,
           -0.9134964334355167,
           -0.9316025600592933,
           -0.9496094744936163,
           -0.9675057801439041,
           -0.9852806603132841,
           -1.0029238299911276,
           -1.0204254927336445,
           -1.0377763020786925,
           -1.0549673269976059,
           -1.0719900209417175,
           -1.0888361940905766,
           -1.1054979884530172,
           -1.1219678555115813,
           -1.138238536135805,
           -1.1543030425209007,
           -1.170154641935878,
           -1.1857868420894673,
           -1.2011933779437158,
           -1.2163681998241418,
           -1.231305462692113,
           -1.2459995164599649,
           -1.2604448972424842,
           -1.2746363194499692,
           -1.2885686686383415,
           -1.3022369950408477,
           -1.3156365077139305,
           -1.328762569236966,
           -1.3416106909118772,
           -1.3541765284142453,
           -1.3664558778525109,
           -1.3784446721962975,
           -1.3901389780388191,
           -1.4015349926618588,
           -1.4126290413749263,
           -1.4234175751030136,
           -1.4338971681998545,
           -1.4440645164658417,
           -1.4539164353517549,
           -1.4634498583312567,
           -1.472661835426719,
           -1.4815495318743994,
           -1.4901102269163031,
           -1.4983413127072205,
           -1.5062402933265162,
           -1.5138047838851967,
           -1.521032509719649,
           -1.5279213056642391,
           -1.534469115395672,
           -1.5406739908426585,
           -1.546534091655041,
           -1.5520476847270517,
           -1.5572131437698975,
           -1.5620289489292922,
           -1.5664936864439893,
           -1.570606048341757,
           -1.5743648321695687,
           -1.5777689407551443,
           -1.5808173819972497,
           -1.5835092686824752,
           -1.585843818326462,
           -1.5878203530378059,
           -1.58943829940311,
           -1.5906971883918763,
           -1.5915966552801444,
           -1.592136439592002
          ],
          [
           -1.5641155815246053,
           -1.5639411136535022,
           -1.5634177620752183,
           -1.5625456829056605,
           -1.561325136374213,
           -1.5597564868784088,
           -1.5578402030612115,
           -1.5555768579116451,
           -1.5529671288897304,
           -1.5500117980769357,
           -1.5467117523535496,
           -1.5430679836046741,
           -1.5390815889567555,
           -1.534753771046873,
           -1.5300858383272828,
           -1.5250792054080275,
           -1.5197353934407483,
           -1.5140560305471975,
           -1.5080428522963312,
           -1.5016977022342604,
           -1.495022532471813,
           -1.4880194043349158,
           -1.4806904890835497,
           -1.4730380687056066,
           -1.4650645367926012,
           -1.4567723995048776,
           -1.4481642766347198,
           -1.439242902776585,
           -1.4300111286146087,
           -1.4204719223385318,
           -1.4106283712002983,
           -1.4004836832248146,
           -1.3900411890897033,
           -1.379304344190387,
           -1.3682767309084987,
           -1.3569620611034594,
           -1.345364178849108,
           -1.3334870634395393,
           -1.3213348326908427,
           -1.3089117465682436,
           -1.2962222111712896,
           -1.2832707831132253,
           -1.2700621743346026,
           -1.2566012573955379,
           -1.242893071295898,
           -1.2289428278781525,
           -1.2147559188737227,
           -1.2003379236604863,
           -1.18569461780673,
           -1.1708319824854034,
           -1.1557562148521006,
           -1.140473739490925,
           -1.1249912210443993,
           -1.10931557815701,
           -1.0934539988769998,
           -1.0774139576777937,
           -1.0612032342791455,
           -1.0448299344689158,
           -1.0283025131495216,
           -1.011629799858689,
           -0.994821027042372,
           -0.9778858613886809,
           -0.9608344385654274,
           -0.943677401740411,
           -0.9264259443026545,
           -0.909091857243995,
           -0.8916875817030998,
           -0.8742262672169165,
           -0.8567218362661233,
           -0.8391890557387861,
           -0.8216436159666363,
           -0.8041022180061848,
           -0.7865826698355034,
           -0.7691039921077291,
           -0.7516865340319084,
           -0.7343520998245407,
           -0.7171240859701167,
           -0.7000276292192732,
           -0.6830897648052793,
           -0.6663395937322009,
           -0.6498084571321295,
           -0.6335301145480324,
           -0.617540921512105,
           -0.6018799998966767,
           -0.5865893921657134,
           -0.5717141878256765,
           -0.5573026070903475,
           -0.543406023142894,
           -0.5300789006318612,
           -0.5173786245797453,
           -0.5053651913338372,
           -0.494100732411007,
           -0.48364884416277426,
           -0.47407370231396445,
           -0.46543895170840266,
           -0.45780637868414,
           -0.45123439616058636,
           -0.4457763981681066,
           -0.4414790679868843,
           -0.4383807475989366,
           -0.4365099903346202,
           -0.4358844184753947,
           -0.4365099903346215,
           -0.43838074759893914,
           -0.441479067986888,
           -0.4457763981681116,
           -0.4512343961605925,
           -0.45780637868414725,
           -0.46543895170841104,
           -0.4740737023139737,
           -0.48364884416278464,
           -0.49410073241101815,
           -0.5053651913338493,
           -0.5173786245797579,
           -0.5300789006318747,
           -0.5434060231429081,
           -0.5573026070903622,
           -0.5717141878256916,
           -0.5865893921657289,
           -0.6018799998966927,
           -0.6175409215121215,
           -0.6335301145480492,
           -0.6498084571321463,
           -0.666339593732218,
           -0.6830897648052965,
           -0.7000276292192906,
           -0.7171240859701343,
           -0.7343520998245585,
           -0.7516865340319263,
           -0.769103992107747,
           -0.7865826698355213,
           -0.8041022180062026,
           -0.8216436159666544,
           -0.8391890557388041,
           -0.8567218362661412,
           -0.8742262672169344,
           -0.8916875817031178,
           -0.909091857244013,
           -0.9264259443026722,
           -0.9436774017404288,
           -0.9608344385654449,
           -0.9778858613886986,
           -0.9948210270423893,
           -1.0116297998587063,
           -1.0283025131495387,
           -1.0448299344689327,
           -1.061203234279162,
           -1.0774139576778103,
           -1.0934539988770162,
           -1.109315578157026,
           -1.1249912210444155,
           -1.1404737394909408,
           -1.155756214852116,
           -1.170831982485419,
           -1.1856946178067453,
           -1.2003379236605014,
           -1.2147559188737376,
           -1.2289428278781669,
           -1.2428930712959123,
           -1.256601257395552,
           -1.270062174334616,
           -1.2832707831132386,
           -1.2962222111713029,
           -1.3089117465682565,
           -1.3213348326908552,
           -1.3334870634395515,
           -1.34536417884912,
           -1.356962061103471,
           -1.36827673090851,
           -1.3793043441903983,
           -1.3900411890897144,
           -1.400483683224825,
           -1.4106283712003085,
           -1.420471922338542,
           -1.4300111286146187,
           -1.439242902776594,
           -1.4481642766347291,
           -1.4567723995048867,
           -1.4650645367926096,
           -1.4730380687056148,
           -1.4806904890835573,
           -1.488019404334923,
           -1.49502253247182,
           -1.5016977022342668,
           -1.5080428522963376,
           -1.5140560305472037,
           -1.5197353934407536,
           -1.5250792054080327,
           -1.5300858383272877,
           -1.5347537710468777,
           -1.53908158895676,
           -1.5430679836046781,
           -1.5467117523535532,
           -1.5500117980769388,
           -1.5529671288897338,
           -1.5555768579116476,
           -1.5578402030612142,
           -1.5597564868784104,
           -1.5613251363742144,
           -1.5625456829056614,
           -1.563417762075219,
           -1.5639411136535026
          ],
          [
           -1.5363364680146492,
           -1.5361675924382945,
           -1.5356610177215406,
           -1.5348168999147793,
           -1.5336354991469654,
           -1.5321171796934667,
           -1.5302624100718418,
           -1.5280717631663567,
           -1.5255459163822604,
           -1.5226856518311216,
           -1.5194918565487403,
           -1.5159655227474598,
           -1.512107748104933,
           -1.5079197360917331,
           -1.5034027963404748,
           -1.4985583450594668,
           -1.4933879054942416,
           -1.4878931084407085,
           -1.482075692814063,
           -1.4759375062780227,
           -1.469480505939436,
           -1.4627067591138092,
           -1.455618444167857,
           -1.4482178514457744,
           -1.4405073842865865,
           -1.4324895601406413,
           -1.4241670117940979,
           -1.415542488711104,
           -1.406618858504308,
           -1.3973991085453616,
           -1.3878863477282077,
           -1.3780838083991895,
           -1.367994848469378,
           -1.357622953726027,
           -1.3469717403617214,
           -1.336044957741632,
           -1.3248464914312992,
           -1.313380366509627,
           -1.3016507511942452,
           -1.2896619608091358,
           -1.2774184621274787,
           -1.2649248781260316,
           -1.2521859931911012,
           -1.2392067588203113,
           -1.2259922998689732,
           -1.2125479213949584,
           -1.1988791161616426,
           -1.1849915728647622,
           -1.170891185155978,
           -1.1565840615436669,
           -1.1420765362599823,
           -1.1273751811926862,
           -1.1124868189906774,
           -1.097418537463656,
           -1.082177705409023,
           -1.0667719900130108,
           -1.0512093759882501,
           -1.0354981866265274,
           -1.0196471069634336,
           -1.0036652092709286,
           -0.987561981114444,
           -0.9713473562329332,
           -0.9550317485229363,
           -0.938626089430876,
           -0.9221418690808262,
           -0.9055911814869994,
           -0.8889867742199562,
           -0.8723421029113281,
           -0.8556713909913438,
           -0.8389896950535723,
           -0.822312976227926,
           -0.8056581779107692,
           -0.789043310143032,
           -0.7724875408347255,
           -0.7560112938960761,
           -0.7396363541378393,
           -0.7233859785293859,
           -0.7072850130326973,
           -0.6913600137400423,
           -0.6756393704064283,
           -0.6601534296567919,
           -0.6449346141345081,
           -0.6300175326184654,
           -0.6154390746569179,
           -0.6012384815524494,
           -0.5874573836189075,
           -0.574139791599121,
           -0.5613320281263943,
           -0.5490825833605446,
           -0.5374418777559852,
           -0.5264619147534537,
           -0.5161958075448835,
           -0.5066971674999631,
           -0.4980193478714069,
           -0.490214545335525,
           -0.4833327737345893,
           -0.47742073848230865,
           -0.47252065521106457,
           -0.468669070433332,
           -0.46589575281955525,
           -0.46422272864131964,
           -0.4636635319853507,
           -0.4642227286413208,
           -0.46589575281955753,
           -0.4686690704333354,
           -0.472520655211069,
           -0.47742073848231414,
           -0.48333277373459593,
           -0.49021454533553255,
           -0.4980193478714154,
           -0.5066971674999725,
           -0.5161958075448937,
           -0.5264619147534646,
           -0.5374418777559968,
           -0.5490825833605568,
           -0.5613320281264071,
           -0.5741397915991344,
           -0.5874573836189214,
           -0.6012384815524638,
           -0.6154390746569327,
           -0.6300175326184808,
           -0.6449346141345237,
           -0.6601534296568077,
           -0.6756393704064444,
           -0.6913600137400585,
           -0.7072850130327137,
           -0.7233859785294025,
           -0.7396363541378562,
           -0.7560112938960928,
           -0.7724875408347425,
           -0.7890433101430488,
           -0.8056581779107863,
           -0.8223129762279431,
           -0.8389896950535896,
           -0.855671390991361,
           -0.8723421029113453,
           -0.8889867742199733,
           -0.9055911814870163,
           -0.9221418690808433,
           -0.9386260894308929,
           -0.955031748522953,
           -0.9713473562329499,
           -0.9875619811144605,
           -1.0036652092709453,
           -1.0196471069634498,
           -1.0354981866265438,
           -1.0512093759882664,
           -1.0667719900130268,
           -1.0821777054090387,
           -1.0974185374636714,
           -1.112486818990693,
           -1.1273751811927013,
           -1.1420765362599972,
           -1.1565840615436815,
           -1.1708911851559924,
           -1.1849915728647764,
           -1.198879116161657,
           -1.2125479213949724,
           -1.2259922998689867,
           -1.2392067588203246,
           -1.2521859931911141,
           -1.2649248781260445,
           -1.2774184621274913,
           -1.2896619608091484,
           -1.3016507511942574,
           -1.313380366509639,
           -1.3248464914313107,
           -1.3360449577416431,
           -1.3469717403617325,
           -1.3576229537260376,
           -1.367994848469389,
           -1.3780838083991998,
           -1.3878863477282173,
           -1.3973991085453712,
           -1.4066188585043178,
           -1.4155424887111128,
           -1.4241670117941065,
           -1.4324895601406498,
           -1.4405073842865947,
           -1.448217851445782,
           -1.4556184441678641,
           -1.4627067591138159,
           -1.469480505939443,
           -1.475937506278029,
           -1.482075692814069,
           -1.487893108440714,
           -1.4933879054942467,
           -1.498558345059472,
           -1.5034027963404795,
           -1.5079197360917376,
           -1.512107748104937,
           -1.5159655227474638,
           -1.5194918565487436,
           -1.5226856518311245,
           -1.5255459163822636,
           -1.5280717631663596,
           -1.5302624100718443,
           -1.5321171796934685,
           -1.5336354991469672,
           -1.53481689991478,
           -1.5356610177215408,
           -1.5361675924382947
          ],
          [
           -1.5090059190266547,
           -1.5088427463803,
           -1.5083532804485538,
           -1.5075376772693572,
           -1.5063961969593629,
           -1.5049292037944746,
           -1.503137166323448,
           -1.5010206575153895,
           -1.498580354942253,
           -1.495817040997694,
           -1.492731603153898,
           -1.489325034258287,
           -1.4855984328722993,
           -1.4815530036547362,
           -1.477190057792502,
           -1.472511013481901,
           -1.4675173964640205,
           -1.4622108406181178,
           -1.4565930886173504,
           -1.4506659926516299,
           -1.4444315152228688,
           -1.437891730018406,
           -1.431048822868965,
           -1.4239050927981034,
           -1.416462953170782,
           -1.4087249329493972,
           -1.4006936780664123,
           -1.3923719529235725,
           -1.3837626420286313,
           -1.3748687517815328,
           -1.3656934124231115,
           -1.3562398801606066,
           -1.3465115394856173,
           -1.3365119057016013,
           -1.3262446276796418,
           -1.3157134908629753,
           -1.304922420542721,
           -1.293875485429402,
           -1.282576901547195,
           -1.2710310364804511,
           -1.2592424140048546,
           -1.2472157191387514,
           -1.2349558036536017,
           -1.2224676920863091,
           -1.209756588300356,
           -1.1968278826472303,
           -1.1836871597846685,
           -1.1703402072137483,
           -1.156793024602887,
           -1.143051833973412,
           -1.1291230908285674,
           -1.1150134963156568,
           -1.100730010519538,
           -1.0862798669948859,
           -1.071670588654556,
           -1.0569100051419833,
           -1.04200627182684,
           -1.0269678905750683,
           -1.0118037324567921,
           -0.9965230625683533,
           -0.9811355671575307,
           -0.9656513832535784,
           -0.9500811310155326,
           -0.9344359490226818,
           -0.9187275327392521,
           -0.9029681763900926,
           -0.8871708184839531,
           -0.8713490912138561,
           -0.8555173739476007,
           -0.8396908509924337,
           -0.823885573772395,
           -0.8081185274898994,
           -0.7924077022486695,
           -0.7767721684858871,
           -0.7612321563886563,
           -0.7458091387433604,
           -0.7305259163746648,
           -0.7154067049609159,
           -0.7004772215511027,
           -0.6857647685421571,
           -0.6712983121928764,
           -0.6571085519450319,
           -0.6432279758937656,
           -0.6296908967108367,
           -0.616533461206436,
           -0.6037936255739987,
           -0.591511087286482,
           -0.5797271637307646,
           -0.5684846071530535,
           -0.5578273455610624,
           -0.5478001401422652,
           -0.5384481517787275,
           -0.5298164126084026,
           -0.5219492034570852,
           -0.5148893443453678,
           -0.5086774129302872,
           -0.5033509141492295,
           -0.498943432660162,
           -0.4954838068208166,
           -0.49299536769469166,
           -0.4914952877738419,
           -0.49099408097334535,
           -0.4914952877738429,
           -0.49299536769469365,
           -0.4954838068208196,
           -0.49894343266016605,
           -0.5033509141492345,
           -0.5086774129302932,
           -0.5148893443453747,
           -0.5219492034570928,
           -0.5298164126084112,
           -0.5384481517787368,
           -0.5478001401422752,
           -0.557827345561073,
           -0.5684846071530648,
           -0.5797271637307764,
           -0.5915110872864945,
           -0.6037936255740117,
           -0.6165334612064495,
           -0.6296908967108504,
           -0.6432279758937798,
           -0.6571085519450464,
           -0.6712983121928912,
           -0.6857647685421722,
           -0.7004772215511179,
           -0.7154067049609313,
           -0.7305259163746803,
           -0.7458091387433762,
           -0.761232156388672,
           -0.7767721684859034,
           -0.7924077022486855,
           -0.8081185274899155,
           -0.8238855737724111,
           -0.83969085099245,
           -0.8555173739476168,
           -0.8713490912138722,
           -0.8871708184839694,
           -0.9029681763901088,
           -0.9187275327392683,
           -0.9344359490226979,
           -0.9500811310155488,
           -0.9656513832535946,
           -0.9811355671575466,
           -0.996523062568369,
           -1.0118037324568079,
           -1.0269678905750839,
           -1.0420062718268552,
           -1.0569100051419984,
           -1.0716705886545712,
           -1.0862798669949008,
           -1.1007300105195525,
           -1.1150134963156715,
           -1.1291230908285816,
           -1.1430518339734261,
           -1.1567930246029008,
           -1.1703402072137623,
           -1.183687159784682,
           -1.1968278826472434,
           -1.2097565883003694,
           -1.222467692086322,
           -1.2349558036536141,
           -1.247215719138764,
           -1.2592424140048668,
           -1.2710310364804631,
           -1.2825769015472068,
           -1.2938754854294132,
           -1.3049224205427323,
           -1.3157134908629862,
           -1.3262446276796525,
           -1.3365119057016117,
           -1.3465115394856277,
           -1.3562398801606166,
           -1.3656934124231208,
           -1.3748687517815419,
           -1.3837626420286404,
           -1.392371952923581,
           -1.4006936780664208,
           -1.4087249329494054,
           -1.4164629531707897,
           -1.423905092798111,
           -1.4310488228689722,
           -1.4378917300184124,
           -1.4444315152228755,
           -1.450665992651636,
           -1.4565930886173561,
           -1.4622108406181233,
           -1.4675173964640256,
           -1.472511013481906,
           -1.4771900577925063,
           -1.4815530036547406,
           -1.4855984328723033,
           -1.4893250342582907,
           -1.492731603153901,
           -1.4958170409976972,
           -1.4985803549422558,
           -1.501020657515392,
           -1.5031371663234503,
           -1.5049292037944766,
           -1.506396196959364,
           -1.507537677269358,
           -1.5083532804485544,
           -1.5088427463803005
          ],
          [
           -1.4821503751016516,
           -1.481993011139136,
           -1.4815209712584887,
           -1.4807344114987728,
           -1.4796335919864443,
           -1.4782188770278082,
           -1.476490735239338,
           -1.474449739716725,
           -1.4720965682438063,
           -1.4694320035427793,
           -1.4664569335673832,
           -1.4631723518410227,
           -1.4595793578421103,
           -1.4556791574392072,
           -1.451473063378888,
           -1.4469624958295986,
           -1.4421489829851417,
           -1.4370341617318392,
           -1.4316197783838198,
           -1.4259076894913512,
           -1.4198998627276134,
           -1.4135983778598316,
           -1.4070054278112574,
           -1.4001233198210825,
           -1.39295447671004,
           -1.3855014382601505,
           -1.3777668627178459,
           -1.3697535284305438,
           -1.3614643356276495,
           -1.3529023083579597,
           -1.34407059659652,
           -1.3349724785351544,
           -1.3256113630721758,
           -1.3159907925181746,
           -1.306114445536307,
           -1.2959861403371655,
           -1.2856098381501244,
           -1.2749896469950346,
           -1.2641298257802909,
           -1.2530347887556574,
           -1.2417091103507973,
           -1.230157530433251,
           -1.218384960022648,
           -1.2063964875012538,
           -1.1941973853645618,
           -1.1817931175595175,
           -1.1691893474622275,
           -1.1563919465515493,
           -1.143407003839894,
           -1.130240836127866,
           -1.1168999991550141,
           -1.103391299725007,
           -1.0897218088899083,
           -1.0758988762849357,
           -1.0619301457120565,
           -1.0478235720779343,
           -1.0335874397990081,
           -1.0192303827936824,
           -1.0047614061885282,
           -0.9901899098717999,
           -0.975525714033042,
           -0.9607790868316937,
           -0.9459607743397068,
           -0.9310820329025815,
           -0.9161546640588526,
           -0.9011910521487236,
           -0.8862042047267039,
           -0.8712077958688722,
           -0.8562162124304236,
           -0.8412446032606936,
           -0.826308931317471,
           -0.8114260285361748,
           -0.7966136531977208,
           -0.7818905493963192,
           -0.7672765080291395,
           -0.7527924285073141,
           -0.7384603801155283,
           -0.7243036616190581,
           -0.7103468573271142,
           -0.6966158873661853,
           -0.6831380493965847,
           -0.6699420484246552,
           -0.6570580107347863,
           -0.6445174773127422,
           -0.6323533714917547,
           -0.6205999349792433,
           -0.6092926259884482,
           -0.5984679730000816,
           -0.5881633778283045,
           -0.5784168622909727,
           -0.5692667540172464,
           -0.5607513088825292,
           -0.5529082703175774,
           -0.5457743693012078,
           -0.5393847731171185,
           -0.5337724957074154,
           -0.5289677873178764,
           -0.5249975256004719,
           -0.5218846338269671,
           -0.5196475537733528,
           -0.5182998006521728,
           -0.5178496248983484,
           -0.5182998006521738,
           -0.5196475537733547,
           -0.5218846338269699,
           -0.5249975256004754,
           -0.528967787317881,
           -0.5337724957074207,
           -0.5393847731171246,
           -0.5457743693012148,
           -0.5529082703175852,
           -0.5607513088825377,
           -0.5692667540172555,
           -0.5784168622909824,
           -0.588163377828315,
           -0.5984679730000925,
           -0.6092926259884596,
           -0.6205999349792553,
           -0.6323533714917671,
           -0.6445174773127549,
           -0.6570580107347994,
           -0.6699420484246686,
           -0.6831380493965983,
           -0.6966158873661994,
           -0.7103468573271284,
           -0.7243036616190726,
           -0.7384603801155429,
           -0.7527924285073289,
           -0.7672765080291543,
           -0.7818905493963343,
           -0.796613653197736,
           -0.8114260285361901,
           -0.8263089313174862,
           -0.841244603260709,
           -0.856216212430439,
           -0.8712077958688875,
           -0.8862042047267195,
           -0.901191052148739,
           -0.9161546640588683,
           -0.9310820329025968,
           -0.9459607743397221,
           -0.960779086831709,
           -0.9755257140330572,
           -0.9901899098718149,
           -1.0047614061885433,
           -1.019230382793697,
           -1.0335874397990228,
           -1.0478235720779487,
           -1.0619301457120711,
           -1.07589887628495,
           -1.0897218088899223,
           -1.103391299725021,
           -1.116899999155028,
           -1.1302408361278795,
           -1.1434070038399073,
           -1.1563919465515624,
           -1.1691893474622406,
           -1.1817931175595302,
           -1.1941973853645742,
           -1.2063964875012663,
           -1.2183849600226597,
           -1.2301575304332633,
           -1.241709110350809,
           -1.2530347887556688,
           -1.264129825780302,
           -1.274989646995046,
           -1.285609838150135,
           -1.2959861403371757,
           -1.3061144455363172,
           -1.3159907925181848,
           -1.3256113630721857,
           -1.3349724785351638,
           -1.3440705965965292,
           -1.3529023083579685,
           -1.3614643356276581,
           -1.3697535284305522,
           -1.3777668627178543,
           -1.385501438260158,
           -1.3929544767100472,
           -1.4001233198210896,
           -1.4070054278112643,
           -1.4135983778598382,
           -1.4198998627276194,
           -1.4259076894913572,
           -1.4316197783838254,
           -1.4370341617318445,
           -1.4421489829851468,
           -1.4469624958296032,
           -1.4514730633788924,
           -1.4556791574392112,
           -1.4595793578421141,
           -1.463172351841026,
           -1.4664569335673863,
           -1.4694320035427826,
           -1.4720965682438087,
           -1.474449739716727,
           -1.4764907352393402,
           -1.47821887702781,
           -1.4796335919864454,
           -1.480734411498774,
           -1.4815209712584896,
           -1.4819930111391364
          ],
          [
           -1.45579581724395,
           -1.4556443619541495,
           -1.4551900480810867,
           -1.45443303163431,
           -1.4533735726982997,
           -1.452012035535762,
           -1.4503488887331337,
           -1.4483847053891974,
           -1.4461201633479634,
           -1.443556045477271,
           -1.4406932399948111,
           -1.437532740843593,
           -1.4340756481191597,
           -1.4303231685511897,
           -1.4262766160424432,
           -1.4219374122683752,
           -1.4173070873410964,
           -1.4123872805417634,
           -1.407179741125906,
           -1.4016863292066277,
           -1.3959090167211112,
           -1.389849888486367,
           -1.3835111433507021,
           -1.3768950954479997,
           -1.3700041755625043,
           -1.3628409326125228,
           -1.3554080352621662,
           -1.3477082736710708,
           -1.339744561392887,
           -1.3315199374342646,
           -1.3230375684870699,
           -1.314300751347654,
           -1.3053129155381842,
           -1.2960776261463225,
           -1.2865985869009149,
           -1.2768796435028686,
           -1.2669247872319993,
           -1.256738158852394,
           -1.2463240528407271,
           -1.235686921964014,
           -1.2248313822354915,
           -1.2137622182796919,
           -1.2024843891403363,
           -1.191003034567402,
           -1.1793234818226717,
           -1.1674512530461763,
           -1.1553920732292988,
           -1.1431518788438026,
           -1.1307368271797673,
           -1.118153306449296,
           -1.1054079467168643,
           -1.0925076317213311,
           -1.079459511658799,
           -1.0662710169997023,
           -1.0529498734175478,
           -1.0395041179105777,
           -1.0259421162010356,
           -1.0122725814995668,
           -0.9985045947242235,
           -0.9846476262643091,
           -0.9707115593784323,
           -0.9567067153131319,
           -0.9426438802226678,
           -0.9285343339612226,
           -0.9143898808049234,
           -0.9002228821415842,
           -0.8860462911395399,
           -0.8718736893717557,
           -0.8577193253256344,
           -0.843598154670429,
           -0.8295258820803249,
           -0.8155190043193172,
           -0.8015948541808392,
           -0.7877716447374393,
           -0.7740685131903322,
           -0.7605055634121977,
           -0.7471039060465281,
           -0.7338856947614208,
           -0.7208741569548701,
           -0.7080936168746219,
           -0.6955695087542187,
           -0.683328377188341,
           -0.6713978615913233,
           -0.6598066612265905,
           -0.6485844769943199,
           -0.6377619259620723,
           -0.6273704245704208,
           -0.617442036603171,
           -0.6080092824454578,
           -0.5991049069284672,
           -0.590761604233775,
           -0.5830116999404128,
           -0.5758867923474024,
           -0.5694173576495684,
           -0.5636323262808878,
           -0.5585586405962413,
           -0.5542208068030755,
           -0.5506404563926804,
           -0.5478359339484672,
           -0.5458219288375323,
           -0.5446091677021763,
           -0.54420418275605,
           -0.544609167702177,
           -0.5458219288375339,
           -0.5478359339484697,
           -0.5506404563926838,
           -0.5542208068030795,
           -0.5585586405962462,
           -0.5636323262808934,
           -0.5694173576495747,
           -0.5758867923474095,
           -0.5830116999404206,
           -0.5907616042337833,
           -0.5991049069284761,
           -0.6080092824454671,
           -0.6174420366031809,
           -0.6273704245704312,
           -0.6377619259620833,
           -0.6485844769943312,
           -0.6598066612266021,
           -0.6713978615913354,
           -0.6833283771883536,
           -0.6955695087542314,
           -0.7080936168746349,
           -0.7208741569548833,
           -0.7338856947614343,
           -0.7471039060465418,
           -0.7605055634122115,
           -0.7740685131903462,
           -0.7877716447374534,
           -0.8015948541808533,
           -0.8155190043193317,
           -0.8295258820803394,
           -0.8435981546704435,
           -0.857719325325649,
           -0.8718736893717701,
           -0.8860462911395547,
           -0.9002228821415987,
           -0.914389880804938,
           -0.9285343339612371,
           -0.9426438802226823,
           -0.9567067153131465,
           -0.9707115593784468,
           -0.9846476262643235,
           -0.9985045947242376,
           -1.0122725814995808,
           -1.0259421162010496,
           -1.0395041179105915,
           -1.0529498734175617,
           -1.0662710169997156,
           -1.0794595116588126,
           -1.0925076317213445,
           -1.1054079467168774,
           -1.1181533064493088,
           -1.1307368271797802,
           -1.1431518788438153,
           -1.1553920732293115,
           -1.1674512530461887,
           -1.1793234818226837,
           -1.191003034567414,
           -1.2024843891403478,
           -1.2137622182797034,
           -1.2248313822355026,
           -1.2356869219640252,
           -1.246324052840738,
           -1.2567381588524045,
           -1.2669247872320097,
           -1.2768796435028786,
           -1.2865985869009247,
           -1.296077626146332,
           -1.3053129155381937,
           -1.3143007513476628,
           -1.3230375684870785,
           -1.3315199374342732,
           -1.3397445613928953,
           -1.347708273671079,
           -1.355408035262174,
           -1.3628409326125304,
           -1.3700041755625116,
           -1.3768950954480066,
           -1.383511143350709,
           -1.3898498884863733,
           -1.3959090167211174,
           -1.4016863292066333,
           -1.4071797411259115,
           -1.4123872805417685,
           -1.4173070873411011,
           -1.42193741226838,
           -1.4262766160424472,
           -1.4303231685511937,
           -1.434075648119163,
           -1.4375327408435963,
           -1.4406932399948138,
           -1.4435560454772736,
           -1.446120163347966,
           -1.4483847053891996,
           -1.4503488887331362,
           -1.4520120355357633,
           -1.4533735726983008,
           -1.4544330316343108,
           -1.4551900480810873,
           -1.45564436195415
          ],
          [
           -1.4299677417861951,
           -1.4298222884428535,
           -1.4293859803722586,
           -1.428658973475123,
           -1.4276415276608299,
           -1.4263340069601764,
           -1.4247368796841076,
           -1.422850718629348,
           -1.4206762013320846,
           -1.4182141103711627,
           -1.4154653337224943,
           -1.4124308651666975,
           -1.409111804752281,
           -1.4055093593169898,
           -1.4016248430702711,
           -1.3974596782401525,
           -1.3930153957881988,
           -1.3882936361965823,
           -1.3832961503317296,
           -1.3780248003894076,
           -1.3724815609266103,
           -1.366668519986056,
           -1.3605878803196596,
           -1.3542419607178797,
           -1.3476331974524525,
           -1.34076414584066,
           -1.3336374819399544,
           -1.3262560043825202,
           -1.3186226363601248,
           -1.3107404277704633,
           -1.302612557537122,
           -1.2942423361162498,
           -1.2856332082040887,
           -1.2767887556606372,
           -1.2677127006659243,
           -1.2584089091266801,
           -1.2488813943525638,
           -1.2391343210225987,
           -1.2291720094640446,
           -1.218998940267627,
           -1.2086197592648307,
           -1.1980392828948685,
           -1.1872625039909386,
           -1.1762945980174937,
           -1.1651409297924662,
           -1.1538070607306656,
           -1.1422987566469738,
           -1.130621996160364,
           -1.1187829797422506,
           -1.1067881394551184,
           -1.0946441494297894,
           -1.0823579371319634,
           -1.0699366954707665,
           -1.0573878958038425,
           -1.0447193018949061,
           -1.0319389848805036,
           -1.0190553393027724,
           -1.0060771002640772,
           -0.9930133617571765,
           -0.9798735962207543,
           -0.9666676753642774,
           -0.9534058922977399,
           -0.94009898499032,
           -0.9267581610666021,
           -0.9133951239290096,
           -0.900022100169448,
           -0.8866518682008329,
           -0.8732977879988802,
           -0.8599738317948925,
           -0.8466946154997624,
           -0.8334754305663614,
           -0.8203322759102115,
           -0.8072818894051397,
           -0.7943417783499137,
           -0.781530248162374,
           -0.7688664283985145,
           -0.7563702950153421,
           -0.7440626875993108,
           -0.7319653200694856,
           -0.7201007831412811,
           -0.7084925366103402,
           -0.6971648892979965,
           -0.686142964304937,
           -0.6754526470677649,
           -0.6651205136285488,
           -0.6551737365390056,
           -0.6456399659611873,
           -0.6365471838298183,
           -0.6279235294411093,
           -0.6197970955572519,
           -0.612195695082782,
           -0.6051465995800558,
           -0.5986762523247166,
           -0.5928099602082236,
           -0.5875715704911072,
           -0.5829831400833387,
           -0.5790646065357186,
           -0.5758334711109545,
           -0.5733045050079809,
           -0.5714894899021989,
           -0.5703970033454606,
           -0.570032258213805,
           -0.5703970033454613,
           -0.5714894899022005,
           -0.5733045050079831,
           -0.5758334711109575,
           -0.5790646065357221,
           -0.5829831400833432,
           -0.5875715704911123,
           -0.5928099602082293,
           -0.598676252324723,
           -0.6051465995800628,
           -0.6121956950827896,
           -0.6197970955572599,
           -0.6279235294411178,
           -0.6365471838298274,
           -0.645639965961197,
           -0.6551737365390157,
           -0.6651205136285593,
           -0.6754526470677757,
           -0.6861429643049483,
           -0.697164889298008,
           -0.7084925366103519,
           -0.7201007831412932,
           -0.7319653200694977,
           -0.7440626875993233,
           -0.7563702950153549,
           -0.7688664283985275,
           -0.7815302481623871,
           -0.7943417783499271,
           -0.8072818894051528,
           -0.8203322759102248,
           -0.833475430566375,
           -0.8466946154997761,
           -0.859973831794906,
           -0.8732977879988938,
           -0.8866518682008467,
           -0.9000221001694618,
           -0.9133951239290234,
           -0.9267581610666159,
           -0.9400989849903335,
           -0.9534058922977536,
           -0.9666676753642909,
           -0.979873596220768,
           -0.9930133617571901,
           -1.0060771002640907,
           -1.0190553393027855,
           -1.031938984880517,
           -1.0447193018949192,
           -1.0573878958038554,
           -1.0699366954707794,
           -1.0823579371319763,
           -1.0946441494298018,
           -1.1067881394551307,
           -1.1187829797422626,
           -1.130621996160376,
           -1.1422987566469858,
           -1.1538070607306772,
           -1.1651409297924775,
           -1.1762945980175052,
           -1.1872625039909495,
           -1.1980392828948796,
           -1.2086197592648413,
           -1.2189989402676378,
           -1.2291720094640548,
           -1.239134321022609,
           -1.2488813943525738,
           -1.2584089091266897,
           -1.2677127006659337,
           -1.2767887556606465,
           -1.285633208204098,
           -1.2942423361162583,
           -1.3026125575371303,
           -1.3107404277704713,
           -1.3186226363601328,
           -1.326256004382528,
           -1.3336374819399621,
           -1.3407641458406676,
           -1.3476331974524596,
           -1.3542419607178862,
           -1.3605878803196663,
           -1.3666685199860624,
           -1.372481560926616,
           -1.3780248003894129,
           -1.3832961503317345,
           -1.3882936361965874,
           -1.3930153957882032,
           -1.397459678240157,
           -1.4016248430702751,
           -1.4055093593169936,
           -1.4091118047522846,
           -1.4124308651667006,
           -1.4154653337224974,
           -1.4182141103711656,
           -1.4206762013320868,
           -1.4228507186293498,
           -1.4247368796841098,
           -1.4263340069601775,
           -1.427641527660831,
           -1.4286589734751243,
           -1.4293859803722595,
           -1.429822288442854
          ],
          [
           -1.404691135723312,
           -1.4045517698690921,
           -1.404133724185038,
           -1.403437154330944,
           -1.4024623198198465,
           -1.401209584138526,
           -1.3996794149171004,
           -1.397872384148585,
           -1.3957891684595651,
           -1.3934305494334072,
           -1.390797413987682,
           -1.3878907548077806,
           -1.384711670838974,
           -1.3812613678394914,
           -1.3775411589974875,
           -1.3735524656151208,
           -1.369296817863288,
           -1.3647758556109504,
           -1.3599913293333439,
           -1.3549451011037956,
           -1.3496391456742824,
           -1.3440755516503233,
           -1.3382565227662893,
           -1.3321843792677133,
           -1.325861559407739,
           -1.319290621065416,
           -1.312474243494175,
           -1.3054152292094647,
           -1.298116506025235,
           -1.2905811292496947,
           -1.2828122840515594,
           -1.2748132880088525,
           -1.2665875938532034,
           -1.2581387924235583,
           -1.2494706158441884,
           -1.240586940942983,
           -1.2314917929271014,
           -1.222189349334257,
           -1.2126839442791435,
           -1.2029800730157956,
           -1.1930823968380362,
           -1.1829957483415516,
           -1.1727251370725555,
           -1.1622757555894856,
           -1.1516529859656197,
           -1.1408624067619915,
           -1.1299098005013923,
           -1.118801161675639,
           -1.1075427053195315,
           -1.0961408761860598,
           -1.0846023585582976,
           -1.0729340867340424,
           -1.0611432562194854,
           -1.0492373356679265,
           -1.0372240795986547,
           -1.0251115419294328,
           -1.012908090353351,
           -1.000622421586938,
           -0.9882635775110435,
           -0.97584096221884,
           -0.963364359975938,
           -0.9508439540856547,
           -0.9382903466374083,
           -0.925714579097475,
           -0.9131281536783002,
           -0.9005430553944825,
           -0.8879717746796729,
           -0.8754273303981215,
           -0.8629232930365409,
           -0.8504738078055017,
           -0.83809361731378,
           -0.8257980834032365,
           -0.8136032076452386,
           -0.8015256499020318,
           -0.7895827442478967,
           -0.7777925114260434,
           -0.7661736668894777,
           -0.7547456233400222,
           -0.7435284865431435,
           -0.7325430430626726,
           -0.7218107384362742,
           -0.7113536442091472,
           -0.701194412171736,
           -0.6913562141213213,
           -0.6818626655034284,
           -0.6727377314046801,
           -0.6640056135821936,
           -0.6556906175429852,
           -0.6478169991442185,
           -0.6404087907800609,
           -0.6334896079535425,
           -0.6270824378909208,
           -0.6212094128164496,
           -0.6158915715261906,
           -0.6111486139236479,
           -0.6069986541363735,
           -0.6034579786400925,
           -0.6005408163910112,
           -0.598259128229155,
           -0.5966224227032567,
           -0.5956376049441885,
           -0.5953088642766879,
           -0.5956376049441893,
           -0.596622422703258,
           -0.5982591282291571,
           -0.6005408163910138,
           -0.603457978640096,
           -0.6069986541363775,
           -0.6111486139236526,
           -0.6158915715261957,
           -0.6212094128164554,
           -0.6270824378909271,
           -0.6334896079535494,
           -0.6404087907800684,
           -0.6478169991442264,
           -0.6556906175429936,
           -0.6640056135822023,
           -0.6727377314046894,
           -0.6818626655034381,
           -0.6913562141213313,
           -0.7011944121717463,
           -0.7113536442091579,
           -0.7218107384362851,
           -0.7325430430626838,
           -0.743528486543155,
           -0.7547456233400338,
           -0.7661736668894895,
           -0.7777925114260554,
           -0.7895827442479089,
           -0.8015256499020441,
           -0.8136032076452512,
           -0.8257980834032492,
           -0.8380936173137927,
           -0.8504738078055146,
           -0.8629232930365538,
           -0.8754273303981343,
           -0.8879717746796859,
           -0.9005430553944954,
           -0.9131281536783133,
           -0.9257145790974879,
           -0.9382903466374212,
           -0.9508439540856678,
           -0.9633643599759509,
           -0.9758409622188527,
           -0.9882635775110562,
           -1.0006224215869506,
           -1.0129080903533636,
           -1.0251115419294452,
           -1.0372240795986671,
           -1.0492373356679385,
           -1.0611432562194973,
           -1.0729340867340544,
           -1.0846023585583093,
           -1.0961408761860718,
           -1.1075427053195432,
           -1.1188011616756504,
           -1.1299098005014037,
           -1.1408624067620023,
           -1.1516529859656308,
           -1.1622757555894963,
           -1.1727251370725662,
           -1.1829957483415618,
           -1.1930823968380464,
           -1.2029800730158053,
           -1.2126839442791535,
           -1.2221893493342668,
           -1.2314917929271108,
           -1.2405869409429922,
           -1.2494706158441975,
           -1.258138792423567,
           -1.2665875938532123,
           -1.2748132880088605,
           -1.2828122840515677,
           -1.2905811292497025,
           -1.2981165060252426,
           -1.305415229209472,
           -1.312474243494182,
           -1.319290621065423,
           -1.3258615594077456,
           -1.3321843792677195,
           -1.3382565227662953,
           -1.3440755516503293,
           -1.3496391456742882,
           -1.3549451011038007,
           -1.3599913293333488,
           -1.364775855610955,
           -1.3692968178632925,
           -1.3735524656151248,
           -1.3775411589974913,
           -1.3812613678394952,
           -1.3847116708389775,
           -1.3878907548077837,
           -1.3907974139876849,
           -1.3934305494334098,
           -1.3957891684595674,
           -1.3978723841485872,
           -1.3996794149171026,
           -1.401209584138527,
           -1.4024623198198474,
           -1.403437154330945,
           -1.4041337241850385,
           -1.4045517698690924
          ],
          [
           -1.3799904525392033,
           -1.3798572509059837,
           -1.379457697741456,
           -1.37879194827616,
           -1.377860261311584,
           -1.3766629993464767,
           -1.3752006287545278,
           -1.373473720014278,
           -1.3714829479923534,
           -1.3692290922813926,
           -1.3667130375942782,
           -1.363935774216565,
           -1.360898398519269,
           -1.357602113534467,
           -1.3540482295964544,
           -1.3502381650515218,
           -1.346173447039724,
           -1.3418557123523582,
           -1.3372867083692273,
           -1.3324682940801142,
           -1.3274024411953107,
           -1.3220912353504215,
           -1.316536877411126,
           -1.3107416848840132,
           -1.304708093440094,
           -1.298438658558088,
           -1.2919360572951413,
           -1.2852030901931526,
           -1.2782426833295168,
           -1.2710578905216863,
           -1.2636518956956162,
           -1.2560280154288535,
           -1.2481897016797268,
           -1.2401405447148672,
           -1.2318842762480535,
           -1.2234247728041987,
           -1.214766059323124,
           -1.2059123130186398,
           -1.1968678675093105,
           -1.1876372172382046,
           -1.1782250221997934,
           -1.1686361129930731,
           -1.1588754962208336,
           -1.1489483602558366,
           -1.138860081395418,
           -1.1286162304267193,
           -1.1182225796253027,
           -1.1076851102103056,
           -1.0970100202794935,
           -1.086203733247489,
           -1.075272906810071,
           -1.0642244424566205,
           -1.0530654955514887,
           -1.0418034860031284,
           -1.0304461095371598,
           -1.019001349585965,
           -1.0074774898027585,
           -0.9958831272021367,
           -0.9842271859216803,
           -0.9725189315899214,
           -0.9607679862746921,
           -0.948984343972113,
           -0.9371783865799401,
           -0.9253609002792378,
           -0.913543092224948,
           -0.9017366074184048,
           -0.8899535456027362,
           -0.87820647798493,
           -0.8665084635456244,
           -0.8548730646491098,
           -0.8433143616112221,
           -0.8318469658216965,
           -0.8204860309502219,
           -0.8092472616922738,
           -0.7981469194326689,
           -0.7872018241229968,
           -0.7764293515856808,
           -0.765847425375188,
           -0.7554745022496172,
           -0.7453295502383173,
           -0.7354320182392706,
           -0.725801796050836,
           -0.7164591637442568,
           -0.7074247293252395,
           -0.698719353724538,
           -0.6903640623084886,
           -0.6823799423196656,
           -0.674788025952298,
           -0.6676091591407661,
           -0.6608638565919467,
           -0.6545721441171725,
           -0.6487533899038328,
           -0.6434261269890796,
           -0.6386078698294421,
           -0.6343149284637993,
           -0.6305622243006994,
           -0.6273631119792253,
           -0.6247292120113075,
           -0.6226702589739831,
           -0.6211939698546166,
           -0.6203059367474075,
           -0.6200095474607966,
           -0.6203059367474082,
           -0.6211939698546178,
           -0.6226702589739849,
           -0.6247292120113098,
           -0.6273631119792283,
           -0.6305622243007031,
           -0.6343149284638036,
           -0.6386078698294467,
           -0.643426126989085,
           -0.6487533899038386,
           -0.6545721441171787,
           -0.6608638565919535,
           -0.6676091591407732,
           -0.6747880259523057,
           -0.6823799423196736,
           -0.6903640623084971,
           -0.698719353724547,
           -0.7074247293252486,
           -0.7164591637442663,
           -0.7258017960508458,
           -0.7354320182392806,
           -0.7453295502383277,
           -0.7554745022496278,
           -0.7658474253751988,
           -0.7764293515856918,
           -0.787201824123008,
           -0.7981469194326802,
           -0.8092472616922854,
           -0.8204860309502334,
           -0.8318469658217083,
           -0.8433143616112339,
           -0.8548730646491218,
           -0.8665084635456364,
           -0.8782064779849421,
           -0.8899535456027484,
           -0.9017366074184167,
           -0.9135430922249603,
           -0.9253609002792499,
           -0.9371783865799521,
           -0.9489843439721253,
           -0.9607679862747043,
           -0.9725189315899334,
           -0.9842271859216923,
           -0.9958831272021487,
           -1.0074774898027703,
           -1.019001349585977,
           -1.0304461095371713,
           -1.0418034860031398,
           -1.0530654955515002,
           -1.064224442456632,
           -1.0752729068100824,
           -1.0862037332475003,
           -1.0970100202795046,
           -1.1076851102103165,
           -1.1182225796253136,
           -1.12861623042673,
           -1.1388600813954282,
           -1.1489483602558466,
           -1.1588754962208436,
           -1.168636112993083,
           -1.1782250221998032,
           -1.187637217238214,
           -1.1968678675093196,
           -1.2059123130186489,
           -1.214766059323133,
           -1.2234247728042071,
           -1.2318842762480622,
           -1.2401405447148757,
           -1.2481897016797352,
           -1.2560280154288612,
           -1.263651895695624,
           -1.2710578905216936,
           -1.2782426833295246,
           -1.2852030901931595,
           -1.2919360572951482,
           -1.298438658558095,
           -1.3047080934401,
           -1.3107416848840192,
           -1.3165368774111312,
           -1.3220912353504266,
           -1.3274024411953163,
           -1.3324682940801194,
           -1.337286708369232,
           -1.3418557123523627,
           -1.346173447039728,
           -1.3502381650515265,
           -1.3540482295964582,
           -1.3576021135344705,
           -1.360898398519272,
           -1.363935774216568,
           -1.3667130375942806,
           -1.369229092281395,
           -1.3714829479923556,
           -1.3734737200142801,
           -1.3752006287545298,
           -1.3766629993464778,
           -1.3778602613115853,
           -1.3787919482761606,
           -1.3794576977414563,
           -1.3798572509059837
          ],
          [
           -1.355889588549581,
           -1.3557626179184155,
           -1.3553817575342837,
           -1.35474716195115,
           -1.3538590888452955,
           -1.3527178991452278,
           -1.3513240572143543,
           -1.3496781310872166,
           -1.3477807927603285,
           -1.3456328185388877,
           -1.3432350894408813,
           -1.3405885916603473,
           -1.3376944170918232,
           -1.3345537639182543,
           -1.3311679372649277,
           -1.3275383499222644,
           -1.3236665231405953,
           -1.319554087500354,
           -1.3152027838614302,
           -1.3106144643957467,
           -1.3057910937074821,
           -1.3007347500456954,
           -1.2954476266144923,
           -1.2899320329862596,
           -1.284190396623888,
           -1.2782252645183316,
           -1.2720393049482914,
           -1.2656353093692518,
           -1.2590161944395928,
           -1.252185004191969,
           -1.245144912358666,
           -1.2378992248601544,
           -1.2304513824666108,
           -1.2228049636427007,
           -1.21496368758648,
           -1.2069314174738324,
           -1.198712163920402,
           -1.1903100886735325,
           -1.1817295085472506,
           -1.1729748996138347,
           -1.1640509016659768,
           -1.1549623229639434,
           -1.1457141452824986,
           -1.1363115292725798,
           -1.1267598201528664,
           -1.1170645537463397,
           -1.107231462876756,
           -1.0972664841395088,
           -1.0871757650606688,
           -1.076965671656959,
           -1.066642796407988,
           -1.056213966650184,
           -1.0456862533993858,
           -1.0350669806059503,
           -1.0243637348423118,
           -1.0135843754181335,
           -1.0027370449123036,
           -0.9918301801039576,
           -0.9808725232761798,
           -0.9698731338559509,
           -0.9588414003419444,
           -0.9477870524577743,
           -0.9367201734519675,
           -0.9256512124470229,
           -0.9145909967181922,
           -0.9035507437577799,
           -0.8925420729526289,
           -0.8815770166708256,
           -0.8706680305183736,
           -0.8598280024876931,
           -0.8490702606772895,
           -0.8384085792161848,
           -0.827857181978105,
           -0.8174307436197986,
           -0.8071443874262957,
           -0.7970136793949271,
           -0.7870546179414823,
           -0.7772836185685081,
           -0.7677174928005145,
           -0.7583734206674521,
           -0.7492689160104907,
           -0.7404217838976584,
           -0.7318500694764086,
           -0.7235719976609922,
           -0.7156059031597508,
           -0.707970150495671,
           -0.7006830438662307,
           -0.6937627269274507,
           -0.6872270728715482,
           -0.6810935654940099,
           -0.6753791723070105,
           -0.6701002111406354,
           -0.6652722120659069,
           -0.6609097768548425,
           -0.6570264385402583,
           -0.6536345239273353,
           -0.6507450221154975,
           -0.6483674621902037,
           -0.6465098032213307,
           -0.6451783395459396,
           -0.6443776240148199,
           -0.6441104114504189,
           -0.6443776240148205,
           -0.6451783395459407,
           -0.6465098032213322,
           -0.6483674621902058,
           -0.6507450221155001,
           -0.6536345239273386,
           -0.657026438540262,
           -0.6609097768548469,
           -0.6652722120659118,
           -0.6701002111406408,
           -0.675379172307016,
           -0.6810935654940159,
           -0.6872270728715546,
           -0.6937627269274576,
           -0.700683043866238,
           -0.7079701504956788,
           -0.7156059031597588,
           -0.7235719976610006,
           -0.7318500694764174,
           -0.7404217838976676,
           -0.7492689160104999,
           -0.7583734206674615,
           -0.7677174928005243,
           -0.777283618568518,
           -0.7870546179414925,
           -0.7970136793949374,
           -0.8071443874263062,
           -0.8174307436198093,
           -0.8278571819781158,
           -0.8384085792161955,
           -0.8490702606773005,
           -0.8598280024877043,
           -0.8706680305183848,
           -0.8815770166708365,
           -0.8925420729526403,
           -0.9035507437577912,
           -0.9145909967182038,
           -0.9256512124470342,
           -0.9367201734519788,
           -0.9477870524577859,
           -0.9588414003419556,
           -0.9698731338559622,
           -0.980872523276191,
           -0.991830180103969,
           -1.002737044912315,
           -1.0135843754181446,
           -1.024363734842323,
           -1.0350669806059611,
           -1.0456862533993967,
           -1.0562139666501946,
           -1.0666427964079988,
           -1.0769656716569693,
           -1.0871757650606795,
           -1.0972664841395188,
           -1.107231462876766,
           -1.1170645537463497,
           -1.1267598201528763,
           -1.1363115292725898,
           -1.1457141452825077,
           -1.1549623229639527,
           -1.1640509016659861,
           -1.1729748996138438,
           -1.1817295085472592,
           -1.1903100886735414,
           -1.1987121639204106,
           -1.2069314174738406,
           -1.214963687586488,
           -1.2228049636427087,
           -1.2304513824666188,
           -1.2378992248601617,
           -1.245144912358673,
           -1.2521850041919764,
           -1.2590161944395997,
           -1.2656353093692583,
           -1.2720393049482979,
           -1.2782252645183383,
           -1.284190396623894,
           -1.2899320329862651,
           -1.2954476266144976,
           -1.3007347500457005,
           -1.3057910937074872,
           -1.3106144643957511,
           -1.3152027838614344,
           -1.3195540875003582,
           -1.323666523140599,
           -1.3275383499222684,
           -1.3311679372649314,
           -1.3345537639182576,
           -1.3376944170918261,
           -1.3405885916603504,
           -1.3432350894408838,
           -1.3456328185388902,
           -1.3477807927603307,
           -1.3496781310872186,
           -1.3513240572143561,
           -1.3527178991452293,
           -1.3538590888452966,
           -1.3547471619511506,
           -1.3553817575342844,
           -1.3557626179184157
          ],
          [
           -1.3324118597838257,
           -1.3322911757895615,
           -1.3319291749878472,
           -1.3313260109480365,
           -1.3304819397062155,
           -1.329397319896312,
           -1.328072612934379,
           -1.3265083832567899,
           -1.3247052986132835,
           -1.3226641304160336,
           -1.3203857541461166,
           -1.3178711498189923,
           -1.3151214025108249,
           -1.3121377029477264,
           -1.3089213481602173,
           -1.305473742205475,
           -1.3017963969601711,
           -1.2978909329869686,
           -1.2937590804780223,
           -1.289402680279094,
           -1.284823684998189,
           -1.280024160202902,
           -1.2750062857109818,
           -1.2697723569789177,
           -1.264324786593683,
           -1.2586661058730972,
           -1.2527989665806014,
           -1.2467261427605878,
           -1.2404505327007778,
           -1.233975161028482,
           -1.227303180947946,
           -1.2204378766263255,
           -1.213382665736195,
           -1.2061411021628259,
           -1.198716878884803,
           -1.1911138310368572,
           -1.1833359391640723,
           -1.1753873326768745,
           -1.1672722935164113,
           -1.15899526004008,
           -1.1505608311370352,
           -1.1419737705834938,
           -1.1332390116475357,
           -1.1243616619528527,
           -1.11534700861049,
           -1.1062005236270342,
           -1.0969278695968925,
           -1.087534905685231,
           -1.0780276939067657,
           -1.0684125057038536,
           -1.0586958288251826,
           -1.0488843745037069,
           -1.0389850849292717,
           -1.0290051410075334,
           -1.018951970392171,
           -1.0088332557719812,
           -0.9986569433880427,
           -0.9884312517487014,
           -0.9781646805014441,
           -0.9678660194107394,
           -0.9575443573794329,
           -0.9472090914381721,
           -0.9368699356124631,
           -0.9265369295601826,
           -0.9162204468536029,
           -0.9059312027591039,
           -0.8956802613447366,
           -0.8854790417206672,
           -0.8753393231903372,
           -0.8652732490611273,
           -0.8552933288326882,
           -0.8454124384493811,
           -0.8356438182710425,
           -0.8260010683844373,
           -0.8164981408473518,
           -0.807149328429661,
           -0.7979692493925619,
           -0.7889728278304103,
           -0.7801752690915554,
           -0.7715920297977186,
           -0.7632387819986172,
           -0.755131371032585,
           -0.74728576671777,
           -0.7397180075748733,
           -0.7324441378836303,
           -0.725480137503016,
           -0.7188418445401684,
           -0.7125448711346667,
           -0.7066045128308649,
           -0.7010356522373452,
           -0.6958526579130437,
           -0.6910692796658457,
           -0.6866985416910963,
           -0.682752635202364,
           -0.679242812401676,
           -0.676179283787615,
           -0.6735711208939892,
           -0.671426166577881,
           -0.6697509549250908,
           -0.6685506427085953,
           -0.6678289541216008,
           -0.6675881402161743,
           -0.6678289541216013,
           -0.6685506427085963,
           -0.6697509549250923,
           -0.6714261665778829,
           -0.6735711208939915,
           -0.676179283787618,
           -0.6792428124016794,
           -0.6827526352023677,
           -0.6866985416911007,
           -0.6910692796658504,
           -0.695852657913049,
           -0.7010356522373508,
           -0.7066045128308708,
           -0.712544871134673,
           -0.7188418445401752,
           -0.7254801375030232,
           -0.7324441378836377,
           -0.7397180075748809,
           -0.747285766717778,
           -0.7551313710325931,
           -0.7632387819986255,
           -0.7715920297977271,
           -0.7801752690915644,
           -0.7889728278304194,
           -0.7979692493925711,
           -0.8071493284296706,
           -0.8164981408473615,
           -0.8260010683844474,
           -0.8356438182710524,
           -0.8454124384493911,
           -0.8552933288326984,
           -0.8652732490611377,
           -0.8753393231903478,
           -0.8854790417206775,
           -0.895680261344747,
           -0.9059312027591144,
           -0.9162204468536136,
           -0.9265369295601932,
           -0.9368699356124739,
           -0.9472090914381829,
           -0.9575443573794435,
           -0.9678660194107499,
           -0.9781646805014546,
           -0.988431251748712,
           -0.998656943388053,
           -1.0088332557719915,
           -1.0189519703921817,
           -1.0290051410075436,
           -1.0389850849292819,
           -1.0488843745037169,
           -1.0586958288251929,
           -1.0684125057038634,
           -1.0780276939067757,
           -1.087534905685241,
           -1.0969278695969022,
           -1.1062005236270438,
           -1.1153470086104995,
           -1.1243616619528618,
           -1.1332390116475448,
           -1.1419737705835027,
           -1.150560831137044,
           -1.1589952600400886,
           -1.1672722935164197,
           -1.175387332676883,
           -1.1833359391640805,
           -1.191113831036865,
           -1.1987168788848106,
           -1.2061411021628334,
           -1.2133826657362023,
           -1.2204378766263326,
           -1.2273031809479529,
           -1.2339751610284886,
           -1.2404505327007842,
           -1.2467261427605942,
           -1.2527989665806076,
           -1.2586661058731035,
           -1.2643247865936886,
           -1.2697723569789228,
           -1.275006285710987,
           -1.280024160202907,
           -1.2848236849981938,
           -1.2894026802790988,
           -1.2937590804780266,
           -1.2978909329869728,
           -1.301796396960175,
           -1.3054737422054787,
           -1.3089213481602204,
           -1.3121377029477295,
           -1.3151214025108278,
           -1.3178711498189948,
           -1.3203857541461193,
           -1.3226641304160358,
           -1.3247052986132855,
           -1.3265083832567917,
           -1.328072612934381,
           -1.3293973198963132,
           -1.3304819397062164,
           -1.3313260109480372,
           -1.3319291749878477,
           -1.3322911757895617
          ],
          [
           -1.309579979428233,
           -1.309465625315556,
           -1.3091226137073928,
           -1.3085510968192071,
           -1.307751328429737,
           -1.3067236640107667,
           -1.3054685609094516,
           -1.303986578583858,
           -1.3022783788925385,
           -1.3003447264391872,
           -1.2981864889735861,
           -1.2958046378502603,
           -1.2932002485464555,
           -1.2903745012412453,
           -1.2873286814577953,
           -1.2840641807709967,
           -1.280582497582915,
           -1.2768852379686997,
           -1.2729741165958248,
           -1.268850957719755,
           -1.2645176962593543,
           -1.259976378955585,
           -1.2552291656172787,
           -1.250278330457995,
           -1.2451262635282128,
           -1.2397754722473464,
           -1.2342285830402997,
           -1.2284883430835154,
           -1.2225576221656926,
           -1.2164394146685698,
           -1.2101368416733758,
           -1.2036531531987473,
           -1.1969917305760809,
           -1.1901560889684453,
           -1.1831498800392928,
           -1.1759768947773002,
           -1.1686410664837033,
           -1.161146473928476,
           -1.1534973446816226,
           -1.145698058625694,
           -1.1377531516553836,
           -1.1296673195697058,
           -1.1214454221617514,
           -1.1130924875103931,
           -1.104613716477491,
           -1.096014487413118,
           -1.0873003610700889,
           -1.078477085727541,
           -1.0695506025214767,
           -1.0605270509780047,
           -1.0514127747424074,
           -1.0422143274941253,
           -1.0329384790341858,
           -1.0235922215274533,
           -1.0141827758773025,
           -1.0047175982047962,
           -0.9952043863981512,
           -0.9856510866910997,
           -0.9760659002206182,
           -0.9664572895053419,
           -0.9568339847757064,
           -0.9472049900754336,
           -0.9375795890413131,
           -0.927967350254311,
           -0.918378132039863,
           -0.9088220865787727,
           -0.899309663172536,
           -0.8898516104882706,
           -0.8804589775889028,
           -0.8711431135341889,
           -0.8619156653178288,
           -0.8527885738859015,
           -0.8437740679627159,
           -0.8348846553926655,
           -0.8261331116917427,
           -0.8175324654910634,
           -0.8090959805483104,
           -0.8008371340028101,
           -0.7927695905575168,
           -0.7849071722881086,
           -0.7772638238072945,
           -0.7698535725529236,
           -0.7626904840229913,
           -0.7557886118503273,
           -0.7491619426954249,
           -0.7428243360377133,
           -0.7367894590630863,
           -0.7310707169772979,
           -0.7256811792185143,
           -0.7206335021943904,
           -0.7159398493248735,
           -0.7116118093258438,
           -0.7076603138140242,
           -0.7040955554430021,
           -0.700926907886073,
           -0.698162849056417,
           -0.6958108889920065,
           -0.6938775038260189,
           -0.6923680772095285,
           -0.691286850450299,
           -0.690636882480591,
           -0.690420020571767,
           -0.6906368824805914,
           -0.6912868504502999,
           -0.6923680772095298,
           -0.6938775038260208,
           -0.6958108889920086,
           -0.6981628490564197,
           -0.7009269078860761,
           -0.7040955554430056,
           -0.7076603138140282,
           -0.711611809325848,
           -0.7159398493248781,
           -0.7206335021943954,
           -0.7256811792185196,
           -0.7310707169773035,
           -0.7367894590630925,
           -0.7428243360377198,
           -0.7491619426954317,
           -0.7557886118503342,
           -0.7626904840229988,
           -0.7698535725529312,
           -0.7772638238073022,
           -0.7849071722881166,
           -0.7927695905575249,
           -0.8008371340028184,
           -0.8090959805483191,
           -0.8175324654910722,
           -0.8261331116917516,
           -0.8348846553926746,
           -0.8437740679627251,
           -0.8527885738859108,
           -0.8619156653178383,
           -0.8711431135341985,
           -0.8804589775889123,
           -0.8898516104882804,
           -0.8993096631725458,
           -0.9088220865787825,
           -0.9183781320398728,
           -0.9279673502543206,
           -0.937579589041323,
           -0.9472049900754437,
           -0.9568339847757162,
           -0.9664572895053518,
           -0.9760659002206281,
           -0.9856510866911095,
           -0.995204386398161,
           -1.004717598204806,
           -1.0141827758773123,
           -1.0235922215274629,
           -1.0329384790341953,
           -1.042214327494135,
           -1.0514127747424167,
           -1.0605270509780138,
           -1.0695506025214858,
           -1.07847708572755,
           -1.087300361070098,
           -1.0960144874131268,
           -1.1046137164774998,
           -1.1130924875104018,
           -1.1214454221617596,
           -1.1296673195697144,
           -1.1377531516553918,
           -1.1456980586257017,
           -1.1534973446816306,
           -1.1611464739284838,
           -1.1686410664837108,
           -1.1759768947773073,
           -1.1831498800393,
           -1.1901560889684524,
           -1.1969917305760878,
           -1.203653153198754,
           -1.2101368416733824,
           -1.2164394146685762,
           -1.2225576221656989,
           -1.2284883430835214,
           -1.2342285830403057,
           -1.2397754722473522,
           -1.2451262635282183,
           -1.250278330458,
           -1.2552291656172834,
           -1.2599763789555896,
           -1.2645176962593592,
           -1.2688509577197595,
           -1.2729741165958288,
           -1.2768852379687032,
           -1.2805824975829183,
           -1.284064180771,
           -1.2873286814577987,
           -1.2903745012412486,
           -1.2932002485464582,
           -1.2958046378502628,
           -1.2981864889735883,
           -1.3003447264391892,
           -1.3022783788925403,
           -1.30398657858386,
           -1.3054685609094532,
           -1.3067236640107676,
           -1.3077513284297382,
           -1.3085510968192076,
           -1.309122613707393,
           -1.3094656253155563
          ],
          [
           -1.2874160358524733,
           -1.2873080411921152,
           -1.2869841073466637,
           -1.2864443847480778,
           -1.2856891241999893,
           -1.284718677003533,
           -1.283533495134061,
           -1.282134131469294,
           -1.2805212400696269,
           -1.278695576511458,
           -1.2766579982745783,
           -1.2744094651848155,
           -1.2719510399132927,
           -1.269283888533825,
           -1.266409281140137,
           -1.2633285925247635,
           -1.2600433029216402,
           -1.2565549988145825,
           -1.252865373814,
           -1.2489762296043627,
           -1.2448894769651089,
           -1.2406071368678424,
           -1.2361313416528217,
           -1.231464336287914,
           -1.226608479713325,
           -1.2215662462755685,
           -1.2163402272542732,
           -1.2109331324855441,
           -1.205347792085714,
           -1.1995871582794106,
           -1.1936543073359316,
           -1.1875524416179801,
           -1.1812848917468182,
           -1.1748551188878915,
           -1.1682667171609011,
           -1.1615234161782129,
           -1.1546290837153075,
           -1.1475877285167526,
           -1.1404035032408633,
           -1.1330807075458178,
           -1.125623791319484,
           -1.1180373580545946,
           -1.11032616837014,
           -1.10249514367893,
           -1.0945493700001865,
           -1.0864941019147178,
           -1.078334766658712,
           -1.0700769683503968,
           -1.0617264923417407,
           -1.0532893096849851,
           -1.044771581701037,
           -1.0361796646336023,
           -1.0275201143693582,
           -1.0187996912003825,
           -1.0100253646004713,
           -1.0012043179817953,
           -0.9923439533925836,
           -0.9834518961100671,
           -0.9745359990757997,
           -0.9656043471126128,
           -0.9566652608538652,
           -0.9477273003062868,
           -0.9387992679576187,
           -0.9298902113294117,
           -0.9210094248638566,
           -0.9121664510214358,
           -0.9033710804536452,
           -0.8946333511022175,
           -0.8859635460633869,
           -0.8773721900430855,
           -0.868870044216894,
           -0.8604680992975104,
           -0.8521775666030064,
           -0.8440098669117485,
           -0.8359766168853296,
           -0.8280896128398884,
           -0.8203608116496731,
           -0.8128023085754985,
           -0.8054263118257697,
           -0.7982451136799333,
           -0.7912710580343942,
           -0.7845165042698801,
           -0.7779937873875125,
           -0.7717151744187756,
           -0.765692817182178,
           -0.7599387015362623,
           -0.7544645933638611,
           -0.7492819816146772,
           -0.7444020188303829,
           -0.7398354596758594,
           -0.735592598098737,
           -0.7316832038333559,
           -0.7281164590505612,
           -0.724900896027066,
           -0.7220443367631779,
           -0.719553835511451,
           -0.717435625187787,
           -0.715695068618028,
           -0.7143366155255092,
           -0.7133637660881095,
           -0.7127790417881408,
           -0.7125839641475267,
           -0.7127790417881411,
           -0.7133637660881101,
           -0.7143366155255104,
           -0.7156950686180296,
           -0.7174356251877889,
           -0.7195538355114535,
           -0.7220443367631808,
           -0.7249008960270692,
           -0.7281164590505648,
           -0.7316832038333599,
           -0.7355925980987412,
           -0.7398354596758637,
           -0.7444020188303876,
           -0.7492819816146824,
           -0.7544645933638666,
           -0.7599387015362681,
           -0.7656928171821841,
           -0.771715174418782,
           -0.777993787387519,
           -0.784516504269887,
           -0.7912710580344013,
           -0.7982451136799407,
           -0.8054263118257771,
           -0.8128023085755062,
           -0.8203608116496809,
           -0.8280896128398965,
           -0.8359766168853379,
           -0.8440098669117568,
           -0.8521775666030146,
           -0.8604680992975189,
           -0.8688700442169026,
           -0.8773721900430944,
           -0.8859635460633957,
           -0.8946333511022265,
           -0.9033710804536543,
           -0.9121664510214449,
           -0.9210094248638658,
           -0.929890211329421,
           -0.9387992679576281,
           -0.9477273003062961,
           -0.9566652608538743,
           -0.965604347112622,
           -0.9745359990758089,
           -0.9834518961100764,
           -0.9923439533925928,
           -1.0012043179818044,
           -1.0100253646004804,
           -1.0187996912003918,
           -1.027520114369367,
           -1.0361796646336112,
           -1.044771581701046,
           -1.0532893096849938,
           -1.061726492341749,
           -1.0700769683504052,
           -1.0783347666587206,
           -1.086494101914726,
           -1.0945493700001947,
           -1.1024951436789379,
           -1.1103261683701477,
           -1.1180373580546026,
           -1.1256237913194915,
           -1.1330807075458253,
           -1.1404035032408706,
           -1.14758772851676,
           -1.1546290837153146,
           -1.1615234161782197,
           -1.168266717160908,
           -1.174855118887898,
           -1.181284891746825,
           -1.1875524416179863,
           -1.1936543073359378,
           -1.1995871582794166,
           -1.20534779208572,
           -1.2109331324855497,
           -1.216340227254279,
           -1.221566246275574,
           -1.2266084797133299,
           -1.2314643362879187,
           -1.2361313416528263,
           -1.2406071368678468,
           -1.244889476965113,
           -1.2489762296043665,
           -1.2528653738140039,
           -1.256554998814586,
           -1.2600433029216436,
           -1.2633285925247666,
           -1.2664092811401402,
           -1.2692838885338278,
           -1.2719510399132954,
           -1.274409465184818,
           -1.2766579982745807,
           -1.2786955765114603,
           -1.2805212400696289,
           -1.2821341314692953,
           -1.2835334951340622,
           -1.2847186770035341,
           -1.28568912419999,
           -1.2864443847480784,
           -1.2869841073466641,
           -1.2873080411921154
          ],
          [
           -1.2659414712405206,
           -1.2658398506164779,
           -1.265535038123436,
           -1.2650271819224537,
           -1.264316529028012,
           -1.2634034254273159,
           -1.2622883162477652,
           -1.2609717459730423,
           -1.2594543587083935,
           -1.257736898495813,
           -1.255820209679953,
           -1.2537052373257243,
           -1.2513930276886733,
           -1.248884728739339,
           -1.2461815907429272,
           -1.243284966895766,
           -1.2401963140200998,
           -1.236917193318941,
           -1.2334492711927678,
           -1.2297943201199981,
           -1.225954219603263,
           -1.2219309571836008,
           -1.21772662952479,
           -1.2133434435701187,
           -1.2087837177739684,
           -1.2040498834106301,
           -1.1991444859628437,
           -1.1940701865925574,
           -1.1888297636964187,
           -1.1834261145484946,
           -1.1778622570326678,
           -1.1721413314670848,
           -1.1662666025229123,
           -1.1602414612395107,
           -1.154069427137915,
           -1.1477541504342637,
           -1.141299414354484,
           -1.1347091375511447,
           -1.1279873766229087,
           -1.1211383287364345,
           -1.1141663343499086,
           -1.1070758800365808,
           -1.0998716014057417,
           -1.092558286117507,
           -1.0851408769865198,
           -1.077624475168244,
           -1.0700143434198919,
           -1.062315909426157,
           -1.0545347691778082,
           -1.0466766903888196,
           -1.0387476159350146,
           -1.0307536672942086,
           -1.0227011479644696,
           -1.0145965468333922,
           -1.0064465414671633,
           -0.9982580012836534,
           -0.990037990568798,
           -0.9817937712901134,
           -0.9735328056553169,
           -0.9652627583576955,
           -0.9569914984430987,
           -0.948727100726244,
           -0.9404778466764712,
           -0.9322522246852005,
           -0.9240589296192502,
           -0.9159068615559388,
           -0.907805123587689,
           -0.8997630185758373,
           -0.8917900447257432,
           -0.8838958898483472,
           -0.8760904241673392,
           -0.8683836915264173,
           -0.8607858988481352,
           -0.8533074036949734,
           -0.8459586997850157,
           -0.8387504003194551,
           -0.8316932189876188,
           -0.8247979485278092,
           -0.8180754367395137,
           -0.8115365598648874,
           -0.8051921932852487,
           -0.799053179511911,
           -0.7931302934901251,
           -0.7874342052801432,
           -0.7819754402301483,
           -0.776764336811429,
           -0.7718110023458694,
           -0.7671252669183622,
           -0.7627166358306408,
           -0.7585942410164456,
           -0.7547667918987904,
           -0.7512425262260796,
           -0.7480291614725159,
           -0.7451338474271396,
           -0.7425631206226448,
           -0.7403228612676532,
           -0.7384182533426896,
           -0.7368537484994595,
           -0.7356330343646077,
           -0.7347590077930711,
           -0.7342337535433784,
           -0.7340585287594793,
           -0.7342337535433787,
           -0.7347590077930719,
           -0.7356330343646088,
           -0.736853748499461,
           -0.7384182533426914,
           -0.7403228612676555,
           -0.7425631206226474,
           -0.7451338474271426,
           -0.7480291614725192,
           -0.751242526226083,
           -0.754766791898794,
           -0.7585942410164497,
           -0.7627166358306453,
           -0.7671252669183669,
           -0.7718110023458745,
           -0.7767643368114343,
           -0.7819754402301539,
           -0.787434205280149,
           -0.7931302934901312,
           -0.7990531795119173,
           -0.805192193285255,
           -0.811536559864894,
           -0.8180754367395204,
           -0.8247979485278162,
           -0.8316932189876259,
           -0.8387504003194626,
           -0.8459586997850232,
           -0.8533074036949809,
           -0.8607858988481429,
           -0.8683836915264251,
           -0.8760904241673472,
           -0.8838958898483553,
           -0.8917900447257513,
           -0.8997630185758454,
           -0.9078051235876973,
           -0.9159068615559471,
           -0.9240589296192587,
           -0.9322522246852087,
           -0.9404778466764797,
           -0.9487271007262527,
           -0.9569914984431073,
           -0.965262758357704,
           -0.9735328056553254,
           -0.981793771290122,
           -0.9900379905688065,
           -0.9982580012836618,
           -1.0064465414671715,
           -1.0145965468334004,
           -1.022701147964478,
           -1.030753667294217,
           -1.0387476159350226,
           -1.0466766903888276,
           -1.0545347691778162,
           -1.062315909426165,
           -1.0700143434198999,
           -1.0776244751682518,
           -1.0851408769865276,
           -1.0925582861175145,
           -1.099871601405749,
           -1.107075880036588,
           -1.1141663343499157,
           -1.1211383287364416,
           -1.1279873766229158,
           -1.134709137551152,
           -1.1412994143544906,
           -1.14775415043427,
           -1.1540694271379215,
           -1.160241461239517,
           -1.1662666025229185,
           -1.1721413314670908,
           -1.1778622570326738,
           -1.1834261145485,
           -1.1888297636964242,
           -1.1940701865925627,
           -1.1991444859628488,
           -1.204049883410635,
           -1.208783717773973,
           -1.2133434435701234,
           -1.2177266295247937,
           -1.221930957183605,
           -1.2259542196032671,
           -1.229794320120002,
           -1.2334492711927711,
           -1.2369171933189445,
           -1.2401963140201029,
           -1.243284966895769,
           -1.2461815907429303,
           -1.2488847287393414,
           -1.2513930276886756,
           -1.2537052373257263,
           -1.255820209679955,
           -1.257736898495815,
           -1.2594543587083953,
           -1.260971745973044,
           -1.2622883162477667,
           -1.263403425427317,
           -1.264316529028013,
           -1.2650271819224541,
           -1.2655350381234363,
           -1.2658398506164779
          ],
          [
           -1.2451770608467245,
           -1.2450818125276055,
           -1.2447961160127106,
           -1.244320116651435,
           -1.2436540567661911,
           -1.2427982757627,
           -1.241753210284753,
           -1.2405193944137598,
           -1.2390974599135294,
           -1.237488136520812,
           -1.235692252282218,
           -1.2337107339382274,
           -1.2315446073550913,
           -1.229194998005514,
           -1.2266631314990828,
           -1.2239503341634996,
           -1.2210580336777388,
           -1.2179877597583244,
           -1.214741144899996,
           -1.211319925172068,
           -1.2077259410718642,
           -1.2039611384366198,
           -1.2000275694153035,
           -1.1959273935017962,
           -1.1916628786308934,
           -1.1872364023385669,
           -1.182650452987893,
           -1.1779076310619996,
           -1.1730106505253064,
           -1.1679623402542214,
           -1.16276564553832,
           -1.1574236296528548,
           -1.1519394755032355,
           -1.1463164873418408,
           -1.140558092557232,
           -1.1346678435354478,
           -1.1286494195926324,
           -1.1225066289777434,
           -1.1162434109434896,
           -1.1098638378829746,
           -1.1033721175287485,
           -1.0967725952100735,
           -1.0900697561632102,
           -1.0832682278883854,
           -1.076372782545821,
           -1.0693883393817523,
           -1.062319967173754,
           -1.0551728866828898,
           -1.0479524730981855,
           -1.0406642584567303,
           -1.0333139340202377,
           -1.025907352586231,
           -1.0184505307090634,
           -1.0109496508027813,
           -1.0034110630943662,
           -0.9958412873921342,
           -0.9882470146300507,
           -0.980635108144429,
           -0.9730126046349176,
           -0.965386714756915,
           -0.9577648232875485,
           -0.9501544888022131,
           -0.9425634427933982,
           -0.9349995881582586,
           -0.9274709969761274,
           -0.9199859074921113,
           -0.9125527202181178,
           -0.90517999305833,
           -0.8978764353624242,
           -0.8906509008069328,
           -0.8835123790033058,
           -0.8764699857306724,
           -0.8695329516923168,
           -0.8627106096977527,
           -0.8560123801772841,
           -0.8494477549434116,
           -0.8430262791236387,
           -0.8367575312024411,
           -0.8306511011266232,
           -0.8247165664481769,
           -0.8189634665021817,
           -0.8134012746442881,
           -0.8080393686027976,
           -0.8028869990340609,
           -0.7979532564065213,
           -0.793247036377652,
           -0.7887770038686034,
           -0.784551556082669,
           -0.7805787847546832,
           -0.7768664379579464,
           -0.7734218818319499,
           -0.7702520626266272,
           -0.7673634694856949,
           -0.7647620984114698,
           -0.7624534178651139,
           -0.7604423364584489,
           -0.7587331731854986,
           -0.7573296306231999,
           -0.7562347715011751,
           -0.755450999000297,
           -0.754980041089729,
           -0.7548229391532756,
           -0.7549800410897294,
           -0.7554509990002977,
           -0.7562347715011761,
           -0.7573296306232012,
           -0.7587331731855003,
           -0.7604423364584509,
           -0.7624534178651161,
           -0.7647620984114725,
           -0.7673634694856977,
           -0.7702520626266304,
           -0.7734218818319532,
           -0.7768664379579501,
           -0.7805787847546872,
           -0.7845515560826734,
           -0.7887770038686079,
           -0.7932470363776569,
           -0.7979532564065264,
           -0.8028869990340661,
           -0.8080393686028031,
           -0.8134012746442937,
           -0.8189634665021874,
           -0.824716566448183,
           -0.8306511011266294,
           -0.8367575312024473,
           -0.8430262791236454,
           -0.8494477549434184,
           -0.856012380177291,
           -0.8627106096977597,
           -0.8695329516923239,
           -0.8764699857306795,
           -0.8835123790033131,
           -0.8906509008069403,
           -0.8978764353624317,
           -0.9051799930583375,
           -0.9125527202181255,
           -0.919985907492119,
           -0.9274709969761352,
           -0.9349995881582662,
           -0.942563442793406,
           -0.9501544888022209,
           -0.9577648232875564,
           -0.9653867147569226,
           -0.9730126046349254,
           -0.9806351081444368,
           -0.9882470146300586,
           -0.995841287392142,
           -1.0034110630943742,
           -1.010949650802789,
           -1.0184505307090708,
           -1.0259073525862386,
           -1.033313934020245,
           -1.0406642584567378,
           -1.047952473098193,
           -1.055172886682897,
           -1.0623199671737615,
           -1.0693883393817591,
           -1.0763727825458282,
           -1.0832682278883925,
           -1.0900697561632169,
           -1.0967725952100804,
           -1.1033721175287552,
           -1.1098638378829813,
           -1.116243410943496,
           -1.12250662897775,
           -1.1286494195926386,
           -1.1346678435354538,
           -1.140558092557238,
           -1.1463164873418465,
           -1.1519394755032413,
           -1.1574236296528606,
           -1.1627656455383253,
           -1.1679623402542265,
           -1.1730106505253115,
           -1.1779076310620045,
           -1.182650452987898,
           -1.1872364023385718,
           -1.1916628786308978,
           -1.1959273935018004,
           -1.200027569415308,
           -1.203961138436624,
           -1.207725941071868,
           -1.2113199251720717,
           -1.2147411448999992,
           -1.2179877597583275,
           -1.2210580336777417,
           -1.2239503341635025,
           -1.2266631314990852,
           -1.2291949980055168,
           -1.2315446073550937,
           -1.2337107339382296,
           -1.2356922522822202,
           -1.237488136520814,
           -1.239097459913531,
           -1.2405193944137611,
           -1.2417532102847546,
           -1.2427982757627012,
           -1.2436540567661913,
           -1.2443201166514357,
           -1.2447961160127112,
           -1.245081812527606
          ],
          [
           -1.2251428928970922,
           -1.225053997507049,
           -1.2247873586470075,
           -1.2243431182670026,
           -1.2237215130163663,
           -1.2229228743427496,
           -1.2219476286309885,
           -1.220796297382034,
           -1.2194694974322358,
           -1.217967941213342,
           -1.2162924370536101,
           -1.2144438895205083,
           -1.2124232998055195,
           -1.2102317661516155,
           -1.2078704843240216,
           -1.2053407481249134,
           -1.2026439499527424,
           -1.1997815814068906,
           -1.1967552339383987,
           -1.193566599547493,
           -1.1902174715286642,
           -1.186709745264018,
           -1.183045419065601,
           -1.1792265950673648,
           -1.1752554801673747,
           -1.1711343870207915,
           -1.1668657350840566,
           -1.162452051710598,
           -1.157895973298218,
           -1.153200246488155,
           -1.1483677294155963,
           -1.1434013930111755,
           -1.138304322352704,
           -1.1330797180660481,
           -1.1277308977736822,
           -1.1222612975890194,
           -1.1166744736541139,
           -1.1109741037177694,
           -1.1051639887504465,
           -1.0992480545916565,
           -1.0932303536247088,
           -1.0871150664727924,
           -1.0809065037093724,
           -1.0746091075747577,
           -1.0682274536894918,
           -1.0617662527538367,
           -1.055230352221151,
           -1.0486247379313218,
           -1.0419545356886326,
           -1.0352250127665066,
           -1.02844157931948,
           -1.0216097896804772,
           -1.014735343519049,
           -1.0078240868336212,
           -1.000882012748057,
           -0.9939152620799024,
           -0.9869301236446334,
           -0.9799330342570356,
           -0.9729305783875428,
           -0.9659294874279991,
           -0.9589366385178907,
           -0.9519590528787097,
           -0.9450038936007588,
           -0.9380784628235205,
           -0.931190198247724,
           -0.9243466689145604,
           -0.9175555701852325,
           -0.9108247178522889,
           -0.9041620413131162,
           -0.897575575735708,
           -0.8910734531475175,
           -0.8846638923800413,
           -0.8783551878049083,
           -0.8721556968018439,
           -0.8660738259051354,
           -0.8601180155832581,
           -0.8542967236163163,
           -0.8486184070480038,
           -0.8430915027029794,
           -0.8377244062769299,
           -0.8325254500251315,
           -0.8275028790959291,
           -0.8226648265780991,
           -0.8180192873552482,
           -0.8135740908859623,
           -0.8093368730548521,
           -0.8053150472664805,
           -0.801515774980751,
           -0.7979459359140076,
           -0.7946120981540841,
           -0.7915204884590417,
           -0.7886769630275319,
           -0.7860869790428248,
           -0.783755567301765,
           -0.7816873062436527,
           -0.7798862976916859,
           -0.7783561446108136,
           -0.7770999311704241,
           -0.7761202053782482,
           -0.775418964523456,
           -0.7749976436326381,
           -0.7748571071029079,
           -0.7749976436326386,
           -0.7754189645234567,
           -0.7761202053782491,
           -0.7770999311704252,
           -0.7783561446108151,
           -0.7798862976916876,
           -0.7816873062436547,
           -0.7837555673017671,
           -0.7860869790428273,
           -0.7886769630275348,
           -0.7915204884590445,
           -0.7946120981540874,
           -0.7979459359140111,
           -0.8015157749807548,
           -0.8053150472664845,
           -0.8093368730548564,
           -0.8135740908859669,
           -0.8180192873552529,
           -0.822664826578104,
           -0.8275028790959343,
           -0.8325254500251367,
           -0.8377244062769353,
           -0.8430915027029849,
           -0.8486184070480096,
           -0.8542967236163223,
           -0.8601180155832642,
           -0.8660738259051417,
           -0.8721556968018502,
           -0.8783551878049147,
           -0.884663892380048,
           -0.8910734531475242,
           -0.8975755757357148,
           -0.9041620413131229,
           -0.9108247178522958,
           -0.9175555701852397,
           -0.9243466689145673,
           -0.9311901982477311,
           -0.9380784628235276,
           -0.9450038936007662,
           -0.9519590528787172,
           -0.9589366385178979,
           -0.9659294874280062,
           -0.97293057838755,
           -0.9799330342570427,
           -0.9869301236446405,
           -0.9939152620799095,
           -1.0008820127480642,
           -1.0078240868336281,
           -1.0147353435190558,
           -1.0216097896804843,
           -1.028441579319487,
           -1.0352250127665137,
           -1.0419545356886393,
           -1.048624737931329,
           -1.055230352221158,
           -1.0617662527538434,
           -1.0682274536894985,
           -1.0746091075747641,
           -1.0809065037093786,
           -1.0871150664727989,
           -1.0932303536247148,
           -1.0992480545916627,
           -1.1051639887504525,
           -1.1109741037177754,
           -1.1166744736541196,
           -1.122261297589025,
           -1.1277308977736877,
           -1.1330797180660537,
           -1.1383043223527096,
           -1.1434013930111804,
           -1.148367729415601,
           -1.1532002464881599,
           -1.1578959732982228,
           -1.1624520517106025,
           -1.1668657350840612,
           -1.171134387020796,
           -1.175255480167379,
           -1.1792265950673686,
           -1.1830454190656048,
           -1.1867097452640218,
           -1.190217471528668,
           -1.1935665995474962,
           -1.1967552339384018,
           -1.1997815814068935,
           -1.202643949952745,
           -1.205340748124916,
           -1.207870484324024,
           -1.210231766151618,
           -1.2124232998055215,
           -1.2144438895205103,
           -1.216292437053612,
           -1.2179679412133437,
           -1.2194694974322373,
           -1.220796297382035,
           -1.22194762863099,
           -1.2229228743427505,
           -1.2237215130163668,
           -1.2243431182670033,
           -1.224787358647008,
           -1.2250539975070494
          ],
          [
           -1.205858349155229,
           -1.2057757683623092,
           -1.2055280719527088,
           -1.2051153978510445,
           -1.2045379759888288,
           -1.20379612839026,
           -1.2028902692924501,
           -1.201820905300214,
           -1.2005886355755675,
           -1.1991941520621279,
           -1.197638239744611,
           -1.1959217769436696,
           -1.1940457356463163,
           -1.192011181872204,
           -1.1898192760760329,
           -1.1874712735863688,
           -1.1849685250811421,
           -1.1823124771000924,
           -1.1795046725944038,
           -1.1765467515137338,
           -1.1734404514308119,
           -1.1701876082037161,
           -1.1667901566758738,
           -1.163250131413743,
           -1.1595696674820328,
           -1.155751001256198,
           -1.1517964712717923,
           -1.147708519110113,
           -1.1434896903193588,
           -1.139142635370315,
           -1.1346701106453152,
           -1.1300749794589506,
           -1.1253602131086593,
           -1.1205288919529752,
           -1.1155842065147876,
           -1.1105294586065149,
           -1.1053680624735671,
           -1.1001035459519155,
           -1.094739551634934,
           -1.0892798380439976,
           -1.0837282807965325,
           -1.0780888737643792,
           -1.0723657302143945,
           -1.0665630839222047,
           -1.0606852902489303,
           -1.0547368271694944,
           -1.0487222962398433,
           -1.0426464234890163,
           -1.036514060220505,
           -1.0303301837057535,
           -1.0240998977509495,
           -1.0178284331164662,
           -1.0115211477664194,
           -1.0051835269238296,
           -0.9988211829048225,
           -0.9924398547031736,
           -0.9860454072943364,
           -0.9796438306258906,
           -0.973241238259139,
           -0.9668438656244216,
           -0.9604580678505846,
           -0.9540903171270622,
           -0.9477471995551706,
           -0.9414354114435944,
           -0.9351617550016939,
           -0.9289331333832693,
           -0.9227565450328423,
           -0.9166390772864741,
           -0.910587899179681,
           -0.9046102534162764,
           -0.8987134474540144,
           -0.8929048436658719,
           -0.8871918485397625,
           -0.8815819008845202,
           -0.8760824590162154,
           -0.8707009869063399,
           -0.8654449392821726,
           -0.8603217456797402,
           -0.855338793461245,
           -0.8505034098215704,
           -0.8458228428224758,
           -0.841304241508196,
           -0.8369546351722469,
           -0.8327809118620558,
           -0.8287897962253592,
           -0.8249878268197974,
           -0.8213813330244342,
           -0.8179764117086352,
           -0.8147789038294142,
           -0.8117943711425187,
           -0.8090280732247344,
           -0.8064849450146354,
           -0.8041695750858923,
           -0.8020861848708204,
           -0.8002386090518285,
           -0.7986302773344918,
           -0.7972641978080114,
           -0.7961429420867635,
           -0.7952686324105528,
           -0.7946429308612872,
           -0.7942670308303844,
           -0.794141650844771,
           -0.7942670308303846,
           -0.7946429308612877,
           -0.7952686324105535,
           -0.7961429420867644,
           -0.7972641978080127,
           -0.7986302773344933,
           -0.8002386090518302,
           -0.8020861848708224,
           -0.8041695750858946,
           -0.806484945014638,
           -0.809028073224737,
           -0.8117943711425217,
           -0.8147789038294173,
           -0.8179764117086387,
           -0.8213813330244377,
           -0.8249878268198014,
           -0.8287897962253633,
           -0.8327809118620599,
           -0.8369546351722515,
           -0.8413042415082006,
           -0.8458228428224804,
           -0.8505034098215752,
           -0.8553387934612499,
           -0.8603217456797453,
           -0.8654449392821778,
           -0.8707009869063455,
           -0.876082459016221,
           -0.881581900884526,
           -0.8871918485397683,
           -0.8929048436658777,
           -0.8987134474540203,
           -0.9046102534162825,
           -0.9105878991796871,
           -0.9166390772864803,
           -0.9227565450328487,
           -0.9289331333832754,
           -0.9351617550017004,
           -0.9414354114436008,
           -0.9477471995551772,
           -0.9540903171270688,
           -0.960458067850591,
           -0.966843865624428,
           -0.9732412382591455,
           -0.9796438306258972,
           -0.9860454072943432,
           -0.9924398547031801,
           -0.9988211829048291,
           -1.005183526923836,
           -1.0115211477664259,
           -1.0178284331164726,
           -1.0240998977509557,
           -1.0303301837057597,
           -1.0365140602205112,
           -1.0426464234890225,
           -1.0487222962398497,
           -1.0547368271695003,
           -1.0606852902489363,
           -1.0665630839222104,
           -1.0723657302144003,
           -1.0780888737643852,
           -1.0837282807965383,
           -1.0892798380440034,
           -1.0947395516349396,
           -1.1001035459519208,
           -1.1053680624735727,
           -1.11052945860652,
           -1.1155842065147927,
           -1.12052889195298,
           -1.1253602131086642,
           -1.1300749794589553,
           -1.13467011064532,
           -1.1391426353703196,
           -1.1434896903193634,
           -1.1477085191101173,
           -1.1517964712717967,
           -1.1557510012562022,
           -1.1595696674820368,
           -1.1632501314137464,
           -1.1667901566758774,
           -1.1701876082037195,
           -1.1734404514308152,
           -1.1765467515137369,
           -1.1795046725944067,
           -1.1823124771000952,
           -1.1849685250811446,
           -1.1874712735863715,
           -1.1898192760760349,
           -1.1920111818722061,
           -1.194045735646318,
           -1.1959217769436714,
           -1.1976382397446128,
           -1.1991941520621294,
           -1.2005886355755688,
           -1.2018209053002151,
           -1.2028902692924517,
           -1.203796128390261,
           -1.2045379759888295,
           -1.2051153978510447,
           -1.2055280719527093,
           -1.2057757683623096
          ],
          [
           -1.187342086171733,
           -1.1872657614138327,
           -1.1870368315505901,
           -1.186655429827572,
           -1.1861217783680427,
           -1.1854361882439555,
           -1.1845990595753704,
           -1.1836108816583129,
           -1.1824722331211077,
           -1.181183782109215,
           -1.1797462864985881,
           -1.1781605941375803,
           -1.1764276431174043,
           -1.1745484620711424,
           -1.172524170501276,
           -1.1703559791356841,
           -1.1680451903120175,
           -1.1655931983903163,
           -1.1630014901936838,
           -1.1602716454767672,
           -1.1574053374217184,
           -1.1544043331612266,
           -1.1512704943281031,
           -1.1480057776307906,
           -1.144612235454032,
           -1.1410920164837761,
           -1.1374473663552347,
           -1.1336806283228,
           -1.1297942439503208,
           -1.1257907538199818,
           -1.121672798257766,
           -1.1174431180731677,
           -1.1131045553104926,
           -1.1086600540087022,
           -1.104112660966355,
           -1.0994655265077418,
           -1.0947219052458175,
           -1.0898851568369914,
           -1.0849587467222488,
           -1.0799462468484289,
           -1.0748513363628018,
           -1.0696778022733213,
           -1.0644295400661277,
           -1.0591105542710018,
           -1.0537249589645457,
           -1.04827697819986,
           -1.042770946350442,
           -1.0372113083549022,
           -1.0316026198479296,
           -1.0259495471616817,
           -1.0202568671805117,
           -1.0145294670305816,
           -1.0087723435845612,
           -1.0029906027601836,
           -0.9971894585900213,
           -0.9913742320384125,
           -0.9855503495400517,
           -0.9797233412333887,
           -0.9738988388606488,
           -0.9680825733050671,
           -0.9622803717348002,
           -0.9564981543220286,
           -0.9507419305049825,
           -0.9450177947600963,
           -0.9393319218512456,
           -0.933690561523097,
           -0.928100032606078,
           -0.9225667165013832,
           -0.9170970500158477,
           -0.9116975175184912,
           -0.9063746423931253,
           -0.9011349777646757,
           -0.8959850964808435,
           -0.8909315803354779,
           -0.8859810085255612,
           -0.8811399453400636,
           -0.876414927086103,
           -0.8718124482658374,
           -0.8673389470262901,
           -0.8630007899138189,
           -0.8588042559750937,
           -0.8547555202571485,
           -0.8508606367701975,
           -0.8471255209882546,
           -0.8435559319740358,
           -0.8401574542258815,
           -0.8369354793553119,
           -0.8338951877140472,
           -0.8310415300986262,
           -0.8283792096688454,
           -0.8259126642228801,
           -0.8236460489768306,
           -0.8215832199993638,
           -0.8197277184528613,
           -0.8180827557908702,
           -0.8166512000575896,
           -0.8154355634285241,
           -0.8144379911223356,
           -0.8136602518023683,
           -0.8131037295724874,
           -0.8127694176559459,
           -0.8126579138282671,
           -0.812769417655946,
           -0.813103729572488,
           -0.813660251802369,
           -0.8144379911223366,
           -0.8154355634285253,
           -0.8166512000575907,
           -0.8180827557908718,
           -0.8197277184528631,
           -0.821583219999366,
           -0.8236460489768328,
           -0.8259126642228826,
           -0.8283792096688479,
           -0.831041530098629,
           -0.8338951877140504,
           -0.8369354793553151,
           -0.840157454225885,
           -0.8435559319740394,
           -0.8471255209882582,
           -0.8508606367702015,
           -0.8547555202571527,
           -0.8588042559750978,
           -0.8630007899138235,
           -0.8673389470262945,
           -0.8718124482658421,
           -0.8764149270861078,
           -0.8811399453400685,
           -0.8859810085255663,
           -0.890931580335483,
           -0.8959850964808486,
           -0.9011349777646811,
           -0.9063746423931307,
           -0.9116975175184965,
           -0.9170970500158533,
           -0.9225667165013888,
           -0.9281000326060839,
           -0.9336905615231028,
           -0.9393319218512516,
           -0.9450177947601021,
           -0.9507419305049882,
           -0.9564981543220346,
           -0.9622803717348062,
           -0.9680825733050729,
           -0.9738988388606546,
           -0.9797233412333947,
           -0.9855503495400576,
           -0.9913742320384182,
           -0.9971894585900271,
           -1.0029906027601894,
           -1.0087723435845672,
           -1.0145294670305876,
           -1.0202568671805174,
           -1.0259495471616875,
           -1.031602619847935,
           -1.0372113083549082,
           -1.0427709463504475,
           -1.0482769781998655,
           -1.0537249589645512,
           -1.059110554271007,
           -1.064429540066133,
           -1.0696778022733269,
           -1.0748513363628072,
           -1.0799462468484342,
           -1.084958746722254,
           -1.0898851568369967,
           -1.0947219052458224,
           -1.0994655265077464,
           -1.1041126609663596,
           -1.1086600540087068,
           -1.1131045553104972,
           -1.117443118073172,
           -1.12167279825777,
           -1.1257907538199858,
           -1.1297942439503248,
           -1.1336806283228038,
           -1.1374473663552385,
           -1.14109201648378,
           -1.1446122354540358,
           -1.1480057776307941,
           -1.1512704943281062,
           -1.1544043331612297,
           -1.1574053374217212,
           -1.16027164547677,
           -1.1630014901936865,
           -1.165593198390319,
           -1.16804519031202,
           -1.1703559791356861,
           -1.172524170501278,
           -1.1745484620711446,
           -1.1764276431174063,
           -1.1781605941375821,
           -1.1797462864985897,
           -1.1811837821092164,
           -1.182472233121109,
           -1.1836108816583137,
           -1.1845990595753715,
           -1.1854361882439566,
           -1.186121778368043,
           -1.1866554298275727,
           -1.1870368315505908,
           -1.1872657614138333
          ],
          [
           -1.1696120172351863,
           -1.1695418685059997,
           -1.1693314649475264,
           -1.1689809344580584,
           -1.1684904902381796,
           -1.167860430845886,
           -1.1670911402736894,
           -1.1661830880476551,
           -1.1651368293482731,
           -1.163953005153077,
           -1.1626323424008633,
           -1.1611756541773535,
           -1.1595838399221021,
           -1.1578578856564137,
           -1.1559988642319778,
           -1.1540079355999004,
           -1.1518863470997267,
           -1.1496354337679935,
           -1.1472566186657802,
           -1.1447514132246255,
           -1.142121417610091,
           -1.1393683211021393,
           -1.1364939024913738,
           -1.1335000304900484,
           -1.1303886641566068,
           -1.1271618533323406,
           -1.123821739088568,
           -1.1203705541825366,
           -1.1168106235200144,
           -1.113144364622299,
           -1.1093742880950928,
           -1.105502998096398,
           -1.1015331928002619,
           -1.0974676648528496,
           -1.0933093018169335,
           -1.0890610866004868,
           -1.084726097864606,
           -1.08030751040552,
           -1.0758085955049135,
           -1.07123272124225,
           -1.066583352762183,
           -1.0618640524895095,
           -1.05707848028347,
           -1.0522303935224686,
           -1.0473236471095693,
           -1.0423621933883251,
           -1.0373500819576995,
           -1.03229145937398,
           -1.0271905687267304,
           -1.0220517490749084,
           -1.0168794347283912,
           -1.0116781543592015,
           -1.006452529925825,
           -1.0012072753930772,
           -0.9959471952290999,
           -0.9906771826601878,
           -0.9854022176633522,
           -0.9801273646757769,
           -0.9748577699996669,
           -0.9695986588804476,
           -0.9643553322358565,
           -0.9591331630132252,
           -0.9539375921521787,
           -0.9487741241301422,
           -0.9436483220684495,
           -0.9385658023775416,
           -0.9335322289207484,
           -0.9285533066775128,
           -0.9236347748886499,
           -0.9187823996684059,
           -0.9140019660706696,
           -0.9092992695997727,
           -0.904680107159869,
           -0.9001502674409481,
           -0.8957155207441087,
           -0.8913816082537942,
           -0.8871542307702633,
           -0.8830390369215941,
           -0.8790416108809833,
           -0.87516745962193,
           -0.8714219997510204,
           -0.8678105439653814,
           -0.8643382871893377,
           -0.8610102924522657,
           -0.8578314765769868,
           -0.8548065957551004,
           -0.8519402310923175,
           -0.8492367742129127,
           -0.8467004130177542,
           -0.844335117694798,
           -0.8421446270843101,
           -0.8401324355032713,
           -0.8383017801342769,
           -0.8366556290836928,
           -0.8351966702117604,
           -0.8339273008337333,
           -0.8328496183859603,
           -0.8319654121441085,
           -0.8312761560725427,
           -0.8307830028743062,
           -0.8304867793003529,
           -0.8303879827648137,
           -0.830486779300353,
           -0.8307830028743066,
           -0.8312761560725433,
           -0.8319654121441092,
           -0.8328496183859613,
           -0.8339273008337345,
           -0.8351966702117617,
           -0.8366556290836945,
           -0.8383017801342787,
           -0.8401324355032733,
           -0.8421446270843124,
           -0.8443351176948002,
           -0.8467004130177567,
           -0.8492367742129153,
           -0.8519402310923204,
           -0.8548065957551035,
           -0.85783147657699,
           -0.861010292452269,
           -0.8643382871893411,
           -0.867810543965385,
           -0.8714219997510241,
           -0.875167459621934,
           -0.8790416108809872,
           -0.8830390369215982,
           -0.8871542307702677,
           -0.8913816082537986,
           -0.8957155207441132,
           -0.9001502674409527,
           -0.9046801071598737,
           -0.9092992695997774,
           -0.9140019660706744,
           -0.9187823996684109,
           -0.9236347748886549,
           -0.9285533066775177,
           -0.9335322289207535,
           -0.9385658023775467,
           -0.943648322068455,
           -0.9487741241301476,
           -0.9539375921521841,
           -0.9591331630132306,
           -0.964355332235862,
           -0.9695986588804529,
           -0.9748577699996723,
           -0.9801273646757823,
           -0.9854022176633577,
           -0.9906771826601932,
           -0.9959471952291055,
           -1.0012072753930825,
           -1.0064525299258302,
           -1.0116781543592068,
           -1.0168794347283965,
           -1.0220517490749137,
           -1.0271905687267355,
           -1.0322914593739854,
           -1.0373500819577046,
           -1.0423621933883305,
           -1.0473236471095744,
           -1.0522303935224737,
           -1.0570784802834747,
           -1.0618640524895144,
           -1.066583352762188,
           -1.071232721242255,
           -1.0758085955049181,
           -1.0803075104055246,
           -1.0847260978646105,
           -1.089061086600491,
           -1.093309301816938,
           -1.0974676648528539,
           -1.1015331928002663,
           -1.105502998096402,
           -1.1093742880950965,
           -1.1131443646223027,
           -1.1168106235200181,
           -1.1203705541825402,
           -1.1238217390885716,
           -1.127161853332344,
           -1.13038866415661,
           -1.1335000304900515,
           -1.1364939024913767,
           -1.1393683211021421,
           -1.1421214176100938,
           -1.1447514132246281,
           -1.1472566186657827,
           -1.1496354337679957,
           -1.1518863470997287,
           -1.1540079355999027,
           -1.1559988642319794,
           -1.1578578856564157,
           -1.159583839922104,
           -1.1611756541773548,
           -1.1626323424008647,
           -1.1639530051530784,
           -1.1651368293482744,
           -1.166183088047656,
           -1.1670911402736905,
           -1.1678604308458864,
           -1.16849049023818,
           -1.1689809344580586,
           -1.1693314649475268,
           -1.169541868506
          ],
          [
           -1.152685295042207,
           -1.1526212197615529,
           -1.1524290345447585,
           -1.152108861275091,
           -1.1516609031171832,
           -1.1510854445557532,
           -1.1503828514496828,
           -1.149553571101327,
           -1.1485981323408772,
           -1.1475171456255748,
           -1.1463113031535075,
           -1.1449813789916814,
           -1.1435282292180138,
           -1.1419527920768135,
           -1.1402560881472807,
           -1.1384392205244587,
           -1.1365033750120235,
           -1.1344498203261837,
           -1.1322799083099033,
           -1.1299950741565283,
           -1.1275968366418145,
           -1.125086798363219,
           -1.1224666459851875,
           -1.119738150489036,
           -1.116903167425851,
           -1.1139636371706843,
           -1.110921585176115,
           -1.1077791222230577,
           -1.10453844466648,
           -1.1012018346734591,
           -1.097771660450739,
           -1.0942503764587055,
           -1.0906405236083696,
           -1.0869447294376648,
           -1.0831657082630073,
           -1.079306261301725,
           -1.0753692767605694,
           -1.0713577298851278,
           -1.0672746829645212,
           -1.0631232852853236,
           -1.0589067730281685,
           -1.054628469100006,
           -1.0502917828944627,
           -1.0459002099722117,
           -1.0414573316527174,
           -1.0369668145081314,
           -1.032432409749547,
           -1.0278579524952198,
           -1.023247360909763,
           -1.018604635202735,
           -1.0139338564744362,
           -1.0092391853961695,
           -1.0045248607116453,
           -0.9997951975457033,
           -0.9950545855060322,
           -0.9903074865631332,
           -0.9855584326934174,
           -0.9808120232700293,
           -0.9760729221858017,
           -0.971345854692662,
           -0.9666356039418494,
           -0.961947007209502,
           -0.9572849517925096,
           -0.9526543705600828,
           -0.9480602371472143,
           -0.9435075607771765,
           -0.9390013807014023,
           -0.934546760246562,
           -0.9301487804603783,
           -0.9258125333497643,
           -0.9215431147071901,
           -0.9173456165238243,
           -0.9132251189909615,
           -0.9091866820944974,
           -0.9052353368107986,
           -0.9013760759161714,
           -0.8976138444262701,
           -0.8939535296861634,
           -0.8903999511363653,
           -0.8869578497848767,
           -0.8836318774201452,
           -0.8804265856047407,
           -0.8773464144944294,
           -0.8743956815320888,
           -0.8715785700705009,
           -0.868899117982364,
           -0.8663612063198076,
           -0.8639685480891713,
           -0.8617246772097336,
           -0.8596329377273557,
           -0.8576964733555557,
           -0.8559182174172705,
           -0.854300883260449,
           -0.8528469552195747,
           -0.8515586801932308,
           -0.8504380599048632,
           -0.8494868439099782,
           -0.8487065234081599,
           -0.8480983259125467,
           -0.8476632108228402,
           -0.8474018659406182,
           -0.847314704957793,
           -0.8474018659406183,
           -0.8476632108228405,
           -0.8480983259125471,
           -0.8487065234081606,
           -0.8494868439099791,
           -0.8504380599048643,
           -0.851558680193232,
           -0.8528469552195762,
           -0.8543008832604506,
           -0.8559182174172723,
           -0.8576964733555577,
           -0.8596329377273577,
           -0.8617246772097358,
           -0.8639685480891738,
           -0.8663612063198103,
           -0.8688991179823667,
           -0.8715785700705037,
           -0.8743956815320917,
           -0.8773464144944326,
           -0.8804265856047441,
           -0.8836318774201485,
           -0.8869578497848801,
           -0.8903999511363688,
           -0.8939535296861671,
           -0.8976138444262738,
           -0.9013760759161754,
           -0.9052353368108025,
           -0.9091866820945014,
           -0.9132251189909657,
           -0.9173456165238286,
           -0.9215431147071944,
           -0.9258125333497689,
           -0.9301487804603826,
           -0.9345467602465665,
           -0.939001380701407,
           -0.943507560777181,
           -0.9480602371472191,
           -0.9526543705600877,
           -0.9572849517925144,
           -0.9619470072095069,
           -0.9666356039418544,
           -0.9713458546926668,
           -0.9760729221858064,
           -0.9808120232700341,
           -0.9855584326934224,
           -0.990307486563138,
           -0.9950545855060371,
           -0.9997951975457082,
           -1.00452486071165,
           -1.0092391853961744,
           -1.0139338564744411,
           -1.0186046352027396,
           -1.0232473609097679,
           -1.0278579524952243,
           -1.0324324097495516,
           -1.036966814508136,
           -1.041457331652722,
           -1.0459002099722163,
           -1.0502917828944671,
           -1.0546284691000105,
           -1.0589067730281727,
           -1.063123285285328,
           -1.0672746829645254,
           -1.071357729885132,
           -1.0753692767605734,
           -1.0793062613017288,
           -1.0831657082630113,
           -1.0869447294376686,
           -1.0906405236083734,
           -1.094250376458709,
           -1.0977716604507424,
           -1.1012018346734622,
           -1.1045384446664837,
           -1.1077791222230609,
           -1.1109215851761183,
           -1.1139636371706876,
           -1.1169031674258536,
           -1.1197381504890387,
           -1.1224666459851904,
           -1.1250867983632213,
           -1.127596836641817,
           -1.1299950741565306,
           -1.1322799083099055,
           -1.1344498203261857,
           -1.1365033750120253,
           -1.1384392205244604,
           -1.1402560881472823,
           -1.1419527920768153,
           -1.1435282292180151,
           -1.144981378991683,
           -1.1463113031535084,
           -1.1475171456255762,
           -1.1485981323408783,
           -1.1495535711013276,
           -1.1503828514496837,
           -1.1510854445557537,
           -1.1516609031171832,
           -1.1521088612750914,
           -1.152429034544759,
           -1.152621219761553
          ],
          [
           -1.1365782951033216,
           -1.1365201670978964,
           -1.1363458214860913,
           -1.1360553734858239,
           -1.1356490151419425,
           -1.1351270153486195,
           -1.1344897198805204,
           -1.1337375514325725,
           -1.1328710096680918,
           -1.1318906712749857,
           -1.1307971900296714,
           -1.1295912968683048,
           -1.1282737999648353,
           -1.1268455848153431,
           -1.125307614328032,
           -1.1236609289181787,
           -1.1219066466072514,
           -1.1200459631253126,
           -1.1180801520157417,
           -1.116010564741183,
           -1.1138386307895316,
           -1.111565857778637,
           -1.1091938315582803,
           -1.1067242163078344,
           -1.10415875462787,
           -1.1014992676238125,
           -1.0987476549795718,
           -1.0959058950188962,
           -1.0929760447519963,
           -1.0899602399047765,
           -1.0868606949277964,
           -1.0836797029818355,
           -1.0804196358967,
           -1.0770829440996383,
           -1.0736721565094467,
           -1.0701898803920777,
           -1.0666388011732306,
           -1.0630216822031044,
           -1.0593413644681517,
           -1.055600766244326,
           -1.0518028826859698,
           -1.0479507853441081,
           -1.0440476216075565,
           -1.0400966140598507,
           -1.0361010597446434,
           -1.0320643293318073,
           -1.0279898661761087,
           -1.0238811852599385,
           -1.0197418720112097,
           -1.0155755809871865,
           -1.011386034414667,
           -1.0071770205766362,
           -1.0029523920352323,
           -0.9987160636806284,
           -0.9944720105952499,
           -0.9902242657226097,
           -0.9859769173299863,
           -0.9817341062541745,
           -0.9775000229196364,
           -0.973278904118578,
           -0.9690750295427709,
           -0.9648927180573703,
           -0.9607363237075236,
           -0.9566102314492618,
           -0.9525188525970167,
           -0.9484666199811091,
           -0.9444579828097418,
           -0.9404974012313965,
           -0.9365893405950719,
           -0.932738265407557,
           -0.9289486329888524,
           -0.9252248868289936,
           -0.9215714496518315,
           -0.9179927161938372,
           -0.9144930457086531,
           -0.9110767542109439,
           -0.9077481064760541,
           -0.904511307815048,
           -0.9013704956478593,
           -0.8983297309004743,
           -0.8953929892552769,
           -0.8925641522868588,
           -0.8898469985186909,
           -0.8872451944390082,
           -0.8847622855170473,
           -0.8824016872633065,
           -0.8801666763797602,
           -0.8780603820478473,
           -0.8760857774035747,
           -0.8742456712501177,
           -0.8725427000588796,
           -0.8709793203099931,
           -0.8695578012227372,
           -0.8682802179252139,
           -0.8671484451109477,
           -0.8661641512277435,
           -0.8653287932412711,
           -0.8646436120123688,
           -0.864109628323076,
           -0.8637276395819227,
           -0.8634982172340773,
           -0.8634217048966784,
           -0.8634982172340775,
           -0.8637276395819231,
           -0.8641096283230767,
           -0.8646436120123693,
           -0.865328793241272,
           -0.8661641512277444,
           -0.8671484451109487,
           -0.8682802179252153,
           -0.8695578012227385,
           -0.8709793203099949,
           -0.8725427000588813,
           -0.8742456712501195,
           -0.8760857774035766,
           -0.8780603820478494,
           -0.8801666763797623,
           -0.8824016872633088,
           -0.8847622855170497,
           -0.8872451944390107,
           -0.8898469985186936,
           -0.8925641522868617,
           -0.8953929892552799,
           -0.8983297309004773,
           -0.9013704956478624,
           -0.9045113078150512,
           -0.9077481064760575,
           -0.9110767542109474,
           -0.9144930457086565,
           -0.9179927161938409,
           -0.9215714496518352,
           -0.9252248868289974,
           -0.9289486329888563,
           -0.9327382654075609,
           -0.9365893405950759,
           -0.9404974012314005,
           -0.944457982809746,
           -0.9484666199811131,
           -0.9525188525970211,
           -0.956610231449266,
           -0.9607363237075278,
           -0.9648927180573748,
           -0.9690750295427754,
           -0.9732789041185823,
           -0.9775000229196409,
           -0.9817341062541787,
           -0.9859769173299906,
           -0.9902242657226141,
           -0.9944720105952544,
           -0.9987160636806328,
           -1.0029523920352366,
           -1.0071770205766406,
           -1.0113860344146712,
           -1.015575580987191,
           -1.019741872011214,
           -1.023881185259943,
           -1.027989866176113,
           -1.0320643293318115,
           -1.0361010597446474,
           -1.0400966140598547,
           -1.0440476216075605,
           -1.0479507853441121,
           -1.0518028826859736,
           -1.0556007662443299,
           -1.0593413644681555,
           -1.0630216822031084,
           -1.0666388011732344,
           -1.0701898803920813,
           -1.0736721565094502,
           -1.077082944099642,
           -1.0804196358967038,
           -1.0836797029818384,
           -1.0868606949277995,
           -1.0899602399047799,
           -1.0929760447519994,
           -1.0959058950188991,
           -1.0987476549795747,
           -1.1014992676238153,
           -1.1041587546278728,
           -1.1067242163078366,
           -1.1091938315582828,
           -1.1115658577786391,
           -1.1138386307895338,
           -1.1160105647411853,
           -1.118080152015744,
           -1.1200459631253143,
           -1.121906646607253,
           -1.1236609289181807,
           -1.1253076143280334,
           -1.1268455848153447,
           -1.1282737999648367,
           -1.129591296868306,
           -1.1307971900296727,
           -1.1318906712749868,
           -1.1328710096680927,
           -1.1337375514325734,
           -1.1344897198805215,
           -1.13512701534862,
           -1.1356490151419427,
           -1.136055373485824,
           -1.1363458214860918,
           -1.1365201670978964
          ],
          [
           -1.1213065999007172,
           -1.1212542685225173,
           -1.1210973103668491,
           -1.1208358333718849,
           -1.12047001743915,
           -1.1200001144402691,
           -1.1194264482262122,
           -1.118749414638809,
           -1.117969481524273,
           -1.11708718874839,
           -1.1161031482129666,
           -1.1150180438730641,
           -1.113832631754471,
           -1.112547739970796,
           -1.1111642687394747,
           -1.1096831903959166,
           -1.1081055494049104,
           -1.106432462368337,
           -1.104665118028123,
           -1.1028047772632732,
           -1.1008527730797166,
           -1.0988105105915722,
           -1.0966794669923325,
           -1.0944611915143303,
           -1.0921573053747056,
           -1.089769501705975,
           -1.08729954546912,
           -1.0847492733469801,
           -1.0821205936155502,
           -1.0794154859906215,
           -1.076636001447003,
           -1.0737842620073899,
           -1.0708624604977224,
           -1.0678728602656904,
           -1.0648177948588076,
           -1.0616996676582633,
           -1.0585209514645275,
           -1.055284188030452,
           -1.0519919875373596,
           -1.0486470280093816,
           -1.0452520546610449,
           -1.0418098791728645,
           -1.0383233788894517,
           -1.0347954959343952,
           -1.0312292362359383,
           -1.0276276684572365,
           -1.0239939228247585,
           -1.0203311898481853,
           -1.0166427189249636,
           -1.0129318168225099,
           -1.0092018460309005,
           -1.0054562229787851,
           -1.0016984161051625,
           -0.997931943779634,
           -0.9941603720637469,
           -0.9903873123061017,
           -0.9866164185640159,
           -0.9828513848447206,
           -0.9790959421593117,
           -0.9753538553830264,
           -0.9716289199158098,
           -0.9679249581376678,
           -0.9642458156538887,
           -0.9605953573259335,
           -0.9569774630846076,
           -0.9533960235230549,
           -0.9498549352681573,
           -0.9463580961300899,
           -0.9429094000310502,
           -0.9395127317155985,
           -0.9361719612465368,
           -0.932890938291905,
           -0.9296734862103859,
           -0.926523395944253,
           -0.9234444197309013,
           -0.9204402646459937,
           -0.9175145859932983,
           -0.9146709805583672,
           -0.911912979745313,
           -0.9092440426180178,
           -0.9066675488691718,
           -0.9041867917425253,
           -0.901804970935648,
           -0.8995251855122547,
           -0.8973504268547945,
           -0.8952835716894314,
           -0.8933273752167701,
           -0.8914844643826453,
           -0.8897573313240067,
           -0.8881483270253078,
           -0.8866596552208914,
           -0.8852933665785873,
           -0.8840513531991021,
           -0.8829353434647937,
           -0.8819468972700494,
           -0.8810874016637577,
           -0.8803580669322734,
           -0.8797599231488423,
           -0.8792938172127093,
           -0.8789604103980804,
           -0.8787601764298264,
           -0.8786934000992829,
           -0.8787601764298265,
           -0.8789604103980807,
           -0.8792938172127095,
           -0.8797599231488428,
           -0.880358066932274,
           -0.8810874016637585,
           -0.8819468972700503,
           -0.8829353434647947,
           -0.8840513531991033,
           -0.8852933665785887,
           -0.8866596552208929,
           -0.8881483270253091,
           -0.8897573313240085,
           -0.8914844643826473,
           -0.893327375216772,
           -0.8952835716894338,
           -0.8973504268547966,
           -0.899525185512257,
           -0.9018049709356505,
           -0.9041867917425278,
           -0.9066675488691742,
           -0.9092440426180205,
           -0.9119129797453158,
           -0.9146709805583702,
           -0.917514585993301,
           -0.9204402646459969,
           -0.9234444197309044,
           -0.9265233959442561,
           -0.9296734862103891,
           -0.9328909382919083,
           -0.9361719612465402,
           -0.9395127317156019,
           -0.9429094000310538,
           -0.9463580961300934,
           -0.9498549352681611,
           -0.9533960235230583,
           -0.9569774630846114,
           -0.9605953573259371,
           -0.9642458156538923,
           -0.9679249581376715,
           -0.9716289199158136,
           -0.9753538553830303,
           -0.9790959421593158,
           -0.9828513848447245,
           -0.9866164185640198,
           -0.9903873123061054,
           -0.9941603720637509,
           -0.9979319437796378,
           -1.0016984161051663,
           -1.005456222978789,
           -1.009201846030904,
           -1.0129318168225134,
           -1.0166427189249674,
           -1.020331189848189,
           -1.0239939228247625,
           -1.02762766845724,
           -1.0312292362359419,
           -1.0347954959343988,
           -1.0383233788894553,
           -1.041809879172868,
           -1.0452520546610484,
           -1.0486470280093851,
           -1.051991987537363,
           -1.0552841880304553,
           -1.0585209514645308,
           -1.0616996676582662,
           -1.0648177948588107,
           -1.0678728602656935,
           -1.0708624604977255,
           -1.0737842620073927,
           -1.076636001447006,
           -1.0794154859906244,
           -1.0821205936155531,
           -1.0847492733469828,
           -1.0872995454691228,
           -1.0897695017059774,
           -1.092157305374708,
           -1.0944611915143323,
           -1.0966794669923348,
           -1.0988105105915742,
           -1.1008527730797188,
           -1.1028047772632752,
           -1.1046651180281246,
           -1.1064324623683386,
           -1.1081055494049117,
           -1.1096831903959177,
           -1.1111642687394763,
           -1.1125477399707975,
           -1.1138326317544722,
           -1.1150180438730652,
           -1.1161031482129677,
           -1.1170871887483909,
           -1.1179694815242738,
           -1.1187494146388095,
           -1.119426448226213,
           -1.1200001144402696,
           -1.1204700174391498,
           -1.1208358333718853,
           -1.1210973103668493,
           -1.1212542685225177
          ],
          [
           -1.106884983813195,
           -1.1068382732234892,
           -1.1066981748213962,
           -1.1064647887065002,
           -1.1061382817064451,
           -1.1057188873693231,
           -1.1052069059528036,
           -1.1046027044097704,
           -1.103906716370178,
           -1.1031194421187789,
           -1.1022414485682877,
           -1.101273369227494,
           -1.1002159041637547,
           -1.0990698199592248,
           -1.0978359496601047,
           -1.0965151927181127,
           -1.0951085149232884,
           -1.0936169483271687,
           -1.0920415911552703,
           -1.090383607707728,
           -1.0886442282468325,
           -1.086824748870119,
           -1.0849265313675438,
           -1.0829510030611702,
           -1.0808996566256888,
           -1.0787740498879472,
           -1.076575805603572,
           -1.0743066112086044,
           -1.0719682185439634,
           -1.0695624435503936,
           -1.0670911659314177,
           -1.0645563287816688,
           -1.0619599381778242,
           -1.0593040627292047,
           -1.0565908330849563,
           -1.0538224413945583,
           -1.0510011407182551,
           -1.0481292443838404,
           -1.0452091252860567,
           -1.0422432151247292,
           -1.0392340035775813,
           -1.0361840374035367,
           -1.0330959194721587,
           -1.0299723077147516,
           -1.0268159139925046,
           -1.023629502876956,
           -1.0204158903379408,
           -1.0171779423341105,
           -1.0139185733010365,
           -1.0106407445318766,
           -1.0073474624455507,
           -1.0040417767374026,
           -1.0007267784073457,
           -0.9974055976605911,
           -0.9940814016761582,
           -0.990757392238543,
           -0.9874368032281186,
           -0.9841228979661167,
           -0.9808189664103362,
           -0.9775283221981171,
           -0.9742542995335444,
           -0.9710002499163437,
           -0.9677695387105126,
           -0.9645655415513491,
           -0.9613916405902698,
           -0.9582512205775776,
           -0.9551476647841964,
           -0.9520843507643263,
           -0.9490646459619554,
           -0.946091903165249,
           -0.9431694558139522,
           -0.9403006131661402,
           -0.9374886553318938,
           -0.9347368281827634,
           -0.93204833814721,
           -0.9294263469035678,
           -0.9268739659834275,
           -0.9243942512997146,
           -0.9219901976150814,
           -0.9196647329675538,
           -0.91742071307165,
           -0.9152609157143936,
           -0.9131880351667838,
           -0.9112046766322905,
           -0.9093133507548777,
           -0.9075164682098074,
           -0.9058163344011038,
           -0.9042151442900015,
           -0.9027149773789563,
           -0.9013177928758668,
           -0.9000254250629903,
           -0.8988395788946855,
           -0.8977618258475053,
           -0.8967936000453527,
           -0.8959361946813591,
           -0.8951907587568826,
           -0.8945582941565293,
           -0.8940396530764207,
           -0.8936355358210488,
           -0.8933464889820101,
           -0.8931729040097101,
           -0.893115016186805,
           -0.8931729040097101,
           -0.8933464889820103,
           -0.8936355358210494,
           -0.8940396530764212,
           -0.89455829415653,
           -0.8951907587568834,
           -0.89593619468136,
           -0.8967936000453536,
           -0.8977618258475065,
           -0.8988395788946865,
           -0.9000254250629915,
           -0.9013177928758681,
           -0.9027149773789579,
           -0.9042151442900029,
           -0.9058163344011056,
           -0.9075164682098094,
           -0.9093133507548796,
           -0.9112046766322925,
           -0.9131880351667859,
           -0.915260915714396,
           -0.9174207130716521,
           -0.9196647329675562,
           -0.9219901976150839,
           -0.9243942512997172,
           -0.92687396598343,
           -0.9294263469035705,
           -0.9320483381472129,
           -0.9347368281827662,
           -0.9374886553318966,
           -0.940300613166143,
           -0.9431694558139552,
           -0.9460919031652522,
           -0.9490646459619584,
           -0.9520843507643293,
           -0.9551476647841998,
           -0.9582512205775806,
           -0.9613916405902732,
           -0.9645655415513523,
           -0.967769538710516,
           -0.9710002499163471,
           -0.9742542995335477,
           -0.9775283221981205,
           -0.9808189664103395,
           -0.9841228979661204,
           -0.9874368032281221,
           -0.9907573922385463,
           -0.9940814016761618,
           -0.9974055976605944,
           -1.000726778407349,
           -1.004041776737406,
           -1.007347462445554,
           -1.0106407445318797,
           -1.0139185733010398,
           -1.0171779423341138,
           -1.0204158903379443,
           -1.0236295028769593,
           -1.026815913992508,
           -1.0299723077147547,
           -1.0330959194721616,
           -1.0361840374035396,
           -1.0392340035775847,
           -1.042243215124732,
           -1.0452091252860596,
           -1.0481292443838435,
           -1.0510011407182582,
           -1.0538224413945612,
           -1.0565908330849592,
           -1.0593040627292076,
           -1.061959938177827,
           -1.0645563287816715,
           -1.0670911659314202,
           -1.069562443550396,
           -1.0719682185439658,
           -1.0743066112086066,
           -1.0765758056035746,
           -1.0787740498879497,
           -1.080899656625691,
           -1.0829510030611724,
           -1.0849265313675456,
           -1.086824748870121,
           -1.0886442282468343,
           -1.0903836077077298,
           -1.092041591155272,
           -1.09361694832717,
           -1.0951085149232898,
           -1.096515192718114,
           -1.097835949660106,
           -1.099069819959226,
           -1.1002159041637558,
           -1.1012733692274952,
           -1.1022414485682885,
           -1.1031194421187798,
           -1.103906716370179,
           -1.1046027044097715,
           -1.1052069059528045,
           -1.1057188873693233,
           -1.1061382817064456,
           -1.1064647887065002,
           -1.106698174821396,
           -1.1068382732234892
          ],
          [
           -1.0933273988229149,
           -1.0932861074695746,
           -1.0931622640035132,
           -1.0929559602026107,
           -1.0926673490166492,
           -1.0922966445471753,
           -1.09184412201909,
           -1.0913101177437514,
           -1.0906950290732993,
           -1.089999314345868,
           -1.0892234928212625,
           -1.0883681446066311,
           -1.087433910571583,
           -1.0864214922521365,
           -1.08533165174281,
           -1.0841652115760996,
           -1.082923054588509,
           -1.0816061237722148,
           -1.0802154221113867,
           -1.0787520124020826,
           -1.0772170170545696,
           -1.075611617876826,
           -1.0739370558378987,
           -1.0721946308096926,
           -1.070385701285683,
           -1.0685116840749411,
           -1.0665740539697652,
           -1.064574343385117,
           -1.0625141419679536,
           -1.0603950961744513,
           -1.058218908813002,
           -1.0559873385507705,
           -1.0537021993814908,
           -1.051365360052069,
           -1.0489787434454647,
           -1.0465443259172171,
           -1.0440641365828736,
           -1.0415402565534908,
           -1.03897481811628,
           -1.0363700038573687,
           -1.0337280457235865,
           -1.0310512240200855,
           -1.0283418663405504,
           -1.0256023464266875,
           -1.022835082953643,
           -1.0200425382379505,
           -1.0172272168646084,
           -1.0143916642298667,
           -1.0115384649963288,
           -1.0086702414570066,
           -1.0057896518050229,
           -1.0028993883057418,
           -1.0000021753682158,
           -0.9971007675129784,
           -0.9941979472333772,
           -0.9912965227478518,
           -0.9883993256407952,
           -0.9855092083899135,
           -0.9826290417783168,
           -0.9797617121899255,
           -0.9769101187871807,
           -0.9740771705704813,
           -0.9712657833192611,
           -0.9684788764151457,
           -0.965719369548208,
           -0.9629901793079507,
           -0.9602942156613137,
           -0.9576343783207003,
           -0.9550135530057592,
           -0.9524346076034351,
           -0.9499003882316086,
           -0.9474137152124831,
           -0.9449773789627328,
           -0.9425941358083041,
           -0.9402667037326419,
           -0.9379977580680035,
           -0.9357899271403992,
           -0.9336457878795671,
           -0.9315678614062253,
           -0.92955860860966,
           -0.927620425729456,
           -0.9257556399558987,
           -0.923966505064203,
           -0.922255197098298,
           -0.9206238101203695,
           -0.9190743520427468,
           -0.9176087405589884,
           -0.9162287991911877,
           -0.9149362534705587,
           -0.9137327272682618,
           -0.9126197392932182,
           -0.911598699773289,
           -0.9106709073357069,
           -0.9098375461019931,
           -0.9090996830118365,
           -0.9084582653894809,
           -0.907914118765142,
           -0.9074679449628127,
           -0.907120320464541,
           -0.9068716950598998,
           -0.9067223907879016,
           -0.9066726011770851,
           -0.9067223907879016,
           -0.9068716950599001,
           -0.9071203204645413,
           -0.907467944962813,
           -0.9079141187651426,
           -0.9084582653894816,
           -0.9090996830118373,
           -0.9098375461019939,
           -0.9106709073357077,
           -0.91159869977329,
           -0.9126197392932193,
           -0.913732727268263,
           -0.9149362534705601,
           -0.9162287991911893,
           -0.9176087405589897,
           -0.9190743520427486,
           -0.9206238101203711,
           -0.9222551970982996,
           -0.923966505064205,
           -0.9257556399559008,
           -0.927620425729458,
           -0.9295586086096621,
           -0.9315678614062274,
           -0.9336457878795691,
           -0.9357899271404013,
           -0.9379977580680058,
           -0.9402667037326444,
           -0.9425941358083064,
           -0.9449773789627353,
           -0.9474137152124855,
           -0.9499003882316112,
           -0.9524346076034376,
           -0.9550135530057619,
           -0.957634378320703,
           -0.9602942156613165,
           -0.9629901793079536,
           -0.9657193695482108,
           -0.9684788764151485,
           -0.9712657833192639,
           -0.9740771705704844,
           -0.9769101187871836,
           -0.9797617121899284,
           -0.9826290417783198,
           -0.9855092083899167,
           -0.9883993256407982,
           -0.991296522747855,
           -0.9941979472333803,
           -0.9971007675129815,
           -1.0000021753682187,
           -1.0028993883057447,
           -1.0057896518050258,
           -1.0086702414570095,
           -1.0115384649963317,
           -1.0143916642298696,
           -1.0172272168646115,
           -1.0200425382379534,
           -1.022835082953646,
           -1.0256023464266901,
           -1.0283418663405528,
           -1.0310512240200882,
           -1.0337280457235893,
           -1.0363700038573713,
           -1.0389748181162826,
           -1.0415402565534935,
           -1.044064136582876,
           -1.0465443259172198,
           -1.0489787434454672,
           -1.0513653600520714,
           -1.0537021993814932,
           -1.0559873385507728,
           -1.058218908813004,
           -1.0603950961744537,
           -1.0625141419679558,
           -1.064574343385119,
           -1.0665740539697675,
           -1.0685116840749431,
           -1.070385701285685,
           -1.0721946308096941,
           -1.0739370558379004,
           -1.0756116178768278,
           -1.0772170170545714,
           -1.0787520124020842,
           -1.080215422111388,
           -1.0816061237722159,
           -1.08292305458851,
           -1.0841652115761007,
           -1.0853316517428109,
           -1.0864214922521378,
           -1.0874339105715838,
           -1.0883681446066318,
           -1.0892234928212632,
           -1.0899993143458686,
           -1.0906950290733004,
           -1.0913101177437519,
           -1.0918441220190909,
           -1.0922966445471756,
           -1.0926673490166496,
           -1.0929559602026109,
           -1.0931622640035135,
           -1.093286107469575
          ],
          [
           -1.0806469610177518,
           -1.0806108613328942,
           -1.0805025899699563,
           -1.0803222299977973,
           -1.0800699198443315,
           -1.0797458532661495,
           -1.079350279305795,
           -1.0788835022364907,
           -1.0783458814940583,
           -1.0777378315957267,
           -1.0770598220454426,
           -1.0763123772252647,
           -1.075496076272341,
           -1.0746115529409233,
           -1.073659495448804,
           -1.0726406463074987,
           -1.0715558021354379,
           -1.0704058134533663,
           -1.0691915844610798,
           -1.0679140727945684,
           -1.0665742892625658,
           -1.0651732975614334,
           -1.0637122139672497,
           -1.0621922070038894,
           -1.0606144970858276,
           -1.0589803561343132,
           -1.0572911071654998,
           -1.05554812384905,
           -1.0537528300356467,
           -1.051906699251794,
           -1.0500112541602034,
           -1.0480680659840058,
           -1.046078753892958,
           -1.044044984349747,
           -1.0419684704144376,
           -1.0398509710050503,
           -1.0376942901121966,
           -1.0355002759656584,
           -1.0332708201507441,
           -1.0310078566722185,
           -1.0287133609635768,
           -1.026389348839402,
           -1.0240378753885333,
           -1.021661033805765,
           -1.0192609541598094,
           -1.0168398020952627,
           -1.0143997774663476,
           -1.0119431129002627,
           -1.0094720722880095,
           -1.006988949200661,
           -1.0044960652291224,
           -1.0019957682455578,
           -0.9994904305847775,
           -0.996982447144054,
           -0.9944742334000017,
           -0.9919682233413627,
           -0.9894668673167696,
           -0.9869726297968092,
           -0.9844879870499846,
           -0.9820154247324908,
           -0.9795574353920362,
           -0.9771165158863179,
           -0.9746951647171301,
           -0.9722958792815095,
           -0.9699211530417512,
           -0.9675734726165967,
           -0.9652553147963754,
           -0.9629691434853935,
           -0.9607174065753843,
           -0.9585025327543749,
           -0.9563269282558876,
           -0.9541929735539413,
           -0.9521030200099101,
           -0.9500593864778457,
           -0.9480643558754576,
           -0.9461201717284898,
           -0.9442290346967939,
           -0.9423930990909116,
           -0.9406144693884962,
           -0.9388951967603668,
           -0.9372372756164244,
           -0.9356426401820562,
           -0.934113161115993,
           -0.9326506421808768,
           -0.9312568169780201,
           -0.9299333457580036,
           -0.9286818123188523,
           -0.9275037210035417,
           -0.9264004938085331,
           -0.9253734676148846,
           -0.9244238915532725,
           -0.9235529245139319,
           -0.9227616328121462,
           -0.9220509880194258,
           -0.9214218649699611,
           -0.9208750399512947,
           -0.9204111890874382,
           -0.9200308869218777,
           -0.9197346052070584,
           -0.919522711906027,
           -0.9193954704109533,
           -0.9193530389822482,
           -0.9193954704109535,
           -0.9195227119060272,
           -0.9197346052070586,
           -0.9200308869218781,
           -0.9204111890874386,
           -0.9208750399512953,
           -0.9214218649699618,
           -0.9220509880194264,
           -0.922761632812147,
           -0.9235529245139328,
           -0.9244238915532734,
           -0.9253734676148856,
           -0.9264004938085342,
           -0.927503721003543,
           -0.9286818123188536,
           -0.9299333457580049,
           -0.9312568169780217,
           -0.9326506421808783,
           -0.9341131611159946,
           -0.9356426401820579,
           -0.9372372756164262,
           -0.9388951967603686,
           -0.9406144693884979,
           -0.9423930990909134,
           -0.9442290346967959,
           -0.9461201717284919,
           -0.9480643558754596,
           -0.9500593864778479,
           -0.9521030200099122,
           -0.9541929735539435,
           -0.9563269282558897,
           -0.9585025327543771,
           -0.9607174065753865,
           -0.9629691434853958,
           -0.9652553147963778,
           -0.9675734726165992,
           -0.9699211530417539,
           -0.972295879281512,
           -0.9746951647171327,
           -0.9771165158863203,
           -0.9795574353920388,
           -0.9820154247324935,
           -0.9844879870499874,
           -0.9869726297968119,
           -0.9894668673167722,
           -0.9919682233413651,
           -0.9944742334000044,
           -0.9969824471440565,
           -0.99949043058478,
           -1.0019957682455605,
           -1.004496065229125,
           -1.0069889492006634,
           -1.0094720722880122,
           -1.0119431129002652,
           -1.0143997774663502,
           -1.0168398020952651,
           -1.019260954159812,
           -1.0216610338057672,
           -1.0240378753885353,
           -1.0263893488394045,
           -1.0287133609635792,
           -1.0310078566722207,
           -1.0332708201507466,
           -1.0355002759656609,
           -1.0376942901121986,
           -1.0398509710050523,
           -1.0419684704144399,
           -1.044044984349749,
           -1.0460787538929601,
           -1.0480680659840078,
           -1.0500112541602051,
           -1.0519066992517958,
           -1.053752830035649,
           -1.0555481238490516,
           -1.0572911071655016,
           -1.0589803561343147,
           -1.0606144970858293,
           -1.062192207003891,
           -1.0637122139672512,
           -1.065173297561435,
           -1.0665742892625674,
           -1.0679140727945697,
           -1.0691915844610809,
           -1.0704058134533674,
           -1.071555802135439,
           -1.0726406463074998,
           -1.0736594954488048,
           -1.0746115529409244,
           -1.0754960762723416,
           -1.0763123772252652,
           -1.0770598220454433,
           -1.0777378315957271,
           -1.078345881494059,
           -1.078883502236491,
           -1.0793502793057959,
           -1.0797458532661497,
           -1.0800699198443315,
           -1.0803222299977973,
           -1.0805025899699563,
           -1.0806108613328942
          ],
          [
           -1.0688559379023295,
           -1.068824776245451,
           -1.0687313159731842,
           -1.0685756311730623,
           -1.0683578452990394,
           -1.0680781311335004,
           -1.067736710733912,
           -1.0673338553639382,
           -1.0668698854088032,
           -1.0663451702746467,
           -1.0657601282715374,
           -1.065115226479803,
           -1.0644109805992459,
           -1.0636479547807942,
           -1.0628267614400728,
           -1.0619480610523289,
           -1.061012561928111,
           -1.0600210199690314,
           -1.0589742384029066,
           -1.0578730674975123,
           -1.0567184042521442,
           -1.0555111920661233,
           -1.0542524203833348,
           -1.0529431243118452,
           -1.0515843842175876,
           -1.0501773252910587,
           -1.048723117085933,
           -1.0472229730284375,
           -1.0456781498963024,
           -1.0440899472660532,
           -1.042459706927366,
           -1.040788812263177,
           -1.0390786875941989,
           -1.0373307974864605,
           -1.0355466460204628,
           -1.033727776020516,
           -1.031875768242803,
           -1.0299922405207005,
           -1.0280788468658721,
           -1.026137276523653,
           -1.0241692529812427,
           -1.0221765329272323,
           -1.0201609051610108,
           -1.0181241894506206,
           -1.0160682353376727,
           -1.0139949208879673,
           -1.01190615138653,
           -1.0098038579758388,
           -1.0076899962360946,
           -1.0055665447064759,
           -1.003435503346439,
           -1.001298891936217,
           -0.9991587484158337,
           -0.9970171271620747,
           -0.9948760972030276,
           -0.9927377403699922,
           -0.9906041493867375,
           -0.9884774258963146,
           -0.9863596784258436,
           -0.9842530202899478,
           -0.9821595674337645,
           -0.980081436216736,
           -0.978020741138672,
           -0.9759795925098821,
           -0.9739600940674951,
           -0.9719643405404037,
           -0.9699944151656211,
           -0.9680523871591803,
           -0.9661403091450645,
           -0.964260214546019,
           -0.9624141149404567,
           -0.9606039973900419,
           -0.9588318217428891,
           -0.9570995179176841,
           -0.9554089831743776,
           -0.9537620793774418,
           -0.9521606302580123,
           -0.9506064186815357,
           -0.9491011839278399,
           -0.9476466189908017,
           -0.946244367905019,
           -0.9448960231071031,
           -0.9436031228393753,
           -0.9423671486038772,
           -0.9411895226747015,
           -0.9400716056766977,
           -0.9390146942386031,
           -0.9380200187286113,
           -0.9370887410802946,
           -0.9362219527166463,
           -0.9354206725798273,
           -0.934685845273937,
           -0.9340183393278491,
           -0.933418945584792,
           -0.9328883757249687,
           -0.9324272609270625,
           -0.9320361506739898,
           -0.9317155117077385,
           -0.9314657271375638,
           -0.9312870957052101,
           -0.931179831210213,
           -0.9311440620976705,
           -0.9311798312102131,
           -0.9312870957052101,
           -0.9314657271375638,
           -0.9317155117077388,
           -0.93203615067399,
           -0.9324272609270631,
           -0.9328883757249693,
           -0.9334189455847925,
           -0.9340183393278498,
           -0.9346858452739376,
           -0.935420672579828,
           -0.936221952716647,
           -0.9370887410802955,
           -0.9380200187286125,
           -0.9390146942386042,
           -0.9400716056766989,
           -0.9411895226747027,
           -0.9423671486038784,
           -0.9436031228393768,
           -0.9448960231071046,
           -0.9462443679050203,
           -0.9476466189908033,
           -0.9491011839278414,
           -0.9506064186815372,
           -0.9521606302580139,
           -0.9537620793774436,
           -0.9554089831743793,
           -0.9570995179176858,
           -0.9588318217428907,
           -0.9606039973900437,
           -0.9624141149404585,
           -0.9642602145460207,
           -0.9661403091450665,
           -0.9680523871591822,
           -0.969994415165623,
           -0.9719643405404057,
           -0.9739600940674973,
           -0.975979592509884,
           -0.9780207411386741,
           -0.9800814362167383,
           -0.9821595674337666,
           -0.9842530202899498,
           -0.9863596784258457,
           -0.9884774258963169,
           -0.9906041493867397,
           -0.9927377403699942,
           -0.9948760972030298,
           -0.9970171271620769,
           -0.9991587484158359,
           -1.001298891936219,
           -1.003435503346441,
           -1.005566544706478,
           -1.0076899962360968,
           -1.009803857975841,
           -1.011906151386532,
           -1.0139949208879693,
           -1.016068235337675,
           -1.0181241894506226,
           -1.0201609051610125,
           -1.0221765329272343,
           -1.0241692529812447,
           -1.0261372765236547,
           -1.0280788468658741,
           -1.0299922405207027,
           -1.031875768242805,
           -1.0337277760205175,
           -1.0355466460204645,
           -1.0373307974864623,
           -1.0390786875942006,
           -1.0407888122631785,
           -1.0424597069273676,
           -1.044089947266055,
           -1.0456781498963041,
           -1.0472229730284388,
           -1.0487231170859346,
           -1.0501773252910602,
           -1.051584384217589,
           -1.0529431243118466,
           -1.054252420383336,
           -1.0555111920661244,
           -1.0567184042521456,
           -1.0578730674975134,
           -1.0589742384029077,
           -1.0600210199690323,
           -1.0610125619281119,
           -1.0619480610523298,
           -1.0628267614400735,
           -1.063647954780795,
           -1.0644109805992463,
           -1.0651152264798034,
           -1.065760128271538,
           -1.0663451702746471,
           -1.066869885408804,
           -1.0673338553639384,
           -1.0677367107339126,
           -1.0680781311335006,
           -1.0683578452990394,
           -1.0685756311730623,
           -1.0687313159731842,
           -1.0688247762454512
          ],
          [
           -1.0579657365300008,
           -1.0579392333990796,
           -1.0578597456646475,
           -1.057727338293165,
           -1.057542119533591,
           -1.0573042408746058,
           -1.0570138969845915,
           -1.0566713256342322,
           -1.056276807601569,
           -1.0558306665592976,
           -1.0553332689440642,
           -1.0547850238074747,
           -1.0541863826484956,
           -1.0535378392268904,
           -1.0528399293572916,
           -1.0520932306834823,
           -1.051298362432414,
           -1.0504559851474566,
           -1.0495668004003467,
           -1.0486315504812502,
           -1.0476510180663416,
           -1.046626025862246,
           -1.045557436226683,
           -1.0444461507645963,
           -1.0432931098990381,
           -1.0420992924160446,
           -1.040865714982708,
           -1.0395934316376332,
           -1.0382835332529323,
           -1.0369371469669015,
           -1.035555435586495,
           -1.0341395969587026,
           -1.0326908633099188,
           -1.0312105005523833,
           -1.0296998075567674,
           -1.0281601153899753,
           -1.0265927865172328,
           -1.024999213967543,
           -1.0233808204615937,
           -1.0217390575012246,
           -1.02007540441958,
           -1.0183913673911,
           -1.0166884784005394,
           -1.0149682941702398,
           -1.013232395044935,
           -1.0114823838334184,
           -1.0097198846064679,
           -1.0079465414504927,
           -1.0061640171764479,
           -1.0043739919836492,
           -1.0025781620782208,
           -1.0007782382460093,
           -0.9989759443799223,
           -0.9971730159617648,
           -0.9953711984987906,
           -0.9935722459153286,
           -0.9917779188999895,
           -0.9899899832091403,
           -0.9882102079274846,
           -0.9864403636867891,
           -0.9846822208439708,
           -0.9829375476199695,
           -0.9812081082010273,
           -0.9794956608042144,
           -0.9778019557092571,
           -0.9761287332589451,
           -0.9744777218306236,
           -0.9728506357815087,
           -0.9712491733707846,
           -0.9696750146616875,
           -0.9681298194069954,
           -0.9666152249215787,
           -0.9651328439458849,
           -0.963684262504445,
           -0.9622710377636953,
           -0.9608946958936059,
           -0.9595567299377921,
           -0.958258597696949,
           -0.9570017196306115,
           -0.955787476782373,
           -0.9546172087338102,
           -0.9534922115924639,
           -0.9524137360192882,
           -0.9513829853010348,
           -0.9504011134730519,
           -0.9494692234979791,
           -0.9485883655057777,
           -0.9477595351004724,
           -0.9469836717388876,
           -0.9462616571865363,
           -0.9455943140556607,
           -0.9449824044302444,
           -0.9444266285825914,
           -0.9439276237858327,
           -0.9434859632264408,
           -0.9431021550205354,
           -0.9427766413374402,
           -0.9425097976336009,
           -0.9423019319996043,
           -0.9421532846226551,
           -0.9420640273664519,
           -0.9420342634699993,
           -0.9420640273664519,
           -0.9421532846226552,
           -0.9423019319996047,
           -0.942509797633601,
           -0.9427766413374404,
           -0.9431021550205357,
           -0.9434859632264413,
           -0.9439276237858333,
           -0.9444266285825921,
           -0.9449824044302451,
           -0.9455943140556614,
           -0.9462616571865369,
           -0.9469836717388885,
           -0.9477595351004732,
           -0.9485883655057787,
           -0.9494692234979801,
           -0.9504011134730529,
           -0.9513829853010358,
           -0.9524137360192894,
           -0.953492211592465,
           -0.9546172087338115,
           -0.9557874767823742,
           -0.9570017196306128,
           -0.9582585976969502,
           -0.9595567299377934,
           -0.9608946958936074,
           -0.9622710377636967,
           -0.9636842625044466,
           -0.9651328439458864,
           -0.9666152249215801,
           -0.968129819406997,
           -0.9696750146616891,
           -0.9712491733707863,
           -0.9728506357815102,
           -0.9744777218306252,
           -0.9761287332589466,
           -0.9778019557092588,
           -0.979495660804216,
           -0.9812081082010289,
           -0.9829375476199714,
           -0.9846822208439726,
           -0.986440363686791,
           -0.9882102079274866,
           -0.9899899832091421,
           -0.9917779188999915,
           -0.9935722459153303,
           -0.9953711984987927,
           -0.9971730159617666,
           -0.9989759443799242,
           -1.000778238246011,
           -1.0025781620782224,
           -1.004373991983651,
           -1.0061640171764497,
           -1.0079465414504947,
           -1.0097198846064697,
           -1.01148238383342,
           -1.013232395044937,
           -1.0149682941702416,
           -1.0166884784005412,
           -1.0183913673911018,
           -1.0200754044195814,
           -1.0217390575012262,
           -1.0233808204615953,
           -1.0249992139675448,
           -1.0265927865172344,
           -1.0281601153899766,
           -1.0296998075567692,
           -1.0312105005523848,
           -1.0326908633099203,
           -1.0341395969587042,
           -1.0355554355864964,
           -1.0369371469669029,
           -1.0382835332529339,
           -1.0395934316376345,
           -1.0408657149827096,
           -1.042099292416046,
           -1.0432931098990395,
           -1.0444461507645975,
           -1.0455574362266842,
           -1.046626025862247,
           -1.0476510180663425,
           -1.0486315504812513,
           -1.0495668004003473,
           -1.050455985147457,
           -1.0512983624324146,
           -1.0520932306834831,
           -1.052839929357292,
           -1.053537839226891,
           -1.054186382648496,
           -1.054785023807475,
           -1.0553332689440647,
           -1.0558306665592982,
           -1.0562768076015696,
           -1.0566713256342326,
           -1.0570138969845921,
           -1.057304240874606,
           -1.057542119533591,
           -1.0577273382931653,
           -1.0578597456646477,
           -1.0579392333990798
          ],
          [
           -1.0479868924672608,
           -1.0479647429965895,
           -1.047898313205298,
           -1.0477876589466204,
           -1.047632873279501,
           -1.047434086423872,
           -1.0471914656979535,
           -1.0469052154374712,
           -1.0465755768966742,
           -1.0462028281310034,
           -1.0457872838612332,
           -1.0453292953188884,
           -1.0448292500727006,
           -1.0442875718358637,
           -1.0437047202537966,
           -1.0430811906721198,
           -1.042417513884516,
           -1.0417142558601253,
           -1.040972017450104,
           -1.040191434072952,
           -1.0393731753781958,
           -1.0385179448879949,
           -1.0376264796162167,
           -1.0366995496645122,
           -1.0357379577949124,
           -1.0347425389784386,
           -1.0337141599192228,
           -1.032653718553614,
           -1.0315621435237388,
           -1.0304403936249853,
           -1.0292894572268614,
           -1.028110351666694,
           -1.0269041226156208,
           -1.0256718434163425,
           -1.0244146143921027,
           -1.0231335621263746,
           -1.0218298387127518,
           -1.020504620974548,
           -1.0191591096536454,
           -1.017794528568142,
           -1.016412123738386,
           -1.0150131624810246,
           -1.0135989324707138,
           -1.0121707407692042,
           -1.0107299128215457,
           -1.0092777914192175,
           -1.007815735630048,
           -1.0063451196948492,
           -1.004867331890765,
           -1.0033837733614033,
           -1.0018958569139058,
           -1.0004050057831968,
           -0.9989126523637387,
           -0.9974202369092289,
           -0.9959292062007655,
           -0.9944410121841278,
           -0.992957110576924,
           -0.9914789594464817,
           -0.9900080177594763,
           -0.988545743904427,
           -0.9870935941883104,
           -0.9856530213086913,
           -0.9842254728028946,
           -0.9828123894758939,
           -0.9814152038087252,
           -0.9800353383493879,
           -0.9786742040883283,
           -0.9773331988207538,
           -0.9760137054981599,
           -0.9747170905716025,
           -0.9734447023293692,
           -0.9721978692318558,
           -0.9709778982465631,
           -0.9697860731862656,
           -0.9686236530535074,
           -0.9674918703946938,
           -0.9663919296671417,
           -0.9653250056225375,
           -0.9642922417103259,
           -0.9632947485046233,
           -0.9623336021582867,
           -0.9614098428878156,
           -0.9605244734927807,
           -0.9596784579134767,
           -0.9588727198304859,
           -0.9581081413098175,
           -0.9573855614972272,
           -0.9567057753652752,
           -0.9560695325165863,
           -0.9554775360466862,
           -0.9549304414696628,
           -0.954428855709776,
           -0.9539733361619801,
           -0.9535643898241598,
           -0.9532024725036913,
           -0.9528879881007528,
           -0.9526212879705753,
           -0.9524026703666187,
           -0.9522323799664077,
           -0.9521106074815152,
           -0.9520374893529249,
           -0.9520131075327393,
           -0.9520374893529249,
           -0.9521106074815153,
           -0.9522323799664079,
           -0.952402670366619,
           -0.9526212879705754,
           -0.9528879881007533,
           -0.9532024725036916,
           -0.95356438982416,
           -0.9539733361619807,
           -0.9544288557097765,
           -0.9549304414696632,
           -0.9554775360466866,
           -0.9560695325165871,
           -0.9567057753652759,
           -0.9573855614972281,
           -0.9581081413098184,
           -0.9588727198304868,
           -0.9596784579134775,
           -0.9605244734927819,
           -0.9614098428878165,
           -0.9623336021582876,
           -0.9632947485046242,
           -0.964292241710327,
           -0.9653250056225385,
           -0.9663919296671429,
           -0.967491870394695,
           -0.9686236530535085,
           -0.9697860731862669,
           -0.9709778982465644,
           -0.972197869231857,
           -0.9734447023293705,
           -0.9747170905716038,
           -0.9760137054981614,
           -0.9773331988207551,
           -0.9786742040883298,
           -0.9800353383493893,
           -0.9814152038087266,
           -0.9828123894758952,
           -0.984225472802896,
           -0.9856530213086927,
           -0.987093594188312,
           -0.9885457439044286,
           -0.9900080177594779,
           -0.9914789594464831,
           -0.9929571105769256,
           -0.9944410121841293,
           -0.9959292062007672,
           -0.9974202369092302,
           -0.9989126523637402,
           -1.0004050057831981,
           -1.0018958569139074,
           -1.0033837733614048,
           -1.0048673318907666,
           -1.0063451196948507,
           -1.0078157356300494,
           -1.009277791419219,
           -1.010729912821547,
           -1.0121707407692055,
           -1.0135989324707149,
           -1.015013162481026,
           -1.0164121237383876,
           -1.0177945285681433,
           -1.019159109653647,
           -1.0205046209745494,
           -1.021829838712753,
           -1.023133562126376,
           -1.024414614392104,
           -1.0256718434163439,
           -1.0269041226156221,
           -1.0281103516666952,
           -1.0292894572268627,
           -1.0304403936249864,
           -1.0315621435237399,
           -1.032653718553615,
           -1.033714159919224,
           -1.0347425389784397,
           -1.0357379577949135,
           -1.036699549664513,
           -1.0376264796162173,
           -1.0385179448879958,
           -1.0393731753781965,
           -1.0401914340729526,
           -1.0409720174501047,
           -1.0417142558601258,
           -1.0424175138845166,
           -1.0430811906721205,
           -1.0437047202537972,
           -1.0442875718358644,
           -1.044829250072701,
           -1.0453292953188889,
           -1.0457872838612337,
           -1.0462028281310038,
           -1.046575576896675,
           -1.0469052154374714,
           -1.0471914656979542,
           -1.0474340864238723,
           -1.0476328732795008,
           -1.0477876589466206,
           -1.0478983132052981,
           -1.04796474299659
          ],
          [
           -1.038929059601267,
           -1.0389109343601124,
           -1.038856574275301,
           -1.0387660262540048,
           -1.0386393684455555,
           -1.038476710197483,
           -1.0382781919939086,
           -1.0380439853762333,
           -1.0377742928460423,
           -1.0374693477501367,
           -1.0371294141475773,
           -1.036754786658618,
           -1.036345790295387,
           -1.0359027802741576,
           -1.0354261418090405,
           -1.0349162898869082,
           -1.03437366902336,
           -1.0337987529995083,
           -1.0331920445793714,
           -1.0325540752076339,
           -1.0318854046875365,
           -1.0311866208386369,
           -1.0304583391341864,
           -1.029701202317857,
           -1.0289158799995408,
           -1.0281030682299561,
           -1.0272634890537722,
           -1.026397890040985,
           -1.0255070437962561,
           -1.0245917474459516,
           -1.0236528221025996,
           -1.022691112306515,
           -1.0217074854443295,
           -1.0207028311441877,
           -1.019678060647378,
           -1.01863410615619,
           -1.0175719201577946,
           -1.0164924747239834,
           -1.0153967607866106,
           -1.0142857873886146,
           -1.0131605809105328,
           -1.0120221842724395,
           -1.0108716561112894,
           -1.0097100699336763,
           -1.0085385132440658,
           -1.0073580866486038,
           -1.0061699029346465,
           -1.0049750861262208,
           -1.0037747705156654,
           -1.002570099671776,
           -1.0013622254248202,
           -1.0001523068288791,
           -0.9989415091020104,
           -0.997731002544824,
           -0.9965219614381169,
           -0.9953155629203033,
           -0.9941129858454422,
           -0.9929154096227564,
           -0.9917240130386111,
           -0.9905399730620142,
           -0.9893644636347705,
           -0.9881986544475299,
           -0.9870437097030379,
           -0.985900786867997,
           -0.984771035415029,
           -0.9836555955563185,
           -0.9825555969706024,
           -0.981472157525255,
           -0.9804063819953014,
           -0.9793593607812722,
           -0.9783321686278847,
           -0.9773258633456195,
           -0.976341484537315,
           -0.9753800523319821,
           -0.9744425661280869,
           -0.9735300033486114,
           -0.9726433182102407,
           -0.9717834405090713,
           -0.9709512744252604,
           -0.9701476973490639,
           -0.9693735587307252,
           -0.9686296789566774,
           -0.9679168482545313,
           -0.9672358256292909,
           -0.9665873378332343,
           -0.9659720783718492,
           -0.9653907065481799,
           -0.9648438465478871,
           -0.964332086567251,
           -0.9638559779862899,
           -0.9634160345890663,
           -0.9630127318331677,
           -0.9626465061702469,
           -0.9623177544193886,
           -0.9620268331949501,
           -0.9617740583903989,
           -0.9615597047195205,
           -0.9613840053162399,
           -0.9612471513941364,
           -0.9611492919665827,
           -0.9610905336282716,
           -0.9610709403987331,
           -0.9610905336282716,
           -0.9611492919665828,
           -0.9612471513941365,
           -0.9613840053162401,
           -0.9615597047195207,
           -0.9617740583903992,
           -0.9620268331949505,
           -0.9623177544193889,
           -0.9626465061702474,
           -0.9630127318331682,
           -0.9634160345890668,
           -0.9638559779862904,
           -0.9643320865672513,
           -0.9648438465478876,
           -0.9653907065481806,
           -0.96597207837185,
           -0.966587337833235,
           -0.9672358256292916,
           -0.9679168482545321,
           -0.9686296789566782,
           -0.9693735587307258,
           -0.9701476973490647,
           -0.9709512744252612,
           -0.9717834405090723,
           -0.9726433182102415,
           -0.9735300033486124,
           -0.974442566128088,
           -0.9753800523319831,
           -0.9763414845373161,
           -0.9773258633456205,
           -0.9783321686278859,
           -0.9793593607812733,
           -0.9804063819953025,
           -0.981472157525256,
           -0.9825555969706036,
           -0.9836555955563195,
           -0.9847710354150302,
           -0.9859007868679982,
           -0.9870437097030393,
           -0.9881986544475312,
           -0.9893644636347718,
           -0.9905399730620156,
           -0.9917240130386125,
           -0.9929154096227575,
           -0.9941129858454435,
           -0.9953155629203048,
           -0.9965219614381182,
           -0.9977310025448252,
           -0.9989415091020116,
           -1.0001523068288802,
           -1.0013622254248213,
           -1.002570099671777,
           -1.0037747705156668,
           -1.004975086126222,
           -1.0061699029346478,
           -1.007358086648605,
           -1.008538513244067,
           -1.0097100699336774,
           -1.0108716561112903,
           -1.0120221842724406,
           -1.013160580910534,
           -1.0142857873886155,
           -1.0153967607866117,
           -1.016492474723985,
           -1.0175719201577957,
           -1.018634106156191,
           -1.0196780606473792,
           -1.0207028311441886,
           -1.0217074854443307,
           -1.0226911123065159,
           -1.0236528221026007,
           -1.0245917474459525,
           -1.0255070437962575,
           -1.0263978900409858,
           -1.0272634890537733,
           -1.028103068229957,
           -1.0289158799995417,
           -1.0297012023178576,
           -1.0304583391341873,
           -1.0311866208386375,
           -1.0318854046875372,
           -1.0325540752076345,
           -1.0331920445793716,
           -1.0337987529995087,
           -1.0343736690233607,
           -1.0349162898869089,
           -1.0354261418090407,
           -1.035902780274158,
           -1.0363457902953872,
           -1.0367547866586184,
           -1.0371294141475778,
           -1.0374693477501369,
           -1.0377742928460425,
           -1.0380439853762333,
           -1.0382781919939088,
           -1.038476710197483,
           -1.0386393684455555,
           -1.0387660262540048,
           -1.0388565742753013,
           -1.0389109343601128
          ],
          [
           -1.0308010008003263,
           -1.0307865469009239,
           -1.0307431979705137,
           -1.030670992304323,
           -1.0305699937005268,
           -1.030440291419423,
           -1.0302820001262505,
           -1.0300952598176158,
           -1.0298802357314902,
           -1.0296371182407347,
           -1.029366122730088,
           -1.0290674894565708,
           -1.0287414833932185,
           -1.0283883940560834,
           -1.0280085353144104,
           -1.027602245183907,
           -1.0271698856030096,
           -1.0267118421920456,
           -1.0262285239952003,
           -1.025720363205168,
           -1.0251878148703937,
           -1.024631356584789,
           -1.0240514881598146,
           -1.0234487312788216,
           -1.0228236291335444,
           -1.022176746042638,
           -1.021508667052162,
           -1.020819997517914,
           -1.0201113626695204,
           -1.0193834071562085,
           -1.0186367945741777,
           -1.0178722069755173,
           -1.0170903443586121,
           -1.016291924140001,
           -1.015477680607669,
           -1.0146483643557633,
           -1.013804741700748,
           -1.0129475940790318,
           -1.01207771742612,
           -1.0111959215373747,
           -1.0103030294104824,
           -1.0093998765697656,
           -1.0084873103724932,
           -1.0075661892973882,
           -1.0066373822155532,
           -1.0057017676440732,
           -1.0047602329825958,
           -1.0038136737332188,
           -1.00286299270406,
           -1.0019090991969293,
           -1.0009529081795565,
           -0.999995339442885,
           -0.9990373167439746,
           -0.9980797669351177,
           -0.9971236190798117,
           -0.9961698035562824,
           -0.9952192511493079,
           -0.9942728921311396,
           -0.9933316553323676,
           -0.9923964672036357,
           -0.9914682508691565,
           -0.9905479251730349,
           -0.989636403719458,
           -0.9887345939078582,
           -0.9878433959642102,
           -0.9869637019696731,
           -0.9860963948878309,
           -0.9852423475918357,
           -0.9844024218928036,
           -0.983577467570848,
           -0.9827683214101848,
           -0.9819758062397707,
           -0.9812007299809773,
           -0.9804438847038298,
           -0.9797060456933646,
           -0.9789879705276863,
           -0.9782903981693202,
           -0.977614048071471,
           -0.9769596193008047,
           -0.9763277896783805,
           -0.9757192149403526,
           -0.975134527920056,
           -0.9745743377530837,
           -0.9740392291069369,
           -0.9735297614368136,
           -0.9730464682690665,
           -0.9725898565138317,
           -0.9721604058082819,
           -0.971758567891919,
           -0.9713847660152609,
           -0.971039394383232,
           -0.9707228176344822,
           -0.9704353703578196,
           -0.9701773566468416,
           -0.9699490496937877,
           -0.9697506914235514,
           -0.9695824921686955,
           -0.9694446303862331,
           -0.9693372524168384,
           -0.9692604722870534,
           -0.9692143715549582,
           -0.9691989991996738,
           -0.9692143715549583,
           -0.9692604722870535,
           -0.9693372524168387,
           -0.9694446303862331,
           -0.9695824921686955,
           -0.9697506914235517,
           -0.969949049693788,
           -0.9701773566468419,
           -0.9704353703578199,
           -0.9707228176344823,
           -0.9710393943832322,
           -0.9713847660152612,
           -0.9717585678919192,
           -0.9721604058082826,
           -0.9725898565138321,
           -0.9730464682690672,
           -0.9735297614368141,
           -0.9740392291069374,
           -0.9745743377530843,
           -0.9751345279200566,
           -0.9757192149403532,
           -0.9763277896783811,
           -0.9769596193008052,
           -0.9776140480714717,
           -0.978290398169321,
           -0.978987970527687,
           -0.9797060456933654,
           -0.9804438847038306,
           -0.981200729980978,
           -0.9819758062397713,
           -0.9827683214101854,
           -0.9835774675708489,
           -0.9844024218928044,
           -0.9852423475918364,
           -0.9860963948878317,
           -0.986963701969674,
           -0.9878433959642111,
           -0.9887345939078592,
           -0.9896364037194592,
           -0.9905479251730359,
           -0.9914682508691574,
           -0.9923964672036368,
           -0.9933316553323687,
           -0.9942728921311407,
           -0.9952192511493088,
           -0.9961698035562833,
           -0.9971236190798126,
           -0.9980797669351188,
           -0.9990373167439753,
           -0.9999953394428859,
           -1.0009529081795574,
           -1.0019090991969302,
           -1.002862992704061,
           -1.0038136737332197,
           -1.0047602329825969,
           -1.005701767644074,
           -1.006637382215554,
           -1.0075661892973893,
           -1.008487310372494,
           -1.0093998765697665,
           -1.0103030294104833,
           -1.0111959215373754,
           -1.0120777174261208,
           -1.0129475940790327,
           -1.0138047417007492,
           -1.0146483643557642,
           -1.01547768060767,
           -1.0162919241400017,
           -1.0170903443586128,
           -1.0178722069755182,
           -1.0186367945741783,
           -1.019383407156209,
           -1.020111362669521,
           -1.0208199975179144,
           -1.0215086670521627,
           -1.0221767460426388,
           -1.022823629133545,
           -1.0234487312788223,
           -1.024051488159815,
           -1.0246313565847893,
           -1.0251878148703941,
           -1.0257203632051681,
           -1.0262285239952005,
           -1.026711842192046,
           -1.0271698856030098,
           -1.0276022451839077,
           -1.0280085353144106,
           -1.0283883940560838,
           -1.0287414833932187,
           -1.029067489456571,
           -1.0293661227300883,
           -1.029637118240735,
           -1.0298802357314907,
           -1.0300952598176156,
           -1.0302820001262507,
           -1.030440291419423,
           -1.0305699937005266,
           -1.030670992304323,
           -1.0307431979705137,
           -1.0307865469009243
          ],
          [
           -1.0236105794363861,
           -1.02359942195341,
           -1.0235659595692972,
           -1.0235102224713435,
           -1.0234322609478625,
           -1.023332145352411,
           -1.0232099660536986,
           -1.0230658333711717,
           -1.0228998774962588,
           -1.0227122483992723,
           -1.0225031157219457,
           -1.0222726686555959,
           -1.0220211158048909,
           -1.0217486850372104,
           -1.0214556233175744,
           -1.0211421965291303,
           -1.0208086892791743,
           -1.0204554046906937,
           -1.0200826641794132,
           -1.0196908072163342,
           -1.019280191075752,
           -1.0188511905687443,
           -1.0184041977621283,
           -1.0179396216828829,
           -1.0174578880080423,
           -1.0169594387400713,
           -1.0164447318677405,
           -1.0159142410125215,
           -1.01536845506054,
           -1.0148078777801257,
           -1.0142330274250093,
           -1.0136444363232306,
           -1.0130426504518313,
           -1.0124282289974194,
           -1.0118017439027045,
           -1.0111637793991197,
           -1.0105149315256619,
           -1.0098558076340944,
           -1.0091870258806808,
           -1.0085092147046293,
           -1.0078230122934546,
           -1.0071290660354777,
           -1.0064280319597099,
           -1.0057205741633886,
           -1.0050073642274557,
           -1.0042890806202935,
           -1.0035664080900581,
           -1.002840037045977,
           -1.0021106629290017,
           -1.0013789855722428,
           -1.0006457085516192,
           -0.9999115385272196,
           -0.9991771845758636,
           -0.9984433575154071,
           -0.9977107692213544,
           -0.99698013193637,
           -0.9962521575733166,
           -0.9955275570124744,
           -0.9948070393936239,
           -0.9940913114037103,
           -0.9933810765608282,
           -0.9926770344953036,
           -0.9919798802286744,
           -0.9912903034513901,
           -0.9906089878000975,
           -0.9899366101353814,
           -0.9892738398208715,
           -0.9886213380046425,
           -0.9879797569038508,
           -0.9873497390935858,
           -0.9867319168009127,
           -0.9861269112051164,
           -0.985535331745159,
           -0.9849577754353814,
           -0.9843948261904854,
           -0.9838470541608387,
           -0.9833150150791566,
           -0.9827992496196045,
           -0.9823002827703718,
           -0.9818186232207653,
           -0.9813547627638517,
           -0.9809091757156837,
           -0.980482318352118,
           -0.9800746283642251,
           -0.9796865243332666,
           -0.9793184052261948,
           -0.9789706499126042,
           -0.9786436167040324,
           -0.9783376429164806,
           -0.9780530444569809,
           -0.9777901154350099,
           -0.9775491277994967,
           -0.9773303310021381,
           -0.9771339516876805,
           -0.9769601934117856,
           -0.9768092363870399,
           -0.97668123725762,
           -0.9765763289030664,
           -0.9764946202715633,
           -0.9764361962430662,
           -0.9764011175225523,
           -0.9763894205636138,
           -0.9764011175225524,
           -0.9764361962430663,
           -0.9764946202715633,
           -0.9765763289030663,
           -0.9766812372576203,
           -0.9768092363870401,
           -0.9769601934117857,
           -0.9771339516876808,
           -0.9773303310021383,
           -0.977549127799497,
           -0.9777901154350104,
           -0.9780530444569813,
           -0.9783376429164811,
           -0.9786436167040329,
           -0.9789706499126044,
           -0.9793184052261952,
           -0.9796865243332671,
           -0.9800746283642257,
           -0.9804823183521184,
           -0.9809091757156841,
           -0.9813547627638523,
           -0.9818186232207657,
           -0.9823002827703724,
           -0.9827992496196049,
           -0.9833150150791571,
           -0.9838470541608393,
           -0.9843948261904859,
           -0.9849577754353821,
           -0.9855353317451596,
           -0.9861269112051169,
           -0.9867319168009132,
           -0.9873497390935864,
           -0.9879797569038514,
           -0.988621338004643,
           -0.9892738398208724,
           -0.989936610135382,
           -0.9906089878000982,
           -0.9912903034513908,
           -0.991979880228675,
           -0.9926770344953044,
           -0.9933810765608287,
           -0.994091311403711,
           -0.9948070393936248,
           -0.9955275570124751,
           -0.9962521575733173,
           -0.9969801319363708,
           -0.9977107692213553,
           -0.9984433575154078,
           -0.9991771845758641,
           -0.9999115385272203,
           -1.0006457085516198,
           -1.0013789855722435,
           -1.0021106629290026,
           -1.0028400370459774,
           -1.003566408090059,
           -1.0042890806202942,
           -1.0050073642274564,
           -1.0057205741633892,
           -1.0064280319597105,
           -1.0071290660354781,
           -1.0078230122934553,
           -1.00850921470463,
           -1.0091870258806814,
           -1.0098558076340953,
           -1.0105149315256625,
           -1.0111637793991204,
           -1.0118017439027052,
           -1.01242822899742,
           -1.013042650451832,
           -1.0136444363232313,
           -1.01423302742501,
           -1.0148078777801264,
           -1.0153684550605406,
           -1.0159142410125217,
           -1.0164447318677412,
           -1.016959438740072,
           -1.0174578880080427,
           -1.0179396216828833,
           -1.0184041977621288,
           -1.0188511905687445,
           -1.0192801910757525,
           -1.0196908072163346,
           -1.0200826641794136,
           -1.020455404690694,
           -1.0208086892791748,
           -1.0211421965291307,
           -1.0214556233175747,
           -1.0217486850372106,
           -1.0220211158048909,
           -1.0222726686555959,
           -1.0225031157219457,
           -1.0227122483992725,
           -1.0228998774962592,
           -1.0230658333711717,
           -1.023209966053699,
           -1.023332145352411,
           -1.0234322609478628,
           -1.0235102224713433,
           -1.023565959569297,
           -1.02359942195341
          ],
          [
           -1.0173647517777304,
           -1.0173564954743755,
           -1.0173317341499462,
           -1.0172904905554678,
           -1.0172328025897117,
           -1.017158723269789,
           -1.017068320689991,
           -1.0169616779688802,
           -1.0168388931846362,
           -1.0167000792986738,
           -1.016545364067539,
           -1.0163748899431002,
           -1.0161888139610515,
           -1.0159873076177475,
           -1.015770556735388,
           -1.015538761315587,
           -1.0152921353813442,
           -1.0150309068074592,
           -1.0147553171394212,
           -1.014465621400816,
           -1.014162087889295,
           -1.0138449979611552,
           -1.0135146458045914,
           -1.013171338201673,
           -1.0128153942791203,
           -1.0124471452479518,
           -1.012066934132081,
           -1.0116751154859562,
           -1.0112720551013352,
           -1.0108581297033035,
           -1.0104337266356442,
           -1.0099992435356895,
           -1.0095550879987798,
           -1.0091016772324792,
           -1.0086394377006955,
           -1.0081688047578758,
           -1.0076902222734487,
           -1.0072041422467057,
           -1.0067110244123236,
           -1.0062113358367393,
           -1.005705550505608,
           -1.0051941489025893,
           -1.0046776175797105,
           -1.0041564487195869,
           -1.00363113968978,
           -1.003102192589597,
           -1.0025701137896523,
           -1.0020354134645162,
           -1.0014986051188126,
           -1.000960205107121,
           -1.0004207321480716,
           -0.9998807068330302,
           -0.9993406511297908,
           -0.9988010878817045,
           -0.9982625403027001,
           -0.9977255314686537,
           -0.9971905838055966,
           -0.9966582185752534,
           -0.9961289553584273,
           -0.9956033115367591,
           -0.9950818017734036,
           -0.9945649374931813,
           -0.9940532263627782,
           -0.9935471717715738,
           -0.9930472723137007,
           -0.9925540212719365,
           -0.9920679061040529,
           -0.9915894079322494,
           -0.9911190010363042,
           -0.9906571523510945,
           -0.9902043209691316,
           -0.9897609576487688,
           -0.9893275043287452,
           -0.9889043936497228,
           -0.9884920484834875,
           -0.9880908814704717,
           -0.9877012945662653,
           -0.9873236785977707,
           -0.9869584128296569,
           -0.9866058645417621,
           -0.9862663886180799,
           -0.985940327147962,
           -0.9856280090401549,
           -0.9853297496502765,
           -0.9850458504223198,
           -0.9847765985447635,
           -0.9845222666218408,
           -0.9842831123605058,
           -0.9840593782736103,
           -0.9838512913997903,
           -0.9836590630405208,
           -0.9834828885147919,
           -0.9833229469318178,
           -0.9831794009821646,
           -0.9830523967476625,
           -0.9829420635304229,
           -0.9828485137012608,
           -0.9827718425677879,
           -0.9827121282624022,
           -0.9826694316503732,
           -0.9826437962581871,
           -0.9826352482222696,
           -0.982643796258187,
           -0.9826694316503732,
           -0.9827121282624022,
           -0.982771842567788,
           -0.9828485137012609,
           -0.9829420635304229,
           -0.9830523967476626,
           -0.9831794009821649,
           -0.983322946931818,
           -0.983482888514792,
           -0.983659063040521,
           -0.9838512913997906,
           -0.9840593782736107,
           -0.9842831123605059,
           -0.9845222666218413,
           -0.9847765985447638,
           -0.9850458504223201,
           -0.9853297496502768,
           -0.9856280090401552,
           -0.9859403271479623,
           -0.9862663886180802,
           -0.9866058645417625,
           -0.9869584128296572,
           -0.9873236785977709,
           -0.9877012945662658,
           -0.9880908814704722,
           -0.988492048483488,
           -0.9889043936497232,
           -0.9893275043287455,
           -0.9897609576487694,
           -0.990204320969132,
           -0.990657152351095,
           -0.9911190010363046,
           -0.9915894079322498,
           -0.9920679061040535,
           -0.9925540212719367,
           -0.9930472723137014,
           -0.9935471717715745,
           -0.9940532263627786,
           -0.9945649374931818,
           -0.9950818017734041,
           -0.9956033115367597,
           -0.996128955358428,
           -0.996658218575254,
           -0.997190583805597,
           -0.9977255314686542,
           -0.9982625403027007,
           -0.9988010878817052,
           -0.9993406511297913,
           -0.9998807068330309,
           -1.000420732148072,
           -1.0009602051071216,
           -1.0014986051188133,
           -1.0020354134645166,
           -1.0025701137896528,
           -1.0031021925895978,
           -1.0036311396897803,
           -1.0041564487195873,
           -1.004677617579711,
           -1.0051941489025897,
           -1.0057055505056087,
           -1.00621133583674,
           -1.0067110244123243,
           -1.0072041422467064,
           -1.0076902222734492,
           -1.0081688047578763,
           -1.008639437700696,
           -1.0091016772324797,
           -1.0095550879987802,
           -1.00999924353569,
           -1.0104337266356447,
           -1.010858129703304,
           -1.0112720551013357,
           -1.0116751154859565,
           -1.0120669341320816,
           -1.0124471452479522,
           -1.012815394279121,
           -1.0131713382016732,
           -1.0135146458045916,
           -1.0138449979611552,
           -1.0141620878892952,
           -1.0144656214008165,
           -1.0147553171394215,
           -1.0150309068074594,
           -1.0152921353813444,
           -1.0155387613155873,
           -1.0157705567353883,
           -1.015987307617748,
           -1.0161888139610518,
           -1.0163748899431004,
           -1.0165453640675393,
           -1.016700079298674,
           -1.0168388931846364,
           -1.0169616779688804,
           -1.0170683206899913,
           -1.017158723269789,
           -1.0172328025897117,
           -1.0172904905554678,
           -1.0173317341499462,
           -1.0173564954743757
          ],
          [
           -1.0120695602592384,
           -1.0120637916076622,
           -1.0120464910365554,
           -1.012017674692304,
           -1.0119773694706233,
           -1.0119256129941692,
           -1.0118624535812126,
           -1.0117879502053786,
           -1.0117021724464759,
           -1.0116052004324323,
           -1.0114971247723612,
           -1.0113780464807847,
           -1.0112480768930492,
           -1.0111073375719668,
           -1.010955960205718,
           -1.0107940864970697,
           -1.0106218680439474,
           -1.0104394662114207,
           -1.0102470519951567,
           -1.0100448058764053,
           -1.009832917668584,
           -1.0096115863555324,
           -1.0093810199215192,
           -1.0091414351730794,
           -1.0088930575527773,
           -1.0086361209449828,
           -1.0083708674737693,
           -1.008097547293036,
           -1.0078164183689697,
           -1.007527746254967,
           -1.007231803859143,
           -1.0069288712045619,
           -1.0066192351823293,
           -1.0063031892976986,
           -1.0059810334093406,
           -1.0056530734619509,
           -1.0053196212123559,
           -1.0049809939493068,
           -1.0046375142071446,
           -1.0042895094735327,
           -1.0039373118914634,
           -1.0035812579557564,
           -1.0032216882042606,
           -1.0028589469040015,
           -1.002493381732507,
           -1.002125343454564,
           -1.0017551855946614,
           -1.0013832641053853,
           -1.0010099370320453,
           -1.0006355641738116,
           -1.0002605067416575,
           -0.999885127013411,
           -0.999509787986221,
           -0.9991348530267588,
           -0.9987606855194823,
           -0.9983876485132955,
           -0.9980161043669458,
           -0.9976464143935087,
           -0.997278938504318,
           -0.9969140348527028,
           -0.9965520594779,
           -0.9961933659495255,
           -0.9958383050129745,
           -0.9954872242361481,
           -0.9951404676578908,
           -0.9947983754385349,
           -0.9944612835129555,
           -0.9941295232465324,
           -0.9938034210944248,
           -0.9934832982645678,
           -0.9931694703847925,
           -0.9928622471744806,
           -0.9925619321211596,
           -0.9922688221624443,
           -0.9919832073737276,
           -0.9917053706620231,
           -0.9914355874663571,
           -0.9911741254651026,
           -0.9909212442906449,
           -0.9906771952517612,
           -0.99044222106409,
           -0.9902165555890576,
           -0.9900004235816249,
           -0.9897940404472023,
           -0.9895976120080737,
           -0.9894113342796639,
           -0.9892353932569623,
           -0.9890699647114136,
           -0.988915213998567,
           -0.9887712958767624,
           -0.9886383543371231,
           -0.9885165224450976,
           -0.9884059221937921,
           -0.9883066643693057,
           -0.9882188484282723,
           -0.9881425623877919,
           -0.9880778827279142,
           -0.9880248743068268,
           -0.9879835902888693,
           -0.9879540720854882,
           -0.9879363493092181,
           -0.9879304397407617,
           -0.987936349309218,
           -0.9879540720854882,
           -0.9879835902888694,
           -0.988024874306827,
           -0.9880778827279142,
           -0.9881425623877919,
           -0.9882188484282725,
           -0.9883066643693059,
           -0.9884059221937922,
           -0.9885165224450978,
           -0.9886383543371232,
           -0.9887712958767625,
           -0.988915213998567,
           -0.9890699647114138,
           -0.9892353932569624,
           -0.9894113342796642,
           -0.989597612008074,
           -0.9897940404472024,
           -0.9900004235816254,
           -0.9902165555890579,
           -0.9904422210640902,
           -0.9906771952517615,
           -0.9909212442906452,
           -0.991174125465103,
           -0.9914355874663573,
           -0.9917053706620234,
           -0.9919832073737279,
           -0.9922688221624446,
           -0.9925619321211598,
           -0.9928622471744808,
           -0.9931694703847928,
           -0.9934832982645682,
           -0.9938034210944251,
           -0.9941295232465324,
           -0.9944612835129558,
           -0.9947983754385352,
           -0.9951404676578912,
           -0.9954872242361487,
           -0.9958383050129748,
           -0.9961933659495258,
           -0.9965520594779004,
           -0.996914034852703,
           -0.9972789385043186,
           -0.9976464143935091,
           -0.998016104366946,
           -0.998387648513296,
           -0.9987606855194827,
           -0.9991348530267592,
           -0.9995097879862214,
           -0.9998851270134115,
           -1.0002605067416577,
           -1.0006355641738118,
           -1.0010099370320458,
           -1.0013832641053857,
           -1.0017551855946618,
           -1.0021253434545645,
           -1.0024933817325075,
           -1.0028589469040017,
           -1.0032216882042608,
           -1.0035812579557568,
           -1.0039373118914636,
           -1.004289509473533,
           -1.004637514207145,
           -1.0049809939493073,
           -1.0053196212123559,
           -1.005653073461951,
           -1.0059810334093409,
           -1.006303189297699,
           -1.00661923518233,
           -1.006928871204562,
           -1.0072318038591435,
           -1.0075277462549672,
           -1.00781641836897,
           -1.008097547293036,
           -1.0083708674737697,
           -1.008636120944983,
           -1.0088930575527775,
           -1.0091414351730796,
           -1.0093810199215194,
           -1.0096115863555326,
           -1.0098329176685843,
           -1.0100448058764055,
           -1.0102470519951567,
           -1.0104394662114207,
           -1.0106218680439474,
           -1.01079408649707,
           -1.010955960205718,
           -1.0111073375719672,
           -1.0112480768930494,
           -1.0113780464807847,
           -1.0114971247723612,
           -1.0116052004324325,
           -1.011702172446476,
           -1.0117879502053788,
           -1.0118624535812129,
           -1.0119256129941692,
           -1.011977369470623,
           -1.0120176746923042,
           -1.0120464910365556,
           -1.0120637916076625
          ],
          [
           -1.0077301276367194,
           -1.0077264171130342,
           -1.007715289049741,
           -1.0076967539670425,
           -1.0076708293883272,
           -1.0076375398247492,
           -1.0075969167536565,
           -1.0075489985908768,
           -1.007493830656877,
           -1.0074314651368244,
           -1.0073619610345608,
           -1.0072853841205343,
           -1.0072018068737052,
           -1.0071113084174745,
           -1.0070139744496651,
           -1.0069098971666082,
           -1.0067991751813767,
           -1.0066819134362206,
           -1.0065582231092576,
           -1.0064282215154838,
           -1.0062920320021644,
           -1.006149783838674,
           -1.0060016121008601,
           -1.0058476575500073,
           -1.005688066506482,
           -1.0055229907181433,
           -1.0053525872236129,
           -1.005177018210495,
           -1.00499645086865,
           -1.00481105723862,
           -1.0046210140553193,
           -1.004426502587103,
           -1.0042277084703255,
           -1.0040248215395189,
           -1.0038180356533126,
           -1.0036075485162304,
           -1.0033935614964966,
           -1.0031762794399979,
           -1.0029559104805417,
           -1.0027326658465663,
           -1.002506759664454,
           -1.0022784087586114,
           -1.0020478324484798,
           -1.0018152523426422,
           -1.001580892130207,
           -1.0013449773696408,
           -1.0011077352752367,
           -1.000869394501405,
           -1.0006301849249755,
           -1.000390337425708,
           -1.0001500836652133,
           -0.999909655864482,
           -0.9996692865802358,
           -0.9994292084803051,
           -0.9991896541182512,
           -0.9989508557074499,
           -0.9987130448948555,
           -0.9984764525346697,
           -0.9982413084621411,
           -0.9980078412677242,
           -0.9977762780718258,
           -0.9975468443003751,
           -0.9973197634614478,
           -0.9970952569231822,
           -0.9968735436932222,
           -0.996654840199924,
           -0.9964393600755653,
           -0.9962273139417954,
           -0.99601890919756,
           -0.9958143498097415,
           -0.9956138361067508,
           -0.9954175645753001,
           -0.995225727660598,
           -0.9950385135701918,
           -0.9948561060816875,
           -0.9946786843545746,
           -0.9945064227463793,
           -0.9943394906333618,
           -0.9941780522359781,
           -0.9940222664493137,
           -0.9938722866787009,
           -0.9937282606807128,
           -0.9935903304097418,
           -0.993458631870343,
           -0.9933332949755331,
           -0.9932144434112198,
           -0.993102194506935,
           -0.9929966591130353,
           -0.9928979414845226,
           -0.9928061391716426,
           -0.9927213429173909,
           -0.9926436365620663,
           -0.9925730969549957,
           -0.9925097938735373,
           -0.9924537899494773,
           -0.9924051406029115,
           -0.9923638939836973,
           -0.992330090920557,
           -0.9923037648778954,
           -0.9922849419203928,
           -0.9922736406854145,
           -0.9922698723632805,
           -0.9922736406854146,
           -0.9922849419203928,
           -0.9923037648778955,
           -0.9923300909205569,
           -0.9923638939836974,
           -0.9924051406029116,
           -0.9924537899494775,
           -0.9925097938735373,
           -0.992573096954996,
           -0.9926436365620666,
           -0.9927213429173909,
           -0.9928061391716427,
           -0.9928979414845227,
           -0.9929966591130354,
           -0.9931021945069353,
           -0.9932144434112198,
           -0.9933332949755332,
           -0.9934586318703432,
           -0.9935903304097421,
           -0.993728260680713,
           -0.993872286678701,
           -0.9940222664493139,
           -0.9941780522359782,
           -0.9943394906333619,
           -0.9945064227463795,
           -0.9946786843545748,
           -0.9948561060816877,
           -0.995038513570192,
           -0.9952257276605981,
           -0.9954175645753002,
           -0.9956138361067508,
           -0.9958143498097417,
           -0.9960189091975602,
           -0.9962273139417955,
           -0.9964393600755658,
           -0.9966548401999242,
           -0.9968735436932226,
           -0.9970952569231825,
           -0.9973197634614479,
           -0.9975468443003752,
           -0.997776278071826,
           -0.9980078412677245,
           -0.9982413084621413,
           -0.9984764525346699,
           -0.9987130448948558,
           -0.9989508557074502,
           -0.9991896541182514,
           -0.9994292084803051,
           -0.9996692865802359,
           -0.9999096558644822,
           -1.0001500836652135,
           -1.0003903374257082,
           -1.0006301849249757,
           -1.0008693945014053,
           -1.0011077352752369,
           -1.0013449773696408,
           -1.0015808921302072,
           -1.0018152523426427,
           -1.00204783244848,
           -1.0022784087586116,
           -1.0025067596644541,
           -1.0027326658465667,
           -1.0029559104805421,
           -1.003176279439998,
           -1.0033935614964968,
           -1.0036075485162304,
           -1.0038180356533128,
           -1.004024821539519,
           -1.004227708470326,
           -1.0044265025871033,
           -1.0046210140553196,
           -1.00481105723862,
           -1.0049964508686502,
           -1.0051770182104953,
           -1.0053525872236133,
           -1.0055229907181436,
           -1.0056880665064822,
           -1.0058476575500075,
           -1.0060016121008601,
           -1.006149783838674,
           -1.0062920320021647,
           -1.0064282215154838,
           -1.0065582231092578,
           -1.0066819134362206,
           -1.006799175181377,
           -1.0069098971666082,
           -1.007013974449665,
           -1.0071113084174745,
           -1.0072018068737052,
           -1.0072853841205343,
           -1.0073619610345608,
           -1.0074314651368246,
           -1.0074938306568773,
           -1.0075489985908768,
           -1.007596916753657,
           -1.0076375398247492,
           -1.007670829388327,
           -1.0076967539670423,
           -1.0077152890497407,
           -1.0077264171130342
          ],
          [
           -1.0043506520309784,
           -1.0043485566575947,
           -1.0043422725383675,
           -1.0043318056742314,
           -1.0043171660606258,
           -1.0042983676783217,
           -1.00427542848059,
           -1.0042483703767193,
           -1.004217219211897,
           -1.00418200474347,
           -1.004142760613602,
           -1.004099524318346,
           -1.0040523371731633,
           -1.0040012442749078,
           -1.0039462944603073,
           -1.0038875402609773,
           -1.0038250378550007,
           -1.0037588470151053,
           -1.0036890310534932,
           -1.0036156567633479,
           -1.003538794357084,
           -1.0034585174013717,
           -1.003374902749,
           -1.0032880304676257,
           -1.0031979837654696,
           -1.0031048489140189,
           -1.0030087151677953,
           -1.0029096746812605,
           -1.0028078224229189,
           -1.0027032560866984,
           -1.0025960760006714,
           -1.0024863850332018,
           -1.0023742884965892,
           -1.0022598940482979,
           -1.0021433115898466,
           -1.0020246531634538,
           -1.0019040328465187,
           -1.0017815666440364,
           -1.0016573723790345,
           -1.0015315695811302,
           -1.0014042793733056,
           -1.0012756243569993,
           -1.0011457284956198,
           -1.0010147169965795,
           -1.000882716191964,
           -1.0007498534179378,
           -1.000616256892997,
           -1.0004820555951883,
           -1.0003473791383966,
           -1.0002123576478268,
           -1.0000771216347906,
           -0.9999418018709196,
           -0.9998065292619196,
           -0.9996714347209937,
           -0.9995366490420525,
           -0.9994023027728306,
           -0.9992685260880405,
           -0.9991354486626853,
           -0.9990031995456508,
           -0.9988719070337119,
           -0.9987416985460705,
           -0.9986127004995579,
           -0.9984850381846224,
           -0.9983588356422342,
           -0.9982342155418283,
           -0.9981112990604161,
           -0.997990205762987,
           -0.997871053484329,
           -0.9977539582123861,
           -0.9976390339732832,
           -0.9975263927181339,
           -0.9974161442117555,
           -0.9973083959234086,
           -0.9972032529196806,
           -0.9971008177596274,
           -0.997001190392287,
           -0.9969044680566802,
           -0.9968107451844036,
           -0.9967201133049248,
           -0.9966326609536857,
           -0.9965484735831118,
           -0.9964676334766319,
           -0.996390219665801,
           -0.9963163078506192,
           -0.9962459703231406,
           -0.9961792758944527,
           -0.9961162898251157,
           -0.9960570737591334,
           -0.9960016856615385,
           -0.9959501797596589,
           -0.9959026064881349,
           -0.9958590124377467,
           -0.9958194403081185,
           -0.9957839288643465,
           -0.9957525128976039,
           -0.9957252231897694,
           -0.9957020864821203,
           -0.995683125448123,
           -0.9956683586703593,
           -0.9956578006216074,
           -0.9956514616501074,
           -0.9956493479690216,
           -0.9956514616501075,
           -0.9956578006216076,
           -0.9956683586703593,
           -0.9956831254481231,
           -0.9957020864821202,
           -0.9957252231897695,
           -0.9957525128976039,
           -0.9957839288643465,
           -0.9958194403081185,
           -0.9958590124377467,
           -0.9959026064881349,
           -0.9959501797596592,
           -0.9960016856615386,
           -0.9960570737591334,
           -0.9961162898251158,
           -0.9961792758944528,
           -0.9962459703231406,
           -0.9963163078506193,
           -0.9963902196658012,
           -0.9964676334766323,
           -0.9965484735831119,
           -0.9966326609536857,
           -0.9967201133049249,
           -0.9968107451844037,
           -0.9969044680566802,
           -0.9970011903922871,
           -0.9971008177596276,
           -0.9972032529196807,
           -0.9973083959234086,
           -0.9974161442117555,
           -0.9975263927181339,
           -0.9976390339732832,
           -0.9977539582123862,
           -0.997871053484329,
           -0.9979902057629872,
           -0.9981112990604161,
           -0.9982342155418285,
           -0.9983588356422343,
           -0.9984850381846228,
           -0.998612700499558,
           -0.9987416985460708,
           -0.9988719070337119,
           -0.9990031995456509,
           -0.9991354486626853,
           -0.9992685260880408,
           -0.9994023027728307,
           -0.9995366490420529,
           -0.999671434720994,
           -0.9998065292619195,
           -0.9999418018709196,
           -1.0000771216347908,
           -1.0002123576478268,
           -1.0003473791383968,
           -1.0004820555951888,
           -1.0006162568929975,
           -1.0007498534179378,
           -1.0008827161919642,
           -1.0010147169965795,
           -1.0011457284956198,
           -1.0012756243569996,
           -1.0014042793733056,
           -1.0015315695811304,
           -1.0016573723790345,
           -1.0017815666440366,
           -1.001904032846519,
           -1.0020246531634538,
           -1.0021433115898468,
           -1.0022598940482979,
           -1.0023742884965894,
           -1.0024863850332018,
           -1.0025960760006714,
           -1.0027032560866984,
           -1.002807822422919,
           -1.0029096746812605,
           -1.0030087151677956,
           -1.003104848914019,
           -1.0031979837654696,
           -1.0032880304676255,
           -1.003374902749,
           -1.0034585174013717,
           -1.0035387943570842,
           -1.003615656763348,
           -1.003689031053493,
           -1.0037588470151053,
           -1.0038250378550004,
           -1.0038875402609773,
           -1.003946294460307,
           -1.0040012442749078,
           -1.0040523371731633,
           -1.004099524318346,
           -1.004142760613602,
           -1.00418200474347,
           -1.004217219211897,
           -1.0042483703767193,
           -1.0042754284805904,
           -1.004298367678322,
           -1.0043171660606258,
           -1.0043318056742312,
           -1.0043422725383675,
           -1.004348556657595
          ],
          [
           -1.0019344028664037,
           -1.001933468967583,
           -1.0019306681693885,
           -1.0019260031657715,
           -1.0019194784438221,
           -1.0019111002795276,
           -1.0019008767318403,
           -1.00188881763506,
           -1.0018749345895346,
           -1.0018592409506928,
           -1.001841751816413,
           -1.001822484012743,
           -1.0018014560779807,
           -1.001778688245132,
           -1.0017542024227613,
           -1.001728022174247,
           -1.0017001726954697,
           -1.0016706807909392,
           -1.0016395748483993,
           -1.0016068848119128,
           -1.0015726421534683,
           -1.0015368798431232,
           -1.0014996323177137,
           -1.0014609354481583,
           -1.0014208265053857,
           -1.0013793441249175,
           -1.0013365282701328,
           -1.0012924201942566,
           -1.0012470624010987,
           -1.0012004986045806,
           -1.0011527736870902,
           -1.001103933656697,
           -1.0010540256032705,
           -1.001003097653543,
           -1.0009511989251492,
           -1.0008983794796993,
           -1.000844690274914,
           -1.0007901831158754,
           -1.0007349106054348,
           -1.000678926093824,
           -1.0006222836275152,
           -1.0005650378973832,
           -1.0005072441862097,
           -1.000448958315584,
           -1.000390236592252,
           -1.000331135753957,
           -1.000271712914831,
           -1.0002120255103824,
           -1.0001521312421366,
           -1.0000920880219786,
           -1.0000319539162548,
           -0.9999717870896841,
           -0.9999116457491323,
           -0.9998515880873078,
           -0.9997916722264277,
           -0.9997319561619148,
           -0.9996724977061724,
           -0.9996133544325012,
           -0.9995545836192047,
           -0.9994962421939442,
           -0.9994383866783919,
           -0.9993810731332446,
           -0.9993243571036435,
           -0.999268293565062,
           -0.9992129368697101,
           -0.9991583406935113,
           -0.9991045579837032,
           -0.9990516409071182,
           -0.9989996407991901,
           -0.9989486081137434,
           -0.9988985923736138,
           -0.998849642122149,
           -0.9988018048756411,
           -0.9987551270767371,
           -0.9987096540488768,
           -0.9986654299518016,
           -0.9986224977381839,
           -0.9985808991114186,
           -0.9985406744846197,
           -0.9985018629408677,
           -0.9984645021947451,
           -0.9984286285552011,
           -0.998394276889784,
           -0.9983614805902806,
           -0.9983302715397923,
           -0.9983006800812897,
           -0.9982727349876735,
           -0.998246463433373,
           -0.9982218909675151,
           -0.9981990414886887,
           -0.9981779372213335,
           -0.9981585986937743,
           -0.9981410447179299,
           -0.9981252923707098,
           -0.9981113569771265,
           -0.9980992520951354,
           -0.9980889895022217,
           -0.9980805791837445,
           -0.9980740293230564,
           -0.9980693462934033,
           -0.9980665346516153,
           -0.9980655971335964,
           -0.9980665346516154,
           -0.9980693462934034,
           -0.9980740293230563,
           -0.9980805791837444,
           -0.9980889895022217,
           -0.9980992520951355,
           -0.9981113569771266,
           -0.9981252923707098,
           -0.9981410447179299,
           -0.9981585986937743,
           -0.9981779372213333,
           -0.9981990414886887,
           -0.9982218909675151,
           -0.9982464634333732,
           -0.9982727349876735,
           -0.9983006800812899,
           -0.9983302715397921,
           -0.9983614805902804,
           -0.9983942768897841,
           -0.9984286285552011,
           -0.9984645021947454,
           -0.9985018629408677,
           -0.9985406744846196,
           -0.9985808991114185,
           -0.9986224977381839,
           -0.9986654299518016,
           -0.9987096540488768,
           -0.9987551270767373,
           -0.998801804875641,
           -0.9988496421221491,
           -0.9988985923736139,
           -0.9989486081137435,
           -0.99899964079919,
           -0.9990516409071182,
           -0.9991045579837032,
           -0.9991583406935113,
           -0.9992129368697104,
           -0.9992682935650621,
           -0.9993243571036436,
           -0.9993810731332448,
           -0.9994383866783921,
           -0.9994962421939443,
           -0.9995545836192048,
           -0.9996133544325012,
           -0.9996724977061724,
           -0.9997319561619148,
           -0.9997916722264281,
           -0.9998515880873078,
           -0.9999116457491324,
           -0.9999717870896841,
           -1.000031953916255,
           -1.0000920880219786,
           -1.0001521312421364,
           -1.0002120255103826,
           -1.000271712914831,
           -1.000331135753957,
           -1.0003902365922521,
           -1.000448958315584,
           -1.0005072441862095,
           -1.0005650378973834,
           -1.0006222836275154,
           -1.0006789260938238,
           -1.0007349106054348,
           -1.0007901831158754,
           -1.000844690274914,
           -1.000898379479699,
           -1.0009511989251494,
           -1.001003097653543,
           -1.0010540256032707,
           -1.001103933656697,
           -1.0011527736870902,
           -1.0012004986045806,
           -1.0012470624010987,
           -1.0012924201942566,
           -1.0013365282701328,
           -1.0013793441249175,
           -1.0014208265053859,
           -1.001460935448158,
           -1.0014996323177134,
           -1.001536879843123,
           -1.0015726421534683,
           -1.0016068848119128,
           -1.0016395748483993,
           -1.0016706807909392,
           -1.0017001726954695,
           -1.0017280221742473,
           -1.0017542024227613,
           -1.001778688245132,
           -1.0018014560779804,
           -1.001822484012743,
           -1.0018417518164133,
           -1.0018592409506928,
           -1.0018749345895346,
           -1.00188881763506,
           -1.0019008767318405,
           -1.0019111002795273,
           -1.001919478443822,
           -1.0019260031657715,
           -1.0019306681693887,
           -1.0019334689675834
          ],
          [
           -1.0004837177080108,
           -1.0004834838382894,
           -1.000482782455051,
           -1.0004816142358564,
           -1.0004799803092497,
           -1.000477882253672,
           -1.0004753220959437,
           -1.0004723023093158,
           -1.000468825811089,
           -1.0004648959598093,
           -1.0004605165520353,
           -1.000455691818687,
           -1.000450426420976,
           -1.0004447254459188,
           -1.0004385944014438,
           -1.0004320392110904,
           -1.00042506620831,
           -1.000417682130369,
           -1.000409894111865,
           -1.0004017096778606,
           -1.0003931367366377,
           -1.0003841835720846,
           -1.0003748588357209,
           -1.0003651715383655,
           -1.0003551310414596,
           -1.0003447470480498,
           -1.0003340295934415,
           -1.0003229890355325,
           -1.000311636044831,
           -1.0002999815941747,
           -1.0002880369481553,
           -1.0002758136522605,
           -1.0002633235217444,
           -1.0002505786302356,
           -1.0002375912980934,
           -1.0002243740805268,
           -1.0002109397554828,
           -1.00019730131132,
           -1.0001834719342744,
           -1.0001694649957351,
           -1.000155294039337,
           -1.0001409727678874,
           -1.0001265150301335,
           -1.0001119348073897,
           -1.000097246200033,
           -1.000082463413881,
           -1.0000676007464662,
           -1.0000526725732204,
           -1.0000376933335768,
           -1.0000226775170145,
           -1.000007639649046,
           -0.9999925942771707,
           -0.999977555956804,
           -0.999962539237196,
           -0.9999475586473529,
           -0.999932628681977,
           -0.9999177637874355,
           -0.9999029783477758,
           -0.9998882866707968,
           -0.9998737029741916,
           -0.9998592413717773,
           -0.9998449158598193,
           -0.9998307403034712,
           -0.9998167284233359,
           -0.9998028937821669,
           -0.9997892497717188,
           -0.9997758095997625,
           -0.9997625862772773,
           -0.999749592605829,
           -0.9997368411651515,
           -0.9997243443009429,
           -0.9997121141128821,
           -0.9997001624428877,
           -0.9996885008636218,
           -0.9996771406672557,
           -0.9996660928545038,
           -0.9996553681239428,
           -0.9996449768616189,
           -0.9996349291309596,
           -0.9996252346629979,
           -0.9996159028469165,
           -0.9996069427209242,
           -0.9995983629634732,
           -0.9995901718848226,
           -0.9995823774189612,
           -0.9995749871158943,
           -0.9995680081343047,
           -0.999561447234589,
           -0.9995553107722867,
           -0.999549604691898,
           -0.9995443345211028,
           -0.9995395053653842,
           -0.9995351219030625,
           -0.9995311883807442,
           -0.9995277086091906,
           -0.9995246859596113,
           -0.9995221233603837,
           -0.9995200232942038,
           -0.9995183877956709,
           -0.9995172184493079,
           -0.9995165163880192,
           -0.9995162822919892,
           -0.9995165163880191,
           -0.9995172184493077,
           -0.9995183877956707,
           -0.9995200232942036,
           -0.9995221233603837,
           -0.9995246859596115,
           -0.9995277086091905,
           -0.9995311883807443,
           -0.9995351219030625,
           -0.9995395053653842,
           -0.9995443345211029,
           -0.9995496046918979,
           -0.9995553107722868,
           -0.9995614472345891,
           -0.9995680081343047,
           -0.9995749871158945,
           -0.999582377418961,
           -0.9995901718848225,
           -0.9995983629634733,
           -0.9996069427209245,
           -0.9996159028469165,
           -0.9996252346629978,
           -0.9996349291309596,
           -0.9996449768616189,
           -0.9996553681239428,
           -0.9996660928545039,
           -0.9996771406672557,
           -0.9996885008636218,
           -0.9997001624428876,
           -0.9997121141128822,
           -0.999724344300943,
           -0.9997368411651518,
           -0.9997495926058289,
           -0.9997625862772771,
           -0.9997758095997625,
           -0.9997892497717186,
           -0.9998028937821668,
           -0.9998167284233359,
           -0.9998307403034713,
           -0.9998449158598195,
           -0.9998592413717773,
           -0.9998737029741916,
           -0.9998882866707969,
           -0.9999029783477761,
           -0.9999177637874355,
           -0.9999326286819769,
           -0.9999475586473532,
           -0.999962539237196,
           -0.9999775559568042,
           -0.9999925942771707,
           -1.0000076396490458,
           -1.0000226775170145,
           -1.0000376933335768,
           -1.0000526725732204,
           -1.0000676007464664,
           -1.0000824634138807,
           -1.0000972462000328,
           -1.0001119348073897,
           -1.0001265150301335,
           -1.0001409727678876,
           -1.0001552940393372,
           -1.000169464995735,
           -1.0001834719342744,
           -1.0001973013113201,
           -1.0002109397554828,
           -1.0002243740805266,
           -1.0002375912980934,
           -1.0002505786302356,
           -1.0002633235217446,
           -1.0002758136522605,
           -1.000288036948155,
           -1.0002999815941747,
           -1.000311636044831,
           -1.0003229890355325,
           -1.0003340295934418,
           -1.0003447470480498,
           -1.0003551310414596,
           -1.0003651715383655,
           -1.0003748588357209,
           -1.0003841835720844,
           -1.0003931367366377,
           -1.0004017096778606,
           -1.000409894111865,
           -1.0004176821303687,
           -1.00042506620831,
           -1.0004320392110906,
           -1.0004385944014436,
           -1.0004447254459188,
           -1.0004504264209757,
           -1.000455691818687,
           -1.000460516552035,
           -1.0004648959598093,
           -1.000468825811089,
           -1.0004723023093158,
           -1.000475322095944,
           -1.000477882253672,
           -1.0004799803092497,
           -1.0004816142358561,
           -1.000482782455051,
           -1.0004834838382894
          ]
         ]
        },
        {
         "colorbar": {
          "x": 0.9
         },
         "opacity": 0.6,
         "type": "surface",
         "x": [
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ],
          [
           -3.141592653589793,
           -3.110487775831478,
           -3.0793828980731632,
           -3.0482780203148483,
           -3.0171731425565333,
           -2.9860682647982184,
           -2.9549633870399035,
           -2.9238585092815885,
           -2.8927536315232736,
           -2.8616487537649586,
           -2.8305438760066437,
           -2.7994389982483288,
           -2.768334120490014,
           -2.737229242731699,
           -2.706124364973384,
           -2.675019487215069,
           -2.643914609456754,
           -2.612809731698439,
           -2.581704853940124,
           -2.5505999761818092,
           -2.5194950984234943,
           -2.4883902206651793,
           -2.4572853429068644,
           -2.4261804651485495,
           -2.3950755873902345,
           -2.3639707096319196,
           -2.3328658318736046,
           -2.3017609541152897,
           -2.2706560763569748,
           -2.23955119859866,
           -2.208446320840345,
           -2.17734144308203,
           -2.146236565323715,
           -2.1151316875654,
           -2.084026809807085,
           -2.05292193204877,
           -2.021817054290455,
           -1.9907121765321403,
           -1.9596072987738253,
           -1.9285024210155104,
           -1.8973975432571955,
           -1.8662926654988805,
           -1.8351877877405656,
           -1.8040829099822506,
           -1.7729780322239357,
           -1.7418731544656207,
           -1.7107682767073058,
           -1.6796633989489909,
           -1.648558521190676,
           -1.617453643432361,
           -1.586348765674046,
           -1.555243887915731,
           -1.5241390101574162,
           -1.4930341323991012,
           -1.4619292546407863,
           -1.4308243768824713,
           -1.3997194991241564,
           -1.3686146213658414,
           -1.3375097436075265,
           -1.3064048658492116,
           -1.2752999880908966,
           -1.2441951103325817,
           -1.2130902325742667,
           -1.1819853548159518,
           -1.1508804770576369,
           -1.119775599299322,
           -1.088670721541007,
           -1.057565843782692,
           -1.026460966024377,
           -0.9953560882660621,
           -0.9642512105077472,
           -0.9331463327494323,
           -0.9020414549911173,
           -0.8709365772328024,
           -0.8398316994744874,
           -0.8087268217161725,
           -0.7776219439578576,
           -0.7465170661995426,
           -0.7154121884412277,
           -0.6843073106829127,
           -0.6532024329245978,
           -0.6220975551662828,
           -0.5909926774079679,
           -0.559887799649653,
           -0.528782921891338,
           -0.4976780441330231,
           -0.46657316637470814,
           -0.4354682886163932,
           -0.40436341085807825,
           -0.3732585330997633,
           -0.34215365534144837,
           -0.31104877758313343,
           -0.2799438998248185,
           -0.24883902206650355,
           -0.2177341443081886,
           -0.18662926654987366,
           -0.15552438879155872,
           -0.12441951103324378,
           -0.09331463327492884,
           -0.062209755516613896,
           -0.031104877758298954,
           1.5987211554602254e-14,
           0.03110487775833093,
           0.06220975551664587,
           0.09331463327496081,
           0.12441951103327575,
           0.1555243887915907,
           0.18662926654990564,
           0.21773414430822058,
           0.24883902206653552,
           0.27994389982485046,
           0.3110487775831654,
           0.34215365534148034,
           0.3732585330997953,
           0.40436341085811023,
           0.43546828861642517,
           0.4665731663747401,
           0.49767804413305505,
           0.52878292189137,
           0.5598877996496849,
           0.5909926774079999,
           0.6220975551663148,
           0.6532024329246298,
           0.6843073106829447,
           0.7154121884412596,
           0.7465170661995746,
           0.7776219439578895,
           0.8087268217162045,
           0.8398316994745194,
           0.8709365772328344,
           0.9020414549911493,
           0.9331463327494642,
           0.9642512105077792,
           0.9953560882660941,
           1.026460966024409,
           1.057565843782724,
           1.088670721541039,
           1.1197755992993539,
           1.1508804770576688,
           1.1819853548159838,
           1.2130902325742987,
           1.2441951103326137,
           1.2752999880909286,
           1.3064048658492435,
           1.3375097436075585,
           1.3686146213658734,
           1.3997194991241884,
           1.4308243768825033,
           1.4619292546408182,
           1.4930341323991332,
           1.5241390101574481,
           1.555243887915763,
           1.586348765674078,
           1.617453643432393,
           1.648558521190708,
           1.6796633989490228,
           1.7107682767073378,
           1.7418731544656527,
           1.7729780322239677,
           1.8040829099822826,
           1.8351877877405975,
           1.8662926654989125,
           1.8973975432572274,
           1.9285024210155424,
           1.9596072987738573,
           1.9907121765321723,
           2.021817054290487,
           2.052921932048802,
           2.084026809807117,
           2.115131687565432,
           2.146236565323747,
           2.177341443082062,
           2.208446320840377,
           2.239551198598692,
           2.2706560763570067,
           2.3017609541153217,
           2.3328658318736366,
           2.3639707096319516,
           2.3950755873902665,
           2.4261804651485814,
           2.4572853429068964,
           2.4883902206652113,
           2.5194950984235263,
           2.550599976181841,
           2.581704853940156,
           2.612809731698471,
           2.643914609456786,
           2.675019487215101,
           2.706124364973416,
           2.737229242731731,
           2.768334120490046,
           2.7994389982483607,
           2.8305438760066757,
           2.8616487537649906,
           2.8927536315233056,
           2.9238585092816205,
           2.9549633870399354,
           2.9860682647982504,
           3.0171731425565653,
           3.0482780203148803,
           3.079382898073195,
           3.11048777583151
          ]
         ],
         "y": [
          [
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793,
           -3.141592653589793
          ],
          [
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478,
           -3.110487775831478
          ],
          [
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632,
           -3.0793828980731632
          ],
          [
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483,
           -3.0482780203148483
          ],
          [
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333,
           -3.0171731425565333
          ],
          [
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184,
           -2.9860682647982184
          ],
          [
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035,
           -2.9549633870399035
          ],
          [
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885,
           -2.9238585092815885
          ],
          [
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736,
           -2.8927536315232736
          ],
          [
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586,
           -2.8616487537649586
          ],
          [
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437,
           -2.8305438760066437
          ],
          [
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288,
           -2.7994389982483288
          ],
          [
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014,
           -2.768334120490014
          ],
          [
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699,
           -2.737229242731699
          ],
          [
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384,
           -2.706124364973384
          ],
          [
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069,
           -2.675019487215069
          ],
          [
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754,
           -2.643914609456754
          ],
          [
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439,
           -2.612809731698439
          ],
          [
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124,
           -2.581704853940124
          ],
          [
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092,
           -2.5505999761818092
          ],
          [
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943,
           -2.5194950984234943
          ],
          [
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793,
           -2.4883902206651793
          ],
          [
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644,
           -2.4572853429068644
          ],
          [
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495,
           -2.4261804651485495
          ],
          [
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345,
           -2.3950755873902345
          ],
          [
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196,
           -2.3639707096319196
          ],
          [
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046,
           -2.3328658318736046
          ],
          [
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897,
           -2.3017609541152897
          ],
          [
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748,
           -2.2706560763569748
          ],
          [
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866,
           -2.23955119859866
          ],
          [
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345,
           -2.208446320840345
          ],
          [
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203,
           -2.17734144308203
          ],
          [
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715,
           -2.146236565323715
          ],
          [
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654,
           -2.1151316875654
          ],
          [
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085,
           -2.084026809807085
          ],
          [
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877,
           -2.05292193204877
          ],
          [
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455,
           -2.021817054290455
          ],
          [
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403,
           -1.9907121765321403
          ],
          [
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253,
           -1.9596072987738253
          ],
          [
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104,
           -1.9285024210155104
          ],
          [
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955,
           -1.8973975432571955
          ],
          [
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805,
           -1.8662926654988805
          ],
          [
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656,
           -1.8351877877405656
          ],
          [
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506,
           -1.8040829099822506
          ],
          [
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357,
           -1.7729780322239357
          ],
          [
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207,
           -1.7418731544656207
          ],
          [
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058,
           -1.7107682767073058
          ],
          [
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909,
           -1.6796633989489909
          ],
          [
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676,
           -1.648558521190676
          ],
          [
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361,
           -1.617453643432361
          ],
          [
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046,
           -1.586348765674046
          ],
          [
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731,
           -1.555243887915731
          ],
          [
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162,
           -1.5241390101574162
          ],
          [
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012,
           -1.4930341323991012
          ],
          [
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863,
           -1.4619292546407863
          ],
          [
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713,
           -1.4308243768824713
          ],
          [
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564,
           -1.3997194991241564
          ],
          [
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414,
           -1.3686146213658414
          ],
          [
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265,
           -1.3375097436075265
          ],
          [
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116,
           -1.3064048658492116
          ],
          [
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966,
           -1.2752999880908966
          ],
          [
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817,
           -1.2441951103325817
          ],
          [
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667,
           -1.2130902325742667
          ],
          [
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518,
           -1.1819853548159518
          ],
          [
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369,
           -1.1508804770576369
          ],
          [
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322,
           -1.119775599299322
          ],
          [
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007,
           -1.088670721541007
          ],
          [
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692,
           -1.057565843782692
          ],
          [
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377,
           -1.026460966024377
          ],
          [
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621,
           -0.9953560882660621
          ],
          [
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472,
           -0.9642512105077472
          ],
          [
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323,
           -0.9331463327494323
          ],
          [
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173,
           -0.9020414549911173
          ],
          [
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024,
           -0.8709365772328024
          ],
          [
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874,
           -0.8398316994744874
          ],
          [
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725,
           -0.8087268217161725
          ],
          [
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576,
           -0.7776219439578576
          ],
          [
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426,
           -0.7465170661995426
          ],
          [
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277,
           -0.7154121884412277
          ],
          [
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127,
           -0.6843073106829127
          ],
          [
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978,
           -0.6532024329245978
          ],
          [
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828,
           -0.6220975551662828
          ],
          [
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679,
           -0.5909926774079679
          ],
          [
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653,
           -0.559887799649653
          ],
          [
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338,
           -0.528782921891338
          ],
          [
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231,
           -0.4976780441330231
          ],
          [
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814,
           -0.46657316637470814
          ],
          [
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932,
           -0.4354682886163932
          ],
          [
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825,
           -0.40436341085807825
          ],
          [
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633,
           -0.3732585330997633
          ],
          [
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837,
           -0.34215365534144837
          ],
          [
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343,
           -0.31104877758313343
          ],
          [
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185,
           -0.2799438998248185
          ],
          [
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355,
           -0.24883902206650355
          ],
          [
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886,
           -0.2177341443081886
          ],
          [
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366,
           -0.18662926654987366
          ],
          [
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872,
           -0.15552438879155872
          ],
          [
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378,
           -0.12441951103324378
          ],
          [
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884,
           -0.09331463327492884
          ],
          [
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896,
           -0.062209755516613896
          ],
          [
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954,
           -0.031104877758298954
          ],
          [
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14,
           1.5987211554602254e-14
          ],
          [
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093,
           0.03110487775833093
          ],
          [
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587,
           0.06220975551664587
          ],
          [
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081,
           0.09331463327496081
          ],
          [
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575,
           0.12441951103327575
          ],
          [
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907,
           0.1555243887915907
          ],
          [
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564,
           0.18662926654990564
          ],
          [
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058,
           0.21773414430822058
          ],
          [
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552,
           0.24883902206653552
          ],
          [
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046,
           0.27994389982485046
          ],
          [
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654,
           0.3110487775831654
          ],
          [
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034,
           0.34215365534148034
          ],
          [
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953,
           0.3732585330997953
          ],
          [
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023,
           0.40436341085811023
          ],
          [
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517,
           0.43546828861642517
          ],
          [
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401,
           0.4665731663747401
          ],
          [
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505,
           0.49767804413305505
          ],
          [
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137,
           0.52878292189137
          ],
          [
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849,
           0.5598877996496849
          ],
          [
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999,
           0.5909926774079999
          ],
          [
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148,
           0.6220975551663148
          ],
          [
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298,
           0.6532024329246298
          ],
          [
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447,
           0.6843073106829447
          ],
          [
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596,
           0.7154121884412596
          ],
          [
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746,
           0.7465170661995746
          ],
          [
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895,
           0.7776219439578895
          ],
          [
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045,
           0.8087268217162045
          ],
          [
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194,
           0.8398316994745194
          ],
          [
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344,
           0.8709365772328344
          ],
          [
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493,
           0.9020414549911493
          ],
          [
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642,
           0.9331463327494642
          ],
          [
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792,
           0.9642512105077792
          ],
          [
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941,
           0.9953560882660941
          ],
          [
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409,
           1.026460966024409
          ],
          [
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724,
           1.057565843782724
          ],
          [
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039,
           1.088670721541039
          ],
          [
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539,
           1.1197755992993539
          ],
          [
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688,
           1.1508804770576688
          ],
          [
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838,
           1.1819853548159838
          ],
          [
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987,
           1.2130902325742987
          ],
          [
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137,
           1.2441951103326137
          ],
          [
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286,
           1.2752999880909286
          ],
          [
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435,
           1.3064048658492435
          ],
          [
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585,
           1.3375097436075585
          ],
          [
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734,
           1.3686146213658734
          ],
          [
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884,
           1.3997194991241884
          ],
          [
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033,
           1.4308243768825033
          ],
          [
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182,
           1.4619292546408182
          ],
          [
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332,
           1.4930341323991332
          ],
          [
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481,
           1.5241390101574481
          ],
          [
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763,
           1.555243887915763
          ],
          [
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078,
           1.586348765674078
          ],
          [
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393,
           1.617453643432393
          ],
          [
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708,
           1.648558521190708
          ],
          [
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228,
           1.6796633989490228
          ],
          [
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378,
           1.7107682767073378
          ],
          [
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527,
           1.7418731544656527
          ],
          [
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677,
           1.7729780322239677
          ],
          [
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826,
           1.8040829099822826
          ],
          [
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975,
           1.8351877877405975
          ],
          [
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125,
           1.8662926654989125
          ],
          [
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274,
           1.8973975432572274
          ],
          [
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424,
           1.9285024210155424
          ],
          [
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573,
           1.9596072987738573
          ],
          [
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723,
           1.9907121765321723
          ],
          [
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487,
           2.021817054290487
          ],
          [
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802,
           2.052921932048802
          ],
          [
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117,
           2.084026809807117
          ],
          [
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432,
           2.115131687565432
          ],
          [
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747,
           2.146236565323747
          ],
          [
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062,
           2.177341443082062
          ],
          [
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377,
           2.208446320840377
          ],
          [
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692,
           2.239551198598692
          ],
          [
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067,
           2.2706560763570067
          ],
          [
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217,
           2.3017609541153217
          ],
          [
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366,
           2.3328658318736366
          ],
          [
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516,
           2.3639707096319516
          ],
          [
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665,
           2.3950755873902665
          ],
          [
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814,
           2.4261804651485814
          ],
          [
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964,
           2.4572853429068964
          ],
          [
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113,
           2.4883902206652113
          ],
          [
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263,
           2.5194950984235263
          ],
          [
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841,
           2.550599976181841
          ],
          [
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156,
           2.581704853940156
          ],
          [
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471,
           2.612809731698471
          ],
          [
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786,
           2.643914609456786
          ],
          [
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101,
           2.675019487215101
          ],
          [
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416,
           2.706124364973416
          ],
          [
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731,
           2.737229242731731
          ],
          [
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046,
           2.768334120490046
          ],
          [
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607,
           2.7994389982483607
          ],
          [
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757,
           2.8305438760066757
          ],
          [
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906,
           2.8616487537649906
          ],
          [
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056,
           2.8927536315233056
          ],
          [
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205,
           2.9238585092816205
          ],
          [
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354,
           2.9549633870399354
          ],
          [
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504,
           2.9860682647982504
          ],
          [
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653,
           3.0171731425565653
          ],
          [
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803,
           3.0482780203148803
          ],
          [
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195,
           3.079382898073195
          ],
          [
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151,
           3.11048777583151
          ]
         ],
         "z": [
          [
           1,
           1,
           0.9999999999999999,
           1,
           1.0000000000000002,
           1,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1.0000000000000002,
           1,
           1.0000000000000002,
           0.9999999999999999,
           1,
           1,
           1,
           1.0000000000000002,
           1,
           0.9999999999999999,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           1,
           1.0000000000000002,
           1,
           1,
           1,
           1.0000000000000002,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           1.0000000000000002,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           1.0000000000000002,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1.0000000000000002,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           1,
           1,
           1.0000000000000002,
           1,
           1.0000000000000002,
           1,
           1,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           1.0000000000000002,
           1,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1.0000000000000002,
           1,
           0.9999999999999998,
           0.9999999999999999,
           0.9999999999999999,
           0.9999999999999999,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           0.9999999999999999,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1,
           0.9999999999999999,
           1,
           1,
           0.9999999999999999,
           1,
           0.9999999999999998,
           1,
           1,
           1,
           0.9999999999999999,
           0.9999999999999999,
           1,
           1,
           1,
           1,
           0.9999999999999999,
           1.0000000000000002
          ],
          [
           1.0004837177080117,
           1.0004834838382903,
           1.0004827824550522,
           1.0004816142358575,
           1.0004799803092508,
           1.0004778822536728,
           1.0004753220959446,
           1.000472302309317,
           1.00046882581109,
           1.0004648959598101,
           1.000460516552036,
           1.000455691818688,
           1.0004504264209768,
           1.0004447254459197,
           1.0004385944014447,
           1.0004320392110913,
           1.0004250662083112,
           1.0004176821303699,
           1.000409894111866,
           1.0004017096778615,
           1.0003931367366383,
           1.0003841835720853,
           1.0003748588357217,
           1.0003651715383663,
           1.0003551310414602,
           1.0003447470480504,
           1.0003340295934422,
           1.0003229890355332,
           1.0003116360448314,
           1.0002999815941753,
           1.0002880369481557,
           1.0002758136522611,
           1.000263323521745,
           1.0002505786302363,
           1.0002375912980939,
           1.0002243740805272,
           1.0002109397554833,
           1.0001973013113203,
           1.0001834719342748,
           1.0001694649957356,
           1.0001552940393375,
           1.0001409727678876,
           1.000126515030134,
           1.00011193480739,
           1.0000972462000333,
           1.0000824634138812,
           1.0000676007464664,
           1.0000526725732204,
           1.0000376933335768,
           1.0000226775170145,
           1.000007639649046,
           0.9999925942771707,
           0.999977555956804,
           0.999962539237196,
           0.9999475586473529,
           0.9999326286819769,
           0.9999177637874352,
           0.9999029783477758,
           0.9998882866707965,
           0.9998737029741914,
           0.999859241371777,
           0.999844915859819,
           0.999830740303471,
           0.9998167284233356,
           0.9998028937821662,
           0.9997892497717181,
           0.9997758095997621,
           0.999762586277277,
           0.9997495926058284,
           0.9997368411651512,
           0.9997243443009424,
           0.9997121141128815,
           0.9997001624428871,
           0.9996885008636212,
           0.999677140667255,
           0.9996660928545031,
           0.9996553681239421,
           0.9996449768616181,
           0.999634929130959,
           0.9996252346629971,
           0.9996159028469157,
           0.9996069427209235,
           0.9995983629634723,
           0.9995901718848216,
           0.9995823774189602,
           0.9995749871158935,
           0.9995680081343037,
           0.9995614472345881,
           0.9995553107722857,
           0.9995496046918969,
           0.9995443345211019,
           0.9995395053653833,
           0.9995351219030616,
           0.9995311883807432,
           0.9995277086091896,
           0.9995246859596103,
           0.9995221233603827,
           0.9995200232942028,
           0.9995183877956699,
           0.9995172184493069,
           0.9995165163880182,
           0.9995162822919882,
           0.9995165163880181,
           0.9995172184493067,
           0.9995183877956697,
           0.9995200232942029,
           0.9995221233603827,
           0.9995246859596104,
           0.9995277086091895,
           0.9995311883807433,
           0.9995351219030617,
           0.9995395053653834,
           0.9995443345211018,
           0.999549604691897,
           0.9995553107722859,
           0.9995614472345881,
           0.9995680081343037,
           0.9995749871158937,
           0.9995823774189603,
           0.9995901718848217,
           0.9995983629634725,
           0.9996069427209237,
           0.9996159028469156,
           0.9996252346629972,
           0.9996349291309587,
           0.999644976861618,
           0.9996553681239421,
           0.9996660928545033,
           0.999677140667255,
           0.9996885008636212,
           0.999700162442887,
           0.9997121141128816,
           0.9997243443009423,
           0.999736841165151,
           0.9997495926058283,
           0.9997625862772768,
           0.9997758095997622,
           0.9997892497717181,
           0.9998028937821665,
           0.9998167284233355,
           0.9998307403034709,
           0.999844915859819,
           0.9998592413717768,
           0.9998737029741915,
           0.9998882866707967,
           0.9999029783477759,
           0.9999177637874352,
           0.9999326286819769,
           0.999947558647353,
           0.9999625392371958,
           0.9999775559568042,
           0.9999925942771707,
           1.0000076396490458,
           1.0000226775170145,
           1.0000376933335768,
           1.0000526725732204,
           1.0000676007464666,
           1.000082463413881,
           1.000097246200033,
           1.00011193480739,
           1.000126515030134,
           1.0001409727678878,
           1.0001552940393375,
           1.0001694649957353,
           1.0001834719342746,
           1.0001973013113206,
           1.0002109397554833,
           1.000224374080527,
           1.0002375912980939,
           1.0002505786302363,
           1.0002633235217453,
           1.0002758136522611,
           1.0002880369481557,
           1.0002999815941753,
           1.0003116360448316,
           1.0003229890355332,
           1.0003340295934424,
           1.0003447470480504,
           1.0003551310414602,
           1.0003651715383661,
           1.0003748588357217,
           1.0003841835720853,
           1.0003931367366383,
           1.0004017096778615,
           1.0004098941118658,
           1.0004176821303696,
           1.000425066208311,
           1.0004320392110915,
           1.0004385944014444,
           1.0004447254459197,
           1.0004504264209766,
           1.0004556918186878,
           1.0004605165520362,
           1.0004648959598104,
           1.00046882581109,
           1.0004723023093167,
           1.0004753220959448,
           1.0004778822536728,
           1.0004799803092506,
           1.0004816142358572,
           1.0004827824550522,
           1.0004834838382903
          ],
          [
           1.0019344028664054,
           1.0019334689675852,
           1.0019306681693905,
           1.0019260031657735,
           1.0019194784438241,
           1.0019111002795296,
           1.0019008767318422,
           1.0018888176350618,
           1.0018749345895364,
           1.0018592409506948,
           1.001841751816415,
           1.001822484012745,
           1.0018014560779824,
           1.001778688245134,
           1.001754202422763,
           1.0017280221742488,
           1.0017001726954713,
           1.0016706807909412,
           1.0016395748484008,
           1.0016068848119142,
           1.0015726421534699,
           1.0015368798431248,
           1.001499632317715,
           1.0014609354481598,
           1.0014208265053872,
           1.0013793441249188,
           1.001336528270134,
           1.0012924201942581,
           1.0012470624010998,
           1.001200498604582,
           1.0011527736870913,
           1.001103933656698,
           1.0010540256032716,
           1.0010030976535438,
           1.00095119892515,
           1.0008983794797002,
           1.0008446902749146,
           1.000790183115876,
           1.0007349106054357,
           1.0006789260938245,
           1.0006222836275158,
           1.0005650378973838,
           1.0005072441862102,
           1.0004489583155847,
           1.0003902365922523,
           1.0003311357539575,
           1.0002717129148313,
           1.0002120255103826,
           1.0001521312421366,
           1.0000920880219788,
           1.0000319539162548,
           0.9999717870896841,
           0.9999116457491323,
           0.9998515880873076,
           0.9997916722264277,
           0.9997319561619146,
           0.999672497706172,
           0.9996133544325008,
           0.9995545836192044,
           0.9994962421939436,
           0.9994383866783915,
           0.999381073133244,
           0.9993243571036429,
           0.9992682935650614,
           0.9992129368697094,
           0.9991583406935104,
           0.9991045579837022,
           0.9990516409071173,
           0.998999640799189,
           0.9989486081137423,
           0.9988985923736127,
           0.9988496421221478,
           0.9988018048756399,
           0.998755127076736,
           0.9987096540488756,
           0.9986654299518002,
           0.9986224977381825,
           0.9985808991114171,
           0.998540674484618,
           0.9985018629408662,
           0.9984645021947437,
           0.9984286285551993,
           0.9983942768897826,
           0.9983614805902787,
           0.9983302715397906,
           0.998300680081288,
           0.9982727349876717,
           0.9982464634333712,
           0.9982218909675131,
           0.9981990414886867,
           0.9981779372213314,
           0.9981585986937724,
           0.998141044717928,
           0.9981252923707079,
           0.9981113569771244,
           0.9980992520951336,
           0.9980889895022197,
           0.9980805791837425,
           0.9980740293230544,
           0.9980693462934015,
           0.9980665346516133,
           0.9980655971335944,
           0.9980665346516134,
           0.9980693462934014,
           0.9980740293230546,
           0.9980805791837424,
           0.9980889895022197,
           0.9980992520951337,
           0.9981113569771245,
           0.998125292370708,
           0.998141044717928,
           0.9981585986937724,
           0.9981779372213314,
           0.9981990414886868,
           0.9982218909675133,
           0.9982464634333712,
           0.9982727349876719,
           0.998300680081288,
           0.9983302715397906,
           0.9983614805902788,
           0.9983942768897827,
           0.9984286285551995,
           0.9984645021947437,
           0.9985018629408662,
           0.9985406744846181,
           0.998580899111417,
           0.9986224977381826,
           0.9986654299518003,
           0.9987096540488756,
           0.9987551270767359,
           0.9988018048756397,
           0.9988496421221479,
           0.9988985923736128,
           0.9989486081137424,
           0.9989996407991891,
           0.9990516409071172,
           0.9991045579837022,
           0.9991583406935105,
           0.9992129368697095,
           0.9992682935650613,
           0.999324357103643,
           0.9993810731332439,
           0.9994383866783915,
           0.9994962421939436,
           0.9995545836192044,
           0.9996133544325008,
           0.999672497706172,
           0.9997319561619146,
           0.9997916722264278,
           0.9998515880873076,
           0.9999116457491322,
           0.9999717870896841,
           1.000031953916255,
           1.0000920880219788,
           1.0001521312421366,
           1.0002120255103828,
           1.0002717129148315,
           1.0003311357539575,
           1.0003902365922523,
           1.0004489583155844,
           1.0005072441862102,
           1.000565037897384,
           1.000622283627516,
           1.0006789260938247,
           1.0007349106054357,
           1.0007901831158763,
           1.0008446902749148,
           1.0008983794797002,
           1.00095119892515,
           1.001003097653544,
           1.0010540256032718,
           1.001103933656698,
           1.0011527736870915,
           1.001200498604582,
           1.0012470624011,
           1.001292420194258,
           1.0013365282701343,
           1.001379344124919,
           1.0014208265053874,
           1.0014609354481596,
           1.0014996323177152,
           1.0015368798431248,
           1.00157264215347,
           1.0016068848119142,
           1.001639574848401,
           1.001670680790941,
           1.0017001726954713,
           1.001728022174249,
           1.0017542024227628,
           1.001778688245134,
           1.0018014560779824,
           1.001822484012745,
           1.001841751816415,
           1.0018592409506948,
           1.0018749345895366,
           1.0018888176350618,
           1.0019008767318425,
           1.0019111002795293,
           1.001919478443824,
           1.0019260031657735,
           1.0019306681693905,
           1.0019334689675852
          ],
          [
           1.0043506520309813,
           1.0043485566575978,
           1.0043422725383706,
           1.0043318056742343,
           1.004317166060629,
           1.0042983676783248,
           1.004275428480593,
           1.0042483703767222,
           1.0042172192118999,
           1.0041820047434729,
           1.0041427606136046,
           1.0040995243183488,
           1.0040523371731662,
           1.0040012442749104,
           1.00394629446031,
           1.00388754026098,
           1.003825037855003,
           1.003758847015108,
           1.0036890310534956,
           1.0036156567633503,
           1.0035387943570864,
           1.0034585174013742,
           1.0033749027490022,
           1.003288030467628,
           1.0031979837654716,
           1.0031048489140209,
           1.0030087151677975,
           1.0029096746812625,
           1.0028078224229209,
           1.0027032560867002,
           1.0025960760006731,
           1.0024863850332033,
           1.0023742884965907,
           1.0022598940482994,
           1.0021433115898482,
           1.0020246531634553,
           1.00190403284652,
           1.0017815666440375,
           1.0016573723790354,
           1.0015315695811313,
           1.0014042793733064,
           1.0012756243570002,
           1.0011457284956204,
           1.00101471699658,
           1.0008827161919647,
           1.0007498534179382,
           1.0006162568929975,
           1.0004820555951888,
           1.0003473791383968,
           1.0002123576478268,
           1.0000771216347908,
           0.9999418018709196,
           0.9998065292619194,
           0.9996714347209935,
           0.9995366490420523,
           0.9994023027728302,
           0.9992685260880401,
           0.9991354486626847,
           0.99900319954565,
           0.998871907033711,
           0.9987416985460698,
           0.998612700499557,
           0.9984850381846213,
           0.998358835642233,
           0.9982342155418271,
           0.9981112990604146,
           0.9979902057629857,
           0.9978710534843277,
           0.9977539582123846,
           0.9976390339732815,
           0.997526392718132,
           0.9974161442117535,
           0.9973083959234067,
           0.9972032529196787,
           0.9971008177596252,
           0.997001190392285,
           0.9969044680566781,
           0.9968107451844015,
           0.9967201133049225,
           0.9966326609536833,
           0.9965484735831095,
           0.9964676334766295,
           0.9963902196657984,
           0.9963163078506165,
           0.9962459703231379,
           0.99617927589445,
           0.996116289825113,
           0.9960570737591306,
           0.9960016856615358,
           0.9959501797596564,
           0.9959026064881321,
           0.9958590124377437,
           0.9958194403081156,
           0.9957839288643436,
           0.995752512897601,
           0.9957252231897666,
           0.9957020864821172,
           0.9956831254481202,
           0.9956683586703563,
           0.9956578006216044,
           0.9956514616501044,
           0.9956493479690186,
           0.9956514616501045,
           0.9956578006216046,
           0.9956683586703563,
           0.9956831254481201,
           0.9957020864821174,
           0.9957252231897665,
           0.9957525128976011,
           0.9957839288643436,
           0.9958194403081159,
           0.9958590124377438,
           0.9959026064881321,
           0.9959501797596564,
           0.996001685661536,
           0.9960570737591308,
           0.996116289825113,
           0.9961792758944502,
           0.9962459703231381,
           0.9963163078506168,
           0.9963902196657987,
           0.9964676334766296,
           0.9965484735831095,
           0.9966326609536834,
           0.9967201133049226,
           0.9968107451844014,
           0.9969044680566782,
           0.997001190392285,
           0.9971008177596256,
           0.9972032529196788,
           0.9973083959234067,
           0.9974161442117537,
           0.9975263927181323,
           0.9976390339732818,
           0.9977539582123847,
           0.9978710534843277,
           0.9979902057629859,
           0.9981112990604146,
           0.9982342155418272,
           0.9983588356422332,
           0.9984850381846216,
           0.9986127004995571,
           0.9987416985460696,
           0.9988719070337111,
           0.9990031995456502,
           0.9991354486626849,
           0.9992685260880404,
           0.9994023027728303,
           0.9995366490420524,
           0.9996714347209937,
           0.9998065292619195,
           0.9999418018709196,
           1.000077121634791,
           1.000212357647827,
           1.000347379138397,
           1.000482055595189,
           1.000616256892998,
           1.0007498534179384,
           1.000882716191965,
           1.0010147169965802,
           1.0011457284956204,
           1.0012756243570005,
           1.0014042793733067,
           1.0015315695811313,
           1.0016573723790356,
           1.001781566644038,
           1.00190403284652,
           1.0020246531634551,
           1.0021433115898484,
           1.0022598940482994,
           1.002374288496591,
           1.0024863850332033,
           1.0025960760006731,
           1.0027032560867002,
           1.002807822422921,
           1.0029096746812625,
           1.0030087151677978,
           1.0031048489140213,
           1.0031979837654719,
           1.0032880304676277,
           1.0033749027490024,
           1.0034585174013742,
           1.0035387943570866,
           1.0036156567633503,
           1.0036890310534956,
           1.003758847015108,
           1.003825037855003,
           1.0038875402609801,
           1.0039462944603097,
           1.0040012442749107,
           1.0040523371731662,
           1.0040995243183486,
           1.0041427606136046,
           1.004182004743473,
           1.0042172192118999,
           1.0042483703767222,
           1.0042754284805933,
           1.004298367678325,
           1.0043171660606287,
           1.004331805674234,
           1.0043422725383704,
           1.0043485566575978
          ],
          [
           1.0077301276367234,
           1.007726417113038,
           1.0077152890497447,
           1.0076967539670463,
           1.0076708293883312,
           1.0076375398247532,
           1.0075969167536605,
           1.0075489985908808,
           1.0074938306568808,
           1.007431465136828,
           1.0073619610345645,
           1.0072853841205378,
           1.007201806873709,
           1.007111308417478,
           1.0070139744496684,
           1.0069098971666117,
           1.0067991751813805,
           1.006681913436224,
           1.006558223109261,
           1.0064282215154872,
           1.0062920320021675,
           1.006149783838677,
           1.0060016121008633,
           1.0058476575500104,
           1.005688066506485,
           1.0055229907181462,
           1.0053525872236155,
           1.0051770182104978,
           1.0049964508686524,
           1.0048110572386224,
           1.0046210140553218,
           1.0044265025871055,
           1.0042277084703277,
           1.0040248215395209,
           1.0038180356533146,
           1.0036075485162321,
           1.0033935614964984,
           1.0031762794399997,
           1.0029559104805434,
           1.0027326658465676,
           1.0025067596644552,
           1.0022784087586125,
           1.002047832448481,
           1.0018152523426433,
           1.0015808921302078,
           1.0013449773696412,
           1.001107735275237,
           1.0008693945014056,
           1.0006301849249757,
           1.0003903374257082,
           1.0001500836652133,
           0.9999096558644818,
           0.9996692865802356,
           0.9994292084803047,
           0.9991896541182508,
           0.9989508557074495,
           0.9987130448948549,
           0.998476452534669,
           0.9982413084621402,
           0.9980078412677231,
           0.9977762780718248,
           0.9975468443003739,
           0.9973197634614464,
           0.9970952569231808,
           0.9968735436932208,
           0.9966548401999225,
           0.9964393600755636,
           0.9962273139417936,
           0.9960189091975579,
           0.9958143498097395,
           0.9956138361067485,
           0.9954175645752977,
           0.9952257276605956,
           0.9950385135701892,
           0.9948561060816848,
           0.994678684354572,
           0.9945064227463765,
           0.9943394906333591,
           0.994178052235975,
           0.9940222664493108,
           0.9938722866786979,
           0.9937282606807096,
           0.9935903304097385,
           0.9934586318703398,
           0.9933332949755297,
           0.9932144434112163,
           0.9931021945069317,
           0.9929966591130316,
           0.9928979414845192,
           0.9928061391716391,
           0.9927213429173872,
           0.9926436365620627,
           0.992573096954992,
           0.9925097938735336,
           0.9924537899494735,
           0.9924051406029076,
           0.9923638939836935,
           0.9923300909205531,
           0.9923037648778917,
           0.992284941920389,
           0.9922736406854106,
           0.9922698723632766,
           0.9922736406854107,
           0.992284941920389,
           0.9923037648778915,
           0.9923300909205532,
           0.9923638939836935,
           0.9924051406029076,
           0.9924537899494738,
           0.9925097938735336,
           0.9925730969549921,
           0.9926436365620629,
           0.9927213429173871,
           0.992806139171639,
           0.9928979414845192,
           0.9929966591130317,
           0.9931021945069317,
           0.9932144434112166,
           0.9933332949755298,
           0.9934586318703398,
           0.9935903304097389,
           0.9937282606807099,
           0.9938722866786978,
           0.9940222664493109,
           0.9941780522359751,
           0.9943394906333591,
           0.9945064227463768,
           0.9946786843545723,
           0.9948561060816851,
           0.9950385135701896,
           0.9952257276605958,
           0.9954175645752978,
           0.9956138361067488,
           0.9958143498097398,
           0.9960189091975581,
           0.9962273139417938,
           0.9964393600755638,
           0.9966548401999226,
           0.9968735436932209,
           0.997095256923181,
           0.9973197634614467,
           0.997546844300374,
           0.9977762780718249,
           0.9980078412677235,
           0.9982413084621404,
           0.9984764525346692,
           0.9987130448948551,
           0.9989508557074496,
           0.999189654118251,
           0.9994292084803049,
           0.9996692865802357,
           0.999909655864482,
           1.0001500836652135,
           1.0003903374257084,
           1.0006301849249761,
           1.0008693945014058,
           1.0011077352752376,
           1.0013449773696415,
           1.001580892130208,
           1.0018152523426436,
           1.0020478324484812,
           1.0022784087586127,
           1.0025067596644552,
           1.0027326658465678,
           1.0029559104805434,
           1.0031762794399999,
           1.0033935614964984,
           1.0036075485162321,
           1.0038180356533148,
           1.004024821539521,
           1.004227708470328,
           1.0044265025871055,
           1.004621014055322,
           1.0048110572386224,
           1.0049964508686529,
           1.005177018210498,
           1.0053525872236158,
           1.0055229907181464,
           1.0056880665064851,
           1.0058476575500104,
           1.0060016121008633,
           1.006149783838677,
           1.0062920320021678,
           1.0064282215154872,
           1.006558223109261,
           1.0066819134362242,
           1.0067991751813803,
           1.0069098971666117,
           1.0070139744496684,
           1.0071113084174783,
           1.0072018068737087,
           1.007285384120538,
           1.0073619610345645,
           1.0074314651368281,
           1.007493830656881,
           1.0075489985908805,
           1.0075969167536607,
           1.007637539824753,
           1.007670829388331,
           1.0076967539670463,
           1.0077152890497447,
           1.0077264171130382
          ],
          [
           1.0120695602592433,
           1.0120637916076674,
           1.0120464910365605,
           1.012017674692309,
           1.0119773694706282,
           1.0119256129941743,
           1.0118624535812175,
           1.0117879502053835,
           1.0117021724464808,
           1.0116052004324372,
           1.0114971247723659,
           1.0113780464807893,
           1.011248076893054,
           1.0111073375719715,
           1.0109559602057228,
           1.0107940864970741,
           1.0106218680439518,
           1.0104394662114249,
           1.010247051995161,
           1.0100448058764095,
           1.009832917668588,
           1.0096115863555366,
           1.009381019921523,
           1.0091414351730834,
           1.008893057552781,
           1.0086361209449861,
           1.0083708674737726,
           1.0080975472930394,
           1.0078164183689728,
           1.00752774625497,
           1.0072318038591461,
           1.0069288712045648,
           1.0066192351823322,
           1.0063031892977012,
           1.005981033409343,
           1.005653073461953,
           1.005319621212358,
           1.004980993949309,
           1.0046375142071469,
           1.0042895094735342,
           1.0039373118914652,
           1.0035812579557577,
           1.003221688204262,
           1.0028589469040026,
           1.0024933817325081,
           1.0021253434545652,
           1.0017551855946623,
           1.001383264105386,
           1.0010099370320458,
           1.0006355641738118,
           1.0002605067416577,
           0.999885127013411,
           0.9995097879862208,
           0.9991348530267585,
           0.9987606855194818,
           0.9983876485132949,
           0.9980161043669449,
           0.9976464143935078,
           0.997278938504317,
           0.9969140348527016,
           0.9965520594778987,
           0.9961933659495238,
           0.9958383050129729,
           0.9954872242361464,
           0.9951404676578888,
           0.9947983754385327,
           0.9944612835129532,
           0.9941295232465298,
           0.9938034210944222,
           0.9934832982645653,
           0.9931694703847898,
           0.9928622471744777,
           0.9925619321211566,
           0.992268822162441,
           0.9919832073737243,
           0.9917053706620197,
           0.9914355874663535,
           0.991174125465099,
           0.9909212442906412,
           0.9906771952517575,
           0.9904422210640861,
           0.9902165555890536,
           0.9900004235816209,
           0.9897940404471981,
           0.9895976120080695,
           0.9894113342796595,
           0.9892353932569579,
           0.9890699647114093,
           0.9889152139985623,
           0.9887712958767577,
           0.9886383543371184,
           0.9885165224450928,
           0.9884059221937873,
           0.988306664369301,
           0.9882188484282675,
           0.9881425623877867,
           0.9880778827279092,
           0.9880248743068218,
           0.9879835902888645,
           0.9879540720854832,
           0.9879363493092131,
           0.9879304397407567,
           0.987936349309213,
           0.9879540720854832,
           0.9879835902888645,
           0.988024874306822,
           0.9880778827279091,
           0.988142562387787,
           0.9882188484282675,
           0.9883066643693011,
           0.9884059221937874,
           0.9885165224450929,
           0.9886383543371186,
           0.9887712958767577,
           0.9889152139985625,
           0.9890699647114095,
           0.9892353932569581,
           0.9894113342796599,
           0.9895976120080696,
           0.9897940404471983,
           0.9900004235816211,
           0.9902165555890537,
           0.9904422210640863,
           0.9906771952517577,
           0.9909212442906414,
           0.9911741254650993,
           0.9914355874663537,
           0.9917053706620199,
           0.9919832073737246,
           0.9922688221624414,
           0.9925619321211568,
           0.9928622471744778,
           0.9931694703847901,
           0.9934832982645656,
           0.9938034210944224,
           0.99412952324653,
           0.9944612835129537,
           0.994798375438533,
           0.9951404676578892,
           0.9954872242361468,
           0.9958383050129731,
           0.9961933659495243,
           0.9965520594778992,
           0.996914034852702,
           0.9972789385043175,
           0.9976464143935083,
           0.9980161043669451,
           0.9983876485132953,
           0.9987606855194824,
           0.9991348530267588,
           0.9995097879862211,
           0.9998851270134115,
           1.000260506741658,
           1.0006355641738123,
           1.0010099370320462,
           1.0013832641053864,
           1.0017551855946627,
           1.0021253434545654,
           1.0024933817325083,
           1.0028589469040028,
           1.0032216882042622,
           1.0035812579557581,
           1.0039373118914654,
           1.0042895094735347,
           1.004637514207147,
           1.0049809939493095,
           1.0053196212123583,
           1.0056530734619533,
           1.0059810334093435,
           1.0063031892977017,
           1.0066192351823327,
           1.006928871204565,
           1.0072318038591463,
           1.0075277462549703,
           1.0078164183689733,
           1.0080975472930396,
           1.008370867473773,
           1.0086361209449868,
           1.0088930575527812,
           1.0091414351730834,
           1.0093810199215232,
           1.0096115863555368,
           1.0098329176685883,
           1.0100448058764095,
           1.010247051995161,
           1.0104394662114249,
           1.0106218680439518,
           1.0107940864970741,
           1.0109559602057225,
           1.0111073375719717,
           1.011248076893054,
           1.0113780464807893,
           1.0114971247723659,
           1.0116052004324374,
           1.011702172446481,
           1.0117879502053837,
           1.011862453581218,
           1.0119256129941743,
           1.011977369470628,
           1.012017674692309,
           1.0120464910365605,
           1.0120637916076674
          ],
          [
           1.0173647517777364,
           1.0173564954743815,
           1.0173317341499521,
           1.0172904905554738,
           1.017232802589718,
           1.017158723269795,
           1.0170683206899969,
           1.0169616779688861,
           1.016838893184642,
           1.0167000792986798,
           1.0165453640675448,
           1.016374889943106,
           1.0161888139610575,
           1.015987307617753,
           1.0157705567353934,
           1.0155387613155924,
           1.0152921353813495,
           1.0150309068074646,
           1.0147553171394266,
           1.0144656214008212,
           1.0141620878892996,
           1.01384499796116,
           1.0135146458045958,
           1.0131713382016774,
           1.0128153942791247,
           1.0124471452479562,
           1.0120669341320851,
           1.01167511548596,
           1.0112720551013392,
           1.0108581297033072,
           1.0104337266356478,
           1.009999243535693,
           1.0095550879987831,
           1.0091016772324823,
           1.0086394377006986,
           1.0081688047578787,
           1.0076902222734514,
           1.0072041422467084,
           1.006711024412326,
           1.0062113358367415,
           1.0057055505056103,
           1.005194148902591,
           1.0046776175797123,
           1.0041564487195884,
           1.0036311396897812,
           1.0031021925895982,
           1.0025701137896532,
           1.0020354134645169,
           1.0014986051188133,
           1.0009602051071214,
           1.0004207321480718,
           0.9998807068330302,
           0.9993406511297905,
           0.9988010878817043,
           0.9982625403026995,
           0.9977255314686531,
           0.9971905838055957,
           0.9966582185752523,
           0.996128955358426,
           0.9956033115367577,
           0.9950818017734018,
           0.9945649374931794,
           0.994053226362776,
           0.9935471717715716,
           0.9930472723136985,
           0.9925540212719338,
           0.9920679061040502,
           0.9915894079322465,
           0.9911190010363011,
           0.9906571523510913,
           0.9902043209691282,
           0.9897609576487653,
           0.9893275043287415,
           0.9889043936497189,
           0.9884920484834837,
           0.9880908814704678,
           0.9877012945662611,
           0.9873236785977663,
           0.9869584128296525,
           0.9866058645417575,
           0.9862663886180753,
           0.985940327147957,
           0.98562800904015,
           0.9853297496502714,
           0.9850458504223146,
           0.9847765985447582,
           0.9845222666218356,
           0.9842831123605003,
           0.984059378273605,
           0.9838512913997847,
           0.9836590630405152,
           0.9834828885147863,
           0.9833229469318119,
           0.9831794009821588,
           0.9830523967476568,
           0.982942063530417,
           0.9828485137012549,
           0.9827718425677819,
           0.9827121282623962,
           0.9826694316503672,
           0.9826437962581811,
           0.9826352482222636,
           0.982643796258181,
           0.9826694316503675,
           0.9827121282623962,
           0.982771842567782,
           0.982848513701255,
           0.982942063530417,
           0.983052396747657,
           0.983179400982159,
           0.983322946931812,
           0.9834828885147864,
           0.9836590630405152,
           0.9838512913997849,
           0.9840593782736051,
           0.9842831123605007,
           0.9845222666218358,
           0.9847765985447587,
           0.985045850422315,
           0.9853297496502716,
           0.9856280090401504,
           0.9859403271479575,
           0.9862663886180756,
           0.9866058645417579,
           0.9869584128296527,
           0.9873236785977667,
           0.9877012945662615,
           0.9880908814704682,
           0.988492048483484,
           0.9889043936497195,
           0.9893275043287418,
           0.9897609576487658,
           0.9902043209691287,
           0.9906571523510918,
           0.9911190010363017,
           0.9915894079322468,
           0.9920679061040507,
           0.9925540212719344,
           0.9930472723136989,
           0.9935471717715723,
           0.9940532263627767,
           0.9945649374931801,
           0.9950818017734023,
           0.9956033115367582,
           0.9961289553584265,
           0.9966582185752529,
           0.9971905838055961,
           0.9977255314686535,
           0.9982625403027002,
           0.9988010878817047,
           0.9993406511297911,
           0.9998807068330309,
           1.0004207321480723,
           1.0009602051071218,
           1.0014986051188137,
           1.0020354134645175,
           1.0025701137896537,
           1.0031021925895989,
           1.0036311396897817,
           1.0041564487195889,
           1.0046776175797125,
           1.0051941489025915,
           1.0057055505056107,
           1.006211335836742,
           1.0067110244123265,
           1.0072041422467088,
           1.0076902222734518,
           1.0081688047578792,
           1.008639437700699,
           1.0091016772324828,
           1.0095550879987838,
           1.0099992435356935,
           1.0104337266356485,
           1.0108581297033077,
           1.0112720551013397,
           1.0116751154859605,
           1.0120669341320858,
           1.0124471452479566,
           1.0128153942791251,
           1.0131713382016776,
           1.0135146458045963,
           1.0138449979611601,
           1.0141620878893,
           1.0144656214008216,
           1.0147553171394266,
           1.0150309068074646,
           1.0152921353813498,
           1.0155387613155926,
           1.0157705567353938,
           1.0159873076177532,
           1.0161888139610573,
           1.0163748899431062,
           1.016545364067545,
           1.0167000792986798,
           1.0168388931846422,
           1.0169616779688861,
           1.017068320689997,
           1.0171587232697947,
           1.0172328025897175,
           1.0172904905554738,
           1.0173317341499521,
           1.0173564954743817
          ],
          [
           1.0236105794363932,
           1.0235994219534166,
           1.0235659595693036,
           1.0235102224713504,
           1.0234322609478697,
           1.023332145352418,
           1.0232099660537055,
           1.0230658333711784,
           1.0228998774962654,
           1.022712248399279,
           1.0225031157219524,
           1.0222726686556023,
           1.022021115804897,
           1.0217486850372166,
           1.0214556233175804,
           1.0211421965291365,
           1.0208086892791806,
           1.0204554046906995,
           1.020082664179419,
           1.01969080721634,
           1.0192801910757576,
           1.0188511905687496,
           1.0184041977621339,
           1.0179396216828884,
           1.0174578880080474,
           1.0169594387400764,
           1.0164447318677454,
           1.0159142410125261,
           1.0153684550605444,
           1.0148078777801304,
           1.0142330274250138,
           1.0136444363232346,
           1.013042650451835,
           1.0124282289974231,
           1.011801743902708,
           1.011163779399123,
           1.010514931525665,
           1.0098558076340975,
           1.0091870258806834,
           1.008509214704632,
           1.0078230122934568,
           1.0071290660354797,
           1.0064280319597116,
           1.0057205741633901,
           1.0050073642274573,
           1.0042890806202949,
           1.0035664080900593,
           1.0028400370459776,
           1.0021106629290026,
           1.0013789855722433,
           1.0006457085516194,
           0.9999115385272196,
           0.9991771845758634,
           0.9984433575154067,
           0.9977107692213539,
           0.9969801319363691,
           0.9962521575733155,
           0.9955275570124731,
           0.9948070393936226,
           0.9940913114037087,
           0.9933810765608262,
           0.9926770344953015,
           0.9919798802286721,
           0.9912903034513877,
           0.9906089878000949,
           0.9899366101353786,
           0.9892738398208685,
           0.9886213380046391,
           0.9879797569038474,
           0.987349739093582,
           0.9867319168009089,
           0.9861269112051123,
           0.9855353317451548,
           0.984957775435377,
           0.9843948261904809,
           0.983847054160834,
           0.9833150150791518,
           0.9827992496195994,
           0.9823002827703666,
           0.98181862322076,
           0.9813547627638464,
           0.9809091757156781,
           0.9804823183521123,
           0.9800746283642193,
           0.9796865243332606,
           0.9793184052261886,
           0.978970649912598,
           0.9786436167040264,
           0.9783376429164745,
           0.9780530444569746,
           0.9777901154350037,
           0.9775491277994902,
           0.9773303310021315,
           0.9771339516876738,
           0.9769601934117788,
           0.9768092363870331,
           0.9766812372576132,
           0.9765763289030596,
           0.9764946202715563,
           0.9764361962430593,
           0.9764011175225454,
           0.9763894205636069,
           0.9764011175225455,
           0.9764361962430594,
           0.9764946202715565,
           0.9765763289030596,
           0.9766812372576136,
           0.9768092363870333,
           0.9769601934117789,
           0.977133951687674,
           0.9773303310021317,
           0.9775491277994904,
           0.9777901154350038,
           0.9780530444569749,
           0.9783376429164747,
           0.9786436167040266,
           0.9789706499125984,
           0.9793184052261893,
           0.9796865243332611,
           0.9800746283642198,
           0.9804823183521127,
           0.9809091757156785,
           0.9813547627638467,
           0.9818186232207606,
           0.9823002827703672,
           0.9827992496195999,
           0.9833150150791522,
           0.9838470541608346,
           0.9843948261904814,
           0.9849577754353778,
           0.9855353317451554,
           0.9861269112051129,
           0.9867319168009094,
           0.9873497390935828,
           0.9879797569038479,
           0.9886213380046397,
           0.9892738398208691,
           0.9899366101353793,
           0.9906089878000955,
           0.9912903034513882,
           0.9919798802286728,
           0.9926770344953025,
           0.993381076560827,
           0.9940913114037093,
           0.9948070393936234,
           0.9955275570124738,
           0.9962521575733162,
           0.9969801319363699,
           0.9977107692213546,
           0.9984433575154076,
           0.9991771845758639,
           0.9999115385272203,
           1.00064570855162,
           1.001378985572244,
           1.0021106629290033,
           1.0028400370459785,
           1.0035664080900601,
           1.0042890806202958,
           1.0050073642274582,
           1.0057205741633908,
           1.0064280319597123,
           1.0071290660354806,
           1.0078230122934575,
           1.0085092147046326,
           1.0091870258806843,
           1.0098558076340982,
           1.0105149315256656,
           1.0111637793991235,
           1.0118017439027085,
           1.0124282289974238,
           1.013042650451836,
           1.0136444363232353,
           1.0142330274250142,
           1.0148078777801306,
           1.015368455060545,
           1.0159142410125266,
           1.016444731867746,
           1.016959438740077,
           1.017457888008048,
           1.0179396216828887,
           1.018404197762134,
           1.0188511905687503,
           1.019280191075758,
           1.0196908072163404,
           1.0200826641794194,
           1.0204554046907,
           1.0208086892791808,
           1.0211421965291367,
           1.0214556233175807,
           1.0217486850372168,
           1.0220211158048975,
           1.0222726686556025,
           1.0225031157219526,
           1.0227122483992792,
           1.0228998774962659,
           1.0230658333711786,
           1.0232099660537062,
           1.023332145352418,
           1.0234322609478694,
           1.0235102224713504,
           1.023565959569304,
           1.023599421953417
          ],
          [
           1.030801000800334,
           1.0307865469009319,
           1.0307431979705217,
           1.0306709923043307,
           1.0305699937005346,
           1.0304402914194308,
           1.0302820001262583,
           1.0300952598176234,
           1.029880235731498,
           1.0296371182407422,
           1.0293661227300959,
           1.029067489456578,
           1.0287414833932258,
           1.0283883940560907,
           1.0280085353144177,
           1.0276022451839142,
           1.0271698856030167,
           1.0267118421920525,
           1.026228523995207,
           1.0257203632051743,
           1.0251878148704001,
           1.024631356584795,
           1.0240514881598208,
           1.0234487312788276,
           1.0228236291335502,
           1.0221767460426436,
           1.0215086670521676,
           1.0208199975179193,
           1.0201113626695255,
           1.0193834071562131,
           1.0186367945741825,
           1.0178722069755222,
           1.0170903443586163,
           1.0162919241400052,
           1.015477680607673,
           1.014648364355767,
           1.0138047417007516,
           1.0129475940790351,
           1.012077717426123,
           1.0111959215373776,
           1.0103030294104853,
           1.009399876569768,
           1.0084873103724956,
           1.0075661892973904,
           1.006637382215555,
           1.0057017676440747,
           1.004760232982597,
           1.00381367373322,
           1.0028629927040609,
           1.0019090991969297,
           1.000952908179557,
           0.9999953394428852,
           0.9990373167439743,
           0.9980797669351175,
           0.9971236190798111,
           0.9961698035562815,
           0.9952192511493068,
           0.9942728921311383,
           0.9933316553323661,
           0.9923964672036341,
           0.9914682508691544,
           0.9905479251730327,
           0.9896364037194556,
           0.9887345939078556,
           0.9878433959642071,
           0.9869637019696699,
           0.9860963948878273,
           0.985242347591832,
           0.9844024218927996,
           0.9835774675708439,
           0.9827683214101804,
           0.981975806239766,
           0.9812007299809726,
           0.9804438847038248,
           0.9797060456933595,
           0.9789879705276809,
           0.9782903981693147,
           0.9776140480714653,
           0.9769596193007988,
           0.9763277896783744,
           0.9757192149403464,
           0.9751345279200496,
           0.9745743377530772,
           0.9740392291069303,
           0.9735297614368067,
           0.9730464682690597,
           0.9725898565138247,
           0.9721604058082749,
           0.9717585678919116,
           0.9713847660152536,
           0.9710393943832245,
           0.9707228176344745,
           0.9704353703578121,
           0.970177356646834,
           0.96994904969378,
           0.9697506914235436,
           0.9695824921686877,
           0.9694446303862251,
           0.9693372524168307,
           0.9692604722870456,
           0.9692143715549503,
           0.9691989991996659,
           0.9692143715549504,
           0.9692604722870456,
           0.9693372524168307,
           0.9694446303862253,
           0.9695824921686877,
           0.969750691423544,
           0.9699490496937804,
           0.9701773566468342,
           0.9704353703578125,
           0.9707228176344751,
           0.9710393943832248,
           0.971384766015254,
           0.971758567891912,
           0.9721604058082753,
           0.9725898565138252,
           0.9730464682690602,
           0.9735297614368074,
           0.9740392291069307,
           0.9745743377530778,
           0.9751345279200503,
           0.975719214940347,
           0.976327789678375,
           0.9769596193007994,
           0.9776140480714659,
           0.9782903981693154,
           0.9789879705276818,
           0.9797060456933603,
           0.9804438847038257,
           0.9812007299809733,
           0.9819758062397668,
           0.9827683214101812,
           0.9835774675708447,
           0.9844024218928006,
           0.9852423475918329,
           0.9860963948878284,
           0.9869637019696708,
           0.9878433959642081,
           0.9887345939078563,
           0.9896364037194564,
           0.9905479251730336,
           0.9914682508691552,
           0.9923964672036348,
           0.9933316553323672,
           0.9942728921311395,
           0.9952192511493076,
           0.9961698035562824,
           0.997123619079812,
           0.9980797669351184,
           0.9990373167439753,
           0.9999953394428861,
           1.0009529081795578,
           1.0019090991969308,
           1.002862992704062,
           1.0038136737332208,
           1.0047602329825984,
           1.0057017676440754,
           1.0066373822155559,
           1.0075661892973913,
           1.0084873103724965,
           1.009399876569769,
           1.0103030294104862,
           1.0111959215373785,
           1.0120777174261242,
           1.0129475940790362,
           1.0138047417007527,
           1.0146483643557678,
           1.015477680607674,
           1.0162919241400061,
           1.0170903443586174,
           1.0178722069755228,
           1.018636794574183,
           1.019383407156214,
           1.0201113626695264,
           1.02081999751792,
           1.0215086670521683,
           1.0221767460426445,
           1.0228236291335508,
           1.0234487312788283,
           1.0240514881598213,
           1.0246313565847958,
           1.0251878148704006,
           1.0257203632051748,
           1.0262285239952071,
           1.026711842192053,
           1.0271698856030167,
           1.0276022451839146,
           1.028008535314418,
           1.0283883940560912,
           1.0287414833932262,
           1.0290674894565786,
           1.029366122730096,
           1.0296371182407424,
           1.0298802357314982,
           1.0300952598176234,
           1.0302820001262585,
           1.0304402914194308,
           1.0305699937005346,
           1.0306709923043307,
           1.0307431979705215,
           1.030786546900932
          ],
          [
           1.038929059601276,
           1.0389109343601213,
           1.03885657427531,
           1.0387660262540137,
           1.0386393684455644,
           1.0384767101974919,
           1.0382781919939172,
           1.0380439853762418,
           1.037774292846051,
           1.0374693477501453,
           1.0371294141475857,
           1.0367547866586264,
           1.0363457902953952,
           1.0359027802741658,
           1.0354261418090485,
           1.0349162898869162,
           1.0343736690233678,
           1.033798752999516,
           1.033192044579379,
           1.0325540752076412,
           1.0318854046875439,
           1.031186620838644,
           1.0304583391341935,
           1.0297012023178638,
           1.0289158799995475,
           1.0281030682299626,
           1.0272634890537784,
           1.0263978900409911,
           1.0255070437962621,
           1.0245917474459574,
           1.023652822102605,
           1.0226911123065203,
           1.0217074854443347,
           1.0207028311441924,
           1.0196780606473828,
           1.0186341061561945,
           1.0175719201577988,
           1.0164924747239876,
           1.0153967607866141,
           1.014285787388618,
           1.013160580910536,
           1.0120221842724422,
           1.010871656111292,
           1.0097100699336785,
           1.008538513244068,
           1.0073580866486058,
           1.0061699029346483,
           1.0049750861262219,
           1.0037747705156665,
           1.0025700996717766,
           1.001362225424821,
           1.0001523068288793,
           0.9989415091020104,
           0.9977310025448236,
           0.9965219614381162,
           0.9953155629203024,
           0.994112985845441,
           0.9929154096227549,
           0.9917240130386096,
           0.9905399730620124,
           0.9893644636347684,
           0.9881986544475273,
           0.9870437097030352,
           0.9859007868679939,
           0.9847710354150255,
           0.983655595556315,
           0.9825555969705985,
           0.9814721575252509,
           0.9804063819952973,
           0.9793593607812675,
           0.97833216862788,
           0.9773258633456146,
           0.9763414845373097,
           0.9753800523319766,
           0.9744425661280812,
           0.9735300033486055,
           0.9726433182102346,
           0.971783440509065,
           0.9709512744252538,
           0.9701476973490573,
           0.9693735587307183,
           0.9686296789566702,
           0.9679168482545238,
           0.9672358256292833,
           0.9665873378332268,
           0.9659720783718414,
           0.9653907065481722,
           0.9648438465478791,
           0.9643320865672428,
           0.9638559779862816,
           0.9634160345890581,
           0.9630127318331594,
           0.9626465061702385,
           0.9623177544193801,
           0.9620268331949416,
           0.9617740583903902,
           0.9615597047195117,
           0.9613840053162309,
           0.9612471513941276,
           0.9611492919665738,
           0.9610905336282627,
           0.9610709403987242,
           0.9610905336282627,
           0.961149291966574,
           0.9612471513941279,
           0.9613840053162311,
           0.9615597047195119,
           0.9617740583903905,
           0.9620268331949419,
           0.9623177544193804,
           0.962646506170239,
           0.9630127318331596,
           0.9634160345890584,
           0.9638559779862822,
           0.9643320865672433,
           0.9648438465478796,
           0.9653907065481729,
           0.9659720783718422,
           0.9665873378332275,
           0.967235825629284,
           0.9679168482545246,
           0.9686296789566711,
           0.969373558730719,
           0.970147697349058,
           0.9709512744252545,
           0.9717834405090657,
           0.9726433182102355,
           0.9735300033486065,
           0.9744425661280822,
           0.9753800523319776,
           0.9763414845373108,
           0.9773258633456156,
           0.9783321686278811,
           0.9793593607812686,
           0.9804063819952982,
           0.9814721575252519,
           0.9825555969705996,
           0.983655595556316,
           0.9847710354150269,
           0.9859007868679951,
           0.9870437097030363,
           0.9881986544475286,
           0.9893644636347695,
           0.9905399730620136,
           0.9917240130386107,
           0.9929154096227559,
           0.9941129858454422,
           0.9953155629203037,
           0.9965219614381176,
           0.9977310025448247,
           0.9989415091020116,
           1.0001523068288805,
           1.0013622254248218,
           1.0025700996717777,
           1.0037747705156679,
           1.0049750861262234,
           1.0061699029346494,
           1.007358086648607,
           1.0085385132440692,
           1.0097100699336796,
           1.0108716561112931,
           1.0120221842724435,
           1.013160580910537,
           1.014285787388619,
           1.0153967607866152,
           1.0164924747239887,
           1.0175719201577997,
           1.0186341061561954,
           1.0196780606473836,
           1.0207028311441935,
           1.0217074854443358,
           1.0226911123065212,
           1.0236528221026062,
           1.0245917474459583,
           1.0255070437962632,
           1.026397890040992,
           1.0272634890537795,
           1.0281030682299632,
           1.0289158799995484,
           1.0297012023178644,
           1.0304583391341942,
           1.0311866208386447,
           1.0318854046875445,
           1.0325540752076419,
           1.0331920445793794,
           1.0337987529995165,
           1.0343736690233685,
           1.0349162898869169,
           1.0354261418090487,
           1.0359027802741665,
           1.0363457902953956,
           1.0367547866586269,
           1.0371294141475862,
           1.0374693477501458,
           1.0377742928460514,
           1.038043985376242,
           1.0382781919939175,
           1.0384767101974917,
           1.0386393684455641,
           1.0387660262540137,
           1.0388565742753102,
           1.0389109343601217
          ],
          [
           1.0479868924672706,
           1.0479647429965993,
           1.0478983132053077,
           1.0477876589466302,
           1.0476328732795106,
           1.0474340864238818,
           1.047191465697963,
           1.046905215437481,
           1.046575576896684,
           1.046202828131013,
           1.0457872838612428,
           1.0453292953188975,
           1.0448292500727097,
           1.0442875718358728,
           1.0437047202538057,
           1.0430811906721287,
           1.0424175138845246,
           1.041714255860134,
           1.0409720174501125,
           1.0401914340729599,
           1.0393731753782038,
           1.0385179448880029,
           1.0376264796162245,
           1.0366995496645197,
           1.03573795779492,
           1.034742538978446,
           1.0337141599192299,
           1.0326537185536209,
           1.0315621435237452,
           1.0304403936249915,
           1.0292894572268676,
           1.0281103516666998,
           1.0269041226156266,
           1.025671843416348,
           1.024414614392108,
           1.0231335621263797,
           1.0218298387127562,
           1.0205046209745523,
           1.0191591096536496,
           1.0177945285681456,
           1.0164121237383896,
           1.0150131624810277,
           1.0135989324707169,
           1.0121707407692069,
           1.0107299128215481,
           1.0092777914192197,
           1.0078157356300497,
           1.0063451196948507,
           1.0048673318907662,
           1.0033837733614042,
           1.0018958569139063,
           1.000405005783197,
           0.9989126523637387,
           0.9974202369092284,
           0.9959292062007649,
           0.994441012184127,
           0.992957110576923,
           0.9914789594464803,
           0.9900080177594746,
           0.988545743904425,
           0.9870935941883081,
           0.9856530213086885,
           0.9842254728028917,
           0.9828123894758906,
           0.9814152038087217,
           0.9800353383493842,
           0.9786742040883242,
           0.9773331988207493,
           0.9760137054981554,
           0.9747170905715975,
           0.9734447023293641,
           0.9721978692318503,
           0.9709778982465573,
           0.9697860731862595,
           0.9686236530535011,
           0.9674918703946872,
           0.966391929667135,
           0.9653250056225305,
           0.9642922417103188,
           0.9632947485046158,
           0.962333602158279,
           0.9614098428878078,
           0.9605244734927729,
           0.9596784579134685,
           0.9588727198304776,
           0.9581081413098089,
           0.9573855614972185,
           0.9567057753652665,
           0.9560695325165773,
           0.9554775360466772,
           0.9549304414696537,
           0.9544288557097667,
           0.9539733361619709,
           0.9535643898241503,
           0.9532024725036818,
           0.9528879881007433,
           0.9526212879705657,
           0.952402670366609,
           0.9522323799663981,
           0.9521106074815056,
           0.9520374893529151,
           0.9520131075327295,
           0.9520374893529151,
           0.9521106074815057,
           0.9522323799663983,
           0.9524026703666093,
           0.9526212879705658,
           0.9528879881007437,
           0.9532024725036822,
           0.9535643898241507,
           0.9539733361619714,
           0.9544288557097672,
           0.9549304414696541,
           0.9554775360466776,
           0.9560695325165781,
           0.9567057753652671,
           0.9573855614972192,
           0.9581081413098098,
           0.9588727198304785,
           0.9596784579134693,
           0.9605244734927739,
           0.9614098428878088,
           0.96233360215828,
           0.9632947485046168,
           0.9642922417103197,
           0.9653250056225315,
           0.9663919296671362,
           0.9674918703946885,
           0.9686236530535022,
           0.9697860731862608,
           0.9709778982465584,
           0.9721978692318515,
           0.9734447023293654,
           0.9747170905715989,
           0.9760137054981568,
           0.9773331988207506,
           0.9786742040883257,
           0.9800353383493855,
           0.9814152038087232,
           0.9828123894758919,
           0.9842254728028931,
           0.9856530213086899,
           0.9870935941883094,
           0.9885457439044263,
           0.9900080177594761,
           0.9914789594464817,
           0.9929571105769243,
           0.9944410121841284,
           0.9959292062007665,
           0.99742023690923,
           0.9989126523637402,
           1.0004050057831986,
           1.001895856913908,
           1.0033837733614057,
           1.0048673318907677,
           1.0063451196948523,
           1.0078157356300514,
           1.009277791419221,
           1.0107299128215494,
           1.0121707407692084,
           1.0135989324707182,
           1.0150131624810292,
           1.016412123738391,
           1.0177945285681471,
           1.019159109653651,
           1.0205046209745539,
           1.0218298387127578,
           1.0231335621263808,
           1.0244146143921091,
           1.0256718434163494,
           1.0269041226156277,
           1.0281103516667012,
           1.0292894572268687,
           1.0304403936249926,
           1.0315621435237465,
           1.0326537185536215,
           1.0337141599192312,
           1.034742538978447,
           1.0357379577949208,
           1.0366995496645208,
           1.0376264796162251,
           1.0385179448880038,
           1.0393731753782047,
           1.0401914340729608,
           1.0409720174501131,
           1.0417142558601347,
           1.0424175138845253,
           1.0430811906721293,
           1.0437047202538061,
           1.0442875718358735,
           1.04482925007271,
           1.0453292953188977,
           1.0457872838612434,
           1.0462028281310134,
           1.0465755768966842,
           1.046905215437481,
           1.0471914656979635,
           1.0474340864238818,
           1.0476328732795106,
           1.0477876589466304,
           1.0478983132053081,
           1.0479647429965997
          ],
          [
           1.0579657365300115,
           1.0579392333990898,
           1.0578597456646581,
           1.0577273382931753,
           1.0575421195336017,
           1.0573042408746167,
           1.057013896984602,
           1.0566713256342428,
           1.0562768076015792,
           1.0558306665593078,
           1.0553332689440744,
           1.0547850238074845,
           1.0541863826485056,
           1.0535378392269001,
           1.0528399293573012,
           1.0520932306834918,
           1.0512983624324235,
           1.0504559851474657,
           1.0495668004003558,
           1.0486315504812593,
           1.0476510180663503,
           1.0466260258622546,
           1.0455574362266917,
           1.0444461507646048,
           1.0432931098990463,
           1.0420992924160524,
           1.0408657149827156,
           1.0395934316376407,
           1.0382835332529396,
           1.0369371469669086,
           1.0355554355865018,
           1.0341395969587093,
           1.032690863309925,
           1.0312105005523893,
           1.0296998075567732,
           1.0281601153899806,
           1.026592786517238,
           1.024999213967548,
           1.0233808204615984,
           1.0217390575012286,
           1.0200754044195837,
           1.0183913673911036,
           1.016688478400543,
           1.014968294170243,
           1.0132323950449376,
           1.0114823838334208,
           1.00971988460647,
           1.0079465414504944,
           1.0061640171764492,
           1.0043739919836503,
           1.0025781620782215,
           1.0007782382460098,
           0.9989759443799225,
           0.9971730159617646,
           0.9953711984987903,
           0.9935722459153277,
           0.9917779188999885,
           0.9899899832091388,
           0.9882102079274827,
           0.986440363686787,
           0.9846822208439683,
           0.9829375476199668,
           0.981208108201024,
           0.9794956608042109,
           0.9778019557092532,
           0.9761287332589409,
           0.9744777218306191,
           0.972850635781504,
           0.9712491733707794,
           0.9696750146616823,
           0.9681298194069897,
           0.9666152249215726,
           0.9651328439458788,
           0.9636842625044385,
           0.9622710377636885,
           0.9608946958935989,
           0.9595567299377847,
           0.9582585976969414,
           0.9570017196306038,
           0.955787476782365,
           0.9546172087338021,
           0.9534922115924553,
           0.9524137360192796,
           0.9513829853010258,
           0.9504011134730427,
           0.9494692234979699,
           0.9485883655057684,
           0.947759535100463,
           0.946983671738878,
           0.9462616571865263,
           0.9455943140556509,
           0.9449824044302344,
           0.944426628582581,
           0.9439276237858225,
           0.9434859632264305,
           0.943102155020525,
           0.9427766413374296,
           0.9425097976335903,
           0.9423019319995939,
           0.9421532846226445,
           0.9420640273664412,
           0.9420342634699886,
           0.9420640273664412,
           0.9421532846226447,
           0.942301931999594,
           0.9425097976335904,
           0.9427766413374301,
           0.9431021550205253,
           0.943485963226431,
           0.9439276237858231,
           0.9444266285825816,
           0.944982404430235,
           0.9455943140556515,
           0.946261657186527,
           0.9469836717388788,
           0.9477595351004637,
           0.9485883655057692,
           0.9494692234979709,
           0.9504011134730439,
           0.9513829853010269,
           0.9524137360192808,
           0.9534922115924565,
           0.9546172087338031,
           0.9557874767823662,
           0.9570017196306051,
           0.9582585976969427,
           0.9595567299377861,
           0.9608946958936003,
           0.9622710377636899,
           0.9636842625044401,
           0.9651328439458802,
           0.9666152249215744,
           0.9681298194069914,
           0.9696750146616838,
           0.9712491733707812,
           0.9728506357815054,
           0.9744777218306209,
           0.9761287332589426,
           0.9778019557092551,
           0.9794956608042126,
           0.9812081082010258,
           0.9829375476199684,
           0.9846822208439703,
           0.9864403636867889,
           0.9882102079274846,
           0.9899899832091406,
           0.9917779188999901,
           0.9935722459153294,
           0.9953711984987921,
           0.9971730159617663,
           0.9989759443799242,
           1.0007782382460115,
           1.0025781620782233,
           1.004373991983652,
           1.006164017176451,
           1.0079465414504964,
           1.0097198846064719,
           1.0114823838334226,
           1.0132323950449393,
           1.0149682941702445,
           1.0166884784005445,
           1.0183913673911054,
           1.0200754044195854,
           1.0217390575012304,
           1.0233808204616,
           1.0249992139675497,
           1.0265927865172397,
           1.028160115389982,
           1.0296998075567747,
           1.0312105005523908,
           1.0326908633099265,
           1.0341395969587104,
           1.035555435586503,
           1.0369371469669098,
           1.038283533252941,
           1.039593431637642,
           1.040865714982717,
           1.0420992924160537,
           1.0432931098990474,
           1.044446150764606,
           1.0455574362266926,
           1.0466260258622557,
           1.0476510180663516,
           1.0486315504812604,
           1.0495668004003567,
           1.0504559851474666,
           1.051298362432424,
           1.0520932306834927,
           1.0528399293573019,
           1.053537839226901,
           1.0541863826485063,
           1.0547850238074854,
           1.0553332689440749,
           1.0558306665593082,
           1.0562768076015798,
           1.056671325634243,
           1.0570138969846026,
           1.0573042408746167,
           1.0575421195336014,
           1.0577273382931758,
           1.0578597456646583,
           1.0579392333990902
          ],
          [
           1.0688559379023412,
           1.0688247762454626,
           1.0687313159731957,
           1.0685756311730739,
           1.068357845299051,
           1.068078131133512,
           1.0677367107339235,
           1.0673338553639495,
           1.066869885408815,
           1.0663451702746582,
           1.0657601282715488,
           1.0651152264798143,
           1.0644109805992565,
           1.0636479547808053,
           1.0628267614400837,
           1.0619480610523393,
           1.0610125619281214,
           1.0600210199690414,
           1.0589742384029168,
           1.057873067497522,
           1.056718404252154,
           1.0555111920661329,
           1.054252420383344,
           1.0529431243118546,
           1.0515843842175963,
           1.0501773252910673,
           1.0487231170859412,
           1.0472229730284457,
           1.0456781498963104,
           1.044089947266061,
           1.0424597069273733,
           1.040788812263184,
           1.0390786875942057,
           1.0373307974864672,
           1.035546646020469,
           1.0337277760205217,
           1.0318757682428088,
           1.029992240520706,
           1.0280788468658772,
           1.0261372765236578,
           1.024169252981247,
           1.0221765329272365,
           1.0201609051610148,
           1.0181241894506239,
           1.0160682353376758,
           1.01399492088797,
           1.0119061513865324,
           1.009803857975841,
           1.0076899962360961,
           1.0055665447064774,
           1.00343550334644,
           1.0012988919362174,
           0.999158748415834,
           0.9970171271620745,
           0.9948760972030272,
           0.9927377403699913,
           0.9906041493867361,
           0.9884774258963133,
           0.9863596784258416,
           0.9842530202899454,
           0.982159567433762,
           0.980081436216733,
           0.9780207411386687,
           0.9759795925098784,
           0.973960094067491,
           0.9719643405403993,
           0.9699944151656162,
           0.9680523871591753,
           0.9661403091450591,
           0.964260214546013,
           0.9624141149404507,
           0.9606039973900354,
           0.9588318217428823,
           0.957099517917677,
           0.9554089831743703,
           0.9537620793774343,
           0.9521606302580043,
           0.9506064186815274,
           0.9491011839278314,
           0.9476466189907932,
           0.94624436790501,
           0.9448960231070939,
           0.9436031228393659,
           0.9423671486038675,
           0.9411895226746916,
           0.9400716056766876,
           0.9390146942385927,
           0.9380200187286011,
           0.937088741080284,
           0.9362219527166356,
           0.9354206725798163,
           0.9346858452739261,
           0.9340183393278378,
           0.9334189455847807,
           0.9328883757249576,
           0.9324272609270511,
           0.9320361506739782,
           0.9317155117077269,
           0.931465727137552,
           0.9312870957051983,
           0.9311798312102013,
           0.9311440620976589,
           0.9311798312102013,
           0.9312870957051986,
           0.9314657271375522,
           0.9317155117077273,
           0.9320361506739786,
           0.9324272609270515,
           0.932888375724958,
           0.9334189455847813,
           0.9340183393278386,
           0.9346858452739267,
           0.9354206725798172,
           0.9362219527166363,
           0.9370887410802848,
           0.9380200187286021,
           0.9390146942385938,
           0.9400716056766888,
           0.9411895226746929,
           0.9423671486038687,
           0.9436031228393674,
           0.9448960231070954,
           0.9462443679050114,
           0.9476466189907945,
           0.949101183927833,
           0.9506064186815288,
           0.9521606302580059,
           0.9537620793774361,
           0.9554089831743721,
           0.9570995179176789,
           0.9588318217428841,
           0.9606039973900372,
           0.9624141149404525,
           0.964260214546015,
           0.966140309145061,
           0.9680523871591772,
           0.9699944151656184,
           0.9719643405404013,
           0.9739600940674932,
           0.9759795925098803,
           0.9780207411386708,
           0.9800814362167352,
           0.982159567433764,
           0.9842530202899474,
           0.9863596784258438,
           0.9884774258963155,
           0.9906041493867384,
           0.9927377403699935,
           0.9948760972030294,
           0.9970171271620767,
           0.9991587484158361,
           1.0012988919362196,
           1.003435503346442,
           1.0055665447064794,
           1.0076899962360983,
           1.009803857975843,
           1.0119061513865344,
           1.013994920887972,
           1.016068235337678,
           1.018124189450626,
           1.0201609051610165,
           1.0221765329272383,
           1.0241692529812492,
           1.0261372765236596,
           1.0280788468658792,
           1.029992240520708,
           1.0318757682428106,
           1.0337277760205237,
           1.035546646020471,
           1.037330797486469,
           1.0390786875942075,
           1.0407888122631856,
           1.0424597069273749,
           1.0440899472660625,
           1.045678149896312,
           1.0472229730284468,
           1.048723117085943,
           1.0501773252910689,
           1.0515843842175978,
           1.0529431243118557,
           1.0542524203833454,
           1.055511192066134,
           1.0567184042521554,
           1.0578730674975234,
           1.0589742384029177,
           1.0600210199690425,
           1.061012561928122,
           1.0619480610523404,
           1.0628267614400844,
           1.0636479547808062,
           1.0644109805992572,
           1.0651152264798147,
           1.0657601282715494,
           1.0663451702746587,
           1.0668698854088157,
           1.0673338553639498,
           1.0677367107339244,
           1.0680781311335121,
           1.068357845299051,
           1.068575631173074,
           1.068731315973196,
           1.068824776245463
          ],
          [
           1.0806469610177643,
           1.0806108613329068,
           1.0805025899699687,
           1.08032222999781,
           1.0800699198443438,
           1.079745853266162,
           1.0793502793058074,
           1.0788835022365029,
           1.0783458814940705,
           1.0777378315957384,
           1.0770598220454544,
           1.0763123772252765,
           1.0754960762723524,
           1.074611552940935,
           1.0736594954488157,
           1.07264064630751,
           1.0715558021354492,
           1.0704058134533774,
           1.0691915844610906,
           1.067914072794579,
           1.0665742892625762,
           1.0651732975614436,
           1.06371221396726,
           1.0621922070038992,
           1.0606144970858375,
           1.0589803561343225,
           1.057291107165509,
           1.055548123849059,
           1.0537528300356553,
           1.0519066992518025,
           1.0500112541602113,
           1.0480680659840136,
           1.0460787538929655,
           1.0440449843497541,
           1.0419684704144445,
           1.0398509710050567,
           1.0376942901122026,
           1.0355002759656644,
           1.0332708201507497,
           1.0310078566722238,
           1.0287133609635817,
           1.0263893488394065,
           1.0240378753885373,
           1.0216610338057686,
           1.0192609541598132,
           1.0168398020952658,
           1.0143997774663502,
           1.0119431129002652,
           1.0094720722880115,
           1.0069889492006625,
           1.0044960652291237,
           1.0019957682455587,
           0.9994904305847779,
           0.996982447144054,
           0.9944742334000013,
           0.9919682233413618,
           0.9894668673167685,
           0.9869726297968078,
           0.9844879870499829,
           0.9820154247324884,
           0.9795574353920337,
           0.9771165158863148,
           0.9746951647171266,
           0.9722958792815056,
           0.969921153041747,
           0.967573472616592,
           0.9652553147963704,
           0.9629691434853882,
           0.9607174065753784,
           0.9585025327543689,
           0.9563269282558811,
           0.9541929735539347,
           0.952103020009903,
           0.9500593864778384,
           0.9480643558754498,
           0.9461201717284818,
           0.9442290346967855,
           0.942393099090903,
           0.9406144693884873,
           0.9388951967603576,
           0.937237275616415,
           0.9356426401820463,
           0.934113161115983,
           0.9326506421808665,
           0.9312568169780095,
           0.9299333457579929,
           0.9286818123188412,
           0.9275037210035305,
           0.9264004938085216,
           0.925373467614873,
           0.9244238915532608,
           0.9235529245139199,
           0.9227616328121342,
           0.9220509880194137,
           0.921421864969949,
           0.9208750399512825,
           0.9204111890874259,
           0.9200308869218654,
           0.919734605207046,
           0.9195227119060144,
           0.9193954704109407,
           0.9193530389822356,
           0.9193954704109409,
           0.9195227119060146,
           0.9197346052070462,
           0.9200308869218656,
           0.9204111890874263,
           0.9208750399512831,
           0.9214218649699495,
           0.9220509880194144,
           0.922761632812135,
           0.9235529245139208,
           0.9244238915532617,
           0.9253734676148739,
           0.9264004938085227,
           0.9275037210035317,
           0.9286818123188425,
           0.9299333457579941,
           0.931256816978011,
           0.9326506421808681,
           0.9341131611159846,
           0.935642640182048,
           0.9372372756164166,
           0.9388951967603594,
           0.9406144693884891,
           0.9423930990909046,
           0.9442290346967874,
           0.9461201717284838,
           0.9480643558754518,
           0.9500593864778404,
           0.952103020009905,
           0.9541929735539367,
           0.9563269282558833,
           0.9585025327543711,
           0.9607174065753806,
           0.9629691434853905,
           0.9652553147963726,
           0.9675734726165943,
           0.9699211530417495,
           0.9722958792815081,
           0.9746951647171291,
           0.9771165158863174,
           0.9795574353920362,
           0.9820154247324911,
           0.9844879870499854,
           0.9869726297968103,
           0.9894668673167709,
           0.9919682233413645,
           0.994474233400004,
           0.9969824471440565,
           0.9994904305847805,
           1.0019957682455611,
           1.0044960652291262,
           1.006988949200665,
           1.0094720722880142,
           1.0119431129002676,
           1.014399777466353,
           1.0168398020952683,
           1.0192609541598157,
           1.021661033805771,
           1.0240378753885395,
           1.026389348839409,
           1.028713360963584,
           1.031007856672226,
           1.0332708201507521,
           1.0355002759656666,
           1.037694290112205,
           1.0398509710050587,
           1.0419684704144467,
           1.0440449843497561,
           1.0460787538929677,
           1.0480680659840154,
           1.0500112541602131,
           1.0519066992518045,
           1.0537528300356573,
           1.0555481238490605,
           1.057291107165511,
           1.058980356134324,
           1.060614497085839,
           1.062192207003901,
           1.0637122139672612,
           1.0651732975614452,
           1.0665742892625776,
           1.0679140727945806,
           1.069191584461092,
           1.0704058134533783,
           1.0715558021354503,
           1.072640646307511,
           1.0736594954488166,
           1.074611552940936,
           1.0754960762723533,
           1.0763123772252772,
           1.0770598220454553,
           1.0777378315957393,
           1.078345881494071,
           1.0788835022365035,
           1.079350279305808,
           1.0797458532661621,
           1.0800699198443442,
           1.0803222299978097,
           1.0805025899699687,
           1.0806108613329066
          ],
          [
           1.0933273988229284,
           1.0932861074695879,
           1.0931622640035266,
           1.092955960202624,
           1.092667349016663,
           1.0922966445471884,
           1.0918441220191033,
           1.0913101177437647,
           1.0906950290733126,
           1.089999314345881,
           1.0892234928212754,
           1.0883681446066438,
           1.0874339105715958,
           1.086421492252149,
           1.085331651742822,
           1.0841652115761118,
           1.082923054588521,
           1.0816061237722265,
           1.0802154221113982,
           1.078752012402094,
           1.077217017054581,
           1.0756116178768373,
           1.0739370558379095,
           1.072194630809703,
           1.0703857012856934,
           1.0685116840749513,
           1.0665740539697752,
           1.0645743433851265,
           1.062514141967963,
           1.0603950961744604,
           1.0582189088130107,
           1.055987338550779,
           1.053702199381499,
           1.0513653600520767,
           1.0489787434454723,
           1.0465443259172245,
           1.0440641365828802,
           1.0415402565534975,
           1.0389748181162861,
           1.0363700038573744,
           1.0337280457235918,
           1.0310512240200904,
           1.0283418663405548,
           1.0256023464266917,
           1.0228350829536468,
           1.020042538237954,
           1.0172272168646115,
           1.0143916642298691,
           1.011538464996331,
           1.0086702414570086,
           1.0057896518050244,
           1.0028993883057429,
           1.0000021753682165,
           0.9971007675129786,
           0.994197947233377,
           0.9912965227478514,
           0.9883993256407944,
           0.9855092083899122,
           0.9826290417783149,
           0.979761712189923,
           0.9769101187871779,
           0.9740771705704784,
           0.9712657833192575,
           0.9684788764151419,
           0.9657193695482036,
           0.962990179307946,
           0.9602942156613083,
           0.9576343783206948,
           0.9550135530057531,
           0.9524346076034288,
           0.9499003882316018,
           0.947413715212476,
           0.9449773789627254,
           0.9425941358082963,
           0.9402667037326338,
           0.937997758067995,
           0.9357899271403903,
           0.9336457878795579,
           0.9315678614062158,
           0.9295586086096501,
           0.927620425729446,
           0.9257556399558884,
           0.9239665050641924,
           0.9222551970982868,
           0.9206238101203582,
           0.9190743520427355,
           0.9176087405589766,
           0.9162287991911757,
           0.9149362534705465,
           0.9137327272682496,
           0.9126197392932058,
           0.9115986997732765,
           0.9106709073356939,
           0.9098375461019801,
           0.9090996830118235,
           0.9084582653894677,
           0.9079141187651288,
           0.9074679449627994,
           0.9071203204645277,
           0.9068716950598864,
           0.9067223907878882,
           0.9066726011770717,
           0.9067223907878882,
           0.9068716950598866,
           0.907120320464528,
           0.9074679449627999,
           0.9079141187651294,
           0.9084582653894685,
           0.9090996830118243,
           0.9098375461019811,
           0.9106709073356949,
           0.9115986997732775,
           0.9126197392932068,
           0.9137327272682508,
           0.9149362534705479,
           0.9162287991911772,
           0.917608740558978,
           0.919074352042737,
           0.92062381012036,
           0.9222551970982885,
           0.9239665050641942,
           0.9257556399558904,
           0.9276204257294478,
           0.929558608609652,
           0.9315678614062178,
           0.9336457878795599,
           0.9357899271403924,
           0.9379977580679972,
           0.9402667037326361,
           0.9425941358082986,
           0.9449773789627277,
           0.9474137152124785,
           0.9499003882316045,
           0.9524346076034313,
           0.9550135530057559,
           0.9576343783206972,
           0.9602942156613113,
           0.9629901793079488,
           0.9657193695482065,
           0.9684788764151446,
           0.9712657833192604,
           0.9740771705704812,
           0.9769101187871808,
           0.9797617121899259,
           0.9826290417783178,
           0.9855092083899152,
           0.9883993256407971,
           0.9912965227478543,
           0.9941979472333801,
           0.9971007675129817,
           1.0000021753682193,
           1.0028993883057458,
           1.005789651805027,
           1.0086702414570115,
           1.011538464996334,
           1.0143916642298723,
           1.0172272168646144,
           1.0200425382379568,
           1.0228350829536497,
           1.0256023464266946,
           1.0283418663405575,
           1.0310512240200933,
           1.0337280457235947,
           1.036370003857377,
           1.0389748181162888,
           1.0415402565535,
           1.0440641365828829,
           1.0465443259172267,
           1.0489787434454747,
           1.0513653600520791,
           1.0537021993815014,
           1.0559873385507812,
           1.0582189088130127,
           1.0603950961744626,
           1.0625141419679651,
           1.0645743433851285,
           1.0665740539697772,
           1.0685116840749533,
           1.0703857012856952,
           1.0721946308097048,
           1.073937055837911,
           1.075611617876839,
           1.0772170170545827,
           1.0787520124020957,
           1.0802154221113998,
           1.0816061237722279,
           1.0829230545885222,
           1.084165211576113,
           1.0853316517428233,
           1.0864214922521505,
           1.0874339105715967,
           1.0883681446066447,
           1.089223492821276,
           1.089999314345882,
           1.0906950290733133,
           1.0913101177437647,
           1.0918441220191042,
           1.0922966445471889,
           1.092667349016663,
           1.0929559602026244,
           1.093162264003527,
           1.0932861074695885
          ],
          [
           1.1068849838132095,
           1.1068382732235034,
           1.1066981748214104,
           1.1064647887065144,
           1.1061382817064596,
           1.1057188873693375,
           1.1052069059528182,
           1.1046027044097848,
           1.1039067163701926,
           1.103119442118793,
           1.1022414485683019,
           1.1012733692275078,
           1.1002159041637687,
           1.0990698199592381,
           1.0978359496601182,
           1.0965151927181258,
           1.0951085149233013,
           1.0936169483271816,
           1.0920415911552832,
           1.0903836077077405,
           1.0886442282468445,
           1.086824748870131,
           1.0849265313675553,
           1.0829510030611817,
           1.0808996566256996,
           1.0787740498879583,
           1.0765758056035826,
           1.0743066112086146,
           1.0719682185439736,
           1.0695624435504032,
           1.067091165931427,
           1.064556328781678,
           1.0619599381778329,
           1.0593040627292136,
           1.0565908330849647,
           1.053822441394566,
           1.0510011407182627,
           1.0481292443838475,
           1.0452091252860634,
           1.0422432151247354,
           1.0392340035775873,
           1.036184037403542,
           1.0330959194721638,
           1.0299723077147562,
           1.026815913992509,
           1.0236295028769598,
           1.0204158903379443,
           1.0171779423341134,
           1.0139185733010392,
           1.0106407445318788,
           1.0073474624455525,
           1.0040417767374037,
           1.0007267784073466,
           0.9974055976605916,
           0.9940814016761582,
           0.9907573922385423,
           0.9874368032281178,
           0.9841228979661155,
           0.9808189664103342,
           0.9775283221981148,
           0.9742542995335416,
           0.9710002499163405,
           0.967769538710509,
           0.9645655415513448,
           0.9613916405902652,
           0.9582512205775726,
           0.9551476647841912,
           0.9520843507643205,
           0.9490646459619492,
           0.9460919031652423,
           0.9431694558139451,
           0.9403006131661327,
           0.9374886553318859,
           0.934736828182755,
           0.9320483381472013,
           0.9294263469035589,
           0.926873965983418,
           0.9243942512997049,
           0.9219901976150713,
           0.9196647329675435,
           0.9174207130716391,
           0.9152609157143826,
           0.9131880351667724,
           0.9112046766322788,
           0.9093133507548656,
           0.9075164682097951,
           0.9058163344010913,
           0.9042151442899887,
           0.9027149773789436,
           0.9013177928758536,
           0.9000254250629768,
           0.8988395788946718,
           0.8977618258474916,
           0.8967936000453389,
           0.8959361946813452,
           0.8951907587568686,
           0.8945582941565152,
           0.8940396530764065,
           0.8936355358210345,
           0.8933464889819956,
           0.8931729040096956,
           0.8931150161867906,
           0.8931729040096958,
           0.8933464889819961,
           0.8936355358210348,
           0.894039653076407,
           0.8945582941565157,
           0.8951907587568694,
           0.895936194681346,
           0.8967936000453398,
           0.8977618258474926,
           0.898839578894673,
           0.9000254250629782,
           0.9013177928758549,
           0.902714977378945,
           0.9042151442899904,
           0.905816334401093,
           0.907516468209797,
           0.9093133507548676,
           0.9112046766322809,
           0.9131880351667747,
           0.9152609157143848,
           0.9174207130716414,
           0.9196647329675457,
           0.9219901976150737,
           0.9243942512997073,
           0.9268739659834206,
           0.9294263469035615,
           0.9320483381472041,
           0.9347368281827578,
           0.9374886553318887,
           0.9403006131661354,
           0.9431694558139481,
           0.9460919031652454,
           0.9490646459619523,
           0.9520843507643235,
           0.9551476647841942,
           0.9582512205775757,
           0.9613916405902686,
           0.9645655415513482,
           0.9677695387105124,
           0.9710002499163439,
           0.9742542995335449,
           0.9775283221981181,
           0.9808189664103378,
           0.9841228979661188,
           0.9874368032281212,
           0.9907573922385459,
           0.9940814016761618,
           0.9974055976605949,
           1.00072677840735,
           1.0040417767374072,
           1.0073474624455558,
           1.010640744531882,
           1.0139185733010427,
           1.017177942334117,
           1.0204158903379477,
           1.023629502876963,
           1.0268159139925122,
           1.0299723077147593,
           1.033095919472167,
           1.0361840374035451,
           1.0392340035775904,
           1.0422432151247385,
           1.0452091252860665,
           1.0481292443838506,
           1.0510011407182656,
           1.0538224413945687,
           1.0565908330849674,
           1.059304062729216,
           1.0619599381778357,
           1.0645563287816806,
           1.0670911659314295,
           1.0695624435504059,
           1.071968218543976,
           1.074306611208617,
           1.076575805603585,
           1.0787740498879606,
           1.080899656625702,
           1.0829510030611837,
           1.0849265313675573,
           1.0868247488701328,
           1.0886442282468465,
           1.0903836077077422,
           1.0920415911552848,
           1.093616948327183,
           1.0951085149233029,
           1.0965151927181271,
           1.0978359496601195,
           1.0990698199592397,
           1.1002159041637696,
           1.1012733692275092,
           1.1022414485683028,
           1.103119442118794,
           1.1039067163701932,
           1.1046027044097853,
           1.105206905952819,
           1.105718887369338,
           1.1061382817064596,
           1.1064647887065149,
           1.1066981748214106,
           1.1068382732235038
          ],
          [
           1.1213065999007323,
           1.1212542685225326,
           1.1210973103668642,
           1.1208358333719002,
           1.1204700174391649,
           1.120000114440284,
           1.119426448226227,
           1.1187494146388237,
           1.1179694815242875,
           1.1170871887484046,
           1.116103148212981,
           1.1150180438730786,
           1.1138326317544853,
           1.1125477399708101,
           1.111164268739489,
           1.1096831903959303,
           1.1081055494049241,
           1.1064324623683508,
           1.1046651180281364,
           1.1028047772632865,
           1.1008527730797297,
           1.0988105105915846,
           1.096679466992345,
           1.0944611915143423,
           1.0921573053747173,
           1.0897695017059867,
           1.0872995454691314,
           1.0847492733469912,
           1.0821205936155611,
           1.079415485990632,
           1.0766360014470133,
           1.0737842620073996,
           1.0708624604977317,
           1.0678728602656995,
           1.0648177948588164,
           1.0616996676582717,
           1.0585209514645355,
           1.0552841880304595,
           1.051991987537367,
           1.0486470280093885,
           1.0452520546610513,
           1.0418098791728707,
           1.0383233788894575,
           1.0347954959344003,
           1.031229236235943,
           1.0276276684572407,
           1.0239939228247625,
           1.0203311898481886,
           1.0166427189249665,
           1.0129318168225123,
           1.0092018460309025,
           1.0054562229787867,
           1.0016984161051636,
           0.9979319437796347,
           0.9941603720637471,
           0.9903873123061014,
           0.9866164185640153,
           0.9828513848447192,
           0.9790959421593101,
           0.9753538553830243,
           0.971628919915807,
           0.9679249581376643,
           0.9642458156538849,
           0.9605953573259294,
           0.956977463084603,
           0.9533960235230499,
           0.9498549352681518,
           0.9463580961300838,
           0.942909400031044,
           0.9395127317155916,
           0.9361719612465296,
           0.9328909382918971,
           0.9296734862103777,
           0.9265233959442444,
           0.9234444197308924,
           0.9204402646459844,
           0.9175145859932884,
           0.914670980558357,
           0.9119129797453026,
           0.909244042618007,
           0.9066675488691603,
           0.9041867917425136,
           0.9018049709356359,
           0.8995251855122425,
           0.897350426854782,
           0.8952835716894186,
           0.8933273752167569,
           0.8914844643826318,
           0.8897573313239932,
           0.8881483270252938,
           0.8866596552208773,
           0.8852933665785732,
           0.8840513531990876,
           0.882935343464779,
           0.8819468972700346,
           0.8810874016637429,
           0.8803580669322585,
           0.8797599231488273,
           0.879293817212694,
           0.8789604103980652,
           0.8787601764298112,
           0.8786934000992677,
           0.8787601764298113,
           0.8789604103980655,
           0.8792938172126944,
           0.8797599231488278,
           0.8803580669322589,
           0.8810874016637437,
           0.8819468972700355,
           0.8829353434647802,
           0.884051353199089,
           0.8852933665785745,
           0.8866596552208789,
           0.8881483270252953,
           0.8897573313239949,
           0.8914844643826338,
           0.893327375216759,
           0.8952835716894209,
           0.8973504268547841,
           0.8995251855122448,
           0.9018049709356386,
           0.9041867917425163,
           0.9066675488691629,
           0.9092440426180096,
           0.9119129797453052,
           0.9146709805583598,
           0.9175145859932914,
           0.9204402646459874,
           0.9234444197308955,
           0.9265233959442477,
           0.9296734862103809,
           0.9328909382919006,
           0.936171961246533,
           0.939512731715595,
           0.9429094000310473,
           0.9463580961300874,
           0.9498549352681556,
           0.9533960235230533,
           0.9569774630846067,
           0.960595357325933,
           0.9642458156538888,
           0.9679249581376684,
           0.971628919915811,
           0.975353855383028,
           0.9790959421593141,
           0.9828513848447231,
           0.9866164185640192,
           0.9903873123061052,
           0.9941603720637511,
           0.9979319437796385,
           1.0016984161051674,
           1.0054562229787904,
           1.0092018460309062,
           1.012931816822516,
           1.0166427189249705,
           1.0203311898481924,
           1.0239939228247663,
           1.0276276684572445,
           1.0312292362359468,
           1.034795495934404,
           1.0383233788894608,
           1.041809879172874,
           1.0452520546610546,
           1.048647028009392,
           1.0519919875373702,
           1.0552841880304629,
           1.0585209514645388,
           1.0616996676582746,
           1.0648177948588198,
           1.0678728602657026,
           1.0708624604977348,
           1.0737842620074025,
           1.0766360014470162,
           1.0794154859906346,
           1.082120593615564,
           1.084749273346994,
           1.0872995454691343,
           1.0897695017059892,
           1.0921573053747198,
           1.0944611915143445,
           1.0966794669923474,
           1.0988105105915866,
           1.1008527730797317,
           1.1028047772632885,
           1.1046651180281382,
           1.1064324623683524,
           1.1081055494049254,
           1.109683190395932,
           1.1111642687394903,
           1.1125477399708115,
           1.1138326317544864,
           1.1150180438730797,
           1.1161031482129822,
           1.1170871887484055,
           1.1179694815242887,
           1.1187494146388246,
           1.119426448226228,
           1.1200001144402847,
           1.1204700174391649,
           1.1208358333719002,
           1.1210973103668644,
           1.1212542685225328
          ],
          [
           1.1365782951033379,
           1.1365201670979124,
           1.1363458214861075,
           1.1360553734858398,
           1.1356490151419587,
           1.1351270153486357,
           1.1344897198805366,
           1.1337375514325885,
           1.1328710096681076,
           1.1318906712750014,
           1.130797190029687,
           1.1295912968683204,
           1.1282737999648507,
           1.126845584815358,
           1.125307614328047,
           1.1236609289181938,
           1.1219066466072658,
           1.1200459631253268,
           1.1180801520157562,
           1.116010564741197,
           1.1138386307895454,
           1.1115658577786505,
           1.1091938315582934,
           1.106724216307847,
           1.1041587546278826,
           1.1014992676238249,
           1.0987476549795838,
           1.0959058950189082,
           1.0929760447520078,
           1.0899602399047879,
           1.0868606949278072,
           1.0836797029818457,
           1.0804196358967104,
           1.077082944099648,
           1.0736721565094562,
           1.0701898803920866,
           1.066638801173239,
           1.0630216822031129,
           1.0593413644681595,
           1.0556007662443334,
           1.0518028826859767,
           1.0479507853441148,
           1.0440476216075627,
           1.0400966140598564,
           1.0361010597446485,
           1.032064329331812,
           1.027989866176113,
           1.0238811852599425,
           1.0197418720112132,
           1.0155755809871894,
           1.0113860344146695,
           1.0071770205766382,
           1.0029523920352337,
           0.9987160636806293,
           0.9944720105952504,
           0.9902242657226097,
           0.9859769173299856,
           0.9817341062541733,
           0.9775000229196349,
           0.9732789041185761,
           0.9690750295427684,
           0.9648927180573674,
           0.96073632370752,
           0.9566102314492579,
           0.9525188525970123,
           0.9484666199811042,
           0.9444579828097363,
           0.9404974012313904,
           0.9365893405950655,
           0.9327382654075499,
           0.928948632988845,
           0.9252248868289857,
           0.921571449651823,
           0.9179927161938282,
           0.9144930457086438,
           0.9110767542109341,
           0.907748106476044,
           0.9045113078150373,
           0.9013704956478482,
           0.8983297309004629,
           0.895392989255265,
           0.8925641522868466,
           0.8898469985186783,
           0.8872451944389953,
           0.884762285517034,
           0.8824016872632929,
           0.8801666763797461,
           0.8780603820478332,
           0.8760857774035602,
           0.8742456712501031,
           0.8725427000588647,
           0.8709793203099782,
           0.8695578012227219,
           0.8682802179251986,
           0.8671484451109319,
           0.8661641512277275,
           0.8653287932412553,
           0.864643612012353,
           0.86410962832306,
           0.8637276395819067,
           0.8634982172340612,
           0.8634217048966623,
           0.8634982172340613,
           0.863727639581907,
           0.8641096283230607,
           0.8646436120123534,
           0.8653287932412561,
           0.8661641512277286,
           0.867148445110933,
           0.8682802179251998,
           0.8695578012227232,
           0.8709793203099797,
           0.8725427000588665,
           0.874245671250105,
           0.8760857774035623,
           0.8780603820478353,
           0.8801666763797484,
           0.8824016872632955,
           0.8847622855170366,
           0.887245194438998,
           0.8898469985186811,
           0.8925641522868496,
           0.895392989255268,
           0.8983297309004659,
           0.9013704956478513,
           0.9045113078150405,
           0.9077481064760473,
           0.9110767542109377,
           0.9144930457086473,
           0.9179927161938319,
           0.9215714496518268,
           0.9252248868289894,
           0.928948632988849,
           0.9327382654075539,
           0.9365893405950694,
           0.9404974012313942,
           0.9444579828097404,
           0.9484666199811081,
           0.9525188525970164,
           0.9566102314492619,
           0.9607363237075243,
           0.9648927180573716,
           0.9690750295427728,
           0.9732789041185804,
           0.9775000229196392,
           0.9817341062541779,
           0.9859769173299899,
           0.9902242657226139,
           0.9944720105952548,
           0.9987160636806337,
           1.002952392035238,
           1.0071770205766424,
           1.0113860344146737,
           1.0155755809871936,
           1.0197418720112172,
           1.0238811852599468,
           1.0279898661761175,
           1.0320643293318161,
           1.036101059744653,
           1.0400966140598602,
           1.0440476216075665,
           1.0479507853441188,
           1.0518028826859804,
           1.0556007662443374,
           1.0593413644681633,
           1.0630216822031167,
           1.066638801173243,
           1.0701898803920904,
           1.0736721565094598,
           1.0770829440996517,
           1.0804196358967137,
           1.083679702981849,
           1.0868606949278103,
           1.089960239904791,
           1.092976044752011,
           1.0959058950189111,
           1.0987476549795867,
           1.1014992676238278,
           1.1041587546278855,
           1.1067242163078497,
           1.109193831558296,
           1.1115658577786527,
           1.1138386307895474,
           1.1160105647411993,
           1.118080152015758,
           1.1200459631253288,
           1.1219066466072676,
           1.1236609289181954,
           1.1253076143280485,
           1.1268455848153598,
           1.128273799964852,
           1.1295912968683215,
           1.1307971900296883,
           1.1318906712750025,
           1.1328710096681087,
           1.1337375514325891,
           1.1344897198805373,
           1.135127015348636,
           1.1356490151419587,
           1.13605537348584,
           1.136345821486108,
           1.1365201670979126
          ],
          [
           1.152685295042224,
           1.15262121976157,
           1.1524290345447756,
           1.1521088612751078,
           1.1516609031172,
           1.1510854445557697,
           1.1503828514496992,
           1.1495535711013436,
           1.1485981323408938,
           1.1475171456255913,
           1.1463113031535237,
           1.1449813789916976,
           1.1435282292180295,
           1.1419527920768298,
           1.1402560881472963,
           1.1384392205244744,
           1.1365033750120386,
           1.1344498203261988,
           1.1322799083099182,
           1.129995074156543,
           1.127596836641829,
           1.125086798363233,
           1.1224666459852017,
           1.1197381504890496,
           1.1169031674258643,
           1.1139636371706976,
           1.110921585176128,
           1.1077791222230702,
           1.1045384446664923,
           1.1012018346734709,
           1.0977716604507506,
           1.0942503764587166,
           1.0906405236083805,
           1.0869447294376753,
           1.0831657082630175,
           1.0793062613017346,
           1.0753692767605785,
           1.071357729885137,
           1.0672746829645297,
           1.0631232852853316,
           1.058906773028176,
           1.0546284691000134,
           1.0502917828944693,
           1.0459002099722179,
           1.0414573316527234,
           1.0369668145081368,
           1.0324324097495516,
           1.0278579524952238,
           1.0232473609097668,
           1.0186046352027383,
           1.0139338564744391,
           1.0092391853961717,
           1.004524860711647,
           0.9997951975457047,
           0.9950545855060329,
           0.9903074865631336,
           0.9855584326934171,
           0.9808120232700284,
           0.9760729221858003,
           0.9713458546926601,
           0.9666356039418471,
           0.9619470072094991,
           0.9572849517925061,
           0.9526543705600787,
           0.9480602371472099,
           0.9435075607771712,
           0.9390013807013967,
           0.9345467602465558,
           0.9301487804603715,
           0.9258125333497573,
           0.9215431147071824,
           0.9173456165238161,
           0.9132251189909528,
           0.909186682094488,
           0.9052353368107888,
           0.9013760759161613,
           0.8976138444262594,
           0.8939535296861524,
           0.8903999511363537,
           0.8869578497848648,
           0.8836318774201329,
           0.880426585604728,
           0.8773464144944163,
           0.8743956815320754,
           0.871578570070487,
           0.8688991179823498,
           0.8663612063197932,
           0.8639685480891566,
           0.8617246772097185,
           0.8596329377273403,
           0.85769647335554,
           0.8559182174172548,
           0.854300883260433,
           0.8528469552195586,
           0.8515586801932143,
           0.8504380599048467,
           0.8494868439099614,
           0.8487065234081431,
           0.8480983259125298,
           0.8476632108228233,
           0.8474018659406012,
           0.847314704957776,
           0.8474018659406015,
           0.8476632108228237,
           0.8480983259125302,
           0.8487065234081437,
           0.8494868439099623,
           0.8504380599048477,
           0.8515586801932156,
           0.8528469552195599,
           0.8543008832604346,
           0.8559182174172564,
           0.857696473355542,
           0.8596329377273424,
           0.8617246772097206,
           0.863968548089159,
           0.8663612063197959,
           0.8688991179823525,
           0.8715785700704898,
           0.8743956815320784,
           0.8773464144944195,
           0.8804265856047313,
           0.8836318774201362,
           0.8869578497848682,
           0.8903999511363573,
           0.8939535296861559,
           0.8976138444262632,
           0.9013760759161653,
           0.9052353368107929,
           0.9091866820944924,
           0.9132251189909569,
           0.9173456165238204,
           0.9215431147071866,
           0.9258125333497617,
           0.930148780460376,
           0.9345467602465602,
           0.9390013807014013,
           0.943507560777176,
           0.9480602371472145,
           0.9526543705600836,
           0.9572849517925108,
           0.9619470072095039,
           0.9666356039418521,
           0.9713458546926648,
           0.9760729221858052,
           0.9808120232700333,
           0.9855584326934219,
           0.9903074865631383,
           0.9950545855060378,
           0.9997951975457093,
           1.0045248607116517,
           1.0092391853961766,
           1.013933856474444,
           1.018604635202743,
           1.0232473609097716,
           1.0278579524952287,
           1.0324324097495563,
           1.0369668145081412,
           1.0414573316527278,
           1.0459002099722225,
           1.0502917828944738,
           1.0546284691000176,
           1.0589067730281805,
           1.0631232852853358,
           1.067274682964534,
           1.0713577298851409,
           1.0753692767605827,
           1.0793062613017386,
           1.0831657082630213,
           1.086944729437679,
           1.0906405236083843,
           1.0942503764587201,
           1.0977716604507541,
           1.1012018346734744,
           1.1045384446664959,
           1.1077791222230735,
           1.1109215851761314,
           1.1139636371707007,
           1.1169031674258671,
           1.1197381504890525,
           1.1224666459852044,
           1.1250867983632358,
           1.1275968366418314,
           1.1299950741565452,
           1.1322799083099204,
           1.1344498203262008,
           1.1365033750120406,
           1.1384392205244762,
           1.1402560881472978,
           1.1419527920768313,
           1.143528229218031,
           1.1449813789916992,
           1.146311303153525,
           1.1475171456255926,
           1.1485981323408947,
           1.1495535711013443,
           1.1503828514497005,
           1.1510854445557703,
           1.1516609031172005,
           1.1521088612751083,
           1.1524290345447759,
           1.15262121976157
          ],
          [
           1.1696120172352042,
           1.1695418685060175,
           1.1693314649475441,
           1.1689809344580762,
           1.1684904902381976,
           1.1678604308459035,
           1.1670911402737074,
           1.1661830880476727,
           1.1651368293482907,
           1.1639530051530946,
           1.1626323424008806,
           1.1611756541773706,
           1.1595838399221194,
           1.1578578856564306,
           1.1559988642319943,
           1.1540079355999169,
           1.1518863470997431,
           1.1496354337680095,
           1.1472566186657962,
           1.144751413224641,
           1.1421214176101062,
           1.1393683211021544,
           1.1364939024913887,
           1.133500030490063,
           1.1303886641566212,
           1.1271618533323546,
           1.1238217390885816,
           1.1203705541825502,
           1.1168106235200275,
           1.1131443646223118,
           1.1093742880951052,
           1.10550299809641,
           1.1015331928002734,
           1.0974676648528607,
           1.0933093018169444,
           1.089061086600497,
           1.084726097864616,
           1.0803075104055295,
           1.0758085955049228,
           1.071232721242259,
           1.0665833527621913,
           1.0618640524895173,
           1.0570784802834774,
           1.0522303935224755,
           1.0473236471095757,
           1.0423621933883311,
           1.0373500819577046,
           1.032291459373985,
           1.0271905687267344,
           1.0220517490749121,
           1.0168794347283945,
           1.0116781543592044,
           1.0064525299258271,
           1.001207275393079,
           0.995947195229101,
           0.9906771826601883,
           0.9854022176633522,
           0.9801273646757763,
           0.9748577699996658,
           0.969598658880446,
           0.9643553322358541,
           0.9591331630132222,
           0.9539375921521753,
           0.9487741241301383,
           0.9436483220684451,
           0.9385658023775364,
           0.9335322289207427,
           0.9285533066775064,
           0.9236347748886431,
           0.9187823996683987,
           0.9140019660706618,
           0.9092992695997643,
           0.9046801071598601,
           0.9001502674409387,
           0.8957155207440988,
           0.8913816082537838,
           0.8871542307702523,
           0.8830390369215827,
           0.8790416108809713,
           0.8751674596219177,
           0.8714219997510075,
           0.8678105439653682,
           0.8643382871893239,
           0.8610102924522516,
           0.8578314765769722,
           0.8548065957550857,
           0.8519402310923024,
           0.8492367742128971,
           0.8467004130177384,
           0.8443351176947816,
           0.8421446270842938,
           0.8401324355032547,
           0.8383017801342599,
           0.8366556290836757,
           0.8351966702117429,
           0.8339273008337159,
           0.8328496183859426,
           0.8319654121440908,
           0.8312761560725249,
           0.8307830028742883,
           0.830486779300335,
           0.8303879827647959,
           0.8304867793003351,
           0.8307830028742889,
           0.8312761560725256,
           0.8319654121440915,
           0.8328496183859437,
           0.833927300833717,
           0.8351966702117445,
           0.8366556290836774,
           0.8383017801342618,
           0.8401324355032567,
           0.8421446270842962,
           0.8443351176947841,
           0.8467004130177408,
           0.8492367742128998,
           0.8519402310923052,
           0.8548065957550888,
           0.8578314765769754,
           0.861010292452255,
           0.8643382871893275,
           0.8678105439653718,
           0.8714219997510112,
           0.8751674596219216,
           0.8790416108809754,
           0.8830390369215867,
           0.8871542307702566,
           0.8913816082537882,
           0.8957155207441033,
           0.9001502674409434,
           0.9046801071598648,
           0.909299269599769,
           0.9140019660706667,
           0.9187823996684036,
           0.9236347748886482,
           0.9285533066775115,
           0.9335322289207479,
           0.9385658023775417,
           0.9436483220684505,
           0.9487741241301437,
           0.9539375921521808,
           0.9591331630132276,
           0.9643553322358597,
           0.9695986588804513,
           0.9748577699996713,
           0.9801273646757817,
           0.9854022176633577,
           0.9906771826601937,
           0.9959471952291066,
           1.0012072753930843,
           1.0064525299258325,
           1.0116781543592095,
           1.0168794347283996,
           1.0220517490749175,
           1.0271905687267398,
           1.0322914593739903,
           1.03735008195771,
           1.042362193388336,
           1.0473236471095808,
           1.0522303935224804,
           1.057078480283482,
           1.0618640524895222,
           1.0665833527621962,
           1.0712327212422637,
           1.0758085955049272,
           1.0803075104055342,
           1.0847260978646205,
           1.0890610866005015,
           1.0933093018169486,
           1.097467664852865,
           1.1015331928002778,
           1.1055029980964137,
           1.109374288095109,
           1.1131443646223156,
           1.1168106235200312,
           1.1203705541825535,
           1.1238217390885854,
           1.127161853332358,
           1.1303886641566245,
           1.1335000304900662,
           1.1364939024913916,
           1.139368321102157,
           1.1421214176101093,
           1.144751413224644,
           1.1472566186657984,
           1.1496354337680117,
           1.1518863470997454,
           1.1540079355999189,
           1.1559988642319963,
           1.1578578856564326,
           1.1595838399221212,
           1.1611756541773721,
           1.162632342400882,
           1.163953005153096,
           1.165136829348292,
           1.1661830880476738,
           1.1670911402737085,
           1.1678604308459044,
           1.1684904902381978,
           1.1689809344580766,
           1.1693314649475448,
           1.169541868506018
          ],
          [
           1.1873420861717516,
           1.1872657614138513,
           1.1870368315506088,
           1.1866554298275906,
           1.1861217783680613,
           1.1854361882439741,
           1.1845990595753888,
           1.183610881658331,
           1.1824722331211257,
           1.1811837821092332,
           1.1797462864986061,
           1.1781605941375983,
           1.176427643117422,
           1.1745484620711597,
           1.1725241705012934,
           1.1703559791357014,
           1.1680451903120346,
           1.1655931983903334,
           1.1630014901937005,
           1.1602716454767834,
           1.1574053374217343,
           1.1544043331612424,
           1.1512704943281187,
           1.1480057776308061,
           1.1446122354540471,
           1.1410920164837908,
           1.1374473663552491,
           1.1336806283228142,
           1.1297942439503346,
           1.1257907538199952,
           1.121672798257779,
           1.1174431180731805,
           1.113104555310505,
           1.1086600540087141,
           1.1041126609663663,
           1.0994655265077529,
           1.094721905245828,
           1.0898851568370018,
           1.0849587467222588,
           1.0799462468484382,
           1.0748513363628107,
           1.06967780227333,
           1.0644295400661357,
           1.059110554271009,
           1.0537249589645525,
           1.0482769781998664,
           1.0427709463504475,
           1.0372113083549077,
           1.0316026198479342,
           1.025949547161686,
           1.0202568671805152,
           1.0145294670305849,
           1.008772343584564,
           1.0029906027601856,
           0.9971894585900226,
           0.9913742320384133,
           0.9855503495400519,
           0.9797233412333884,
           0.9738988388606479,
           0.9680825733050655,
           0.9622803717347981,
           0.956498154322026,
           0.9507419305049791,
           0.9450177947600925,
           0.9393319218512413,
           0.933690561523092,
           0.9281000326060724,
           0.9225667165013771,
           0.9170970500158411,
           0.9116975175184837,
           0.9063746423931174,
           0.9011349777646671,
           0.8959850964808346,
           0.8909315803354683,
           0.8859810085255512,
           0.8811399453400529,
           0.8764149270860918,
           0.8718124482658258,
           0.8673389470262779,
           0.8630007899138064,
           0.8588042559750804,
           0.854755520257135,
           0.8508606367701834,
           0.84712552098824,
           0.8435559319740208,
           0.8401574542258662,
           0.8369354793552961,
           0.8338951877140313,
           0.8310415300986098,
           0.8283792096688285,
           0.825912664222863,
           0.8236460489768133,
           0.8215832199993462,
           0.8197277184528435,
           0.8180827557908521,
           0.8166512000575713,
           0.8154355634285059,
           0.8144379911223173,
           0.8136602518023498,
           0.813103729572469,
           0.8127694176559273,
           0.8126579138282485,
           0.8127694176559274,
           0.8131037295724693,
           0.8136602518023504,
           0.8144379911223181,
           0.8154355634285068,
           0.8166512000575726,
           0.8180827557908538,
           0.8197277184528453,
           0.8215832199993482,
           0.8236460489768155,
           0.8259126642228656,
           0.8283792096688313,
           0.8310415300986126,
           0.8338951877140344,
           0.8369354793552993,
           0.8401574542258697,
           0.8435559319740243,
           0.8471255209882437,
           0.8508606367701874,
           0.854755520257139,
           0.8588042559750846,
           0.8630007899138107,
           0.8673389470262823,
           0.8718124482658304,
           0.8764149270860967,
           0.8811399453400579,
           0.8859810085255562,
           0.8909315803354735,
           0.8959850964808397,
           0.9011349777646726,
           0.9063746423931227,
           0.9116975175184893,
           0.9170970500158466,
           0.9225667165013828,
           0.9281000326060782,
           0.9336905615230978,
           0.939331921851247,
           0.9450177947600983,
           0.9507419305049851,
           0.9564981543220319,
           0.9622803717348041,
           0.9680825733050715,
           0.973898838860654,
           0.9797233412333944,
           0.985550349540058,
           0.9913742320384193,
           0.9971894585900286,
           1.0029906027601914,
           1.00877234358457,
           1.0145294670305907,
           1.020256867180521,
           1.025949547161692,
           1.03160261984794,
           1.0372113083549135,
           1.0427709463504535,
           1.048276978199872,
           1.053724958964558,
           1.0591105542710146,
           1.064429540066141,
           1.0696778022733353,
           1.0748513363628158,
           1.0799462468484433,
           1.0849587467222637,
           1.0898851568370067,
           1.094721905245833,
           1.0994655265077575,
           1.1041126609663712,
           1.1086600540087188,
           1.1131045553105094,
           1.1174431180731847,
           1.121672798257783,
           1.1257907538199994,
           1.1297942439503388,
           1.133680628322818,
           1.137447366355253,
           1.1410920164837945,
           1.1446122354540504,
           1.1480057776308092,
           1.1512704943281218,
           1.1544043331612455,
           1.1574053374217375,
           1.1602716454767863,
           1.1630014901937031,
           1.1655931983903356,
           1.1680451903120368,
           1.1703559791357032,
           1.1725241705012954,
           1.1745484620711621,
           1.1764276431174239,
           1.1781605941375999,
           1.1797462864986075,
           1.1811837821092348,
           1.1824722331211273,
           1.183610881658332,
           1.18459905957539,
           1.1854361882439748,
           1.1861217783680613,
           1.186655429827591,
           1.1870368315506092,
           1.187265761413852
          ],
          [
           1.2058583491552484,
           1.2057757683623287,
           1.2055280719527284,
           1.2051153978510638,
           1.204537975988848,
           1.2037961283902792,
           1.2028902692924694,
           1.2018209053002327,
           1.2005886355755864,
           1.1991941520621465,
           1.1976382397446297,
           1.195921776943688,
           1.1940457356463345,
           1.1920111818722223,
           1.189819276076051,
           1.1874712735863868,
           1.18496852508116,
           1.18231247710011,
           1.179504672594421,
           1.1765467515137509,
           1.1734404514308285,
           1.1701876082037326,
           1.1667901566758903,
           1.163250131413759,
           1.1595696674820488,
           1.1557510012562136,
           1.1517964712718076,
           1.147708519110128,
           1.1434896903193732,
           1.1391426353703291,
           1.134670110645329,
           1.130074979458964,
           1.1253602131086722,
           1.1205288919529877,
           1.1155842065147996,
           1.1105294586065264,
           1.1053680624735784,
           1.1001035459519262,
           1.0947395516349443,
           1.0892798380440076,
           1.083728280796542,
           1.0780888737643883,
           1.072365730214403,
           1.0665630839222127,
           1.0606852902489379,
           1.0547368271695012,
           1.0487222962398497,
           1.0426464234890223,
           1.0365140602205103,
           1.0303301837057581,
           1.0240998977509537,
           1.01782843311647,
           1.0115211477664223,
           1.005183526923832,
           0.9988211829048241,
           0.992439854703175,
           0.9860454072943373,
           0.9796438306258906,
           0.9732412382591386,
           0.9668438656244203,
           0.9604580678505829,
           0.9540903171270598,
           0.9477471995551677,
           0.9414354114435907,
           0.9351617550016896,
           0.9289331333832643,
           0.9227565450328369,
           0.9166390772864681,
           0.9105878991796742,
           0.9046102534162691,
           0.8987134474540065,
           0.8929048436658633,
           0.8871918485397534,
           0.8815819008845105,
           0.8760824590162052,
           0.8707009869063291,
           0.865444939282161,
           0.8603217456797283,
           0.8553387934612324,
           0.8505034098215574,
           0.8458228428224623,
           0.8413042415081821,
           0.8369546351722326,
           0.8327809118620408,
           0.8287897962253438,
           0.8249878268197817,
           0.821381333024418,
           0.8179764117086187,
           0.8147789038293971,
           0.8117943711425014,
           0.8090280732247167,
           0.8064849450146175,
           0.804169575085874,
           0.8020861848708019,
           0.8002386090518099,
           0.7986302773344729,
           0.7972641978079923,
           0.7961429420867443,
           0.7952686324105336,
           0.7946429308612679,
           0.794267030830365,
           0.7941416508447515,
           0.7942670308303652,
           0.7946429308612684,
           0.7952686324105342,
           0.7961429420867452,
           0.7972641978079935,
           0.7986302773344744,
           0.8002386090518117,
           0.8020861848708039,
           0.8041695750858765,
           0.80648494501462,
           0.8090280732247193,
           0.8117943711425044,
           0.8147789038294003,
           0.8179764117086221,
           0.8213813330244216,
           0.8249878268197854,
           0.8287897962253479,
           0.8327809118620452,
           0.836954635172237,
           0.8413042415081866,
           0.8458228428224669,
           0.8505034098215624,
           0.8553387934612374,
           0.8603217456797334,
           0.8654449392821664,
           0.8707009869063347,
           0.8760824590162107,
           0.8815819008845163,
           0.8871918485397592,
           0.8929048436658692,
           0.8987134474540124,
           0.9046102534162752,
           0.9105878991796804,
           0.9166390772864741,
           0.9227565450328433,
           0.9289331333832707,
           0.9351617550016962,
           0.9414354114435973,
           0.9477471995551743,
           0.9540903171270665,
           0.9604580678505893,
           0.9668438656244269,
           0.9732412382591451,
           0.9796438306258972,
           0.9860454072943439,
           0.9924398547031814,
           0.9988211829048308,
           1.0051835269238385,
           1.011521147766429,
           1.0178284331164762,
           1.0240998977509599,
           1.0303301837057646,
           1.0365140602205165,
           1.0426464234890285,
           1.0487222962398557,
           1.0547368271695075,
           1.0606852902489436,
           1.0665630839222184,
           1.072365730214409,
           1.0780888737643943,
           1.0837282807965476,
           1.0892798380440132,
           1.09473955163495,
           1.100103545951932,
           1.1053680624735838,
           1.1105294586065315,
           1.1155842065148047,
           1.1205288919529925,
           1.1253602131086773,
           1.1300749794589686,
           1.1346701106453339,
           1.1391426353703333,
           1.1434896903193776,
           1.147708519110132,
           1.1517964712718118,
           1.1557510012562175,
           1.1595696674820526,
           1.1632501314137624,
           1.1667901566758936,
           1.1701876082037361,
           1.1734404514308319,
           1.1765467515137538,
           1.179504672594424,
           1.1823124771001128,
           1.1849685250811623,
           1.1874712735863895,
           1.189819276076053,
           1.1920111818722243,
           1.1940457356463365,
           1.1959217769436898,
           1.1976382397446315,
           1.1991941520621483,
           1.200588635575588,
           1.2018209053002342,
           1.2028902692924708,
           1.20379612839028,
           1.2045379759888488,
           1.205115397851064,
           1.2055280719527284,
           1.205775768362329
          ],
          [
           1.2251428928971122,
           1.2250539975070693,
           1.224787358647028,
           1.224343118267023,
           1.2237215130163863,
           1.2229228743427696,
           1.2219476286310085,
           1.2207962973820536,
           1.2194694974322555,
           1.2179679412133613,
           1.2162924370536294,
           1.2144438895205278,
           1.2124232998055386,
           1.2102317661516349,
           1.2078704843240404,
           1.205340748124932,
           1.2026439499527606,
           1.1997815814069088,
           1.1967552339384167,
           1.1935665995475107,
           1.190217471528682,
           1.1867097452640358,
           1.183045419065618,
           1.1792265950673817,
           1.1752554801673911,
           1.1711343870208077,
           1.1668657350840723,
           1.1624520517106136,
           1.1578959732982332,
           1.1532002464881699,
           1.1483677294156105,
           1.1434013930111895,
           1.1383043223527178,
           1.1330797180660614,
           1.127730897773695,
           1.1222612975890318,
           1.1166744736541259,
           1.110974103717781,
           1.1051639887504576,
           1.0992480545916672,
           1.0932303536247188,
           1.087115066472802,
           1.0809065037093812,
           1.0746091075747664,
           1.0682274536895,
           1.0617662527538445,
           1.055230352221158,
           1.0486247379313285,
           1.0419545356886382,
           1.035225012766512,
           1.028441579319485,
           1.0216097896804817,
           1.0147353435190525,
           1.0078240868336241,
           1.0008820127480593,
           0.9939152620799042,
           0.9869301236446344,
           0.979933034257036,
           0.9729305783875428,
           0.9659294874279983,
           0.9589366385178895,
           0.9519590528787079,
           0.9450038936007563,
           0.9380784628235171,
           0.93119019824772,
           0.9243466689145556,
           0.9175555701852274,
           0.9108247178522829,
           0.9041620413131097,
           0.8975755757357009,
           0.8910734531475097,
           0.884663892380033,
           0.8783551878048992,
           0.8721556968018341,
           0.8660738259051252,
           0.8601180155832471,
           0.8542967236163048,
           0.8486184070479917,
           0.8430915027029666,
           0.8377244062769166,
           0.8325254500251176,
           0.8275028790959147,
           0.8226648265780843,
           0.8180192873552328,
           0.8135740908859465,
           0.8093368730548358,
           0.8053150472664637,
           0.8015157749807338,
           0.79794593591399,
           0.7946120981540662,
           0.7915204884590232,
           0.7886769630275132,
           0.7860869790428058,
           0.7837555673017457,
           0.7816873062436331,
           0.7798862976916663,
           0.7783561446107938,
           0.7770999311704042,
           0.7761202053782281,
           0.775418964523436,
           0.7749976436326181,
           0.7748571071028877,
           0.7749976436326184,
           0.7754189645234365,
           0.7761202053782289,
           0.7770999311704052,
           0.7783561446107953,
           0.779886297691668,
           0.7816873062436351,
           0.783755567301748,
           0.7860869790428083,
           0.7886769630275162,
           0.7915204884590262,
           0.7946120981540695,
           0.7979459359139935,
           0.8015157749807377,
           0.8053150472664677,
           0.8093368730548401,
           0.813574090885951,
           0.8180192873552375,
           0.8226648265780891,
           0.8275028790959199,
           0.8325254500251228,
           0.837724406276922,
           0.8430915027029722,
           0.8486184070479975,
           0.8542967236163107,
           0.8601180155832533,
           0.8660738259051313,
           0.8721556968018406,
           0.8783551878049056,
           0.8846638923800396,
           0.8910734531475162,
           0.8975755757357077,
           0.9041620413131165,
           0.9108247178522898,
           0.9175555701852344,
           0.9243466689145627,
           0.931190198247727,
           0.9380784628235241,
           0.9450038936007634,
           0.9519590528787151,
           0.9589366385178967,
           0.9659294874280056,
           0.97293057838755,
           0.9799330342570434,
           0.9869301236446416,
           0.9939152620799113,
           1.0008820127480667,
           1.0078240868336312,
           1.0147353435190594,
           1.0216097896804885,
           1.0284415793194919,
           1.035225012766519,
           1.0419545356886453,
           1.0486247379313354,
           1.0552303522211648,
           1.0617662527538512,
           1.0682274536895067,
           1.0746091075747726,
           1.0809065037093875,
           1.0871150664728084,
           1.093230353624725,
           1.0992480545916734,
           1.1051639887504636,
           1.110974103717787,
           1.1166744736541316,
           1.1222612975890374,
           1.1277308977737004,
           1.133079718066067,
           1.1383043223527232,
           1.1434013930111944,
           1.1483677294156154,
           1.1532002464881748,
           1.157895973298238,
           1.162452051710618,
           1.1668657350840772,
           1.1711343870208122,
           1.1752554801673953,
           1.1792265950673855,
           1.1830454190656219,
           1.186709745264039,
           1.1902174715286853,
           1.193566599547514,
           1.1967552339384198,
           1.1997815814069117,
           1.2026439499527635,
           1.205340748124935,
           1.2078704843240424,
           1.210231766151637,
           1.2124232998055406,
           1.2144438895205296,
           1.2162924370536312,
           1.217967941213363,
           1.2194694974322569,
           1.2207962973820552,
           1.2219476286310098,
           1.22292287434277,
           1.223721513016387,
           1.2243431182670232,
           1.2247873586470281,
           1.2250539975070693
          ],
          [
           1.2451770608467454,
           1.2450818125276264,
           1.2447961160127314,
           1.2443201166514561,
           1.2436540567662118,
           1.2427982757627207,
           1.241753210284774,
           1.2405193944137805,
           1.2390974599135498,
           1.2374881365208323,
           1.2356922522822384,
           1.2337107339382476,
           1.2315446073551113,
           1.2291949980055337,
           1.2266631314991026,
           1.2239503341635192,
           1.221058033677758,
           1.2179877597583433,
           1.2147411449000145,
           1.2113199251720868,
           1.2077259410718824,
           1.203961138436638,
           1.2000275694153213,
           1.1959273935018138,
           1.1916628786309107,
           1.187236402338584,
           1.1826504529879096,
           1.1779076310620158,
           1.1730106505253222,
           1.1679623402542367,
           1.1627656455383348,
           1.1574236296528697,
           1.1519394755032495,
           1.1463164873418545,
           1.1405580925572456,
           1.134667843535461,
           1.128649419592645,
           1.1225066289777557,
           1.1162434109435013,
           1.109863837882986,
           1.1033721175287594,
           1.0967725952100837,
           1.0900697561632198,
           1.0832682278883945,
           1.0763727825458296,
           1.06938833938176,
           1.0623199671737618,
           1.0551728866828967,
           1.047952473098192,
           1.0406642584567363,
           1.0333139340202429,
           1.0259073525862357,
           1.0184505307090674,
           1.0109496508027849,
           1.0034110630943691,
           0.9958412873921363,
           0.9882470146300523,
           0.9806351081444299,
           0.9730126046349178,
           0.9653867147569145,
           0.9577648232875476,
           0.9501544888022113,
           0.9425634427933958,
           0.9349995881582557,
           0.9274709969761238,
           0.919985907492107,
           0.9125527202181127,
           0.9051799930583243,
           0.8978764353624179,
           0.8906509008069259,
           0.8835123790032984,
           0.8764699857306639,
           0.8695329516923077,
           0.8627106096977432,
           0.8560123801772738,
           0.8494477549434007,
           0.8430262791236273,
           0.8367575312024289,
           0.8306511011266103,
           0.8247165664481636,
           0.8189634665021677,
           0.8134012746442735,
           0.8080393686027825,
           0.8028869990340453,
           0.7979532564065052,
           0.7932470363776353,
           0.7887770038685864,
           0.7845515560826515,
           0.7805787847546654,
           0.776866437957928,
           0.773421881831931,
           0.7702520626266081,
           0.7673634694856754,
           0.76476209841145,
           0.7624534178650939,
           0.7604423364584287,
           0.7587331731854783,
           0.7573296306231793,
           0.7562347715011544,
           0.7554509990002762,
           0.7549800410897082,
           0.7548229391532547,
           0.7549800410897085,
           0.7554509990002769,
           0.7562347715011554,
           0.7573296306231806,
           0.7587331731854797,
           0.7604423364584306,
           0.7624534178650961,
           0.7647620984114527,
           0.7673634694856782,
           0.7702520626266112,
           0.7734218818319345,
           0.7768664379579316,
           0.7805787847546692,
           0.7845515560826558,
           0.7887770038685907,
           0.7932470363776402,
           0.7979532564065102,
           0.8028869990340505,
           0.8080393686027879,
           0.8134012746442792,
           0.8189634665021734,
           0.8247165664481695,
           0.8306511011266166,
           0.8367575312024352,
           0.8430262791236337,
           0.8494477549434075,
           0.8560123801772807,
           0.8627106096977502,
           0.8695329516923148,
           0.8764699857306711,
           0.8835123790033055,
           0.8906509008069332,
           0.8978764353624255,
           0.9051799930583319,
           0.9125527202181203,
           0.9199859074921147,
           0.9274709969761316,
           0.9349995881582635,
           0.9425634427934036,
           0.9501544888022192,
           0.9577648232875555,
           0.9653867147569224,
           0.9730126046349257,
           0.9806351081444379,
           0.98824701463006,
           0.9958412873921441,
           1.003411063094377,
           1.0109496508027924,
           1.018450530709075,
           1.0259073525862432,
           1.0333139340202504,
           1.0406642584567434,
           1.0479524730981995,
           1.0551728866829042,
           1.062319967173769,
           1.0693883393817674,
           1.0763727825458367,
           1.0832682278884016,
           1.0900697561632267,
           1.0967725952100906,
           1.103372117528766,
           1.1098638378829926,
           1.1162434109435078,
           1.122506628977762,
           1.1286494195926513,
           1.134667843535467,
           1.1405580925572514,
           1.1463164873418603,
           1.1519394755032555,
           1.157423629652875,
           1.1627656455383404,
           1.167962340254242,
           1.1730106505253275,
           1.1779076310620207,
           1.1826504529879145,
           1.1872364023385886,
           1.1916628786309151,
           1.195927393501818,
           1.2000275694153257,
           1.203961138436642,
           1.2077259410718864,
           1.2113199251720903,
           1.214741144900018,
           1.2179877597583464,
           1.2210580336777608,
           1.2239503341635218,
           1.226663131499105,
           1.2291949980055366,
           1.2315446073551135,
           1.2337107339382496,
           1.2356922522822402,
           1.2374881365208341,
           1.2390974599135514,
           1.2405193944137816,
           1.2417532102847753,
           1.2427982757627218,
           1.243654056766212,
           1.2443201166514566,
           1.244796116012732,
           1.2450818125276268
          ],
          [
           1.2659414712405423,
           1.2658398506164996,
           1.2655350381234578,
           1.2650271819224754,
           1.2643165290280336,
           1.2634034254273376,
           1.262288316247787,
           1.2609717459730636,
           1.259454358708415,
           1.2577368984958344,
           1.2558202096799738,
           1.2537052373257451,
           1.2513930276886942,
           1.2488847287393594,
           1.2461815907429479,
           1.2432849668957862,
           1.24019631402012,
           1.2369171933189609,
           1.2334492711927876,
           1.2297943201200177,
           1.2259542196032822,
           1.2219309571836199,
           1.2177266295248084,
           1.2133434435701371,
           1.2087837177739864,
           1.204049883410648,
           1.1991444859628613,
           1.1940701865925742,
           1.1888297636964351,
           1.183426114548511,
           1.1778622570326838,
           1.1721413314671003,
           1.1662666025229274,
           1.1602414612395253,
           1.1540694271379295,
           1.1477541504342776,
           1.1412994143544972,
           1.1347091375511578,
           1.1279873766229211,
           1.1211383287364465,
           1.11416633434992,
           1.1070758800365919,
           1.099871601405752,
           1.092558286117517,
           1.0851408769865292,
           1.0776244751682529,
           1.0700143434199,
           1.0623159094261645,
           1.0545347691778153,
           1.046676690388826,
           1.0387476159350204,
           1.030753667294214,
           1.0227011479644743,
           1.0145965468333962,
           1.0064465414671666,
           0.998258001283656,
           0.9900379905688002,
           0.9817937712901149,
           0.9735328056553175,
           0.9652627583576955,
           0.9569914984430982,
           0.9487271007262427,
           0.9404778466764693,
           0.9322522246851979,
           0.924058929619247,
           0.9159068615559348,
           0.9078051235876843,
           0.8997630185758319,
           0.8917900447257369,
           0.8838958898483403,
           0.8760904241673317,
           0.868383691526409,
           0.8607858988481263,
           0.8533074036949637,
           0.8459586997850053,
           0.8387504003194441,
           0.8316932189876072,
           0.824797948527797,
           0.8180754367395006,
           0.8115365598648737,
           0.8051921932852345,
           0.7990531795118961,
           0.7931302934901096,
           0.7874342052801272,
           0.7819754402301318,
           0.7767643368114118,
           0.7718110023458519,
           0.7671252669183442,
           0.7627166358306222,
           0.7585942410164266,
           0.7547667918987708,
           0.7512425262260597,
           0.7480291614724957,
           0.7451338474271193,
           0.742563120622624,
           0.7403228612676322,
           0.7384182533426684,
           0.7368537484994381,
           0.735633034364586,
           0.7347590077930495,
           0.7342337535433566,
           0.7340585287594575,
           0.7342337535433571,
           0.7347590077930503,
           0.7356330343645873,
           0.7368537484994395,
           0.7384182533426702,
           0.7403228612676345,
           0.7425631206226265,
           0.745133847427122,
           0.748029161472499,
           0.7512425262260631,
           0.7547667918987746,
           0.7585942410164307,
           0.7627166358306265,
           0.7671252669183488,
           0.7718110023458568,
           0.7767643368114171,
           0.7819754402301373,
           0.787434205280133,
           0.7931302934901157,
           0.7990531795119025,
           0.8051921932852408,
           0.8115365598648804,
           0.8180754367395074,
           0.8247979485278039,
           0.8316932189876142,
           0.8387504003194515,
           0.8459586997850128,
           0.8533074036949713,
           0.860785898848134,
           0.8683836915264169,
           0.8760904241673396,
           0.8838958898483484,
           0.8917900447257452,
           0.89976301857584,
           0.9078051235876926,
           0.9159068615559431,
           0.9240589296192553,
           0.9322522246852061,
           0.9404778466764777,
           0.9487271007262513,
           0.9569914984431066,
           0.965262758357704,
           0.973532805655326,
           0.9817937712901232,
           0.9900379905688087,
           0.9982580012836645,
           1.006446541467175,
           1.0145965468334044,
           1.0227011479644827,
           1.0307536672942224,
           1.0387476159350284,
           1.0466766903888343,
           1.0545347691778233,
           1.0623159094261723,
           1.070014343419908,
           1.0776244751682607,
           1.085140876986537,
           1.0925582861175243,
           1.0998716014057592,
           1.1070758800365992,
           1.1141663343499273,
           1.1211383287364534,
           1.1279873766229283,
           1.1347091375511646,
           1.1412994143545039,
           1.1477541504342839,
           1.1540694271379357,
           1.1602414612395318,
           1.1662666025229336,
           1.172141331467106,
           1.1778622570326898,
           1.1834261145485165,
           1.1888297636964409,
           1.1940701865925796,
           1.1991444859628664,
           1.204049883410653,
           1.2087837177739913,
           1.2133434435701413,
           1.2177266295248124,
           1.2219309571836237,
           1.2259542196032862,
           1.2297943201200212,
           1.233449271192791,
           1.2369171933189642,
           1.240196314020123,
           1.2432849668957895,
           1.2461815907429505,
           1.248884728739362,
           1.2513930276886964,
           1.2537052373257476,
           1.255820209679976,
           1.2577368984958364,
           1.2594543587084166,
           1.2609717459730656,
           1.262288316247788,
           1.2634034254273385,
           1.2643165290280345,
           1.2650271819224757,
           1.265535038123458,
           1.2658398506164996
          ],
          [
           1.2874160358524958,
           1.2873080411921376,
           1.2869841073466861,
           1.2864443847481002,
           1.2856891242000117,
           1.2847186770035555,
           1.2835334951340829,
           1.2821341314693162,
           1.2805212400696488,
           1.27869557651148,
           1.2766579982746,
           1.2744094651848372,
           1.2719510399133143,
           1.2692838885338462,
           1.2664092811401586,
           1.2633285925247844,
           1.260043302921661,
           1.256554998814603,
           1.2528653738140205,
           1.2489762296043827,
           1.2448894769651286,
           1.240607136867862,
           1.236131341652841,
           1.2314643362879332,
           1.2266084797133436,
           1.2215662462755872,
           1.2163402272542914,
           1.2109331324855617,
           1.2053477920857314,
           1.1995871582794277,
           1.1936543073359482,
           1.1875524416179961,
           1.1812848917468342,
           1.1748551188879068,
           1.168266717160916,
           1.1615234161782275,
           1.1546290837153217,
           1.1475877285167662,
           1.1404035032408764,
           1.1330807075458302,
           1.125623791319496,
           1.1180373580546061,
           1.1103261683701509,
           1.1024951436789405,
           1.0945493700001965,
           1.0864941019147272,
           1.0783347666587209,
           1.070076968350405,
           1.0617264923417482,
           1.0532893096849922,
           1.0447715817010435,
           1.0361796646336083,
           1.0275201143693633,
           1.0187996912003872,
           1.0100253646004753,
           1.0012043179817989,
           0.9923439533925863,
           0.9834518961100691,
           0.974535999075801,
           0.9656043471126134,
           0.9566652608538652,
           0.947727300306286,
           0.9387992679576173,
           0.9298902113294096,
           0.9210094248638538,
           0.9121664510214322,
           0.9033710804536407,
           0.8946333511022125,
           0.885963546063381,
           0.8773721900430792,
           0.8688700442168866,
           0.8604680992975022,
           0.8521775666029975,
           0.844009866911739,
           0.8359766168853195,
           0.8280896128398774,
           0.8203608116496615,
           0.8128023085754861,
           0.8054263118257566,
           0.7982451136799197,
           0.7912710580343799,
           0.7845165042698651,
           0.7779937873874968,
           0.7717151744187594,
           0.7656928171821611,
           0.7599387015362448,
           0.7544645933638431,
           0.7492819816146588,
           0.7444020188303637,
           0.7398354596758399,
           0.735592598098717,
           0.7316832038333356,
           0.7281164590505406,
           0.7249008960270449,
           0.7220443367631566,
           0.7195538355114293,
           0.717435625187765,
           0.715695068618006,
           0.714336615525487,
           0.7133637660880872,
           0.7127790417881182,
           0.7125839641475042,
           0.7127790417881187,
           0.7133637660880878,
           0.7143366155254882,
           0.7156950686180076,
           0.717435625187767,
           0.7195538355114318,
           0.7220443367631595,
           0.724900896027048,
           0.7281164590505441,
           0.7316832038333395,
           0.7355925980987214,
           0.7398354596758443,
           0.7444020188303686,
           0.7492819816146639,
           0.7544645933638486,
           0.7599387015362506,
           0.7656928171821673,
           0.7717151744187657,
           0.7779937873875035,
           0.784516504269872,
           0.791271058034387,
           0.7982451136799269,
           0.8054263118257641,
           0.8128023085754938,
           0.8203608116496693,
           0.8280896128398855,
           0.8359766168853275,
           0.8440098669117474,
           0.8521775666030059,
           0.860468099297511,
           0.8688700442168952,
           0.8773721900430879,
           0.88596354606339,
           0.8946333511022214,
           0.90337108045365,
           0.9121664510214413,
           0.921009424863863,
           0.9298902113294187,
           0.9387992679576265,
           0.9477273003062953,
           0.9566652608538743,
           0.9656043471126227,
           0.9745359990758101,
           0.9834518961100784,
           0.9923439533925954,
           1.0012043179818078,
           1.0100253646004844,
           1.0187996912003965,
           1.0275201143693724,
           1.036179664633617,
           1.0447715817010523,
           1.053289309685001,
           1.0617264923417569,
           1.0700769683504137,
           1.0783347666587295,
           1.0864941019147356,
           1.0945493700002047,
           1.1024951436789485,
           1.1103261683701589,
           1.1180373580546141,
           1.1256237913195037,
           1.133080707545838,
           1.1404035032408837,
           1.1475877285167735,
           1.1546290837153288,
           1.1615234161782344,
           1.168266717160923,
           1.1748551188879135,
           1.1812848917468406,
           1.1875524416180026,
           1.1936543073359545,
           1.1995871582794337,
           1.2053477920857374,
           1.2109331324855672,
           1.2163402272542971,
           1.2215662462755923,
           1.2266084797133487,
           1.2314643362879378,
           1.2361313416528457,
           1.2406071368678662,
           1.2448894769651329,
           1.2489762296043867,
           1.2528653738140243,
           1.2565549988146067,
           1.2600433029216642,
           1.2633285925247877,
           1.2664092811401613,
           1.2692838885338493,
           1.271951039913317,
           1.2744094651848394,
           1.2766579982746025,
           1.278695576511482,
           1.2805212400696508,
           1.2821341314693175,
           1.2835334951340847,
           1.2847186770035564,
           1.2856891242000124,
           1.2864443847481009,
           1.2869841073466866,
           1.2873080411921378
          ],
          [
           1.309579979428256,
           1.3094656253155794,
           1.3091226137074161,
           1.3085510968192304,
           1.3077513284297604,
           1.3067236640107895,
           1.3054685609094747,
           1.303986578583881,
           1.3022783788925612,
           1.3003447264392098,
           1.2981864889736086,
           1.2958046378502825,
           1.2932002485464775,
           1.2903745012412677,
           1.2873286814578173,
           1.284064180771018,
           1.2805824975829365,
           1.2768852379687206,
           1.272974116595846,
           1.2688509577197757,
           1.264517696259375,
           1.2599763789556053,
           1.255229165617299,
           1.2502783304580147,
           1.2451262635282325,
           1.2397754722473655,
           1.2342285830403186,
           1.228488343083534,
           1.2225576221657108,
           1.2164394146685875,
           1.210136841673393,
           1.2036531531987642,
           1.1969917305760973,
           1.1901560889684615,
           1.1831498800393083,
           1.1759768947773155,
           1.1686410664837181,
           1.1611464739284902,
           1.1534973446816366,
           1.1456980586257073,
           1.1377531516553965,
           1.1296673195697182,
           1.1214454221617631,
           1.1130924875104042,
           1.1046137164775016,
           1.0960144874131281,
           1.0873003610700986,
           1.0784770857275499,
           1.069550602521485,
           1.0605270509780125,
           1.0514127747424145,
           1.042214327494132,
           1.0329384790341916,
           1.0235922215274584,
           1.0141827758773072,
           1.0047175982048002,
           0.9952043863981545,
           0.9856510866911021,
           0.97606590022062,
           0.966457289505343,
           0.9568339847757067,
           0.9472049900754334,
           0.937579589041312,
           0.9279673502543091,
           0.9183781320398605,
           0.9088220865787695,
           0.8993096631725321,
           0.8898516104882659,
           0.8804589775888972,
           0.8711431135341828,
           0.8619156653178217,
           0.8527885738858937,
           0.8437740679627074,
           0.8348846553926562,
           0.8261331116917326,
           0.8175324654910526,
           0.8090959805482989,
           0.8008371340027979,
           0.7927695905575037,
           0.7849071722880948,
           0.77726382380728,
           0.7698535725529084,
           0.7626904840229755,
           0.7557886118503108,
           0.7491619426954077,
           0.7428243360376955,
           0.736789459063068,
           0.7310707169772789,
           0.7256811792184947,
           0.7206335021943704,
           0.715939849324853,
           0.7116118093258228,
           0.707660313814003,
           0.7040955554429803,
           0.700926907886051,
           0.6981628490563947,
           0.695810888991984,
           0.6938775038259961,
           0.6923680772095053,
           0.6912868504502759,
           0.6906368824805678,
           0.6904200205717438,
           0.6906368824805681,
           0.6912868504502768,
           0.6923680772095068,
           0.6938775038259979,
           0.6958108889919861,
           0.6981628490563973,
           0.700926907886054,
           0.7040955554429837,
           0.7076603138140068,
           0.7116118093258271,
           0.7159398493248577,
           0.7206335021943754,
           0.7256811792185002,
           0.7310707169772845,
           0.7367894590630741,
           0.7428243360377019,
           0.7491619426954146,
           0.7557886118503178,
           0.7626904840229829,
           0.769853572552916,
           0.7772638238072878,
           0.7849071722881028,
           0.7927695905575118,
           0.8008371340028062,
           0.8090959805483074,
           0.8175324654910614,
           0.8261331116917415,
           0.8348846553926653,
           0.8437740679627166,
           0.8527885738859029,
           0.8619156653178311,
           0.8711431135341923,
           0.8804589775889069,
           0.8898516104882755,
           0.8993096631725419,
           0.908822086578779,
           0.9183781320398704,
           0.927967350254319,
           0.937579589041322,
           0.9472049900754432,
           0.9568339847757167,
           0.9664572895053529,
           0.97606590022063,
           0.9856510866911121,
           0.9952043863981643,
           1.00471759820481,
           1.014182775877317,
           1.0235922215274682,
           1.0329384790342013,
           1.0422143274941416,
           1.051412774742424,
           1.0605270509780218,
           1.069550602521494,
           1.0784770857275592,
           1.0873003610701075,
           1.096014487413137,
           1.1046137164775105,
           1.113092487510413,
           1.1214454221617713,
           1.1296673195697267,
           1.137753151655405,
           1.1456980586257153,
           1.1534973446816446,
           1.1611464739284982,
           1.1686410664837257,
           1.1759768947773226,
           1.1831498800393156,
           1.1901560889684686,
           1.1969917305761044,
           1.2036531531987709,
           1.2101368416733995,
           1.216439414668594,
           1.222557622165717,
           1.22848834308354,
           1.2342285830403243,
           1.2397754722473713,
           1.2451262635282379,
           1.2502783304580196,
           1.2552291656173034,
           1.2599763789556098,
           1.2645176962593794,
           1.2688509577197802,
           1.2729741165958497,
           1.2768852379687243,
           1.2805824975829398,
           1.2840641807710218,
           1.2873286814578202,
           1.2903745012412706,
           1.2932002485464802,
           1.295804637850285,
           1.2981864889736106,
           1.3003447264392118,
           1.302278378892563,
           1.303986578583883,
           1.305468560909476,
           1.3067236640107904,
           1.3077513284297613,
           1.3085510968192309,
           1.3091226137074163,
           1.3094656253155794
          ],
          [
           1.3324118597838495,
           1.3322911757895854,
           1.3319291749878712,
           1.3313260109480605,
           1.3304819397062395,
           1.3293973198963358,
           1.3280726129344027,
           1.3265083832568134,
           1.3247052986133068,
           1.3226641304160567,
           1.32038575414614,
           1.3178711498190152,
           1.3151214025108477,
           1.3121377029477492,
           1.3089213481602395,
           1.3054737422054972,
           1.3017963969601933,
           1.2978909329869905,
           1.2937590804780439,
           1.2894026802791156,
           1.2848236849982102,
           1.280024160202923,
           1.2750062857110025,
           1.2697723569789379,
           1.2643247865937033,
           1.2586661058731172,
           1.252798966580621,
           1.246726142760607,
           1.2404505327007964,
           1.2339751610285004,
           1.227303180947964,
           1.2204378766263433,
           1.2133826657362121,
           1.2061411021628428,
           1.1987168788848195,
           1.191113831036873,
           1.1833359391640879,
           1.1753873326768896,
           1.1672722935164257,
           1.1589952600400941,
           1.150560831137049,
           1.141973770583507,
           1.1332390116475484,
           1.1243616619528647,
           1.1153470086105013,
           1.1062005236270451,
           1.0969278695969027,
           1.0875349056852408,
           1.0780276939067748,
           1.068412505703862,
           1.0586958288251904,
           1.048884374503714,
           1.0389850849292783,
           1.0290051410075394,
           1.0189519703921763,
           1.008833255771986,
           0.9986569433880463,
           0.9884312517487047,
           0.9781646805014464,
           0.9678660194107411,
           0.9575443573794338,
           0.9472090914381726,
           0.9368699356124627,
           0.9265369295601814,
           0.9162204468536009,
           0.9059312027591012,
           0.895680261344733,
           0.8854790417206629,
           0.8753393231903324,
           0.8652732490611216,
           0.8552933288326816,
           0.8454124384493737,
           0.8356438182710343,
           0.8260010683844283,
           0.8164981408473421,
           0.8071493284296506,
           0.7979692493925505,
           0.7889728278303981,
           0.7801752690915426,
           0.7715920297977048,
           0.7632387819986027,
           0.7551313710325698,
           0.747285766717754,
           0.7397180075748567,
           0.732444137883613,
           0.7254801375029981,
           0.7188418445401499,
           0.7125448711346476,
           0.706604512830845,
           0.7010356522373249,
           0.6958526579130229,
           0.6910692796658242,
           0.6866985416910745,
           0.6827526352023418,
           0.6792428124016535,
           0.6761792837875922,
           0.6735711208939659,
           0.6714261665778576,
           0.6697509549250672,
           0.6685506427085716,
           0.6678289541215771,
           0.6675881402161504,
           0.6678289541215776,
           0.6685506427085726,
           0.6697509549250686,
           0.6714261665778595,
           0.6735711208939683,
           0.6761792837875952,
           0.6792428124016568,
           0.6827526352023454,
           0.6866985416910788,
           0.691069279665829,
           0.6958526579130281,
           0.7010356522373306,
           0.7066045128308509,
           0.7125448711346538,
           0.7188418445401565,
           0.7254801375030052,
           0.7324441378836204,
           0.7397180075748643,
           0.7472857667177621,
           0.755131371032578,
           0.7632387819986111,
           0.7715920297977134,
           0.7801752690915514,
           0.7889728278304072,
           0.7979692493925598,
           0.8071493284296601,
           0.8164981408473517,
           0.8260010683844382,
           0.8356438182710442,
           0.8454124384493837,
           0.8552933288326917,
           0.8652732490611317,
           0.8753393231903427,
           0.8854790417206733,
           0.8956802613447437,
           0.9059312027591119,
           0.9162204468536116,
           0.926536929560192,
           0.9368699356124732,
           0.9472090914381833,
           0.9575443573794443,
           0.9678660194107516,
           0.9781646805014572,
           0.988431251748715,
           0.9986569433880569,
           1.0088332557719963,
           1.0189519703921868,
           1.0290051410075496,
           1.0389850849292883,
           1.0488843745037242,
           1.0586958288252006,
           1.0684125057038718,
           1.0780276939067845,
           1.0875349056852506,
           1.0969278695969127,
           1.1062005236270545,
           1.1153470086105108,
           1.1243616619528738,
           1.1332390116475572,
           1.141973770583516,
           1.1505608311370576,
           1.1589952600401026,
           1.1672722935164341,
           1.175387332676898,
           1.183335939164096,
           1.1911138310368807,
           1.198716878884827,
           1.2061411021628503,
           1.2133826657362197,
           1.2204378766263502,
           1.2273031809479709,
           1.2339751610285072,
           1.240450532700803,
           1.246726142760613,
           1.2527989665806272,
           1.2586661058731232,
           1.2643247865937088,
           1.2697723569789434,
           1.2750062857110076,
           1.2800241602029279,
           1.284823684998215,
           1.2894026802791203,
           1.2937590804780483,
           1.2978909329869945,
           1.3017963969601969,
           1.3054737422055012,
           1.3089213481602426,
           1.3121377029477521,
           1.3151214025108506,
           1.3178711498190177,
           1.3203857541461423,
           1.3226641304160591,
           1.3247052986133088,
           1.3265083832568154,
           1.3280726129344043,
           1.329397319896337,
           1.3304819397062402,
           1.3313260109480607,
           1.3319291749878712,
           1.3322911757895854
          ],
          [
           1.3558895885496056,
           1.3557626179184399,
           1.3553817575343081,
           1.3547471619511744,
           1.3538590888453201,
           1.3527178991452522,
           1.3513240572143785,
           1.349678131087241,
           1.3477807927603527,
           1.345632818538912,
           1.343235089440905,
           1.3405885916603715,
           1.3376944170918468,
           1.3345537639182776,
           1.3311679372649512,
           1.3275383499222877,
           1.323666523140618,
           1.3195540875003768,
           1.3152027838614524,
           1.310614464395769,
           1.305791093707504,
           1.300734750045717,
           1.2954476266145136,
           1.2899320329862807,
           1.2841903966239085,
           1.2782252645183525,
           1.2720393049483116,
           1.2656353093692716,
           1.2590161944396123,
           1.2521850041919882,
           1.2451449123586844,
           1.2378992248601726,
           1.2304513824666288,
           1.2228049636427183,
           1.2149636875864969,
           1.2069314174738488,
           1.1987121639204181,
           1.1903100886735485,
           1.1817295085472657,
           1.1729748996138496,
           1.164050901665991,
           1.1549623229639572,
           1.145714145282512,
           1.1363115292725925,
           1.1267598201528786,
           1.1170645537463513,
           1.107231462876767,
           1.097266484139519,
           1.0871757650606786,
           1.076965671656968,
           1.0666427964079968,
           1.056213966650192,
           1.0456862533993931,
           1.0350669806059567,
           1.0243637348423178,
           1.0135843754181386,
           1.0027370449123083,
           0.9918301801039615,
           0.9808725232761829,
           0.9698731338559534,
           0.9588414003419461,
           0.9477870524577754,
           0.9367201734519676,
           0.9256512124470223,
           0.914590996718191,
           0.9035507437577777,
           0.8925420729526261,
           0.8815770166708217,
           0.870668030518369,
           0.8598280024876878,
           0.8490702606772833,
           0.8384085792161776,
           0.8278571819780972,
           0.8174307436197898,
           0.8071443874262861,
           0.7970136793949166,
           0.7870546179414711,
           0.7772836185684963,
           0.7677174928005018,
           0.7583734206674385,
           0.7492689160104764,
           0.7404217838976433,
           0.7318500694763926,
           0.7235719976609755,
           0.7156059031597333,
           0.7079701504956529,
           0.7006830438662119,
           0.6937627269274311,
           0.687227072871528,
           0.6810935654939891,
           0.6753791723069892,
           0.6701002111406137,
           0.6652722120658846,
           0.6609097768548198,
           0.6570264385402351,
           0.6536345239273117,
           0.6507450221154736,
           0.6483674621901795,
           0.6465098032213065,
           0.6451783395459152,
           0.6443776240147955,
           0.6441104114503944,
           0.6443776240147959,
           0.6451783395459163,
           0.646509803221308,
           0.6483674621901817,
           0.6507450221154762,
           0.653634523927315,
           0.6570264385402389,
           0.6609097768548239,
           0.6652722120658894,
           0.6701002111406189,
           0.6753791723069948,
           0.6810935654939954,
           0.6872270728715345,
           0.693762726927438,
           0.7006830438662193,
           0.7079701504956607,
           0.7156059031597414,
           0.7235719976609838,
           0.7318500694764014,
           0.7404217838976523,
           0.7492689160104856,
           0.7583734206674481,
           0.7677174928005116,
           0.7772836185685061,
           0.7870546179414813,
           0.797013679394927,
           0.8071443874262967,
           0.8174307436198006,
           0.827857181978108,
           0.8384085792161885,
           0.8490702606772943,
           0.8598280024876989,
           0.8706680305183803,
           0.8815770166708329,
           0.8925420729526373,
           0.903550743757789,
           0.9145909967182023,
           0.9256512124470335,
           0.9367201734519788,
           0.9477870524577867,
           0.9588414003419573,
           0.9698731338559645,
           0.9808725232761942,
           0.9918301801039728,
           1.0027370449123194,
           1.0135843754181497,
           1.024363734842329,
           1.0350669806059676,
           1.045686253399404,
           1.0562139666502026,
           1.0666427964080072,
           1.0769656716569784,
           1.087175765060689,
           1.0972664841395294,
           1.1072314628767772,
           1.1170645537463615,
           1.1267598201528886,
           1.1363115292726023,
           1.145714145282521,
           1.1549623229639665,
           1.1640509016660003,
           1.1729748996138585,
           1.1817295085472748,
           1.1903100886735571,
           1.1987121639204268,
           1.2069314174738572,
           1.214963687586505,
           1.222804963642726,
           1.2304513824666368,
           1.2378992248601801,
           1.2451449123586917,
           1.2521850041919953,
           1.2590161944396192,
           1.2656353093692783,
           1.272039304948318,
           1.2782252645183587,
           1.2841903966239148,
           1.2899320329862864,
           1.2954476266145194,
           1.3007347500457223,
           1.3057910937075092,
           1.3106144643957736,
           1.315202783861457,
           1.319554087500381,
           1.3236665231406222,
           1.3275383499222917,
           1.3311679372649545,
           1.3345537639182812,
           1.3376944170918497,
           1.3405885916603741,
           1.343235089440908,
           1.3456328185389141,
           1.347780792760355,
           1.3496781310872425,
           1.3513240572143803,
           1.3527178991452535,
           1.3538590888453208,
           1.3547471619511753,
           1.3553817575343088,
           1.3557626179184403
          ],
          [
           1.3799904525392286,
           1.3798572509060085,
           1.379457697741481,
           1.378791948276185,
           1.3778602613116093,
           1.3766629993465018,
           1.375200628754553,
           1.3734737200143028,
           1.3714829479923782,
           1.3692290922814172,
           1.3667130375943028,
           1.3639357742165896,
           1.3608983985192933,
           1.357602113534491,
           1.3540482295964786,
           1.3502381650515458,
           1.3461734470397477,
           1.3418557123523815,
           1.3372867083692503,
           1.3324682940801373,
           1.3274024411953333,
           1.3220912353504433,
           1.3165368774111477,
           1.3107416848840352,
           1.3047080934401152,
           1.2984386585581096,
           1.291936057295162,
           1.285203090193173,
           1.2782426833295373,
           1.271057890521706,
           1.2636518956956357,
           1.2560280154288725,
           1.2481897016797454,
           1.2401405447148857,
           1.2318842762480715,
           1.2234247728042158,
           1.214766059323141,
           1.2059123130186562,
           1.1968678675093263,
           1.18763721723822,
           1.1782250221998083,
           1.1686361129930873,
           1.1588754962208476,
           1.1489483602558497,
           1.1388600813954308,
           1.1286162304267318,
           1.1182225796253142,
           1.1076851102103167,
           1.097010020279504,
           1.086203733247499,
           1.0752729068100804,
           1.0642244424566292,
           1.0530654955514966,
           1.0418034860031358,
           1.0304461095371664,
           1.0190013495859713,
           1.0074774898027636,
           0.9958831272021412,
           0.984227185921684,
           0.9725189315899244,
           0.9607679862746944,
           0.9489843439721147,
           0.9371783865799409,
           0.9253609002792378,
           0.9135430922249475,
           0.9017366074184031,
           0.8899535456027339,
           0.8782064779849269,
           0.8665084635456205,
           0.854873064649105,
           0.8433143616112164,
           0.83184696582169,
           0.8204860309502146,
           0.8092472616922657,
           0.7981469194326598,
           0.787201824122987,
           0.7764293515856701,
           0.7658474253751764,
           0.7554745022496049,
           0.745329550238304,
           0.7354320182392565,
           0.7258017960508211,
           0.7164591637442409,
           0.7074247293252228,
           0.6987193537245208,
           0.6903640623084705,
           0.6823799423196467,
           0.6747880259522785,
           0.6676091591407458,
           0.6608638565919258,
           0.6545721441171508,
           0.6487533899038108,
           0.6434261269890571,
           0.6386078698294189,
           0.6343149284637757,
           0.6305622243006754,
           0.6273631119792011,
           0.6247292120112828,
           0.6226702589739583,
           0.6211939698545916,
           0.6203059367473825,
           0.6200095474607715,
           0.6203059367473831,
           0.6211939698545929,
           0.62267025897396,
           0.6247292120112853,
           0.627363111979204,
           0.6305622243006791,
           0.6343149284637799,
           0.6386078698294235,
           0.6434261269890623,
           0.6487533899038165,
           0.6545721441171571,
           0.6608638565919325,
           0.6676091591407529,
           0.674788025952286,
           0.6823799423196547,
           0.690364062308479,
           0.6987193537245295,
           0.7074247293252319,
           0.7164591637442506,
           0.7258017960508308,
           0.7354320182392665,
           0.7453295502383143,
           0.7554745022496154,
           0.7658474253751871,
           0.7764293515856812,
           0.7872018241229982,
           0.7981469194326712,
           0.8092472616922771,
           0.8204860309502262,
           0.8318469658217017,
           0.8433143616112282,
           0.8548730646491169,
           0.8665084635456324,
           0.878206477984939,
           0.8899535456027461,
           0.9017366074184152,
           0.9135430922249596,
           0.9253609002792499,
           0.937178386579953,
           0.9489843439721269,
           0.9607679862747066,
           0.9725189315899364,
           0.984227185921696,
           0.9958831272021532,
           1.0074774898027756,
           1.0190013495859829,
           1.030446109537178,
           1.041803486003147,
           1.0530654955515082,
           1.0642244424566405,
           1.0752729068100915,
           1.0862037332475103,
           1.0970100202795148,
           1.1076851102103276,
           1.1182225796253251,
           1.1286162304267422,
           1.138860081395441,
           1.14894836025586,
           1.1588754962208576,
           1.1686361129930973,
           1.178225022199818,
           1.1876372172382297,
           1.1968678675093358,
           1.2059123130186653,
           1.2147660593231502,
           1.2234247728042245,
           1.23188427624808,
           1.2401405447148939,
           1.2481897016797538,
           1.2560280154288803,
           1.2636518956956435,
           1.2710578905217134,
           1.2782426833295444,
           1.2852030901931801,
           1.291936057295169,
           1.298438658558116,
           1.3047080934401214,
           1.3107416848840412,
           1.3165368774111534,
           1.322091235350449,
           1.327402441195339,
           1.3324682940801424,
           1.3372867083692552,
           1.3418557123523862,
           1.3461734470397517,
           1.3502381650515496,
           1.354048229596482,
           1.357602113534495,
           1.3608983985192966,
           1.3639357742165923,
           1.3667130375943055,
           1.3692290922814196,
           1.3714829479923807,
           1.3734737200143048,
           1.3752006287545548,
           1.3766629993465032,
           1.37786026131161,
           1.378791948276186,
           1.3794576977414816,
           1.379857250906009
          ],
          [
           1.4046911357233376,
           1.404551769869118,
           1.4041337241850638,
           1.40343715433097,
           1.4024623198198718,
           1.4012095841385512,
           1.3996794149171257,
           1.3978723841486103,
           1.3957891684595902,
           1.3934305494334318,
           1.390797413987707,
           1.3878907548078054,
           1.3847116708389988,
           1.381261367839516,
           1.3775411589975122,
           1.3735524656151448,
           1.3692968178633123,
           1.3647758556109741,
           1.359991329333367,
           1.3549451011038187,
           1.3496391456743055,
           1.3440755516503462,
           1.338256522766312,
           1.3321843792677355,
           1.3258615594077607,
           1.3192906210654374,
           1.3124742434941965,
           1.3054152292094858,
           1.2981165060252555,
           1.290581129249715,
           1.2828122840515794,
           1.2748132880088718,
           1.2665875938532227,
           1.258138792423577,
           1.2494706158442068,
           1.2405869409430013,
           1.231491792927119,
           1.2221893493342741,
           1.21268394427916,
           1.2029800730158116,
           1.1930823968380517,
           1.1829957483415667,
           1.1727251370725704,
           1.1622757555894996,
           1.151652985965633,
           1.1408624067620043,
           1.1299098005014045,
           1.1188011616756508,
           1.1075427053195426,
           1.0961408761860705,
           1.0846023585583076,
           1.0729340867340518,
           1.061143256219494,
           1.0492373356679345,
           1.037224079598662,
           1.0251115419294394,
           1.0129080903533567,
           1.0006224215869433,
           0.988263577511048,
           0.9758409622188436,
           0.963364359975941,
           0.950843954085657,
           0.9382903466374097,
           0.9257145790974758,
           0.9131281536783002,
           0.9005430553944817,
           0.8879717746796714,
           0.8754273303981189,
           0.8629232930365376,
           0.8504738078054975,
           0.8380936173137751,
           0.8257980834032306,
           0.8136032076452319,
           0.8015256499020241,
           0.7895827442478881,
           0.777792511426034,
           0.7661736668894673,
           0.7547456233400109,
           0.7435284865431314,
           0.7325430430626597,
           0.7218107384362604,
           0.7113536442091325,
           0.7011944121717203,
           0.691356214121305,
           0.6818626655034113,
           0.672737731404662,
           0.6640056135821747,
           0.6556906175429656,
           0.6478169991441983,
           0.6404087907800399,
           0.6334896079535207,
           0.6270824378908983,
           0.6212094128164266,
           0.615891571526167,
           0.611148613923624,
           0.606998654136349,
           0.6034579786400677,
           0.600540816390986,
           0.5982591282291296,
           0.5966224227032313,
           0.595637604944163,
           0.5953088642766623,
           0.5956376049441636,
           0.5966224227032325,
           0.5982591282291317,
           0.6005408163909887,
           0.6034579786400711,
           0.6069986541363531,
           0.6111486139236285,
           0.6158915715261722,
           0.6212094128164325,
           0.6270824378909047,
           0.6334896079535276,
           0.6404087907800472,
           0.6478169991442061,
           0.655690617542974,
           0.6640056135821835,
           0.6727377314046712,
           0.6818626655034209,
           0.6913562141213149,
           0.7011944121717307,
           0.7113536442091432,
           0.7218107384362713,
           0.7325430430626708,
           0.7435284865431429,
           0.7547456233400225,
           0.7661736668894793,
           0.7777925114260462,
           0.7895827442479003,
           0.8015256499020365,
           0.8136032076452443,
           0.8257980834032431,
           0.8380936173137876,
           0.8504738078055103,
           0.8629232930365504,
           0.8754273303981316,
           0.8879717746796844,
           0.9005430553944945,
           0.9131281536783133,
           0.9257145790974887,
           0.9382903466374227,
           0.9508439540856699,
           0.9633643599759539,
           0.9758409622188566,
           0.9882635775110608,
           1.000622421586956,
           1.0129080903533694,
           1.0251115419294519,
           1.0372240795986745,
           1.0492373356679467,
           1.061143256219506,
           1.0729340867340638,
           1.0846023585583193,
           1.0961408761860825,
           1.1075427053195541,
           1.1188011616756623,
           1.129909800501416,
           1.1408624067620152,
           1.1516529859656441,
           1.1622757555895102,
           1.1727251370725806,
           1.182995748341577,
           1.1930823968380622,
           1.2029800730158215,
           1.21268394427917,
           1.222189349334284,
           1.2314917929271283,
           1.2405869409430104,
           1.2494706158442157,
           1.2581387924235858,
           1.2665875938532316,
           1.2748132880088803,
           1.2828122840515874,
           1.290581129249723,
           1.2981165060252633,
           1.3054152292094932,
           1.3124742434942036,
           1.3192906210654445,
           1.3258615594077674,
           1.3321843792677417,
           1.338256522766318,
           1.3440755516503518,
           1.349639145674311,
           1.3549451011038243,
           1.359991329333372,
           1.3647758556109786,
           1.3692968178633165,
           1.3735524656151492,
           1.377541158997516,
           1.3812613678395196,
           1.3847116708390022,
           1.3878907548078085,
           1.39079741398771,
           1.3934305494334347,
           1.3957891684595929,
           1.3978723841486125,
           1.3996794149171277,
           1.4012095841385523,
           1.402462319819873,
           1.4034371543309705,
           1.404133724185064,
           1.404551769869118
          ],
          [
           1.4299677417862213,
           1.42982228844288,
           1.429385980372285,
           1.4286589734751496,
           1.4276415276608563,
           1.4263340069602024,
           1.4247368796841338,
           1.4228507186293737,
           1.4206762013321101,
           1.4182141103711887,
           1.4154653337225196,
           1.412430865166723,
           1.409111804752306,
           1.405509359317015,
           1.401624843070296,
           1.3974596782401776,
           1.3930153957882234,
           1.3882936361966067,
           1.3832961503317538,
           1.3780248003894313,
           1.372481560926634,
           1.36666851998608,
           1.3605878803196834,
           1.3542419607179028,
           1.3476331974524753,
           1.3407641458406823,
           1.3336374819399766,
           1.3262560043825422,
           1.318622636360146,
           1.3107404277704844,
           1.3026125575371428,
           1.29424233611627,
           1.2856332082041089,
           1.2767887556606567,
           1.2677127006659432,
           1.2584089091266986,
           1.248881394352582,
           1.2391343210226164,
           1.229172009464062,
           1.218998940267644,
           1.208619759264847,
           1.1980392828948845,
           1.1872625039909537,
           1.1762945980175086,
           1.1651409297924804,
           1.1538070607306792,
           1.1422987566469869,
           1.1306219961603765,
           1.1187829797422624,
           1.1067881394551298,
           1.0946441494298,
           1.0823579371319734,
           1.0699366954707759,
           1.0573878958038512,
           1.0447193018949144,
           1.031938984880511,
           1.019055339302779,
           1.0060771002640831,
           0.9930133617571819,
           0.9798735962207591,
           0.9666676753642811,
           0.9534058922977429,
           0.9400989849903221,
           0.9267581610666036,
           0.9133951239290101,
           0.900022100169448,
           0.8866518682008319,
           0.8732977879988782,
           0.8599738317948898,
           0.8466946154997589,
           0.833475430566357,
           0.8203322759102062,
           0.8072818894051333,
           0.7943417783499067,
           0.7815302481623662,
           0.7688664283985056,
           0.7563702950153324,
           0.7440626875993,
           0.7319653200694739,
           0.7201007831412686,
           0.7084925366103267,
           0.6971648892979819,
           0.6861429643049217,
           0.6754526470677488,
           0.6651205136285316,
           0.6551737365389876,
           0.6456399659611685,
           0.6365471838297986,
           0.6279235294410888,
           0.6197970955572306,
           0.61219569508276,
           0.6051465995800331,
           0.5986762523246933,
           0.5928099602081998,
           0.5875715704910828,
           0.5829831400833138,
           0.5790646065356932,
           0.575833471110929,
           0.573304505007955,
           0.5714894899021729,
           0.5703970033454343,
           0.5700322582137787,
           0.5703970033454351,
           0.5714894899021743,
           0.5733045050079572,
           0.5758334711109319,
           0.5790646065356968,
           0.5829831400833183,
           0.5875715704910879,
           0.5928099602082054,
           0.5986762523246997,
           0.60514659958004,
           0.6121956950827675,
           0.6197970955572386,
           0.6279235294410974,
           0.6365471838298077,
           0.6456399659611781,
           0.6551737365389976,
           0.6651205136285421,
           0.6754526470677595,
           0.686142964304933,
           0.6971648892979935,
           0.7084925366103384,
           0.7201007831412806,
           0.731965320069486,
           0.7440626875993125,
           0.756370295015345,
           0.7688664283985187,
           0.7815302481623793,
           0.79434177834992,
           0.8072818894051468,
           0.8203322759102195,
           0.8334754305663705,
           0.8466946154997725,
           0.8599738317949034,
           0.873297787998892,
           0.8866518682008458,
           0.9000221001694616,
           0.913395123929024,
           0.9267581610666173,
           0.9400989849903358,
           0.9534058922977566,
           0.9666676753642948,
           0.9798735962207724,
           0.9930133617571953,
           1.0060771002640967,
           1.0190553393027924,
           1.031938984880524,
           1.0447193018949275,
           1.0573878958038643,
           1.0699366954707887,
           1.0823579371319862,
           1.0946441494298125,
           1.106788139455142,
           1.1187829797422746,
           1.1306219961603887,
           1.1422987566469986,
           1.153807060730691,
           1.165140929792492,
           1.17629459801752,
           1.1872625039909648,
           1.1980392828948956,
           1.2086197592648578,
           1.2189989402676542,
           1.2291720094640721,
           1.2391343210226267,
           1.2488813943525918,
           1.258408909126708,
           1.2677127006659528,
           1.2767887556606659,
           1.285633208204118,
           1.2942423361162787,
           1.3026125575371512,
           1.3107404277704926,
           1.318622636360154,
           1.32625600438255,
           1.333637481939984,
           1.3407641458406896,
           1.3476331974524822,
           1.3542419607179093,
           1.3605878803196896,
           1.366668519986086,
           1.3724815609266399,
           1.378024800389437,
           1.383296150331759,
           1.3882936361966118,
           1.3930153957882279,
           1.397459678240182,
           1.4016248430703002,
           1.405509359317019,
           1.4091118047523095,
           1.4124308651667261,
           1.4154653337225227,
           1.4182141103711912,
           1.4206762013321128,
           1.4228507186293757,
           1.4247368796841355,
           1.4263340069602037,
           1.4276415276608572,
           1.4286589734751503,
           1.4293859803722857,
           1.4298222884428802
          ],
          [
           1.4557958172439769,
           1.4556443619541763,
           1.4551900480811135,
           1.4544330316343368,
           1.4533735726983266,
           1.4520120355357886,
           1.4503488887331604,
           1.4483847053892238,
           1.4461201633479899,
           1.443556045477297,
           1.4406932399948373,
           1.437532740843619,
           1.4340756481191856,
           1.4303231685512154,
           1.426276616042469,
           1.421937412268401,
           1.4173070873411218,
           1.4123872805417885,
           1.407179741125931,
           1.4016863292066524,
           1.3959090167211359,
           1.389849888486391,
           1.3835111433507261,
           1.3768950954480232,
           1.3700041755625276,
           1.362840932612546,
           1.355408035262189,
           1.3477082736710932,
           1.3397445613929089,
           1.3315199374342863,
           1.3230375684870912,
           1.3143007513476748,
           1.3053129155382048,
           1.2960776261463427,
           1.2865985869009346,
           1.2768796435028882,
           1.2669247872320184,
           1.2567381588524125,
           1.246324052840745,
           1.2356869219640316,
           1.2248313822355086,
           1.2137622182797085,
           1.2024843891403525,
           1.1910030345674176,
           1.1793234818226868,
           1.1674512530461907,
           1.1553920732293128,
           1.1431518788438157,
           1.13073682717978,
           1.1181533064493079,
           1.1054079467168758,
           1.092507631721342,
           1.0794595116588095,
           1.0662710169997118,
           1.0529498734175569,
           1.039504117910586,
           1.025942116201043,
           1.0122725814995734,
           0.9985045947242295,
           0.9846476262643146,
           0.9707115593784369,
           0.9567067153131357,
           0.9426438802226709,
           0.9285343339612249,
           0.9143898808049249,
           0.9002228821415849,
           0.8860462911395398,
           0.8718736893717547,
           0.8577193253256323,
           0.8435981546704262,
           0.8295258820803212,
           0.8155190043193128,
           0.8015948541808336,
           0.7877716447374328,
           0.7740685131903248,
           0.7605055634121894,
           0.7471039060465189,
           0.7338856947614106,
           0.7208741569548589,
           0.7080936168746098,
           0.6955695087542058,
           0.6833283771883271,
           0.6713978615913083,
           0.6598066612265745,
           0.648584476994303,
           0.6377619259620544,
           0.627370424570402,
           0.6174420366031512,
           0.6080092824454373,
           0.5991049069284459,
           0.590761604233753,
           0.5830116999403899,
           0.5758867923473787,
           0.5694173576495442,
           0.563632326280863,
           0.558558640596216,
           0.5542208068030497,
           0.5506404563926544,
           0.5478359339484408,
           0.5458219288375057,
           0.5446091677021494,
           0.5442041827560231,
           0.5446091677021503,
           0.5458219288375072,
           0.5478359339484433,
           0.5506404563926575,
           0.5542208068030537,
           0.5585586405962207,
           0.5636323262808686,
           0.5694173576495505,
           0.5758867923473858,
           0.5830116999403977,
           0.5907616042337612,
           0.5991049069284548,
           0.6080092824454467,
           0.6174420366031613,
           0.6273704245704126,
           0.6377619259620653,
           0.6485844769943143,
           0.6598066612265863,
           0.6713978615913205,
           0.6833283771883396,
           0.6955695087542183,
           0.7080936168746228,
           0.7208741569548721,
           0.7338856947614241,
           0.7471039060465325,
           0.7605055634122032,
           0.7740685131903389,
           0.787771644737447,
           0.801594854180848,
           0.8155190043193269,
           0.8295258820803355,
           0.8435981546704407,
           0.857719325325647,
           0.8718736893717691,
           0.8860462911395545,
           0.9002228821415993,
           0.9143898808049394,
           0.9285343339612393,
           0.9426438802226854,
           0.9567067153131503,
           0.9707115593784512,
           0.9846476262643288,
           0.9985045947242436,
           1.0122725814995877,
           1.025942116201057,
           1.0395041179105997,
           1.0529498734175706,
           1.0662710169997252,
           1.0794595116588228,
           1.0925076317213553,
           1.105407946716889,
           1.1181533064493208,
           1.1307368271797926,
           1.1431518788438286,
           1.1553920732293255,
           1.1674512530462031,
           1.1793234818226987,
           1.1910030345674296,
           1.202484389140364,
           1.21376221827972,
           1.2248313822355197,
           1.2356869219640427,
           1.246324052840756,
           1.2567381588524231,
           1.2669247872320286,
           1.276879643502898,
           1.2865985869009446,
           1.2960776261463522,
           1.3053129155382144,
           1.314300751347684,
           1.3230375684871,
           1.331519937434295,
           1.3397445613929173,
           1.3477082736711012,
           1.3554080352621969,
           1.3628409326125532,
           1.370004175562535,
           1.3768950954480301,
           1.383511143350733,
           1.3898498884863972,
           1.395909016721142,
           1.4016863292066581,
           1.4071797411259366,
           1.4123872805417936,
           1.4173070873411264,
           1.4219374122684056,
           1.426276616042473,
           1.4303231685512194,
           1.4340756481191894,
           1.4375327408436225,
           1.4406932399948402,
           1.4435560454773,
           1.4461201633479923,
           1.448384705389226,
           1.4503488887331628,
           1.45201203553579,
           1.4533735726983275,
           1.4544330316343377,
           1.4551900480811142,
           1.4556443619541768
          ],
          [
           1.482150375101679,
           1.4819930111391635,
           1.4815209712585165,
           1.4807344114988006,
           1.4796335919864712,
           1.4782188770278355,
           1.476490735239365,
           1.474449739716752,
           1.4720965682438332,
           1.4694320035428061,
           1.4664569335674098,
           1.4631723518410493,
           1.4595793578421365,
           1.4556791574392336,
           1.4514730633789144,
           1.4469624958296246,
           1.4421489829851677,
           1.4370341617318647,
           1.4316197783838451,
           1.4259076894913765,
           1.419899862727638,
           1.4135983778598562,
           1.407005427811282,
           1.4001233198211065,
           1.392954476710064,
           1.3855014382601738,
           1.3777668627178694,
           1.369753528430567,
           1.3614643356276719,
           1.352902308357982,
           1.3440705965965418,
           1.334972478535176,
           1.3256113630721968,
           1.3159907925181953,
           1.3061144455363276,
           1.2959861403371855,
           1.285609838150144,
           1.274989646995054,
           1.2641298257803095,
           1.2530347887556754,
           1.241709110350815,
           1.2301575304332686,
           1.2183849600226644,
           1.2063964875012698,
           1.1941973853645773,
           1.1817931175595326,
           1.1691893474622421,
           1.1563919465515633,
           1.1434070038399076,
           1.1302408361278788,
           1.1168999991550266,
           1.1033912997250188,
           1.0897218088899192,
           1.0758988762849462,
           1.0619301457120662,
           1.0478235720779432,
           1.0335874397990161,
           1.0192303827936897,
           1.0047614061885353,
           0.9901899098718059,
           0.9755257140330472,
           0.9607790868316983,
           0.9459607743397106,
           0.9310820329025844,
           0.9161546640588548,
           0.9011910521487251,
           0.8862042047267046,
           0.8712077958688719,
           0.8562162124304223,
           0.8412446032606915,
           0.8263089313174681,
           0.811426028536171,
           0.7966136531977162,
           0.7818905493963135,
           0.7672765080291328,
           0.7527924285073065,
           0.7384603801155197,
           0.7243036616190486,
           0.7103468573271036,
           0.6966158873661737,
           0.6831380493965722,
           0.6699420484246416,
           0.6570580107347717,
           0.6445174773127267,
           0.6323533714917381,
           0.6205999349792257,
           0.6092926259884296,
           0.598467973000062,
           0.5881633778282842,
           0.5784168622909515,
           0.5692667540172242,
           0.5607513088825062,
           0.5529082703175536,
           0.5457743693011834,
           0.5393847731170933,
           0.5337724957073896,
           0.5289677873178502,
           0.5249975256004452,
           0.5218846338269403,
           0.5196475537733256,
           0.5182998006521455,
           0.517849624898321,
           0.5182998006521464,
           0.5196475537733274,
           0.5218846338269431,
           0.5249975256004489,
           0.5289677873178547,
           0.533772495707395,
           0.5393847731170995,
           0.5457743693011904,
           0.5529082703175614,
           0.5607513088825147,
           0.5692667540172334,
           0.5784168622909611,
           0.5881633778282944,
           0.5984679730000729,
           0.609292625988441,
           0.6205999349792376,
           0.6323533714917505,
           0.6445174773127395,
           0.6570580107347849,
           0.6699420484246552,
           0.6831380493965857,
           0.6966158873661877,
           0.7103468573271178,
           0.7243036616190629,
           0.7384603801155344,
           0.7527924285073213,
           0.7672765080291478,
           0.7818905493963287,
           0.7966136531977313,
           0.8114260285361862,
           0.8263089313174833,
           0.8412446032607069,
           0.8562162124304378,
           0.8712077958688873,
           0.88620420472672,
           0.9011910521487403,
           0.9161546640588705,
           0.9310820329025997,
           0.9459607743397258,
           0.9607790868317134,
           0.9755257140330625,
           0.9901899098718211,
           1.0047614061885501,
           1.0192303827937046,
           1.033587439799031,
           1.0478235720779578,
           1.0619301457120809,
           1.0758988762849604,
           1.0897218088899334,
           1.1033912997250326,
           1.1168999991550401,
           1.1302408361278924,
           1.1434070038399209,
           1.1563919465515766,
           1.1691893474622552,
           1.1817931175595453,
           1.19419738536459,
           1.2063964875012825,
           1.2183849600226764,
           1.2301575304332804,
           1.241709110350827,
           1.253034788755687,
           1.2641298257803206,
           1.2749896469950648,
           1.2856098381501548,
           1.295986140337196,
           1.3061144455363378,
           1.3159907925182055,
           1.3256113630722068,
           1.3349724785351853,
           1.344070596596551,
           1.352902308357991,
           1.361464335627681,
           1.3697535284305753,
           1.3777668627178776,
           1.3855014382601818,
           1.3929544767100717,
           1.4001233198211136,
           1.4070054278112885,
           1.4135983778598626,
           1.4198998627276445,
           1.425907689491382,
           1.431619778383851,
           1.4370341617318698,
           1.4421489829851724,
           1.4469624958296294,
           1.4514730633789183,
           1.4556791574392378,
           1.4595793578421403,
           1.4631723518410529,
           1.4664569335674131,
           1.469432003542809,
           1.4720965682438358,
           1.4744497397167544,
           1.4764907352393675,
           1.478218877027837,
           1.4796335919864727,
           1.4807344114988013,
           1.481520971258517,
           1.4819930111391637
          ],
          [
           1.5090059190266825,
           1.5088427463803278,
           1.5083532804485815,
           1.507537677269385,
           1.5063961969593904,
           1.5049292037945021,
           1.5031371663234756,
           1.501020657515417,
           1.4985803549422805,
           1.4958170409977214,
           1.492731603153925,
           1.4893250342583144,
           1.4855984328723262,
           1.481553003654763,
           1.4771900577925285,
           1.4725110134819275,
           1.4675173964640467,
           1.4622108406181438,
           1.4565930886173764,
           1.4506659926516554,
           1.4444315152228941,
           1.437891730018431,
           1.43104882286899,
           1.423905092798128,
           1.4164629531708062,
           1.4087249329494211,
           1.4006936780664359,
           1.3923719529235958,
           1.3837626420286546,
           1.3748687517815554,
           1.3656934124231337,
           1.3562398801606288,
           1.346511539485639,
           1.3365119057016226,
           1.326244627679663,
           1.3157134908629957,
           1.3049224205427412,
           1.2938754854294212,
           1.2825769015472144,
           1.27103103648047,
           1.2592424140048728,
           1.2472157191387694,
           1.234955803653619,
           1.2224676920863258,
           1.2097565883003722,
           1.196827882647246,
           1.1836871597846839,
           1.1703402072137632,
           1.156793024602901,
           1.1430518339734255,
           1.1291230908285803,
           1.115013496315669,
           1.1007300105195497,
           1.086279866994897,
           1.0716705886545665,
           1.056910005141993,
           1.042006271826849,
           1.0269678905750765,
           1.0118037324567999,
           0.9965230625683601,
           0.981135567157537,
           0.9656513832535839,
           0.9500811310155373,
           0.9344359490226857,
           0.9187275327392552,
           0.9029681763900951,
           0.8871708184839546,
           0.8713490912138566,
           0.8555173739476003,
           0.8396908509924326,
           0.8238855737723929,
           0.8081185274898964,
           0.7924077022486655,
           0.7767721684858824,
           0.7612321563886505,
           0.7458091387433535,
           0.730525916374657,
           0.7154067049609071,
           0.7004772215510929,
           0.6857647685421464,
           0.6712983121928647,
           0.6571085519450192,
           0.6432279758937516,
           0.6296908967108217,
           0.61653346120642,
           0.6037936255739818,
           0.591511087286464,
           0.5797271637307455,
           0.5684846071530334,
           0.5578273455610413,
           0.5478001401422432,
           0.5384481517787046,
           0.5298164126083789,
           0.5219492034570606,
           0.5148893443453426,
           0.5086774129302613,
           0.5033509141492031,
           0.4989434326601351,
           0.49548380682078924,
           0.492995367694664,
           0.49149528777381407,
           0.4909940809733175,
           0.49149528777381507,
           0.4929953676946661,
           0.49548380682079224,
           0.49894343266013913,
           0.503350914149208,
           0.5086774129302672,
           0.5148893443453494,
           0.5219492034570683,
           0.5298164126083873,
           0.538448151778714,
           0.5478001401422531,
           0.557827345561052,
           0.5684846071530447,
           0.5797271637307573,
           0.5915110872864764,
           0.6037936255739946,
           0.6165334612064335,
           0.6296908967108354,
           0.6432279758937658,
           0.6571085519450335,
           0.6712983121928793,
           0.6857647685421614,
           0.7004772215511081,
           0.7154067049609226,
           0.7305259163746726,
           0.7458091387433694,
           0.7612321563886663,
           0.7767721684858984,
           0.7924077022486816,
           0.8081185274899125,
           0.8238855737724091,
           0.8396908509924488,
           0.8555173739476167,
           0.8713490912138727,
           0.887170818483971,
           0.9029681763901112,
           0.9187275327392714,
           0.9344359490227018,
           0.9500811310155534,
           0.9656513832535999,
           0.9811355671575528,
           0.9965230625683761,
           1.0118037324568154,
           1.0269678905750923,
           1.0420062718268643,
           1.0569100051420082,
           1.0716705886545816,
           1.0862798669949119,
           1.1007300105195643,
           1.1150134963156837,
           1.1291230908285945,
           1.1430518339734397,
           1.156793024602915,
           1.170340207213777,
           1.1836871597846974,
           1.1968278826472591,
           1.2097565883003856,
           1.2224676920863387,
           1.2349558036536317,
           1.247215719138782,
           1.2592424140048852,
           1.2710310364804818,
           1.2825769015472261,
           1.293875485429433,
           1.3049224205427525,
           1.3157134908630068,
           1.3262446276796735,
           1.336511905701633,
           1.3465115394856493,
           1.3562398801606386,
           1.3656934124231432,
           1.3748687517815648,
           1.3837626420286637,
           1.3923719529236047,
           1.4006936780664445,
           1.4087249329494294,
           1.4164629531708142,
           1.4239050927981354,
           1.4310488228689968,
           1.437891730018438,
           1.4444315152229008,
           1.4506659926516616,
           1.4565930886173821,
           1.462210840618149,
           1.4675173964640518,
           1.4725110134819324,
           1.477190057792533,
           1.4815530036547675,
           1.4855984328723304,
           1.489325034258318,
           1.4927316031539284,
           1.4958170409977245,
           1.4985803549422831,
           1.5010206575154192,
           1.5031371663234778,
           1.5049292037945041,
           1.5063961969593915,
           1.5075376772693858,
           1.5083532804485822,
           1.5088427463803282
          ],
          [
           1.5363364680146776,
           1.5361675924383227,
           1.5356610177215688,
           1.5348168999148073,
           1.533635499146994,
           1.532117179693495,
           1.53026241007187,
           1.5280717631663852,
           1.5255459163822889,
           1.5226856518311493,
           1.519491856548768,
           1.5159655227474875,
           1.5121077481049607,
           1.5079197360917604,
           1.5034027963405021,
           1.4985583450594937,
           1.4933879054942685,
           1.4878931084407354,
           1.48207569281409,
           1.475937506278049,
           1.4694805059394622,
           1.4627067591138347,
           1.4556184441678823,
           1.4482178514457997,
           1.4405073842866114,
           1.4324895601406662,
           1.424167011794122,
           1.4155424887111279,
           1.4066188585043318,
           1.3973991085453852,
           1.3878863477282306,
           1.3780838083992124,
           1.3679948484694007,
           1.357622953726049,
           1.346971740361743,
           1.3360449577416533,
           1.3248464914313198,
           1.3133803665096473,
           1.3016507511942652,
           1.2896619608091553,
           1.2774184621274975,
           1.26492487812605,
           1.2521859931911192,
           1.2392067588203288,
           1.2259922998689903,
           1.2125479213949748,
           1.1988791161616588,
           1.1849915728647775,
           1.1708911851559929,
           1.1565840615436813,
           1.142076536259996,
           1.1273751811926993,
           1.11248681899069,
           1.0974185374636678,
           1.0821777054090338,
           1.0667719900130213,
           1.0512093759882601,
           1.0354981866265365,
           1.019647106963442,
           1.0036652092709364,
           0.9875619811144508,
           0.9713473562329394,
           0.9550317485229418,
           0.9386260894308808,
           0.9221418690808301,
           0.9055911814870024,
           0.8889867742199583,
           0.8723421029113296,
           0.8556713909913445,
           0.8389896950535719,
           0.8223129762279249,
           0.8056581779107672,
           0.789043310143029,
           0.7724875408347216,
           0.7560112938960711,
           0.7396363541378335,
           0.723385978529379,
           0.7072850130326893,
           0.6913600137400332,
           0.6756393704064184,
           0.6601534296567808,
           0.6449346141344959,
           0.6300175326184523,
           0.6154390746569036,
           0.601238481552434,
           0.587457383618891,
           0.5741397915991034,
           0.5613320281263755,
           0.5490825833605248,
           0.5374418777559644,
           0.526461914753432,
           0.5161958075448607,
           0.5066971674999393,
           0.4980193478713823,
           0.49021454533549963,
           0.48333277373456324,
           0.4774207384822818,
           0.47252065521103725,
           0.46866907043330425,
           0.4658957528195272,
           0.4642227286412914,
           0.4636635319853224,
           0.46422272864129255,
           0.4658957528195295,
           0.46866907043330763,
           0.4725206552110417,
           0.47742073848228733,
           0.48333277373456984,
           0.4902145453355072,
           0.49801934787139074,
           0.5066971674999488,
           0.5161958075448709,
           0.5264619147534428,
           0.5374418777559761,
           0.5490825833605372,
           0.5613320281263884,
           0.5741397915991169,
           0.5874573836189049,
           0.6012384815524484,
           0.6154390746569183,
           0.6300175326184675,
           0.6449346141345115,
           0.6601534296567966,
           0.6756393704064343,
           0.6913600137400495,
           0.7072850130327057,
           0.7233859785293957,
           0.7396363541378502,
           0.756011293896088,
           0.7724875408347386,
           0.7890433101430461,
           0.8056581779107841,
           0.822312976227942,
           0.8389896950535892,
           0.8556713909913616,
           0.8723421029113466,
           0.8889867742199756,
           0.9055911814870193,
           0.9221418690808472,
           0.9386260894308975,
           0.9550317485229587,
           0.9713473562329562,
           0.9875619811144675,
           1.003665209270953,
           1.0196471069634585,
           1.035498186626553,
           1.0512093759882764,
           1.066771990013037,
           1.0821777054090498,
           1.0974185374636833,
           1.1124868189907053,
           1.1273751811927144,
           1.142076536260011,
           1.1565840615436958,
           1.1708911851560075,
           1.184991572864792,
           1.1988791161616728,
           1.2125479213949888,
           1.225992299869004,
           1.2392067588203421,
           1.252185993191132,
           1.264924878126063,
           1.2774184621275104,
           1.2896619608091677,
           1.3016507511942774,
           1.3133803665096595,
           1.3248464914313314,
           1.3360449577416647,
           1.346971740361754,
           1.3576229537260598,
           1.367994848469411,
           1.3780838083992226,
           1.3878863477282406,
           1.3973991085453947,
           1.406618858504341,
           1.415542488711137,
           1.424167011794131,
           1.4324895601406746,
           1.4405073842866198,
           1.4482178514458073,
           1.4556184441678899,
           1.4627067591138418,
           1.4694805059394687,
           1.4759375062780555,
           1.482075692814096,
           1.4878931084407407,
           1.4933879054942736,
           1.498558345059499,
           1.5034027963405068,
           1.507919736091765,
           1.5121077481049647,
           1.5159655227474913,
           1.5194918565487718,
           1.5226856518311525,
           1.5255459163822918,
           1.5280717631663874,
           1.5302624100718727,
           1.5321171796934967,
           1.5336354991469952,
           1.5348168999148084,
           1.5356610177215695,
           1.5361675924383231
          ],
          [
           1.564115581524634,
           1.563941113653531,
           1.563417762075247,
           1.5625456829056896,
           1.5613251363742418,
           1.5597564868784373,
           1.5578402030612402,
           1.5555768579116738,
           1.5529671288897589,
           1.5500117980769637,
           1.5467117523535778,
           1.543067983604702,
           1.5390815889567835,
           1.534753771046901,
           1.5300858383273104,
           1.525079205408055,
           1.5197353934407756,
           1.5140560305472248,
           1.5080428522963578,
           1.5016977022342868,
           1.4950225324718396,
           1.488019404334942,
           1.4806904890835757,
           1.4730380687056324,
           1.4650645367926265,
           1.456772399504903,
           1.448164276634745,
           1.4392429027766096,
           1.430011128614633,
           1.4204719223385558,
           1.410628371200322,
           1.400483683224838,
           1.3900411890897262,
           1.3793043441904096,
           1.3682767309085209,
           1.3569620611034812,
           1.3453641788491293,
           1.3334870634395601,
           1.3213348326908632,
           1.3089117465682638,
           1.2962222111713093,
           1.2832707831132444,
           1.2700621743346214,
           1.2566012573955563,
           1.242893071295916,
           1.2289428278781698,
           1.2147559188737393,
           1.2003379236605025,
           1.1856946178067456,
           1.1708319824854185,
           1.155756214852115,
           1.1404737394909388,
           1.1249912210444126,
           1.1093155781570228,
           1.0934539988770116,
           1.077413957677805,
           1.061203234279156,
           1.0448299344689258,
           1.0283025131495311,
           1.0116297998586976,
           0.9948210270423797,
           0.977885861388688,
           0.9608344385654337,
           0.9436774017404166,
           0.9264259443026591,
           0.9090918572439992,
           0.8916875817031032,
           0.8742262672169189,
           0.8567218362661247,
           0.8391890557387867,
           0.8216436159666362,
           0.8041022180061836,
           0.7865826698355013,
           0.769103992107726,
           0.7516865340319044,
           0.7343520998245358,
           0.7171240859701107,
           0.7000276292192662,
           0.6830897648052713,
           0.6663395937321919,
           0.6498084571321193,
           0.6335301145480212,
           0.6175409215120927,
           0.6018799998966632,
           0.5865893921656987,
           0.5717141878256607,
           0.5573026070903305,
           0.5434060231428759,
           0.530078900631842,
           0.5173786245797249,
           0.5053651913338157,
           0.4941007324109844,
           0.48364884416275067,
           0.47407370231393986,
           0.4654389517083772,
           0.4578063786841137,
           0.4512343961605593,
           0.44577639816807896,
           0.4414790679868561,
           0.43838074759890805,
           0.4365099903345916,
           0.43588441847536596,
           0.4365099903345928,
           0.43838074759891066,
           0.44147906798685993,
           0.4457763981680839,
           0.4512343961605655,
           0.457806378684121,
           0.4654389517083856,
           0.4740737023139492,
           0.48364884416276094,
           0.49410073241099567,
           0.5053651913338276,
           0.5173786245797376,
           0.5300789006318555,
           0.5434060231428899,
           0.5573026070903452,
           0.5717141878256758,
           0.5865893921657143,
           0.6018799998966792,
           0.6175409215121092,
           0.6335301145480378,
           0.6498084571321362,
           0.6663395937322089,
           0.6830897648052886,
           0.7000276292192837,
           0.7171240859701284,
           0.7343520998245535,
           0.7516865340319223,
           0.769103992107744,
           0.7865826698355192,
           0.8041022180062016,
           0.8216436159666541,
           0.8391890557388048,
           0.8567218362661427,
           0.874226267216937,
           0.8916875817031209,
           0.909091857244017,
           0.9264259443026771,
           0.9436774017404344,
           0.9608344385654514,
           0.9778858613887057,
           0.9948210270423972,
           1.011629799858715,
           1.028302513149548,
           1.0448299344689427,
           1.061203234279173,
           1.0774139576778217,
           1.093453998877028,
           1.1093155781570387,
           1.1249912210444286,
           1.1404737394909548,
           1.1557562148521305,
           1.1708319824854339,
           1.1856946178067609,
           1.2003379236605174,
           1.2147559188737542,
           1.228942827878184,
           1.24289307129593,
           1.2566012573955703,
           1.2700621743346348,
           1.2832707831132577,
           1.2962222111713224,
           1.3089117465682767,
           1.3213348326908758,
           1.3334870634395724,
           1.3453641788491415,
           1.356962061103493,
           1.3682767309085322,
           1.3793043441904207,
           1.3900411890897373,
           1.4004836832248482,
           1.410628371200332,
           1.4204719223385658,
           1.4300111286146429,
           1.439242902776619,
           1.448164276634754,
           1.4567723995049116,
           1.465064536792635,
           1.4730380687056404,
           1.480690489083583,
           1.488019404334949,
           1.4950225324718467,
           1.5016977022342932,
           1.5080428522963643,
           1.5140560305472306,
           1.519735393440781,
           1.5250792054080604,
           1.5300858383273155,
           1.5347537710469052,
           1.5390815889567877,
           1.543067983604706,
           1.546711752353581,
           1.550011798076967,
           1.5529671288897617,
           1.555576857911676,
           1.5578402030612426,
           1.5597564868784388,
           1.561325136374243,
           1.56254568290569,
           1.5634177620752476,
           1.5639411136535313
          ],
          [
           1.5923163850583166,
           1.5921364395920308,
           1.5915966552801728,
           1.590697188391904,
           1.5894382994031377,
           1.5878203530378328,
           1.5858438183264885,
           1.583509268682502,
           1.5808173819972755,
           1.5777689407551698,
           1.5743648321695938,
           1.5706060483417819,
           1.5664936864440138,
           1.5620289489293155,
           1.5572131437699208,
           1.552047684727074,
           1.546534091655063,
           1.5406739908426805,
           1.5344691153956929,
           1.5279213056642593,
           1.5210325097196686,
           1.513804783885216,
           1.5062402933265349,
           1.4983413127072385,
           1.4901102269163202,
           1.4815495318744158,
           1.472661835426735,
           1.4634498583312723,
           1.4539164353517697,
           1.4440645164658559,
           1.433897168199868,
           1.4234175751030267,
           1.4126290413749385,
           1.4015349926618703,
           1.3901389780388305,
           1.378444672196308,
           1.3664558778525204,
           1.354176528414254,
           1.3416106909118855,
           1.3287625692369736,
           1.3156365077139374,
           1.3022369950408537,
           1.2885686686383468,
           1.2746363194499737,
           1.260444897242488,
           1.245999516459968,
           1.231305462692115,
           1.2163681998241431,
           1.2011933779437163,
           1.1857868420894668,
           1.1701546419358768,
           1.1543030425208989,
           1.1382385361358023,
           1.121967855511578,
           1.105497988453013,
           1.0888361940905718,
           1.0719900209417115,
           1.0549673269975992,
           1.0377763020786848,
           1.020425492733636,
           1.002923829991118,
           0.9852806603132738,
           0.967505780143893,
           0.9496094744936043,
           0.9316025600592805,
           0.9134964334355029,
           0.8953031250424074,
           0.8770353594663353,
           0.8587066229867907,
           0.840331239143952,
           0.8219244532832125,
           0.8035025270934048,
           0.7850828442281256,
           0.7666840281570318,
           0.748326073424726,
           0.730030491482822,
           0.7118204721836744,
           0.6937210618515792,
           0.675759358538112,
           0.6579647245686393,
           0.6403690157271247,
           0.6230068253181332,
           0.6059157397809684,
           0.5891366003855592,
           0.5727137626755475,
           0.5566953416059313,
           0.5411334256451215,
           0.5260842374442484,
           0.5116082121349049,
           0.4977699572575078,
           0.4846380514665671,
           0.4722846337164748,
           0.46078473239182793,
           0.4502152871597973,
           0.44065382786685064,
           0.4321767970319126,
           0.42485753670602694,
           0.4187640056255593,
           0.41395634414656846,
           0.4104844539298284,
           0.40838579522348095,
           0.4076836149416835,
           0.4083857952234824,
           0.41048445392983124,
           0.41395634414657273,
           0.418764005625565,
           0.4248575367060339,
           0.4321767970319208,
           0.44065382786685997,
           0.45021528715980763,
           0.4607847323918393,
           0.4722846337164871,
           0.4846380514665801,
           0.4977699572575217,
           0.5116082121349194,
           0.5260842374442636,
           0.5411334256451371,
           0.5566953416059475,
           0.5727137626755643,
           0.5891366003855762,
           0.6059157397809859,
           0.6230068253181509,
           0.6403690157271426,
           0.6579647245686575,
           0.6757593585381304,
           0.6937210618515978,
           0.7118204721836929,
           0.7300304914828407,
           0.7483260734247448,
           0.7666840281570508,
           0.7850828442281444,
           0.8035025270934237,
           0.8219244532832315,
           0.8403312391439709,
           0.8587066229868096,
           0.8770353594663539,
           0.895303125042426,
           0.9134964334355217,
           0.9316025600592992,
           0.9496094744936227,
           0.9675057801439114,
           0.9852806603132919,
           1.0029238299911363,
           1.0204254927336538,
           1.0377763020787025,
           1.0549673269976165,
           1.0719900209417288,
           1.0888361940905888,
           1.1054979884530298,
           1.1219678555115946,
           1.1382385361358192,
           1.1543030425209153,
           1.170154641935893,
           1.1857868420894828,
           1.201193377943732,
           1.2163681998241587,
           1.2313054626921305,
           1.2459995164599829,
           1.2604448972425029,
           1.2746363194499883,
           1.2885686686383608,
           1.3022369950408674,
           1.315636507713951,
           1.3287625692369867,
           1.3416106909118983,
           1.354176528414267,
           1.3664558778525326,
           1.3784446721963197,
           1.390138978038842,
           1.401534992661882,
           1.41262904137495,
           1.4234175751030376,
           1.4338971681998787,
           1.4440645164658656,
           1.4539164353517797,
           1.4634498583312823,
           1.4726618354267442,
           1.4815495318744252,
           1.490110226916329,
           1.4983413127072467,
           1.506240293326543,
           1.5138047838852238,
           1.521032509719676,
           1.527921305664266,
           1.5344691153956993,
           1.5406739908426863,
           1.5465340916550687,
           1.5520476847270794,
           1.5572131437699257,
           1.5620289489293206,
           1.5664936864440178,
           1.5706060483417856,
           1.5743648321695976,
           1.577768940755173,
           1.5808173819972786,
           1.5835092686825043,
           1.585843818326491,
           1.587820353037835,
           1.5894382994031389,
           1.5906971883919057,
           1.5915966552801737,
           1.5921364395920312
          ],
          [
           1.620911596159626,
           1.6207262911103784,
           1.6201704281408038,
           1.6192441637909225,
           1.6179477589792188,
           1.616281579030623,
           1.614246093716285,
           1.6118418773057541,
           1.609069608632345,
           1.6059300711726845,
           1.6024241531415957,
           1.598552847603704,
           1.5943172526033595,
           1.5897185713146904,
           1.58475811221385,
           1.5794372892757838,
           1.5737576221981024,
           1.567720736654969,
           1.5613283645842106,
           1.5545823445112252,
           1.5474846219136376,
           1.5400372496310617,
           1.5322423883247924,
           1.524102306992739,
           1.5156193835454659,
           1.5067961054497903,
           1.497635070447077,
           1.4881389873540667,
           1.4783106769549121,
           1.4681530729939725,
           1.4576692232799209,
           1.446862290912816,
           1.435735555647024,
           1.424292415404244,
           1.4125363879524087,
           1.4004711127679599,
           1.3881003531008826,
           1.3754279982640418,
           1.3624580661707564,
           1.3491947061472427,
           1.335642202049594,
           1.3218049757183792,
           1.3076875908077923,
           1.2932947570306321,
           1.2786313348653158,
           1.263702340776678,
           1.2485129530086303,
           1.2330685180138936,
           1.2173745575941533,
           1.2014367768332233,
           1.1852610729163273,
           1.1688535449405995,
           1.152220504835583,
           1.1353684895281395,
           1.1183042745040321,
           1.1010348889388744,
           1.08356763259453,
           1.065910094703822,
           1.0480701750970915,
           1.0300561078593158,
           1.0118764878467652,
           0.9935403004383274,
           0.9750569549494152,
           0.9564363221967332,
           0.9376887767710256,
           0.9188252446532893,
           0.8998572568988061,
           0.8807970102136671,
           0.8616574353610125,
           0.8424522744594518,
           0.8231961683739127,
           0.803904755548495,
           0.7845947837892684,
           0.7652842366677127,
           0.7459924763747872,
           0.726740404998892,
           0.7075506463090253,
           0.6884477501686225,
           0.6694584216442319,
           0.6506117766469597,
           0.6319396254704814,
           0.6134767847537376,
           0.5952614170471328,
           0.5773353951004331,
           0.5597446849707286,
           0.5425397377744368,
           0.5257758740529511,
           0.509513636974885,
           0.4938190807453283,
           0.4787639486659961,
           0.46442568179319194,
           0.4508871853572941,
           0.4382362684606097,
           0.4265646669225387,
           0.4159665648275677,
           0.40653655359967167,
           0.3983670139171446,
           0.39154497788263265,
           0.3861486223205051,
           0.382243645165008,
           0.37987986231779436,
           0.3790884038403738,
           0.379879862317796,
           0.3822436451650112,
           0.38614862232050995,
           0.39154497788263887,
           0.3983670139171523,
           0.4065365535996808,
           0.41596656482757804,
           0.4265646669225501,
           0.4382362684606223,
           0.45088718535730754,
           0.46442568179320637,
           0.4787639486660112,
           0.49381908074534414,
           0.5095136369749015,
           0.5257758740529681,
           0.5425397377744543,
           0.5597446849707466,
           0.5773353951004515,
           0.5952614170471514,
           0.6134767847537566,
           0.6319396254705004,
           0.650611776646979,
           0.6694584216442514,
           0.688447750168642,
           0.707550646309045,
           0.7267404049989118,
           0.7459924763748069,
           0.7652842366677325,
           0.7845947837892882,
           0.8039047555485148,
           0.8231961683739326,
           0.8424522744594717,
           0.8616574353610322,
           0.8807970102136867,
           0.8998572568988258,
           0.9188252446533086,
           0.9376887767710449,
           0.9564363221967525,
           0.9750569549494342,
           0.9935403004383464,
           1.011876487846784,
           1.0300561078593344,
           1.04807017509711,
           1.0659100947038402,
           1.083567632594548,
           1.101034888938892,
           1.11830427450405,
           1.1353684895281568,
           1.1522205048356,
           1.1688535449406166,
           1.185261072916344,
           1.2014367768332397,
           1.2173745575941695,
           1.2330685180139096,
           1.248512953008646,
           1.2637023407766936,
           1.278631334865331,
           1.2932947570306472,
           1.307687590807807,
           1.3218049757183938,
           1.335642202049608,
           1.3491947061472567,
           1.36245806617077,
           1.375427998264055,
           1.3881003531008953,
           1.4004711127679725,
           1.412536387952421,
           1.4242924154042556,
           1.4357355556470357,
           1.446862290912827,
           1.4576692232799318,
           1.4681530729939833,
           1.4783106769549226,
           1.4881389873540765,
           1.4976350704470867,
           1.5067961054497998,
           1.5156193835454748,
           1.5241023069927475,
           1.5322423883248004,
           1.5400372496310692,
           1.5474846219136449,
           1.5545823445112321,
           1.5613283645842173,
           1.5677207366549752,
           1.5737576221981082,
           1.5794372892757895,
           1.5847581122138554,
           1.5897185713146953,
           1.5943172526033642,
           1.5985528476037083,
           1.6024241531415997,
           1.6059300711726883,
           1.609069608632348,
           1.611841877305757,
           1.614246093716288,
           1.6162815790306249,
           1.6179477589792204,
           1.6192441637909234,
           1.6201704281408045,
           1.6207262911103786
          ],
          [
           1.649873550808615,
           1.6496830068133812,
           1.6491114271445872,
           1.6481589687558702,
           1.646825893246419,
           1.645112566875921,
           1.6430194605860307,
           1.6405471500288773,
           1.637696315603318,
           1.6344677424997978,
           1.6308623207548438,
           1.626881045316417,
           1.6225250161215152,
           1.617795438187644,
           1.6126936217199632,
           1.6072209822361716,
           1.6013790407114146,
           1.5951694237457796,
           1.5885938637572306,
           1.5816541992031377,
           1.5743523748339086,
           1.5666904419825842,
           1.5586705588946907,
           1.5502949911030606,
           1.5415661118528492,
           1.5324864025824934,
           1.5230584534669802,
           1.5132849640304287,
           1.503168743835744,
           1.4927127132599045,
           1.4819199043643465,
           1.470793461870932,
           1.4593366442550915,
           1.4475528249690095,
           1.435445493809111,
           1.4230182584436957,
           1.4102748461183252,
           1.3972191055585683,
           1.38385500909193,
           1.3701866550133353,
           1.3562182702213645,
           1.341954213155671,
           1.327398977069647,
           1.3125571936765468,
           1.2974336372119573,
           1.2820332289608516,
           1.2663610423035356,
           1.2504223083417314,
           1.2342224221739568,
           1.2177669498984318,
           1.2010616364321023,
           1.1841124142463058,
           1.1669254131332665,
           1.1495069711333747,
           1.1318636467713372,
           1.1140022327702386,
           1.0959297714367409,
           1.0776535719386477,
           1.0591812297284742,
           1.040520648404264,
           1.021680064342512,
           1.0026680744887337,
           0.9834936677500995,
           0.964166260503006,
           0.9446957368080425,
           0.9250924940172793,
           0.9053674945661834,
           0.8855323248669664,
           0.8655992623641828,
           0.8455813519794921,
           0.8254924933631421,
           0.8053475405872573,
           0.7851624161620532,
           0.7649542415311192,
           0.7447414865042794,
           0.7245441404110243,
           0.7043839080934119,
           0.6842844341851351,
           0.6642715594107146,
           0.6443736128334979,
           0.6246217440031983,
           0.605050298682692,
           0.5856972410932666,
           0.5666046241552029,
           0.5478191066654604,
           0.5293925122736205,
           0.5113824188813901,
           0.49385275796023975,
           0.4768743904430562,
           0.46052560856163444,
           0.4448924909136486,
           0.4300690116984874,
           0.41615677671858753,
           0.4032642334010131,
           0.39150518848837546,
           0.3809964779584966,
           0.37185468450472736,
           0.36419190190657397,
           0.3581107060543971,
           0.35369869231075335,
           0.35102313472527163,
           0.3501264491913849,
           0.3510231347252735,
           0.353698692310757,
           0.3581107060544025,
           0.364191901906581,
           0.37185468450473597,
           0.38099647795850683,
           0.3915051884883869,
           0.40326423340102574,
           0.4161567767186014,
           0.4300690116985022,
           0.44489249091366423,
           0.46052560856165087,
           0.47687439044307334,
           0.49385275796025757,
           0.5113824188814086,
           0.5293925122736393,
           0.5478191066654796,
           0.5666046241552223,
           0.5856972410932865,
           0.605050298682712,
           0.6246217440032185,
           0.6443736128335182,
           0.6642715594107349,
           0.6842844341851555,
           0.7043839080934327,
           0.7245441404110452,
           0.7447414865043,
           0.7649542415311401,
           0.7851624161620738,
           0.805347540587278,
           0.8254924933631628,
           0.8455813519795127,
           0.8655992623642034,
           0.8855323248669867,
           0.9053674945662039,
           0.9250924940172996,
           0.9446957368080627,
           0.9641662605030261,
           0.9834936677501193,
           1.0026680744887535,
           1.0216800643425314,
           1.040520648404283,
           1.0591812297284933,
           1.0776535719386666,
           1.0959297714367597,
           1.114002232770257,
           1.1318636467713554,
           1.1495069711333927,
           1.1669254131332842,
           1.184112414246323,
           1.2010616364321194,
           1.217766949898449,
           1.2342224221739737,
           1.2504223083417478,
           1.266361042303552,
           1.2820332289608676,
           1.297433637211973,
           1.312557193676562,
           1.327398977069662,
           1.3419542131556856,
           1.3562182702213792,
           1.3701866550133495,
           1.383855009091944,
           1.3972191055585819,
           1.4102748461183388,
           1.4230182584437083,
           1.4354454938091237,
           1.4475528249690217,
           1.4593366442551037,
           1.4707934618709435,
           1.4819199043643578,
           1.4927127132599154,
           1.5031687438357548,
           1.5132849640304389,
           1.5230584534669904,
           1.5324864025825031,
           1.5415661118528583,
           1.5502949911030695,
           1.5586705588946992,
           1.5666904419825924,
           1.5743523748339163,
           1.5816541992031452,
           1.588593863757237,
           1.5951694237457856,
           1.6013790407114206,
           1.6072209822361774,
           1.6126936217199683,
           1.6177954381876491,
           1.6225250161215201,
           1.626881045316421,
           1.6308623207548478,
           1.634467742499801,
           1.6376963156033213,
           1.6405471500288804,
           1.6430194605860338,
           1.645112566875923,
           1.6468258932464204,
           1.6481589687558713,
           1.6491114271445881,
           1.6496830068133819
          ],
          [
           1.6791742301846384,
           1.6789785698787945,
           1.6783916414713393,
           1.6774136024929234,
           1.6760447154960907,
           1.6742853480577007,
           1.6721359727827725,
           1.6695971673102232,
           1.6666696143210884,
           1.6633541015499844,
           1.6596515218006913,
           1.6555628729669136,
           1.651089258059432,
           1.6462318852410287,
           1.6409920678707677,
           1.6353712245593979,
           1.6293708792378674,
           1.6229926612411694,
           1.616238305409985,
           1.6091096522128647,
           1.601608647891989,
           1.5937373446358656,
           1.5854979007826835,
           1.5768925810584347,
           1.5679237568543445,
           1.558593906548622,
           1.5489056158780783,
           1.538861578365739,
           1.5284645958112215,
           1.5177175788513775,
           1.5066235475994936,
           1.4951856323722499,
           1.4834070745146324,
           1.4712912273341188,
           1.4588415571567153,
           1.4460616445188428,
           1.432955185510652,
           1.4195259932881512,
           1.405777999773547,
           1.3917152575654892,
           1.377341942083512,
           1.362662353973888,
           1.3476809218074637,
           1.3324022051038449,
           1.3168308977206273,
           1.300971831651323,
           1.284829981281283,
           1.2684104681574109,
           1.2517185663348889,
           1.2347597083727087,
           1.21753949205964,
           1.2000636879636533,
           1.1823382479109412,
           1.1643693145159317,
           1.1461632319013153,
           1.127726557767666,
           1.1090660769961243,
           1.0901888169955045,
           1.0711020650377736,
           1.0518133878640052,
           1.0323306538876553,
           1.0126620583745551,
           0.9928161520408478,
           0.9728018735829295,
           0.9526285867393752,
           0.9323061225863025,
           0.9118448278875266,
           0.8912556204626949,
           0.8705500527042863,
           0.8497403845726724,
           0.828839667632631,
           0.8078618419708234,
           0.7868218481583288,
           0.7657357568021849,
           0.7446209186716978,
           0.7234961388944159,
           0.7023818792959302,
           0.6813004936043535,
           0.6602765009423297,
           0.6393369037584826,
           0.618511557051927,
           0.597833596322065,
           0.5773399319717752,
           0.5570718176494316,
           0.5370754988370705,
           0.5174029452809491,
           0.4981126657462926,
           0.4792705948407481,
           0.46095102766948287,
           0.44323755686374217,
           0.4262239359155283,
           0.4100147510498077,
           0.3947257310470527,
           0.38048346428272134,
           0.36742423546013664,
           0.35569166200460534,
           0.34543283453240736,
           0.3367927872615716,
           0.3299073749789531,
           0.3248950103232337,
           0.3218481501912821,
           0.32082576981536165,
           0.3218481501912842,
           0.3248950103232378,
           0.32990737497895917,
           0.3367927872615795,
           0.34543283453241713,
           0.3556916620046167,
           0.3674242354601494,
           0.38048346428273544,
           0.39472573104706804,
           0.4100147510498239,
           0.42622393591554536,
           0.44323755686376004,
           0.46095102766950136,
           0.47927059484076723,
           0.4981126657463122,
           0.5174029452809692,
           0.537075498837091,
           0.5570718176494523,
           0.5773399319717962,
           0.5978335963220862,
           0.6185115570519482,
           0.639336903758504,
           0.6602765009423511,
           0.6813004936043752,
           0.7023818792959519,
           0.7234961388944375,
           0.7446209186717194,
           0.7657357568022067,
           0.7868218481583504,
           0.8078618419708451,
           0.8288396676326524,
           0.849740384572694,
           0.8705500527043077,
           0.8912556204627161,
           0.911844827887548,
           0.9323061225863235,
           0.9526285867393961,
           0.97280187358295,
           0.9928161520408685,
           1.0126620583745756,
           1.0323306538876753,
           1.0518133878640252,
           1.0711020650377934,
           1.090188816995524,
           1.1090660769961436,
           1.127726557767685,
           1.1461632319013344,
           1.1643693145159504,
           1.1823382479109594,
           1.2000636879636712,
           1.2175394920596578,
           1.234759708372726,
           1.2517185663349062,
           1.2684104681574275,
           1.2848299812812998,
           1.3009718316513392,
           1.3168308977206435,
           1.3324022051038606,
           1.3476809218074792,
           1.3626623539739033,
           1.377341942083527,
           1.3917152575655036,
           1.4057779997735609,
           1.4195259932881654,
           1.4329551855106655,
           1.4460616445188559,
           1.4588415571567284,
           1.4712912273341314,
           1.4834070745146448,
           1.4951856323722617,
           1.5066235475995051,
           1.5177175788513886,
           1.5284645958112322,
           1.5388615783657493,
           1.5489056158780885,
           1.5585939065486316,
           1.567923756854354,
           1.5768925810584435,
           1.585497900782692,
           1.593737344635874,
           1.6016086478919969,
           1.6091096522128723,
           1.616238305409992,
           1.622992661241176,
           1.6293708792378738,
           1.6353712245594039,
           1.6409920678707735,
           1.646231885241034,
           1.6510892580594367,
           1.655562872966918,
           1.659651521800695,
           1.663354101549988,
           1.6666696143210917,
           1.6695971673102261,
           1.6721359727827751,
           1.6742853480577027,
           1.6760447154960922,
           1.6774136024929245,
           1.6783916414713402,
           1.6789785698787951
          ],
          [
           1.708785287772754,
           1.7085846352226353,
           1.7079827303353938,
           1.7069797313984303,
           1.7055759022176598,
           1.7037716121080715,
           1.7015673358809056,
           1.6989636538278279,
           1.6959612517026164,
           1.6925609207009913,
           1.6887635574393314,
           1.6845701639331756,
           1.6799818475765347,
           1.6749998211231742,
           1.6696254026712192,
           1.6638600156525638,
           1.6577051888287808,
           1.6511625562953975,
           1.6442338574966375,
           1.6369209372529483,
           1.629225745803886,
           1.621150338869212,
           1.6126968777313588,
           1.6038676293427514,
           1.5946649664618393,
           1.5850913678221146,
           1.5751494183388235,
           1.5648418093585912,
           1.5541713389577403,
           1.5431409122956923,
           1.5317535420305437,
           1.520012348804679,
           1.5079205618091538,
           1.4954815194365472,
           1.4826986700330884,
           1.4695755727620825,
           1.4561158985920555,
           1.4423234314246098,
           1.428202069378746,
           1.4137558262504322,
           1.3989888331684777,
           1.383905340470367,
           1.3685097198246752,
           1.3528064666300599,
           1.336800202724695,
           1.3204956794444314,
           1.3038977810730636,
           1.2870115287339186,
           1.2698420847787182,
           1.252394757737453,
           1.234675007901999,
           1.216688453626641,
           1.1984408784407912,
           1.1799382390833124,
           1.161186674584311,
           1.1421925165395412,
           1.1229623007451226,
           1.1035027803868027,
           1.0838209410092063,
           1.0639240175273699,
           1.0438195135864188,
           1.0235152236269334,
           1.0030192580749124,
           0.9823400721483667,
           0.9614864988598277,
           0.9404677868984358,
           0.9192936442003659,
           0.8979742881665947,
           0.8765205036677396,
           0.8549437101934595,
           0.8332560397665745,
           0.8114704275591791,
           0.7896007175309633,
           0.7676617858722022,
           0.7456696855910968,
           0.7236418162551561,
           0.701597123698503,
           0.6795563354612016,
           0.6575422388506001,
           0.6355800098191601,
           0.6136976023339489,
           0.5919262095362652,
           0.5703008096690096,
           0.5488608113064065,
           0.5276508135256205,
           0.5067214967379385,
           0.48613065799109095,
           0.4659443991305957,
           0.44623846490809965,
           0.42709970749174814,
           0.40862761912572393,
           0.3909358200409114,
           0.3741533082066993,
           0.35842516799117147,
           0.3439123017546822,
           0.33078961560085923,
           0.3192420118043222,
           0.3094576063059774,
           0.30161791213578837,
           0.29588538524615204,
           0.29238965885842294,
           0.2912147122272459,
           0.2923896588584253,
           0.2958853852461567,
           0.30161791213579536,
           0.3094576063059865,
           0.3192420118043332,
           0.33078961560087194,
           0.34391230175469645,
           0.358425167991187,
           0.3741533082067161,
           0.3909358200409291,
           0.4086276191257425,
           0.4270997074917675,
           0.4462384649081196,
           0.4659443991306162,
           0.48613065799111194,
           0.5067214967379601,
           0.5276508135256421,
           0.5488608113064285,
           0.5703008096690318,
           0.5919262095362875,
           0.6136976023339714,
           0.6355800098191826,
           0.6575422388506227,
           0.6795563354612243,
           0.7015971236985258,
           0.7236418162551786,
           0.7456696855911195,
           0.7676617858722248,
           0.7896007175309857,
           0.8114704275592014,
           0.8332560397665968,
           0.8549437101934819,
           0.8765205036677619,
           0.8979742881666167,
           0.9192936442003878,
           0.9404677868984576,
           0.9614864988598493,
           0.982340072148388,
           1.0030192580749338,
           1.0235152236269545,
           1.0438195135864394,
           1.0639240175273905,
           1.0838209410092268,
           1.1035027803868227,
           1.1229623007451424,
           1.1421925165395608,
           1.1611866745843304,
           1.1799382390833315,
           1.1984408784408103,
           1.2166884536266596,
           1.2346750079020175,
           1.252394757737471,
           1.269842084778736,
           1.287011528733936,
           1.3038977810730807,
           1.3204956794444482,
           1.3368002027247117,
           1.352806466630076,
           1.3685097198246912,
           1.3839053404703827,
           1.3989888331684932,
           1.4137558262504473,
           1.4282020693787607,
           1.442323431424624,
           1.4561158985920695,
           1.469575572762096,
           1.4826986700331017,
           1.4954815194365603,
           1.5079205618091664,
           1.5200123488046913,
           1.5317535420305555,
           1.5431409122957036,
           1.5541713389577514,
           1.564841809358602,
           1.575149418338834,
           1.585091367822125,
           1.5946649664618489,
           1.6038676293427605,
           1.6126968777313677,
           1.6211503388692203,
           1.629225745803894,
           1.636920937252956,
           1.6442338574966446,
           1.6511625562954042,
           1.6577051888287875,
           1.66386001565257,
           1.6696254026712245,
           1.6749998211231796,
           1.6799818475765391,
           1.68457016393318,
           1.688763557439335,
           1.692560920700995,
           1.69596125170262,
           1.6989636538278305,
           1.701567335880908,
           1.7037716121080735,
           1.705575902217661,
           1.7069797313984314,
           1.7079827303353943,
           1.7085846352226361
          ],
          [
           1.7386780767871457,
           1.7384725569786033,
           1.7378560506330987,
           1.7368287169868584,
           1.735390821419838,
           1.733542735435247,
           1.7312849366312055,
           1.7286180086648517,
           1.7255426412093173,
           1.722059629904099,
           1.7181698762994355,
           1.7138743877954328,
           1.709174277576776,
           1.7040707645440043,
           1.6985651732424376,
           1.692658933790004,
           1.686353581805348,
           1.67965075833777,
           1.6725522098007322,
           1.6650597879108335,
           1.657175449634397,
           1.6489012571440098,
           1.6402393777876392,
           1.631192084073194,
           1.6217617536717381,
           1.6119508694428726,
           1.6017620194862001,
           1.5911978972231904,
           1.5802613015142353,
           1.5689551368161994,
           1.5572824133863472,
           1.5452462475391848,
           1.5328498619634718,
           1.5200965861074844,
           1.506989856641524,
           1.493533218007709,
           1.4797303230682577,
           1.4655849338647913,
           1.4511009225027005,
           1.4362822721763175,
           1.4211330783525835,
           1.4056575501331199,
           1.389860011817138,
           1.3737449046905212,
           1.3573167890697377,
           1.3405803466330541,
           1.32354038307592,
           1.3062018311324626,
           1.2885697540108894,
           1.270649349297399,
           1.2524459533910854,
           1.2339650465415073,
           1.2152122585713105,
           1.1961933753788327,
           1.1769143463303056,
           1.1573812926685554,
           1.137600517085453,
           1.1175785146294224,
           1.0973219851478053,
           1.0768378474977347,
           1.056133255799497,
           1.0352156180545193,
           1.0140926175078513,
           0.9927722372043358,
           0.9712627882712417,
           0.9495729425611291,
           0.9277117704111707,
           0.9056887844240157,
           0.8835139903568381,
           0.861197946427218,
           0.8387518326167529,
           0.8161875318880385,
           0.7935177256431991,
           0.7707560062616634,
           0.7479170101852156,
           0.7250165757990535,
           0.7020719313248908,
           0.6791019191398775,
           0.6561272644151036,
           0.6331708977888328,
           0.6102583440157144,
           0.587418191224049,
           0.5646826586094434,
           0.5420882840853399,
           0.5196767574822397,
           0.4974959290126656,
           0.47560102618979677,
           0.4540561138227194,
           0.43293582859162394,
           0.4123274076772114,
           0.39233300283144096,
           0.37307221610445296,
           0.3546846956191704,
           0.3373324704505623,
           0.3212014669509931,
           0.3065013384078275,
           0.2934624110028237,
           0.2823283534887884,
           0.2733433922773581,
           0.26673385523746246,
           0.26268568838859196,
           0.26132192321285425,
           0.2626856883885948,
           0.266733855237468,
           0.2733433922773661,
           0.2823283534887987,
           0.29346241100283615,
           0.30650133840784183,
           0.32120146695100904,
           0.33733247045057957,
           0.35468469561918886,
           0.37307221610447233,
           0.3923330028314612,
           0.4123274076772322,
           0.4329358285916454,
           0.4540561138227413,
           0.47560102618981914,
           0.49749592901268824,
           0.5196767574822627,
           0.5420882840853631,
           0.5646826586094669,
           0.5874181912240726,
           0.610258344015738,
           0.6331708977888564,
           0.656127264415127,
           0.6791019191399011,
           0.7020719313249143,
           0.7250165757990771,
           0.7479170101852393,
           0.7707560062616868,
           0.7935177256432224,
           0.8161875318880617,
           0.8387518326167761,
           0.861197946427241,
           0.883513990356861,
           0.9056887844240383,
           0.9277117704111933,
           0.9495729425611515,
           0.9712627882712639,
           0.9927722372043579,
           1.014092617507873,
           1.0352156180545409,
           1.0561332557995182,
           1.076837847497756,
           1.0973219851478262,
           1.1175785146294432,
           1.1376005170854733,
           1.1573812926685754,
           1.1769143463303253,
           1.1961933753788525,
           1.2152122585713299,
           1.2339650465415262,
           1.252445953391104,
           1.2706493492974176,
           1.2885697540109076,
           1.3062018311324806,
           1.3235403830759378,
           1.3405803466330712,
           1.3573167890697548,
           1.3737449046905381,
           1.3898600118171545,
           1.4056575501331359,
           1.421133078352599,
           1.4362822721763329,
           1.4511009225027156,
           1.465584933864806,
           1.479730323068272,
           1.493533218007723,
           1.5069898566415376,
           1.520096586107498,
           1.5328498619634852,
           1.5452462475391975,
           1.5572824133863592,
           1.5689551368162111,
           1.5802613015142468,
           1.5911978972232013,
           1.601762019486211,
           1.6119508694428832,
           1.6217617536717484,
           1.6311920840732033,
           1.640239377787648,
           1.6489012571440183,
           1.657175449634405,
           1.6650597879108415,
           1.6725522098007397,
           1.679650758337777,
           1.6863535818053546,
           1.6926589337900106,
           1.6985651732424434,
           1.70407076454401,
           1.709174277576781,
           1.7138743877954374,
           1.71816987629944,
           1.7220596299041027,
           1.7255426412093209,
           1.7286180086648548,
           1.7312849366312084,
           1.733542735435249,
           1.7353908214198395,
           1.7368287169868593,
           1.7378560506330996,
           1.7384725569786041
          ],
          [
           1.768823677885037,
           1.7686134162648677,
           1.7679826848683293,
           1.766931644081184,
           1.7654605611925678,
           1.7635698103644257,
           1.7612598725889683,
           1.758531335634421,
           1.7553848939793926,
           1.751821348736289,
           1.747841607564263,
           1.7434466845722905,
           1.7386377002130564,
           1.7334158811684204,
           1.7277825602273496,
           1.7217391761573064,
           1.7152872735702116,
           1.7084285027842157,
           1.7011646196826746,
           1.6934974855718592,
           1.6854290670391043,
           1.6769614358132952,
           1.6680967686297696,
           1.658837347101961,
           1.6491855576023353,
           1.6391438911554537,
           1.6287149433462988,
           1.6179014142473267,
           1.606706108368095,
           1.5951319346317188,
           1.583181906382893,
           1.570859141432718,
           1.5581668621461848,
           1.545108395578803,
           1.5316871736696285,
           1.5179067334987744,
           1.5037707176184465,
           1.489282874467621,
           1.4744470588817098,
           1.4592672327099563,
           1.4437474655548885,
           1.4278919356499786,
           1.4117049308937302,
           1.3951908500608075,
           1.3783542042135575,
           1.3611996183404202,
           1.3437318332513943,
           1.3259557077649038,
           1.3078762212253308,
           1.2894984763961372,
           1.2708277027801307,
           1.2518692604261443,
           1.2326286442904717,
           1.2131114892319979,
           1.1933235757324996,
           1.173270836448334,
           1.1529593637172215,
           1.1323954181645814,
           1.111585438578577,
           1.0905360532525534,
           1.0692540930289134,
           1.047746606320995,
           1.026020876440803,
           1.0040844416225179,
           0.9819451182071164,
           0.9596110275453436,
           0.9370906272887426,
           0.9143927478765754,
           0.8915266351967428,
           0.8685020006095792,
           0.8453290797852597,
           0.8220187021322324,
           0.7985823730031862,
           0.7750323713794043,
           0.7513818663834202,
           0.7276450567919742,
           0.7038373387659189,
           0.6799755083451225,
           0.6560780069572989,
           0.632165220365891,
           0.6082598442675192,
           0.5843873333098775,
           0.5605764548347775,
           0.5368599743818097,
           0.5132755071380486,
           0.489866578244943,
           0.4666839451261408,
           0.44378724624257254,
           0.42124705134451595,
           0.3991473947693952,
           0.3775888682247264,
           0.3566923187013075,
           0.3366031156497392,
           0.31749577846374727,
           0.2995784320427041,
           0.28309602003778994,
           0.2683304293674694,
           0.25559480086060293,
           0.24521880127329798,
           0.23752246495673277,
           0.23277946464682847,
           0.231176322114963,
           0.23277946464683177,
           0.2375224649567392,
           0.24521880127330728,
           0.2555948008606148,
           0.26833042936748364,
           0.2830960200378061,
           0.2995784320427219,
           0.31749577846376636,
           0.3366031156497594,
           0.35669231870132856,
           0.3775888682247482,
           0.3991473947694177,
           0.42124705134453894,
           0.4437872462425959,
           0.4666839451261645,
           0.489866578244967,
           0.5132755071380728,
           0.536859974381834,
           0.560576454834802,
           0.5843873333099021,
           0.6082598442675438,
           0.6321652203659154,
           0.6560780069573234,
           0.679975508345147,
           0.7038373387659435,
           0.7276450567919986,
           0.7513818663834444,
           0.7750323713794288,
           0.7985823730032106,
           0.8220187021322565,
           0.8453290797852836,
           0.868502000609603,
           0.8915266351967664,
           0.9143927478765989,
           0.9370906272887658,
           0.9596110275453665,
           0.9819451182071394,
           1.0040844416225405,
           1.0260208764408254,
           1.0477466063210177,
           1.0692540930289351,
           1.090536053252575,
           1.1115854385785986,
           1.1323954181646028,
           1.1529593637172424,
           1.1732708364483546,
           1.1933235757325202,
           1.2131114892320178,
           1.2326286442904915,
           1.2518692604261639,
           1.2708277027801498,
           1.2894984763961563,
           1.3078762212253494,
           1.3259557077649222,
           1.3437318332514123,
           1.361199618340438,
           1.3783542042135748,
           1.3951908500608246,
           1.4117049308937468,
           1.4278919356499948,
           1.4437474655549047,
           1.459267232709972,
           1.474447058881725,
           1.4892828744676363,
           1.5037707176184614,
           1.5179067334987886,
           1.5316871736696422,
           1.5451083955788167,
           1.5581668621461984,
           1.570859141432731,
           1.5831819063829053,
           1.595131934631731,
           1.6067061083681067,
           1.617901414247338,
           1.62871494334631,
           1.6391438911554643,
           1.6491855576023455,
           1.6588373471019706,
           1.6680967686297792,
           1.676961435813304,
           1.685429067039113,
           1.6934974855718674,
           1.7011646196826824,
           1.7084285027842228,
           1.7152872735702183,
           1.7217391761573129,
           1.727782560227355,
           1.7334158811684262,
           1.7386377002130615,
           1.7434466845722953,
           1.7478416075642673,
           1.751821348736293,
           1.755384893979396,
           1.7585313356344237,
           1.761259872588971,
           1.763569810364428,
           1.7654605611925696,
           1.7669316440811849,
           1.7679826848683302,
           1.768613416264868
          ],
          [
           1.7991929271442884,
           1.7989780492112952,
           1.7983334693287212,
           1.7972593492378275,
           1.7957559584808982,
           1.7938236743616065,
           1.7914629818897365,
           1.7886744737104472,
           1.7854588500183495,
           1.7818169184567185,
           1.7777495940022263,
           1.7732578988356555,
           1.7683429621991196,
           1.763006020240395,
           1.7572484158450437,
           1.751071598457109,
           1.7444771238892354,
           1.7374666541231825,
           1.730041957101811,
           1.7222049065137204,
           1.7139574815718717,
           1.705301766787651,
           1.6962399517419933,
           1.6867743308553593,
           1.6769073031585426,
           1.6666413720664999,
           1.655979145157619,
           1.6449233339611211,
           1.633476753755547,
           1.6216423233816435,
           1.60942306507328,
           1.596822104310475,
           1.5838426696990324,
           1.5704880928818203,
           1.5567618084872927,
           1.5426673541215146,
           1.5282083704106855,
           1.5133886011020017,
           1.4982118932316433,
           1.4826821973697715,
           1.466803567953655,
           1.450580163721469,
           1.434016248260935,
           1.4171161906888483,
           1.3998844664796881,
           1.3823256584639942,
           1.3644444580200716,
           1.346245666485915,
           1.3277341968221295,
           1.308915075561126,
           1.2897934450831607,
           1.270374566265949,
           1.2506638215618524,
           1.230666718565177,
           1.210388894142201,
           1.1898361192085232,
           1.169014304252506,
           1.1479295057205237,
           1.1265879333999698,
           1.1049959589602665,
           1.0831601258413655,
           1.061087160714573,
           1.0387839867834092,
           1.0162577392444023,
           0.9935157832915462,
           0.9705657351264805,
           0.9474154865330282,
           0.9240732336943122,
           0.9005475110794057,
           0.8768472314123661,
           0.852981732969914,
           0.8289608357486017,
           0.8047949084159745,
           0.7804949484366512,
           0.7560726783749847,
           0.7315406621630366,
           0.7069124461425113,
           0.6822027310180144,
           0.6574275825992926,
           0.6326046915011108,
           0.6077536949997192,
           0.5828965782698535,
           0.5580581775899044,
           0.5332668152643985,
           0.508555105573518,
           0.48396098378076063,
           0.45952902701762494,
           0.4353121576581401,
           0.4113738472375535,
           0.3877909715758536,
           0.36465750206441583,
           0.34208924364823806,
           0.3202298216848459,
           0.2992580232609614,
           0.27939630758397865,
           0.26091963152212355,
           0.24416243547018726,
           0.22951951371345325,
           0.217433900696578,
           0.20836363091248816,
           0.20272308218560967,
           0.20080707285571164,
           0.2027230821856136,
           0.20836363091249577,
           0.21743390069658897,
           0.22951951371346707,
           0.24416243547020344,
           0.2609196315221418,
           0.27939630758399847,
           0.2992580232609824,
           0.32022982168486797,
           0.342089243648261,
           0.36465750206443936,
           0.38779097157587755,
           0.41137384723757797,
           0.43531215765816483,
           0.45952902701764997,
           0.4839609837807859,
           0.5085551055735436,
           0.5332668152644239,
           0.55805817758993,
           0.5828965782698791,
           0.6077536949997446,
           0.6326046915011362,
           0.6574275825993181,
           0.6822027310180397,
           0.7069124461425365,
           0.7315406621630618,
           0.7560726783750098,
           0.7804949484366763,
           0.8047949084159993,
           0.8289608357486264,
           0.8529817329699385,
           0.8768472314123906,
           0.9005475110794298,
           0.9240732336943361,
           0.9474154865330522,
           0.970565735126504,
           0.9935157832915695,
           1.0162577392444254,
           1.0387839867834323,
           1.061087160714596,
           1.083160125841388,
           1.104995958960289,
           1.1265879333999917,
           1.1479295057205454,
           1.1690143042525276,
           1.1898361192085447,
           1.210388894142222,
           1.2306667185651978,
           1.2506638215618728,
           1.2703745662659687,
           1.2897934450831803,
           1.3089150755611454,
           1.3277341968221488,
           1.346245666485934,
           1.36444445802009,
           1.3823256584640122,
           1.3998844664797059,
           1.4171161906888656,
           1.434016248260952,
           1.450580163721486,
           1.4668035679536715,
           1.4826821973697875,
           1.4982118932316588,
           1.513388601102017,
           1.5282083704107003,
           1.5426673541215292,
           1.5567618084873072,
           1.5704880928818343,
           1.5838426696990462,
           1.596822104310488,
           1.6094230650732924,
           1.621642323381656,
           1.6334767537555592,
           1.6449233339611324,
           1.6559791451576302,
           1.6666413720665108,
           1.6769073031585533,
           1.6867743308553693,
           1.6962399517420028,
           1.70530176678766,
           1.7139574815718803,
           1.7222049065137286,
           1.7300419571018189,
           1.7374666541231896,
           1.744477123889242,
           1.7510715984571157,
           1.7572484158450494,
           1.7630060202404008,
           1.768342962199125,
           1.7732578988356602,
           1.7777495940022308,
           1.7818169184567225,
           1.7854588500183532,
           1.78867447371045,
           1.7914629818897392,
           1.7938236743616087,
           1.7957559584808995,
           1.7972593492378286,
           1.7983334693287218,
           1.7989780492112961
          ],
          [
           1.8297564442776084,
           1.8295370752200042,
           1.8288790224853526,
           1.8277824493785917,
           1.8262476280428452,
           1.824274939411828,
           1.8218648731433733,
           1.8190180275342203,
           1.8157351094162615,
           1.812016934034499,
           1.8078644249069917,
           1.803278613667141,
           1.7982606398887075,
           1.7928117508940102,
           1.7869333015458229,
           1.7806267540235374,
           1.773893677584246,
           1.7667357483094492,
           1.7591547488382058,
           1.7511525680875912,
           1.7427312009614657,
           1.733892748048622,
           1.7246394153115228,
           1.714973513766955,
           1.7048974591600574,
           1.6944137716333552,
           1.6835250753925783,
           1.6722340983712563,
           1.6605436718962716,
           1.6484567303568076,
           1.635976310879381,
           1.6231055530119478,
           1.609847698420412,
           1.5962060906012316,
           1.5821841746142464,
           1.567785496840335,
           1.5530137047690484,
           1.5378725468219807,
           1.5223658722183524,
           1.506497630890071,
           1.4902718734544587,
           1.4736927512538807,
           1.4567645164727168,
           1.4394915223434952,
           1.4218782234556235,
           1.4039291761819743,
           1.3856490392407441,
           1.3670425744124755,
           1.3481146474350274,
           1.3288702291026666,
           1.3093143965993863,
           1.2894523351012233,
           1.2692893396877798,
           1.2488308176096332,
           1.228082290965929,
           1.2070493998555385,
           1.185737906075966,
           1.1641536974571245,
           1.1423027929326008,
           1.1201913484697272,
           1.0978256640023412,
           1.0752121915375368,
           1.0523575446410873,
           1.0292685095470813,
           1.005952058187511,
           0.9824153634995385,
           0.9586658174450154,
           0.9347110522726542,
           0.9105589656732556,
           0.886217750629561,
           0.8616959309537192,
           0.8370024037491824,
           0.8121464903462684,
           0.7871379976634759,
           0.7619872924694291,
           0.7367053917033822,
           0.7113040729109102,
           0.6857960100423461,
           0.6601949414515732,
           0.6345158790718725,
           0.6087753706457103,
           0.5829918308482815,
           0.5571859626019476,
           0.5313812974507247,
           0.5056048944441466,
           0.47988825185356104,
           0.4542685070484503,
           0.42879002957971685,
           0.40350655446570244,
           0.37848406131234397,
           0.353804685004515,
           0.3295720479593858,
           0.3059185257754867,
           0.283015063333298,
           0.2610841418890634,
           0.24041609273655937,
           0.22138757660358271,
           0.20447766310362459,
           0.19027041647096177,
           0.17942417549889914,
           0.17258506318876615,
           0.17024355572239155,
           0.17258506318877093,
           0.17942417549890832,
           0.19027041647097476,
           0.20447766310364068,
           0.22138757660360128,
           0.24041609273657988,
           0.26108414188908535,
           0.28301506333332105,
           0.30591852577551076,
           0.3295720479594104,
           0.3538046850045402,
           0.37848406131236956,
           0.4035065544657283,
           0.42879002957974294,
           0.4542685070484766,
           0.4798882518535874,
           0.5056048944441731,
           0.5313812974507512,
           0.5571859626019743,
           0.5829918308483081,
           0.6087753706457365,
           0.6345158790718989,
           0.6601949414515995,
           0.6857960100423726,
           0.7113040729109364,
           0.7367053917034083,
           0.7619872924694551,
           0.7871379976635018,
           0.8121464903462939,
           0.8370024037492079,
           0.8616959309537447,
           0.8862177506295861,
           0.9105589656732804,
           0.9347110522726788,
           0.95866581744504,
           0.9824153634995628,
           1.0059520581875352,
           1.0292685095471052,
           1.052357544641111,
           1.07521219153756,
           1.0978256640023645,
           1.12019134846975,
           1.1423027929326235,
           1.164153697457147,
           1.1857379060759883,
           1.2070493998555603,
           1.2280822909659506,
           1.248830817609654,
           1.2692893396878007,
           1.2894523351012437,
           1.3093143965994067,
           1.3288702291026864,
           1.3481146474350472,
           1.3670425744124948,
           1.3856490392407632,
           1.4039291761819928,
           1.4218782234556415,
           1.4394915223435132,
           1.4567645164727343,
           1.4736927512538982,
           1.4902718734544753,
           1.5064976308900875,
           1.5223658722183686,
           1.5378725468219965,
           1.5530137047690638,
           1.56778549684035,
           1.5821841746142609,
           1.596206090601246,
           1.6098476984204262,
           1.6231055530119611,
           1.6359763108793939,
           1.6484567303568205,
           1.6605436718962838,
           1.6722340983712682,
           1.6835250753925897,
           1.6944137716333663,
           1.7048974591600683,
           1.7149735137669653,
           1.7246394153115328,
           1.733892748048631,
           1.7427312009614746,
           1.7511525680875997,
           1.7591547488382135,
           1.766735748309457,
           1.7738936775842529,
           1.7806267540235443,
           1.7869333015458289,
           1.7928117508940162,
           1.7982606398887129,
           1.803278613667146,
           1.8078644249069962,
           1.8120169340345031,
           1.815735109416265,
           1.8190180275342236,
           1.8218648731433764,
           1.82427493941183,
           1.8262476280428466,
           1.8277824493785928,
           1.8288790224853535,
           1.829537075220005
          ],
          [
           1.8604846610560841,
           1.8602609254319462,
           1.8595897735885951,
           1.8584713706023206,
           1.8569059915639674,
           1.8548940215245266,
           1.8524359554190786,
           1.8495323979691858,
           1.8461840635638809,
           1.842391776119428,
           1.838156468918058,
           1.8334791844259333,
           1.8283610740906138,
           1.8228033981183556,
           1.8168075252316038,
           1.810374932407092,
           1.8035072045950018,
           1.7962060344197004,
           1.7884732218626198,
           1.7803106739279033,
           1.771720404291516,
           1.7627045329345852,
           1.7532652857618145,
           1.743404994205906,
           1.733126094819019,
           1.7224311288523948,
           1.7113227418254062,
           1.699803683085407,
           1.687876805359911,
           1.6755450643027898,
           1.6628115180363574,
           1.6496793266914147,
           1.636151751947552,
           1.6222321565762738,
           1.6079240039897849,
           1.5932308577986172,
           1.578156381381646,
           1.562704337472457,
           1.5468785877665239,
           1.5306830925541846,
           1.514121910385046,
           1.4971991977701622,
           1.4799192089291489,
           1.4622862955903595,
           1.4443049068533371,
           1.4259795891240286,
           1.4073149861347187,
           1.3883158390623582,
           1.368986986760947,
           1.3493333661259814,
           1.3293600126116976,
           1.309072060925069,
           1.2884747459243076,
           1.2675734037541035,
           1.246373473255172,
           1.224880497692006,
           1.2031001268503165,
           1.1810381195647135,
           1.1587003467481163,
           1.136092795007566,
           1.1132215709471156,
           1.0900929062779559,
           1.066713163879747,
           1.043088844986383,
           1.0192265977055108,
           0.9951332271258819,
           0.9708157073223864,
           0.9462811956385072,
           0.921537049713942,
           0.8965908478367048,
           0.8714504133411989,
           0.8461238439561963,
           0.8206195472422931,
           0.7949462835648758,
           0.7691132184502305,
           0.7431299867027039,
           0.717006771366807,
           0.6907544015661182,
           0.664384474535261,
           0.6379095089181023,
           0.611343138832405,
           0.5847003615893345,
           0.5579978567377899,
           0.5312544009285324,
           0.5044914129495652,
           0.47773367769031944,
           0.45101031910324685,
           0.42435612413091334,
           0.39781336784197374,
           0.37143436375194916,
           0.3452850765706691,
           0.3194503084992961,
           0.29404123369537816,
           0.26920643987162796,
           0.2451481443697971,
           0.22214575147008286,
           0.20058881508741594,
           0.18101890044811622,
           0.16417024236181552,
           0.1509754211463707,
           0.14246751607536998,
           0.1395153389439158,
           0.14246751607537597,
           0.15097542114638204,
           0.16417024236183111,
           0.18101890044813504,
           0.20058881508743717,
           0.22214575147010587,
           0.24514814436982135,
           0.2692064398716531,
           0.294041233695404,
           0.31945030849932243,
           0.34528507657069585,
           0.37143436375197614,
           0.3978133678420009,
           0.4243561241309407,
           0.45101031910327427,
           0.47773367769034697,
           0.5044914129495929,
           0.5312544009285598,
           0.5579978567378174,
           0.5847003615893618,
           0.6113431388324322,
           0.6379095089181294,
           0.6643844745352881,
           0.6907544015661453,
           0.7170067713668341,
           0.7431299867027308,
           0.7691132184502572,
           0.7949462835649022,
           0.8206195472423194,
           0.8461238439562225,
           0.8714504133412247,
           0.8965908478367307,
           0.9215370497139674,
           0.9462811956385325,
           0.9708157073224116,
           0.9951332271259068,
           1.0192265977055357,
           1.0430888449864073,
           1.066713163879771,
           1.0900929062779798,
           1.1132215709471394,
           1.1360927950075894,
           1.1587003467481394,
           1.1810381195647361,
           1.2031001268503387,
           1.2248804976920282,
           1.2463734732551937,
           1.2675734037541249,
           1.2884747459243289,
           1.3090720609250903,
           1.3293600126117182,
           1.3493333661260016,
           1.368986986760967,
           1.388315839062378,
           1.4073149861347383,
           1.4259795891240474,
           1.4443049068533558,
           1.4622862955903777,
           1.4799192089291666,
           1.4971991977701797,
           1.5141219103850632,
           1.5306830925542012,
           1.5468785877665403,
           1.5627043374724732,
           1.5781563813816617,
           1.5932308577986325,
           1.6079240039897995,
           1.622232156576288,
           1.6361517519475661,
           1.649679326691428,
           1.6628115180363707,
           1.6755450643028025,
           1.6878768053599236,
           1.699803683085419,
           1.7113227418254182,
           1.7224311288524063,
           1.7331260948190295,
           1.7434049942059164,
           1.753265285761824,
           1.7627045329345945,
           1.7717204042915253,
           1.7803106739279118,
           1.788473221862628,
           1.7962060344197077,
           1.8035072045950085,
           1.8103749324070988,
           1.81680752523161,
           1.8228033981183613,
           1.828361074090619,
           1.8334791844259384,
           1.8381564689180627,
           1.8423917761194322,
           1.8461840635638849,
           1.8495323979691891,
           1.8524359554190815,
           1.8548940215245286,
           1.8569059915639687,
           1.858471370602322,
           1.859589773588596,
           1.860260925431947
          ],
          [
           1.8913478499145329,
           1.8911198713720723,
           1.8904359914328355,
           1.88929637714924,
           1.887701306901918,
           1.8856511703396643,
           1.883146468295431,
           1.8801878126784557,
           1.876775926342604,
           1.8729116429310653,
           1.8685959066975297,
           1.863829772304019,
           1.8586144045955646,
           1.8529510783519556,
           1.8468411780167941,
           1.8402861974041478,
           1.8332877393831026,
           1.8258475155405562,
           1.8179673458226422,
           1.809649158155192,
           1.8008949880437055,
           1.7917069781533348,
           1.7820873778694377,
           1.772038542839321,
           1.7615629344958401,
           1.7506631195636027,
           1.7393417695485849,
           1.7276016602120627,
           1.7154456710298371,
           1.70287678463785,
           1.6898980862653794,
           1.676512763157148,
           1.6627241039858096,
           1.6485354982564349,
           1.6339504357048036,
           1.6189725056915116,
           1.603605396594121,
           1.587852895199857,
           1.5717188861016334,
           1.5552073511005413,
           1.5383223686183125,
           1.5210681131237123,
           1.5034488545773272,
           1.4854689578997953,
           1.4671328824692056,
           1.448445181654169,
           1.4294105023899795,
           1.4100335848063354,
           1.3903192619163185,
           1.3702724593777855,
           1.3498981953400064,
           1.329201580390381,
           1.3081878176184212,
           1.2868622028169745,
           1.26523012484397,
           1.2432970661719263,
           1.2210686036571878,
           1.1985504095665285,
           1.1757482529056078,
           1.1526680011020591,
           1.129315622106045,
           1.1056971869834156,
           1.0818188730916707,
           1.057686967947481,
           1.033307873917511,
           1.008688113892846,
           0.9838343381430862,
           0.9587533325911199,
           0.9334520288064646,
           0.9079375160874691,
           0.8822170560954273,
           0.8562981006233209,
           0.8301883132373978,
           0.803895595733358,
           0.7774281206176071,
           0.750794371181682,
           0.7240031912183369,
           0.697063847079237,
           0.669986105666676,
           0.6427803331877345,
           0.6154576212308607,
           0.5880299491807931,
           0.5605103955170775,
           0.532913415685029,
           0.5052552118374298,
           0.4775542311843775,
           0.4498318471810215,
           0.4221133050213526,
           0.394429056141703,
           0.3668166764534911,
           0.3393236787606508,
           0.3120117250485135,
           0.28496307983275804,
           0.2582907303705947,
           0.23215462121163874,
           0.20678819608710633,
           0.18254216743309326,
           0.15995547822850043,
           0.1398612826527609,
           0.12350603786807961,
           0.1125504828785645,
           0.10865215008546714,
           0.11255048287857237,
           0.12350603786809393,
           0.13986128265277983,
           0.15995547822852252,
           0.18254216743311746,
           0.20678819608713195,
           0.23215462121166525,
           0.2582907303706219,
           0.2849630798327857,
           0.31201172504854147,
           0.339323678760679,
           0.3668166764535195,
           0.39442905614173135,
           0.4221133050213811,
           0.44983184718104996,
           0.477554231184406,
           0.5052552118374583,
           0.5329134156850575,
           0.560510395517106,
           0.5880299491808214,
           0.6154576212308888,
           0.6427803331877625,
           0.6699861056667038,
           0.6970638470792646,
           0.7240031912183644,
           0.7507943711817094,
           0.7774281206176343,
           0.8038955957333851,
           0.8301883132374247,
           0.8562981006233477,
           0.8822170560954538,
           0.9079375160874956,
           0.9334520288064907,
           0.9587533325911457,
           0.983834338143112,
           1.0086881138928714,
           1.033307873917536,
           1.0576869679475058,
           1.0818188730916953,
           1.1056971869834402,
           1.1293156221060692,
           1.152668001102083,
           1.1757482529056316,
           1.1985504095665518,
           1.2210686036572111,
           1.2432970661719491,
           1.2652301248439923,
           1.2868622028169967,
           1.3081878176184432,
           1.3292015803904023,
           1.3498981953400273,
           1.3702724593778062,
           1.3903192619163387,
           1.4100335848063557,
           1.4294105023899994,
           1.4484451816541881,
           1.4671328824692247,
           1.4854689578998141,
           1.5034488545773455,
           1.5210681131237302,
           1.53832236861833,
           1.5552073511005584,
           1.57171888610165,
           1.5878528951998736,
           1.603605396594137,
           1.618972505691527,
           1.633950435704819,
           1.6485354982564495,
           1.6627241039858245,
           1.6765127631571621,
           1.6898980862653925,
           1.7028767846378634,
           1.71544567102985,
           1.7276016602120747,
           1.7393417695485969,
           1.7506631195636142,
           1.7615629344958514,
           1.7720385428393315,
           1.782087377869448,
           1.7917069781533446,
           1.8008949880437148,
           1.8096491581552006,
           1.8179673458226502,
           1.8258475155405638,
           1.8332877393831095,
           1.8402861974041549,
           1.8468411780168004,
           1.8529510783519616,
           1.8586144045955701,
           1.863829772304024,
           1.8685959066975342,
           1.8729116429310695,
           1.8767759263426078,
           1.880187812678459,
           1.8831464682954344,
           1.8856511703396663,
           1.8877013069019197,
           1.889296377149241,
           1.8904359914328366,
           1.8911198713720725
          ],
          [
           1.9223161527110013,
           1.922084053745497,
           1.9213878132627347,
           1.920227600491053,
           1.9186036974346452,
           1.9165164988090209,
           1.9139665119507128,
           1.9109543567012592,
           1.9074807652655374,
           1.90354658204453,
           1.899152763442606,
           1.8943003776494334,
           1.888990604396654,
           1.88322473468945,
           1.8770041705131741,
           1.870330424515217,
           1.8632051196623074,
           1.8556299888734686,
           1.847606874628867,
           1.8391377285548176,
           1.8302246109852365,
           1.820869690499848,
           1.8110752434395005,
           1.8008436533989571,
           1.790177410697572,
           1.779079111828303,
           1.7675514588855354,
           1.7555972589722642,
           1.7432194235871967,
           1.7304209679924243,
           1.7172050105623486,
           1.7035747721146306,
           1.6895335752239913,
           1.6750848435197938,
           1.6602321009684131,
           1.644978971141521,
           1.6293291764715214,
           1.6132865374955176,
           1.5968549720893375,
           1.5800384946933246,
           1.5628412155318028,
           1.5452673398283459,
           1.5273211670192561,
           1.5090070899679453,
           1.4903295941832795,
           1.4712932570453308,
           1.45190274704247,
           1.4321628230242662,
           1.4120783334752995,
           1.391654215815744,
           1.3708954957354462,
           1.349807286569265,
           1.3283947887226462,
           1.3066632891578598,
           1.284618160953044,
           1.262264862948243,
           1.2396089394950973,
           1.2166560203297885,
           1.19341182059241,
           1.1698821410202636,
           1.1460728683478398,
           1.1219899759526801,
           1.0976395247942157,
           1.0730276647024437,
           1.0481606360853963,
           1.0230447721394471,
           0.9976865016654296,
           0.9720923526173988,
           0.9462689565411563,
           0.9202230540983304,
           0.8939615019215347,
           0.8674912811105284,
           0.8408195077633394,
           0.8139534460468516,
           0.7869005244580134,
           0.7596683561231438,
           0.7322647642481797,
           0.704697814195107,
           0.6769758541601936,
           0.649107567128732,
           0.6211020377701366,
           0.5929688393559723,
           0.564718147848513,
           0.5363608933613458,
           0.5079089637884748,
           0.4793754824429374,
           0.45077519256937953,
           0.4221249992352799,
           0.39344474803596774,
           0.3647583687928208,
           0.33609559702627756,
           0.3074946376956036,
           0.27900641764988904,
           0.25070161795496776,
           0.2226827737112088,
           0.1951060281858607,
           0.16822211773739454,
           0.14245709281517907,
           0.11857543344055704,
           0.09799511288167106,
           0.08322896995952223,
           0.07768384728899864,
           0.08322896995953323,
           0.09799511288168976,
           0.1185754334405802,
           0.14245709281520474,
           0.1682221177374217,
           0.19510602818588874,
           0.22268277371123743,
           0.25070161795499674,
           0.27900641764991824,
           0.30749463769563296,
           0.3360955970263071,
           0.36475836879285034,
           0.39344474803599716,
           0.4221249992353094,
           0.4507751925694089,
           0.4793754824429667,
           0.5079089637885041,
           0.5363608933613752,
           0.5647181478485422,
           0.5929688393560012,
           0.6211020377701655,
           0.6491075671287606,
           0.676975854160222,
           0.7046978141951354,
           0.7322647642482079,
           0.7596683561231717,
           0.7869005244580412,
           0.8139534460468794,
           0.8408195077633669,
           0.8674912811105557,
           0.8939615019215618,
           0.9202230540983573,
           0.9462689565411829,
           0.9720923526174252,
           0.9976865016654558,
           1.0230447721394729,
           1.0481606360854219,
           1.0730276647024692,
           1.0976395247942408,
           1.121989975952705,
           1.1460728683478645,
           1.1698821410202878,
           1.193411820592434,
           1.2166560203298122,
           1.2396089394951206,
           1.262264862948266,
           1.284618160953067,
           1.3066632891578824,
           1.3283947887226681,
           1.349807286569287,
           1.3708954957354673,
           1.391654215815765,
           1.4120783334753204,
           1.4321628230242869,
           1.45190274704249,
           1.47129325704535,
           1.490329594183299,
           1.5090070899679644,
           1.5273211670192743,
           1.545267339828364,
           1.5628412155318203,
           1.5800384946933423,
           1.5968549720893546,
           1.6132865374955345,
           1.6293291764715379,
           1.6449789711415366,
           1.6602321009684287,
           1.675084843519809,
           1.6895335752240062,
           1.703574772114645,
           1.7172050105623624,
           1.7304209679924376,
           1.7432194235872098,
           1.7555972589722766,
           1.7675514588855477,
           1.779079111828315,
           1.7901774106975836,
           1.8008436533989678,
           1.811075243439511,
           1.8208696904998574,
           1.8302246109852458,
           1.8391377285548267,
           1.8476068746288752,
           1.8556299888734766,
           1.8632051196623152,
           1.8703304245152241,
           1.8770041705131806,
           1.8832247346894564,
           1.8889906043966596,
           1.894300377649439,
           1.8991527634426109,
           1.9035465820445348,
           1.9074807652655412,
           1.9109543567012623,
           1.913966511950716,
           1.9165164988090233,
           1.9186036974346468,
           1.9202276004910546,
           1.9213878132627358,
           1.9220840537454977
          ],
          [
           1.9533596096125903,
           1.9531235113569507,
           1.9524152737936546,
           1.951235068519992,
           1.9495831814861981,
           1.9474600129275967,
           1.944866077269632,
           1.9418020030058256,
           1.938268532548698,
           1.934266522053705,
           1.929796941216255,
           1.9248608730418764,
           1.919459513589615,
           1.913594171688756,
           1.9072662686289712,
           1.9004773378240092,
           1.8932290244490406,
           1.8855230850518137,
           1.8773613871377495,
           1.8687459087291491,
           1.8596787378986814,
           1.8501620722773373,
           1.8401982185370604,
           1.8297895918482596,
           1.818938715312445,
           1.8076482193702357,
           1.7959208411850056,
           1.783759424002463,
           1.7711669164864656,
           1.758146372031416,
           1.7447009480515845,
           1.7308339052477604,
           1.7165486068516416,
           1.7018485178484155,
           1.6867372041780249,
           1.671218331915646,
           1.6552956664319647,
           1.6389730715338724,
           1.6222545085862785,
           1.6051440356157927,
           1.5876458063971115,
           1.5697640695230255,
           1.5515031674590634,
           1.5328675355839008,
           1.5138617012167943,
           1.4944902826334427,
           1.4747579880718564,
           1.4546696147300147,
           1.4342300477573178,
           1.4134442592421217,
           1.3923173071979547,
           1.3708543345513946,
           1.3490605681350265,
           1.326941317689427,
           1.304501974878743,
           1.281748012325184,
           1.2586849826686277,
           1.2353185176586257,
           1.2116543272873865,
           1.1876981989738826,
           1.1634559968111478,
           1.1389336608911766,
           1.1141372067247193,
           1.0890727247768188,
           1.0637463801433764,
           1.0381644123995346,
           1.012333135657625,
           0.9862589388811717,
           0.9599482865125939,
           0.9334077194865077,
           0.9066438567188898,
           0.8796633971862303,
           0.8524731227399998,
           0.8250799018429315,
           0.7974906944684178,
           0.7697125584779424,
           0.7417526578913863,
           0.7136182736020933,
           0.6853168172787685,
           0.6568558494634507,
           0.628243103255222,
           0.5994865155188154,
           0.5705942683635976,
           0.5415748448419198,
           0.5124371046460406,
           0.4831903884237157,
           0.4538446638429222,
           0.4244107338786899,
           0.3949005400859227,
           0.3653276148495324,
           0.33570777458050577,
           0.30606021654850457,
           0.2764093199289719,
           0.2467877351345683,
           0.21724196556811293,
           0.18784310465696927,
           0.15870913183991997,
           0.13005579167223102,
           0.10232691659148421,
           0.0765747291120776,
           0.05565644496403768,
           0.04664039038740978,
           0.05565644496405471,
           0.07657472911210234,
           0.10232691659151197,
           0.1300557916722601,
           0.15870913183994975,
           0.18784310465699938,
           0.21724196556814324,
           0.24678773513459876,
           0.2764093199290024,
           0.30606021654853505,
           0.3357077745805363,
           0.3653276148495628,
           0.394900540085953,
           0.42441073387872014,
           0.45384466384295236,
           0.4831903884237459,
           0.5124371046460707,
           0.5415748448419496,
           0.5705942683636275,
           0.5994865155188449,
           0.6282431032552515,
           0.6568558494634799,
           0.6853168172787976,
           0.7136182736021224,
           0.7417526578914151,
           0.769712558477971,
           0.7974906944684461,
           0.8250799018429597,
           0.8524731227400278,
           0.8796633971862581,
           0.9066438567189173,
           0.9334077194865351,
           0.9599482865126211,
           0.9862589388811986,
           1.012333135657652,
           1.038164412399561,
           1.0637463801434026,
           1.0890727247768448,
           1.1141372067247448,
           1.138933660891202,
           1.1634559968111728,
           1.1876981989739075,
           1.2116543272874112,
           1.2353185176586496,
           1.2586849826686515,
           1.2817480123252076,
           1.3045019748787665,
           1.3269413176894496,
           1.3490605681350492,
           1.3708543345514168,
           1.3923173071979766,
           1.4134442592421432,
           1.4342300477573389,
           1.4546696147300355,
           1.474757988071877,
           1.4944902826334625,
           1.513861701216814,
           1.53286753558392,
           1.551503167459082,
           1.5697640695230441,
           1.5876458063971295,
           1.6051440356158104,
           1.6222545085862958,
           1.6389730715338895,
           1.6552956664319811,
           1.671218331915662,
           1.6867372041780406,
           1.7018485178484313,
           1.7165486068516567,
           1.7308339052477746,
           1.744700948051598,
           1.7581463720314294,
           1.7711669164864792,
           1.783759424002476,
           1.795920841185018,
           1.8076482193702477,
           1.8189387153124565,
           1.8297895918482703,
           1.8401982185370709,
           1.8501620722773469,
           1.859678737898691,
           1.8687459087291587,
           1.8773613871377581,
           1.8855230850518216,
           1.8932290244490482,
           1.900477337824016,
           1.9072662686289779,
           1.9135941716887623,
           1.9194595135896209,
           1.9248608730418817,
           1.9297969412162599,
           1.9342665220537092,
           1.9382685325487021,
           1.9418020030058294,
           1.9448660772696351,
           1.9474600129275992,
           1.9495831814862004,
           1.9512350685199933,
           1.9524152737936553,
           1.9531235113569514
          ],
          [
           1.984448188079657,
           1.984208210125703,
           1.9834883343188423,
           1.9822887348100686,
           1.9806097018043312,
           1.9784516414904794,
           1.9758150759432274,
           1.9727006429971317,
           1.96910909609264,
           1.96504130409424,
           1.9604982510807496,
           1.9554810361078139,
           1.9499908729426565,
           1.9440290897711627,
           1.9375971288773617,
           1.9306965462953927,
           1.9233290114340484,
           1.9154963066739787,
           1.9072003269376776,
           1.8984430792323401,
           1.8892266821657335,
           1.879553365435184,
           1.8694254692898258,
           1.8588454439662498,
           1.8478158490977,
           1.8363393530969647,
           1.8244187325131433,
           1.8120568713624399,
           1.7992567604331753,
           1.7860214965652033,
           1.772354281903919,
           1.7582584231290745,
           1.7437373306586041,
           1.7287945178276924,
           1.7134336000433041,
           1.6976582939144287,
           1.6814724163582873,
           1.6648798836827627,
           1.6478847106453323,
           1.6304910094887877,
           1.6127029889540438,
           1.594524953270353,
           1.5759613011232514,
           1.5570165246005927,
           1.5376952081170343,
           1.5180020273173593,
           1.4979417479590564,
           1.477519224774593,
           1.4567394003138456,
           1.435607303767206,
           1.4141280497698905,
           1.3923068371880583,
           1.370148947887368,
           1.3476597454846921,
           1.324844674083756,
           1.301709256995576,
           1.2782590954446582,
           1.254499867262057,
           1.2304373255665237,
           1.206077297435168,
           1.1814256825652587,
           1.1564884519290723,
           1.1312716464239896,
           1.105781375520478,
           1.0800238159110571,
           1.0540052101639883,
           1.0277318653861824,
           1.0012101519008159,
           0.974446501946376,
           0.9474474084054578,
           0.9202194235736794,
           0.892769157981758,
           0.8651032792872801,
           0.8372285112573088,
           0.8091516328691315,
           0.780879477564721,
           0.7524189327057356,
           0.7237769392913571,
           0.6949604920227721,
           0.6659766398284065,
           0.6368324870072932,
           0.6075351952106766,
           0.5780919865743277,
           0.548510148452551,
           0.5187970404165477,
           0.4889601045103276,
           0.45900688028576075,
           0.42894502700559567,
           0.39878235686917146,
           0.3685268856772386,
           0.33818691200184,
           0.3077711447422449,
           0.2772889165297433,
           0.2467505576728371,
           0.2161680900256445,
           0.18555661050496494,
           0.15493731735854227,
           0.12434500048331583,
           0.09385010320576291,
           0.06364352007629748,
           0.0345579064237627,
           0.015551811920342959,
           0.03455790642379102,
           0.06364352007632823,
           0.09385010320579418,
           0.12434500048334725,
           0.15493731735857375,
           0.1855566105049964,
           0.21616809002567594,
           0.24675055767286846,
           0.2772889165297747,
           0.3077711447422761,
           0.33818691200187123,
           0.3685268856772697,
           0.39878235686920255,
           0.42894502700562653,
           0.45900688028579156,
           0.48896010451035843,
           0.5187970404165784,
           0.5485101484525814,
           0.5780919865743581,
           0.6075351952107068,
           0.6368324870073231,
           0.6659766398284364,
           0.6949604920228019,
           0.7237769392913866,
           0.7524189327057648,
           0.7808794775647503,
           0.8091516328691605,
           0.8372285112573374,
           0.8651032792873088,
           0.8927691579817865,
           0.9202194235737075,
           0.9474474084054857,
           0.9744465019464037,
           1.0012101519008432,
           1.0277318653862098,
           1.0540052101640152,
           1.080023815911084,
           1.1057813755205042,
           1.1312716464240158,
           1.156488451929098,
           1.1814256825652842,
           1.206077297435193,
           1.2304373255665488,
           1.2544998672620817,
           1.2782590954446826,
           1.3017092569955997,
           1.3248446740837798,
           1.3476597454847152,
           1.370148947887391,
           1.3923068371880807,
           1.4141280497699127,
           1.4356073037672277,
           1.456739400313867,
           1.477519224774614,
           1.4979417479590773,
           1.5180020273173793,
           1.5376952081170545,
           1.5570165246006125,
           1.5759613011232703,
           1.5945249532703716,
           1.6127029889540623,
           1.6304910094888057,
           1.6478847106453498,
           1.6648798836827798,
           1.6814724163583041,
           1.697658293914445,
           1.71343360004332,
           1.7287945178277078,
           1.7437373306586195,
           1.758258423129089,
           1.7723542819039333,
           1.786021496565217,
           1.799256760433189,
           1.8120568713624527,
           1.8244187325131562,
           1.836339353096977,
           1.847815849097711,
           1.858845443966261,
           1.869425469289836,
           1.8795533654351941,
           1.889226682165743,
           1.898443079232349,
           1.9072003269376858,
           1.9154963066739872,
           1.9233290114340562,
           1.9306965462954004,
           1.9375971288773681,
           1.9440290897711694,
           1.949990872942662,
           1.955481036107819,
           1.9604982510807545,
           1.9650413040942447,
           1.9691090960926443,
           1.9727006429971352,
           1.9758150759432307,
           1.9784516414904822,
           1.9806097018043327,
           1.9822887348100704,
           1.983488334318843,
           1.9842082101257037
          ],
          [
           2.015551811920359,
           2.01530807216807,
           2.01457691187592,
           2.0133585079238236,
           2.011653155064198,
           2.009461265850807,
           2.0067833705391784,
           2.003620116958603,
           1.9999722703557572,
           1.9958407132099947,
           1.9912264450203332,
           1.9861305820642159,
           1.980554357128086,
           1.9744991192098615,
           1.9679663331933719,
           1.9609575794948437,
           1.953474553681534,
           1.9455190660625934,
           1.9370930412522762,
           1.928198517705603,
           1.918837647226601,
           1.9090126944492405,
           1.8987260362912115,
           1.8879801613806755,
           1.8767776694561464,
           1.8651212707396543,
           1.8530137852833628,
           1.8404581422898028,
           1.827457379405921,
           1.8140146419911116,
           1.8001331823594484,
           1.7858163589963103,
           1.771067635749623,
           1.7558905809959402,
           1.7402888667815963,
           1.7242662679391776,
           1.707826661179566,
           1.690974024159822,
           1.6737124345271803,
           1.656046068939457,
           1.6379792020621606,
           1.619516205542635,
           1.6006615469615613,
           1.5814197887621726,
           1.5617955871575535,
           1.5417936910164094,
           1.5214189407277265,
           1.500676267044762,
           1.4795706899088326,
           1.4581073172534105,
           1.4362913437890732,
           1.4141280497698903,
           1.3916227997418977,
           1.3687810412743588,
           1.3456083036745923,
           1.322110196687227,
           1.2982924091788464,
           1.2741607078091088,
           1.249720935689573,
           1.2249790110316334,
           1.199940925785183,
           1.1746127442698822,
           1.14900060180123,
           1.123110703314022,
           1.096949321986279,
           1.0705227978673202,
           1.043837536514433,
           1.016900007643548,
           0.9897167438005483,
           0.9622943390614236,
           0.9346394477714836,
           0.9067587833364877,
           0.8786591170819784,
           0.8503472772016545,
           0.8218301478216721,
           0.79311466821592,
           0.7642078322183837,
           0.7351166878939576,
           0.7058483375502316,
           0.6764099382026356,
           0.6468087026479155,
           0.6170519013626908,
           0.5871468655348042,
           0.5571009916715634,
           0.5269217484374376,
           0.4966166866992735,
           0.4661934542774682,
           0.4356598177556318,
           0.4050236951450074,
           0.3742932057229879,
           0.3434767479447449,
           0.3125831250101714,
           0.2816217549886015,
           0.2506030390826852,
           0.21953904506542016,
           0.18844487023226536,
           0.15734162333824564,
           0.12626380760020947,
           0.09528107871030649,
           0.06458197524022186,
           0.0349905650663745,
           0.015551811920358946,
           0.03499056506640336,
           0.06458197524025314,
           0.09528107871033827,
           0.12626380760024136,
           0.15734162333827767,
           0.1884448702322973,
           0.21953904506545208,
           0.2506030390827171,
           0.28162175498863334,
           0.31258312501020313,
           0.3434767479447767,
           0.3742932057230195,
           0.405023695145039,
           0.4356598177556632,
           0.46619345427749953,
           0.4966166866993048,
           0.5269217484374686,
           0.5571009916715943,
           0.5871468655348352,
           0.6170519013627215,
           0.646808702647946,
           0.6764099382026659,
           0.7058483375502617,
           0.7351166878939874,
           0.7642078322184135,
           0.7931146682159494,
           0.8218301478217016,
           0.8503472772016837,
           0.8786591170820074,
           0.9067587833365163,
           0.934639447771512,
           0.9622943390614519,
           0.9897167438005762,
           1.0169000076435757,
           1.0438375365144605,
           1.0705227978673473,
           1.0969493219863062,
           1.1231107033140488,
           1.1490006018012564,
           1.1746127442699088,
           1.199940925785209,
           1.224979011031659,
           1.2497209356895982,
           1.2741607078091337,
           1.2982924091788712,
           1.3221101966872513,
           1.3456083036746163,
           1.3687810412743822,
           1.391622799741921,
           1.4141280497699136,
           1.4362913437890958,
           1.4581073172534327,
           1.4795706899088543,
           1.5006762670447835,
           1.5214189407277476,
           1.54179369101643,
           1.561795587157574,
           1.5814197887621926,
           1.6006615469615806,
           1.6195162055426544,
           1.6379792020621797,
           1.6560460689394754,
           1.673712434527198,
           1.6909740241598392,
           1.7078266611795831,
           1.724266267939194,
           1.7402888667816123,
           1.755890580995956,
           1.7710676357496384,
           1.7858163589963247,
           1.8001331823594626,
           1.8140146419911256,
           1.8274573794059346,
           1.840458142289816,
           1.8530137852833755,
           1.865121270739667,
           1.876777669456158,
           1.8879801613806868,
           1.8987260362912222,
           1.909012694449251,
           1.9188376472266109,
           1.9281985177056125,
           1.937093041252285,
           1.945519066062602,
           1.953474553681542,
           1.9609575794948513,
           1.9679663331933783,
           1.9744991192098686,
           1.9805543571280917,
           1.986130582064221,
           1.9912264450203383,
           1.995840713209999,
           1.9999722703557614,
           2.003620116958606,
           2.0067833705391815,
           2.0094612658508098,
           2.0116531550642,
           2.0133585079238245,
           2.014576911875921,
           2.0153080721680703
          ],
          [
           2.046640390387426,
           2.0463930049195564,
           2.0456509084451997,
           2.0444142807378602,
           2.0426834213725593,
           2.0404587496546256,
           2.0377408045200283,
           2.034530244407302,
           2.030827847101084,
           2.026634509547345,
           2.021951247640345,
           2.01677919598142,
           2.011119607609651,
           2.004973853704534,
           1.9983434232607389,
           1.991229922735085,
           1.983635075665846,
           1.9755607222645375,
           1.967008818980324,
           1.9579814380372171,
           1.9484807669442366,
           1.9385091079787253,
           1.9280688776430206,
           1.9171626060947038,
           1.9057929365506576,
           1.8939626246651935,
           1.8816745378825086,
           1.8689316547637682,
           1.855737064289129,
           1.8420939651350277,
           1.8280056649271041,
           1.8134755794691404,
           1.7985072319484319,
           1.7831042521180482,
           1.7672703754564554,
           1.751009442305039,
           1.734325396984098,
           1.717222286887922,
           1.6997042615596436,
           1.6817755717466025,
           1.663440568437038,
           1.6447037018790087,
           1.625569520582535,
           1.6060426703060573,
           1.5861278930284468,
           1.56583002590792,
           1.5451540002294046,
           1.5241048403420663,
           1.5026876625889534,
           1.4809076742309577,
           1.4587701723676083,
           1.436280542857568,
           1.413444259242121,
           1.3902668816754573,
           1.3667540558661373,
           1.3429115120348478,
           1.3187450638944038,
           1.2942606076589804,
           1.2694641210908018,
           1.244361662594007,
           1.2189593703672563,
           1.1932634616288718,
           1.167280231931066,
           1.1410160545832133,
           1.1144773802083516,
           1.0876707364623757,
           1.0606027279520132,
           1.0332800363960666,
           1.0057094210850335,
           0.9778977197078674,
           0.9498518496322071,
           0.9215788097472046,
           0.8930856830079468,
           0.864379639859839,
           0.8354679427737629,
           0.8063579521932612,
           0.7770571342906473,
           0.7475730710601368,
           0.7179134734582071,
           0.6880861985573076,
           0.6580992720435055,
           0.6279609179153314,
           0.5976795980141689,
           0.5672640651709738,
           0.5367234355105874,
           0.5060672881829283,
           0.4753058051245524,
           0.44444997051549323,
           0.4135118614282585,
           0.3825050816246454,
           0.35144542711096977,
           0.3203519404441438,
           0.28924864440904763,
           0.25816752123273295,
           0.22715390855682865,
           0.19627691452319856,
           0.16565115314589401,
           0.13548672861345973,
           0.10621893567429927,
           0.07889597174768917,
           0.056461340729673556,
           0.04664039038742575,
           0.05646134072969199,
           0.07889597174771555,
           0.10621893567432865,
           0.1354867286134904,
           0.16565115314592535,
           0.19627691452323018,
           0.2271539085568605,
           0.2581675212327649,
           0.28924864440907955,
           0.32035194044417575,
           0.3514454271110017,
           0.3825050816246772,
           0.41351186142829033,
           0.444449970515525,
           0.4753058051245839,
           0.50606728818296,
           0.536723435510619,
           0.5672640651710052,
           0.5976795980142001,
           0.6279609179153623,
           0.6580992720435362,
           0.6880861985573383,
           0.7179134734582377,
           0.7475730710601671,
           0.7770571342906775,
           0.8063579521932913,
           0.8354679427737927,
           0.8643796398598685,
           0.8930856830079759,
           0.9215788097472337,
           0.949851849632236,
           0.9778977197078961,
           1.005709421085062,
           1.0332800363960948,
           1.0606027279520411,
           1.0876707364624034,
           1.1144773802083792,
           1.1410160545832402,
           1.1672802319310929,
           1.1932634616288986,
           1.2189593703672825,
           1.244361662594033,
           1.2694641210908275,
           1.294260607659006,
           1.3187450638944287,
           1.3429115120348727,
           1.3667540558661617,
           1.390266881675481,
           1.4134442592421448,
           1.4362805428575913,
           1.4587701723676314,
           1.4809076742309801,
           1.5026876625889756,
           1.5241048403420883,
           1.545154000229426,
           1.565830025907941,
           1.5861278930284672,
           1.6060426703060775,
           1.6255695205825547,
           1.6447037018790283,
           1.6634405684370568,
           1.6817755717466212,
           1.6997042615596616,
           1.7172222868879397,
           1.7343253969841153,
           1.7510094423050557,
           1.7672703754564714,
           1.7831042521180642,
           1.7985072319484476,
           1.813475579469155,
           1.8280056649271188,
           1.842093965135042,
           1.8557370642891429,
           1.8689316547637815,
           1.8816745378825215,
           1.8939626246652062,
           1.9057929365506694,
           1.9171626060947151,
           1.928068877643032,
           1.9385091079787358,
           1.948480766944247,
           1.9579814380372265,
           1.9670088189803332,
           1.975560722264546,
           1.9836350756658538,
           1.9912299227350923,
           1.998343423260746,
           2.0049738537045405,
           2.011119607609657,
           2.0167791959814254,
           2.02195124764035,
           2.0266345095473492,
           2.030827847101088,
           2.0345302444073052,
           2.037740804520032,
           2.040458749654628,
           2.042683421372561,
           2.0444142807378616,
           2.045650908445201,
           2.0463930049195573
          ],
          [
           2.0776838472890145,
           2.077432930268637,
           2.0766802401523283,
           2.0754259597604907,
           2.073670393746924,
           2.0714139685285375,
           2.0686572321870003,
           2.065400854342374,
           2.0616456259987963,
           2.057392459362284,
           2.052642387630767,
           2.0473965647564403,
           2.041656265180577,
           2.035422883540936,
           2.028697934351919,
           2.021483051657667,
           2.01377998865828,
           2.005590617309376,
           1.9969169278952386,
           1.9877610285757972,
           1.9781251449077317,
           1.9680116193400115,
           1.9574229106841996,
           1.9463615935598955,
           1.934830357815709,
           1.9228320079262076,
           1.9103694623653003,
           1.897445752956582,
           1.884064024201193,
           1.8702275325838142,
           1.855939645857458,
           1.8412038423077963,
           1.8260237099978252,
           1.8104029459937485,
           1.7943453555730486,
           1.7778548514158186,
           1.7609354527805345,
           1.7435912846655737,
           1.7258265769579353,
           1.707645663570777,
           1.6890529815715698,
           1.6700530703028857,
           1.6506505704980805,
           1.6308502233944133,
           1.6106568698464703,
           1.5900754494431357,
           1.5691109996317891,
           1.5477686548539196,
           1.5260536456969305,
           1.5039712980676136,
           1.481527032393575,
           1.4587263628598603,
           1.435574896689158,
           1.4120783334752987,
           1.3882424645813707,
           1.3640731726156767,
           1.3395764310010387,
           1.3147583036557102,
           1.2896249448074673,
           1.2641825989664754,
           1.238437601087425,
           1.212396376957413,
           1.1860654438534126,
           1.159451411522246,
           1.1325609835472557,
           1.1054009591799199,
           1.0779782357322947,
           1.050299811648419,
           1.0223727904010511,
           0.9942043853962087,
           0.9658019261143994,
           0.9371728657775844,
           0.9083247909094713,
           0.8792654332601068,
           0.8500026847030003,
           0.8205446158969006,
           0.7908994997531285,
           0.761075841089452,
           0.7310824143215777,
           0.7009283117009031,
           0.6706230055388714,
           0.6401764291967095,
           0.6095990835709767,
           0.5789021786975146,
           0.5480978244582663,
           0.5171992910810566,
           0.4862213706493111,
           0.4551808877485387,
           0.42409743523533905,
           0.3929944583123118,
           0.3619008925642759,
           0.3308537107495656,
           0.29990201328851734,
           0.2691138461977139,
           0.238588055646308,
           0.20847591020479123,
           0.1790226812450133,
           0.15065207437263334,
           0.12414521725603232,
           0.10101549176324748,
           0.08412710413871463,
           0.07768384728901459,
           0.08412710413872737,
           0.1010154917632687,
           0.12414521725605818,
           0.15065207437266173,
           0.17902268124504317,
           0.20847591020482187,
           0.23858805564633917,
           0.26911384619774537,
           0.29990201328854904,
           0.3308537107495974,
           0.3619008925643079,
           0.3929944583123437,
           0.42409743523537086,
           0.45518088774857063,
           0.48622137064934284,
           0.5171992910810884,
           0.548097824458298,
           0.5789021786975461,
           0.6095990835710081,
           0.6401764291967407,
           0.6706230055389024,
           0.7009283117009342,
           0.7310824143216086,
           0.7610758410894827,
           0.7908994997531591,
           0.8205446158969311,
           0.8500026847030306,
           0.8792654332601368,
           0.908324790909501,
           0.9371728657776138,
           0.9658019261144286,
           0.9942043853962379,
           1.02237279040108,
           1.0502998116484477,
           1.077978235732323,
           1.1054009591799476,
           1.1325609835472834,
           1.1594514115222734,
           1.1860654438534397,
           1.2123963769574402,
           1.2384376010874516,
           1.2641825989665016,
           1.2896249448074932,
           1.314758303655736,
           1.339576431001064,
           1.3640731726157018,
           1.3882424645813956,
           1.412078333475323,
           1.435574896689182,
           1.458726362859884,
           1.481527032393598,
           1.5039712980676367,
           1.5260536456969531,
           1.5477686548539416,
           1.5691109996318109,
           1.5900754494431568,
           1.6106568698464914,
           1.6308502233944338,
           1.6506505704981005,
           1.6700530703029053,
           1.6890529815715891,
           1.707645663570796,
           1.7258265769579535,
           1.7435912846655917,
           1.7609354527805523,
           1.7778548514158357,
           1.7943453555730653,
           1.8104029459937647,
           1.8260237099978414,
           1.8412038423078116,
           1.8559396458574728,
           1.8702275325838287,
           1.8840640242012074,
           1.8974457529565956,
           1.9103694623653136,
           1.9228320079262202,
           1.9348303578157209,
           1.9463615935599066,
           1.9574229106842107,
           1.9680116193400221,
           1.978125144907742,
           1.9877610285758067,
           1.9969169278952474,
           2.0055906173093843,
           2.0137799886582877,
           2.021483051657675,
           2.0286979343519254,
           2.0354228835409427,
           2.0416562651805834,
           2.047396564756446,
           2.052642387630772,
           2.0573924593622888,
           2.0616456259988003,
           2.065400854342378,
           2.0686572321870034,
           2.07141396852854,
           2.073670393746926,
           2.0754259597604916,
           2.076680240152329,
           2.0774329302686376
          ],
          [
           2.108652150085483,
           2.108397813674186,
           2.1076348664477407,
           2.1063634944147904,
           2.1045840075440925,
           2.102296839696083,
           2.099502548527139,
           2.0962018153666135,
           2.092395445066725,
           2.088084365825435,
           2.083269628982434,
           2.077952408788411,
           2.072134002147777,
           2.0658158283350723,
           2.058999428685273,
           2.051686466258282,
           2.0438787254778887,
           2.035578111745526,
           2.026786651029194,
           2.0175064894279373,
           2.0077398927123267,
           1.9974892458414142,
           1.9867570524566995,
           1.9755459343536823,
           1.9638586309316368,
           1.9516979986223018,
           1.9390670102982563,
           1.9259687546618123,
           1.9124064356153516,
           1.8983833716141185,
           1.8839029950025827,
           1.8689688513356082,
           1.853584598685779,
           1.837754006938397,
           1.8214809570758057,
           1.804769440452901,
           1.7876235580658792,
           1.770047519816517,
           1.7520456437745489,
           1.7336223554410037,
           1.7147821870157232,
           1.6955297766726738,
           1.6758698678471349,
           1.6558073085393663,
           1.635347050639979,
           1.6144941492829323,
           1.5932537622329088,
           1.5716311493147788,
           1.5496316718939651,
           1.5272607924178572,
           1.504524074029921,
           1.481427180269993,
           1.4579758748763547,
           1.4341760217077286,
           1.4100335848063341,
           1.3855546286267368,
           1.3607453184595106,
           1.335611921083896,
           1.3101608056898641,
           1.284398445117527,
           1.2583314174710125,
           1.2319664081751047,
           1.205310212556702,
           1.178369739050067,
           1.1511520131458282,
           1.1236641822298077,
           1.0959135214904592,
           1.067907441114868,
           1.039653495045424,
           1.011159391635749,
           0.9824330066297433,
           0.9534823989977994,
           0.9243158303076461,
           0.8949417884953678,
           0.8653690171509089,
           0.8356065517642165,
           0.8056637648250075,
           0.7755504222767353,
           0.7452767546602687,
           0.714853547443023,
           0.6842922566610011,
           0.6536051583255766,
           0.6228055434037727,
           0.5919079751010079,
           0.5609286325022378,
           0.529885775726424,
           0.49880038487446643,
           0.46769705200271816,
           0.4366052486842019,
           0.4055611629845139,
           0.374610419754654,
           0.34381220562642667,
           0.3132456878772784,
           0.2830202841535214,
           0.2532925759512772,
           0.2242949587181315,
           0.1963852784253082,
           0.17013328589071428,
           0.14646504420863626,
           0.12686390153286498,
           0.11348056693655068,
           0.10865215008548304,
           0.11348056693656039,
           0.12686390153288238,
           0.1464650442086588,
           0.17013328589074014,
           0.1963852784253362,
           0.2242949587181608,
           0.2532925759513074,
           0.2830202841535522,
           0.31324568787730955,
           0.3438122056264582,
           0.3746104197546858,
           0.40556116298454575,
           0.4366052486842338,
           0.46769705200275,
           0.49880038487449835,
           0.5298857757264561,
           0.5609286325022698,
           0.5919079751010398,
           0.6228055434038045,
           0.6536051583256082,
           0.6842922566610327,
           0.7148535474430544,
           0.7452767546602997,
           0.7755504222767663,
           0.8056637648250382,
           0.8356065517642474,
           0.8653690171509393,
           0.894941788495398,
           0.9243158303076762,
           0.9534823989978292,
           0.9824330066297728,
           1.0111593916357786,
           1.039653495045453,
           1.0679074411148968,
           1.0959135214904878,
           1.123664182229836,
           1.1511520131458564,
           1.178369739050095,
           1.2053102125567297,
           1.231966408175132,
           1.2583314174710396,
           1.2843984451175536,
           1.3101608056898906,
           1.3356119210839221,
           1.3607453184595364,
           1.3855546286267624,
           1.4100335848063592,
           1.4341760217077533,
           1.4579758748763791,
           1.481427180270017,
           1.5045240740299446,
           1.5272607924178805,
           1.549631671893988,
           1.5716311493148012,
           1.593253762232931,
           1.6144941492829537,
           1.6353470506400005,
           1.6558073085393872,
           1.6758698678471553,
           1.6955297766726938,
           1.7147821870157425,
           1.7336223554410228,
           1.7520456437745675,
           1.7700475198165355,
           1.7876235580658972,
           1.8047694404529186,
           1.8214809570758226,
           1.8377540069384135,
           1.853584598685795,
           1.868968851335624,
           1.883902995002598,
           1.8983833716141332,
           1.9124064356153658,
           1.9259687546618263,
           1.9390670102982699,
           1.9516979986223146,
           1.9638586309316488,
           1.975545934353694,
           1.9867570524567109,
           1.997489245841425,
           2.0077398927123373,
           2.017506489427947,
           2.026786651029203,
           2.0355781117455343,
           2.0438787254778967,
           2.05168646625829,
           2.05899942868528,
           2.0658158283350794,
           2.072134002147783,
           2.0779524087884162,
           2.0832696289824395,
           2.0880843658254395,
           2.0923954450667295,
           2.0962018153666175,
           2.0995025485271426,
           2.1022968396960855,
           2.1045840075440947,
           2.1063634944147918,
           2.1076348664477416,
           2.1083978136741863
          ],
          [
           2.139515338943932,
           2.1392576932385614,
           2.1384848192354404,
           2.1371969062603813,
           2.1353942698125525,
           2.133077351498753,
           2.1302467189414935,
           2.12690306566099,
           2.1230472109312024,
           2.118680099610069,
           2.113802801944153,
           2.108416513347898,
           2.102522554157788,
           2.0961223693616877,
           2.0892175283037036,
           2.081809724364961,
           2.073900774620698,
           2.0654926194741625,
           2.0565873222678337,
           2.0471870688725278,
           2.0372941672550464,
           2.0269110470250546,
           2.016040258961965,
           2.004684474522675,
           1.992846485331105,
           1.9805292026505468,
           1.9677356568399824,
           1.954468996795604,
           1.9407324893789268,
           1.9265295188330163,
           1.9118635861885123,
           1.896738308661319,
           1.8811574190440237,
           1.8651247650933434,
           1.848644308916145,
           1.831720126356888,
           1.8143564063896522,
           1.7965574505183024,
           1.7783276721887502,
           1.759671596217776,
           1.7405938582434164,
           1.7210992042025592,
           1.7011924898421267,
           1.680878680271063,
           1.6601628495613112,
           1.6390501804070994,
           1.6175459638531482,
           1.5956555991039418,
           1.5733845934279664,
           1.550738562172901,
           1.5277232289101672,
           1.5043444257301128,
           1.4806080937124766,
           1.4565202836007756,
           1.4320871567140077,
           1.4073149861347174,
           1.3822101582192285,
           1.3567791744839828,
           1.3310286539316802,
           1.3049653358927649,
           1.2785960834721375,
           1.2519278877085012,
           1.2249678725751776,
           1.197723300977615,
           1.170201581935416,
           1.1424102791772317,
           1.1143571214274537,
           1.0860500147271872,
           1.0574970572122062,
           1.0287065568725626,
           0.9996870529488595,
           0.9704473417879914,
           0.9409965081986251,
           0.911343963630666,
           0.8814994928766353,
           0.8514733114886828,
           0.821276136768487,
           0.790919276083498,
           0.7604147374852279,
           0.7297753692894531,
           0.6990150376242135,
           0.668148854257457,
           0.6371934717321694,
           0.6061674696519179,
           0.575091865943825,
           0.5439908017647548,
           0.5128924711052755,
           0.481830400458039,
           0.45084523734707194,
           0.41998729103962656,
           0.38932020448326227,
           0.35892635716821447,
           0.3289149599718182,
           0.29943439270438094,
           0.27069127185574476,
           0.24298010580292917,
           0.21672892723415205,
           0.19256616480762503,
           0.1714053652837583,
           0.15450920126830833,
           0.14341177530675722,
           0.13951533894393164,
           0.14341177530676513,
           0.154509201268323,
           0.17140536528377814,
           0.19256616480764854,
           0.21672892723417814,
           0.24298010580295695,
           0.27069127185577385,
           0.2994343927044109,
           0.3289149599718488,
           0.35892635716824556,
           0.38932020448329374,
           0.4199872910396582,
           0.45084523734710363,
           0.48183040045807085,
           0.5128924711053073,
           0.5439908017647868,
           0.575091865943857,
           0.6061674696519498,
           0.6371934717322014,
           0.6681488542574886,
           0.699015037624245,
           0.7297753692894847,
           0.7604147374852593,
           0.7909192760835294,
           0.8212761367685181,
           0.8514733114887137,
           0.881499492876666,
           0.9113439636306966,
           0.9409965081986557,
           0.9704473417880215,
           0.9996870529488895,
           1.0287065568725924,
           1.0574970572122357,
           1.0860500147272163,
           1.1143571214274826,
           1.1424102791772603,
           1.1702015819354448,
           1.1977233009776431,
           1.2249678725752056,
           1.2519278877085287,
           1.2785960834721648,
           1.3049653358927917,
           1.3310286539317067,
           1.3567791744840088,
           1.3822101582192545,
           1.407314986134743,
           1.432087156714033,
           1.4565202836008002,
           1.4806080937125012,
           1.504344425730137,
           1.527723228910191,
           1.5507385621729244,
           1.5733845934279893,
           1.5956555991039645,
           1.6175459638531708,
           1.6390501804071211,
           1.6601628495613328,
           1.680878680271084,
           1.701192489842147,
           1.7210992042025794,
           1.7405938582434362,
           1.7596715962177956,
           1.7783276721887689,
           1.7965574505183208,
           1.8143564063896704,
           1.8317201263569054,
           1.8486443089161624,
           1.86512476509336,
           1.88115741904404,
           1.8967383086613347,
           1.9118635861885276,
           1.9265295188330311,
           1.9407324893789413,
           1.9544689967956177,
           1.9677356568399957,
           1.9805292026505597,
           1.9928464853311172,
           2.004684474522687,
           2.0160402589619766,
           2.0269110470250657,
           2.037294167255057,
           2.0471870688725375,
           2.056587322267843,
           2.065492619474171,
           2.073900774620706,
           2.081809724364969,
           2.0892175283037107,
           2.0961223693616944,
           2.1025225541577943,
           2.108416513347904,
           2.113802801944158,
           2.118680099610074,
           2.123047210931207,
           2.1269030656609935,
           2.1302467189414966,
           2.133077351498756,
           2.1353942698125548,
           2.1371969062603826,
           2.1384848192354418,
           2.139257693238562
          ],
          [
           2.1702435557224073,
           2.1699827087084027,
           2.1692002319236163,
           2.167896318127263,
           2.1660712885431685,
           2.1637255927975416,
           2.1608598088319857,
           2.157474642791895,
           2.1535709288903986,
           2.149149629248086,
           2.144211833708765,
           2.1387587596315623,
           2.1327917516597266,
           2.1263122814665225,
           2.119321947478699,
           2.1118224745780205,
           2.103815713781457,
           2.09530364190066,
           2.0862883611814462,
           2.07677209892407,
           2.0667572070851645,
           2.056246161862308,
           2.0452415632622825,
           2.0337461346542023,
           2.0217627223087966,
           2.009294294925288,
           1.9963439431474357,
           1.9829148790704902,
           1.9690104357409806,
           1.954634066651477,
           1.939789345232673,
           1.9244799643454213,
           1.9087097357756242,
           1.8924825897352067,
           1.8758025743727842,
           1.8586738552980324,
           1.8411007151242527,
           1.8230875530341553,
           1.8046388843744903,
           1.785759340285862,
           1.7664536673748443,
           1.7467267274364362,
           1.7265834972359373,
           1.7060290683605333,
           1.6850686471522682,
           1.6637075547356925,
           1.6419512271553356,
           1.619805215640333,
           1.5972751870160544,
           1.5743669242855398,
           1.5510863274070206,
           1.5274394142978664,
           1.5034323221000996,
           1.4790713087483094,
           1.4543627548875082,
           1.4293131661965113,
           1.4039291761819723,
           1.3782175495196807,
           1.3521851860335183,
           1.3258391254191173,
           1.2991865528394324,
           1.2722348055439971,
           1.2449913806936228,
           1.2174639446091235,
           1.1896603437080469,
           1.1615886174496448,
           1.1332570136783457,
           1.1046740068436702,
           1.0758483196848612,
           1.0467889491081577,
           1.0175051971624818,
           0.9880067082471731,
           0.9583035139793269,
           0.9284060875299825,
           0.8983254097377418,
           0.868073049966514,
           0.8376612655484968,
           0.8071031248249164,
           0.7764126603802339,
           0.745605061224826,
           0.7146969156545672,
           0.6837065206513355,
           0.6526542795003635,
           0.6215632175559157,
           0.5904596579424018,
           0.5593741161922382,
           0.528342498088878,
           0.49740772245183973,
           0.46662194665945983,
           0.43604965711701776,
           0.40577201421351555,
           0.3758930321287321,
           0.34654845335457957,
           0.3179185645063572,
           0.29024666256414144,
           0.26386520421274223,
           0.23923109850637794,
           0.21696804457933114,
           0.19790278742326556,
           0.1830582236398312,
           0.17353674920945947,
           0.17024355572240732,
           0.17353674920946616,
           0.18305822363984392,
           0.19790278742328318,
           0.21696804457935256,
           0.23923109850640223,
           0.2638652042127685,
           0.29024666256416937,
           0.31791856450638617,
           0.3465484533546094,
           0.3758930321287625,
           0.4057720142135466,
           0.436049657117049,
           0.4666219466594914,
           0.4974077224518715,
           0.5283424980889099,
           0.5593741161922701,
           0.5904596579424338,
           0.6215632175559478,
           0.6526542795003955,
           0.6837065206513674,
           0.7146969156545989,
           0.7456050612248577,
           0.7764126603802655,
           0.807103124824948,
           0.8376612655485282,
           0.8680730499665451,
           0.8983254097377726,
           0.9284060875300135,
           0.9583035139793574,
           0.9880067082472034,
           1.017505197162512,
           1.0467889491081876,
           1.075848319684891,
           1.1046740068436998,
           1.1332570136783748,
           1.1615886174496737,
           1.1896603437080755,
           1.2174639446091517,
           1.2449913806936512,
           1.2722348055440253,
           1.29918655283946,
           1.3258391254191446,
           1.3521851860335452,
           1.3782175495197073,
           1.4039291761819985,
           1.4293131661965373,
           1.4543627548875337,
           1.4790713087483347,
           1.5034323221001247,
           1.5274394142978907,
           1.5510863274070448,
           1.5743669242855634,
           1.5972751870160777,
           1.6198052156403564,
           1.6419512271553582,
           1.6637075547357145,
           1.68506864715229,
           1.7060290683605546,
           1.726583497235958,
           1.7467267274364568,
           1.7664536673748645,
           1.7857593402858818,
           1.8046388843745094,
           1.823087553034174,
           1.841100715124271,
           1.8586738552980502,
           1.8758025743728015,
           1.8924825897352238,
           1.9087097357756406,
           1.924479964345437,
           1.9397893452326882,
           1.954634066651492,
           1.9690104357409952,
           1.9829148790705042,
           1.9963439431474497,
           2.0092942949253016,
           2.0217627223088095,
           2.0337461346542147,
           2.0452415632622944,
           2.056246161862319,
           2.0667572070851747,
           2.0767720989240797,
           2.0862883611814556,
           2.095303641900669,
           2.103815713781465,
           2.111822474578028,
           2.119321947478706,
           2.1263122814665296,
           2.132791751659733,
           2.1387587596315685,
           2.14421183370877,
           2.1491496292480905,
           2.153570928890403,
           2.1574746427918985,
           2.1608598088319897,
           2.1637255927975443,
           2.1660712885431703,
           2.167896318127265,
           2.169200231923618,
           2.1699827087084036
          ],
          [
           2.2008070728557274,
           2.2005431303752494,
           2.199751368369691,
           2.1984319831350527,
           2.1965853017925996,
           2.194211782230849,
           2.1913120130245294,
           2.187886713330676,
           2.1839367327621106,
           2.1794630512385673,
           2.174466778815823,
           2.168949155493216,
           2.162911551000018,
           2.1563554645611864,
           2.1492825246430947,
           2.141694488679898,
           2.133593242781303,
           2.12498080142256,
           2.115859307117622,
           2.1062310300764904,
           2.0960983678478984,
           2.0854638449485865,
           2.074330112480579,
           2.0626999477379866,
           2.050576253805059,
           2.0379620591473557,
           2.024860517198119,
           2.0112749059421606,
           1.997208627499799,
           1.9826652077136688,
           1.967648295741541,
           1.9521616636586212,
           1.936209206073183,
           1.919794939759848,
           1.9029230033152824,
           1.8855976568416777,
           1.8678232816639773,
           1.8496043800875548,
           1.8309455752038502,
           1.8118516107524074,
           1.7923273510488196,
           1.7723777809893082,
           1.7520080061440513,
           1.7312232529530045,
           1.710028869039797,
           1.688430323661433,
           1.6664332083140254,
           1.6440432375176637,
           1.621266249806887,
           1.5981082089571554,
           1.5745752054823166,
           1.5506734584434474,
           1.5264093176158202,
           1.5017892660682304,
           1.476819923217817,
           1.4515080484340641,
           1.4258605452782507,
           1.3998844664796857,
           1.3735870197681177,
           1.3469755747034873,
           1.3200576706705123,
           1.292841026237551,
           1.2653335501181302,
           1.2375433540212182,
           1.2094787677349181,
           1.1811483568606678,
           1.1525609437048525,
           1.1237256319467808,
           1.0946518358423964,
           1.0653493149000948,
           1.035828215189301,
           1.0060991187283967,
           0.9761731027652644,
           0.9460618112369922,
           0.9157775413101168,
           0.8853333487070386,
           0.8547431765837754,
           0.8240220141303641,
           0.7931860929456351,
           0.7622531317724875,
           0.7312426436231101,
           0.7001763240399063,
           0.6690785457504861,
           0.637976994040065,
           0.6069034898780823,
           0.5758950657877057,
           0.5449953849334982,
           0.5142566301998142,
           0.48374204168934254,
           0.4535293540570041,
           0.42371548629467287,
           0.39442297127196474,
           0.3658087761748523,
           0.33807632234900503,
           0.3114915441416717,
           0.286403411318822,
           0.26326774804368874,
           0.24266904291522431,
           0.22532658069911576,
           0.21205935441839774,
           0.20367911969315064,
           0.2008070728557273,
           0.20367911969315652,
           0.21205935441840904,
           0.22532658069913167,
           0.24266904291524397,
           0.2632677480437114,
           0.28640341131884683,
           0.3114915441416983,
           0.33807632234903295,
           0.3658087761748812,
           0.3944229712719945,
           0.42371548629470335,
           0.453529354057035,
           0.4837420416893738,
           0.5142566301998457,
           0.5449953849335298,
           0.5758950657877373,
           0.6069034898781144,
           0.637976994040097,
           0.6690785457505181,
           0.7001763240399381,
           0.7312426436231418,
           0.7622531317725193,
           0.793186092945667,
           0.8240220141303957,
           0.8547431765838068,
           0.88533334870707,
           0.9157775413101479,
           0.9460618112370232,
           0.9761731027652952,
           1.0060991187284274,
           1.0358282151893314,
           1.065349314900125,
           1.0946518358424264,
           1.1237256319468105,
           1.1525609437048818,
           1.1811483568606969,
           1.209478767734947,
           1.2375433540212468,
           1.2653335501181586,
           1.2928410262375791,
           1.3200576706705403,
           1.3469755747035148,
           1.3735870197681448,
           1.3998844664797125,
           1.425860545278277,
           1.4515080484340903,
           1.476819923217843,
           1.5017892660682557,
           1.526409317615845,
           1.550673458443472,
           1.574575205482341,
           1.5981082089571794,
           1.6212662498069108,
           1.6440432375176872,
           1.6664332083140485,
           1.6884303236614555,
           1.710028869039819,
           1.7312232529530258,
           1.7520080061440721,
           1.772377780989329,
           1.79232735104884,
           1.8118516107524272,
           1.8309455752038697,
           1.8496043800875743,
           1.867823281663996,
           1.8855976568416954,
           1.9029230033153,
           1.919794939759865,
           1.9362092060732001,
           1.9521616636586374,
           1.967648295741557,
           1.9826652077136842,
           1.997208627499814,
           2.011274905942175,
           2.0248605171981326,
           2.037962059147369,
           2.050576253805072,
           2.062699947737999,
           2.0743301124805904,
           2.0854638449485976,
           2.0960983678479086,
           2.1062310300765006,
           2.1158593071176313,
           2.124980801422569,
           2.133593242781312,
           2.141694488679906,
           2.149282524643102,
           2.156355464561194,
           2.162911551000024,
           2.168949155493222,
           2.174466778815829,
           2.1794630512385726,
           2.183936732762115,
           2.18788671333068,
           2.1913120130245325,
           2.194211782230852,
           2.196585301792601,
           2.1984319831350545,
           2.199751368369693,
           2.2005431303752503
          ],
          [
           2.2311763221149787,
           2.2309093878481794,
           2.230108651692429,
           2.228774313571006,
           2.226906706653874,
           2.224506297304524,
           2.2215736850057923,
           2.2181096022648474,
           2.21411491449764,
           2.209590619893182,
           2.204537849258062,
           2.198957865841707,
           2.1928520651429633,
           2.186221974698663,
           2.179069253854907,
           2.1713956935219314,
           2.163203215913477,
           2.154493874271728,
           2.1452698525789877,
           2.135533465257391,
           2.1252871568580924,
           2.1145335017415268,
           2.1032752037505067,
           2.0915150958781075,
           2.079256139932492,
           2.0665014262010653,
           2.053254173116592,
           2.0395177269281977,
           2.0252955613804837,
           2.0105912774043397,
           1.9954086028234261,
           1.9797513920807421,
           1.96362362599019,
           1.9470294115185924,
           1.9299729816042686,
           1.9124586950189606,
           1.8944910362807261,
           1.8760746156263206,
           1.8572141690526225,
           1.8379145584378556,
           1.8181807717547045,
           1.7980179233889717,
           1.7774312545792015,
           1.756426133994738,
           1.735008058472036,
           1.7131826539317712,
           1.6909556765024194,
           1.6683330138796586,
           1.6453206869551564,
           1.6219248517532867,
           1.5981518017200957,
           1.574007970415621,
           1.5494999346686562,
           1.524634418262458,
           1.4994182962310103,
           1.4738585998586624,
           1.4479625224916512,
           1.42173742628876,
           1.395190850060805,
           1.368330518375622,
           1.3411643521377619,
           1.313700480891501,
           1.2859472571436497,
           1.2579132730610927,
           1.2296073799695768,
           1.20103871116841,
           1.1722167086846487,
           1.1431511547256665,
           1.1138522087578133,
           1.0843304513506185,
           1.0545969361929046,
           1.0246632520254455,
           0.9945415966658634,
           0.9642448658539029,
           0.9337867603573842,
           0.9031819157027018,
           0.8724460600988841,
           0.8415962077066035,
           0.8106508964943511,
           0.7796304827040629,
           0.7485575076677974,
           0.7174571577224346,
           0.686357844741989,
           0.6552919440133831,
           0.6242967387378472,
           0.5934156375886158,
           0.5626997551336975,
           0.5322099765856829,
           0.5020196705486704,
           0.472218268040699,
           0.44291599262840553,
           0.41425009772088,
           0.38639301850989055,
           0.35956281464054446,
           0.33403602292807294,
           0.3101622710177808,
           0.2883782334463595,
           0.26921514098045224,
           0.25328902747497034,
           0.24125852092663153,
           0.23373826277268167,
           0.23117632211497857,
           0.2337382627726869,
           0.24125852092664166,
           0.2532890274749849,
           0.26921514098047045,
           0.2883782334463807,
           0.31016227101780436,
           0.3340360229280984,
           0.35956281464057144,
           0.3863930185099187,
           0.4142500977209091,
           0.4429159926284354,
           0.47221826804072936,
           0.5020196705487011,
           0.5322099765857142,
           0.5626997551337289,
           0.5934156375886475,
           0.624296738737879,
           0.655291944013415,
           0.6863578447420211,
           0.7174571577224665,
           0.7485575076678292,
           0.7796304827040949,
           0.8106508964943829,
           0.8415962077066352,
           0.8724460600989158,
           0.9031819157027333,
           0.9337867603574155,
           0.964244865853934,
           0.9945415966658944,
           1.0246632520254764,
           1.0545969361929353,
           1.084330451350649,
           1.1138522087578437,
           1.1431511547256965,
           1.1722167086846784,
           1.2010387111684395,
           1.2296073799696061,
           1.2579132730611213,
           1.2859472571436783,
           1.3137004808915294,
           1.34116435213779,
           1.3683305183756496,
           1.3951908500608323,
           1.4217374262887872,
           1.447962522491678,
           1.4738585998586888,
           1.4994182962310363,
           1.5246344182624838,
           1.5494999346686815,
           1.574007970415646,
           1.5981518017201204,
           1.621924851753311,
           1.64532068695518,
           1.6683330138796821,
           1.6909556765024425,
           1.7131826539317936,
           1.7350080584720584,
           1.7564261339947598,
           1.7774312545792228,
           1.7980179233889926,
           1.8181807717547247,
           1.8379145584378755,
           1.8572141690526422,
           1.87607461562634,
           1.8944910362807448,
           1.9124586950189784,
           1.9299729816042868,
           1.9470294115186098,
           1.963623625990207,
           1.9797513920807586,
           1.995408602823442,
           2.0105912774043553,
           2.025295561380499,
           2.0395177269282123,
           2.053254173116606,
           2.066501426201079,
           2.079256139932505,
           2.09151509587812,
           2.103275203750519,
           2.114533501741538,
           2.1252871568581035,
           2.135533465257401,
           2.1452698525789975,
           2.1544938742717368,
           2.163203215913486,
           2.1713956935219394,
           2.1790692538549146,
           2.1862219746986695,
           2.19285206514297,
           2.1989578658417126,
           2.2045378492580676,
           2.209590619893187,
           2.214114914497644,
           2.218109602264851,
           2.221573685005796,
           2.2245062973045266,
           2.2269067066538755,
           2.228774313571008,
           2.23010865169243,
           2.2309093878481803
          ],
          [
           2.26132192321287,
           2.2610520986708,
           2.2602426929238604,
           2.2588939096002845,
           2.257006088048565,
           2.254579703289752,
           2.2516153659509284,
           2.248113822180138,
           2.2440759535431134,
           2.239502776902242,
           2.2343954442782725,
           2.228755242695389,
           2.2225835940103447,
           2.2158820547264586,
           2.208652315793405,
           2.2008962023937984,
           2.1926156737177496,
           2.1838128227266633,
           2.174489875907724,
           2.1646491930206397,
           2.1542932668384362,
           2.1434247228842214,
           2.1320463191661108,
           2.1201609459126827,
           2.1077716253116203,
           2.0948815112544605,
           2.0814938890906824,
           2.06761217539472,
           2.0532399177498717,
           2.038380794553494,
           2.023038614848374,
           2.007217318185694,
           1.9909209745256193,
           1.9741537841822352,
           1.9569200778203009,
           1.9392243165122003,
           1.9210710918644203,
           1.9024651262240393,
           1.883411272976958,
           1.8639145169510738,
           1.8439799749392438,
           1.8236128963587956,
           1.802818664066483,
           1.7816027953503153,
           1.7599709431225388,
           1.7379288973413556,
           1.715482586692818,
           1.692638080568744,
           1.6694015913816787,
           1.6457794772639212,
           1.6217782452046383,
           1.5974045546873052,
           1.572665221899333,
           1.5475672245970777,
           1.52211770772281,
           1.4963239898860479,
           1.470193570840467,
           1.4437341401099948,
           1.4169535869444445,
           1.3898600118171351,
           1.3624617397155303,
           1.3347673355225063,
           1.3067856218423253,
           1.2785256996940266,
           1.2499969725787887,
           1.2212091745305684,
           1.192172402885832,
           1.162897156664585,
           1.1333943816491023,
           1.1036755234890137,
           1.0737525904649647,
           1.0436382279253487,
           1.013345806894299,
           0.982889529964224,
           0.9522845583722898,
           0.9215471651700423,
           0.890694920699014,
           0.8597469182765402,
           0.8287240502009326,
           0.7976493470724071,
           0.766548397221922,
           0.7354498680463402,
           0.704386157664881,
           0.6733942140600974,
           0.6425165704084265,
           0.6118026604404933,
           0.5813104972760792,
           0.5511088240041498,
           0.52127987443988,
           0.4919229163099357,
           0.46315878067097943,
           0.43513559558293374,
           0.40803590553033586,
           0.38208520343554303,
           0.3575615058663722,
           0.33480476664540315,
           0.3142234069395718,
           0.2962929402914186,
           0.28153915025368004,
           0.2704976100432627,
           0.2636463446573747,
           0.2613219232128697,
           0.2636463446573794,
           0.270497610043272,
           0.28153915025369336,
           0.29629294029143555,
           0.31422340693959167,
           0.33480476664542547,
           0.3575615058663965,
           0.38208520343556907,
           0.4080359055303632,
           0.43513559558296205,
           0.4631587806710087,
           0.49192291630996554,
           0.5212798744399104,
           0.5511088240041806,
           0.5813104972761104,
           0.6118026604405247,
           0.6425165704084581,
           0.6733942140601292,
           0.704386157664913,
           0.735449868046372,
           0.766548397221954,
           0.7976493470724391,
           0.8287240502009644,
           0.8597469182765721,
           0.8906949206990459,
           0.921547165170074,
           0.9522845583723211,
           0.9828895299642553,
           1.0133458068943302,
           1.0436382279253797,
           1.0737525904649956,
           1.1036755234890445,
           1.1333943816491328,
           1.1628971566646151,
           1.1921724028858622,
           1.221209174530598,
           1.249996972578818,
           1.278525699694056,
           1.3067856218423541,
           1.3347673355225351,
           1.3624617397155585,
           1.3898600118171631,
           1.4169535869444718,
           1.4437341401100223,
           1.4701935708404943,
           1.4963239898860747,
           1.5221177077228365,
           1.5475672245971042,
           1.5726652218993586,
           1.5974045546873306,
           1.621778245204663,
           1.6457794772639456,
           1.6694015913817026,
           1.6926380805687675,
           1.7154825866928418,
           1.7379288973413785,
           1.7599709431225612,
           1.7816027953503375,
           1.8028186640665043,
           1.8236128963588172,
           1.8439799749392647,
           1.8639145169510938,
           1.8834112729769779,
           1.902465126224059,
           1.921071091864439,
           1.9392243165122185,
           1.956920077820319,
           1.9741537841822525,
           1.9909209745256364,
           2.0072173181857105,
           2.0230386148483905,
           2.0383807945535097,
           2.0532399177498872,
           2.0676121753947347,
           2.0814938890906967,
           2.094881511254474,
           2.107771625311633,
           2.120160945912695,
           2.132046319166123,
           2.1434247228842334,
           2.1542932668384474,
           2.1646491930206504,
           2.1744898759077333,
           2.1838128227266727,
           2.1926156737177585,
           2.200896202393807,
           2.2086523157934126,
           2.2158820547264657,
           2.222583594010351,
           2.228755242695395,
           2.234395444278278,
           2.239502776902247,
           2.2440759535431183,
           2.2481138221801418,
           2.251615365950932,
           2.254579703289755,
           2.2570060880485667,
           2.258893909600286,
           2.2602426929238617,
           2.2610520986708007
          ],
          [
           2.2912147122272613,
           2.290942096755034,
           2.290124319473878,
           2.288761587781978,
           2.286854247315029,
           2.2844027819044856,
           2.281407813519423,
           2.2778701021923284,
           2.2737905459292462,
           2.2691701806047897,
           2.264010179842625,
           2.2583118548821752,
           2.2520766544323556,
           2.245306164513325,
           2.2380021082873265,
           2.2301663458798484,
           2.22180087419248,
           2.212907826709002,
           2.2034894732964108,
           2.193548220002782,
           2.183086608854084,
           2.172107317652262,
           2.160613159777181,
           2.1486070839952895,
           2.1360921742781485,
           2.123071649634343,
           2.1095488639586177,
           2.095527305902547,
           2.0810105987714564,
           2.066002500452881,
           2.050506903382377,
           2.0345278345531796,
           2.018069455576916,
           2.001136062803399,
           1.9837320875084494,
           1.9658620961597324,
           1.9475307907717818,
           1.9287430093627091,
           1.9095037265266093,
           1.8898180541374194,
           1.8696912422019287,
           1.8491286798819127,
           1.8281358967079144,
           1.8067185640101742,
           1.7848824965955887,
           1.7626336547034938,
           1.7399781462776025,
           1.7169222295966373,
           1.6934723163122776,
           1.6696349749501,
           1.645416934937405,
           1.6208250912314415,
           1.5958665096328057,
           1.5705484328820125,
           1.5448782876528262,
           1.5188636925743448,
           1.4925124674356396,
           1.465832643752661,
           1.4388324769080072,
           1.4115204601110707,
           1.3839053404703636,
           1.355996137523122,
           1.3278021646316427,
           1.2993330537338033,
           1.270598784030073,
           1.2416097153051187,
           1.2123766267240081,
           1.1829107621175787,
           1.153223882987138,
           1.1233283307260231,
           1.0932370998884802,
           1.0629639247525946,
           1.032523381946708,
           1.0019310125677765,
           0.9712034680544751,
           0.9403586851383525,
           0.909416096549395,
           0.8783968858846675,
           0.8473242972731818,
           0.8162240133332862,
           0.7851246186088728,
           0.7540581704260013,
           0.7230609052264285,
           0.6921741162569892,
           0.6614452484025252,
           0.6309292682874762,
           0.6006903826840958,
           0.5708041953645064,
           0.5413604102099654,
           0.5124662025002339,
           0.48425038176843244,
           0.45686844026832113,
           0.4305084872546344,
           0.40539785320969157,
           0.381809721828243,
           0.3600684026081358,
           0.34055072481393606,
           0.32367965286910666,
           0.30990524428923755,
           0.29966892981849,
           0.2933516242666895,
           0.29121471222726114,
           0.2933516242666939,
           0.29966892981849863,
           0.30990524428925,
           0.3236796528691226,
           0.34055072481395493,
           0.36006840260815703,
           0.3818097218282664,
           0.40539785320971666,
           0.4305084872546609,
           0.4568684402683488,
           0.48425038176846114,
           0.5124662025002632,
           0.5413604102099954,
           0.570804195364537,
           0.6006903826841267,
           0.6309292682875075,
           0.6614452484025567,
           0.6921741162570209,
           0.7230609052264604,
           0.7540581704260331,
           0.7851246186089047,
           0.8162240133333182,
           0.8473242972732138,
           0.8783968858846994,
           0.9094160965494269,
           0.9403586851383843,
           0.9712034680545067,
           1.0019310125678078,
           1.0325233819467394,
           1.0629639247526257,
           1.0932370998885113,
           1.1233283307260542,
           1.1532238829871686,
           1.1829107621176094,
           1.2123766267240383,
           1.2416097153051486,
           1.2705987840301027,
           1.2993330537338326,
           1.3278021646316718,
           1.355996137523151,
           1.3839053404703923,
           1.4115204601110989,
           1.4388324769080352,
           1.4658326437526885,
           1.492512467435667,
           1.5188636925743717,
           1.5448782876528528,
           1.5705484328820387,
           1.5958665096328315,
           1.6208250912314668,
           1.6454169349374304,
           1.669634974950125,
           1.6934723163123018,
           1.7169222295966613,
           1.7399781462776265,
           1.7626336547035169,
           1.7848824965956116,
           1.8067185640101961,
           1.8281358967079355,
           1.8491286798819337,
           1.8696912422019498,
           1.8898180541374399,
           1.9095037265266295,
           1.928743009362729,
           1.947530790771801,
           1.9658620961597504,
           1.9837320875084674,
           2.001136062803417,
           2.0180694555769327,
           2.034527834553196,
           2.050506903382393,
           2.066002500452897,
           2.0810105987714715,
           2.0955273059025616,
           2.1095488639586324,
           2.123071649634357,
           2.1360921742781613,
           2.1486070839953015,
           2.1606131597771934,
           2.172107317652274,
           2.1830866088540954,
           2.1935482200027923,
           2.2034894732964205,
           2.2129078267090114,
           2.2218008741924886,
           2.2301663458798564,
           2.2380021082873345,
           2.245306164513333,
           2.2520766544323623,
           2.2583118548821814,
           2.264010179842631,
           2.2691701806047946,
           2.273790545929251,
           2.277870102192332,
           2.2814078135194267,
           2.2844027819044888,
           2.286854247315031,
           2.28876158778198,
           2.29012431947388,
           2.290942096755035
          ],
          [
           2.320825769815377,
           2.320550460604341,
           2.3197246033805023,
           2.318348409364541,
           2.316422230567226,
           2.3139465597540583,
           2.31092203039613,
           2.3073494166075963,
           2.3032296330702167,
           2.298563734945596,
           2.293352917775822,
           2.2875985173733615,
           2.281302009701192,
           2.2744650107442883,
           2.2670892763737416,
           2.2591767022049347,
           2.2507293234513996,
           2.241749314776133,
           2.2322389901423794,
           2.222200802666105,
           2.2116373444726176,
           2.200551346560068,
           2.188945678672853,
           2.176823349188259,
           2.164187505020045,
           2.1510414315430615,
           2.137388552543413,
           2.1232324301992014,
           2.108576765097376,
           2.0934253962928553,
           2.077782301416744,
           2.0616515968412332,
           2.045037537909592,
           2.027944519240662,
           2.010377075118281,
           1.9923398799773204,
           1.973837748999367,
           1.9548756388326374,
           1.9354586484524723,
           1.9155920201807728,
           1.8952811408850019,
           1.8745315433800023,
           1.8533489080588386,
           1.831739064782304,
           1.8097079950606445,
           1.7872618345655604,
           1.7644068760157574,
           1.7411495724853303,
           1.7174965411912206,
           1.6934545678240864,
           1.6690306114963276,
           1.644231810391989,
           1.6190654882161064,
           1.5935391615560996,
           1.5676605482855255,
           1.5414375771613456,
           1.5148783987905008,
           1.4879913981708046,
           1.460785209045866,
           1.4332687303551404,
           1.4054511451096803,
           1.3773419420835082,
           1.3489509407819367,
           1.3202883202343552,
           1.2913646522634166,
           1.2621909400094102,
           1.2327786626433332,
           1.2031398273914777,
           1.1732870302268277,
           1.1432335268690308,
           1.1129933160889711,
           1.082581237753578,
           1.0520130885938803,
           1.02130575936309,
           0.9904773979082644,
           0.9595476037555971,
           0.9285376611650779,
           0.897470819320521,
           0.8663726304804124,
           0.8352713596407944,
           0.8041984826952927,
           0.7731892943845313,
           0.7422836526873406,
           0.7115268928894211,
           0.6809709524770375,
           0.650675757173072,
           0.6207109283967724,
           0.5911578819299743,
           0.5621123938472904,
           0.533687707325223,
           0.5060182326042711,
           0.4792638343813113,
           0.45361457737787175,
           0.42929556923405304,
           0.4065711476449631,
           0.3857470645987922,
           0.36716855396278025,
           0.35121144364999973,
           0.3382633311691722,
           0.3286931591742262,
           0.32281107199993037,
           0.3208257698153768,
           0.3228110719999345,
           0.32869315917423414,
           0.3382633311691838,
           0.35121144365001467,
           0.3671685539627981,
           0.38574706459881253,
           0.40657114764498553,
           0.42929556923407725,
           0.4536145773778974,
           0.47926383438133824,
           0.5060182326042992,
           0.5336877073252518,
           0.5621123938473199,
           0.5911578819300044,
           0.620710928396803,
           0.650675757173103,
           0.6809709524770687,
           0.7115268928894525,
           0.7422836526873724,
           0.7731892943845631,
           0.8041984826953246,
           0.8352713596408263,
           0.8663726304804443,
           0.897470819320553,
           0.9285376611651098,
           0.9595476037556291,
           0.990477397908296,
           1.0213057593631216,
           1.0520130885939118,
           1.0825812377536093,
           1.1129933160890024,
           1.1432335268690617,
           1.1732870302268583,
           1.2031398273915084,
           1.2327786626433637,
           1.2621909400094402,
           1.2913646522634463,
           1.3202883202343847,
           1.3489509407819662,
           1.3773419420835373,
           1.405451145109709,
           1.4332687303551688,
           1.4607852090458942,
           1.4879913981708324,
           1.5148783987905283,
           1.5414375771613729,
           1.5676605482855526,
           1.5935391615561258,
           1.6190654882161326,
           1.6442318103920148,
           1.6690306114963527,
           1.693454567824111,
           1.7174965411912453,
           1.7411495724853545,
           1.7644068760157814,
           1.7872618345655837,
           1.8097079950606678,
           1.8317390647823262,
           1.8533489080588603,
           1.874531543380024,
           1.895281140885023,
           1.9155920201807932,
           1.9354586484524927,
           1.9548756388326574,
           1.9738377489993864,
           1.9923398799773386,
           2.010377075118299,
           2.0279445192406804,
           2.04503753790961,
           2.06165159684125,
           2.0777823014167605,
           2.093425396292871,
           2.1085767650973914,
           2.1232324301992165,
           2.1373885525434275,
           2.1510414315430757,
           2.1641875050200587,
           2.1768233491882714,
           2.1889456786728654,
           2.20055134656008,
           2.2116373444726287,
           2.2222008026661153,
           2.2322389901423896,
           2.241749314776142,
           2.2507293234514085,
           2.259176702204943,
           2.267089276373749,
           2.2744650107442963,
           2.2813020097011987,
           2.2875985173733677,
           2.2933529177758274,
           2.298563734945601,
           2.3032296330702215,
           2.3073494166076,
           2.3109220303961338,
           2.313946559754061,
           2.316422230567228,
           2.3183484093645426,
           2.3197246033805037,
           2.3205504606043417
          ],
          [
           2.3501264491914,
           2.3498485412991874,
           2.349014889318994,
           2.347625708334373,
           2.345681356798712,
           2.343182336506647,
           2.3401292925544617,
           2.3365230132899097,
           2.33236443025201,
           2.327654618101516,
           2.322394794542876,
           2.3165863202386654,
           2.3102306987176227,
           2.3033295762775663,
           2.29588474188467,
           2.2878981270707315,
           2.279371805830295,
           2.2703079945196882,
           2.2607090517602617,
           2.2505774783484047,
           2.239915917175157,
           2.2287271531585513,
           2.2170141131921692,
           2.204779866113753,
           2.1920276226981072,
           2.178760735679019,
           2.1649826998053676,
           2.1506971519372087,
           2.1359078711881847,
           2.120618779121352,
           2.1048339400062437,
           2.0885575611458798,
           2.0717939932833986,
           2.0545477310990643,
           2.0368234138096453,
           2.018625825883527,
           1.9999598978865014,
           1.9808307074749312,
           1.9612434805549912,
           1.941203592628989,
           1.9207165703523257,
           1.899788093327651,
           1.8784239961661093,
           1.8566302708494717,
           1.8344130694313587,
           1.8117787071208666,
           1.7887336657977746,
           1.765284598015284,
           1.74143833155407,
           1.7172018746005042,
           1.6925824216324556,
           1.6675873601083466,
           1.6422242780694805,
           1.6165009727824133,
           1.5904254605678094,
           1.5640059879853299,
           1.5372510445713654,
           1.5101693773586238,
           1.4827700074447592,
           1.4550622489225877,
           1.4270557305385108,
           1.3987604205103579,
           1.3701866550133313,
           1.3413451709358255,
           1.3122471436191736,
           1.2829042304311458,
           1.253328621187742,
           1.2235330966382316,
           1.1935310964729842,
           1.1633367986130014,
           1.1329652119075386,
           1.1024322848184887,
           1.0717550332282968,
           1.0409516911983379,
           1.0100418893597942,
           0.9790468666799272,
           0.9479897226635657,
           0.9168957186838694,
           0.8857926391609663,
           0.8547112258061589,
           0.8236857012150388,
           0.7927544018154079,
           0.7619605446237143,
           0.7313531574428002,
           0.7009882079124623,
           0.6709299727976629,
           0.6412526941530742,
           0.6120425717166246,
           0.5834001376905427,
           0.5554430450685516,
           0.528309264063598,
           0.5021606076670052,
           0.47718637495535,
           0.45360668216810984,
           0.4316747224230146,
           0.41167675637677276,
           0.39392816032317246,
           0.3787635541855952,
           0.3665192916885639,
           0.3575079123180733,
           0.35198677612438073,
           0.3501264491913999,
           0.35198677612438456,
           0.35750791231808077,
           0.3665192916885749,
           0.37876355418560936,
           0.3939281603231895,
           0.41167675637679224,
           0.43167472242303623,
           0.45360668216813327,
           0.477186374955375,
           0.5021606076670315,
           0.5283092640636254,
           0.5554430450685799,
           0.5834001376905718,
           0.6120425717166542,
           0.6412526941531044,
           0.6709299727976936,
           0.7009882079124933,
           0.7313531574428316,
           0.7619605446237459,
           0.7927544018154397,
           0.8236857012150706,
           0.8547112258061909,
           0.8857926391609983,
           0.9168957186839014,
           0.9479897226635976,
           0.979046866679959,
           1.010041889359826,
           1.0409516911983694,
           1.0717550332283283,
           1.10243228481852,
           1.13296521190757,
           1.1633367986130327,
           1.193531096473015,
           1.2235330966382625,
           1.2533286211877726,
           1.282904230431176,
           1.3122471436192036,
           1.3413451709358553,
           1.3701866550133608,
           1.3987604205103872,
           1.4270557305385398,
           1.4550622489226164,
           1.4827700074447874,
           1.5101693773586518,
           1.537251044571393,
           1.5640059879853572,
           1.5904254605678365,
           1.61650097278244,
           1.6422242780695064,
           1.6675873601083724,
           1.692582421632481,
           1.7172018746005295,
           1.7414383315540949,
           1.7652845980153085,
           1.7887336657977986,
           1.81177870712089,
           1.8344130694313818,
           1.8566302708494942,
           1.878423996166131,
           1.8997880933276725,
           1.920716570352347,
           1.9412035926290094,
           1.9612434805550116,
           1.9808307074749512,
           1.999959897886521,
           2.0186258258835457,
           2.0368234138096635,
           2.0545477310990825,
           2.0717939932834164,
           2.0885575611458966,
           2.10483394000626,
           2.120618779121368,
           2.1359078711882002,
           2.1506971519372238,
           2.1649826998053827,
           2.1787607356790333,
           2.1920276226981206,
           2.204779866113766,
           2.2170141131921817,
           2.228727153158563,
           2.2399159171751686,
           2.2505774783484154,
           2.2607090517602715,
           2.2703079945196976,
           2.2793718058303045,
           2.2878981270707395,
           2.2958847418846777,
           2.3033295762775743,
           2.3102306987176293,
           2.3165863202386716,
           2.3223947945428813,
           2.3276546181015214,
           2.332364430252015,
           2.3365230132899133,
           2.3401292925544657,
           2.34318233650665,
           2.345681356798714,
           2.347625708334374,
           2.3490148893189953,
           2.3498485412991883
          ],
          [
           2.3790884038403886,
           2.378807990217812,
           2.377966822343191,
           2.376565119191491,
           2.3746032457064876,
           2.372081712779275,
           2.3690011772186437,
           2.365362441713837,
           2.361166454790294,
           2.356414310759198,
           2.3511072496617227,
           2.3452466572091293,
           2.338834064719954,
           2.3318711490557695,
           2.3243597325571685,
           2.3163017829818457,
           2.307699413446863,
           2.2985548823774473,
           2.2888705934649187,
           2.278649095636648,
           2.2678930830412507,
           2.2566053950525666,
           2.2447890162963726,
           2.232447076704166,
           2.2195828515988403,
           2.2061997618175706,
           2.1923013738778017,
           2.177891400192847,
           2.1629736993443145,
           2.147552276419362,
           2.13163128342162,
           2.1152150197656447,
           2.0983079328658043,
           2.0809146188317698,
           2.06303982328412,
           2.04468844230516,
           2.0258655235417793,
           2.006576267479171,
           1.9868260289064752,
           1.9666203185979574,
           1.9459648052362335,
           1.9248653176073516,
           1.903327847101298,
           1.881358550555811,
           1.8589637534863122,
           1.8361499537504122,
           1.8129238257019684,
           1.7892922248971566,
           1.7652621934236743,
           1.7408409659342123,
           1.7160359764769308,
           1.6908548662291754,
           1.665305492256377,
           1.6393959374364253,
           1.6131345217112552,
           1.5865298148525782,
           1.5595906509582496,
           1.5323261449306733,
           1.5047457112298264,
           1.4768590852423111,
           1.4486763476658155,
           1.4202079523773716,
           1.3914647583362252,
           1.3624580661707524,
           1.3331996602172453,
           1.3037018569208276,
           1.2739775606806114,
           1.2440403284290464,
           1.2139044444873963,
           1.1835850075454908,
           1.1530980319868078,
           1.1224605662348774,
           1.0916908313529257,
           1.0608083838086857,
           1.0298343071485183,
           0.9987914383431258,
           0.967704635811012,
           0.9366010976410354,
           0.9055107403720049,
           0.8744666508959609,
           0.8435056266757709,
           0.8126688225271637,
           0.7820025256789912,
           0.7515590845606146,
           0.7213980204525368,
           0.6915873541289226,
           0.6622051807175503,
           0.6333415230985651,
           0.6051004837342058,
           0.5776026912329811,
           0.5509879926672183,
           0.5254182636739393,
           0.5010800806890082,
           0.4781868086711316,
           0.45697939837984863,
           0.4377248834036417,
           0.42071130138397445,
           0.4062377095916518,
           0.394598385014931,
           0.386061449835492,
           0.3808440584937032,
           0.37908840384038855,
           0.38084405849370684,
           0.3860614498354991,
           0.39459838501494143,
           0.4062377095916653,
           0.42071130138399077,
           0.43772488340366034,
           0.4569793983798695,
           0.4781868086711544,
           0.5010800806890326,
           0.5254182636739649,
           0.5509879926672453,
           0.577602691233009,
           0.6051004837342343,
           0.6333415230985944,
           0.6622051807175802,
           0.6915873541289531,
           0.7213980204525676,
           0.7515590845606458,
           0.7820025256790226,
           0.8126688225271953,
           0.8435056266758026,
           0.8744666508959927,
           0.9055107403720367,
           0.9366010976410672,
           0.9677046358110439,
           0.9987914383431576,
           1.0298343071485503,
           1.0608083838087177,
           1.0916908313529574,
           1.122460566234909,
           1.1530980319868396,
           1.183585007545522,
           1.2139044444874274,
           1.2440403284290775,
           1.2739775606806423,
           1.303701856920858,
           1.3331996602172755,
           1.3624580661707824,
           1.3914647583362547,
           1.4202079523774012,
           1.4486763476658446,
           1.4768590852423402,
           1.5047457112298548,
           1.5323261449307017,
           1.5595906509582773,
           1.5865298148526057,
           1.6131345217112825,
           1.639395937436452,
           1.6653054922564037,
           1.6908548662292016,
           1.7160359764769566,
           1.7408409659342376,
           1.7652621934236992,
           1.7892922248971812,
           1.8129238257019928,
           1.836149953750436,
           1.8589637534863355,
           1.881358550555834,
           1.9033278471013204,
           1.924865317607374,
           1.9459648052362553,
           1.9666203185979783,
           1.9868260289064956,
           2.006576267479191,
           2.025865523541799,
           2.044688442305179,
           2.0630398232841385,
           2.080914618831788,
           2.098307932865822,
           2.115215019765661,
           2.131631283421637,
           2.147552276419378,
           2.1629736993443305,
           2.1778914001928618,
           2.192301373877817,
           2.2061997618175853,
           2.219582851598854,
           2.232447076704179,
           2.244789016296385,
           2.256605395052578,
           2.2678930830412622,
           2.278649095636659,
           2.288870593464929,
           2.2985548823774566,
           2.3076994134468722,
           2.3163017829818546,
           2.324359732557176,
           2.331871149055777,
           2.3388340647199612,
           2.3452466572091355,
           2.3511072496617285,
           2.3564143107592033,
           2.361166454790299,
           2.365362441713841,
           2.369001177218648,
           2.3720817127792775,
           2.3746032457064894,
           2.376565119191493,
           2.377966822343193,
           2.3788079902178123
          ],
          [
           2.407683614941698,
           2.407400786465576,
           2.4065523753326565,
           2.405138604426379,
           2.4031598452095264,
           2.400616617710072,
           2.3975095905019073,
           2.393839580680991,
           2.3896075538376276,
           2.384814624025757,
           2.379462053730303,
           2.3735512538338144,
           2.3670837835838396,
           2.3600613505626558,
           2.3524858106612228,
           2.34435916805945,
           2.335683575215107,
           2.326461332864022,
           2.3166948900344577,
           2.3063868440789177,
           2.29553994072697,
           2.2841570741630584,
           2.272241287133707,
           2.259795771088987,
           2.2468238663636106,
           2.233329062403616,
           2.2193149980452156,
           2.2047854618530756,
           2.189744392526095,
           2.1741958793795964,
           2.1581441629138087,
           2.1415936354796234,
           2.124548842053792,
           2.107014481137106,
           2.088995405790621,
           2.0704966248267094,
           2.0515233041736702,
           2.032080768434794,
           2.012174502665293,
           1.991810154393281,
           1.9709935359142121,
           1.9497306268917862,
           1.9280275773024882,
           1.9058907107656413,
           1.8833265283062588,
           1.860341712604159,
           1.8369431327899355,
           1.8131378498565196,
           1.7889331227645262,
           1.7643364153304235,
           1.7393554039991856,
           1.7139979866176733,
           1.688272292341967,
           1.6621866928316353,
           1.6357498149070002,
           1.6089705548724336,
           1.58185809474037,
           1.554421920627892,
           1.5266718436415365,
           1.4986180236176625,
           1.4702709961468914,
           1.441641703383681,
           1.412741529228339,
           1.3835823395715536,
           1.3541765284142497,
           1.3245370708224669,
           1.2946775838531452,
           1.2646123967984397,
           1.2343566323510993,
           1.2039263006008745,
           1.1733384081431013,
           1.1426110850292297,
           1.1117637328314867,
           1.0808171977495273,
           1.0497939734785782,
           1.0187184395122073,
           0.987617141697129,
           0.9565191232220615,
           0.9254563158350347,
           0.8944640029624333,
           0.8635813685469855,
           0.8328521477896573,
           0.8023253984577065,
           0.7720564137670652,
           0.742107799608109,
           0.7125507392607264,
           0.6834664663948319,
           0.6549479599084516,
           0.6271018586569576,
           0.6000505654068261,
           0.5739344605219003,
           0.5489140683278294,
           0.5251719038405691,
           0.502913569306688,
           0.48236747559894755,
           0.4637823659886404,
           0.4474216963055106,
           0.433554008081084,
           0.4224388867618337,
           0.41430904447211747,
           0.40935042796555193,
           0.4076836149416981,
           0.4093504279655554,
           0.4143090444721242,
           0.42243888676184366,
           0.43355400808109684,
           0.44742169630552625,
           0.46378236598865835,
           0.4823674755989677,
           0.5029135693067099,
           0.5251719038405926,
           0.5489140683278545,
           0.5739344605219266,
           0.6000505654068534,
           0.6271018586569858,
           0.6549479599084804,
           0.6834664663948614,
           0.7125507392607566,
           0.7421077996081396,
           0.7720564137670963,
           0.8023253984577376,
           0.8328521477896889,
           0.8635813685470173,
           0.8944640029624651,
           0.9254563158350666,
           0.9565191232220934,
           0.9876171416971611,
           1.0187184395122393,
           1.04979397347861,
           1.0808171977495593,
           1.1117637328315184,
           1.1426110850292612,
           1.1733384081431326,
           1.2039263006009058,
           1.2343566323511304,
           1.2646123967984708,
           1.2946775838531763,
           1.3245370708224973,
           1.35417652841428,
           1.3835823395715836,
           1.4127415292283687,
           1.4416417033837106,
           1.4702709961469207,
           1.4986180236176914,
           1.5266718436415654,
           1.5544219206279202,
           1.5818580947403977,
           1.6089705548724613,
           1.6357498149070273,
           1.6621866928316622,
           1.6882722923419935,
           1.7139979866176995,
           1.7393554039992114,
           1.764336415330449,
           1.7889331227645513,
           1.8131378498565442,
           1.8369431327899597,
           1.860341712604183,
           1.8833265283062823,
           1.9058907107656644,
           1.9280275773025106,
           1.9497306268918082,
           1.9709935359142339,
           1.991810154393302,
           2.0121745026653133,
           2.0320807684348146,
           2.0515233041736898,
           2.0704966248267285,
           2.0889954057906395,
           2.1070144811371243,
           2.12454884205381,
           2.1415936354796403,
           2.158144162913825,
           2.1741958793796132,
           2.1897443925261113,
           2.20478546185309,
           2.2193149980452302,
           2.2333290624036306,
           2.246823866363624,
           2.2597957710889998,
           2.272241287133719,
           2.28415707416307,
           2.295539940726982,
           2.306386844078929,
           2.316694890034468,
           2.3264613328640316,
           2.3356835752151164,
           2.344359168059459,
           2.352485810661231,
           2.360061350562663,
           2.3670837835838463,
           2.3735512538338206,
           2.379462053730309,
           2.384814624025762,
           2.3896075538376316,
           2.3938395806809956,
           2.397509590501911,
           2.4006166177100754,
           2.403159845209529,
           2.405138604426381,
           2.406552375332658,
           2.407400786465576
          ],
          [
           2.4358844184753803,
           2.435599263986462,
           2.434743876119476,
           2.4333184816723343,
           2.431323458636951,
           2.428759336192647,
           2.425626794697497,
           2.4219266656782485,
           2.417659931819578,
           2.4128277269536667,
           2.4074313360512543,
           2.4014721952155424,
           2.394951891680537,
           2.387872163815631,
           2.380234901138495,
           2.3720421443385824,
           2.3632960853138494,
           2.3539990672235853,
           2.344153584560587,
           2.333762283246245,
           2.3228279607525306,
           2.3113535662552733,
           2.2993422008235904,
           2.2867971176508592,
           2.27372172233317,
           2.2601195732018295,
           2.245994381717198,
           2.2313500129318657,
           2.2161904860320907,
           2.2005199749673183,
           2.18434280917869,
           2.167663474438636,
           2.1504866138149716,
           2.1328170287743906,
           2.114659680441946,
           2.096019691034975,
           2.076902345492041,
           2.0573130933198622,
           2.037257550683902,
           2.0167415027713456,
           1.9957709064586735,
           1.9743518933199748,
           1.9524907730166348,
           1.9301940371141504,
           1.9074683633776774,
           1.8843206206045817,
           1.8607578740599597,
           1.8367873915898711,
           1.8124166504971668,
           1.7876533452764725,
           1.7625053963183606,
           1.7369809597083599,
           1.7110884382645317,
           1.6848364939783762,
           1.6582340620482965,
           1.631290366723403,
           1.604014939208822,
           1.5764176379227688,
           1.5485086714415568,
           1.520298624522703,
           1.4917984876599617,
           1.4630196906992894,
           1.4339741411337565,
           1.4046742678009547,
           1.3751330708318301,
           1.3453641788491246,
           1.3153819145914882,
           1.2852013703517007,
           1.2548384948712337,
           1.2243101936369472,
           1.193634444888947,
           1.1628304340831794,
           1.131918710071778,
           1.1009213668839255,
           1.0698622557271993,
           1.0387672327020674,
           1.0076644487480484,
           0.9765846895333842,
           0.9455617743672035,
           0.9146330247440565,
           0.8838398147853288,
           0.853228217528566,
           0.8228497625557228,
           0.7927623215267533,
           0.7630311382579532,
           0.7337300181817398,
           0.7049426869770062,
           0.6767643177967955,
           0.6493032078429932,
           0.6226825539362444,
           0.5970422280269547,
           0.5725403816668492,
           0.5493546090498836,
           0.5276822723144149,
           0.5077394533787926,
           0.4897578782279066,
           0.4739791274917155,
           0.4606455968772624,
           0.4499881033900844,
           0.4422107915230808,
           0.43747497266628754,
           0.43588441847538034,
           0.43747497266629076,
           0.44221079152308734,
           0.44998810339009393,
           0.46064559687727485,
           0.47397912749173055,
           0.48975787822792394,
           0.507739453378812,
           0.5276822723144363,
           0.5493546090499067,
           0.5725403816668737,
           0.5970422280269806,
           0.6226825539362711,
           0.649303207843021,
           0.6767643177968239,
           0.7049426869770353,
           0.7337300181817696,
           0.7630311382579834,
           0.792762321526784,
           0.8228497625557539,
           0.8532282175285973,
           0.8838398147853603,
           0.9146330247440881,
           0.9455617743672352,
           0.976584689533416,
           1.0076644487480804,
           1.0387672327020994,
           1.0698622557272315,
           1.1009213668839575,
           1.1319187100718098,
           1.1628304340832114,
           1.1936344448889786,
           1.2243101936369787,
           1.2548384948712648,
           1.2852013703517318,
           1.315381914591519,
           1.3453641788491553,
           1.3751330708318603,
           1.4046742678009847,
           1.4339741411337865,
           1.463019690699319,
           1.4917984876599912,
           1.520298624522732,
           1.5485086714415854,
           1.5764176379227974,
           1.6040149392088503,
           1.6312903667234313,
           1.658234062048324,
           1.6848364939784035,
           1.7110884382645584,
           1.7369809597083863,
           1.7625053963183865,
           1.7876533452764978,
           1.812416650497192,
           1.836787391589896,
           1.8607578740599842,
           1.8843206206046055,
           1.9074683633777008,
           1.9301940371141735,
           1.9524907730166572,
           1.974351893319997,
           1.9957709064586948,
           2.0167415027713664,
           2.0372575506839223,
           2.057313093319883,
           2.0769023454920608,
           2.096019691034994,
           2.1146596804419646,
           2.132817028774409,
           2.1504866138149903,
           2.167663474438654,
           2.1843428091787067,
           2.200519974967335,
           2.216190486032107,
           2.2313500129318804,
           2.245994381717213,
           2.260119573201844,
           2.2737217223331836,
           2.2867971176508726,
           2.2993422008236024,
           2.3113535662552853,
           2.3228279607525426,
           2.3337622832462555,
           2.3441535845605976,
           2.3539990672235955,
           2.3632960853138587,
           2.3720421443385913,
           2.3802349011385027,
           2.3878721638156386,
           2.394951891680544,
           2.401472195215549,
           2.40743133605126,
           2.4128277269536724,
           2.4176599318195824,
           2.421926665678253,
           2.4256267946975005,
           2.4287593361926496,
           2.4313234586369536,
           2.4333184816723357,
           2.4347438761194766,
           2.435599263986462
          ],
          [
           2.4636635319853366,
           2.4633761383305792,
           2.462514034268843,
           2.4610774505078568,
           2.4590667715610195,
           2.456482535748495,
           2.4533254351994076,
           2.449596315855794,
           2.4452961774791744,
           2.4404261736608057,
           2.4349876118369003,
           2.4289819533103096,
           2.4224108132804094,
           2.415275960883181,
           2.407579319243734,
           2.3993229655438193,
           2.3905091311071764,
           2.3811402015058856,
           2.371218716691274,
           2.3607473711532942,
           2.349729014112727,
           2.338166649751035,
           2.3260634374831857,
           2.3134226922793424,
           2.300247885041924,
           2.2865426430452347,
           2.2723107504456,
           2.2575561488708034,
           2.2422829380985387,
           2.2264953768346154,
           2.2101978836028473,
           2.1933950377597977,
           2.1760915806490173,
           2.1582924169110416,
           2.140002615967184,
           2.1212274136972344,
           2.101972214333445,
           2.082242592595776,
           2.0620442960962695,
           2.0413832480437586,
           2.020265550283805,
           1.9986974867130438,
           1.9766855271118986,
           1.9542363314451308,
           1.9313567546859502,
           1.908053852226542,
           1.8843348859460614,
           1.860207331016514,
           1.8356788835377065,
           1.8107574691048531,
           1.7854512524266777,
           1.7597686481283674,
           1.7337183328927803,
           1.7073092591154344,
           1.6805506702744646,
           1.6534521182466029,
           1.6260234828350382,
           1.5982749938156728,
           1.5702172558558294,
           1.5418612767152209,
           1.5132184992044266,
           1.4843008374531128,
           1.4551207181309227,
           1.4256911273709942,
           1.39602566427253,
           1.3661386020084825,
           1.3360449577416482,
           1.305760572762537,
           1.2753022045114772,
           1.2446876324427756,
           1.2139357800387294,
           1.183066855695415,
           1.1521025156910418,
           1.121066053022626,
           1.0899826165692597,
           1.0588794658207807,
           1.027786267306224,
           0.9967354398674223,
           0.9657625570369504,
           0.9349068159615991,
           0.9042115834911496,
           0.8737250310963881,
           0.8435008709659785,
           0.813599205592374,
           0.7840875018134568,
           0.7550416967431474,
           0.7265474359885744,
           0.6987014321421134,
           0.671612911212544,
           0.6454050832072113,
           0.6202165268842789,
           0.5962023145949659,
           0.5735346202617995,
           0.5524024566684206,
           0.5330100928437382,
           0.5155736404542124,
           0.5003153218623412,
           0.48745510842747347,
           0.47719980336262063,
           0.46973024253987106,
           0.46518799514938153,
           0.46366353198533655,
           0.4651879951493847,
           0.4697302425398772,
           0.47719980336262985,
           0.48745510842748546,
           0.5003153218623557,
           0.5155736404542292,
           0.5330100928437572,
           0.5524024566684415,
           0.5735346202618219,
           0.5962023145949897,
           0.6202165268843043,
           0.6454050832072379,
           0.6716129112125714,
           0.6987014321421418,
           0.7265474359886034,
           0.755041696743177,
           0.784087501813487,
           0.8135992055924044,
           0.8435008709660095,
           0.8737250310964192,
           0.9042115834911809,
           0.9349068159616306,
           0.9657625570369821,
           0.9967354398674542,
           1.0277862673062559,
           1.0588794658208127,
           1.0899826165692919,
           1.121066053022658,
           1.1521025156910738,
           1.1830668556954465,
           1.2139357800387611,
           1.2446876324428071,
           1.2753022045115088,
           1.3057605727625683,
           1.3360449577416793,
           1.3661386020085133,
           1.3960256642725608,
           1.4256911273710247,
           1.455120718130953,
           1.4843008374531428,
           1.5132184992044564,
           1.54186127671525,
           1.5702172558558585,
           1.5982749938157015,
           1.6260234828350666,
           1.6534521182466306,
           1.6805506702744923,
           1.7073092591154615,
           1.7337183328928072,
           1.759768648128394,
           1.7854512524267039,
           1.810757469104879,
           1.835678883537732,
           1.8602073310165388,
           1.8843348859460862,
           1.908053852226566,
           1.931356754685974,
           1.954236331445154,
           1.9766855271119215,
           1.9986974867130662,
           2.0202655502838267,
           2.04138324804378,
           2.0620442960962904,
           2.0822425925957964,
           2.1019722143334656,
           2.121227413697253,
           2.140002615967203,
           2.1582924169110607,
           2.1760915806490355,
           2.193395037759815,
           2.210197883602865,
           2.2264953768346314,
           2.2422829380985543,
           2.2575561488708193,
           2.272310750445615,
           2.2865426430452493,
           2.300247885041938,
           2.3134226922793557,
           2.3260634374831985,
           2.3381666497510474,
           2.349729014112739,
           2.360747371153305,
           2.371218716691285,
           2.3811402015058953,
           2.3905091311071858,
           2.399322965543828,
           2.407579319243742,
           2.415275960883189,
           2.422410813280417,
           2.428981953310316,
           2.4349876118369065,
           2.440426173660811,
           2.4452961774791793,
           2.449596315855798,
           2.453325435199411,
           2.456482535748498,
           2.4590667715610217,
           2.4610774505078585,
           2.462514034268844,
           2.46337613833058
          ],
          [
           2.4909940809733313,
           2.4907045330518747,
           2.4898359674878416,
           2.488388618883923,
           2.486362878250302,
           2.4837592930135575,
           2.480578567029841,
           2.4768215606030535,
           2.472489290508953,
           2.467582930026355,
           2.4621038089768197,
           2.456053413774456,
           2.449433387487738,
           2.4422455299154966,
           2.434491797679533,
           2.426174304336628,
           2.417295320513029,
           2.407857274064881,
           2.3978627502684398,
           2.3873144920443345,
           2.376215400220615,
           2.364568533839808,
           2.3523771105157776,
           2.3396445068467777,
           2.326374258891762,
           2.312570062717753,
           2.2982357750268836,
           2.283375413872642,
           2.2679931594758345,
           2.252093355151921,
           2.235680508362594,
           2.2187592919058887,
           2.2013345452606305,
           2.1834112761027917,
           2.16499466201324,
           2.146090052398575,
           2.1267029706491822,
           2.1068391165614027,
           2.086504369053839,
           2.0657047892113334,
           2.0444466236941334,
           2.0227363085542955,
           2.0005804735064707,
           1.9779859467060674,
           1.9549597600944126,
           1.9315091553780914,
           1.9076415907182989,
           1.8833647482159221,
           1.8586865422894134,
           1.8336151290555323,
           1.8081589168380061,
           1.782326577946415,
           1.7561270618875031,
           1.7295696101941649,
           1.7026637730839715,
           1.6754194281900665,
           1.6478468016431573,
           1.6199564918251874,
           1.591759496164001,
           1.5632672413952764,
           1.5344916177845718,
           1.5054450178803043,
           1.4761403804599122,
           1.4465912404387822,
           1.4168117856376492,
           1.3868169214524748,
           1.35662234464528,
           1.3262446276796573,
           1.2957013152660435,
           1.2650110350653665,
           1.2341936248321244,
           1.203270278666664,
           1.1722637154990099,
           1.141198373450384,
           1.1101006343196658,
           1.0789990831235972,
           1.0479248083792048,
           1.0169117496424114,
           0.9859970996796523,
           0.9552217694946188,
           0.9246309251640091,
           0.8942746058954003,
           0.8642084326538892,
           0.8344944157213195,
           0.8052018670667832,
           0.7764084185664192,
           0.7482011387131646,
           0.7206777268835728,
           0.6939477434236494,
           0.6681338034071804,
           0.6433726196239965,
           0.619815724886712,
           0.5976296365120741,
           0.5769951536308955,
           0.5581054165002001,
           0.5411623340432979,
           0.5263710415323061,
           0.5139322296313852,
           0.5040325191929363,
           0.496833527450494,
           0.49246078831706025,
           0.4909940809733314,
           0.49246078831706325,
           0.4968335274504999,
           0.5040325191929452,
           0.5139322296313967,
           0.5263710415323201,
           0.5411623340433143,
           0.5581054165002185,
           0.5769951536309159,
           0.5976296365120961,
           0.6198157248867354,
           0.6433726196240215,
           0.6681338034072064,
           0.6939477434236765,
           0.7206777268836007,
           0.7482011387131933,
           0.7764084185664484,
           0.8052018670668131,
           0.8344944157213499,
           0.86420843265392,
           0.8942746058954312,
           0.9246309251640403,
           0.9552217694946504,
           0.9859970996796841,
           1.0169117496424434,
           1.0479248083792367,
           1.0789990831236291,
           1.1101006343196977,
           1.141198373450416,
           1.1722637154990416,
           1.2032702786666958,
           1.234193624832156,
           1.2650110350653982,
           1.2957013152660752,
           1.3262446276796889,
           1.3566223446453114,
           1.3868169214525057,
           1.41681178563768,
           1.4465912404388126,
           1.4761403804599427,
           1.5054450178803347,
           1.5344916177846013,
           1.5632672413953057,
           1.5917594961640302,
           1.6199564918252165,
           1.6478468016431858,
           1.6754194281900945,
           1.7026637730839993,
           1.7295696101941922,
           1.7561270618875302,
           1.782326577946442,
           1.8081589168380325,
           1.8336151290555582,
           1.858686542289439,
           1.8833647482159475,
           1.9076415907183235,
           1.9315091553781154,
           1.9549597600944362,
           1.9779859467060907,
           2.000580473506494,
           2.022736308554318,
           2.0444466236941556,
           2.0657047892113547,
           2.08650436905386,
           2.106839116561423,
           2.1267029706492027,
           2.146090052398595,
           2.164994662013259,
           2.1834112761028104,
           2.201334545260649,
           2.218759291905906,
           2.2356805083626115,
           2.2520933551519375,
           2.267993159475851,
           2.2833754138726574,
           2.2982357750268987,
           2.3125700627177674,
           2.326374258891776,
           2.339644506846791,
           2.3523771105157896,
           2.3645685338398197,
           2.3762154002206266,
           2.387314492044345,
           2.3978627502684504,
           2.407857274064891,
           2.417295320513038,
           2.426174304336637,
           2.434491797679541,
           2.4422455299155046,
           2.449433387487745,
           2.4560534137744625,
           2.462103808976825,
           2.46758293002636,
           2.4724892905089577,
           2.476821560603058,
           2.4805785670298444,
           2.48375929301356,
           2.486362878250304,
           2.4883886188839246,
           2.489835967487842,
           2.490704533051875
          ],
          [
           2.5178496248983344,
           2.5175580057105655,
           2.5166832276371878,
           2.5152255291512344,
           2.5131853077186825,
           2.510563119815218,
           2.507359680950482,
           2.50357586570057,
           2.499212707749807,
           2.4942713999430377,
           2.4887532943499475,
           2.4826599023431735,
           2.475992894692248,
           2.468754101675717,
           2.4609455132140665,
           2.4525692790264646,
           2.4436277088146316,
           2.434123272477582,
           2.42405860036139,
           2.4134364835485673,
           2.4022598741921644,
           2.3905318859002316,
           2.3782557941768725,
           2.3654350369267942,
           2.3520732150309325,
           2.338174093001573,
           2.3237415997262385,
           2.308779829310568,
           2.293293042031524,
           2.2772856654134217,
           2.26076229544063,
           2.243727697922251,
           2.226186810025763,
           2.2081447419984346,
           2.1896067790974065,
           2.1705783837516512,
           2.151065197981628,
           2.1310730461053833,
           2.1106079377631586,
           2.0896760712962843,
           2.06828383752036,
           2.046437823937492,
           2.0241448194377543,
           2.001411819546183,
           1.978246032278585,
           1.9546548846773943,
           1.9306460301078465,
           1.9062273564051226,
           1.881406994974917,
           1.8561933309634797,
           1.8305950146287349,
           1.804620974061978,
           1.7782804294302634,
           1.751582908933355,
           1.7245382666965436,
           1.6971567028523893,
           1.6694487861012044,
           1.6414254790827447,
           1.6130981669411262,
           1.5844786895226086,
           1.555579377713,
           1.5264130944996628,
           1.4969932814343925,
           1.4673340112800257,
           1.4374500477481322,
           1.407356913380627,
           1.3770709667980274,
           1.3466094907354051,
           1.31599079251819,
           1.2852343188988167,
           1.2543607874868004,
           1.2233923373644309,
           1.192352701892582,
           1.1612674071796691,
           1.1301640002126494,
           1.0990723112287637,
           1.0680247555296956,
           1.0370566805831058,
           1.0062067648784374,
           0.9755174755339502,
           0.9450355919764529,
           0.9148128029571114,
           0.884906383458006,
           0.8553799562895908,
           0.8263043398113263,
           0.7977584774362231,
           0.7698304353450915,
           0.7426184407887831,
           0.7162319129076388,
           0.6907924095135319,
           0.6664343755430062,
           0.643305531975513,
           0.6215666907373779,
           0.6013907290854216,
           0.5829604208603348,
           0.5664648249908523,
           0.552094003799805,
           0.5400320144907836,
           0.53044840004841,
           0.5234887767065259,
           0.5192654961488097,
           0.5178496248983345,
           0.5192654961488126,
           0.5234887767065317,
           0.5304484000484185,
           0.5400320144907949,
           0.5520940037998187,
           0.566464824990868,
           0.5829604208603529,
           0.6013907290854414,
           0.6215666907373995,
           0.643305531975536,
           0.6664343755430306,
           0.6907924095135575,
           0.7162319129076654,
           0.7426184407888108,
           0.7698304353451197,
           0.797758477436252,
           0.8263043398113561,
           0.8553799562896209,
           0.8849063834580366,
           0.9148128029571422,
           0.9450355919764841,
           0.9755174755339815,
           1.0062067648784692,
           1.0370566805831376,
           1.0680247555297273,
           1.0990723112287955,
           1.1301640002126812,
           1.1612674071797011,
           1.1923527018926139,
           1.2233923373644628,
           1.2543607874868319,
           1.2852343188988484,
           1.3159907925182215,
           1.3466094907354367,
           1.3770709667980587,
           1.4073569133806578,
           1.437450047748163,
           1.4673340112800564,
           1.4969932814344231,
           1.5264130944996932,
           1.5555793777130302,
           1.5844786895226384,
           1.6130981669411553,
           1.6414254790827738,
           1.669448786101233,
           1.6971567028524177,
           1.7245382666965714,
           1.7515829089333825,
           1.778280429430291,
           1.8046209740620052,
           1.8305950146287615,
           1.856193330963506,
           1.8814069949749426,
           1.9062273564051477,
           1.9306460301078714,
           1.9546548846774183,
           1.9782460322786088,
           2.001411819546206,
           2.0241448194377774,
           2.0464378239375147,
           2.068283837520382,
           2.0896760712963065,
           2.11060793776318,
           2.131073046105404,
           2.1510651979816484,
           2.1705783837516717,
           2.189606779097426,
           2.2081447419984532,
           2.2261868100257813,
           2.2437276979222687,
           2.2607622954406463,
           2.2772856654134386,
           2.29329304203154,
           2.3087798293105837,
           2.3237415997262536,
           2.3381740930015877,
           2.3520732150309467,
           2.365435036926808,
           2.378255794176886,
           2.3905318859002436,
           2.4022598741921763,
           2.4134364835485784,
           2.4240586003614006,
           2.4341232724775916,
           2.443627708814641,
           2.4525692790264744,
           2.4609455132140745,
           2.4687541016757244,
           2.4759928946922556,
           2.4826599023431806,
           2.4887532943499533,
           2.494271399943043,
           2.499212707749812,
           2.5035758657005744,
           2.507359680950486,
           2.510563119815221,
           2.5131853077186856,
           2.515225529151236,
           2.5166832276371887,
           2.517558005710566
          ],
          [
           2.5442041827560367,
           2.5439105734552343,
           2.543029826321043,
           2.5415621836629136,
           2.539508049346089,
           2.536867988816251,
           2.5336427291348538,
           2.529833159025979,
           2.5254403289358107,
           2.5204654511060474,
           2.514909899662902,
           2.5087752107235426,
           2.502063082522209,
           2.494775375558473,
           2.486914112770503,
           2.478481479736529,
           2.469479824908085,
           2.4599116598790256,
           2.4497796596947707,
           2.439086663206687,
           2.427835673477097,
           2.41602985824094,
           2.4036725504307532,
           2.390767248772361,
           2.377317618459391,
           2.363327491915613,
           2.3488008696549882,
           2.333741921250386,
           2.318154986423052,
           2.3020445762661588,
           2.285415374617221,
           2.2682722395956825,
           2.250620205323768,
           2.2324644838506393,
           2.2138104673020553,
           2.1946637302802405,
           2.1750300325413723,
           2.1549153219811994,
           2.134325737962804,
           2.113267615024408,
           2.0917474870095702,
           2.0697720916671125,
           2.0473483757737765,
           2.0244835008390174,
           2.001184849458643,
           1.977460032392259,
           1.95331689644893,
           1.9287635332761943,
           1.9038082891598471,
           1.8784597759559463,
           1.8527268832925416,
           1.8266187921970833,
           1.8001449903266025,
           1.773315289002123,
           1.7461398422767747,
           1.7186291682994175,
           1.6907941732729133,
           1.6626461783493256,
           1.6341969498542779,
           1.6054587332905534,
           1.5764442916381072,
           1.5471669485454946,
           1.5176406370980848,
           1.4878799549533435,
           1.4579002267552794,
           1.427717574881499,
           1.397348999740169,
           1.3668124710238376,
           1.3361270315460025,
           1.3053129155381993,
           1.2743916835737847,
           1.2433863766125413,
           1.2123216920298003,
           1.1812241849049567,
           1.1501224982935496,
           1.119047626685483,
           1.0880332173414087,
           1.0571159146683071,
           1.026335753191851,
           0.995736604925301,
           0.9653666868971138,
           0.9352791340955159,
           0.9055326418466207,
           0.8761921792781666,
           0.84732977150202,
           0.8190253417656805,
           0.7913675951702105,
           0.7644549115450553,
           0.7383961955410765,
           0.7133116059352447,
           0.6893330531328852,
           0.6666043149125254,
           0.6452805791771903,
           0.6255271865131439,
           0.6075173277982274,
           0.5914284717398701,
           0.5774373761732585,
           0.5657136938318644,
           0.5564124213720216,
           0.5496657334453733,
           0.5455750272374409,
           0.5442041827560364,
           0.5455750272374437,
           0.549665733445379,
           0.5564124213720298,
           0.5657136938318754,
           0.5774373761732717,
           0.5914284717398856,
           0.6075173277982451,
           0.6255271865131633,
           0.6452805791772114,
           0.6666043149125479,
           0.6893330531329093,
           0.7133116059352699,
           0.7383961955411029,
           0.7644549115450824,
           0.7913675951702384,
           0.8190253417657094,
           0.8473297715020495,
           0.8761921792781965,
           0.9055326418466512,
           0.9352791340955466,
           0.9653666868971449,
           0.9957366049253322,
           1.0263357531918824,
           1.0571159146683389,
           1.0880332173414402,
           1.1190476266855147,
           1.1501224982935816,
           1.1812241849049887,
           1.2123216920298323,
           1.2433863766125728,
           1.2743916835738165,
           1.305312915538231,
           1.336127031546034,
           1.3668124710238694,
           1.3973489997402,
           1.42771757488153,
           1.4579002267553103,
           1.4878799549533739,
           1.5176406370981155,
           1.5471669485455253,
           1.5764442916381374,
           1.605458733290583,
           1.6341969498543072,
           1.6626461783493547,
           1.6907941732729421,
           1.7186291682994461,
           1.7461398422768026,
           1.7733152890021506,
           1.8001449903266298,
           1.82661879219711,
           1.8527268832925685,
           1.8784597759559727,
           1.9038082891598729,
           1.9287635332762196,
           1.953316896448955,
           1.9774600323922833,
           2.001184849458667,
           2.0244835008390414,
           2.0473483757737996,
           2.0697720916671356,
           2.091747487009592,
           2.1132676150244296,
           2.134325737962825,
           2.1549153219812207,
           2.1750300325413927,
           2.1946637302802605,
           2.2138104673020744,
           2.2324644838506584,
           2.250620205323787,
           2.2682722395957,
           2.285415374617238,
           2.3020445762661756,
           2.318154986423068,
           2.333741921250402,
           2.348800869655004,
           2.363327491915629,
           2.377317618459405,
           2.3907672487723732,
           2.403672550430766,
           2.4160298582409525,
           2.427835673477109,
           2.439086663206698,
           2.4497796596947814,
           2.4599116598790363,
           2.469479824908094,
           2.4784814797365375,
           2.4869141127705108,
           2.4947753755584805,
           2.5020630825222163,
           2.508775210723549,
           2.5149098996629076,
           2.5204654511060527,
           2.525440328935816,
           2.529833159025984,
           2.5336427291348578,
           2.5368679888162546,
           2.5395080493460918,
           2.5415621836629145,
           2.5430298263210442,
           2.543910573455235
          ],
          [
           2.570032258213792,
           2.569736738159881,
           2.5688502600303904,
           2.567373069928419,
           2.565305578047175,
           2.562648358702486,
           2.5594021503791935,
           2.5555678557923223,
           2.5511465419642,
           2.546139440318935,
           2.540547946796002,
           2.534373621984928,
           2.527618191283446,
           2.5202835450817593,
           2.5123717389759657,
           2.5038849940140393,
           2.494825696978191,
           2.4851964007078626,
           2.4749998244680986,
           2.464238854368528,
           2.4529165438387923,
           2.441036114166836,
           2.428600955107159,
           2.415614625566879,
           2.4020808543782426,
           2.388003541167136,
           2.3733867573281087,
           2.358234747117537,
           2.342551928877747,
           2.326342896406244,
           2.309612420485708,
           2.2923654505920457,
           2.274607116799637,
           2.256342731904985,
           2.2375777937922483,
           2.2183179880667456,
           2.1985691909853706,
           2.178337472716109,
           2.1576291009624953,
           2.1364505449929214,
           2.1148084801193416,
           2.09270979267512,
           2.0701615855476585,
           2.047171184328103,
           2.023746144147978,
           1.9998942572811798,
           1.9756235615994906,
           1.9509423499808594,
           1.9258591807823493,
           1.9003828895040427,
           1.874522601786685,
           1.8482877479046986,
           1.8216880789377785,
           1.7947336848290567,
           1.7674350145662807,
           1.7398028987551122,
           1.7118485748913381,
           1.6835837156820985,
           1.6550204608162464,
           1.6261714526416189,
           1.5970498762735639,
           1.5676695047359535,
           1.538044749824659,
           1.508190719485942,
           1.4781232826204131,
           1.4478591423593956,
           1.417415919017159,
           1.3868122441021236,
           1.3560678669754342,
           1.325203775978697,
           1.294242336116264,
           1.2632074456722882,
           1.2321247144684528,
           1.201021666821588,
           1.1699279726338903,
           1.1388757104281957,
           1.107899666502784,
           1.0770376746861063,
           1.046331001361975,
           1.0158247804205023,
           0.9855685024375732,
           0.9556165615066127,
           0.9260288614747682,
           0.8968714805069076,
           0.8682173884301418,
           0.8401472045784946,
           0.8127499741095585,
           0.7861239271633046,
           0.7603771669730068,
           0.7356282095982857,
           0.7120062695305268,
           0.6896511536236288,
           0.6687125945547623,
           0.6493488315904554,
           0.6317242421379895,
           0.6160058573570131,
           0.6023586749630505,
           0.590939823420152,
           0.5818918314172479,
           0.5753354892630804,
           0.5713630021406789,
           0.5700322582137918,
           0.5713630021406816,
           0.5753354892630859,
           0.5818918314172559,
           0.5909398234201627,
           0.6023586749630634,
           0.6160058573570283,
           0.6317242421380067,
           0.6493488315904744,
           0.668712594554783,
           0.6896511536236511,
           0.7120062695305505,
           0.7356282095983104,
           0.7603771669730328,
           0.7861239271633315,
           0.8127499741095864,
           0.840147204578523,
           0.868217388430171,
           0.8968714805069373,
           0.9260288614747983,
           0.9556165615066432,
           0.9855685024376041,
           1.0158247804205334,
           1.0463310013620066,
           1.077037674686138,
           1.1078996665028158,
           1.1388757104282274,
           1.1699279726339225,
           1.20102166682162,
           1.232124714468485,
           1.26320744567232,
           1.294242336116296,
           1.3252037759787285,
           1.3560678669754658,
           1.3868122441021553,
           1.41741591901719,
           1.447859142359427,
           1.4781232826204442,
           1.508190719485973,
           1.5380447498246896,
           1.5676695047359839,
           1.597049876273594,
           1.6261714526416484,
           1.655020460816276,
           1.6835837156821276,
           1.711848574891367,
           1.7398028987551406,
           1.7674350145663087,
           1.794733684829085,
           1.8216880789378058,
           1.848287747904726,
           1.8745226017867116,
           1.900382889504069,
           1.9258591807823755,
           1.9509423499808851,
           1.9756235615995157,
           1.9998942572812046,
           2.023746144148002,
           2.0471711843281266,
           2.070161585547682,
           2.0927097926751426,
           2.1148084801193643,
           2.1364505449929436,
           2.157629100962517,
           2.17833747271613,
           2.198569190985391,
           2.2183179880667656,
           2.2375777937922674,
           2.2563427319050042,
           2.2746071167996558,
           2.292365450592063,
           2.3096124204857253,
           2.3263428964062602,
           2.342551928877763,
           2.3582347471175535,
           2.373386757328124,
           2.388003541167151,
           2.402080854378257,
           2.4156146255668918,
           2.428600955107172,
           2.4410361141668484,
           2.4529165438388048,
           2.4642388543685394,
           2.474999824468109,
           2.485196400707873,
           2.4948256969782,
           2.503884994014048,
           2.512371738975974,
           2.5202835450817673,
           2.527618191283453,
           2.534373621984935,
           2.540547946796008,
           2.5461394403189406,
           2.551146541964205,
           2.5555678557923267,
           2.5594021503791975,
           2.5626483587024897,
           2.565305578047177,
           2.5673730699284203,
           2.568850260030392,
           2.569736738159882
          ],
          [
           2.595308864276675,
           2.595011511091673,
           2.594119534815882,
           2.5926331852948787,
           2.5905528789645222,
           2.5878791988912653,
           2.584612894829535,
           2.5807548832971157,
           2.5763062476697822,
           2.571268238296686,
           2.5656422726383403,
           2.5594299354293284,
           2.5526329788682323,
           2.545253322837602,
           2.5372930551571846,
           2.5287544318740243,
           2.519639877593478,
           2.509951985855662,
           2.4996935195623413,
           2.488867411459828,
           2.477476764684045,
           2.4655248533745557,
           2.453015123365074,
           2.4399511929587554,
           2.426336853797397,
           2.4121760718346383,
           2.3974729884242927,
           2.3822319215360506,
           2.3664573671121047,
           2.3501540005796238,
           2.3333266785355655,
           2.3159804406220523,
           2.298120511612476,
           2.2797523037306093,
           2.2608814192274567,
           2.2415136532432203,
           2.2216549969847716,
           2.2013116412524116,
           2.1804899803534576,
           2.159196616444459,
           2.137438364348643,
           2.115222256900571,
           2.092555550876087,
           2.069445733572518,
           2.0459005301118802,
           2.0219279115486675,
           1.9975361038738002,
           1.9727335980177012,
           1.947529160968391,
           1.921931848135218,
           1.8959510171056388,
           1.8695963429616327,
           1.8428778353442108,
           1.8158058574795857,
           1.7883911474091883,
           1.7606448416986593,
           1.7325785019386166,
           1.7042041443933136,
           1.6755342732030054,
           1.6465819176029766,
           1.6173606736878057,
           1.5878847513248613,
           1.5581690269076136,
           1.5282291027387218,
           1.4980813739467012,
           1.4677431039701798,
           1.4372325097922243,
           1.4065688582758629,
           1.3757725751425653,
           1.3448653683493514,
           1.3138703678580734,
           1.2828122840515734,
           1.2517175873331081,
           1.2206147117417006,
           1.1895342857160895,
           1.158509393425588,
           1.1275758703288428,
           1.0967726367775528,
           1.0661420734867282,
           1.0357304424519282,
           1.0055883562729906,
           0.9757712976564308,
           0.9463401888605888,
           0.9173620076815238,
           0.8889104418211431,
           0.8610665666022372,
           0.8339195213909587,
           0.8075671471342598,
           0.7821165306165028,
           0.7576843802492857,
           0.7343971340546438,
           0.7123906749323897,
           0.6918095052874825,
           0.6728052192849756,
           0.6555341159829494,
           0.6401538321062754,
           0.6268189505952749,
           0.6156756663764523,
           0.6068557583043898,
           0.600470302318191,
           0.5966037229025488,
           0.595308864276675,
           0.5966037229025514,
           0.6004703023181963,
           0.6068557583043975,
           0.6156756663764626,
           0.6268189505952875,
           0.6401538321062902,
           0.6555341159829662,
           0.6728052192849944,
           0.6918095052875027,
           0.7123906749324117,
           0.7343971340546671,
           0.7576843802493103,
           0.7821165306165282,
           0.8075671471342865,
           0.8339195213909862,
           0.8610665666022655,
           0.888910441821172,
           0.9173620076815534,
           0.9463401888606188,
           0.9757712976564611,
           1.0055883562730215,
           1.0357304424519593,
           1.0661420734867595,
           1.0967726367775843,
           1.1275758703288743,
           1.1585093934256196,
           1.1895342857161215,
           1.2206147117417323,
           1.25171758733314,
           1.2828122840516056,
           1.3138703678581056,
           1.3448653683493834,
           1.375772575142597,
           1.4065688582758944,
           1.4372325097922558,
           1.4677431039702111,
           1.498081373946732,
           1.5282291027387527,
           1.5581690269076445,
           1.587884751324892,
           1.6173606736878359,
           1.6465819176030063,
           1.6755342732030352,
           1.7042041443933431,
           1.7325785019386455,
           1.7606448416986877,
           1.7883911474092165,
           1.8158058574796134,
           1.8428778353442385,
           1.8695963429616596,
           1.8959510171056657,
           1.921931848135244,
           1.9475291609684169,
           1.972733598017727,
           1.9975361038738253,
           2.0219279115486923,
           2.0459005301119046,
           2.069445733572542,
           2.0925555508761104,
           2.1152222569005947,
           2.137438364348666,
           2.1591966164444814,
           2.180489980353479,
           2.201311641252433,
           2.221654996984792,
           2.2415136532432407,
           2.260881419227477,
           2.279752303730628,
           2.2981205116124945,
           2.3159804406220705,
           2.333326678535583,
           2.3501540005796415,
           2.3664573671121216,
           2.382231921536066,
           2.3974729884243082,
           2.4121760718346534,
           2.426336853797411,
           2.439951192958769,
           2.453015123365087,
           2.4655248533745677,
           2.477476764684057,
           2.488867411459839,
           2.4996935195623524,
           2.5099519858556727,
           2.5196398775934883,
           2.5287544318740336,
           2.537293055157193,
           2.54525332283761,
           2.55263297886824,
           2.559429935429335,
           2.565642272638346,
           2.5712682382966916,
           2.5763062476697867,
           2.5807548832971205,
           2.584612894829539,
           2.5878791988912684,
           2.5905528789645245,
           2.5926331852948805,
           2.5941195348158828,
           2.595011511091673
          ],
          [
           2.620009547460784,
           2.619710437085586,
           2.6188131904664824,
           2.6173180611324107,
           2.6152254716632934,
           2.61253601373807,
           2.609250448202936,
           2.605369705160783,
           2.6008948840831465,
           2.595827253946261,
           2.5901682533931565,
           2.583919490924056,
           2.5770827451176928,
           2.5696599648865432,
           2.5616532697693524,
           2.5530649502647753,
           2.5438974682103987,
           2.5341534572118976,
           2.523835723127621,
           2.512947244614465,
           2.5014911737415235,
           2.4894708366786755,
           2.4768897344680356,
           2.463751543886976,
           2.4500601184123565,
           2.4358194892965517,
           2.421033866766982,
           2.405707641362017,
           2.3898453854174666,
           2.3734518547193395,
           2.3565319903401596,
           2.339090920677945,
           2.3211339637189825,
           2.302666629547713,
           2.283694623129614,
           2.264223847395684,
           2.2442604066603016,
           2.2238106104076847,
           2.202880977486129,
           2.1814782407535644,
           2.159609352222938,
           2.137281488761473,
           2.114502058404146,
           2.091278707348763,
           2.0676193277080546,
           2.043532066103194,
           2.0190253331934285,
           1.994107814248089,
           1.9687884808804172,
           1.9430766040776413,
           1.9169817686787303,
           1.890513889470665,
           1.8636832290961458,
           1.8365004179908908,
           1.808976476597428,
           1.7811228401352057,
           1.752951386244396,
           1.7244744658637976,
           1.6957049377523863,
           1.6666562071203432,
           1.6373422688997186,
           1.6077777562584203,
           1.5779779950452009,
           1.5479590649490367,
           1.5177378682652485,
           1.4873322072842632,
           1.456760871458602,
           1.4260437356606683,
           1.3952018710192151,
           1.3642576700163167,
           1.3332349877385257,
           1.3021593014034785,
           1.2710578905216998,
           1.23996004029444,
           1.208897271078296,
           1.177903596944786,
           1.147015816495674,
           1.1162738391153773,
           1.0857210496820506,
           1.0554047143229082,
           1.025376428954036,
           0.9956926109103215,
           0.9664150317088019,
           0.9376113855926866,
           0.9093558835951673,
           0.8817298559994922,
           0.8548223367798037,
           0.828730591451862,
           0.8035605344885087,
           0.779426964214625,
           0.756453522796304,
           0.7347722686944677,
           0.714522732597071,
           0.6958503213179472,
           0.6789039454581123,
           0.6638327848795629,
           0.6507821791120075,
           0.6398887404007706,
           0.6312749279024634,
           0.6250434714217471,
           0.6212721573940321,
           0.620009547460784,
           0.6212721573940347,
           0.6250434714217521,
           0.6312749279024712,
           0.6398887404007808,
           0.6507821791120201,
           0.6638327848795774,
           0.6789039454581287,
           0.6958503213179656,
           0.7145227325970909,
           0.7347722686944892,
           0.756453522796327,
           0.7794269642146493,
           0.8035605344885342,
           0.8287305914518882,
           0.8548223367798309,
           0.88172985599952,
           0.909355883595196,
           0.937611385592716,
           0.9664150317088319,
           0.9956926109103517,
           1.0253764289540666,
           1.0554047143229388,
           1.085721049682082,
           1.116273839115409,
           1.1470158164957058,
           1.177903596944818,
           1.208897271078328,
           1.2399600402944717,
           1.2710578905217316,
           1.3021593014035102,
           1.3332349877385579,
           1.3642576700163485,
           1.3952018710192466,
           1.4260437356606999,
           1.4567608714586338,
           1.4873322072842947,
           1.5177378682652798,
           1.5479590649490678,
           1.5779779950452317,
           1.6077777562584512,
           1.6373422688997488,
           1.6666562071203732,
           1.6957049377524158,
           1.7244744658638274,
           1.752951386244425,
           1.7811228401352341,
           1.8089764765974565,
           1.8365004179909186,
           1.8636832290961736,
           1.8905138894706925,
           1.9169817686787574,
           1.9430766040776677,
           1.9687884808804432,
           1.9941078142481148,
           2.019025333193454,
           2.043532066103218,
           2.0676193277080785,
           2.091278707348787,
           2.114502058404169,
           2.1372814887614964,
           2.1596093522229607,
           2.181478240753587,
           2.2028809774861506,
           2.2238106104077064,
           2.2442604066603224,
           2.2642238473957046,
           2.283694623129634,
           2.3026666295477325,
           2.321133963719001,
           2.3390909206779633,
           2.3565319903401765,
           2.373451854719357,
           2.389845385417483,
           2.405707641362033,
           2.4210338667669977,
           2.4358194892965663,
           2.4500601184123707,
           2.46375154388699,
           2.476889734468049,
           2.4894708366786884,
           2.501491173741535,
           2.5129472446144767,
           2.5238357231276316,
           2.534153457211908,
           2.543897468210409,
           2.5530649502647846,
           2.5616532697693604,
           2.5696599648865512,
           2.5770827451177,
           2.5839194909240626,
           2.590168253393163,
           2.595827253946267,
           2.6008948840831514,
           2.6053697051607876,
           2.60925044820294,
           2.6125360137380733,
           2.6152254716632966,
           2.6173180611324125,
           2.6188131904664833,
           2.619710437085587
          ],
          [
           2.6441104114504066,
           2.643809618202594,
           2.642907324170722,
           2.64140378650046,
           2.639299433804676,
           2.636594866219067,
           2.6332908554810994,
           2.629388345033296,
           2.6248884501522336,
           2.61979245810495,
           2.614101828334783,
           2.6078181926790203,
           2.6009433556211086,
           2.5934792945805745,
           2.5854281602442013,
           2.5767922769424834,
           2.567574143075824,
           2.5577764315954887,
           2.547401990544846,
           2.5364538436670654,
           2.5249351910860613,
           2.512849410068213,
           2.5002000558731345,
           2.486990862702666,
           2.47322574475813,
           2.458908797416987,
           2.444044298541096,
           2.428636709930079,
           2.412690678934625,
           2.3962110402461305,
           2.3792028178807243,
           2.361671227377627,
           2.3436216782338612,
           2.3250597765996597,
           2.305991328261478,
           2.2864223419424285,
           2.2663590329531496,
           2.2458078272297355,
           2.224775365799382,
           2.203268509718927,
           2.1812943455365392,
           2.1588601913325287,
           2.1359736034016477,
           2.1126423836465253,
           2.088874587760006,
           2.0646785342834044,
           2.040062814638087,
           2.015036304239604,
           1.9896081748169303,
           1.9637879080745275,
           1.9375853108521268,
           1.9110105319566564,
           1.884074080862923,
           1.8567868485049217,
           1.829160130408378,
           1.8012056524478608,
           1.772935599549101,
           1.7443626476996297,
           1.7154999996792557,
           1.686361424977036,
           1.6569613044241187,
           1.6273146801431861,
           1.5974373114961793,
           1.5673457378037008,
           1.5370573487130712,
           1.5065904632085216,
           1.4759644183874163,
           1.4451996692713667,
           1.414317901080781,
           1.3833421555752237,
           1.352296973248059,
           1.3212085533584876,
           1.290104933980862,
           1.2590161944396059,
           1.2279746826621518,
           1.1970152700980765,
           1.1661756368851814,
           1.1354965898428782,
           1.1050224155702295,
           1.0748012703245151,
           1.0448856073269717,
           1.0153326405146312,
           0.9862048413112727,
           0.9575704614530354,
           0.929504069950139,
           0.9020870855342477,
           0.8754082770735037,
           0.8495641931575928,
           0.8246594683025682,
           0.8008069373635798,
           0.7781274728549046,
           0.7567494441200319,
           0.7368076862626092,
           0.71844186566252,
           0.7017941443773256,
           0.6870060847757167,
           0.6742148036838882,
           0.6635484826277284,
           0.6551214595327159,
           0.6490292488971532,
           0.6453439337118627,
           0.6441104114504065,
           0.6453439337118652,
           0.6490292488971582,
           0.6551214595327234,
           0.6635484826277382,
           0.6742148036839004,
           0.6870060847757309,
           0.7017941443773417,
           0.7184418656625381,
           0.7368076862626287,
           0.7567494441200531,
           0.7781274728549272,
           0.8008069373636038,
           0.8246594683025931,
           0.8495641931576189,
           0.8754082770735305,
           0.9020870855342754,
           0.9295040699501675,
           0.9575704614530645,
           0.9862048413113024,
           1.0153326405146612,
           1.044885607327002,
           1.0748012703245458,
           1.1050224155702606,
           1.1354965898429097,
           1.166175636885213,
           1.1970152700981083,
           1.2279746826621836,
           1.2590161944396379,
           1.2901049339808943,
           1.3212085533585196,
           1.352296973248091,
           1.3833421555752554,
           1.414317901080813,
           1.4451996692713984,
           1.4759644183874479,
           1.5065904632085527,
           1.5370573487131025,
           1.5673457378037314,
           1.5974373114962097,
           1.6273146801432163,
           1.656961304424149,
           1.6863614249770662,
           1.7154999996792855,
           1.7443626476996588,
           1.7729355995491303,
           1.8012056524478897,
           1.829160130408407,
           1.85678684850495,
           1.884074080862951,
           1.9110105319566837,
           1.937585310852154,
           1.9637879080745542,
           1.9896081748169567,
           2.01503630423963,
           2.040062814638113,
           2.0646785342834293,
           2.088874587760031,
           2.1126423836465493,
           2.1359736034016716,
           2.1588601913325522,
           2.181294345536562,
           2.203268509718949,
           2.2247753657994043,
           2.245807827229757,
           2.2663590329531704,
           2.2864223419424485,
           2.3059913282614977,
           2.325059776599679,
           2.34362167823388,
           2.3616712273776446,
           2.379202817880742,
           2.396211040246148,
           2.4126906789346414,
           2.428636709930095,
           2.444044298541112,
           2.4589087974170023,
           2.473225744758145,
           2.48699086270268,
           2.500200055873148,
           2.5128494100682253,
           2.524935191086074,
           2.5364538436670765,
           2.547401990544857,
           2.557776431595499,
           2.567574143075834,
           2.5767922769424922,
           2.5854281602442097,
           2.5934792945805825,
           2.6009433556211166,
           2.607818192679027,
           2.6141018283347894,
           2.6197924581049556,
           2.6248884501522385,
           2.6293883450333,
           2.6332908554811034,
           2.6365948662190704,
           2.6392994338046782,
           2.6414037865004616,
           2.642907324170723,
           2.643809618202595
          ],
          [
           2.667588140216162,
           2.6672857368485547,
           2.6663786136378094,
           2.664867031272626,
           2.6627514242758767,
           2.66003240106771,
           2.65671074405499,
           2.6527874097481696,
           2.6482635289070213,
           2.643140406717019,
           2.63741952299846,
           2.631102532450843,
           2.624191264935373,
           2.6166877257988816,
           2.608594096242887,
           2.5999127337419834,
           2.590646172516252,
           2.5807971240629097,
           2.570368477753002,
           2.5593633014995727,
           2.547784842504403,
           2.5356365280911977,
           2.522921966633839,
           2.509644948589291,
           2.495809447645631,
           2.48141962199681,
           2.466479815756877,
           2.450994560527712,
           2.4349685771357414,
           2.418406777554666,
           2.401314267032999,
           2.3836963464471452,
           2.365558514902885,
           2.3469064726105415,
           2.3277461240617443,
           2.3080835815387015,
           2.287925168990165,
           2.2672774263120083,
           2.246147114074446,
           2.224541218742574,
           2.202466958442109,
           2.179931789328013,
           2.156943412620291,
           2.133509782378559,
           2.10963911409535,
           2.085339894197437,
           2.0606208905550343,
           2.035491164110673,
           2.009960081753017,
           1.9840373305761645,
           1.9577329336822402,
           1.9310572677046822,
           1.9040210822518095,
           1.8766355214954635,
           1.848912148158079,
           1.8208629701840067,
           1.7925004704177252,
           1.763837639653415,
           1.7348880134677684,
           1.705665713301724,
           1.6761854923176942,
           1.6464627866277184,
           1.6165137725656553,
           1.5863554307639207,
           1.5560056178931816,
           1.5254831470325958,
           1.494807877759088,
           1.4640008171769152,
           1.4330842332528457,
           1.4020817819762184,
           1.3710186500240198,
           1.3399217147740112,
           1.3088197236658732,
           1.2777434950492594,
           1.2467261427606005,
           1.2158033267116366,
           1.1850135317152997,
           1.154398376567626,
           1.1240029549780628,
           1.0938762092008423,
           1.0640713360432101,
           1.0346462231526183,
           1.0056639109147627,
           0.977193071686902,
           0.9493084931716274,
           0.9220915462176549,
           0.8956306089596645,
           0.8700214088319494,
           0.8453672317003136,
           0.8217789336652918,
           0.799374677175816,
           0.7782793010775473,
           0.7586232274053906,
           0.740540810651319,
           0.7241680533279444,
           0.7096396502464939,
           0.6970853864837099,
           0.686625999577632,
           0.678368717155658,
           0.6724027807156268,
           0.6687953414785864,
           0.6675881402161622,
           0.668795341478589,
           0.6724027807156318,
           0.6783687171556656,
           0.6866259995776417,
           0.6970853864837216,
           0.7096396502465077,
           0.7241680533279602,
           0.7405408106513367,
           0.75862322740541,
           0.7782793010775682,
           0.7993746771758383,
           0.8217789336653154,
           0.8453672317003383,
           0.8700214088319751,
           0.8956306089596913,
           0.9220915462176824,
           0.9493084931716559,
           0.9771930716869309,
           1.0056639109147922,
           1.0346462231526483,
           1.0640713360432406,
           1.0938762092008731,
           1.1240029549780939,
           1.1543983765676573,
           1.185013531715331,
           1.2158033267116684,
           1.2467261427606322,
           1.2777434950492914,
           1.308819723665905,
           1.3399217147740428,
           1.371018650024052,
           1.40208178197625,
           1.4330842332528775,
           1.4640008171769472,
           1.49480787775912,
           1.5254831470326276,
           1.5560056178932131,
           1.5863554307639518,
           1.6165137725656864,
           1.6464627866277497,
           1.6761854923177248,
           1.7056657133017539,
           1.7348880134677982,
           1.7638376396534448,
           1.7925004704177547,
           1.8208629701840353,
           1.8489121481581077,
           1.8766355214954917,
           1.9040210822518377,
           1.93105726770471,
           1.9577329336822673,
           1.9840373305761911,
           2.009960081753043,
           2.0354911641106983,
           2.0606208905550596,
           2.085339894197462,
           2.109639114095375,
           2.1335097823785834,
           2.156943412620315,
           2.1799317893280366,
           2.2024669584421317,
           2.224541218742597,
           2.2461471140744678,
           2.26727742631203,
           2.2879251689901863,
           2.308083581538722,
           2.3277461240617647,
           2.346906472610561,
           2.365558514902904,
           2.383696346447163,
           2.4013142670330163,
           2.418406777554683,
           2.4349685771357588,
           2.450994560527728,
           2.4664798157568923,
           2.4814196219968254,
           2.495809447645646,
           2.5096449485893046,
           2.5229219666338523,
           2.53563652809121,
           2.547784842504416,
           2.5593633014995842,
           2.570368477753013,
           2.5807971240629195,
           2.5906461725162617,
           2.599912733741993,
           2.6085940962428955,
           2.6166877257988896,
           2.6241912649353805,
           2.6311025324508495,
           2.6374195229984663,
           2.643140406717025,
           2.648263528907027,
           2.6527874097481736,
           2.656710744054994,
           2.660032401067713,
           2.662751424275879,
           2.6648670312726273,
           2.6663786136378107,
           2.6672857368485547
          ],
          [
           2.6904200205717554,
           2.6901160783314664,
           2.689204339656411,
           2.6876850686979488,
           2.6855587057549006,
           2.682825867343961,
           2.6794873462994064,
           2.675544111903253,
           2.6709973100473654,
           2.665848263429347,
           2.660098471784443,
           2.6537496121560316,
           2.6468035392077356,
           2.639262285580561,
           2.631128062298944,
           2.6224032592301,
           2.6130904456015203,
           2.603192370582098,
           2.5927119639328935,
           2.581652336734252,
           2.5700167821966664,
           2.557808776563556,
           2.545031980114961,
           2.5316902382820787,
           2.5177875828835683,
           2.503328233495653,
           2.488316598969249,
           2.4727572791087082,
           2.456655066528211,
           2.440014948703482,
           2.4228421102383084,
           2.4051419353673107,
           2.3869200107186574,
           2.368182128362851,
           2.348934289176448,
           2.3291827065526256,
           2.308933810493901,
           2.288194252126071,
           2.266970908676715,
           2.2452708889662842,
           2.2231015394651408,
           2.2004704509758293,
           2.177385466006527,
           2.153854686909117,
           2.1298864848637415,
           2.105489509801158,
           2.0806727013649007,
           2.0554453010272726,
           2.0298168654867705,
           2.003797281489855,
           1.9773967822373035,
           1.9506259655549372,
           1.9234958140306515,
           1.8960177173447075,
           1.8682034970485624,
           1.8400654340795766,
           1.811616299335169,
           1.7828693876709947,
           1.7538385557340228,
           1.7245382640936426,
           1.6949836241928133,
           1.6651904507074546,
           1.6351753199764631,
           1.604955635247606,
           1.5745496995766084,
           1.5439767973184355,
           1.5132572852610897,
           1.4824126945728424,
           1.4514658448624882,
           1.4204409717867281,
           1.389363869775362,
           1.358262051577516,
           1.3271649264515422,
           1.296103998913998,
           1.265113090009934,
           1.2342285830403121,
           1.2034896955450518,
           1.1729387790404526,
           1.1426216474786495,
           1.1125879345434728,
           1.0828914786044057,
           1.053590732270879,
           1.024749190843386,
           0.9964358303367237,
           0.968725540926198,
           0.9416995354175602,
           0.9154457044953312,
           0.8900588810200176,
           0.8656409647259535,
           0.842300846928821,
           0.8201540635035117,
           0.7993220954719585,
           0.7799312330393903,
           0.7621109247474102,
           0.7459915530081082,
           0.7317016146770365,
           0.7193643426037595,
           0.7090938794290086,
           0.700991200656415,
           0.6951400660821866,
           0.6916033379055933,
           0.6904200205717552,
           0.6916033379055957,
           0.6951400660821914,
           0.7009912006564223,
           0.709093879429018,
           0.7193643426037712,
           0.7317016146770501,
           0.7459915530081238,
           0.7621109247474276,
           0.7799312330394094,
           0.7993220954719791,
           0.820154063503534,
           0.8423008469288444,
           0.8656409647259781,
           0.8900588810200432,
           0.9154457044953577,
           0.9416995354175876,
           0.9687255409262262,
           0.9964358303367525,
           1.0247491908434154,
           1.0535907322709088,
           1.082891478604436,
           1.1125879345435037,
           1.1426216474786806,
           1.172938779040484,
           1.2034896955450833,
           1.2342285830403439,
           1.2651130900099659,
           1.29610399891403,
           1.327164926451574,
           1.3582620515775479,
           1.389363869775394,
           1.4204409717867599,
           1.45146584486252,
           1.4824126945728742,
           1.5132572852611212,
           1.5439767973184668,
           1.5745496995766397,
           1.6049556352476368,
           1.6351753199764945,
           1.6651904507074855,
           1.694983624192844,
           1.7245382640936726,
           1.753838555734053,
           1.7828693876710247,
           1.811616299335198,
           1.8400654340796057,
           1.868203497048591,
           1.8960177173447357,
           1.92349581403068,
           1.9506259655549647,
           1.9773967822373306,
           2.003797281489882,
           2.0298168654867967,
           2.055445301027299,
           2.0806727013649264,
           2.1054895098011834,
           2.1298864848637664,
           2.153854686909141,
           2.177385466006551,
           2.200470450975853,
           2.223101539465164,
           2.2452708889663064,
           2.266970908676737,
           2.2881942521260923,
           2.308933810493922,
           2.3291827065526465,
           2.3489342891764675,
           2.368182128362871,
           2.386920010718677,
           2.405141935367329,
           2.4228421102383266,
           2.4400149487035,
           2.456655066528228,
           2.472757279108725,
           2.488316598969265,
           2.503328233495669,
           2.517787582883583,
           2.5316902382820925,
           2.5450319801149752,
           2.557808776563569,
           2.570016782196679,
           2.581652336734263,
           2.5927119639329046,
           2.6031923705821085,
           2.6130904456015305,
           2.622403259230109,
           2.631128062298953,
           2.639262285580569,
           2.646803539207743,
           2.653749612156038,
           2.6600984717844494,
           2.665848263429353,
           2.6709973100473703,
           2.6755441119032572,
           2.6794873462994104,
           2.6828258673439644,
           2.6855587057549037,
           2.687685068697951,
           2.689204339656413,
           2.690116078331467
          ],
          [
           2.712583964147515,
           2.7122785528353126,
           2.7113624080693883,
           2.7098357973771328,
           2.7076991666888173,
           2.704953140415128,
           2.701598521556883,
           2.6976362918481525,
           2.6930676119343073,
           2.687893821586945,
           2.6821164399579693,
           2.675737165875537,
           2.6687578781849943,
           2.661180636138355,
           2.653007679836369,
           2.6442414307277065,
           2.6348844921703383,
           2.6249396500607554,
           2.614409873537307,
           2.6032983157646,
           2.5916083148066336,
           2.5793433945971462,
           2.5665072660165014,
           2.553103828085402,
           2.5391371692867533,
           2.524611569028112,
           2.5095314992584474,
           2.493901626254272,
           2.4777268125917398,
           2.4610121193229757,
           2.443762808376742,
           2.4259843452056,
           2.407682401704003,
           2.3888628594242403,
           2.369531813119992,
           2.349695574650329,
           2.329360677280479,
           2.3085338804195294,
           2.2872221748395627,
           2.265432788425507,
           2.243173192510413,
           2.220451108856857,
           2.197274517351954,
           2.173651664491022,
           2.149591072733464,
           2.125101550823975,
           2.100192205182928,
           2.0748724524819013,
           2.049152033533887,
           2.0230410286431004,
           1.9965498745765538,
           1.969689383339091,
           1.9424707629555322,
           1.914905640488407,
           1.8870060875477117,
           1.8587846485806938,
           1.8302543722652107,
           1.8014288463702852,
           1.7723222364925042,
           1.7429493291275338,
           1.7133255795927218,
           1.6834671653801343,
           1.6533910455899459,
           1.6231150271723085,
           1.5926578387919776,
           1.562039213224116,
           1.5312799792915224,
           1.5004021644621384,
           1.4694291093393483,
           1.438385595393403,
           1.4072979873956142,
           1.3761943921208992,
           1.3451048349685704,
           1.3140614562014854,
           1.2830987284993671,
           1.2522536974351668,
           1.2215662462755805,
           1.1910793861270756,
           1.1608395718298299,
           1.1308970430569287,
           1.1013061886952562,
           1.0721259306329283,
           1.043420120396191,
           1.0152579384870861,
           0.9877142815861916,
           0.9608701168371648,
           0.9348127751231802,
           0.9096361466210859,
           0.8854407322642617,
           0.862333494731557,
           0.8404274434255248,
           0.8198408815237308,
           0.8006962422699059,
           0.7831184495725202,
           0.7672327583036139,
           0.7531620654494517,
           0.7410237355636886,
           0.730926050447727,
           0.7229644664600547,
           0.7172179310492722,
           0.7137455571420509,
           0.7125839641475152,
           0.7137455571420531,
           0.717217931049277,
           0.7229644664600617,
           0.7309260504477363,
           0.7410237355637002,
           0.7531620654494652,
           0.7672327583036292,
           0.7831184495725375,
           0.8006962422699248,
           0.8198408815237513,
           0.8404274434255468,
           0.8623334947315803,
           0.8854407322642861,
           0.9096361466211113,
           0.9348127751232065,
           0.9608701168371921,
           0.9877142815862195,
           1.0152579384871148,
           1.0434201203962203,
           1.072125930632958,
           1.1013061886952864,
           1.1308970430569594,
           1.1608395718298608,
           1.191079386127107,
           1.2215662462756118,
           1.2522536974351983,
           1.2830987284993989,
           1.3140614562015174,
           1.3451048349686021,
           1.3761943921209312,
           1.4072979873956464,
           1.4383855953934348,
           1.46942910933938,
           1.5004021644621701,
           1.5312799792915543,
           1.5620392132241476,
           1.592657838792009,
           1.6231150271723398,
           1.6533910455899772,
           1.6834671653801656,
           1.7133255795927522,
           1.742949329127564,
           1.7723222364925342,
           1.8014288463703152,
           1.8302543722652402,
           1.8587846485807227,
           1.8870060875477408,
           1.9149056404884355,
           1.9424707629555602,
           1.9696893833391187,
           1.9965498745765813,
           2.0230410286431275,
           2.0491520335339137,
           2.074872452481927,
           2.1001922051829536,
           2.1251015508239997,
           2.149591072733489,
           2.173651664491046,
           2.197274517351978,
           2.2204511088568806,
           2.243173192510436,
           2.2654327884255303,
           2.287222174839585,
           2.3085338804195517,
           2.3293606772805004,
           2.34969557465035,
           2.3695318131200125,
           2.38886285942426,
           2.407682401704022,
           2.4259843452056185,
           2.4437628083767597,
           2.461012119322994,
           2.477726812591757,
           2.493901626254288,
           2.509531499258463,
           2.5246115690281266,
           2.539137169286768,
           2.5531038280854164,
           2.5665072660165142,
           2.579343394597159,
           2.591608314806646,
           2.603298315764611,
           2.6144098735373182,
           2.6249396500607656,
           2.634884492170348,
           2.6442414307277162,
           2.6530076798363775,
           2.661180636138363,
           2.668757878185002,
           2.675737165875544,
           2.6821164399579756,
           2.687893821586951,
           2.693067611934312,
           2.6976362918481573,
           2.7015985215568876,
           2.7049531404151312,
           2.7076991666888195,
           2.709835797377134,
           2.7113624080693897,
           2.712278552835313
          ],
          [
           2.7340585287594683,
           2.733751716789256,
           2.7328313711433596,
           2.7312977626327033,
           2.729151342664725,
           2.7263927433278123,
           2.7230227775107645,
           2.7190424390584873,
           2.714452902965549,
           2.709255525609578,
           2.703451845026894,
           2.697043581233163,
           2.6900326365923175,
           2.6824210962374297,
           2.6742112285477218,
           2.665405485686401,
           2.6560065042045804,
           2.646017105717128,
           2.6354402976569475,
           2.6242792741148535,
           2.6125374167730024,
           2.6002182959406275,
           2.587325671701719,
           2.5738634951852895,
           2.5598359099698915,
           2.5452472536352677,
           2.530102059475248,
           2.514405058387456,
           2.498161180956926,
           2.4813755597524425,
           2.464053531856312,
           2.446200641650373,
           2.4278226438833554,
           2.4089255070473015,
           2.389515417093568,
           2.3695987815221433,
           2.3491822338815247,
           2.328272638720321,
           2.3068770970361383,
           2.2850029522721913,
           2.262657796917544,
           2.239849479772967,
           2.216586113951273,
           2.192876085688575,
           2.1687280640515523,
           2.1441510116353637,
           2.1191541963576843,
           2.0937472044664247,
           2.0679399548923376,
           2.0417427150930085,
           2.0151661185519467,
           1.9882211841158741,
           1.9609193373750684,
           1.933272434316158,
           1.9052927875042935,
           1.876993195082621,
           1.848386972911759,
           1.8194879902109977,
           1.7903107091066628,
           1.7608702285419118,
           1.7311823330566942,
           1.7012635470070765,
           1.6711311948600025,
           1.6408034682730814,
           1.6102995007492136,
           1.5796394507425617,
           1.5488445941848488,
           1.5179374274979212,
           1.4869417822577164,
           1.4558829527726767,
           1.424787837931024,
           1.3936850987483829,
           1.3626053330991004,
           1.33158126912583,
           1.3006479787715182,
           1.269843112737149,
           1.2392071578993527,
           1.2087837177739797,
           1.1786198159200594,
           1.148766221160822,
           1.119277792052754,
           1.090213836037645,
           1.0616384760256627,
           1.0336210136276904,
           1.006236273734568,
           0.9795649095133225,
           0.9536936401170545,
           0.9287153855924658,
           0.9047292549637526,
           0.8818403349785432,
           0.8601592197121867,
           0.8398012169243184,
           0.8208851681452504,
           0.8035318288087878,
           0.7878617752662991,
           0.7739928394271197,
           0.7620371194740723,
           0.7520976739481566,
           0.7442650698269309,
           0.7386140123377072,
           0.7352003218706407,
           0.7340585287594683,
           0.7352003218706431,
           0.738614012337712,
           0.7442650698269379,
           0.7520976739481658,
           0.7620371194740835,
           0.7739928394271329,
           0.7878617752663142,
           0.8035318288088047,
           0.820885168145269,
           0.8398012169243386,
           0.8601592197122082,
           0.881840334978566,
           0.9047292549637769,
           0.9287153855924908,
           0.9536936401170804,
           0.9795649095133495,
           1.0062362737345956,
           1.033621013627719,
           1.0616384760256918,
           1.0902138360376745,
           1.119277792052784,
           1.1487662211608527,
           1.1786198159200902,
           1.208783717774011,
           1.239207157899384,
           1.2698431127371805,
           1.30064797877155,
           1.3315812691258617,
           1.3626053330991323,
           1.3936850987484146,
           1.4247878379310557,
           1.455882952772709,
           1.4869417822577484,
           1.5179374274979531,
           1.5488445941848805,
           1.5796394507425935,
           1.610299500749245,
           1.6408034682731127,
           1.6711311948600336,
           1.7012635470071076,
           1.7311823330567246,
           1.7608702285419424,
           1.7903107091066928,
           1.8194879902110275,
           1.8483869729117883,
           1.8769931950826504,
           1.9052927875043224,
           1.9332724343161862,
           1.9609193373750966,
           1.988221184115902,
           2.0151661185519743,
           2.0417427150930356,
           2.0679399548923643,
           2.093747204466451,
           2.11915419635771,
           2.144151011635389,
           2.168728064051577,
           2.1928760856886,
           2.216586113951297,
           2.2398494797729906,
           2.262657796917567,
           2.2850029522722144,
           2.30687709703616,
           2.3282726387203425,
           2.3491822338815456,
           2.3695987815221633,
           2.389515417093588,
           2.4089255070473214,
           2.4278226438833754,
           2.4462006416503916,
           2.464053531856331,
           2.4813755597524607,
           2.4981611809569437,
           2.514405058387472,
           2.5301020594752637,
           2.5452472536352833,
           2.5598359099699057,
           2.573863495185303,
           2.5873256717017328,
           2.600218295940641,
           2.612537416773015,
           2.6242792741148646,
           2.6354402976569586,
           2.6460171057171387,
           2.6560065042045897,
           2.6654054856864104,
           2.6742112285477306,
           2.682421096237438,
           2.6900326365923246,
           2.6970435812331703,
           2.7034518450269003,
           2.709255525609584,
           2.714452902965554,
           2.7190424390584913,
           2.723022777510768,
           2.7263927433278154,
           2.729151342664727,
           2.731297762632705,
           2.732831371143361,
           2.7337517167892575
          ],
          [
           2.7548229391532653,
           2.754514793611544,
           2.7535904483125244,
           2.752050177252688,
           2.7498944371531833,
           2.7471238675509713,
           2.7437392909277083,
           2.739741712877633,
           2.7351323223161295,
           2.72991249173102,
           2.7240837774790516,
           2.7176479201304713,
           2.7106068448650293,
           2.702962661923226,
           2.6947176671171085,
           2.685874342405494,
           2.6764353565390016,
           2.6664035657809695,
           2.6557820147109354,
           2.6445739371180843,
           2.6327827569928743,
           2.620412089625853,
           2.607465742823609,
           2.593947718252807,
           2.579862212924343,
           2.56521362083085,
           2.5500065347521037,
           2.534245748244325,
           2.517936257830945,
           2.501083265414188,
           2.4836921809287142,
           2.4657686252607434,
           2.447318433458415,
           2.4283476582617816,
           2.4088625739837073,
           2.3888696807762115,
           2.368375709320337,
           2.347387625981633,
           2.3259126384777806,
           2.3039582021098277,
           2.281532026614027,
           2.2586420836974317,
           2.235296615327289,
           2.2115041428519517,
           2.1872734770397027,
           2.1626137291314516,
           2.137534323014149,
           2.1120450086338374,
           2.0861558767808632,
           2.059877375395022,
           2.0332203275555094,
           2.006195951339753,
           1.9788158817567307,
           1.9510921949845474,
           1.9230374351691246,
           1.8946646440711865,
           1.8659873938826885,
           1.8370198235717548,
           1.8077766791574688,
           1.778273358362915,
           1.7485259601469674,
           1.7185513396728789,
           1.6883671693348596,
           1.6579920065326863,
           1.627445368958745,
           1.5967478182412984,
           1.565921052871159,
           1.5349880114246977,
           1.5039729871814456,
           1.4729017553155426,
           1.4418017139110029,
           1.4107020401029162,
           1.3796338626686668,
           1.3486304523690917,
           1.317727431247649,
           1.2869630019074103,
           1.2563781974631876,
           1.2260171523604717,
           1.1959273935018069,
           1.166160150047281,
           1.1367706787649143,
           1.107818599788781,
           1.0793682349748546,
           1.0514889375998693,
           1.024255397812239,
           0.9977479029418862,
           0.972052525517443,
           0.9472612047814005,
           0.9234716800237547,
           0.9007872268898107,
           0.8793161421056205,
           0.8591709194522656,
           0.8404670624408342,
           0.8233214894429569,
           0.8078505073807455,
           0.7941673620695527,
           0.7823794168360968,
           0.7725850633237592,
           0.764870523317802,
           0.7593067486326163,
           0.7559466564064954,
           0.754822939153265,
           0.7559466564064977,
           0.7593067486326209,
           0.7648705233178089,
           0.7725850633237682,
           0.7823794168361079,
           0.7941673620695658,
           0.8078505073807605,
           0.8233214894429736,
           0.8404670624408528,
           0.8591709194522855,
           0.8793161421056419,
           0.9007872268898334,
           0.9234716800237786,
           0.9472612047814254,
           0.972052525517469,
           0.9977479029419131,
           1.0242553978122666,
           1.0514889375998975,
           1.0793682349748834,
           1.1078185997888106,
           1.1367706787649443,
           1.1661601500473116,
           1.1959273935018377,
           1.2260171523605028,
           1.2563781974632189,
           1.2869630019074418,
           1.3177274312476808,
           1.3486304523691237,
           1.3796338626686988,
           1.410702040102948,
           1.4418017139110348,
           1.4729017553155745,
           1.5039729871814775,
           1.5349880114247298,
           1.5659210528711907,
           1.5967478182413302,
           1.627445368958777,
           1.6579920065327174,
           1.6883671693348905,
           1.71855133967291,
           1.748525960146998,
           1.7782733583629453,
           1.8077766791574994,
           1.8370198235717845,
           1.8659873938827183,
           1.8946646440712156,
           1.9230374351691537,
           1.951092194984576,
           1.9788158817567592,
           2.006195951339781,
           2.033220327555537,
           2.0598773753950494,
           2.08615587678089,
           2.1120450086338636,
           2.137534323014175,
           2.162613729131477,
           2.187273477039728,
           2.211504142851976,
           2.2352966153273126,
           2.258642083697456,
           2.28153202661405,
           2.3039582021098504,
           2.3259126384778033,
           2.3473876259816553,
           2.3683757093203583,
           2.3888696807762324,
           2.408862573983727,
           2.4283476582618015,
           2.4473184334584355,
           2.4657686252607616,
           2.4836921809287325,
           2.5010832654142052,
           2.517936257830962,
           2.5342457482443415,
           2.55000653475212,
           2.5652136208308653,
           2.579862212924358,
           2.593947718252821,
           2.607465742823623,
           2.620412089625866,
           2.6327827569928868,
           2.644573937118096,
           2.6557820147109465,
           2.6664035657809806,
           2.676435356539011,
           2.685874342405503,
           2.6947176671171174,
           2.7029626619232334,
           2.710606844865037,
           2.7176479201304784,
           2.724083777479058,
           2.7299124917310253,
           2.7351323223161352,
           2.739741712877638,
           2.7437392909277127,
           2.747123867550975,
           2.749894437153186,
           2.75205017725269,
           2.753590448312526,
           2.7545147936115444
          ],
          [
           2.7748571071028976,
           2.774547693808068,
           2.773619546276774,
           2.772072941587942,
           2.769908341604422,
           2.767126393070619,
           2.763727927750464,
           2.7597139626070786,
           2.755085700025818,
           2.749844528082842,
           2.743992020861727,
           2.737529938821121,
           2.7304602292168716,
           2.722785026582562,
           2.7145066532729034,
           2.7056276200749716,
           2.6961506268928774,
           2.6860785635120856,
           2.6754145104502727,
           2.664161739902354,
           2.6523237167880978,
           2.639904099911612,
           2.6269067432429285,
           2.6133356973329263,
           2.599195210873955,
           2.584489732419762,
           2.5692239122796288,
           2.5534026046031495,
           2.5370308696736577,
           2.5201139764301277,
           2.502657405239328,
           2.484666850942183,
           2.466148226200722,
           2.4471076651746193,
           2.4275515275593147,
           2.407486403020966,
           2.38691911606709,
           2.36585673139583,
           2.344306559771231,
           2.32227616447694,
           2.2997733684062807,
           2.2768062618528986,
           2.253383211073059,
           2.2295128676984506,
           2.2052041790869716,
           2.180466399708644,
           2.1553091036746035,
           2.1297421985292186,
           2.103775940438909,
           2.0774209509264034,
           2.050688235316125,
           2.023589203075395,
           1.9961356902573815,
           1.9683399842754956,
           1.9402148512654998,
           1.9117735663212454,
           1.8830299469230172,
           1.85399838991425,
           1.8246939124232067,
           1.7951321971713803,
           1.7653296426601768,
           1.7353034187820027,
           1.7050715284613578,
           1.6746528759957546,
           1.6440673428349335,
           1.613335871609127,
           1.582480559291789,
           1.5515247604571836,
           1.520493201665469,
           1.489412108072952,
           1.4583093434166636,
           1.4272145645515408,
           1.3961593917131447,
           1.3651775956227141,
           1.3343053024226292,
           1.303581217200466,
           1.2730468664916144,
           1.2427468595965907,
           1.2127291677504606,
           1.1830454190656114,
           1.1537512056492778,
           1.124906397275201,
           1.0965754533582093,
           1.0688277216368545,
           1.0417377078267613,
           1.0153852955269982,
           0.9898558898924389,
           0.965240452221336,
           0.9416353860625185,
           0.9191422294358271,
           0.8978671033762968,
           0.8779198657704981,
           0.8594129232447981,
           0.8424596647796068,
           0.8271725006664928,
           0.8136605205117472,
           0.8020268237654599,
           0.7923656229150573,
           0.784759267408359,
           0.7792753773723049,
           0.7759643007585225,
           0.7748571071028976,
           0.7759643007585247,
           0.7792753773723096,
           0.7847592674083657,
           0.7923656229150663,
           0.8020268237654709,
           0.8136605205117602,
           0.8271725006665076,
           0.8424596647796234,
           0.8594129232448162,
           0.877919865770518,
           0.8978671033763183,
           0.9191422294358497,
           0.9416353860625419,
           0.9652404522213608,
           0.9898558898924645,
           1.0153852955270248,
           1.0417377078267887,
           1.0688277216368827,
           1.0965754533582381,
           1.1249063972752302,
           1.1537512056493078,
           1.1830454190656416,
           1.2127291677504914,
           1.2427468595966218,
           1.2730468664916457,
           1.3035812172004977,
           1.3343053024226608,
           1.3651775956227459,
           1.3961593917131767,
           1.4272145645515726,
           1.458309343416696,
           1.4894121080729843,
           1.5204932016655008,
           1.5515247604572153,
           1.582480559291821,
           1.6133358716091586,
           1.644067342834965,
           1.674652875995786,
           1.7050715284613889,
           1.7353034187820338,
           1.7653296426602076,
           1.795132197171411,
           1.8246939124232369,
           1.8539983899142802,
           1.883029946923047,
           1.9117735663212747,
           1.9402148512655288,
           1.968339984275524,
           1.99613569025741,
           2.023589203075423,
           2.0506882353161524,
           2.077420950926431,
           2.1037759404389362,
           2.1297421985292453,
           2.1553091036746297,
           2.1804663997086693,
           2.205204179086997,
           2.2295128676984755,
           2.2533832110730834,
           2.2768062618529226,
           2.299773368406304,
           2.3222761644769627,
           2.3443065597712542,
           2.3658567313958527,
           2.386919116067112,
           2.407486403020987,
           2.427551527559335,
           2.447107665174639,
           2.4661482262007417,
           2.484666850942202,
           2.5026574052393458,
           2.5201139764301455,
           2.537030869673674,
           2.553402604603166,
           2.569223912279645,
           2.5844897324197778,
           2.59919521087397,
           2.6133356973329405,
           2.6269067432429423,
           2.639904099911625,
           2.6523237167881097,
           2.664161739902366,
           2.6754145104502842,
           2.6860785635120963,
           2.6961506268928876,
           2.705627620074981,
           2.7145066532729123,
           2.72278502658257,
           2.730460229216879,
           2.7375299388211283,
           2.7439920208617337,
           2.7498445280828476,
           2.755085700025823,
           2.7597139626070826,
           2.7637279277504683,
           2.767126393070622,
           2.7699083416044243,
           2.7720729415879433,
           2.773619546276776,
           2.774547693808069
          ],
          [
           2.794141650844761,
           2.7938310344061787,
           2.792899278434728,
           2.7913466629838823,
           2.789173654878216,
           2.7863809078172546,
           2.7829692625222164,
           2.7789397469269934,
           2.7742935764151424,
           2.769032154105068,
           2.7631570711860025,
           2.756670107307857,
           2.749573231028471,
           2.7418686003223125,
           2.7335585631551873,
           2.7246456581300977,
           2.7151326152099746,
           2.705022356523686,
           2.6943179972623748,
           2.683022846673976,
           2.6711404091645403,
           2.658674385515898,
           2.645628674230136,
           2.63200737301243,
           2.61781478040489,
           2.603055397585341,
           2.5877339303463347,
           2.571855291271175,
           2.555424602125404,
           2.538447196484009,
           2.5209286226166077,
           2.502874646655089,
           2.484291256070631,
           2.4651846634896932,
           2.4455613108815966,
           2.425427874153606,
           2.404791268193098,
           2.3836586524004706,
           2.3620374367610077,
           2.3399352885089058,
           2.3173601394423167,
           2.294320193954477,
           2.2708239378529638,
           2.246880148046861,
           2.222497903190297,
           2.1976865953804405,
           2.1724559430188615,
           2.146816004957181,
           2.1207771960614057,
           2.0943503043443776,
           2.067546509832547,
           2.0403774053520407,
           2.012855019439921,
           1.9849918416098828,
           1.9568008502276266,
           1.9282955432801012,
           1.8994899723549474,
           1.870398780182078,
           1.8410372421286834,
           1.8114213120822644,
           1.781567673203733,
           1.751493794084284,
           1.7212179908955805,
           1.6907594961825183,
           1.6601385350109332,
           1.6293764092480623,
           1.5984955908198795,
           1.5675198248542077,
           1.5364742436783922,
           1.5053854926904555,
           1.4742818691563175,
           1.4431934749936397,
           1.4121523845726975,
           1.3811928284798263,
           1.3503513940276235,
           1.319667243029923,
           1.2891823469524046,
           1.2589417389560116,
           1.2289937815140064,
           1.1993904471368726,
           1.1701876082037261,
           1.141445329886712,
           1.1132281575747933,
           1.0856053869707731,
           1.058651301089714,
           1.0324453537185128,
           1.0070722735855213,
           0.9826220577581447,
           0.959189817063583,
           0.9368754313160116,
           0.9157829688671861,
           0.8960198248625433,
           0.8776955372588838,
           0.8609202509254809,
           0.8458028195396691,
           0.8324485632448813,
           0.8209567364626542,
           0.8114178020756133,
           0.8039106502843892,
           0.7984999355733866,
           0.7952337252536711,
           0.7941416508447611,
           0.7952337252536734,
           0.7984999355733913,
           0.8039106502843958,
           0.8114178020756221,
           0.8209567364626651,
           0.832448563244894,
           0.8458028195396836,
           0.8609202509254974,
           0.877695537258902,
           0.8960198248625628,
           0.915782968867207,
           0.936875431316034,
           0.9591898170636064,
           0.9826220577581692,
           1.0070722735855469,
           1.0324453537185392,
           1.0586513010897414,
           1.0856053869708011,
           1.113228157574822,
           1.1414453298867413,
           1.170187608203756,
           1.1993904471369028,
           1.228993781514037,
           1.2589417389560424,
           1.2891823469524357,
           1.3196672430299545,
           1.350351394027655,
           1.381192828479858,
           1.4121523845727293,
           1.4431934749936717,
           1.4742818691563497,
           1.5053854926904875,
           1.536474243678424,
           1.56751982485424,
           1.5984955908199112,
           1.629376409248094,
           1.660138535010965,
           1.69075949618255,
           1.721217990895612,
           1.7514937940843156,
           1.781567673203764,
           1.811421312082295,
           1.8410372421287138,
           1.8703987801821085,
           1.8994899723549776,
           1.9282955432801305,
           1.9568008502276557,
           1.984991841609912,
           2.0128550194399493,
           2.0403774053520687,
           2.0675465098325745,
           2.094350304344405,
           2.1207771960614323,
           2.1468160049572074,
           2.1724559430188877,
           2.197686595380466,
           2.222497903190322,
           2.2468801480468863,
           2.2708239378529878,
           2.294320193954501,
           2.31736013944234,
           2.339935288508929,
           2.36203743676103,
           2.383658652400493,
           2.4047912681931196,
           2.4254278741536277,
           2.445561310881617,
           2.4651846634897128,
           2.4842912560706507,
           2.5028746466551075,
           2.5209286226166254,
           2.5384471964840274,
           2.555424602125422,
           2.5718552912711914,
           2.587733930346351,
           2.603055397585357,
           2.6178147804049057,
           2.6320073730124447,
           2.645628674230149,
           2.6586743855159107,
           2.671140409164553,
           2.683022846673988,
           2.6943179972623863,
           2.705022356523697,
           2.715132615209985,
           2.724645658130107,
           2.733558563155196,
           2.741868600322321,
           2.7495732310284784,
           2.7566701073078637,
           2.763157071186009,
           2.7690321541050738,
           2.7742935764151473,
           2.778939746926998,
           2.782969262522221,
           2.7863809078172577,
           2.789173654878218,
           2.791346662983884,
           2.7928992784347293,
           2.7938310344061787
          ],
          [
           2.8126579138282577,
           2.8123461577049422,
           2.8114109836329657,
           2.809852674528005,
           2.8076717019889466,
           2.804868726407715,
           2.8014445971244144,
           2.7974003526291744,
           2.7927372208125156,
           2.7874566192664663,
           2.7815601556391116,
           2.7750496280457235,
           2.7679270255400947,
           2.7601945286502225,
           2.7518545099830316,
           2.742909534903382,
           2.733362362293263,
           2.7232159453976936,
           2.7124734327645954,
           2.701138169286642,
           2.689213697353947,
           2.6767037581273283,
           2.663612292942884,
           2.649943444859667,
           2.6357015603634126,
           2.6208911912405637,
           2.605517096638187,
           2.5895842453269595,
           2.5730978181860236,
           2.556063210930414,
           2.5384860371037337,
           2.5203721313610434,
           2.5017275530693786,
           2.482558590256045,
           2.4628717639378714,
           2.442673832867934,
           2.421971798739987,
           2.400772911894942,
           2.3790846775782826,
           2.3569148628024124,
           2.3342715038735165,
           2.3111629146488317,
           2.287597695597155,
           2.2635847437432086,
           2.2391332635851304,
           2.214252779083978,
           2.188953146834909,
           2.163244570541659,
           2.137137616929305,
           2.1106432332452036,
           2.0837727665145658,
           2.0565379847356566,
           2.02895110022016,
           2.0010247953071683,
           1.9727722507046772,
           1.9442071767406661,
           1.9153438478370517,
           1.8861971405542335,
           1.8567825755918106,
           1.827116364172505,
           1.7972154592814642,
           1.7670976122819135,
           1.7367814354804274,
           1.7062864712704624,
           1.6756332685405386,
           1.6448434670924035,
           1.613939890872844,
           1.582946650878016,
           1.5518892586374482,
           1.5207947512211741,
           1.4896918287306826,
           1.458611005223036,
           1.427584773964922,
           1.3966477878028882,
           1.365837055245896,
           1.335192152558758,
           1.3047554517249584,
           1.2745723635110935,
           1.244691593999762,
           1.2151654117904838,
           1.1860499215275147,
           1.1574053374217277,
           1.1292962479133624,
           1.1017918595064333,
           1.0749662040548715,
           1.0488982894098882,
           1.0236721684526293,
           0.9993768963781611,
           0.9761063411010975,
           0.9539588075033251,
           0.9330364339143966,
           0.9134443199721182,
           0.8952893503420941,
           0.8786786902029626,
           0.8637179471555405,
           0.8505090207463055,
           0.8391476942400402,
           0.8297210609469349,
           0.8223049146005594,
           0.8169612636082183,
           0.8137361454247116,
           0.8126579138282576,
           0.8137361454247138,
           0.8169612636082227,
           0.8223049146005661,
           0.8297210609469438,
           0.8391476942400509,
           0.8505090207463182,
           0.8637179471555548,
           0.8786786902029788,
           0.8952893503421119,
           0.9134443199721375,
           0.9330364339144174,
           0.9539588075033473,
           0.9761063411011209,
           0.9993768963781854,
           1.0236721684526549,
           1.0488982894099146,
           1.0749662040548988,
           1.1017918595064613,
           1.129296247913391,
           1.157405337421757,
           1.1860499215275446,
           1.215165411790514,
           1.2446915939997925,
           1.2745723635111246,
           1.3047554517249897,
           1.3351921525587893,
           1.3658370552459276,
           1.39664778780292,
           1.4275847739649539,
           1.4586110052230683,
           1.4896918287307146,
           1.5207947512212063,
           1.5518892586374804,
           1.5829466508780479,
           1.6139398908728755,
           1.644843467092435,
           1.67563326854057,
           1.7062864712704933,
           1.7367814354804585,
           1.7670976122819444,
           1.797215459281495,
           1.8271163641725356,
           1.8567825755918412,
           1.8861971405542635,
           1.9153438478370817,
           1.9442071767406957,
           1.9727722507047065,
           2.001024795307197,
           2.0289511002201883,
           2.0565379847356846,
           2.0837727665145938,
           2.1106432332452307,
           2.137137616929332,
           2.1632445705416856,
           2.188953146834936,
           2.214252779084004,
           2.2391332635851557,
           2.2635847437432335,
           2.287597695597179,
           2.3111629146488557,
           2.3342715038735395,
           2.356914862802435,
           2.3790846775783057,
           2.4007729118949643,
           2.421971798740009,
           2.4426738328679547,
           2.462871763937892,
           2.4825585902560654,
           2.501727553069398,
           2.520372131361062,
           2.5384860371037523,
           2.5560632109304318,
           2.573097818186041,
           2.5895842453269764,
           2.605517096638204,
           2.6208911912405797,
           2.6357015603634273,
           2.649943444859681,
           2.663612292942898,
           2.676703758127341,
           2.689213697353959,
           2.701138169286654,
           2.712473432764606,
           2.7232159453977043,
           2.733362362293273,
           2.742909534903391,
           2.7518545099830405,
           2.7601945286502314,
           2.767927025540102,
           2.7750496280457306,
           2.781560155639118,
           2.787456619266472,
           2.792737220812521,
           2.797400352629179,
           2.801444597124418,
           2.8048687264077183,
           2.8076717019889488,
           2.8098526745280066,
           2.8114109836329675,
           2.8123461577049436
          ],
          [
           2.8303879827648046,
           2.830075149323747,
           2.829136744213406,
           2.827573053095184,
           2.8253845521479772,
           2.822571908183717,
           2.8191359788105457,
           2.815077812645051,
           2.8103986495754114,
           2.80509992107775,
           2.799183250588425,
           2.7926504539354964,
           2.7855035398330643,
           2.7777447104427333,
           2.7693763620069856,
           2.7604010855598506,
           2.7508216677208837,
           2.740641091579142,
           2.729862537674571,
           2.7184893850849945,
           2.7065252126277515,
           2.6939738001859412,
           2.6808391301702277,
           2.66712538912824,
           2.6528369695147984,
           2.6379784716374783,
           2.6225547057934384,
           2.606570694614996,
           2.590031675643138,
           2.5729431041500104,
           2.555310656233512,
           2.537140232209363,
           2.518437960328533,
           2.4992102008506816,
           2.479463550507293,
           2.459204847391581,
           2.438441176315984,
           2.417179874682179,
           2.3954285389131593,
           2.373195031502016,
           2.350487488737692,
           2.327314329174281,
           2.3036842629174257,
           2.2796063018091077,
           2.255089770600797,
           2.2301443192144856,
           2.204779936201891,
           2.1790069635239364,
           2.1528361127859337,
           2.126278483078583,
           2.099345580591304,
           2.0720493401826423,
           2.0444021491126945,
           2.01641687316495,
           1.9881068854097756,
           1.959486097889227,
           1.930568996533126,
           1.9013706796496077,
           1.8719069003697182,
           1.842194113465289,
           1.8122495270021814,
           1.7820911593370143,
           1.751737902014371,
           1.7212095891726649,
           1.6905270741194933,
           1.65971231379004,
           1.6287884618529571,
           1.5977799712743117,
           1.5667127071877167,
           1.5356140709422497,
           1.5045131362019386,
           1.4734407979416855,
           1.4424299351117484,
           1.4115155876095646,
           1.380735147982361,
           1.3501285679594628,
           1.3197385794454801,
           1.2896109289530402,
           1.2597946235665236,
           1.2303421853483367,
           1.2013099095617676,
           1.1727581201210642,
           1.1447514132246346,
           1.1173588771296987,
           1.0906542724656065,
           1.064716153393425,
           1.0396279054255873,
           1.0154776710772864,
           0.9923581301662288,
           0.9703660981696908,
           0.9496019045018124,
           0.9301685140472246,
           0.9121703610999459,
           0.8957118763108529,
           0.8808957053211036,
           0.8678206426880591,
           0.8565793355152468,
           0.847255845293019,
           0.8399231895296114,
           0.834641011118665,
           0.8314535369338389,
           0.8303879827648046,
           0.8314535369338413,
           0.8346410111186693,
           0.839923189529618,
           0.8472558452930276,
           0.8565793355152574,
           0.8678206426880716,
           0.8808957053211179,
           0.895711876310869,
           0.9121703610999635,
           0.9301685140472437,
           0.9496019045018331,
           0.9703660981697128,
           0.992358130166252,
           1.0154776710773106,
           1.0396279054256126,
           1.064716153393451,
           1.0906542724656334,
           1.1173588771297265,
           1.1447514132246632,
           1.1727581201210935,
           1.2013099095617972,
           1.2303421853483665,
           1.2597946235665543,
           1.289610928953071,
           1.319738579445511,
           1.3501285679594943,
           1.3807351479823928,
           1.4115155876095964,
           1.4424299351117804,
           1.473440797941717,
           1.5045131362019706,
           1.5356140709422819,
           1.5667127071877485,
           1.5977799712743435,
           1.6287884618529889,
           1.6597123137900716,
           1.6905270741195246,
           1.7212095891726964,
           1.7517379020144022,
           1.7820911593370456,
           1.8122495270022125,
           1.84219411346532,
           1.8719069003697482,
           1.9013706796496377,
           1.930568996533156,
           1.9594860978892565,
           1.9881068854098045,
           2.0164168731649785,
           2.044402149112723,
           2.0720493401826707,
           2.0993455805913315,
           2.12627848307861,
           2.1528361127859608,
           2.179006963523963,
           2.2047799362019176,
           2.230144319214512,
           2.2550897706008217,
           2.2796063018091326,
           2.3036842629174497,
           2.327314329174305,
           2.350487488737716,
           2.37319503150204,
           2.395428538913182,
           2.4171798746822013,
           2.4384411763160054,
           2.4592048473916015,
           2.479463550507313,
           2.499210200850702,
           2.518437960328553,
           2.5371402322093815,
           2.5553106562335306,
           2.5729431041500277,
           2.5900316756431554,
           2.606570694615013,
           2.622554705793455,
           2.637978471637494,
           2.652836969514813,
           2.667125389128254,
           2.680839130170242,
           2.693973800185955,
           2.7065252126277644,
           2.718489385085006,
           2.729862537674583,
           2.7406410915791524,
           2.7508216677208934,
           2.7604010855598604,
           2.7693763620069944,
           2.7777447104427417,
           2.7855035398330714,
           2.792650453935503,
           2.799183250588432,
           2.8050999210777556,
           2.810398649575417,
           2.815077812645055,
           2.81913597881055,
           2.82257190818372,
           2.82538455214798,
           2.8275730530951857,
           2.829136744213407,
           2.8300751493237475
          ],
          [
           2.8473147049577845,
           2.8470008555317854,
           2.8460594033413966,
           2.8444906366734384,
           2.8422950360861194,
           2.8394732745300293,
           2.8360262175189646,
           2.8319549233520633,
           2.8272606433891245,
           2.821944822381474,
           2.816009098861153,
           2.8094553055917504,
           2.802285470084646,
           2.7945018151850047,
           2.786106759732427,
           2.777102919301732,
           2.76749310703003,
           2.7572803345368997,
           2.7464678129452382,
           2.735058954011146,
           2.723057371372066,
           2.710466881923331,
           2.697291507334291,
           2.6835354757162784,
           2.66920322345589,
           2.6542993972283644,
           2.638828856207265,
           2.622796674488263,
           2.6062081437465254,
           2.589068776149115,
           2.57138430754589,
           2.5531607009646846,
           2.5344041504390606,
           2.5151210851997456,
           2.4953181742639057,
           2.4750023314598244,
           2.45418072092833,
           2.4328607631464454,
           2.4110501415233694,
           2.3887568096240073,
           2.3659889990809138,
           2.3427552282618316,
           2.319064311766963,
           2.294925370837867,
           2.270347844768514,
           2.2453415034185364,
           2.2199164609394186,
           2.194083190836116,
           2.1678525424997406,
           2.1412357593615265,
           2.1142444988344278,
           2.086890854226649,
           2.0591873788312562,
           2.031147112417976,
           2.002783610377536,
           1.9741109757956055,
           1.9451438947627142,
           1.9158976752586336,
           1.886388289984634,
           1.8566324235548888,
           1.826647524499001,
           1.7964518625709323,
           1.766064591905237,
           1.7355058206086826,
           1.7047966874231584,
           1.673959446142642,
           1.6430175585108378,
           1.611995796363852,
           1.5809203538098093,
           1.5498189702490244,
           1.5187210650267564,
           1.4876578844657888,
           1.456662661935223,
           1.4257707914583524,
           1.3950200151251573,
           1.3644506242273284,
           1.3341056735430048,
           1.3040312075250273,
           1.274276496243536,
           1.2448942777476335,
           1.2159410019829542,
           1.1874770694723975,
           1.1595670555815025,
           1.1322799083099118,
           1.1056891041710535,
           1.079872742895095,
           1.054913557554506,
           1.0308988125319494,
           1.007920057958081,
           0.9860727064770556,
           0.9654553973068226,
           0.9461691146078026,
           0.9283160333318126,
           0.911998077108406,
           0.897315190113558,
           0.8843633483199058,
           0.8732323639995466,
           0.8640035683645814,
           0.8567474868265822,
           0.8515216444451315,
           0.8483686503565612,
           0.8473147049577844,
           0.8483686503565633,
           0.8515216444451358,
           0.8567474868265885,
           0.8640035683645898,
           0.8732323639995572,
           0.8843633483199181,
           0.8973151901135722,
           0.911998077108422,
           0.92831603333183,
           0.9461691146078216,
           0.9654553973068432,
           0.9860727064770775,
           1.0079200579581038,
           1.0308988125319734,
           1.0549135575545312,
           1.079872742895121,
           1.1056891041710806,
           1.1322799083099395,
           1.159567055581531,
           1.1874770694724264,
           1.2159410019829837,
           1.2448942777476637,
           1.2742764962435664,
           1.304031207525058,
           1.3341056735430359,
           1.36445062422736,
           1.395020015125189,
           1.425770791458384,
           1.456662661935255,
           1.4876578844658208,
           1.5187210650267884,
           1.5498189702490563,
           1.5809203538098413,
           1.6119957963638838,
           1.6430175585108693,
           1.6739594461426734,
           1.70479668742319,
           1.7355058206087137,
           1.766064591905268,
           1.7964518625709633,
           1.826647524499032,
           1.8566324235549196,
           1.8863882899846645,
           1.9158976752586638,
           1.945143894762744,
           1.974110975795635,
           2.002783610377566,
           2.0311471124180054,
           2.059187378831285,
           2.0868908542266773,
           2.1142444988344553,
           2.1412357593615536,
           2.1678525424997677,
           2.1940831908361433,
           2.2199164609394457,
           2.245341503418562,
           2.2703478447685397,
           2.294925370837892,
           2.3190643117669874,
           2.342755228261856,
           2.365988999080937,
           2.3887568096240304,
           2.411050141523392,
           2.4328607631464676,
           2.4541807209283517,
           2.4750023314598453,
           2.4953181742639257,
           2.515121085199766,
           2.53440415043908,
           2.5531607009647033,
           2.571384307545909,
           2.5890687761491322,
           2.606208143746543,
           2.6227966744882805,
           2.6388288562072817,
           2.65429939722838,
           2.669203223455904,
           2.683535475716292,
           2.697291507334305,
           2.710466881923345,
           2.7230573713720787,
           2.7350589540111576,
           2.7464678129452493,
           2.75728033453691,
           2.76749310703004,
           2.777102919301741,
           2.7861067597324363,
           2.7945018151850136,
           2.802285470084654,
           2.8094553055917575,
           2.8160090988611595,
           2.8219448223814796,
           2.82726064338913,
           2.8319549233520673,
           2.836026217518969,
           2.839473274530033,
           2.8422950360861217,
           2.84449063667344,
           2.846059403341398,
           2.847000855531786
          ],
          [
           2.86342170489667,
           2.8631068998416827,
           2.8621625815978384,
           2.8605890409535215,
           2.858386762639648,
           2.8555564254558323,
           2.8520989024484753,
           2.8480152611422973,
           2.8433067638272145,
           2.8379748679029713,
           2.832021226284373,
           2.8254476878704837,
           2.8182562980816477,
           2.810449299468759,
           2.8020291323997633,
           2.792998435828997,
           2.7833600481556227,
           2.7731170081781022,
           2.762272556152432,
           2.75083013496264,
           2.738793391412946,
           2.7261661776519017,
           2.7129525527399005,
           2.699156784372512,
           2.6847833507733525,
           2.669836942771515,
           2.6543224660800346,
           2.638245043793462,
           2.621610019124353,
           2.6044229584004093,
           2.5866896543460816,
           2.5684161296747945,
           2.5496086410204737,
           2.530273683239873,
           2.5104179941202935,
           2.4900485595307207,
           2.4691726190581593,
           2.4477976721751635,
           2.4259314849891345,
           2.403582097629134,
           2.3807578323316014,
           2.3574673022926507,
           2.3337194213616086,
           2.30952341465819,
           2.2848888302042645,
           2.259825551670702,
           2.234343812350335,
           2.20845421047979,
           2.1821677260459174,
           2.155495739226946,
           2.1284500506344255,
           2.101042903539639,
           2.073287008287672,
           2.0451955691237833,
           2.0167823136803964,
           1.9880615253989846,
           1.9590480791895264,
           1.9297574806611721,
           1.900205909291291,
           1.8704102659362218,
           1.8403882251256063,
           1.8101582926229685,
           1.779739868777654,
           1.749153318236679,
           1.718420046628245,
           1.6875625848700957,
           1.6566046817931421,
           1.6255714058007462,
           1.5944892563023754,
           1.563386285661259,
           1.532292232371595,
           1.5012386661217223,
           1.470259145292706,
           1.4393893872704453,
           1.4086674516929878,
           1.3781339363874558,
           1.3478321852413346,
           1.3178085065631475,
           1.288112399573821,
           1.2587967854828859,
           1.229918238090163,
           1.2015372069614685,
           1.1737182239112651,
           1.1465300807598138,
           1.1200459631253206,
           1.0943435214278585,
           1.0695048564718037,
           1.0456163932069125,
           1.022768612969505,
           1.0010556122829193,
           0.9805744559529087,
           0.9614242946975926,
           0.9437052239503197,
           0.9275168717249421,
           0.9129567201464613,
           0.900118187357758,
           0.8890885229255453,
           0.8799465982242614,
           0.8727606999267522,
           0.8675864550932191,
           0.8644650256887061,
           0.8634217048966701,
           0.8644650256887082,
           0.8675864550932234,
           0.8727606999267585,
           0.8799465982242699,
           0.8890885229255558,
           0.9001181873577702,
           0.9129567201464753,
           0.9275168717249579,
           0.9437052239503372,
           0.9614242946976116,
           0.9805744559529289,
           1.001055612282941,
           1.0227686129695277,
           1.0456163932069364,
           1.0695048564718288,
           1.0943435214278847,
           1.1200459631253474,
           1.1465300807598413,
           1.1737182239112933,
           1.2015372069614971,
           1.2299182380901923,
           1.2587967854829154,
           1.2881123995738515,
           1.3178085065631782,
           1.3478321852413655,
           1.3781339363874867,
           1.4086674516930193,
           1.4393893872704768,
           1.4702591452927378,
           1.501238666121754,
           1.5322922323716273,
           1.563386285661291,
           1.5944892563024071,
           1.6255714058007784,
           1.656604681793174,
           1.6875625848701277,
           1.7184200466282764,
           1.7491533182367103,
           1.7797398687776853,
           1.8101582926229998,
           1.8403882251256374,
           1.8704102659362527,
           1.9002059092913215,
           1.9297574806612026,
           1.9590480791895566,
           1.988061525399014,
           2.016782313680426,
           2.0451955691238126,
           2.073287008287701,
           2.1010429035396676,
           2.1284500506344535,
           2.1554957392269745,
           2.1821677260459444,
           2.208454210479817,
           2.2343438123503616,
           2.2598255516707275,
           2.2848888302042902,
           2.309523414658215,
           2.3337194213616326,
           2.3574673022926746,
           2.380757832331626,
           2.403582097629157,
           2.425931484989157,
           2.447797672175186,
           2.4691726190581815,
           2.4900485595307416,
           2.510417994120315,
           2.5302736832398933,
           2.5496086410204932,
           2.568416129674813,
           2.5866896543460998,
           2.6044229584004275,
           2.62161001912437,
           2.6382450437934786,
           2.654322466080051,
           2.669836942771531,
           2.684783350773368,
           2.6991567843725264,
           2.712952552739914,
           2.726166177651914,
           2.7387933914129583,
           2.7508301349626523,
           2.762272556152443,
           2.773117008178113,
           2.7833600481556333,
           2.792998435829007,
           2.8020291323997717,
           2.810449299468767,
           2.8182562980816552,
           2.825447687870491,
           2.8320212262843794,
           2.837974867902977,
           2.8433067638272194,
           2.848015261142302,
           2.8520989024484793,
           2.8555564254558354,
           2.8583867626396504,
           2.860589040953523,
           2.86216258159784,
           2.8631068998416827
          ],
          [
           2.878693400099275,
           2.8783776988512155,
           2.877430692819312,
           2.875852675166386,
           2.8736441345840045,
           2.8708057554235262,
           2.867338417881073,
           2.863243198237932,
           2.85852136915837,
           2.853174400047279,
           2.8472039574705668,
           2.8406119056417185,
           2.8334003069784504,
           2.825571422733966,
           2.81712771370788,
           2.808071841042522,
           2.7984066671109735,
           2.788135256503928,
           2.7772608771231866,
           2.765787001390476,
           2.753717307581104,
           2.741055681292981,
           2.7278062170625317,
           2.7139732201401854,
           2.6995612084393508,
           2.684574914674121,
           2.6690192887024358,
           2.652899500093028,
           2.636220940936238,
           2.6189892289207215,
           2.601210210700184,
           2.582889965576621,
           2.564034809529094,
           2.5446512996199098,
           2.5247462388131874,
           2.5043266812442146,
           2.483399937981826,
           2.4619735833301877,
           2.440055461721051,
           2.4176536952526253,
           2.394776691936923,
           2.3714331547237104,
           2.347632091376128,
           2.3233828252807984,
           2.298695007283727,
           2.273578628652802,
           2.2480440352781503,
           2.222101943233231,
           2.195763455832367,
           2.169040082334657,
           2.141943758459881,
           2.1144868688993665,
           2.0866822720238827,
           2.0585433270116495,
           2.0300839236426134,
           2.001318515030383,
           1.9722621535907277,
           1.9429305305753874,
           1.9133400195321548,
           1.8835077240866416,
           1.8534515304777315,
           1.8231901653170302,
           1.792743259082131,
           1.7621314158933667,
           1.7313762901626584,
           1.7005006707393442,
           1.6695285732090461,
           1.6384853410243745,
           1.6073977561561423,
           1.5762941599448383,
           1.5452045847966869,
           1.514160897296653,
           1.4831969531894096,
           1.452348764492317,
           1.4216546787315363,
           1.3911555699085023,
           1.3608950402788393,
           1.3309196313236125,
           1.3012790413723812,
           1.2720263461532992,
           1.2432182170498403,
           1.21491512999114,
           1.1871815556571774,
           1.160086119024819,
           1.1337017132354075,
           1.1081055494049177,
           1.0833791204823855,
           1.0596080538633785,
           1.0368818245982887,
           1.015293299282306,
           0.9949380808269711,
           0.9759136271807439,
           0.9583181236249185,
           0.9422490993458632,
           0.9278017950496512,
           0.9150673092709656,
           0.904130575625168,
           0.8950682493106837,
           0.8879466053155933,
           0.8828195688670023,
           0.8797270064679892,
           0.8786934000992751,
           0.8797270064679912,
           0.8828195688670066,
           0.8879466053155997,
           0.8950682493106921,
           0.9041305756251783,
           0.9150673092709777,
           0.9278017950496651,
           0.9422490993458791,
           0.9583181236249358,
           0.9759136271807629,
           0.9949380808269914,
           1.0152932992823278,
           1.0368818245983116,
           1.0596080538634023,
           1.0833791204824104,
           1.1081055494049437,
           1.1337017132354343,
           1.1600861190248466,
           1.1871815556572058,
           1.2149151299911687,
           1.2432182170498696,
           1.272026346153329,
           1.3012790413724113,
           1.330919631323643,
           1.3608950402788704,
           1.3911555699085334,
           1.4216546787315676,
           1.4523487644923487,
           1.4831969531894418,
           1.5141608972966851,
           1.5452045847967188,
           1.5762941599448705,
           1.6073977561561748,
           1.6384853410244065,
           1.6695285732090779,
           1.7005006707393757,
           1.7313762901626901,
           1.7621314158933983,
           1.7927432590821621,
           1.8231901653170612,
           1.8534515304777621,
           1.883507724086672,
           1.9133400195321852,
           1.9429305305754174,
           1.9722621535907576,
           2.0013185150304134,
           2.030083923642643,
           2.0585433270116784,
           2.0866822720239115,
           2.114486868899395,
           2.1419437584599095,
           2.1690400823346847,
           2.1957634558323944,
           2.2221019432332576,
           2.248044035278177,
           2.2735786286528277,
           2.298695007283753,
           2.3233828252808233,
           2.347632091376153,
           2.371433154723734,
           2.394776691936947,
           2.4176536952526484,
           2.440055461721074,
           2.46197358333021,
           2.483399937981847,
           2.5043266812442364,
           2.524746238813208,
           2.54465129961993,
           2.5640348095291134,
           2.58288996557664,
           2.601210210700202,
           2.6189892289207393,
           2.636220940936255,
           2.652899500093045,
           2.669019288702452,
           2.684574914674137,
           2.699561208439366,
           2.7139732201402,
           2.7278062170625454,
           2.7410556812929943,
           2.7537173075811174,
           2.7657870013904877,
           2.7772608771231986,
           2.7881352565039386,
           2.7984066671109837,
           2.8080718410425307,
           2.8171277137078894,
           2.825571422733975,
           2.8334003069784583,
           2.8406119056417256,
           2.8472039574705725,
           2.8531744000472847,
           2.8585213691583755,
           2.8632431982379365,
           2.8673384178810766,
           2.87080575542353,
           2.8736441345840067,
           2.8758526751663878,
           2.877430692819313,
           2.878377698851216
          ],
          [
           2.8931150161867976,
           2.8927984773178146,
           2.8918489591709386,
           2.890266757153295,
           2.888052363700023,
           2.8852064684099203,
           2.8817299582368845,
           2.8776239177386813,
           2.8728896293850457,
           2.867528573927576,
           2.8615424308344046,
           2.8549330787930827,
           2.847702596285721,
           2.8398532622409225,
           2.8313875567676803,
           2.8223081619770363,
           2.8126179628979573,
           2.8023200484946202,
           2.7914177127930606,
           2.779914456125968,
           2.7678139865053297,
           2.755120221133568,
           2.741837288064887,
           2.7279695280296843,
           2.71352149643613,
           2.698497965564371,
           2.6829039269703028,
           2.6667445941174717,
           2.650025405257454,
           2.632752026580983,
           2.6149303556642676,
           2.596566525237258,
           2.577666907303215,
           2.5582381176417806,
           2.538287020730868,
           2.5178207351261492,
           2.4968466393407245,
           2.4753723782717567,
           2.453405870225498,
           2.430955314597265,
           2.4080292002686012,
           2.384636314790113,
           2.360785754425436,
           2.3364869351394377,
           2.3117496046222796,
           2.286583855450337,
           2.26100013949539,
           2.235009283704991,
           2.2086225073895878,
           2.1818514411660517,
           2.154708147722695,
           2.127205144587905,
           2.099355429103285,
           2.071172505822716,
           2.0426704165812746,
           2.0138637735024787,
           1.9847677952389524,
           1.9553983467704352,
           1.9257719831139237,
           1.8959059973336612,
           1.8658184732733374,
           1.8355283434688716,
           1.8050554527368774,
           1.774420627970406,
           1.7436457547085216,
           1.7127538610777537,
           1.6817692097290409,
           1.6507173984098664,
           1.6196254698134576,
           1.588522031329029,
           1.55743738527144,
           1.5264036700851369,
           1.4954550128832216,
           1.4646276934818268,
           1.4339603198028423,
           1.4034940141201753,
           1.373272609087062,
           1.3433428517704866,
           1.3137546129948847,
           1.2845610981190518,
           1.255819053894612,
           1.227588964242232,
           1.1999352256041607,
           1.172926289981175,
           1.1466347608671885,
           1.1211374241401433,
           1.0965151927181198,
           1.0728529407169454,
           1.050239200355539,
           1.0287656935043163,
           1.0085266702655453,
           0.9896180301299019,
           0.9721362079115968,
           0.956176817537278,
           0.941833062215457,
           0.9291939392957269,
           0.9183422911253867,
           0.9093527772820512,
           0.9022898655744989,
           0.8972059553780473,
           0.8941397534231477,
           0.8931150161867976,
           0.8941397534231499,
           0.8972059553780514,
           0.9022898655745051,
           0.9093527772820597,
           0.9183422911253969,
           0.929193939295739,
           0.9418330622154709,
           0.9561768175372936,
           0.9721362079116138,
           0.9896180301299206,
           1.0085266702655655,
           1.0287656935043379,
           1.0502392003555616,
           1.0728529407169693,
           1.0965151927181447,
           1.121137424140169,
           1.146634760867215,
           1.172926289981202,
           1.1999352256041889,
           1.2275889642422608,
           1.2558190538946412,
           1.2845610981190816,
           1.3137546129949151,
           1.3433428517705173,
           1.373272609087093,
           1.4034940141202068,
           1.4339603198028739,
           1.4646276934818585,
           1.4954550128832533,
           1.5264036700851684,
           1.557437385271472,
           1.5885220313290611,
           1.6196254698134893,
           1.6507173984098988,
           1.6817692097290726,
           1.7127538610777855,
           1.7436457547085529,
           1.7744206279704373,
           1.8050554527369087,
           1.8355283434689031,
           1.8658184732733685,
           1.8959059973336922,
           1.9257719831139544,
           1.9553983467704654,
           1.9847677952389826,
           2.013863773502509,
           2.0426704165813043,
           2.071172505822745,
           2.099355429103314,
           2.127205144587933,
           2.1547081477227232,
           2.1818514411660797,
           2.2086225073896153,
           2.2350092837050184,
           2.2610001394954167,
           2.286583855450363,
           2.3117496046223054,
           2.336486935139463,
           2.3607857544254602,
           2.384636314790137,
           2.408029200268625,
           2.4309553145972886,
           2.4534058702255206,
           2.475372378271779,
           2.4968466393407462,
           2.51782073512617,
           2.538287020730889,
           2.558238117641801,
           2.577666907303235,
           2.596566525237277,
           2.614930355664286,
           2.632752026581001,
           2.650025405257472,
           2.6667445941174894,
           2.6829039269703188,
           2.698497965564387,
           2.7135214964361443,
           2.727969528029699,
           2.741837288064901,
           2.7551202211335815,
           2.767813986505342,
           2.77991445612598,
           2.791417712793072,
           2.802320048494632,
           2.812617962897967,
           2.8223081619770456,
           2.831387556767689,
           2.839853262240931,
           2.8477025962857287,
           2.8549330787930893,
           2.8615424308344104,
           2.867528573927583,
           2.8728896293850505,
           2.877623917738686,
           2.881729958236888,
           2.885206468409923,
           2.8880523637000257,
           2.890266757153297,
           2.8918489591709395,
           2.8927984773178155
          ],
          [
           2.9066726011770783,
           2.9063552824512664,
           2.9054034254374206,
           2.9038173276540773,
           2.901597485058263,
           2.898744592185454,
           2.895259542347079,
           2.891143427887131,
           2.8863975404998983,
           2.8810233716113514,
           2.8750226128271703,
           2.868397156450947,
           2.8611490960766157,
           2.8532807272597602,
           2.8447945482730232,
           2.8356932609514938,
           2.8259797716346395,
           2.8156571922120595,
           2.8047288412811366,
           2.7931982454254913,
           2.7810691406240613,
           2.7683454738016002,
           2.755031404532475,
           2.74113130691076,
           2.726649771600928,
           2.7115916080847717,
           2.6959618471217066,
           2.679765743441235,
           2.663008778688138,
           2.64569666464292,
           2.627835346742196,
           2.6094310079260548,
           2.5904900728420306,
           2.571019212438187,
           2.5510253489809256,
           2.530515661536632,
           2.509497591960059,
           2.4879788514365697,
           2.4659674276300065,
           2.443471592493072,
           2.4204999108027985,
           2.3970612494898997,
           2.3731647878377653,
           2.34882002863445,
           2.324036810369508,
           2.2988253205768077,
           2.273196110434813,
           2.2471601107471724,
           2.2207286494390264,
           2.193913470718278,
           2.1667267560663293,
           2.139181147239511,
           2.111289771480824,
           2.0830662691617348,
           2.0545248240956897,
           2.0256801967888984,
           1.9965477609197362,
           1.9671435433659121,
           1.9374842681282172,
           1.9075874045310761,
           1.877471220112999,
           1.8471548386538468,
           1.8166583038199682,
           1.7860026489416316,
           1.7552099734684288,
           1.724303526675435,
           1.6933077992132732,
           1.6622486231052873,
           1.6311532807901292,
           1.6000506237821255,
           1.5689712014669666,
           1.5379474004565323,
           1.5070135947814183,
           1.4762063069871352,
           1.4455643799006426,
           1.4151291584243482,
           1.3849446801670209,
           1.3550578730029563,
           1.325518756725984,
           1.2963806447947726,
           1.2677003407118286,
           1.2395383218066482,
           1.2119589010814897,
           1.185030355326171,
           1.1588250049525175,
           1.133419228031064,
           1.108893388001293,
           1.0853316517428164,
           1.0628216725334123,
           1.0414541114128242,
           1.0213219712817465,
           1.0025197214474844,
           0.9851421970395323,
           0.9692832683766159,
           0.9550342902449983,
           0.9424823598385809,
           0.9317084337035432,
           0.9227853763808174,
           0.9157760336319458,
           0.9107314377000684,
           0.9076892575801194,
           0.9066726011770783,
           0.9076892575801216,
           0.9107314377000726,
           0.9157760336319521,
           0.9227853763808255,
           0.9317084337035534,
           0.9424823598385929,
           0.9550342902450122,
           0.9692832683766316,
           0.9851421970395494,
           1.002519721447503,
           1.0213219712817667,
           1.0414541114128455,
           1.062821672533435,
           1.0853316517428402,
           1.1088933880013176,
           1.1334192280310897,
           1.158825004952544,
           1.185030355326198,
           1.2119589010815175,
           1.239538321806677,
           1.2677003407118574,
           1.296380644794802,
           1.3255187567260143,
           1.355057873002987,
           1.3849446801670517,
           1.4151291584243795,
           1.4455643799006739,
           1.4762063069871667,
           1.50701359478145,
           1.5379474004565639,
           1.5689712014669985,
           1.6000506237821577,
           1.631153280790161,
           1.6622486231053195,
           1.6933077992133052,
           1.7243035266754667,
           1.7552099734684605,
           1.7860026489416632,
           1.8166583038199997,
           1.8471548386538785,
           1.87747122011303,
           1.9075874045311074,
           1.9374842681282476,
           1.9671435433659425,
           1.9965477609197662,
           2.0256801967889286,
           2.054524824095719,
           2.083066269161764,
           2.1112897714808527,
           2.1391811472395394,
           2.1667267560663577,
           2.193913470718306,
           2.2207286494390535,
           2.2471601107471995,
           2.273196110434839,
           2.2988253205768334,
           2.3240368103695337,
           2.348820028634475,
           2.3731647878377897,
           2.3970612494899237,
           2.4204999108028225,
           2.4434715924930956,
           2.4659674276300287,
           2.4879788514365924,
           2.5094975919600806,
           2.530515661536653,
           2.5510253489809465,
           2.5710192124382076,
           2.590490072842051,
           2.6094310079260734,
           2.6278353467422146,
           2.645696664642937,
           2.663008778688156,
           2.679765743441252,
           2.6959618471217226,
           2.7115916080847873,
           2.7266497716009432,
           2.741131306910775,
           2.755031404532489,
           2.7683454738016136,
           2.781069140624074,
           2.793198245425504,
           2.804728841281148,
           2.81565719221207,
           2.8259797716346498,
           2.8356932609515035,
           2.844794548273032,
           2.853280727259769,
           2.861149096076623,
           2.8683971564509543,
           2.875022612827177,
           2.881023371611357,
           2.8863975404999036,
           2.891143427887135,
           2.8952595423470835,
           2.898744592185457,
           2.9015974850582658,
           2.903817327654079,
           2.9054034254374215,
           2.906355282451267
          ],
          [
           2.9193530389822415,
           2.9190349974108027,
           2.9180809725184713,
           2.916491263799775,
           2.914266370507734,
           2.911406991797838,
           2.9079140269312136,
           2.9037885755385338,
           2.899031937946737,
           2.8936456155711245,
           2.8876313113758325,
           2.8809909304063086,
           2.873726580397862,
           2.865840572465013,
           2.857335421876938,
           2.848213848924962,
           2.8384787798887454,
           2.828133348108544,
           2.817180895171708,
           2.8056249722224558,
           2.793469341404842,
           2.7807179774498643,
           2.7673750694187076,
           2.7534450226153018,
           2.738932460682622,
           2.7238422278985652,
           2.7081793916887196,
           2.691949245375014,
           2.6751573111810076,
           2.657809343516581,
           2.6399113325669337,
           2.621469508213173,
           2.6024903443143854,
           2.582980563383933,
           2.5629471416959078,
           2.5423973148610948,
           2.521338583915649,
           2.4997787219699146,
           2.4777257814694233,
           2.455188102125265,
           2.4321743195766685,
           2.4086933748548764,
           2.3847545247242783,
           2.360367352984393,
           2.3355417828246714,
           2.3102880903333674,
           2.284616919271949,
           2.2585392972377876,
           2.232066653350278,
           2.205210837609219,
           2.177984142089273,
           2.1503993241508246,
           2.1224696318655587,
           2.0942088318747873,
           2.0656312399199703,
           2.0367517543080753,
           2.007585892599486,
           1.9781498318329753,
           1.9484604526307745,
           1.9185353875568094,
           1.8883930741323167,
           1.8580528129448972,
           1.8275348313187405,
           1.7968603530442793,
           1.7660516746933366,
           1.735132249068903,
           1.7041267763543226,
           1.6730613035311805,
           1.6419633326239358,
           1.610861938296102,
           1.5797878952597606,
           1.5487738158573576,
           1.5178542980196241,
           1.4870660835805136,
           1.4564482266203556,
           1.426042271089187,
           1.3958924364066432,
           1.3660458090121754,
           1.3365525369156697,
           1.3074660231380761,
           1.2788431124996662,
           1.2507442644809115,
           1.2232337028313287,
           1.1963795302412343,
           1.1702537937631572,
           1.1449324838705561,
           1.1204954472432085,
           1.0970261908396024,
           1.0746115529409295,
           1.05334121613821,
           1.0333070383082201,
           1.0146021811836423,
           0.9973200228546129,
           0.9815528509792532,
           0.9673903478289495,
           0.9549178961970571,
           0.9442147555569073,
           0.9353521787158074,
           0.9283915578463188,
           0.9233827019856842,
           0.9203623527674555,
           0.9193530389822417,
           0.9203623527674575,
           0.9233827019856884,
           0.9283915578463249,
           0.9353521787158156,
           0.9442147555569173,
           0.954917896197069,
           0.9673903478289633,
           0.9815528509792686,
           0.99732002285463,
           1.0146021811836607,
           1.0333070383082401,
           1.0533412161382312,
           1.074611552940952,
           1.0970261908396262,
           1.1204954472432334,
           1.1449324838705819,
           1.1702537937631836,
           1.1963795302412616,
           1.2232337028313567,
           1.2507442644809401,
           1.278843112499695,
           1.307466023138106,
           1.3365525369156996,
           1.3660458090122058,
           1.3958924364066738,
           1.4260422710892182,
           1.456448226620387,
           1.4870660835805452,
           1.5178542980196557,
           1.5487738158573896,
           1.5797878952597924,
           1.6108619382961338,
           1.6419633326239678,
           1.6730613035312125,
           1.7041267763543544,
           1.7351322490689347,
           1.766051674693368,
           1.796860353044311,
           1.8275348313187716,
           1.8580528129449283,
           1.8883930741323478,
           1.91853538755684,
           1.9484604526308051,
           1.9781498318330062,
           2.0075858925995167,
           2.0367517543081046,
           2.0656312399199996,
           2.0942088318748167,
           2.122469631865587,
           2.1503993241508534,
           2.1779841420893016,
           2.2052108376092465,
           2.2320666533503055,
           2.2585392972378147,
           2.284616919271976,
           2.310288090333393,
           2.3355417828246967,
           2.3603673529844182,
           2.384754524724303,
           2.4086933748549004,
           2.432174319576692,
           2.4551881021252884,
           2.4777257814694456,
           2.4997787219699372,
           2.5213385839156706,
           2.542397314861116,
           2.562947141695929,
           2.582980563383953,
           2.6024903443144045,
           2.621469508213193,
           2.639911332566952,
           2.657809343516599,
           2.6751573111810254,
           2.691949245375031,
           2.708179391688736,
           2.7238422278985803,
           2.7389324606826375,
           2.753445022615317,
           2.767375069418722,
           2.780717977449877,
           2.7934693414048546,
           2.8056249722224678,
           2.81718089517172,
           2.8281333481085547,
           2.838478779888756,
           2.848213848924972,
           2.857335421876947,
           2.8658405724650216,
           2.8737265803978698,
           2.8809909304063153,
           2.887631311375839,
           2.8936456155711303,
           2.899031937946743,
           2.9037885755385378,
           2.907914026931218,
           2.9114069917978407,
           2.914266370507736,
           2.9164912637997777,
           2.918080972518472,
           2.9190349974108036
          ],
          [
           2.9311440620976645,
           2.9308253539935265,
           2.9298693301156065,
           2.928276291796699,
           2.926046741356086,
           2.923181382247236,
           2.9196811192662198,
           2.915547058822383,
           2.910780509273404,
           2.905382981327298,
           2.8993561885144468,
           2.892702047733278,
           2.885422679873757,
           2.8775204105234495,
           2.868997770761518,
           2.859857498046682,
           2.850102537205861,
           2.8397360415309607,
           2.8287613739920796,
           2.8171821085762376,
           2.8050020317617,
           2.792225144138922,
           2.7788556621902654,
           2.7648980202417768,
           2.7503568726016296,
           2.735237095901195,
           2.719543791656242,
           2.7032822890674124,
           2.686458148080944,
           2.6690771627325667,
           2.6511453647997176,
           2.632669027789553,
           2.6136546712928777,
           2.5941090657369936,
           2.574039237573606,
           2.553452474941415,
           2.5323563338468507,
           2.510758644910608,
           2.488667520732311,
           2.4660913639307105,
           2.443038875922519,
           2.419519066509152,
           2.3955412643475706,
           2.3711151283889285,
           2.3462506603771285,
           2.320958218508564,
           2.2952485323644676,
           2.269132719238444,
           2.2426223019940674,
           2.2157292286008676,
           2.1884658935118746,
           2.160845161062066,
           2.1328803910847602,
           2.104585466962295,
           2.075974826348243,
           2.0470634948210167,
           2.017867122753039,
           1.9884020257055577,
           1.9586852286866392,
           1.9287345146385797,
           1.8985684775505878,
           1.8682065806225268,
           1.8376692199349818,
           1.8069777941087635,
           1.776154780461637,
           1.7452238181894666,
           1.714209799110261,
           1.683138966509174,
           1.6520390226054662,
           1.6209392451227171,
           1.5898706133732063,
           1.5588659441565387,
           1.527960037608825,
           1.497189832906835,
           1.466594573413027,
           1.4362159804201047,
           1.4060984340920408,
           1.376289159473066,
           1.34683841451497,
           1.317799675923165,
           1.289229817211995,
           1.261189271664978,
           1.233742170904459,
           1.2069564474994732,
           1.1809038875286062,
           1.1556601163676208,
           1.1313044983629654,
           1.1079199287473582,
           1.0855924945259479,
           1.0644109805992514,
           1.0444661986822825,
           1.0258501202773718,
           1.0086548016858008,
           0.9929710992693522,
           0.9788871870355021,
           0.9664869057315154,
           0.955847991907325,
           0.9470402549784054,
           0.9401237876213427,
           0.9351473068977227,
           0.9321467274731243,
           0.9311440620976645,
           0.9321467274731263,
           0.9351473068977268,
           0.940123787621349,
           0.9470402549784136,
           0.9558479919073348,
           0.9664869057315273,
           0.9788871870355156,
           0.9929710992693673,
           1.0086548016858177,
           1.0258501202773902,
           1.0444661986823025,
           1.0644109805992725,
           1.0855924945259703,
           1.1079199287473815,
           1.1313044983629899,
           1.155660116367646,
           1.1809038875286326,
           1.2069564474995,
           1.233742170904487,
           1.2611892716650064,
           1.2892298172120238,
           1.3177996759231942,
           1.3468384145150003,
           1.3762891594730966,
           1.4060984340920717,
           1.436215980420136,
           1.4665945734130583,
           1.4971898329068665,
           1.5279600376088565,
           1.5588659441565704,
           1.589870613373238,
           1.6209392451227491,
           1.6520390226054982,
           1.683138966509206,
           1.714209799110293,
           1.7452238181894981,
           1.7761547804616689,
           1.806977794108795,
           1.8376692199350133,
           1.868206580622558,
           1.8985684775506189,
           1.9287345146386108,
           1.9586852286866696,
           1.9884020257055883,
           2.0178671227530693,
           2.0470634948210464,
           2.075974826348273,
           2.104585466962325,
           2.132880391084789,
           2.1608451610620945,
           2.188465893511903,
           2.2157292286008956,
           2.242622301994095,
           2.2691327192384714,
           2.2952485323644938,
           2.32095821850859,
           2.3462506603771542,
           2.3711151283889533,
           2.395541264347596,
           2.419519066509177,
           2.4430388759225425,
           2.4660913639307345,
           2.4886675207323337,
           2.5107586449106307,
           2.532356333846872,
           2.5534524749414365,
           2.5740392375736265,
           2.594109065737014,
           2.6136546712928976,
           2.6326690277895723,
           2.6511453647997363,
           2.669077162732584,
           2.6864581480809617,
           2.70328228906743,
           2.7195437916562586,
           2.735237095901211,
           2.7503568726016447,
           2.764898020241791,
           2.7788556621902796,
           2.792225144138936,
           2.8050020317617124,
           2.8171821085762496,
           2.8287613739920903,
           2.8397360415309714,
           2.850102537205871,
           2.8598574980466918,
           2.8689977707615273,
           2.8775204105234584,
           2.8854226798737646,
           2.892702047733285,
           2.8993561885144534,
           2.9053829813273038,
           2.910780509273409,
           2.915547058822387,
           2.919681119266224,
           2.9231813822472392,
           2.9260467413560884,
           2.928276291796702,
           2.929869330115608,
           2.930825353993527
          ],
          [
           2.942034263469994,
           2.9417149445018995,
           2.940757088598037,
           2.939160998789659,
           2.936927180229092,
           2.934056340340877,
           2.9305493890349976,
           2.926407438983799,
           2.921631805964707,
           2.916224009271363,
           2.9101857721962783,
           2.9035190225886787,
           2.8962258934917373,
           2.8883087238640144,
           2.879770059390526,
           2.8706126533895255,
           2.8608394678217954,
           2.850453674409993,
           2.8394586558763946,
           2.827858007308247,
           2.8156555376608927,
           2.8028552714098,
           2.789461450363768,
           2.7754785356527143,
           2.7609112099047888,
           2.745764379628903,
           2.7300431778203453,
           2.713752966808768,
           2.696899341369693,
           2.67948813212265,
           2.6615254092412517,
           2.6430174865029,
           2.6239709257084396,
           2.6043925415049642,
           2.5842894066481272,
           2.5636688577438123,
           2.5425385015128383,
           2.5209062216265714,
           2.4987801861659933,
           2.4761688557618506,
           2.453080992479168,
           2.429525669515589,
           2.405512281789872,
           2.381050557504378,
           2.3561505707737056,
           2.3308227554207415,
           2.305077920051483,
           2.2789272645310037,
           2.252382397995121,
           2.2254553585456107,
           2.1981586347914326,
           2.170505189414364,
           2.1425084849548313,
           2.1141825120326216,
           2.085541820237623,
           2.0566015519477645,
           2.0273774793549633,
           1.9978860450049614,
           1.9681444061833753,
           1.9381704835078117,
           1.907983014114028,
           1.8776016098523785,
           1.8470468209381896,
           1.81634020552513,
           1.7855044056924843,
           1.7545632303532632,
           1.7235417455975248,
           1.6924663729803024,
           1.6613649962413861,
           1.630267076898636,
           1.5992037790796783,
           1.5682081038389066,
           1.5373150330354235,
           1.5065616826079677,
           1.4759874647568814,
           1.4456342581093697,
           1.415546584377902,
           1.3857717892946584,
           1.3563602246873456,
           1.3273654274227988,
           1.2988442895563501,
           1.2708572123658886,
           1.2434682350126516,
           1.216745126372598,
           1.1907594261753374,
           1.165586419076664,
           1.1413050228500718,
           1.117997569774076,
           1.09574945887912,
           1.0746486564691033,
           1.0547850238074798,
           1.0362494546629273,
           1.0191328121163223,
           1.0035246640507993,
           0.9895118301683672,
           0.9771767697860372,
           0.966595857992562,
           0.9578376162035364,
           0.9509609793133736,
           0.9460136927356172,
           0.94303093601274,
           0.9420342634699939,
           0.9430309360127421,
           0.9460136927356213,
           0.9509609793133798,
           0.9578376162035444,
           0.966595857992572,
           0.9771767697860488,
           0.9895118301683807,
           1.0035246640508146,
           1.0191328121163392,
           1.0362494546629457,
           1.0547850238074998,
           1.0746486564691242,
           1.0957494588791423,
           1.1179975697740991,
           1.1413050228500963,
           1.1655864190766891,
           1.1907594261753636,
           1.2167451263726248,
           1.2434682350126793,
           1.2708572123659172,
           1.2988442895563792,
           1.3273654274228284,
           1.3563602246873758,
           1.3857717892946888,
           1.4155465843779327,
           1.4456342581094004,
           1.4759874647569127,
           1.5065616826079995,
           1.5373150330354552,
           1.5682081038389384,
           1.5992037790797102,
           1.6302670768986678,
           1.6613649962414183,
           1.6924663729803344,
           1.7235417455975568,
           1.754563230353295,
           1.785504405692516,
           1.8163402055251616,
           1.8470468209382207,
           1.8776016098524098,
           1.9079830141140588,
           1.938170483507843,
           1.9681444061834061,
           1.9978860450049916,
           2.027377479354994,
           2.0566015519477943,
           2.0855418202376526,
           2.114182512032651,
           2.14250848495486,
           2.170505189414393,
           2.198158634791461,
           2.225455358545639,
           2.252382397995149,
           2.2789272645310312,
           2.3050779200515095,
           2.3308227554207672,
           2.356150570773731,
           2.3810505575044036,
           2.405512281789897,
           2.4295256695156136,
           2.453080992479192,
           2.4761688557618746,
           2.4987801861660155,
           2.5209062216265936,
           2.54253850151286,
           2.5636688577438336,
           2.5842894066481477,
           2.6043925415049847,
           2.62397092570846,
           2.6430174865029192,
           2.661525409241271,
           2.6794881321226685,
           2.696899341369711,
           2.713752966808785,
           2.7300431778203618,
           2.7457643796289193,
           2.7609112099048034,
           2.7754785356527285,
           2.7894614503637816,
           2.802855271409814,
           2.8156555376609056,
           2.8278580073082593,
           2.839458655876406,
           2.8504536744100046,
           2.8608394678218056,
           2.870612653389535,
           2.8797700593905358,
           2.8883087238640237,
           2.896225893491745,
           2.9035190225886853,
           2.910185772196285,
           2.916224009271369,
           2.921631805964713,
           2.9264074389838033,
           2.9305493890350016,
           2.9340563403408795,
           2.9369271802290946,
           2.939160998789661,
           2.940757088598038,
           2.941714944501901
          ],
          [
           2.9520131075327343,
           2.951693232778823,
           2.950733710036222,
           2.949134843892949,
           2.9468971420980243,
           2.944021315715746,
           2.9405082793433315,
           2.9363591513935257,
           2.9315752544443257,
           2.9261581156584557,
           2.920109467275725,
           2.9134312471819763,
           2.9061255995588713,
           2.8981948756193665,
           2.8896416344343616,
           2.8804686438566645,
           2.870678881549128,
           2.860275536124569,
           2.8492620084059,
           2.837641912815762,
           2.825419078905906,
           2.8125975530375618,
           2.7991816002251557,
           2.785175706156916,
           2.770584579407189,
           2.7554131538567366,
           2.7396665913387577,
           2.723350284530114,
           2.7064698601090216,
           2.6890311822024917,
           2.6710403561489935,
           2.65250373260419,
           2.6334279120202617,
           2.6138197495321798,
           2.5936863602874984,
           2.5730351252596897,
           2.5518736975888903,
           2.5302100094981426,
           2.5080522798378317,
           2.4854090223161576,
           2.46228905447905,
           2.438701507509174,
           2.414655836920432,
           2.390161834231907,
           2.365229639713417,
           2.3398697563039224,
           2.3140930648140303,
           2.2879108405347646,
           2.261334771386801,
           2.234376977757544,
           2.207050034187804,
           2.1793669930855497,
           2.151341410661312,
           2.1229873752983424,
           2.0943195385906725,
           2.0653531493037085,
           2.036104090535001,
           2.006588920377136,
           1.9768249164102283,
           1.9468301243778903,
           1.9166234114274059,
           1.8862245243214846,
           1.8556541530545472,
           1.8249340003297105,
           1.794086857371893,
           1.763136686565494,
           1.7321087114090157,
           1.7010295142700311,
           1.6699271423971416,
           1.6388312225948576,
           1.607773084884801,
           1.5767858953525082,
           1.5459047982013068,
           1.515167066788547,
           1.4846122630872014,
           1.454282404576714,
           1.424222136997045,
           1.394478910672459,
           1.365103157198198,
           1.3361484621553466,
           1.30767172815133,
           1.2797333208577752,
           1.252397188830473,
           1.2257309457682581,
           1.1998059015551141,
           1.1746970260399152,
           1.1504828272154797,
           1.1272451235213614,
           1.1050686887668222,
           1.084040748103027,
           1.0642503050987842,
           1.0457872838612383,
           1.0287414768178365,
           1.0132012986020473,
           0.9992523595101913,
           0.9869758877867836,
           0.976447047499516,
           0.9677332162603991,
           0.9608923022356392,
           0.9559711901595545,
           0.9530044089755835,
           0.9520131075327342,
           0.9530044089755856,
           0.9559711901595583,
           0.9608923022356451,
           0.9677332162604071,
           0.976447047499526,
           0.9869758877867952,
           0.9992523595102046,
           1.0132012986020624,
           1.0287414768178533,
           1.0457872838612567,
           1.064250305098804,
           1.0840407481030478,
           1.1050686887668444,
           1.1272451235213847,
           1.150482827215504,
           1.1746970260399403,
           1.1998059015551406,
           1.2257309457682852,
           1.2523971888305008,
           1.2797333208578032,
           1.307671728151359,
           1.336148462155376,
           1.3651031571982275,
           1.3944789106724895,
           1.424222136997076,
           1.454282404576745,
           1.4846122630872332,
           1.5151670667885784,
           1.5459047982013383,
           1.57678589535254,
           1.6077730848848328,
           1.6388312225948896,
           1.6699271423971738,
           1.7010295142700629,
           1.7321087114090479,
           1.7631366865655258,
           1.7940868573719249,
           1.824934000329742,
           1.8556541530545783,
           1.8862245243215159,
           1.9166234114274372,
           1.9468301243779214,
           1.9768249164102587,
           2.0065889203771663,
           2.0361040905350314,
           2.0653531493037387,
           2.0943195385907023,
           2.122987375298372,
           2.151341410661341,
           2.1793669930855786,
           2.2070500341878323,
           2.234376977757572,
           2.2613347713868284,
           2.2879108405347917,
           2.3140930648140574,
           2.3398697563039486,
           2.365229639713443,
           2.390161834231933,
           2.4146558369204563,
           2.4387015075091982,
           2.462289054479074,
           2.4854090223161807,
           2.508052279837855,
           2.530210009498165,
           2.5518736975889125,
           2.573035125259711,
           2.5936863602875193,
           2.6138197495322,
           2.6334279120202813,
           2.6525037326042096,
           2.6710403561490126,
           2.68903118220251,
           2.706469860109039,
           2.7233502845301314,
           2.739666591338774,
           2.755413153856753,
           2.770584579407205,
           2.7851757061569304,
           2.7991816002251704,
           2.812597553037575,
           2.825419078905919,
           2.837641912815774,
           2.8492620084059115,
           2.8602755361245804,
           2.8706788815491384,
           2.8804686438566742,
           2.8896416344343705,
           2.898194875619375,
           2.9061255995588793,
           2.913431247181984,
           2.9201094672757315,
           2.9261581156584615,
           2.9315752544443314,
           2.93635915139353,
           2.940508279343336,
           2.9440213157157498,
           2.9468971420980266,
           2.949134843892951,
           2.950733710036223,
           2.9516932327788243
          ],
          [
           2.9610709403987285,
           2.9607505643996306,
           2.9597895383924087,
           2.958188168378462,
           2.9559469644643337,
           2.953066641018828,
           2.9495481168946363,
           2.945392515716104,
           2.9406011662352896,
           2.9351756027589877,
           2.929117565649867,
           2.9224290019054666,
           2.9151120658193315,
           2.9071691197291902,
           2.8986027348576964,
           2.889415692251924,
           2.8796109838285466,
           2.869191813532357,
           2.858161598616633,
           2.8465239710547103,
           2.8342827790930847,
           2.82144208895738,
           2.808006186723624,
           2.7939795803684686,
           2.7793670020132977,
           2.764173410378581,
           2.748403993466359,
           2.7320641714904506,
           2.715159600075772,
           2.69769617375021,
           2.679680029754638,
           2.661117552199107,
           2.6420153765958485,
           2.6223803948026516,
           2.6022197604133015,
           2.581540894635306,
           2.560351492698928,
           2.538659530845764,
           2.5164732739497437,
           2.4938012838285224,
           2.4706524283088194,
           2.447035891115456,
           2.4229611826605946,
           2.3984381518171722,
           2.373476998768702,
           2.348088289036641,
           2.322282968796425,
           2.2960723816041284,
           2.2694682866676077,
           2.2424828788090125,
           2.215128810279758,
           2.1874192146045597,
           2.1593677326479357,
           2.130988541114812,
           2.1022963837164794,
           2.0733066052542024,
           2.0440351888951485,
           2.01449879693897,
           1.984714815398039,
           1.9547014027397178,
           1.9244775431647503,
           1.8940631048210563,
           1.8634789033761185,
           1.8327467713924108,
           1.8018896339672457,
           1.7709315911087642,
           1.7398980073205996,
           1.708815608855207,
           1.6777125890650466,
           1.6466187222255637,
           1.6155654861163908,
           1.5845861935176755,
           1.5537161325950544,
           1.5229927158949355,
           1.4924556373342752,
           1.462147036125584,
           1.4321116660053816,
           1.4023970674071868,
           1.3730537393112845,
           1.344135306386421,
           1.3156986756900244,
           1.2878041755985468,
           1.2605156677977452,
           1.2339006210979417,
           1.208030133610739,
           1.182978887540547,
           1.1588250186809979,
           1.1356498809176023,
           1.113537684968805,
           1.0925749906835844,
           1.0728500339630438,
           1.0544518733228574,
           1.037469347750141,
           1.0219898471552187,
           1.0080979093898845,
           0.9958736730509532,
           0.9853912320771245,
           0.9767169548168967,
           0.9699078446009081,
           0.9650100284326358,
           0.9620574629199502,
           0.9610709403987284,
           0.9620574629199521,
           0.9650100284326398,
           0.9699078446009142,
           0.9767169548169046,
           0.9853912320771345,
           0.9958736730509649,
           1.0080979093898979,
           1.0219898471552338,
           1.0374693477501575,
           1.0544518733228756,
           1.0728500339630636,
           1.0925749906836055,
           1.1135376849688268,
           1.1356498809176256,
           1.1588250186810223,
           1.182978887540572,
           1.2080301336107653,
           1.2339006210979686,
           1.260515667797773,
           1.2878041755985752,
           1.3156986756900533,
           1.34413530638645,
           1.3730537393113145,
           1.402397067407217,
           1.4321116660054123,
           1.462147036125615,
           1.4924556373343065,
           1.5229927158949672,
           1.5537161325950866,
           1.5845861935177072,
           1.6155654861164226,
           1.646618722225596,
           1.6777125890650786,
           1.708815608855239,
           1.7398980073206314,
           1.7709315911087957,
           1.8018896339672774,
           1.8327467713924424,
           1.8634789033761496,
           1.8940631048210874,
           1.9244775431647811,
           1.9547014027397487,
           1.9847148153980696,
           2.0144987969390007,
           2.044035188895178,
           2.0733066052542326,
           2.1022963837165096,
           2.1309885411148413,
           2.1593677326479646,
           2.187419214604588,
           2.215128810279786,
           2.24248287880904,
           2.2694682866676357,
           2.296072381604156,
           2.3222829687964515,
           2.348088289036667,
           2.3734769987687283,
           2.3984381518171976,
           2.422961182660619,
           2.44703589111548,
           2.4706524283088434,
           2.493801283828546,
           2.516473273949767,
           2.538659530845787,
           2.5603514926989503,
           2.5815408946353275,
           2.6022197604133224,
           2.622380394802672,
           2.642015376595869,
           2.661117552199126,
           2.6796800297546572,
           2.697696173750228,
           2.71515960007579,
           2.732064171490467,
           2.748403993466376,
           2.7641734103785964,
           2.7793670020133123,
           2.7939795803684833,
           2.8080061867236386,
           2.8214420889573932,
           2.8342827790930976,
           2.846523971054722,
           2.858161598616645,
           2.8691918135323675,
           2.879610983828556,
           2.8894156922519336,
           2.8986027348577053,
           2.907169119729199,
           2.915112065819339,
           2.9224290019054737,
           2.929117565649874,
           2.9351756027589935,
           2.940601166235294,
           2.945392515716108,
           2.9495481168946402,
           2.9530666410188315,
           2.955946964464336,
           2.9581881683784643,
           2.95978953839241,
           2.960750564399632
          ],
          [
           2.9691989991996697,
           2.968878176011151,
           2.9679158088583253,
           2.966312205011093,
           2.964067876691841,
           2.9611835412351186,
           2.9576601213128226,
           2.9534987452265793,
           2.9487007472694797,
           2.9432676681598444,
           2.9372012555502254,
           2.9305034646153856,
           2.9231764587235975,
           2.9152226101961696,
           2.9066445011607946,
           2.8974449245049385,
           2.8876268849362527,
           2.877193600157719,
           2.8661485021661055,
           2.85449523868314,
           2.8422376747298137,
           2.8293798943552098,
           2.8159262025323915,
           2.8018811272350694,
           2.787249421710083,
           2.772036066962148,
           2.7562462744688774,
           2.7398854891457427,
           2.7229593925825237,
           2.705473906574773,
           2.687435196976026,
           2.668849677898922,
           2.6497240162960085,
           2.630065136953908,
           2.6098802279377145,
           2.5891767465259576,
           2.567962425680294,
           2.54624528109833,
           2.524033618902551,
           2.501336044023473,
           2.478161469340674,
           2.454519125651541,
           2.430418572544317,
           2.4058697102594464,
           2.380882792631411,
           2.355468441212158,
           2.3296376606871085,
           2.303401855705463,
           2.2767728492583386,
           2.2497629027511588,
           2.222384737930753,
           2.1946515608429404,
           2.166577088012928,
           2.138175575058785,
           2.1094618479675167,
           2.0804513372838582,
           2.0511601154837877,
           2.021604937827753,
           1.9918032870125573,
           1.961773421965327,
           1.9315344311476033,
           1.9011062907615588,
           1.8705099282727433,
           1.83976729168327,
           1.8089014250042454,
           1.777936550384204,
           1.7468981573483793,
           1.7158130995879732,
           1.684709699704234,
           1.6536178622529625,
           1.6225691953432146,
           1.5915971409098282,
           1.5607371135911865,
           1.5300266478870637,
           1.4995055529295347,
           1.469216073753057,
           1.4392030573754835,
           1.4095141212753872,
           1.3801998209468997,
           1.3513138121063613,
           1.322913001794308,
           1.2950576810491445,
           1.2678116300275877,
           1.2412421844382002,
           1.2154202499997233,
           1.1904202494460876,
           1.166319984549053,
           1.1432003939684647,
           1.121145186806316,
           1.1002403319557543,
           1.0805733851873092,
           1.0622326399109212,
           1.0453060941479568,
           1.0298802357314942,
           1.0160386601123834,
           1.003860549924026,
           0.9934190616332043,
           0.9847796805689468,
           0.9779986192731485,
           0.9731213431154347,
           0.9701813092936102,
           0.9691989991996697,
           0.9701813092936123,
           0.9731213431154386,
           0.9779986192731545,
           0.9847796805689547,
           0.9934190616332139,
           1.0038605499240378,
           1.0160386601123967,
           1.0298802357315093,
           1.0453060941479735,
           1.0622326399109394,
           1.0805733851873287,
           1.1002403319557748,
           1.1211451868063382,
           1.1432003939684878,
           1.1663199845490773,
           1.1904202494461127,
           1.2154202499997493,
           1.2412421844382273,
           1.2678116300276152,
           1.2950576810491727,
           1.3229130017943367,
           1.3513138121063906,
           1.38019982094693,
           1.4095141212754176,
           1.4392030573755141,
           1.469216073753088,
           1.4995055529295658,
           1.530026647887095,
           1.5607371135912183,
           1.59159714090986,
           1.6225691953432468,
           1.653617862252995,
           1.684709699704266,
           1.7158130995880054,
           1.7468981573484113,
           1.7779365503842357,
           1.8089014250042774,
           1.8397672916833017,
           1.870509928272775,
           1.9011062907615903,
           1.9315344311476343,
           1.9617734219653582,
           1.991803287012588,
           2.0216049378277834,
           2.051160115483818,
           2.0804513372838884,
           2.1094618479675464,
           2.1381755750588143,
           2.166577088012957,
           2.1946515608429693,
           2.2223847379307813,
           2.2497629027511867,
           2.276772849258366,
           2.3034018557054896,
           2.329637660687135,
           2.3554684412121842,
           2.3808827926314367,
           2.4058697102594717,
           2.4304185725443412,
           2.4545191256515655,
           2.4781614693406975,
           2.5013360440234966,
           2.5240336189025743,
           2.546245281098353,
           2.5679624256803164,
           2.589176746525979,
           2.609880227937736,
           2.630065136953928,
           2.649724016296029,
           2.668849677898942,
           2.6874351969760446,
           2.7054739065747913,
           2.7229593925825415,
           2.739885489145759,
           2.7562462744688943,
           2.7720360669621646,
           2.7872494217100985,
           2.8018811272350845,
           2.815926202532406,
           2.829379894355223,
           2.842237674729826,
           2.8544952386831524,
           2.866148502166118,
           2.8771936001577307,
           2.887626884936263,
           2.8974449245049487,
           2.9066445011608026,
           2.915222610196178,
           2.923176458723605,
           2.930503464615393,
           2.9372012555502316,
           2.94326766815985,
           2.948700747269485,
           2.9534987452265846,
           2.9576601213128266,
           2.9611835412351217,
           2.964067876691843,
           2.966312205011094,
           2.967915808858327,
           2.968878176011151
          ],
          [
           2.97638942056361,
           2.976068203808789,
           2.975104656331007,
           2.973499086522444,
           2.9712520084774585,
           2.9683641421544857,
           2.964836413604386,
           2.960669955266891,
           2.9558661063373415,
           2.950426413206417,
           2.9443526299760543,
           2.937646719055373,
           2.930310851840917,
           2.9223474094862083,
           2.913758983766206,
           2.9045483780429446,
           2.8947186083393808,
           2.8842729045291957,
           2.873214711651187,
           2.8615476913577313,
           2.8492757235077564,
           2.8364029079157174,
           2.8229335662691577,
           2.8088722442286707,
           2.7942237137253567,
           2.7789929754723337,
           2.7631852617083728,
           2.7468060391934546,
           2.729861012477856,
           2.7123561274684342,
           2.694297575317921,
           2.675691796665519,
           2.656545486259684,
           2.636865597996893,
           2.616659350413385,
           2.595934232670323,
           2.5746980110766837,
           2.552958736198356,
           2.5307247506065695,
           2.5080046973238455,
           2.484807529031228,
           2.461142518106697,
           2.437019267571392,
           2.4124477230276717,
           2.3874381856811526,
           2.362001326547785,
           2.336148201956795,
           2.3098902704709974,
           2.283239411357704,
           2.2562079447562073,
           2.228808653701722,
           2.201054808180791,
           2.172960191409505,
           2.1445391285435638,
           2.1158065180481143,
           2.0867778659755563,
           2.0574693234208783,
           2.0278977274465673,
           1.9980806457923723,
           1.9680364257089498,
           1.9377842472780327,
           1.9073441816046701,
           1.8767372542881415,
           1.8459855145961421,
           1.8151121107799266,
           1.7841413719739914,
           1.753098897119558,
           1.722011651332729,
           1.690908070100784,
           1.659818171627474,
           1.6287736775526298,
           1.5978081421332928,
           1.5669570897813099,
           1.5362581605917824,
           1.5057512631513361,
           1.4754787334655517,
           1.4454854982693206,
           1.4158192402585714,
           1.3865305618821668,
           1.3576731432352853,
           1.3293038882809116,
           1.301483052083598,
           1.2742743399742174,
           1.24774496760463,
           1.2219656687608755,
           1.1970106356942753,
           1.1729573747752273,
           1.1498864587224376,
           1.1278811558407866,
           1.107026917023639,
           1.087410703209558,
           1.0691201400144876,
           1.052242492814954,
           1.0368634648967192,
           1.023065833371175,
           1.010927951931785,
           1.0005221651732557,
           0.9919131945640142,
           0.9851565692222263,
           0.9802971831588023,
           0.9773680625587519,
           0.9763894205636101,
           0.977368062558754,
           0.9802971831588063,
           0.9851565692222322,
           0.9919131945640222,
           1.0005221651732656,
           1.0109279519317966,
           1.0230658333711884,
           1.0368634648967343,
           1.0522424928149705,
           1.0691201400145056,
           1.0874107032095774,
           1.10702691702366,
           1.1278811558408086,
           1.1498864587224606,
           1.1729573747752517,
           1.1970106356943002,
           1.2219656687609015,
           1.2477449676046568,
           1.2742743399742449,
           1.3014830520836262,
           1.3293038882809405,
           1.357673143235315,
           1.3865305618821966,
           1.4158192402586016,
           1.4454854982693512,
           1.4754787334655828,
           1.5057512631513672,
           1.536258160591814,
           1.5669570897813416,
           1.5978081421333248,
           1.6287736775526618,
           1.6598181716275058,
           1.690908070100816,
           1.7220116513327612,
           1.7530988971195895,
           1.7841413719740231,
           1.8151121107799584,
           1.8459855145961737,
           1.876737254288173,
           1.9073441816047016,
           1.9377842472780642,
           1.9680364257089809,
           1.9980806457924034,
           2.027897727446598,
           2.057469323420909,
           2.0867778659755865,
           2.115806518048144,
           2.144539128543593,
           2.1729601914095342,
           2.2010548081808197,
           2.2288086537017504,
           2.2562079447562358,
           2.283239411357731,
           2.309890270471024,
           2.3361482019568216,
           2.362001326547811,
           2.387438185681178,
           2.4124477230276975,
           2.4370192675714173,
           2.4611425181067212,
           2.4848075290312517,
           2.508004697323869,
           2.530724750606592,
           2.5529587361983785,
           2.574698011076706,
           2.5959342326703445,
           2.6166593504134057,
           2.6368655979969136,
           2.656545486259704,
           2.675691796665539,
           2.69429757531794,
           2.7123561274684524,
           2.729861012477875,
           2.7468060391934714,
           2.7631852617083896,
           2.7789929754723497,
           2.794223713725372,
           2.808872244228685,
           2.8229335662691715,
           2.8364029079157307,
           2.8492757235077693,
           2.8615476913577433,
           2.8732147116511983,
           2.884272904529206,
           2.894718608339391,
           2.904548378042955,
           2.913758983766215,
           2.9223474094862167,
           2.9303108518409244,
           2.93764671905538,
           2.944352629976061,
           2.950426413206422,
           2.9558661063373473,
           2.9606699552668956,
           2.9648364136043903,
           2.9683641421544884,
           2.971252008477461,
           2.973499086522447,
           2.975104656331008,
           2.9760682038087904
          ],
          [
           2.9826352482222664,
           2.9823136911434576,
           2.9813491230185547,
           2.9797418532146627,
           2.977492397452301,
           2.974601477969253,
           2.9710700237516376,
           2.966899170833888,
           2.962090262669821,
           2.9566448505775313,
           2.950564694261317,
           2.9438517624144684,
           2.936508233407278,
           2.9285364960652696,
           2.9199391505432835,
           2.9107190093017272,
           2.9008790981920507,
           2.8904226576592467,
           2.8793531440700426,
           2.867674231176321,
           2.855389811724257,
           2.842503999220725,
           2.829021129869625,
           2.8149457646919798,
           2.8002826918450077,
           2.7850369291567674,
           2.769213726894537,
           2.7528185707868116,
           2.7358571853206017,
           2.7183355373377824,
           2.7002598399564284,
           2.6816365568454863,
           2.6624724068837846,
           2.642774369237288,
           2.622549688891664,
           2.601805882680726,
           2.580550745855159,
           2.5587923592400923,
           2.5365390970347472,
           2.5137996353124192,
           2.4905829612846317,
           2.466898383399416,
           2.4427555423503686,
           2.4181644230805293,
           2.3931353678731813,
           2.3676790906305643,
           2.34180669245118,
           2.315529678627016,
           2.288859977193611,
           2.2618099591785374,
           2.2343924607076886,
           2.206620807143654,
           2.1785088394467103,
           2.150070942966286,
           2.121322078889516,
           2.0922778185932995,
           2.0629543811673337,
           2.033368674397529,
           2.003538339521928,
           1.9734818000942476,
           1.9432183153130336,
           1.912768038196307,
           1.8821520790015411,
           1.8513925743074657,
           1.8205127621857529,
           1.7895370638947548,
           1.758491172521104,
           1.7274021489742675,
           1.696298525699157,
           1.6652104184063787,
           1.634169646021051,
           1.6032098589096704,
           1.5723666752488727,
           1.5416778251360825,
           1.5111833016937235,
           1.4809255179669094,
           1.4509494678381243,
           1.4213028884583214,
           1.392036420798457,
           1.3632037638364582,
           1.3348618165940924,
           1.307070800717396,
           1.2798943545597803,
           1.253399587809355,
           1.2276570836665925,
           1.202740833537791,
           1.1787280873366333,
           1.155699101025556,
           1.1337367623044001,
           1.1129260757651345,
           1.0933534908326517,
           1.0751060598682067,
           1.0582704203274735,
           1.0429316040773475,
           1.0291716888313198,
           1.017068320689994,
           1.006693151983196,
           0.9981102534792825,
           0.9913745725948272,
           0.9865305173501867,
           0.9836107475038185,
           0.9826352482222663,
           0.9836107475038204,
           0.9865305173501907,
           0.9913745725948331,
           0.9981102534792903,
           1.0066931519832059,
           1.0170683206900053,
           1.0291716888313331,
           1.0429316040773622,
           1.05827042032749,
           1.0751060598682247,
           1.0933534908326712,
           1.1129260757651553,
           1.1337367623044219,
           1.155699101025579,
           1.1787280873366575,
           1.2027408335378162,
           1.227657083666619,
           1.2533995878093818,
           1.2798943545598076,
           1.3070708007174239,
           1.3348618165941213,
           1.3632037638364876,
           1.3920364207984868,
           1.4213028884583514,
           1.4509494678381551,
           1.4809255179669405,
           1.511183301693755,
           1.5416778251361143,
           1.5723666752489047,
           1.6032098589097024,
           1.6341696460210826,
           1.665210418406411,
           1.696298525699189,
           1.7274021489742997,
           1.7584911725211356,
           1.7895370638947865,
           1.8205127621857844,
           1.851392574307497,
           1.8821520790015727,
           1.9127680381963386,
           1.9432183153130649,
           1.9734818000942786,
           2.003538339521959,
           2.0333686743975594,
           2.062954381167364,
           2.0922778185933297,
           2.1213220788895457,
           2.1500709429663156,
           2.1785088394467396,
           2.206620807143683,
           2.2343924607077166,
           2.2618099591785654,
           2.2888599771936384,
           2.3155296786270436,
           2.341806692451207,
           2.367679090630591,
           2.3931353678732075,
           2.4181644230805546,
           2.4427555423503935,
           2.4668983833994402,
           2.4905829612846557,
           2.5137996353124428,
           2.5365390970347708,
           2.5587923592401154,
           2.5805507458551813,
           2.6018058826807478,
           2.622549688891685,
           2.642774369237309,
           2.6624724068838055,
           2.6816365568455054,
           2.700259839956448,
           2.718335537337801,
           2.7358571853206195,
           2.752818570786829,
           2.7692137268945536,
           2.7850369291567834,
           2.8002826918450237,
           2.8149457646919944,
           2.829021129869639,
           2.8425039992207384,
           2.8553898117242698,
           2.8676742311763332,
           2.879353144070054,
           2.890422657659257,
           2.900879098192061,
           2.910719009301737,
           2.9199391505432923,
           2.9285364960652784,
           2.9365082334072854,
           2.943851762414475,
           2.9505646942613235,
           2.956644850577537,
           2.9620902626698267,
           2.966899170833892,
           2.971070023751642,
           2.9746014779692564,
           2.9774923974523033,
           2.979741853214665,
           2.981349123018556,
           2.9823136911434585
          ],
          [
           2.987930439740759,
           2.987608595250959,
           2.9866431651684984,
           2.9850344596870553,
           2.9827829959058634,
           2.979889497995208,
           2.9763548974298066,
           2.9721803332917665,
           2.9673671526453345,
           2.9619169109861416,
           2.955831372768227,
           2.9491125120126225,
           2.941762513001938,
           2.933783771065926,
           2.925178893463706,
           2.9159507003689975,
           2.90610222596542,
           2.8956367196597297,
           2.8845576474216865,
           2.872868693260103,
           2.86057376084566,
           2.847676975292037,
           2.834182685108086,
           2.8200954643349525,
           2.805420114883397,
           2.790161669087978,
           2.774325392496329,
           2.757916786913467,
           2.7409415937229045,
           2.723405797508371,
           2.7053156300021706,
           2.68667757438859,
           2.6674983699934605,
           2.647785017393841,
           2.6275447839849813,
           2.606785210045231,
           2.5855141153433387,
           2.5637396063368314,
           2.541470084014746,
           2.518714252443037,
           2.4954811280765736,
           2.47178004990769,
           2.4476206905279967,
           2.4230130681874558,
           2.397967559942817,
           2.372494915996318,
           2.346606275335214,
           2.320313182793274,
           2.29362760766691,
           2.2665619640311925,
           2.239129132914632,
           2.211342486506484,
           2.1832159145862726,
           2.154763853382518,
           2.1260013170860126,
           2.0969439322626404,
           2.067607975431352,
           2.038010414094493,
           2.008168951529857,
           1.9781020756763201,
           1.947829112467018,
           1.917370283985174,
           1.8867467718366517,
           1.8559807861488746,
           1.8250956406160155,
           1.7941158340129746,
           1.7630671385926175,
           1.731976695758069,
           1.7008731193597073,
           1.6697866068986034,
           1.6387490588168665,
           1.6077942059112174,
           1.5769577447076752,
           1.5462774803687311,
           1.515793476353763,
           1.4855482096000185,
           1.4555867294146096,
           1.425956817545103,
           1.3967091460046943,
           1.3678974281462977,
           1.339578557191526,
           1.3118127249181015,
           1.2846635115008627,
           1.2581979356193553,
           1.23248645195555,
           1.2076028812215454,
           1.1836242560514276,
           1.160630564706183,
           1.1387043738942715,
           1.1179303124937052,
           1.0983944000159294,
           1.0801832077267528,
           1.0633828468195585,
           1.048077787140478,
           1.0343495216267093,
           1.0222751053612562,
           1.0119256129941716,
           1.0033645727404419,
           0.9966464473305362,
           0.9918152400765299,
           0.9889033057272915,
           0.987930439740759,
           0.9889033057272933,
           0.9918152400765339,
           0.9966464473305423,
           1.0033645727404499,
           1.0119256129941814,
           1.0222751053612675,
           1.0343495216267224,
           1.0480777871404932,
           1.063382846819575,
           1.0801832077267708,
           1.0983944000159487,
           1.1179303124937259,
           1.1387043738942935,
           1.1606305647062058,
           1.1836242560514516,
           1.2076028812215704,
           1.232486451955576,
           1.2581979356193822,
           1.2846635115008902,
           1.31181272491813,
           1.3395785571915548,
           1.3678974281463272,
           1.396709146004724,
           1.4259568175451334,
           1.45558672941464,
           1.4855482096000494,
           1.5157934763537941,
           1.5462774803687624,
           1.5769577447077066,
           1.6077942059112493,
           1.6387490588168983,
           1.6697866068986353,
           1.7008731193597388,
           1.731976695758101,
           1.7630671385926493,
           1.7941158340130066,
           1.8250956406160472,
           1.8559807861489066,
           1.8867467718366835,
           1.917370283985206,
           1.9478291124670493,
           1.978102075676351,
           2.008168951529888,
           2.0380104140945234,
           2.0676079754313825,
           2.0969439322626706,
           2.1260013170860423,
           2.1547638533825477,
           2.183215914586302,
           2.2113424865065126,
           2.2391291329146608,
           2.2665619640312205,
           2.2936276076669375,
           2.3203131827933006,
           2.346606275335241,
           2.372494915996344,
           2.3979675599428427,
           2.423013068187481,
           2.4476206905280216,
           2.4717800499077143,
           2.495481128076597,
           2.5187142524430612,
           2.5414700840147693,
           2.5637396063368545,
           2.5855141153433605,
           2.6067852100452527,
           2.627544783985002,
           2.6477850173938604,
           2.667498369993481,
           2.6866775743886095,
           2.705315630002189,
           2.72340579750839,
           2.740941593722922,
           2.757916786913484,
           2.7743253924963454,
           2.7901616690879942,
           2.805420114883413,
           2.820095464334967,
           2.8341826851081,
           2.84767697529205,
           2.8605737608456727,
           2.872868693260115,
           2.884557647421698,
           2.8956367196597412,
           2.90610222596543,
           2.915950700369008,
           2.9251788934637153,
           2.9337837710659342,
           2.941762513001946,
           2.949112512012629,
           2.955831372768233,
           2.9619169109861474,
           2.96736715264534,
           2.972180333291772,
           2.976354897429811,
           2.9798894979952117,
           2.982782995905866,
           2.9850344596870566,
           2.9866431651684993,
           2.987608595250959
          ],
          [
           2.9922698723632783,
           2.9919477930973577,
           2.9909816589122444,
           2.989371780679016,
           2.9871186766267956,
           2.984223072509598,
           2.980685901841596,
           2.976508306202524,
           2.971691635615422,
           2.9662374489994625,
           2.9601475147011156,
           2.9534238111075037,
           2.946068527346343,
           2.9380840640775165,
           2.9294730343819597,
           2.920238264754224,
           2.9103827962058255,
           2.8999098854872556,
           2.888823006437381,
           2.8771258514698372,
           2.864822333207003,
           2.85191658627318,
           2.838412969259705,
           2.8243160668759884,
           2.8096306923017393,
           2.79436188975711,
           2.778514937309035,
           2.7620953499337655,
           2.7451088828574113,
           2.7275615351983835,
           2.709459553937793,
           2.690809438246311,
           2.671617944198646,
           2.651892089909673,
           2.6316391611294407,
           2.6108667173377893,
           2.589582598383089,
           2.5677949317138484,
           2.545512140256517,
           2.5227429509978716,
           2.49949640433592,
           2.4757818642693383,
           2.4516090295021336,
           2.4269879455475616,
           2.4019290179233392,
           2.3764430265389977,
           2.3505411413858344,
           2.3242349396504505,
           2.2975364243843184,
           2.270458044874336,
           2.2430127188728806,
           2.2152138568605992,
           2.1870753885310243,
           2.158611791703188,
           2.1298381238866,
           2.1007700567423604,
           2.0714239137045056,
           2.0418167110469407,
           2.011966202703105,
           1.9818909291674789,
           1.9516102708296463,
           1.9211445061120545,
           1.8905148748008507,
           1.859743646973801,
           1.8288541979385347,
           1.7978710895957524,
           1.7668201586326002,
           1.7357286119271829,
           1.7046251295012753,
           1.6735399752884694,
           1.6425051158816242,
           1.611554347277173,
           1.5807234294331733,
           1.5500502281894197,
           1.519574863745452,
           1.4893398644377,
           1.4593903239797825,
           1.4297740596082968,
           1.4005417676880947,
           1.3717471722555348,
           1.3434471606999223,
           1.3157018992960114,
           1.2885749196134146,
           1.2621331649754097,
           1.2364469841873718,
           1.211590057817378,
           1.1876392405600265,
           1.1646743018894659,
           1.1427775466233605,
           1.1220332975594423,
           1.1025272244420972,
           1.0843455076042767,
           1.0675738310795801,
           1.052296208995408,
           1.0385936605622792,
           1.026542762487529,
           1.0162141221977552,
           1.007670829388329,
           1.0009669552651335,
           0.996146176373397,
           0.9932406012807955,
           0.9922698723632783,
           0.9932406012807976,
           0.996146176373401,
           1.0009669552651392,
           1.007670829388337,
           1.0162141221977652,
           1.02654276248754,
           1.0385936605622927,
           1.0522962089954226,
           1.0675738310795966,
           1.0843455076042945,
           1.1025272244421163,
           1.122033297559463,
           1.1427775466233827,
           1.1646743018894887,
           1.1876392405600504,
           1.2115900578174028,
           1.2364469841873977,
           1.2621331649754366,
           1.2885749196134422,
           1.3157018992960394,
           1.3434471606999507,
           1.3717471722555636,
           1.4005417676881247,
           1.429774059608327,
           1.459390323979813,
           1.4893398644377311,
           1.5195748637454831,
           1.5500502281894515,
           1.5807234294332049,
           1.6115543472772043,
           1.6425051158816564,
           1.6735399752885014,
           1.7046251295013073,
           1.7357286119272148,
           1.7668201586326322,
           1.7978710895957843,
           1.828854197938566,
           1.8597436469738324,
           1.8905148748008824,
           1.9211445061120862,
           1.9516102708296772,
           1.9818909291675102,
           2.0119662027031358,
           2.0418167110469714,
           2.0714239137045363,
           2.1007700567423906,
           2.1298381238866297,
           2.158611791703217,
           2.1870753885310537,
           2.215213856860628,
           2.243012718872909,
           2.270458044874364,
           2.2975364243843455,
           2.3242349396504776,
           2.3505411413858615,
           2.3764430265390244,
           2.401929017923365,
           2.4269879455475873,
           2.4516090295021584,
           2.475781864269363,
           2.4994964043359444,
           2.522742950997895,
           2.5455121402565397,
           2.5677949317138715,
           2.589582598383111,
           2.610866717337811,
           2.631639161129462,
           2.651892089909693,
           2.6716179441986667,
           2.69080943824633,
           2.709459553937811,
           2.727561535198402,
           2.745108882857429,
           2.7620953499337824,
           2.778514937309052,
           2.794361889757126,
           2.8096306923017558,
           2.824316066876003,
           2.8384129692597186,
           2.8519165862731928,
           2.864822333207016,
           2.877125851469849,
           2.8888230064373928,
           2.8999098854872667,
           2.9103827962058357,
           2.920238264754234,
           2.9294730343819686,
           2.9380840640775245,
           2.9460685273463505,
           2.9534238111075113,
           2.9601475147011223,
           2.966237448999468,
           2.9716916356154277,
           2.9765083062025286,
           2.9806859018416,
           2.9842230725096006,
           2.987118676626798,
           2.9893717806790177,
           2.990981658912246,
           2.9919477930973586
          ],
          [
           2.99564934796902,
           2.9953270863346497,
           2.9943604052199713,
           2.9927496160236116,
           2.990495237854647,
           2.9875979977004854,
           2.9840588306636056,
           2.97987888026886,
           2.975059498843553,
           2.9696022479730426,
           2.9635088990351424,
           2.9567814338171656,
           2.949422045220048,
           2.941433138054585,
           2.932817329935496,
           2.9235774522796887,
           2.913716551415862,
           2.903237889813341,
           2.892144947438885,
           2.880441423251118,
           2.86813123684318,
           2.8552185302452617,
           2.8417076698997823,
           2.827603248823229,
           2.8129100889699608,
           2.7976332438147544,
           2.781778001172396,
           2.7653498862743566,
           2.7483546651244355,
           2.730798348157272,
           2.7126871942258606,
           2.6940277149466088,
           2.6748266794331395,
           2.655091119452936,
           2.634828335044102,
           2.614045900633005,
           2.5927516716973904,
           2.570953792023735,
           2.548660701612219,
           2.525881145287752,
           2.50262418208099,
           2.478899195449414,
           2.4547159044151443,
           2.4300843757035224,
           2.4050150369744703,
           2.3795186912474153,
           2.3536065326301627,
           2.327290163472566,
           2.3005816130772683,
           2.273493358112243,
           2.2460383448833445,
           2.218230013639697,
           2.1900823251005432,
           2.16160978940906,
           2.132827497736777,
           2.103751156781359,
           2.0743971264207044,
           2.0447824608072556,
           2.0149249532079123,
           1.9848431849165384,
           1.954556578587209,
           1.9240854563562768,
           1.8934511031389545,
           1.862675835500047,
           1.8317830765068959,
           1.8007974369730422,
           1.769744803490626,
           1.7386524336241043,
           1.7075490585925923,
           1.67646499369685,
           1.6454322566419592,
           1.6144846937587625,
           1.5836581139247867,
           1.5529904297152166,
           1.5225218049606726,
           1.4922948074330395,
           1.4623545648032277,
           1.4327489212940667,
           1.4035285915657822,
           1.3747473073008933,
           1.3464619506849782,
           1.318732667504192,
           1.291622950909974,
           1.2651996850703229,
           1.2395331360034292,
           1.2146968749871612,
           1.1907676182278923,
           1.1678249651931367,
           1.1459510174753014,
           1.125229860636624,
           1.1057468936119312,
           1.0875879943424585,
           1.0708385167390009,
           1.055582123019843,
           1.0418994668517394,
           1.029866756059681,
           1.0195542380052116,
           1.0110246646185324,
           1.0043318056742327,
           0.9995190862355928,
           0.99661842546098,
           0.9956493479690199,
           0.9966184254609819,
           0.9995190862355966,
           1.0043318056742387,
           1.0110246646185401,
           1.0195542380052218,
           1.0298667560596924,
           1.0418994668517525,
           1.0555821230198579,
           1.0708385167390173,
           1.0875879943424764,
           1.1057468936119508,
           1.1252298606366447,
           1.1459510174753231,
           1.1678249651931598,
           1.1907676182279163,
           1.2146968749871863,
           1.2395331360034552,
           1.2651996850703497,
           1.2916229509100017,
           1.3187326675042201,
           1.346461950685007,
           1.3747473073009226,
           1.403528591565812,
           1.4327489212940974,
           1.4623545648032583,
           1.4922948074330704,
           1.5225218049607039,
           1.552990429715248,
           1.5836581139248185,
           1.6144846937587944,
           1.6454322566419912,
           1.676464993696882,
           1.7075490585926245,
           1.738652433624136,
           1.769744803490658,
           1.8007974369730737,
           1.8317830765069276,
           1.8626758355000785,
           1.8934511031389858,
           1.9240854563563086,
           1.9545565785872399,
           1.984843184916569,
           2.0149249532079434,
           2.0447824608072858,
           2.0743971264207346,
           2.1037511567813887,
           2.132827497736807,
           2.161609789409089,
           2.190082325100572,
           2.218230013639726,
           2.246038344883373,
           2.273493358112271,
           2.300581613077296,
           2.3272901634725933,
           2.3536065326301903,
           2.379518691247441,
           2.4050150369744965,
           2.4300843757035477,
           2.454715904415169,
           2.4788991954494386,
           2.5026241820810142,
           2.5258811452877756,
           2.5486607016122425,
           2.5709537920237575,
           2.5927516716974126,
           2.614045900633026,
           2.634828335044123,
           2.655091119452957,
           2.67482667943316,
           2.6940277149466283,
           2.7126871942258792,
           2.7307983481572906,
           2.748354665124453,
           2.765349886274374,
           2.7817780011724125,
           2.797633243814771,
           2.8129100889699763,
           2.827603248823244,
           2.841707669899797,
           2.8552185302452755,
           2.8681312368431926,
           2.8804414232511295,
           2.8921449474388967,
           2.9032378898133517,
           2.913716551415872,
           2.923577452279698,
           2.932817329935505,
           2.941433138054594,
           2.949422045220056,
           2.9567814338171727,
           2.963508899035149,
           2.969602247973049,
           2.9750594988435584,
           2.9798788802688647,
           2.9840588306636096,
           2.9875979977004894,
           2.9904952378546494,
           2.9927496160236142,
           2.994360405219973,
           2.995327086334651
          ],
          [
           2.9980655971335954,
           2.997743205361963,
           2.996776133961177,
           2.9951646947070567,
           2.992909407337824,
           2.9900109997227386,
           2.986470408099886,
           2.9822887773848334,
           2.977467461552377,
           2.9720080240941265,
           2.965912238555217,
           2.9591820891539893,
           2.951819771489098,
           2.943827693339079,
           2.935208475560109,
           2.92596495308835,
           2.916100176054008,
           2.9056174110150397,
           2.894520142319258,
           2.8828120736044935,
           2.8704971294474397,
           2.8575794571728688,
           2.8440634288359874,
           2.82995364339199,
           2.815254929068126,
           2.7999723459550885,
           2.7841111888360657,
           2.767676990273505,
           2.7506755239755245,
           2.7331128084658904,
           2.7149951110837334,
           2.6963289523415876,
           2.677121110672966,
           2.6573786276036344,
           2.637108813383865,
           2.6163192531225006,
           2.5950178134674244,
           2.573212649881254,
           2.550912214565665,
           2.528125265092798,
           2.5048608738077216,
           2.4811284380720133,
           2.456937691425164,
           2.4322987157477995,
           2.4072219545187403,
           2.3817182272666186,
           2.3557987453263856,
           2.3294751290214637,
           2.3027594264036977,
           2.2756641336956465,
           2.248202217593224,
           2.2203871396012245,
           2.192232882589995,
           2.163753979778318,
           2.1349655463655686,
           2.1058833140552267,
           2.076523668731843,
           2.0469036915743186,
           2.017041203909629,
           1.986954816132462,
           1.9566639810370938,
           1.926189051927359,
           1.8955513458878055,
           1.864773212612541,
           1.833878109196109,
           1.8028906812905625,
           1.7718368510215954,
           1.7407439120303565,
           1.7096406319612993,
           1.67855736264411,
           1.6475261581116478,
           1.6165809004466916,
           1.5857574332467457,
           1.555093702224913,
           1.524629902110084,
           1.4944086285535976,
           1.4644750331720822,
           1.4348769791362739,
           1.4056651938317397,
           1.3768934140503784,
           1.3486185179068382,
           1.3209006362068387,
           1.2938032343358041,
           1.2673931539209635,
           1.241740601616894,
           1.2169190704871937,
           1.1930051777743136,
           1.1700784016029575,
           1.1482206986583867,
           1.1275159854936365,
           1.1080494682674913,
           1.0899068098172549,
           1.0731731293774398,
           1.0579318391533965,
           1.0442633332556117,
           1.0322435577136568,
           1.0219425044662152,
           1.0134226859343587,
           1.0067376582198766,
           1.0019306681693896,
           0.9990335007415136,
           0.9980655971335952,
           0.9990335007415155,
           1.0019306681693936,
           1.0067376582198824,
           1.0134226859343665,
           1.0219425044662247,
           1.0322435577136684,
           1.0442633332556248,
           1.0579318391534116,
           1.0731731293774562,
           1.0899068098172728,
           1.1080494682675108,
           1.1275159854936576,
           1.1482206986584085,
           1.1700784016029806,
           1.1930051777743373,
           1.216919070487219,
           1.24174060161692,
           1.2673931539209902,
           1.2938032343358317,
           1.3209006362068667,
           1.348618517906867,
           1.3768934140504083,
           1.4056651938317695,
           1.4348769791363043,
           1.4644750331721126,
           1.4944086285536282,
           1.5246299021101155,
           1.5550937022249443,
           1.585757433246777,
           1.6165809004467233,
           1.64752615811168,
           1.6785573626441417,
           1.7096406319613315,
           1.7407439120303887,
           1.7718368510216274,
           1.8028906812905945,
           1.8338781091961411,
           1.8647732126125722,
           1.8955513458878372,
           1.9261890519273905,
           1.9566639810371251,
           1.9869548161324928,
           2.0170412039096592,
           2.0469036915743493,
           2.0765236687318733,
           2.105883314055257,
           2.1349655463655983,
           2.1637539797783476,
           2.1922328825900244,
           2.220387139601253,
           2.2482022175932523,
           2.275664133695675,
           2.302759426403725,
           2.3294751290214912,
           2.355798745326412,
           2.3817182272666453,
           2.4072219545187665,
           2.432298715747825,
           2.456937691425188,
           2.4811284380720386,
           2.504860873807746,
           2.5281252650928216,
           2.5509122145656886,
           2.5732126498812766,
           2.595017813467447,
           2.6163192531225223,
           2.637108813383886,
           2.6573786276036553,
           2.677121110672987,
           2.6963289523416063,
           2.7149951110837525,
           2.733112808465908,
           2.7506755239755423,
           2.767676990273522,
           2.784111188836083,
           2.7999723459551054,
           2.815254929068141,
           2.8299536433920043,
           2.8440634288360016,
           2.8575794571728825,
           2.870497129447453,
           2.8828120736045055,
           2.8945201423192697,
           2.9056174110150503,
           2.916100176054018,
           2.92596495308836,
           2.9352084755601178,
           2.9438276933390872,
           2.951819771489106,
           2.959182089153997,
           2.9659122385552235,
           2.9720080240941322,
           2.9774674615523824,
           2.9822887773848388,
           2.9864704080998905,
           2.990010999722742,
           2.9929094073378266,
           2.995164694707058,
           2.9967761339611787,
           2.9977432053619633
          ],
          [
           2.9995162822919883,
           2.99919381248834,
           2.9982265070669647,
           2.9966146780301406,
           2.9943588454938235,
           2.9914597378567254,
           2.9879182920387337,
           2.9837356537903816,
           2.978913178075594,
           2.973452429530464,
           2.967355183001345,
           2.960623424166123,
           2.953259350243103,
           2.9452653707925838,
           2.936644108616832,
           2.927398400764866,
           2.917531299649202,
           2.9070460742824737,
           2.895946211642714,
           2.8842354181769543,
           2.8719176214537945,
           2.858996971976608,
           2.84547784517022,
           2.831364843555071,
           2.816662799124249,
           2.8013767759401778,
           2.7855120729693343,
           2.769074227175071,
           2.7520690168904713,
           2.7345024654952086,
           2.716380845422573,
           2.697710682525281,
           2.67849876083132,
           2.658752127723974,
           2.6384780995833665,
           2.6176842679303594,
           2.5963785061174174,
           2.5745689766152857,
           2.552264138948904,
           2.52947275834101,
           2.5062039151274442,
           2.4824670150141936,
           2.4582718002529123,
           2.4336283618188848,
           2.4085471526834494,
           2.3830390022815795,
           2.3571151322849007,
           2.330787173800865,
           2.3040671861301374,
           2.2769676772266525,
           2.249501626018197,
           2.2216825067599046,
           2.1935243156086845,
           2.1650415996233967,
           2.1362494884134815,
           2.107163728677727,
           2.0778007218947394,
           2.048177565447374,
           2.018312097484485,
           1.9882229458445537,
           1.9579295813864206,
           1.9274523760916529,
           1.8968126663200582,
           1.8660328216129798,
           1.8351363194464896,
           1.8041478263360182,
           1.7730932856822252,
           1.7420000127211368,
           1.7108967968947564,
           1.6798140118854155,
           1.6487837334503515,
           1.6178398650431534,
           1.587018271004504,
           1.5563569168327083,
           1.525896015689237,
           1.4956781798380243,
           1.4657485751398567,
           1.4361550760036526,
           1.4069484173138251,
           1.3781823387879242,
           1.3499137159574668,
           1.3222026705027836,
           1.2951126510211852,
           1.268710473502024,
           1.2430663088911926,
           1.218253603265246,
           1.1943489144721593,
           1.1714316478683584,
           1.1495836732972278,
           1.1288888060846423,
           1.1094321369873812,
           1.0912992001355921,
           1.074574974406585,
           1.0593427225355803,
           1.0456826835142758,
           1.0336706469673362,
           1.0233764522812274,
           1.0148624688668106,
           1.008182125270955,
           1.0033785619707922,
           1.0004834838382897,
           0.9995162822919884,
           1.0004834838382919,
           1.003378561970796,
           1.008182125270961,
           1.0148624688668184,
           1.0233764522812367,
           1.0336706469673478,
           1.045682683514289,
           1.0593427225355954,
           1.0745749744066013,
           1.0912992001356099,
           1.1094321369874003,
           1.1288888060846627,
           1.1495836732972495,
           1.1714316478683813,
           1.194348914472183,
           1.218253603265271,
           1.2430663088912186,
           1.268710473502051,
           1.2951126510212128,
           1.3222026705028118,
           1.3499137159574954,
           1.3781823387879535,
           1.4069484173138551,
           1.4361550760036828,
           1.465748575139887,
           1.4956781798380554,
           1.525896015689268,
           1.55635691683274,
           1.5870182710045353,
           1.6178398650431849,
           1.648783733450383,
           1.6798140118854474,
           1.7108967968947881,
           1.7420000127211688,
           1.7730932856822574,
           1.8041478263360502,
           1.8351363194465218,
           1.8660328216130115,
           1.89681266632009,
           1.9274523760916846,
           1.9579295813864523,
           1.9882229458445848,
           2.0183120974845155,
           2.048177565447405,
           2.0778007218947696,
           2.1071637286777567,
           2.1362494884135113,
           2.165041599623426,
           2.193524315608714,
           2.2216825067599335,
           2.249501626018225,
           2.2769676772266805,
           2.304067186130165,
           2.330787173800892,
           2.3571151322849273,
           2.3830390022816057,
           2.408547152683475,
           2.43362836181891,
           2.4582718002529367,
           2.482467015014218,
           2.506203915127468,
           2.5294727583410346,
           2.552264138948927,
           2.5745689766153084,
           2.5963785061174396,
           2.6176842679303816,
           2.6384780995833874,
           2.658752127723994,
           2.678498760831341,
           2.6977106825253006,
           2.7163808454225915,
           2.734502465495227,
           2.7520690168904887,
           2.7690742271750874,
           2.7855120729693503,
           2.8013767759401937,
           2.8166627991242645,
           2.8313648435550856,
           2.8454778451702336,
           2.8589969719766217,
           2.8719176214538074,
           2.8842354181769667,
           2.8959462116427255,
           2.907046074282485,
           2.9175312996492124,
           2.9273984007648757,
           2.9366441086168407,
           2.9452653707925927,
           2.9532593502431106,
           2.9606234241661307,
           2.9673551830013514,
           2.97345242953047,
           2.9789131780755995,
           2.983735653790386,
           2.9879182920387377,
           2.991459737856729,
           2.994358845493826,
           2.996614678030142,
           2.9982265070669656,
           2.999193812488341
          ],
          [
           3,
           2.999677504194068,
           2.9987101207910003,
           2.997098161868588,
           2.9948421476687392,
           2.991942806766705,
           2.988401076309713,
           2.9842181023267096,
           2.9793952401114328,
           2.9739340546815924,
           2.96783632131742,
           2.96110402618347,
           2.9537393670380996,
           2.9457447540357156,
           2.9371228106274834,
           2.927876374566925,
           2.918008499027559,
           2.907522453840494,
           2.8964217268607664,
           2.8847100254720894,
           2.872391278240657,
           2.8594696367296866,
           2.845949477487531,
           2.831835404223384,
           2.817132250185963,
           2.8018450807619644,
           2.7859791963126668,
           2.769540135268778,
           2.7525336775054314,
           2.73496584802134,
           2.716842920948255,
           2.6981714239193764,
           2.678958142827934,
           2.659210127010139,
           2.6389346948898282,
           2.6181394401256193,
           2.596832238305251,
           2.5750212542359208,
           2.5527149498840433,
           2.5299220930229334,
           2.5066517666523693,
           2.4829133792601352,
           2.4587166760022225,
           2.4340717508857153,
           2.4089890600463186,
           2.3834794362212492,
           2.3575541045277544,
           2.3312246996679384,
           2.3045032846919513,
           2.2774023714639533,
           2.2499349429886575,
           2.2221144777707926,
           2.193954976395436,
           2.1654709905339162,
           2.1366776545979196,
           2.1075907202832984,
           2.078226594265017,
           2.0486023793252537,
           2.0187359192177876,
           1.9886458475929094,
           1.958351641327715,
           1.9278736786258825,
           1.8972333022679102,
           1.8664528884058247,
           1.8355559213037362,
           1.8045670744249098,
           1.7735122982541318,
           1.742418915217197,
           1.711315722012353,
           1.6802330995953667,
           1.649203130952895,
           1.6182597266487537,
           1.5874387579232352,
           1.5567781968534804,
           1.5263182627274532,
           1.4961015733274858,
           1.4661732992419205,
           1.4365813186040413,
           1.4073763687752252,
           1.378612190424997,
           1.350345658200505,
           1.3226368907175428,
           1.295549330956093,
           1.2691497863407857,
           1.2435084158996748,
           1.2186986500373664,
           1.1947970268011252,
           1.1718829272976403,
           1.1500381924401608,
           1.1293466038419477,
           1.109893213836369,
           1.091763513710301,
           1.0750424356299084,
           1.0598131925963747,
           1.0461559719972728,
           1.034146511433914,
           1.023854599558435,
           1.015342558226969,
           1.0086637735756747,
           1.003861350718125,
           1.0009669679025603,
           0.9999999999999999,
           1.0009669679025626,
           1.0038613507181289,
           1.0086637735756805,
           1.015342558226977,
           1.023854599558445,
           1.0341465114339252,
           1.0461559719972862,
           1.0598131925963896,
           1.0750424356299246,
           1.0917635137103192,
           1.1098932138363884,
           1.1293466038419684,
           1.1500381924401826,
           1.1718829272976632,
           1.1947970268011494,
           1.2186986500373913,
           1.2435084158997007,
           1.2691497863408125,
           1.2955493309561206,
           1.3226368907175707,
           1.350345658200534,
           1.3786121904250266,
           1.4073763687752552,
           1.4365813186040717,
           1.4661732992419512,
           1.4961015733275167,
           1.5263182627274845,
           1.5567781968535117,
           1.5874387579232667,
           1.6182597266487855,
           1.649203130952927,
           1.6802330995953987,
           1.7113157220123851,
           1.742418915217229,
           1.773512298254164,
           1.8045670744249418,
           1.835555921303768,
           1.8664528884058562,
           1.8972333022679417,
           1.9278736786259139,
           1.9583516413277464,
           1.9886458475929405,
           2.0187359192178183,
           2.0486023793252843,
           2.078226594265047,
           2.1075907202833286,
           2.1366776545979493,
           2.165470990533946,
           2.1939549763954647,
           2.2221144777708215,
           2.2499349429886855,
           2.2774023714639813,
           2.3045032846919793,
           2.331224699667965,
           2.3575541045277815,
           2.3834794362212763,
           2.408989060046345,
           2.4340717508857406,
           2.4587166760022474,
           2.4829133792601596,
           2.5066517666523938,
           2.529922093022957,
           2.5527149498840664,
           2.5750212542359434,
           2.5968322383052733,
           2.61813944012564,
           2.638934694889849,
           2.6592101270101605,
           2.678958142827954,
           2.698171423919396,
           2.7168429209482743,
           2.734965848021358,
           2.752533677505449,
           2.7695401352687954,
           2.7859791963126836,
           2.80184508076198,
           2.8171322501859786,
           2.8318354042233986,
           2.8459494774875456,
           2.8594696367297003,
           2.87239127824067,
           2.884710025472102,
           2.8964217268607775,
           2.9075224538405053,
           2.9180084990275703,
           2.927876374566935,
           2.9371228106274923,
           2.945744754035725,
           2.9537393670381076,
           2.9611040261834765,
           2.9678363213174266,
           2.9739340546815987,
           2.979395240111438,
           2.9842181023267145,
           2.9884010763097173,
           2.9919428067667075,
           2.9948421476687415,
           2.997098161868591,
           2.998710120791002,
           2.9996775041940684
          ],
          [
           2.9995162822919874,
           2.9991938124883393,
           2.9982265070669634,
           2.9966146780301397,
           2.9943588454938226,
           2.9914597378567245,
           2.987918292038733,
           2.9837356537903807,
           2.9789131780755933,
           2.973452429530463,
           2.9673551830013443,
           2.9606234241661222,
           2.953259350243102,
           2.945265370792583,
           2.936644108616831,
           2.927398400764865,
           2.9175312996492013,
           2.907046074282473,
           2.895946211642713,
           2.8842354181769534,
           2.8719176214537936,
           2.858996971976607,
           2.845477845170219,
           2.83136484355507,
           2.8166627991242477,
           2.801376775940177,
           2.785512072969333,
           2.76907422717507,
           2.7520690168904705,
           2.7345024654952077,
           2.716380845422572,
           2.69771068252528,
           2.678498760831319,
           2.658752127723973,
           2.6384780995833657,
           2.6176842679303585,
           2.5963785061174165,
           2.5745689766152853,
           2.5522641389489027,
           2.5294727583410097,
           2.506203915127443,
           2.482467015014193,
           2.458271800252911,
           2.4336283618188834,
           2.4085471526834485,
           2.383039002281578,
           2.3571151322848993,
           2.3307871738008643,
           2.3040671861301365,
           2.2769676772266516,
           2.249501626018196,
           2.2216825067599033,
           2.1935243156086837,
           2.165041599623396,
           2.1362494884134806,
           2.1071637286777256,
           2.0778007218947385,
           2.0481775654473737,
           2.018312097484484,
           1.9882229458445528,
           1.95792958138642,
           1.9274523760916522,
           1.8968126663200575,
           1.8660328216129791,
           1.835136319446489,
           1.8041478263360171,
           1.7730932856822246,
           1.742000012721136,
           1.7108967968947555,
           1.6798140118854143,
           1.6487837334503503,
           1.6178398650431522,
           1.5870182710045027,
           1.5563569168327078,
           1.5258960156892358,
           1.4956781798380234,
           1.4657485751398558,
           1.4361550760036517,
           1.4069484173138243,
           1.3781823387879233,
           1.349913715957466,
           1.322202670502783,
           1.2951126510211846,
           1.2687104735020232,
           1.2430663088911917,
           1.2182536032652451,
           1.1943489144721584,
           1.1714316478683575,
           1.1495836732972267,
           1.1288888060846414,
           1.1094321369873803,
           1.091299200135591,
           1.074574974406584,
           1.0593427225355796,
           1.0456826835142747,
           1.0336706469673353,
           1.0233764522812263,
           1.0148624688668098,
           1.0081821252709542,
           1.0033785619707911,
           1.0004834838382888,
           0.9995162822919874,
           1.0004834838382908,
           1.0033785619707951,
           1.0081821252709602,
           1.0148624688668175,
           1.0233764522812359,
           1.0336706469673467,
           1.0456826835142883,
           1.0593427225355945,
           1.0745749744066007,
           1.091299200135609,
           1.1094321369873994,
           1.128888806084662,
           1.1495836732972486,
           1.1714316478683806,
           1.1943489144721824,
           1.2182536032652702,
           1.2430663088912177,
           1.2687104735020498,
           1.295112651021212,
           1.3222026705028112,
           1.3499137159574945,
           1.3781823387879526,
           1.4069484173138542,
           1.436155076003682,
           1.4657485751398864,
           1.4956781798380545,
           1.5258960156892671,
           1.556356916832739,
           1.5870182710045346,
           1.617839865043184,
           1.648783733450382,
           1.6798140118854465,
           1.7108967968947875,
           1.742000012721168,
           1.7730932856822563,
           1.804147826336049,
           1.835136319446521,
           1.8660328216130109,
           1.896812666320089,
           1.9274523760916837,
           1.9579295813864512,
           1.988222945844584,
           2.0183120974845146,
           2.048177565447404,
           2.0778007218947687,
           2.107163728677756,
           2.1362494884135104,
           2.1650415996234247,
           2.193524315608713,
           2.221682506759932,
           2.2495016260182243,
           2.2769676772266796,
           2.304067186130164,
           2.3307871738008914,
           2.357115132284927,
           2.3830390022816044,
           2.4085471526834747,
           2.433628361818909,
           2.458271800252936,
           2.4824670150142176,
           2.5062039151274673,
           2.529472758341033,
           2.5522641389489262,
           2.5745689766153075,
           2.596378506117439,
           2.6176842679303807,
           2.638478099583387,
           2.6587521277239934,
           2.67849876083134,
           2.6977106825252997,
           2.7163808454225906,
           2.7345024654952264,
           2.752069016890488,
           2.7690742271750866,
           2.7855120729693494,
           2.801376775940193,
           2.8166627991242636,
           2.8313648435550847,
           2.8454778451702327,
           2.8589969719766204,
           2.8719176214538065,
           2.884235418176966,
           2.8959462116427246,
           2.907046074282484,
           2.9175312996492115,
           2.927398400764875,
           2.9366441086168398,
           2.9452653707925918,
           2.9532593502431097,
           2.96062342416613,
           2.9673551830013505,
           2.973452429530469,
           2.9789131780755986,
           2.983735653790385,
           2.987918292038737,
           2.991459737856728,
           2.994358845493825,
           2.996614678030141,
           2.9982265070669647,
           2.99919381248834
          ],
          [
           2.998065597133593,
           2.997743205361961,
           2.9967761339611747,
           2.995164694707055,
           2.992909407337822,
           2.990010999722737,
           2.986470408099884,
           2.9822887773848317,
           2.977467461552375,
           2.9720080240941247,
           2.9659122385552146,
           2.959182089153987,
           2.951819771489096,
           2.943827693339077,
           2.935208475560107,
           2.925964953088348,
           2.9161001760540057,
           2.905617411015038,
           2.8945201423192564,
           2.8828120736044913,
           2.8704971294474384,
           2.8575794571728665,
           2.8440634288359856,
           2.829953643391988,
           2.8152549290681237,
           2.7999723459550867,
           2.7841111888360635,
           2.7676769902735034,
           2.7506755239755223,
           2.7331128084658878,
           2.714995111083731,
           2.6963289523415854,
           2.6771211106729647,
           2.6573786276036326,
           2.6371088133838625,
           2.616319253122499,
           2.5950178134674227,
           2.5732126498812526,
           2.5509122145656633,
           2.5281252650927963,
           2.5048608738077194,
           2.4811284380720116,
           2.456937691425162,
           2.4322987157477978,
           2.4072219545187385,
           2.381718227266617,
           2.3557987453263833,
           2.3294751290214624,
           2.302759426403696,
           2.275664133695645,
           2.2482022175932217,
           2.2203871396012227,
           2.1922328825899933,
           2.1637539797783165,
           2.134965546365567,
           2.105883314055225,
           2.0765236687318414,
           2.0469036915743173,
           2.017041203909627,
           1.9869548161324602,
           1.9566639810370923,
           1.926189051927357,
           1.8955513458878037,
           1.864773212612539,
           1.8338781091961076,
           1.8028906812905607,
           1.7718368510215938,
           1.7407439120303547,
           1.7096406319612978,
           1.678557362644108,
           1.647526158111646,
           1.6165809004466898,
           1.585757433246744,
           1.555093702224911,
           1.5246299021100826,
           1.4944086285535954,
           1.4644750331720802,
           1.434876979136272,
           1.4056651938317377,
           1.376893414050377,
           1.3486185179068364,
           1.320900636206837,
           1.2938032343358024,
           1.2673931539209615,
           1.2417406016168921,
           1.2169190704871917,
           1.1930051777743116,
           1.170078401602956,
           1.1482206986583847,
           1.127515985493635,
           1.1080494682674895,
           1.0899068098172529,
           1.073173129377438,
           1.057931839153395,
           1.0442633332556095,
           1.0322435577136548,
           1.0219425044662132,
           1.013422685934357,
           1.0067376582198746,
           1.0019306681693876,
           0.9990335007415116,
           0.9980655971335932,
           0.9990335007415135,
           1.0019306681693916,
           1.0067376582198806,
           1.0134226859343647,
           1.021942504466223,
           1.0322435577136662,
           1.044263333255623,
           1.0579318391534096,
           1.0731731293774545,
           1.0899068098172708,
           1.1080494682675088,
           1.1275159854936554,
           1.1482206986584067,
           1.1700784016029786,
           1.1930051777743358,
           1.2169190704872168,
           1.2417406016169181,
           1.2673931539209884,
           1.2938032343358299,
           1.3209006362068652,
           1.3486185179068648,
           1.376893414050406,
           1.4056651938317677,
           1.4348769791363025,
           1.4644750331721108,
           1.4944086285536264,
           1.5246299021101137,
           1.5550937022249425,
           1.5857574332467756,
           1.6165809004467215,
           1.647526158111678,
           1.6785573626441401,
           1.7096406319613295,
           1.7407439120303867,
           1.7718368510216258,
           1.8028906812905925,
           1.8338781091961394,
           1.8647732126125705,
           1.8955513458878352,
           1.9261890519273885,
           1.9566639810371236,
           1.9869548161324915,
           2.0170412039096575,
           2.0469036915743475,
           2.076523668731872,
           2.105883314055255,
           2.1349655463655965,
           2.163753979778346,
           2.192232882590022,
           2.220387139601251,
           2.24820221759325,
           2.2756641336956736,
           2.3027594264037234,
           2.3294751290214895,
           2.3557987453264104,
           2.381718227266643,
           2.4072219545187648,
           2.432298715747823,
           2.456937691425187,
           2.481128438072036,
           2.5048608738077434,
           2.5281252650928194,
           2.550912214565686,
           2.573212649881275,
           2.5950178134674453,
           2.616319253122521,
           2.637108813383884,
           2.6573786276036526,
           2.6771211106729846,
           2.696328952341605,
           2.7149951110837502,
           2.7331128084659064,
           2.75067552397554,
           2.7676769902735208,
           2.7841111888360803,
           2.7999723459551036,
           2.8152549290681397,
           2.8299536433920025,
           2.8440634288359994,
           2.8575794571728803,
           2.870497129447451,
           2.8828120736045033,
           2.894520142319268,
           2.905617411015049,
           2.916100176054016,
           2.925964953088358,
           2.935208475560116,
           2.9438276933390854,
           2.951819771489104,
           2.9591820891539946,
           2.9659122385552212,
           2.9720080240941305,
           2.977467461552381,
           2.982288777384837,
           2.9864704080998883,
           2.99001099972274,
           2.9929094073378244,
           2.9951646947070563,
           2.9967761339611765,
           2.9977432053619615
          ],
          [
           2.995649347969017,
           2.995327086334647,
           2.994360405219968,
           2.992749616023609,
           2.990495237854644,
           2.9875979977004823,
           2.9840588306636024,
           2.9798788802688576,
           2.97505949884355,
           2.9696022479730395,
           2.9635088990351393,
           2.9567814338171625,
           2.949422045220045,
           2.9414331380545824,
           2.9328173299354927,
           2.9235774522796856,
           2.9137165514158587,
           2.903237889813338,
           2.892144947438882,
           2.880441423251115,
           2.8681312368431775,
           2.8552185302452586,
           2.8417076698997796,
           2.827603248823226,
           2.8129100889699576,
           2.797633243814752,
           2.7817780011723925,
           2.765349886274354,
           2.7483546651244324,
           2.7307983481572693,
           2.7126871942258584,
           2.694027714946606,
           2.674826679433137,
           2.655091119452934,
           2.634828335044099,
           2.6140459006330024,
           2.5927516716973877,
           2.570953792023732,
           2.5486607016122163,
           2.5258811452877494,
           2.5026241820809876,
           2.478899195449411,
           2.4547159044151416,
           2.4300843757035198,
           2.405015036974467,
           2.379518691247412,
           2.35360653263016,
           2.3272901634725636,
           2.3005816130772656,
           2.2734933581122405,
           2.246038344883342,
           2.218230013639695,
           2.1900823251005406,
           2.161609789409057,
           2.1328274977367743,
           2.1037511567813567,
           2.0743971264207017,
           2.044782460807253,
           2.0149249532079097,
           1.984843184916535,
           1.954556578587206,
           1.9240854563562744,
           1.893451103138952,
           1.8626758355000446,
           1.8317830765068936,
           1.8007974369730397,
           1.7697448034906236,
           1.7386524336241016,
           1.7075490585925897,
           1.6764649936968472,
           1.6454322566419566,
           1.6144846937587598,
           1.583658113924784,
           1.552990429715214,
           1.52252180496067,
           1.4922948074330369,
           1.462354564803225,
           1.4327489212940643,
           1.4035285915657796,
           1.3747473073008907,
           1.3464619506849758,
           1.3187326675041893,
           1.2916229509099717,
           1.2651996850703202,
           1.2395331360034265,
           1.2146968749871583,
           1.1907676182278895,
           1.167824965193134,
           1.1459510174752985,
           1.1252298606366211,
           1.1057468936119286,
           1.0875879943424553,
           1.070838516738998,
           1.0555821230198403,
           1.0418994668517363,
           1.029866756059678,
           1.019554238005209,
           1.0110246646185297,
           1.0043318056742299,
           0.9995190862355898,
           0.996618425460977,
           0.9956493479690169,
           0.9966184254609789,
           0.9995190862355938,
           1.0043318056742356,
           1.0110246646185372,
           1.019554238005219,
           1.0298667560596892,
           1.0418994668517496,
           1.0555821230198552,
           1.0708385167390144,
           1.0875879943424736,
           1.105746893611948,
           1.125229860636642,
           1.1459510174753205,
           1.1678249651931571,
           1.1907676182279134,
           1.2146968749871834,
           1.2395331360034523,
           1.2651996850703469,
           1.291622950909999,
           1.3187326675042175,
           1.3464619506850044,
           1.37474730730092,
           1.4035285915658096,
           1.4327489212940945,
           1.4623545648032557,
           1.4922948074330677,
           1.5225218049607012,
           1.552990429715245,
           1.5836581139248158,
           1.6144846937587916,
           1.6454322566419888,
           1.6764649936968794,
           1.7075490585926216,
           1.7386524336241336,
           1.7697448034906553,
           1.8007974369730715,
           1.831783076506925,
           1.8626758355000763,
           1.8934511031389836,
           1.9240854563563061,
           1.9545565785872374,
           1.9848431849165666,
           2.0149249532079407,
           2.044782460807283,
           2.074397126420732,
           2.103751156781387,
           2.132827497736804,
           2.1616097894090864,
           2.1900823251005694,
           2.2182300136397237,
           2.24603834488337,
           2.2734933581122685,
           2.3005816130772927,
           2.3272901634725907,
           2.353606532630187,
           2.379518691247439,
           2.4050150369744934,
           2.4300843757035455,
           2.4547159044151665,
           2.478899195449436,
           2.5026241820810116,
           2.5258811452877725,
           2.54866070161224,
           2.570953792023755,
           2.5927516716974104,
           2.6140459006330237,
           2.63482833504412,
           2.6550911194529534,
           2.6748266794331568,
           2.6940277149466247,
           2.7126871942258766,
           2.7307983481572875,
           2.74835466512445,
           2.765349886274371,
           2.78177800117241,
           2.7976332438147677,
           2.812910088969974,
           2.8276032488232405,
           2.841707669899794,
           2.8552185302452724,
           2.8681312368431904,
           2.8804414232511264,
           2.8921449474388936,
           2.903237889813349,
           2.91371655141587,
           2.9235774522796953,
           2.932817329935502,
           2.941433138054591,
           2.949422045220053,
           2.9567814338171696,
           2.963508899035146,
           2.9696022479730457,
           2.9750594988435553,
           2.979878880268862,
           2.9840588306636064,
           2.9875979977004863,
           2.9904952378546463,
           2.992749616023611,
           2.99436040521997,
           2.995327086334648
          ],
          [
           2.9922698723632744,
           2.9919477930973533,
           2.990981658912241,
           2.9893717806790114,
           2.9871186766267916,
           2.984223072509594,
           2.980685901841592,
           2.97650830620252,
           2.971691635615418,
           2.9662374489994585,
           2.9601475147011116,
           2.9534238111074997,
           2.946068527346339,
           2.938084064077512,
           2.9294730343819557,
           2.92023826475422,
           2.9103827962058215,
           2.8999098854872516,
           2.888823006437377,
           2.8771258514698332,
           2.8648223332069995,
           2.8519165862731755,
           2.8384129692597004,
           2.8243160668759844,
           2.8096306923017362,
           2.794361889757106,
           2.7785149373090317,
           2.762095349933761,
           2.7451088828574077,
           2.72756153519838,
           2.709459553937789,
           2.6908094382463066,
           2.6716179441986423,
           2.6518920899096687,
           2.631639161129437,
           2.6108667173377857,
           2.5895825983830854,
           2.567794931713845,
           2.5455121402565135,
           2.522742950997868,
           2.499496404335917,
           2.4757818642693348,
           2.45160902950213,
           2.426987945547557,
           2.401929017923336,
           2.376443026538994,
           2.3505411413858313,
           2.3242349396504465,
           2.297536424384314,
           2.270458044874332,
           2.243012718872877,
           2.2152138568605957,
           2.187075388531021,
           2.158611791703184,
           2.1298381238865964,
           2.1007700567423573,
           2.071423913704502,
           2.041816711046937,
           2.0119662027031016,
           1.9818909291674753,
           1.9516102708296423,
           1.9211445061120511,
           1.8905148748008473,
           1.8597436469737973,
           1.828854197938531,
           1.7978710895957488,
           1.7668201586325967,
           1.7357286119271793,
           1.704625129501272,
           1.673539975288466,
           1.6425051158816208,
           1.6115543472771692,
           1.58072342943317,
           1.5500502281894164,
           1.5195748637454487,
           1.4893398644376967,
           1.4593903239797792,
           1.4297740596082933,
           1.4005417676880911,
           1.371747172255531,
           1.3434471606999185,
           1.3157018992960077,
           1.288574919613411,
           1.2621331649754062,
           1.236446984187368,
           1.2115900578173744,
           1.1876392405600227,
           1.1646743018894623,
           1.1427775466233567,
           1.1220332975594385,
           1.1025272244420932,
           1.0843455076042727,
           1.0675738310795764,
           1.0522962089954042,
           1.0385936605622754,
           1.026542762487525,
           1.0162141221977512,
           1.007670829388325,
           1.0009669552651295,
           0.9961461763733932,
           0.9932406012807915,
           0.9922698723632744,
           0.9932406012807936,
           0.9961461763733972,
           1.0009669552651355,
           1.0076708293883327,
           1.0162141221977612,
           1.0265427624875363,
           1.0385936605622887,
           1.0522962089954186,
           1.0675738310795928,
           1.084345507604291,
           1.1025272244421125,
           1.1220332975594591,
           1.142777546623379,
           1.1646743018894852,
           1.1876392405600467,
           1.2115900578173993,
           1.2364469841873942,
           1.2621331649754328,
           1.2885749196134386,
           1.3157018992960359,
           1.3434471606999472,
           1.3717471722555603,
           1.400541767688121,
           1.4297740596083237,
           1.4593903239798096,
           1.4893398644377276,
           1.5195748637454798,
           1.5500502281894477,
           1.5807234294332015,
           1.6115543472772007,
           1.6425051158816528,
           1.673539975288498,
           1.704625129501304,
           1.7357286119272113,
           1.7668201586326289,
           1.7978710895957808,
           1.8288541979385624,
           1.8597436469738293,
           1.8905148748008793,
           1.9211445061120827,
           1.9516102708296739,
           1.9818909291675064,
           2.0119662027031326,
           2.041816711046968,
           2.0714239137045323,
           2.1007700567423875,
           2.1298381238866257,
           2.1586117917032137,
           2.1870753885310505,
           2.215213856860624,
           2.2430127188729054,
           2.27045804487436,
           2.297536424384342,
           2.3242349396504736,
           2.350541141385858,
           2.376443026539021,
           2.401929017923362,
           2.426987945547583,
           2.451609029502155,
           2.475781864269359,
           2.4994964043359413,
           2.522742950997892,
           2.545512140256536,
           2.5677949317138675,
           2.5895825983831076,
           2.6108667173378066,
           2.6316391611294576,
           2.6518920899096896,
           2.671617944198663,
           2.690809438246326,
           2.7094595539378075,
           2.727561535198398,
           2.745108882857426,
           2.7620953499337784,
           2.7785149373090485,
           2.7943618897571225,
           2.809630692301751,
           2.824316066875999,
           2.8384129692597146,
           2.851916586273189,
           2.8648223332070124,
           2.877125851469845,
           2.8888230064373888,
           2.8999098854872627,
           2.9103827962058317,
           2.92023826475423,
           2.9294730343819646,
           2.9380840640775205,
           2.9460685273463465,
           2.9534238111075073,
           2.9601475147011183,
           2.966237448999464,
           2.9716916356154237,
           2.976508306202524,
           2.980685901841596,
           2.9842230725095966,
           2.9871186766267943,
           2.9893717806790137,
           2.990981658912242,
           2.9919477930973546
          ],
          [
           2.987930439740754,
           2.987608595250954,
           2.986643165168493,
           2.9850344596870504,
           2.9827829959058585,
           2.9798894979952033,
           2.9763548974298017,
           2.9721803332917616,
           2.9673671526453296,
           2.9619169109861367,
           2.9558313727682215,
           2.9491125120126176,
           2.941762513001933,
           2.9337837710659214,
           2.925178893463702,
           2.9159507003689926,
           2.9061022259654146,
           2.895636719659725,
           2.884557647421681,
           2.872868693260098,
           2.860573760845655,
           2.847676975292033,
           2.8341826851080807,
           2.8200954643349476,
           2.805420114883392,
           2.790161669087973,
           2.7743253924963236,
           2.757916786913462,
           2.7409415937228996,
           2.7234057975083665,
           2.705315630002166,
           2.686677574388585,
           2.667498369993456,
           2.647785017393836,
           2.6275447839849764,
           2.6067852100452265,
           2.5855141153433334,
           2.5637396063368274,
           2.541470084014741,
           2.518714252443033,
           2.4954811280765683,
           2.4717800499076854,
           2.4476206905279922,
           2.4230130681874513,
           2.397967559942812,
           2.3724949159963136,
           2.3466062753352093,
           2.320313182793269,
           2.293627607666906,
           2.266561964031188,
           2.239129132914628,
           2.2113424865064792,
           2.183215914586268,
           2.1547638533825135,
           2.126001317086008,
           2.096943932262636,
           2.067607975431348,
           2.0380104140944884,
           2.0081689515298526,
           1.9781020756763155,
           1.947829112467014,
           1.9173702839851698,
           1.8867467718366475,
           1.8559807861488704,
           1.825095640616011,
           1.7941158340129704,
           1.7630671385926133,
           1.7319766957580647,
           1.7008731193597029,
           1.669786606898599,
           1.6387490588168618,
           1.6077942059112134,
           1.5769577447076704,
           1.5462774803687267,
           1.5157934763537586,
           1.485548209600014,
           1.4555867294146057,
           1.4259568175450985,
           1.3967091460046899,
           1.3678974281462934,
           1.3395785571915217,
           1.311812724918097,
           1.2846635115008584,
           1.258197935619351,
           1.2324864519555456,
           1.2076028812215407,
           1.1836242560514232,
           1.160630564706178,
           1.1387043738942668,
           1.1179303124937006,
           1.0983944000159247,
           1.0801832077267481,
           1.0633828468195539,
           1.0480777871404732,
           1.0343495216267045,
           1.022275105361251,
           1.0119256129941667,
           1.003364572740437,
           0.9966464473305312,
           0.9918152400765249,
           0.9889033057272865,
           0.987930439740754,
           0.9889033057272884,
           0.9918152400765288,
           0.9966464473305373,
           1.0033645727404448,
           1.0119256129941765,
           1.0222751053612626,
           1.034349521626718,
           1.0480777871404883,
           1.0633828468195705,
           1.0801832077267661,
           1.098394400015944,
           1.1179303124937212,
           1.1387043738942888,
           1.1606305647062014,
           1.1836242560514474,
           1.2076028812215658,
           1.2324864519555714,
           1.2581979356193775,
           1.2846635115008858,
           1.3118127249181255,
           1.3395785571915504,
           1.3678974281463225,
           1.3967091460047198,
           1.4259568175451292,
           1.455586729414636,
           1.4855482096000452,
           1.5157934763537897,
           1.546277480368758,
           1.5769577447077021,
           1.6077942059112447,
           1.6387490588168938,
           1.6697866068986313,
           1.7008731193597348,
           1.7319766957580964,
           1.763067138592645,
           1.794115834013002,
           1.8250956406160426,
           1.855980786148902,
           1.886746771836679,
           1.9173702839852016,
           1.9478291124670453,
           1.9781020756763468,
           2.0081689515298833,
           2.038010414094519,
           2.0676079754313785,
           2.096943932262666,
           2.126001317086038,
           2.154763853382543,
           2.183215914586297,
           2.211342486506508,
           2.239129132914656,
           2.266561964031216,
           2.293627607666933,
           2.320313182793296,
           2.3466062753352364,
           2.3724949159963393,
           2.397967559942838,
           2.423013068187476,
           2.447620690528017,
           2.4717800499077103,
           2.4954811280765923,
           2.518714252443056,
           2.5414700840147644,
           2.5637396063368496,
           2.585514115343356,
           2.6067852100452478,
           2.6275447839849972,
           2.647785017393856,
           2.667498369993476,
           2.686677574388604,
           2.7053156300021843,
           2.7234057975083847,
           2.740941593722917,
           2.7579167869134795,
           2.774325392496341,
           2.790161669087989,
           2.8054201148834084,
           2.8200954643349623,
           2.8341826851080953,
           2.847676975292046,
           2.8605737608456674,
           2.87286869326011,
           2.8845576474216927,
           2.895636719659736,
           2.906102225965425,
           2.915950700369003,
           2.9251788934637104,
           2.9337837710659294,
           2.941762513001941,
           2.9491125120126243,
           2.955831372768228,
           2.9619169109861425,
           2.967367152645335,
           2.972180333291767,
           2.976354897429806,
           2.979889497995207,
           2.9827829959058607,
           2.9850344596870517,
           2.9866431651684944,
           2.987608595250954
          ],
          [
           2.9826352482222607,
           2.982313691143452,
           2.981349123018549,
           2.979741853214657,
           2.977492397452295,
           2.9746014779692467,
           2.971070023751632,
           2.966899170833882,
           2.962090262669815,
           2.956644850577525,
           2.950564694261311,
           2.9438517624144627,
           2.936508233407271,
           2.9285364960652633,
           2.9199391505432772,
           2.910719009301722,
           2.900879098192045,
           2.89042265765924,
           2.8793531440700373,
           2.8676742311763155,
           2.8553898117242507,
           2.8425039992207193,
           2.829021129869619,
           2.8149457646919744,
           2.8002826918450023,
           2.7850369291567607,
           2.769213726894531,
           2.7528185707868063,
           2.7358571853205964,
           2.718335537337777,
           2.700259839956423,
           2.681636556845481,
           2.6624724068837784,
           2.6427743692372827,
           2.622549688891658,
           2.6018058826807207,
           2.5805507458551538,
           2.558792359240087,
           2.5365390970347423,
           2.5137996353124143,
           2.4905829612846264,
           2.46689838339941,
           2.4427555423503633,
           2.4181644230805235,
           2.3931353678731764,
           2.3676790906305594,
           2.3418066924511747,
           2.315529678627011,
           2.2888599771936056,
           2.2618099591785326,
           2.2343924607076824,
           2.2066208071436493,
           2.178508839446705,
           2.1500709429662805,
           2.1213220788895106,
           2.092277818593294,
           2.0629543811673283,
           2.033368674397524,
           2.0035383395219233,
           1.9734818000942425,
           1.943218315313028,
           1.9127680381963017,
           1.882152079001536,
           1.8513925743074606,
           1.8205127621857473,
           1.7895370638947494,
           1.7584911725210988,
           1.7274021489742626,
           1.6962985256991518,
           1.665210418406374,
           1.634169646021046,
           1.6032098589096653,
           1.5723666752488679,
           1.5416778251360774,
           1.5111833016937184,
           1.480925517966904,
           1.4509494678381194,
           1.4213028884583159,
           1.392036420798452,
           1.3632037638364527,
           1.3348618165940873,
           1.3070708007173903,
           1.2798943545597747,
           1.2533995878093496,
           1.227657083666587,
           1.2027408335377856,
           1.1787280873366277,
           1.1556991010255504,
           1.1337367623043946,
           1.112926075765129,
           1.0933534908326457,
           1.075106059868201,
           1.0582704203274678,
           1.0429316040773415,
           1.0291716888313143,
           1.0170683206899882,
           1.0066931519831903,
           0.9981102534792766,
           0.9913745725948213,
           0.9865305173501808,
           0.9836107475038126,
           0.9826352482222604,
           0.9836107475038147,
           0.9865305173501848,
           0.9913745725948274,
           0.9981102534792846,
           1.0066931519832,
           1.0170683206899995,
           1.0291716888313276,
           1.0429316040773564,
           1.0582704203274842,
           1.075106059868219,
           1.0933534908326654,
           1.1129260757651498,
           1.1337367623044166,
           1.1556991010255737,
           1.1787280873366517,
           1.2027408335378107,
           1.2276570836666132,
           1.2533995878093764,
           1.2798943545598023,
           1.3070708007174185,
           1.3348618165941162,
           1.3632037638364825,
           1.3920364207984814,
           1.4213028884583463,
           1.4509494678381496,
           1.4809255179669352,
           1.5111833016937495,
           1.5416778251361087,
           1.5723666752488996,
           1.6032098589096972,
           1.634169646021078,
           1.6652104184064058,
           1.6962985256991838,
           1.727402148974295,
           1.7584911725211307,
           1.7895370638947814,
           1.8205127621857793,
           1.8513925743074922,
           1.8821520790015678,
           1.9127680381963335,
           1.9432183153130596,
           1.9734818000942733,
           2.003538339521954,
           2.0333686743975545,
           2.0629543811673585,
           2.0922778185933244,
           2.1213220788895404,
           2.1500709429663103,
           2.1785088394467342,
           2.2066208071436777,
           2.2343924607077112,
           2.2618099591785605,
           2.2888599771936335,
           2.3155296786270387,
           2.3418066924512013,
           2.3676790906305856,
           2.393135367873202,
           2.4181644230805492,
           2.4427555423503877,
           2.466898383399435,
           2.4905829612846504,
           2.5137996353124374,
           2.536539097034765,
           2.558792359240109,
           2.5805507458551755,
           2.601805882680742,
           2.622549688891679,
           2.642774369237303,
           2.6624724068837997,
           2.6816365568455,
           2.7002598399564426,
           2.7183355373377953,
           2.7358571853206137,
           2.752818570786823,
           2.7692137268945483,
           2.7850369291567776,
           2.8002826918450174,
           2.814945764691988,
           2.8290211298696337,
           2.842503999220733,
           2.8553898117242635,
           2.8676742311763275,
           2.879353144070049,
           2.8904226576592515,
           2.900879098192055,
           2.910719009301731,
           2.919939150543286,
           2.928536496065272,
           2.936508233407279,
           2.9438517624144693,
           2.9505646942613177,
           2.9566448505775305,
           2.962090262669821,
           2.9668991708338863,
           2.9710700237516363,
           2.9746014779692507,
           2.9774923974522975,
           2.9797418532146587,
           2.9813491230185503,
           2.9823136911434522
          ],
          [
           2.9763894205636032,
           2.9760682038087825,
           2.9751046563309997,
           2.9734990865224376,
           2.9712520084774514,
           2.9683641421544786,
           2.964836413604379,
           2.960669955266884,
           2.955866106337335,
           2.9504264132064097,
           2.9443526299760476,
           2.9376467190553663,
           2.93031085184091,
           2.9223474094862016,
           2.913758983766199,
           2.9045483780429384,
           2.894718608339374,
           2.884272904529188,
           2.87321471165118,
           2.8615476913577247,
           2.84927572350775,
           2.8364029079157107,
           2.8229335662691515,
           2.8088722442286636,
           2.7942237137253496,
           2.778992975472327,
           2.763185261708366,
           2.7468060391934483,
           2.72986101247785,
           2.712356127468428,
           2.6942975753179144,
           2.675691796665513,
           2.656545486259678,
           2.636865597996887,
           2.616659350413378,
           2.5959342326703165,
           2.574698011076677,
           2.5529587361983492,
           2.530724750606563,
           2.508004697323839,
           2.4848075290312215,
           2.46114251810669,
           2.437019267571386,
           2.412447723027666,
           2.3874381856811455,
           2.3620013265477784,
           2.3361482019567883,
           2.309890270470991,
           2.283239411357698,
           2.2562079447562016,
           2.228808653701716,
           2.2010548081807846,
           2.1729601914094987,
           2.1445391285435575,
           2.115806518048108,
           2.0867778659755505,
           2.057469323420872,
           2.0278977274465606,
           1.998080645792366,
           1.9680364257089435,
           1.9377842472780267,
           1.9073441816046641,
           1.8767372542881353,
           1.8459855145961364,
           1.815112110779921,
           1.7841413719739856,
           1.753098897119552,
           1.722011651332723,
           1.6909080701007777,
           1.659818171627468,
           1.6287736775526238,
           1.597808142133287,
           1.566957089781304,
           1.5362581605917767,
           1.5057512631513301,
           1.4754787334655453,
           1.4454854982693146,
           1.4158192402585656,
           1.3865305618821604,
           1.3576731432352795,
           1.3293038882809054,
           1.3014830520835918,
           1.2742743399742111,
           1.2477449676046235,
           1.2219656687608693,
           1.1970106356942687,
           1.1729573747752213,
           1.1498864587224313,
           1.12788115584078,
           1.1070269170236327,
           1.0874107032095515,
           1.069120140014481,
           1.0522424928149472,
           1.0368634648967128,
           1.0230658333711684,
           1.0109279519317784,
           1.000522165173249,
           0.9919131945640075,
           0.9851565692222194,
           0.9802971831587954,
           0.977368062558745,
           0.9763894205636032,
           0.9773680625587471,
           0.9802971831587997,
           0.9851565692222255,
           0.9919131945640154,
           1.0005221651732588,
           1.0109279519317897,
           1.0230658333711817,
           1.0368634648967276,
           1.0522424928149638,
           1.069120140014499,
           1.0874107032095712,
           1.1070269170236535,
           1.127881155840802,
           1.1498864587224542,
           1.1729573747752455,
           1.1970106356942938,
           1.2219656687608953,
           1.2477449676046504,
           1.274274339974239,
           1.30148305208362,
           1.3293038882809343,
           1.3576731432353086,
           1.3865305618821904,
           1.415819240258596,
           1.445485498269345,
           1.4754787334655763,
           1.5057512631513614,
           1.536258160591808,
           1.5669570897813356,
           1.5978081421333188,
           1.6287736775526556,
           1.6598181716275,
           1.6909080701008101,
           1.7220116513327552,
           1.753098897119584,
           1.7841413719740171,
           1.8151121107799526,
           1.8459855145961679,
           1.876737254288167,
           1.9073441816046954,
           1.9377842472780578,
           1.968036425708975,
           1.9980806457923972,
           2.0278977274465912,
           2.057469323420903,
           2.0867778659755802,
           2.115806518048138,
           2.1445391285435864,
           2.172960191409528,
           2.2010548081808134,
           2.2288086537017446,
           2.2562079447562295,
           2.2832394113577257,
           2.3098902704710182,
           2.336148201956815,
           2.3620013265478046,
           2.3874381856811717,
           2.4124477230276913,
           2.4370192675714106,
           2.461142518106715,
           2.4848075290312455,
           2.5080046973238623,
           2.530724750606586,
           2.5529587361983723,
           2.5746980110766993,
           2.5959342326703383,
           2.6166593504133995,
           2.636865597996907,
           2.6565454862596978,
           2.675691796665532,
           2.6942975753179335,
           2.7123561274684462,
           2.7298610124778677,
           2.746806039193465,
           2.7631852617083834,
           2.7789929754723426,
           2.794223713725365,
           2.808872244228678,
           2.8229335662691653,
           2.836402907915724,
           2.849275723507763,
           2.861547691357737,
           2.8732147116511917,
           2.8842729045291997,
           2.8947186083393843,
           2.904548378042948,
           2.9137589837662077,
           2.9223474094862096,
           2.9303108518409173,
           2.9376467190553734,
           2.9443526299760543,
           2.950426413206416,
           2.9558661063373406,
           2.960669955266889,
           2.9648364136043837,
           2.9683641421544817,
           2.9712520084774536,
           2.9734990865224393,
           2.9751046563310015,
           2.9760682038087833
          ],
          [
           2.9691989991996617,
           2.968878176011143,
           2.9679158088583177,
           2.966312205011085,
           2.964067876691833,
           2.9611835412351106,
           2.9576601213128146,
           2.953498745226572,
           2.9487007472694717,
           2.9432676681598364,
           2.937201255550217,
           2.9305034646153776,
           2.923176458723589,
           2.915222610196162,
           2.906644501160786,
           2.897444924504931,
           2.887626884936245,
           2.877193600157712,
           2.8661485021660984,
           2.8544952386831324,
           2.8422376747298057,
           2.829379894355202,
           2.815926202532384,
           2.801881127235062,
           2.7872494217100754,
           2.7720360669621407,
           2.7562462744688703,
           2.7398854891457347,
           2.722959392582516,
           2.705473906574765,
           2.6874351969760184,
           2.668849677898915,
           2.649724016296001,
           2.6300651369539,
           2.6098802279377074,
           2.58917674652595,
           2.567962425680287,
           2.5462452810983223,
           2.524033618902544,
           2.501336044023466,
           2.4781614693406664,
           2.4545191256515335,
           2.430418572544309,
           2.4058697102594393,
           2.380882792631404,
           2.355468441212151,
           2.3296376606871014,
           2.303401855705456,
           2.2767728492583315,
           2.2497629027511516,
           2.2223847379307458,
           2.194651560842934,
           2.166577088012921,
           2.138175575058778,
           2.1094618479675096,
           2.0804513372838516,
           2.05116011548378,
           2.021604937827746,
           1.9918032870125504,
           1.96177342196532,
           1.9315344311475962,
           1.901106290761552,
           1.8705099282727362,
           1.8397672916832628,
           1.8089014250042386,
           1.777936550384197,
           1.7468981573483724,
           1.7158130995879668,
           1.6847096997042275,
           1.6536178622529556,
           1.622569195343208,
           1.5915971409098215,
           1.5607371135911796,
           1.5300266478870563,
           1.4995055529295278,
           1.4692160737530502,
           1.4392030573754768,
           1.4095141212753801,
           1.380199820946893,
           1.3513138121063542,
           1.322913001794301,
           1.2950576810491374,
           1.2678116300275806,
           1.2412421844381931,
           1.2154202499997158,
           1.1904202494460803,
           1.1663199845490455,
           1.1432003939684574,
           1.1211451868063087,
           1.1002403319557468,
           1.0805733851873016,
           1.0622326399109137,
           1.045306094147949,
           1.0298802357314867,
           1.0160386601123756,
           1.0038605499240185,
           0.9934190616331963,
           0.9847796805689388,
           0.9779986192731406,
           0.9731213431154269,
           0.9701813092936024,
           0.9691989991996618,
           0.9701813092936045,
           0.9731213431154307,
           0.9779986192731466,
           0.984779680568947,
           0.9934190616332061,
           1.00386054992403,
           1.0160386601123892,
           1.0298802357315018,
           1.045306094147966,
           1.0622326399109316,
           1.0805733851873212,
           1.1002403319557674,
           1.121145186806331,
           1.1432003939684805,
           1.1663199845490697,
           1.1904202494461054,
           1.215420249999742,
           1.2412421844382202,
           1.267811630027608,
           1.2950576810491656,
           1.3229130017943298,
           1.3513138121063837,
           1.380199820946923,
           1.4095141212754103,
           1.4392030573755072,
           1.4692160737530813,
           1.499505552929559,
           1.5300266478870879,
           1.5607371135912114,
           1.5915971409098533,
           1.62256919534324,
           1.6536178622529878,
           1.6847096997042594,
           1.7158130995879985,
           1.7468981573484044,
           1.7779365503842288,
           1.8089014250042703,
           1.8397672916832948,
           1.8705099282727682,
           1.9011062907615834,
           1.9315344311476275,
           1.9617734219653513,
           1.9918032870125815,
           2.0216049378277767,
           2.051160115483811,
           2.0804513372838813,
           2.109461847967539,
           2.138175575058807,
           2.16657708801295,
           2.194651560842962,
           2.2223847379307746,
           2.2497629027511796,
           2.276772849258359,
           2.3034018557054825,
           2.329637660687128,
           2.355468441212177,
           2.3808827926314295,
           2.4058697102594646,
           2.4304185725443337,
           2.4545191256515584,
           2.478161469340691,
           2.50133604402349,
           2.524033618902567,
           2.5462452810983454,
           2.567962425680309,
           2.589176746525972,
           2.6098802279377282,
           2.6300651369539203,
           2.649724016296021,
           2.668849677898934,
           2.6874351969760366,
           2.7054739065747837,
           2.7229593925825344,
           2.7398854891457516,
           2.7562462744688863,
           2.7720360669621567,
           2.787249421710091,
           2.8018811272350765,
           2.8159262025323977,
           2.829379894355215,
           2.8422376747298186,
           2.8544952386831444,
           2.86614850216611,
           2.877193600157723,
           2.887626884936255,
           2.8974449245049407,
           2.9066445011607955,
           2.91522261019617,
           2.923176458723597,
           2.930503464615385,
           2.9372012555502236,
           2.943267668159842,
           2.948700747269477,
           2.9534987452265766,
           2.9576601213128186,
           2.9611835412351137,
           2.9640678766918356,
           2.966312205011086,
           2.967915808858319,
           2.968878176011143
          ],
          [
           2.9610709403987197,
           2.960750564399622,
           2.9597895383923998,
           2.9581881683784537,
           2.955946964464325,
           2.953066641018819,
           2.949548116894628,
           2.945392515716095,
           2.9406011662352802,
           2.935175602758979,
           2.9291175656498583,
           2.9224290019054573,
           2.915112065819322,
           2.9071691197291822,
           2.8986027348576875,
           2.8894156922519145,
           2.8796109838285373,
           2.869191813532348,
           2.858161598616624,
           2.846523971054702,
           2.8342827790930754,
           2.821442088957372,
           2.808006186723616,
           2.79397958036846,
           2.779367002013289,
           2.764173410378572,
           2.7484039934663507,
           2.732064171490442,
           2.715159600075763,
           2.697696173750202,
           2.6796800297546306,
           2.661117552199098,
           2.6420153765958405,
           2.622380394802644,
           2.602219760413293,
           2.5815408946352982,
           2.5603514926989197,
           2.538659530845756,
           2.5164732739497353,
           2.4938012838285144,
           2.4706524283088114,
           2.4470358911154477,
           2.422961182660586,
           2.3984381518171647,
           2.373476998768694,
           2.3480882890366326,
           2.322282968796417,
           2.296072381604121,
           2.2694682866676,
           2.242482878809005,
           2.21512881027975,
           2.1874192146045517,
           2.1593677326479277,
           2.130988541114804,
           2.1022963837164723,
           2.0733066052541953,
           2.0440351888951405,
           2.0144987969389625,
           1.9847148153980312,
           1.9547014027397098,
           1.9244775431647427,
           1.8940631048210486,
           1.8634789033761108,
           1.832746771392403,
           1.8018896339672383,
           1.7709315911087564,
           1.7398980073205919,
           1.7088156088551993,
           1.6777125890650386,
           1.6466187222255564,
           1.615565486116383,
           1.5845861935176684,
           1.553716132595047,
           1.5229927158949277,
           1.492455637334268,
           1.4621470361255762,
           1.4321116660053739,
           1.402397067407179,
           1.373053739311277,
           1.3441353063864132,
           1.3156986756900166,
           1.287804175598539,
           1.2605156677977374,
           1.2339006210979337,
           1.2080301336107313,
           1.1829788875405385,
           1.1588250186809899,
           1.1356498809175943,
           1.1135376849687966,
           1.0925749906835762,
           1.0728500339630356,
           1.0544518733228487,
           1.0374693477501329,
           1.0219898471552102,
           1.0080979093898759,
           0.9958736730509448,
           0.9853912320771159,
           0.976716954816888,
           0.9699078446008993,
           0.9650100284326271,
           0.9620574629199414,
           0.9610709403987197,
           0.9620574629199433,
           0.9650100284326311,
           0.9699078446009053,
           0.976716954816896,
           0.9853912320771259,
           0.9958736730509564,
           1.0080979093898892,
           1.0219898471552253,
           1.0374693477501493,
           1.0544518733228672,
           1.072850033963055,
           1.092574990683597,
           1.1135376849688188,
           1.1356498809176174,
           1.158825018681014,
           1.182978887540564,
           1.2080301336107573,
           1.2339006210979606,
           1.2605156677977651,
           1.2878041755985674,
           1.3156986756900455,
           1.3441353063864425,
           1.3730537393113071,
           1.4023970674072097,
           1.4321116660054047,
           1.4621470361256073,
           1.492455637334299,
           1.5229927158949594,
           1.5537161325950786,
           1.5845861935176997,
           1.6155654861164148,
           1.6466187222255888,
           1.6777125890650708,
           1.7088156088552315,
           1.739898007320624,
           1.7709315911087884,
           1.80188963396727,
           1.8327467713924348,
           1.863478903376142,
           1.89406310482108,
           1.9244775431647736,
           1.954701402739741,
           1.9847148153980623,
           2.014498796938993,
           2.0440351888951707,
           2.073306605254225,
           2.1022963837165016,
           2.1309885411148333,
           2.159367732647957,
           2.18741921460458,
           2.215128810279778,
           2.2424828788090325,
           2.2694682866676277,
           2.2960723816041475,
           2.3222829687964435,
           2.3480882890366592,
           2.3734769987687203,
           2.3984381518171896,
           2.422961182660611,
           2.447035891115472,
           2.4706524283088354,
           2.493801283828538,
           2.5164732739497584,
           2.5386595308457784,
           2.5603514926989424,
           2.581540894635319,
           2.6022197604133144,
           2.6223803948026636,
           2.64201537659586,
           2.6611175521991175,
           2.6796800297546484,
           2.6976961737502196,
           2.715159600075781,
           2.732064171490459,
           2.748403993466367,
           2.764173410378588,
           2.7793670020133043,
           2.793979580368475,
           2.8080061867236297,
           2.8214420889573844,
           2.8342827790930882,
           2.8465239710547134,
           2.8581615986166358,
           2.869191813532359,
           2.8796109838285475,
           2.889415692251925,
           2.8986027348576964,
           2.9071691197291902,
           2.91511206581933,
           2.922429001905465,
           2.929117565649865,
           2.9351756027589846,
           2.940601166235286,
           2.9453925157160996,
           2.9495481168946314,
           2.9530666410188227,
           2.955946964464327,
           2.9581881683784554,
           2.959789538392401,
           2.960750564399623
          ],
          [
           2.9520131075327245,
           2.9516932327788132,
           2.950733710036212,
           2.9491348438929395,
           2.9468971420980146,
           2.9440213157157364,
           2.9405082793433217,
           2.9363591513935154,
           2.931575254444316,
           2.926158115658446,
           2.9201094672757155,
           2.9134312471819666,
           2.9061255995588615,
           2.8981948756193563,
           2.8896416344343523,
           2.880468643856655,
           2.870678881549119,
           2.8602755361245595,
           2.84926200840589,
           2.8376419128157524,
           2.825419078905896,
           2.8125975530375524,
           2.7991816002251464,
           2.785175706156906,
           2.77058457940718,
           2.7554131538567277,
           2.7396665913387483,
           2.7233502845301047,
           2.706469860109012,
           2.689031182202483,
           2.671040356148984,
           2.6525037326041807,
           2.6334279120202524,
           2.61381974953217,
           2.593686360287489,
           2.5730351252596804,
           2.5518736975888814,
           2.5302100094981332,
           2.508052279837823,
           2.4854090223161482,
           2.4622890544790406,
           2.4387015075091645,
           2.414655836920423,
           2.390161834231898,
           2.365229639713408,
           2.339869756303914,
           2.3140930648140214,
           2.2879108405347557,
           2.261334771386792,
           2.234376977757535,
           2.207050034187796,
           2.1793669930855417,
           2.151341410661303,
           2.122987375298334,
           2.094319538590664,
           2.0653531493037005,
           2.0361040905349927,
           2.0065889203771277,
           1.9768249164102198,
           1.946830124377882,
           1.9166234114273977,
           1.8862245243214761,
           1.8556541530545385,
           1.824934000329702,
           1.794086857371885,
           1.7631366865654858,
           1.7321087114090072,
           1.7010295142700225,
           1.6699271423971331,
           1.6388312225948494,
           1.6077730848847929,
           1.5767858953525,
           1.5459047982012983,
           1.5151670667885386,
           1.484612263087193,
           1.4542824045767055,
           1.4242221369970363,
           1.3944789106724507,
           1.365103157198189,
           1.336148462155338,
           1.3076717281513213,
           1.2797333208577666,
           1.2523971888304641,
           1.2257309457682493,
           1.1998059015551052,
           1.1746970260399063,
           1.1504828272154708,
           1.1272451235213523,
           1.105068688766813,
           1.0840407481030179,
           1.0642503050987748,
           1.0457872838612288,
           1.028741476817827,
           1.0132012986020378,
           0.9992523595101818,
           0.9869758877867739,
           0.9764470474995063,
           0.9677332162603894,
           0.9608923022356295,
           0.9559711901595447,
           0.9530044089755739,
           0.9520131075327244,
           0.9530044089755758,
           0.9559711901595486,
           0.9608923022356355,
           0.9677332162603975,
           0.9764470474995163,
           0.9869758877867857,
           0.9992523595101953,
           1.013201298602053,
           1.0287414768178438,
           1.0457872838612472,
           1.0642503050987948,
           1.084040748103039,
           1.1050686887668353,
           1.1272451235213756,
           1.1504828272154952,
           1.1746970260399314,
           1.1998059015551317,
           1.2257309457682763,
           1.252397188830492,
           1.2797333208577946,
           1.3076717281513506,
           1.3361484621553676,
           1.365103157198219,
           1.3944789106724809,
           1.4242221369970673,
           1.4542824045767366,
           1.4846122630872245,
           1.5151670667885702,
           1.54590479820133,
           1.5767858953525318,
           1.6077730848848246,
           1.6388312225948813,
           1.6699271423971656,
           1.7010295142700549,
           1.7321087114090394,
           1.7631366865655174,
           1.7940868573719166,
           1.8249340003297336,
           1.8556541530545698,
           1.8862245243215074,
           1.916623411427429,
           1.9468301243779131,
           1.9768249164102505,
           2.006588920377158,
           2.036104090535023,
           2.06535314930373,
           2.094319538590694,
           2.1229873752983632,
           2.1513414106613324,
           2.17936699308557,
           2.207050034187824,
           2.2343769777575635,
           2.2613347713868195,
           2.287910840534783,
           2.3140930648140485,
           2.3398697563039397,
           2.365229639713434,
           2.3901618342319235,
           2.4146558369204474,
           2.438701507509189,
           2.4622890544790645,
           2.4854090223161713,
           2.5080522798378455,
           2.5302100094981554,
           2.551873697588903,
           2.573035125259702,
           2.59368636028751,
           2.613819749532191,
           2.633427912020272,
           2.6525037326042007,
           2.671040356149003,
           2.6890311822025006,
           2.7064698601090296,
           2.723350284530122,
           2.7396665913387652,
           2.7554131538567437,
           2.770584579407195,
           2.785175706156921,
           2.7991816002251606,
           2.8125975530375658,
           2.8254190789059095,
           2.837641912815765,
           2.8492620084059017,
           2.86027553612457,
           2.8706788815491286,
           2.8804686438566645,
           2.8896416344343607,
           2.898194875619365,
           2.9061255995588695,
           2.913431247181974,
           2.9201094672757217,
           2.9261581156584517,
           2.9315752544443217,
           2.9363591513935203,
           2.940508279343326,
           2.94402131571574,
           2.946897142098017,
           2.9491348438929412,
           2.9507337100362134,
           2.9516932327788146
          ],
          [
           2.942034263469983,
           2.941714944501889,
           2.940757088598026,
           2.9391609987896485,
           2.9369271802290813,
           2.934056340340866,
           2.9305493890349865,
           2.9264074389837886,
           2.9216318059646964,
           2.9162240092713527,
           2.9101857721962676,
           2.9035190225886676,
           2.8962258934917267,
           2.888308723864004,
           2.8797700593905162,
           2.870612653389515,
           2.860839467821785,
           2.850453674409983,
           2.8394586558763844,
           2.8278580073082367,
           2.8156555376608816,
           2.8028552714097894,
           2.789461450363757,
           2.775478535652704,
           2.7609112099047777,
           2.7457643796288926,
           2.730043177820335,
           2.7137529668087574,
           2.6968993413696825,
           2.6794881321226396,
           2.6615254092412415,
           2.64301748650289,
           2.62397092570843,
           2.604392541504954,
           2.584289406648117,
           2.5636688577438025,
           2.542538501512828,
           2.520906221626561,
           2.4987801861659826,
           2.4761688557618404,
           2.4530809924791583,
           2.42952566951558,
           2.4055122817898624,
           2.381050557504368,
           2.356150570773695,
           2.3308227554207317,
           2.3050779200514726,
           2.2789272645309944,
           2.252382397995112,
           2.2254553585456014,
           2.1981586347914233,
           2.1705051894143543,
           2.142508484954822,
           2.114182512032612,
           2.0855418202376135,
           2.0566015519477547,
           2.0273774793549544,
           1.9978860450049518,
           1.9681444061833662,
           1.9381704835078029,
           1.9079830141140184,
           1.8776016098523693,
           1.8470468209381803,
           1.816340205525121,
           1.785504405692475,
           1.754563230353254,
           1.7235417455975155,
           1.6924663729802933,
           1.6613649962413772,
           1.6302670768986267,
           1.5992037790796692,
           1.5682081038388975,
           1.537315033035414,
           1.5065616826079589,
           1.4759874647568718,
           1.4456342581093604,
           1.4155465843778925,
           1.3857717892946488,
           1.3563602246873363,
           1.3273654274227893,
           1.2988442895563406,
           1.270857212365879,
           1.2434682350126418,
           1.2167451263725884,
           1.1907594261753276,
           1.1655864190766543,
           1.1413050228500619,
           1.117997569774066,
           1.09574945887911,
           1.0746486564690931,
           1.0547850238074696,
           1.0362494546629168,
           1.019132812116312,
           1.003524664050789,
           0.9895118301683569,
           0.9771767697860266,
           0.9665958579925513,
           0.9578376162035257,
           0.950960979313363,
           0.9460136927356064,
           0.9430309360127292,
           0.9420342634699831,
           0.9430309360127312,
           0.9460136927356105,
           0.950960979313369,
           0.9578376162035337,
           0.9665958579925614,
           0.9771767697860383,
           0.9895118301683703,
           1.0035246640508042,
           1.0191328121163288,
           1.0362494546629353,
           1.0547850238074894,
           1.0746486564691142,
           1.095749458879132,
           1.1179975697740896,
           1.1413050228500865,
           1.1655864190766796,
           1.190759426175354,
           1.2167451263726154,
           1.2434682350126696,
           1.2708572123659074,
           1.2988442895563697,
           1.3273654274228188,
           1.3563602246873663,
           1.3857717892946793,
           1.4155465843779234,
           1.4456342581093915,
           1.4759874647569033,
           1.5065616826079904,
           1.5373150330354461,
           1.5682081038389293,
           1.599203779079701,
           1.6302670768986587,
           1.6613649962414094,
           1.6924663729803253,
           1.7235417455975475,
           1.7545632303532857,
           1.7855044056925065,
           1.8163402055251525,
           1.8470468209382116,
           1.8776016098524002,
           1.90798301411405,
           1.9381704835078335,
           1.968144406183397,
           1.997886045004982,
           2.027377479354984,
           2.0566015519477845,
           2.085541820237643,
           2.1141825120326416,
           2.142508484954851,
           2.170505189414383,
           2.1981586347914512,
           2.225455358545629,
           2.252382397995139,
           2.2789272645310215,
           2.3050779200514997,
           2.330822755420758,
           2.356150570773721,
           2.381050557504394,
           2.4055122817898873,
           2.429525669515604,
           2.453080992479182,
           2.476168855761864,
           2.4987801861660057,
           2.520906221626584,
           2.5425385015128503,
           2.563668857743824,
           2.584289406648138,
           2.6043925415049745,
           2.62397092570845,
           2.643017486502909,
           2.6615254092412606,
           2.679488132122658,
           2.6968993413697,
           2.7137529668087748,
           2.730043177820352,
           2.745764379628909,
           2.760911209904793,
           2.7754785356527183,
           2.789461450363771,
           2.8028552714098036,
           2.815655537660895,
           2.827858007308249,
           2.839458655876396,
           2.8504536744099935,
           2.8608394678217954,
           2.8706126533895246,
           2.879770059390525,
           2.888308723864013,
           2.896225893491734,
           2.903519022588675,
           2.9101857721962743,
           2.9162240092713585,
           2.921631805964702,
           2.9264074389837926,
           2.930549389034991,
           2.934056340340869,
           2.9369271802290835,
           2.9391609987896503,
           2.940757088598027,
           2.94171494450189
          ],
          [
           2.931144062097653,
           2.930825353993515,
           2.9298693301155945,
           2.9282762917966876,
           2.9260467413560742,
           2.9231813822472246,
           2.919681119266208,
           2.9155470588223715,
           2.910780509273392,
           2.9053829813272865,
           2.899356188514435,
           2.8927020477332666,
           2.8854226798737455,
           2.877520410523438,
           2.8689977707615064,
           2.859857498046671,
           2.850102537205849,
           2.8397360415309496,
           2.8287613739920676,
           2.8171821085762256,
           2.805002031761689,
           2.7922251441389108,
           2.7788556621902543,
           2.7648980202417657,
           2.7503568726016185,
           2.7352370959011836,
           2.71954379165623,
           2.7032822890674018,
           2.6864581480809324,
           2.6690771627325556,
           2.6511453647997065,
           2.6326690277895426,
           2.6136546712928665,
           2.5941090657369825,
           2.5740392375735954,
           2.5534524749414045,
           2.5323563338468396,
           2.5107586449105974,
           2.4886675207323,
           2.4660913639307003,
           2.443038875922508,
           2.419519066509142,
           2.3955412643475604,
           2.371115128388918,
           2.3462506603771174,
           2.320958218508553,
           2.2952485323644565,
           2.2691327192384336,
           2.242622301994057,
           2.215729228600857,
           2.1884658935118644,
           2.160845161062056,
           2.13288039108475,
           2.104585466962285,
           2.075974826348233,
           2.0470634948210065,
           2.017867122753029,
           1.988402025705548,
           1.9586852286866292,
           1.9287345146385697,
           1.8985684775505778,
           1.868206580622517,
           1.8376692199349722,
           1.8069777941087535,
           1.7761547804616271,
           1.7452238181894566,
           1.714209799110251,
           1.683138966509164,
           1.6520390226054564,
           1.6209392451227074,
           1.5898706133731961,
           1.558865944156529,
           1.527960037608815,
           1.4971898329068247,
           1.466594573413017,
           1.4362159804200947,
           1.4060984340920306,
           1.3762891594730557,
           1.3468384145149601,
           1.3177996759231547,
           1.2892298172119847,
           1.2611892716649675,
           1.2337421709044485,
           1.2069564474994627,
           1.1809038875285955,
           1.1556601163676103,
           1.1313044983629545,
           1.1079199287473473,
           1.0855924945259372,
           1.0644109805992406,
           1.0444661986822714,
           1.0258501202773607,
           1.0086548016857897,
           0.9929710992693408,
           0.9788871870354906,
           0.9664869057315042,
           0.9558479919073133,
           0.9470402549783938,
           0.9401237876213311,
           0.9351473068977111,
           0.9321467274731127,
           0.9311440620976529,
           0.9321467274731147,
           0.9351473068977152,
           0.9401237876213374,
           0.947040254978402,
           0.9558479919073234,
           0.9664869057315159,
           0.9788871870355043,
           0.9929710992693562,
           1.0086548016858066,
           1.0258501202773789,
           1.0444661986822912,
           1.0644109805992616,
           1.0855924945259592,
           1.1079199287473707,
           1.1313044983629792,
           1.1556601163676357,
           1.180903887528622,
           1.2069564474994896,
           1.2337421709044767,
           1.2611892716649962,
           1.2892298172120136,
           1.3177996759231843,
           1.3468384145149903,
           1.3762891594730862,
           1.4060984340920617,
           1.4362159804201258,
           1.466594573413048,
           1.4971898329068565,
           1.527960037608847,
           1.5588659441565607,
           1.5898706133732279,
           1.620939245122739,
           1.6520390226054884,
           1.683138966509196,
           1.714209799110283,
           1.745223818189488,
           1.7761547804616586,
           1.806977794108785,
           1.8376692199350033,
           1.868206580622548,
           1.8985684775506093,
           1.9287345146386004,
           1.9586852286866598,
           1.9884020257055783,
           2.017867122753059,
           2.0470634948210362,
           2.0759748263482622,
           2.1045854669623147,
           2.1328803910847784,
           2.1608451610620842,
           2.1884658935118924,
           2.215729228600885,
           2.2426223019940847,
           2.2691327192384607,
           2.295248532364483,
           2.3209582185085798,
           2.346250660377143,
           2.3711151283889427,
           2.3955412643475853,
           2.4195190665091664,
           2.443038875922532,
           2.4660913639307234,
           2.488667520732323,
           2.51075864491062,
           2.5323563338468613,
           2.553452474941426,
           2.574039237573616,
           2.5941090657370034,
           2.613654671292887,
           2.6326690277895617,
           2.651145364799726,
           2.669077162732573,
           2.6864581480809497,
           2.7032822890674186,
           2.719543791656247,
           2.7352370959012,
           2.750356872601633,
           2.76489802024178,
           2.7788556621902685,
           2.7922251441389245,
           2.8050020317617013,
           2.8171821085762385,
           2.828761373992079,
           2.8397360415309603,
           2.85010253720586,
           2.85985749804668,
           2.8689977707615153,
           2.8775204105234464,
           2.8854226798737534,
           2.892702047733273,
           2.899356188514442,
           2.9053829813272922,
           2.9107805092733976,
           2.9155470588223755,
           2.9196811192662127,
           2.9231813822472277,
           2.9260467413560765,
           2.9282762917966902,
           2.9298693301155962,
           2.9308253539935154
          ],
          [
           2.919353038982229,
           2.9190349974107903,
           2.918080972518459,
           2.9164912637997635,
           2.914266370507721,
           2.911406991797825,
           2.907914026931201,
           2.903788575538521,
           2.8990319379467246,
           2.8936456155711117,
           2.8876313113758196,
           2.880990930406296,
           2.8737265803978493,
           2.8658405724650007,
           2.857335421876926,
           2.8482138489249493,
           2.8384787798887334,
           2.8281333481085316,
           2.8171808951716955,
           2.805624972222443,
           2.7934693414048293,
           2.7807179774498523,
           2.7673750694186956,
           2.75344502261529,
           2.73893246068261,
           2.7238422278985523,
           2.7081793916887076,
           2.6919492453750022,
           2.6751573111809956,
           2.657809343516569,
           2.639911332566922,
           2.621469508213162,
           2.6024903443143725,
           2.5829805633839213,
           2.562947141695896,
           2.542397314861083,
           2.521338583915637,
           2.4997787219699026,
           2.477725781469412,
           2.455188102125253,
           2.432174319576657,
           2.4086933748548645,
           2.384754524724267,
           2.360367352984382,
           2.33554178282466,
           2.3102880903333562,
           2.284616919271938,
           2.2585392972377765,
           2.232066653350267,
           2.205210837609208,
           2.177984142089262,
           2.1503993241508135,
           2.1224696318655476,
           2.0942088318747762,
           2.0656312399199592,
           2.036751754308064,
           2.0075858925994754,
           1.9781498318329642,
           1.9484604526307638,
           1.9185353875567985,
           1.8883930741323058,
           1.8580528129448861,
           1.8275348313187292,
           1.7968603530442686,
           1.7660516746933257,
           1.7351322490688923,
           1.7041267763543118,
           1.67306130353117,
           1.6419633326239254,
           1.6108619382960914,
           1.57978789525975,
           1.5487738158573472,
           1.5178542980196137,
           1.4870660835805027,
           1.456448226620345,
           1.4260422710891758,
           1.3958924364066323,
           1.3660458090121645,
           1.3365525369156588,
           1.3074660231380653,
           1.278843112499655,
           1.2507442644809004,
           1.2232337028313178,
           1.196379530241223,
           1.170253793763146,
           1.1449324838705446,
           1.1204954472431972,
           1.097026190839591,
           1.074611552940918,
           1.053341216138198,
           1.0333070383082084,
           1.01460218118363,
           0.9973200228546009,
           0.9815528509792409,
           0.9673903478289373,
           0.9549178961970448,
           0.9442147555568947,
           0.935352178715795,
           0.9283915578463061,
           0.9233827019856715,
           0.9203623527674429,
           0.9193530389822292,
           0.9203623527674449,
           0.9233827019856758,
           0.9283915578463124,
           0.9353521787158031,
           0.9442147555569049,
           0.9549178961970566,
           0.9673903478289511,
           0.9815528509792563,
           0.9973200228546177,
           1.0146021811836488,
           1.0333070383082281,
           1.0533412161382194,
           1.0746115529409401,
           1.0970261908396144,
           1.1204954472432216,
           1.1449324838705701,
           1.170253793763172,
           1.1963795302412503,
           1.2232337028313456,
           1.250744264480929,
           1.278843112499684,
           1.307466023138095,
           1.336552536915689,
           1.366045809012195,
           1.395892436406663,
           1.426042271089207,
           1.456448226620376,
           1.4870660835805343,
           1.517854298019645,
           1.5487738158573787,
           1.5797878952597817,
           1.6108619382961236,
           1.641963332623957,
           1.673061303531202,
           1.7041267763543437,
           1.735132249068924,
           1.7660516746933574,
           1.7968603530443004,
           1.8275348313187614,
           1.8580528129449179,
           1.8883930741323367,
           1.918535387556829,
           1.9484604526307943,
           1.9781498318329953,
           2.0075858925995056,
           2.036751754308094,
           2.0656312399199885,
           2.0942088318748056,
           2.1224696318655765,
           2.1503993241508423,
           2.17798414208929,
           2.2052108376092354,
           2.232066653350294,
           2.258539297237803,
           2.284616919271964,
           2.3102880903333816,
           2.3355417828246856,
           2.3603673529844067,
           2.3847545247242916,
           2.408693374854889,
           2.4321743195766805,
           2.4551881021252764,
           2.4777257814694345,
           2.499778721969925,
           2.521338583915659,
           2.542397314861104,
           2.5629471416959175,
           2.5829805633839413,
           2.602490344314393,
           2.6214695082131807,
           2.6399113325669403,
           2.657809343516587,
           2.675157311181014,
           2.691949245375019,
           2.708179391688724,
           2.723842227898568,
           2.738932460682625,
           2.753445022615304,
           2.7673750694187094,
           2.780717977449865,
           2.793469341404842,
           2.8056249722224553,
           2.8171808951717066,
           2.8281333481085422,
           2.838478779888744,
           2.8482138489249595,
           2.8573354218769342,
           2.8658405724650087,
           2.873726580397857,
           2.880990930406303,
           2.8876313113758263,
           2.8936456155711174,
           2.8990319379467304,
           2.9037885755385258,
           2.907914026931205,
           2.9114069917978287,
           2.9142663705077236,
           2.916491263799765,
           2.9180809725184598,
           2.9190349974107908
          ],
          [
           2.906672601177065,
           2.906355282451253,
           2.905403425437407,
           2.903817327654064,
           2.9015974850582498,
           2.8987445921854404,
           2.8952595423470657,
           2.8911434278871178,
           2.886397540499885,
           2.881023371611338,
           2.875022612827157,
           2.868397156450934,
           2.8611490960766024,
           2.853280727259747,
           2.8447945482730104,
           2.835693260951481,
           2.8259797716346267,
           2.815657192212046,
           2.8047288412811238,
           2.7931982454254785,
           2.781069140624048,
           2.768345473801587,
           2.7550314045324624,
           2.7411313069107472,
           2.7266497716009153,
           2.711591608084759,
           2.6959618471216937,
           2.679765743441222,
           2.663008778688125,
           2.645696664642907,
           2.627835346742183,
           2.609431007926042,
           2.590490072842018,
           2.5710192124381748,
           2.551025348980913,
           2.5305156615366196,
           2.5094975919600464,
           2.4879788514365573,
           2.4659674276299937,
           2.4434715924930597,
           2.4204999108027856,
           2.3970612494898877,
           2.3731647878377533,
           2.3488200286344374,
           2.324036810369496,
           2.2988253205767952,
           2.2731961104348,
           2.247160110747161,
           2.220728649439014,
           2.193913470718266,
           2.1667267560663177,
           2.1391811472394995,
           2.1112897714808123,
           2.0830662691617228,
           2.0545248240956777,
           2.0256801967888864,
           1.9965477609197242,
           1.9671435433659006,
           1.9374842681282054,
           1.9075874045310646,
           1.8774712201129875,
           1.8471548386538352,
           1.8166583038199566,
           1.78600264894162,
           1.7552099734684172,
           1.7243035266754236,
           1.6933077992132621,
           1.6622486231052758,
           1.6311532807901177,
           1.6000506237821142,
           1.568971201466955,
           1.5379474004565208,
           1.5070135947814067,
           1.4762063069871239,
           1.4455643799006308,
           1.4151291584243368,
           1.3849446801670091,
           1.3550578730029448,
           1.3255187567259725,
           1.2963806447947608,
           1.2677003407118166,
           1.2395383218066365,
           1.2119589010814775,
           1.1850303553261587,
           1.1588250049525053,
           1.133419228031052,
           1.1088933880012808,
           1.0853316517428042,
           1.0628216725333999,
           1.0414541114128117,
           1.021321971281734,
           1.0025197214474715,
           0.9851421970395193,
           0.9692832683766032,
           0.9550342902449852,
           0.9424823598385675,
           0.93170843370353,
           0.922785376380804,
           0.9157760336319325,
           0.910731437700055,
           0.907689257580106,
           0.9066726011770648,
           0.9076892575801082,
           0.910731437700059,
           0.9157760336319388,
           0.9227853763808122,
           0.9317084337035402,
           0.9424823598385798,
           0.9550342902449991,
           0.9692832683766186,
           0.9851421970395364,
           1.0025197214474901,
           1.021321971281754,
           1.0414541114128328,
           1.0628216725334225,
           1.0853316517428278,
           1.1088933880013054,
           1.1334192280310775,
           1.158825004952532,
           1.185030355326186,
           1.2119589010815055,
           1.239538321806665,
           1.2677003407118457,
           1.2963806447947905,
           1.3255187567260027,
           1.3550578730029752,
           1.3849446801670402,
           1.415129158424368,
           1.4455643799006623,
           1.4762063069871554,
           1.5070135947814387,
           1.5379474004565523,
           1.568971201466987,
           1.600050623782146,
           1.6311532807901497,
           1.662248623105308,
           1.6933077992132939,
           1.7243035266754554,
           1.7552099734684485,
           1.7860026489416516,
           1.816658303819988,
           1.8471548386538665,
           1.8774712201130184,
           1.9075874045310952,
           1.9374842681282363,
           1.9671435433659308,
           1.9965477609197548,
           2.0256801967889166,
           2.0545248240957075,
           2.083066269161752,
           2.111289771480841,
           2.1391811472395275,
           2.1667267560663457,
           2.1939134707182935,
           2.2207286494390415,
           2.247160110747188,
           2.2731961104348275,
           2.2988253205768214,
           2.3240368103695217,
           2.348820028634463,
           2.3731647878377773,
           2.3970612494899117,
           2.4204999108028096,
           2.443471592493083,
           2.4659674276300168,
           2.48797885143658,
           2.5094975919600677,
           2.530515661536641,
           2.551025348980934,
           2.571019212438195,
           2.590490072842038,
           2.6094310079260605,
           2.6278353467422018,
           2.645696664642925,
           2.663008778688143,
           2.679765743441239,
           2.6959618471217097,
           2.711591608084775,
           2.7266497716009304,
           2.7411313069107615,
           2.755031404532476,
           2.768345473801601,
           2.7810691406240613,
           2.793198245425491,
           2.8047288412811353,
           2.8156571922120572,
           2.8259797716346364,
           2.8356932609514907,
           2.844794548273019,
           2.8532807272597553,
           2.86114909607661,
           2.868397156450941,
           2.8750226128271636,
           2.881023371611344,
           2.8863975404998903,
           2.8911434278871218,
           2.89525954234707,
           2.8987445921854436,
           2.901597485058252,
           2.9038173276540657,
           2.905403425437408,
           2.9063552824512535
          ],
          [
           2.8931150161867834,
           2.8927984773178004,
           2.891848959170924,
           2.890266757153281,
           2.888052363700009,
           2.885206468409906,
           2.8817299582368703,
           2.877623917738668,
           2.8728896293850315,
           2.867528573927563,
           2.86154243083439,
           2.854933078793069,
           2.8477025962857074,
           2.8398532622409087,
           2.8313875567676665,
           2.8223081619770216,
           2.8126179628979435,
           2.8023200484946065,
           2.791417712793047,
           2.779914456125954,
           2.767813986505316,
           2.7551202211335544,
           2.741837288064873,
           2.7279695280296705,
           2.713521496436116,
           2.6984979655643566,
           2.682903926970289,
           2.6667445941174583,
           2.650025405257441,
           2.6327520265809694,
           2.614930355664254,
           2.5965665252372445,
           2.5776669073032017,
           2.5582381176417677,
           2.5382870207308543,
           2.517820735126136,
           2.4968466393407107,
           2.4753723782717434,
           2.453405870225484,
           2.4309553145972522,
           2.408029200268588,
           2.3846363147900997,
           2.360785754425423,
           2.336486935139425,
           2.3117496046222668,
           2.2865838554503233,
           2.2610001394953776,
           2.2350092837049784,
           2.2086225073895753,
           2.1818514411660392,
           2.1547081477226824,
           2.1272051445878923,
           2.0993554291032726,
           2.071172505822703,
           2.042670416581262,
           2.0138637735024663,
           1.9847677952389402,
           1.955398346770423,
           1.9257719831139113,
           1.895905997333649,
           1.8658184732733252,
           1.8355283434688594,
           1.8050554527368647,
           1.7744206279703938,
           1.7436457547085091,
           1.7127538610777417,
           1.6817692097290289,
           1.6507173984098544,
           1.6196254698134454,
           1.5885220313290167,
           1.557437385271428,
           1.5264036700851247,
           1.4954550128832091,
           1.4646276934818148,
           1.4339603198028301,
           1.4034940141201633,
           1.37327260908705,
           1.343342851770474,
           1.3137546129948723,
           1.2845610981190392,
           1.2558190538945995,
           1.2275889642422197,
           1.199935225604148,
           1.172926289981162,
           1.1466347608671756,
           1.1211374241401304,
           1.096515192718107,
           1.0728529407169323,
           1.0502392003555259,
           1.028765693504303,
           1.0085266702655318,
           0.9896180301298881,
           0.9721362079115831,
           0.9561768175372642,
           0.9418330622154432,
           0.9291939392957129,
           0.9183422911253725,
           0.9093527772820371,
           0.9022898655744847,
           0.897205955378033,
           0.8941397534231333,
           0.8931150161867832,
           0.8941397534231356,
           0.8972059553780373,
           0.9022898655744909,
           0.9093527772820453,
           0.9183422911253828,
           0.929193939295725,
           0.9418330622154569,
           0.9561768175372798,
           0.9721362079116003,
           0.989618030129907,
           1.0085266702655518,
           1.0287656935043243,
           1.0502392003555483,
           1.072852940716956,
           1.0965151927181316,
           1.1211374241401562,
           1.1466347608672023,
           1.1729262899811894,
           1.1999352256041758,
           1.227588964242248,
           1.2558190538946288,
           1.2845610981190692,
           1.3137546129949025,
           1.3433428517705048,
           1.3732726090870808,
           1.4034940141201944,
           1.4339603198028616,
           1.4646276934818463,
           1.4954550128832411,
           1.5264036700851566,
           1.5574373852714598,
           1.588522031329049,
           1.6196254698134775,
           1.6507173984098864,
           1.6817692097290604,
           1.7127538610777735,
           1.7436457547085407,
           1.774420627970425,
           1.8050554527368963,
           1.835528343468891,
           1.8658184732733567,
           1.8959059973336798,
           1.925771983113942,
           1.955398346770453,
           1.9847677952389704,
           2.013863773502496,
           2.042670416581292,
           2.0711725058227324,
           2.099355429103301,
           2.1272051445879208,
           2.1547081477227104,
           2.1818514411660668,
           2.2086225073896024,
           2.235009283705005,
           2.261000139495404,
           2.2865838554503495,
           2.3117496046222925,
           2.33648693513945,
           2.3607857544254474,
           2.384636314790124,
           2.408029200268612,
           2.430955314597275,
           2.453405870225507,
           2.475372378271766,
           2.496846639340733,
           2.5178207351261563,
           2.538287020730875,
           2.5582381176417877,
           2.5776669073032217,
           2.5965665252372636,
           2.614930355664273,
           2.632752026580987,
           2.650025405257458,
           2.666744594117475,
           2.6829039269703054,
           2.6984979655643735,
           2.713521496436131,
           2.7279695280296847,
           2.7418372880648874,
           2.7551202211335677,
           2.7678139865053284,
           2.779914456125966,
           2.7914177127930584,
           2.802320048494617,
           2.8126179628979533,
           2.822308161977031,
           2.831387556767675,
           2.8398532622409176,
           2.8477025962857145,
           2.8549330787930756,
           2.8615424308343966,
           2.8675285739275687,
           2.872889629385037,
           2.877623917738672,
           2.8817299582368743,
           2.885206468409909,
           2.888052363700011,
           2.8902667571532827,
           2.8918489591709253,
           2.8927984773178013
          ],
          [
           2.8786934000992597,
           2.8783776988512004,
           2.877430692819297,
           2.875852675166371,
           2.8736441345839894,
           2.870805755423511,
           2.8673384178810575,
           2.8632431982379174,
           2.8585213691583546,
           2.853174400047264,
           2.847203957470551,
           2.840611905641703,
           2.8334003069784357,
           2.825571422733951,
           2.8171277137078654,
           2.8080718410425063,
           2.7984066671109584,
           2.7881352565039124,
           2.777260877123172,
           2.7657870013904606,
           2.7537173075810895,
           2.7410556812929667,
           2.7278062170625166,
           2.7139732201401707,
           2.6995612084393366,
           2.6845749146741067,
           2.669019288702421,
           2.6528995000930133,
           2.636220940936223,
           2.618989228920707,
           2.6012102107001693,
           2.5828899655766064,
           2.5640348095290793,
           2.5446512996198956,
           2.5247462388131727,
           2.5043266812442013,
           2.4833999379818117,
           2.461973583330174,
           2.440055461721037,
           2.4176536952526106,
           2.394776691936909,
           2.371433154723696,
           2.3476320913761137,
           2.323382825280784,
           2.2986950072837136,
           2.273578628652788,
           2.2480440352781366,
           2.2221019432332176,
           2.1957634558323536,
           2.1690400823346434,
           2.1419437584598677,
           2.1144868688993532,
           2.08668227202387,
           2.0585433270116362,
           2.0300839236426005,
           2.0013185150303703,
           1.9722621535907146,
           1.9429305305753741,
           1.9133400195321415,
           1.8835077240866285,
           1.8534515304777182,
           1.823190165317017,
           1.792743259082118,
           1.7621314158933539,
           1.7313762901626453,
           1.7005006707393313,
           1.669528573209033,
           1.6384853410243616,
           1.6073977561561297,
           1.5762941599448255,
           1.5452045847966742,
           1.5141608972966403,
           1.483196953189397,
           1.4523487644923043,
           1.4216546787315234,
           1.3911555699084892,
           1.3608950402788262,
           1.3309196313235994,
           1.301279041372368,
           1.272026346153286,
           1.243218217049827,
           1.2149151299911265,
           1.187181555657164,
           1.1600861190248055,
           1.133701713235394,
           1.1081055494049044,
           1.0833791204823715,
           1.0596080538633645,
           1.0368818245982747,
           1.0152932992822918,
           0.9949380808269568,
           0.9759136271807296,
           0.9583181236249039,
           0.9422490993458487,
           0.9278017950496363,
           0.9150673092709508,
           0.9041305756251529,
           0.8950682493106685,
           0.887946605315578,
           0.8828195688669873,
           0.879727006467974,
           0.8786934000992599,
           0.8797270064679761,
           0.8828195688669914,
           0.8879466053155843,
           0.8950682493106772,
           0.9041305756251633,
           0.915067309270963,
           0.9278017950496504,
           0.9422490993458643,
           0.9583181236249212,
           0.9759136271807484,
           0.994938080826977,
           1.0152932992823136,
           1.0368818245982974,
           1.0596080538633883,
           1.0833791204823962,
           1.10810554940493,
           1.1337017132354206,
           1.160086119024833,
           1.1871815556571923,
           1.2149151299911551,
           1.2432182170498565,
           1.272026346153316,
           1.3012790413723982,
           1.3309196313236298,
           1.360895040278857,
           1.3911555699085207,
           1.4216546787315547,
           1.4523487644923356,
           1.4831969531894287,
           1.514160897296672,
           1.545204584796706,
           1.5762941599448574,
           1.6073977561561617,
           1.6384853410243936,
           1.6695285732090648,
           1.700500670739363,
           1.7313762901626772,
           1.7621314158933856,
           1.7927432590821493,
           1.8231901653170481,
           1.8534515304777492,
           1.883507724086659,
           1.9133400195321721,
           1.9429305305754043,
           1.9722621535907443,
           2.0013185150304,
           2.03008392364263,
           2.058543327011665,
           2.086682272023898,
           2.1144868688993816,
           2.1419437584598957,
           2.169040082334671,
           2.1957634558323806,
           2.2221019432332443,
           2.2480440352781637,
           2.273578628652814,
           2.298695007283739,
           2.3233828252808095,
           2.347632091376139,
           2.37143315472372,
           2.3947766919369333,
           2.4176536952526346,
           2.4400554617210597,
           2.461973583330196,
           2.4833999379818334,
           2.5043266812442218,
           2.5247462388131936,
           2.544651299619915,
           2.564034809529099,
           2.5828899655766255,
           2.6012102107001875,
           2.6189892289207246,
           2.636220940936241,
           2.6528995000930298,
           2.669019288702437,
           2.6845749146741222,
           2.699561208439351,
           2.7139732201401854,
           2.7278062170625303,
           2.7410556812929796,
           2.753717307581102,
           2.765787001390472,
           2.7772608771231835,
           2.788135256503924,
           2.7984066671109686,
           2.808071841042516,
           2.8171277137078743,
           2.8255714227339594,
           2.8334003069784433,
           2.84061190564171,
           2.847203957470558,
           2.8531744000472696,
           2.85852136915836,
           2.8632431982379214,
           2.867338417881061,
           2.8708057554235142,
           2.8736441345839916,
           2.8758526751663727,
           2.8774306928192974,
           2.878377698851201
          ],
          [
           2.863421704896654,
           2.863106899841666,
           2.8621625815978224,
           2.860589040953505,
           2.858386762639632,
           2.8555564254558163,
           2.8520989024484593,
           2.8480152611422813,
           2.8433067638271985,
           2.8379748679029553,
           2.832021226284357,
           2.8254476878704677,
           2.8182562980816317,
           2.810449299468743,
           2.802029132399747,
           2.7929984358289817,
           2.783360048155607,
           2.7731170081780867,
           2.762272556152416,
           2.7508301349626243,
           2.73879339141293,
           2.7261661776518857,
           2.7129525527398846,
           2.699156784372496,
           2.6847833507733374,
           2.6698369427715,
           2.6543224660800195,
           2.638245043793446,
           2.621610019124338,
           2.604422958400394,
           2.5866896543460656,
           2.568416129674779,
           2.5496086410204586,
           2.5302736832398582,
           2.510417994120279,
           2.4900485595307056,
           2.4691726190581447,
           2.447797672175149,
           2.4259314849891194,
           2.4035820976291196,
           2.380757832331587,
           2.357467302292636,
           2.3337194213615935,
           2.3095234146581753,
           2.2848888302042503,
           2.2598255516706875,
           2.2343438123503203,
           2.208454210479776,
           2.182167726045903,
           2.155495739226932,
           2.1284500506344113,
           2.101042903539625,
           2.073287008287658,
           2.045195569123769,
           2.016782313680382,
           1.9880615253989706,
           1.9590480791895128,
           1.9297574806611584,
           1.9002059092912773,
           1.870410265936208,
           1.840388225125593,
           1.810158292622955,
           1.7797398687776402,
           1.7491533182366654,
           1.7184200466282311,
           1.6875625848700821,
           1.6566046817931284,
           1.6255714058007324,
           1.5944892563023614,
           1.5633862856612453,
           1.5322922323715817,
           1.5012386661217088,
           1.4702591452926923,
           1.4393893872704318,
           1.408667451692974,
           1.378133936387442,
           1.3478321852413209,
           1.3178085065631335,
           1.2881123995738073,
           1.2587967854828717,
           1.2299182380901488,
           1.2015372069614543,
           1.173718223911251,
           1.1465300807597996,
           1.1200459631253061,
           1.094343521427844,
           1.069504856471789,
           1.0456163932068978,
           1.02276861296949,
           1.0010556122829044,
           0.9805744559528936,
           0.9614242946975774,
           0.9437052239503043,
           0.9275168717249267,
           0.9129567201464455,
           0.9001181873577423,
           0.8890885229255295,
           0.8799465982242454,
           0.872760699926736,
           0.867586455093203,
           0.86446502568869,
           0.863421704896654,
           0.8644650256886921,
           0.8675864550932072,
           0.8727606999267425,
           0.8799465982242538,
           0.8890885229255401,
           0.9001181873577545,
           0.9129567201464597,
           0.9275168717249423,
           0.9437052239503217,
           0.9614242946975963,
           0.9805744559529138,
           1.001055612282926,
           1.0227686129695128,
           1.0456163932069218,
           1.0695048564718141,
           1.09434352142787,
           1.120045963125333,
           1.146530080759827,
           1.1737182239112791,
           1.2015372069614831,
           1.2299182380901783,
           1.2587967854829016,
           1.2881123995738375,
           1.3178085065631644,
           1.347832185241352,
           1.3781339363874732,
           1.4086674516930056,
           1.4393893872704635,
           1.4702591452927245,
           1.5012386661217405,
           1.5322922323716135,
           1.5633862856612775,
           1.5944892563023934,
           1.6255714058007646,
           1.6566046817931601,
           1.687562584870114,
           1.7184200466282629,
           1.7491533182366965,
           1.7797398687776715,
           1.8101582926229862,
           1.8403882251256238,
           1.8704102659362387,
           1.9002059092913077,
           1.9297574806611881,
           1.9590480791895428,
           1.9880615253990004,
           2.016782313680412,
           2.0451955691237984,
           2.073287008287687,
           2.1010429035396534,
           2.1284500506344393,
           2.1554957392269594,
           2.18216772604593,
           2.2084542104798026,
           2.2343438123503474,
           2.2598255516707138,
           2.284888830204276,
           2.3095234146582,
           2.3337194213616184,
           2.35746730229266,
           2.3807578323316108,
           2.403582097629142,
           2.425931484989142,
           2.4477976721751715,
           2.469172619058167,
           2.4900485595307265,
           2.5104179941202993,
           2.5302736832398782,
           2.5496086410204786,
           2.568416129674798,
           2.5866896543460847,
           2.604422958400412,
           2.621610019124355,
           2.638245043793463,
           2.654322466080036,
           2.669836942771516,
           2.684783350773352,
           2.699156784372511,
           2.7129525527398988,
           2.726166177651899,
           2.738793391412943,
           2.7508301349626363,
           2.7622725561524275,
           2.773117008178097,
           2.783360048155617,
           2.792998435828991,
           2.802029132399756,
           2.8104492994687518,
           2.8182562980816392,
           2.825447687870475,
           2.8320212262843634,
           2.837974867902961,
           2.8433067638272043,
           2.8480152611422858,
           2.8520989024484633,
           2.8555564254558194,
           2.8583867626396344,
           2.860589040953507,
           2.862162581597824,
           2.8631068998416667
          ],
          [
           2.8473147049577676,
           2.8470008555317685,
           2.8460594033413797,
           2.8444906366734215,
           2.842295036086103,
           2.839473274530012,
           2.8360262175189477,
           2.8319549233520456,
           2.8272606433891077,
           2.8219448223814565,
           2.8160090988611355,
           2.809455305591734,
           2.802285470084629,
           2.7945018151849883,
           2.7861067597324096,
           2.7771029193017154,
           2.7674931070300133,
           2.757280334536883,
           2.746467812945221,
           2.7350589540111296,
           2.7230573713720494,
           2.7104668819233146,
           2.697291507334274,
           2.6835354757162615,
           2.669203223455873,
           2.654299397228347,
           2.6388288562072484,
           2.622796674488247,
           2.6062081437465094,
           2.589068776149099,
           2.571384307545874,
           2.5531607009646686,
           2.534404150439044,
           2.5151210851997297,
           2.4953181742638897,
           2.4750023314598084,
           2.4541807209283144,
           2.432860763146429,
           2.411050141523354,
           2.388756809623992,
           2.365988999080898,
           2.342755228261816,
           2.319064311766947,
           2.2949253708378516,
           2.270347844768499,
           2.2453415034185213,
           2.219916460939404,
           2.194083190836101,
           2.1678525424997255,
           2.1412357593615114,
           2.1142444988344127,
           2.0868908542266342,
           2.059187378831241,
           2.0311471124179614,
           2.0027836103775214,
           1.9741109757955908,
           1.945143894762699,
           1.9158976752586192,
           1.8863882899846192,
           1.8566324235548743,
           1.8266475244989862,
           1.7964518625709178,
           1.7660645919052225,
           1.735505820608668,
           1.7047966874231437,
           1.6739594461426275,
           1.6430175585108233,
           1.6119957963638376,
           1.5809203538097951,
           1.5498189702490102,
           1.5187210650267422,
           1.4876578844657746,
           1.456662661935209,
           1.4257707914583377,
           1.395020015125143,
           1.3644506242273142,
           1.3341056735429901,
           1.3040312075250124,
           1.2742764962435218,
           1.2448942777476188,
           1.2159410019829395,
           1.1874770694723824,
           1.1595670555814879,
           1.1322799083098969,
           1.1056891041710384,
           1.0798727428950796,
           1.0549135575544906,
           1.0308988125319338,
           1.0079200579580652,
           0.9860727064770397,
           0.9654553973068067,
           0.9461691146077864,
           0.9283160333317962,
           0.9119980771083898,
           0.8973151901135414,
           0.8843633483198894,
           0.87323236399953,
           0.8640035683645646,
           0.8567474868265652,
           0.8515216444451146,
           0.8483686503565442,
           0.8473147049577674,
           0.8483686503565465,
           0.8515216444451189,
           0.8567474868265719,
           0.864003568364573,
           0.8732323639995405,
           0.8843633483199016,
           0.8973151901135556,
           0.9119980771084057,
           0.9283160333318138,
           0.9461691146078055,
           0.9654553973068274,
           0.9860727064770617,
           1.0079200579580883,
           1.0308988125319578,
           1.0549135575545159,
           1.0798727428951058,
           1.1056891041710653,
           1.1322799083099244,
           1.1595670555815163,
           1.1874770694724115,
           1.2159410019829688,
           1.244894277747649,
           1.2742764962435518,
           1.3040312075250435,
           1.3341056735430215,
           1.3644506242273455,
           1.3950200151251746,
           1.4257707914583695,
           1.4566626619352407,
           1.4876578844658066,
           1.518721065026774,
           1.5498189702490421,
           1.5809203538098273,
           1.6119957963638698,
           1.6430175585108548,
           1.6739594461426592,
           1.7047966874231757,
           1.7355058206086995,
           1.7660645919052538,
           1.796451862570949,
           1.8266475244990172,
           1.8566324235549048,
           1.8863882899846498,
           1.9158976752586494,
           1.9451438947627293,
           1.9741109757956201,
           2.002783610377551,
           2.0311471124179907,
           2.05918737883127,
           2.0868908542266618,
           2.1142444988344407,
           2.141235759361539,
           2.1678525424997526,
           2.194083190836128,
           2.21991646093943,
           2.245341503418547,
           2.2703478447685246,
           2.294925370837877,
           2.3190643117669714,
           2.3427552282618405,
           2.3659889990809213,
           2.388756809624015,
           2.411050141523377,
           2.4328607631464516,
           2.4541807209283357,
           2.4750023314598293,
           2.4953181742639106,
           2.51512108519975,
           2.534404150439064,
           2.5531607009646873,
           2.571384307545893,
           2.5890687761491167,
           2.6062081437465268,
           2.6227966744882636,
           2.6388288562072653,
           2.6542993972283635,
           2.6692032234558876,
           2.6835354757162757,
           2.6972915073342887,
           2.710466881923328,
           2.723057371372062,
           2.735058954011141,
           2.7464678129452325,
           2.757280334536893,
           2.7674931070300235,
           2.7771029193017247,
           2.786106759732419,
           2.7945018151849967,
           2.8022854700846365,
           2.809455305591741,
           2.816009098861142,
           2.8219448223814623,
           2.827260643389113,
           2.8319549233520505,
           2.836026217518952,
           2.839473274530016,
           2.842295036086105,
           2.844490636673423,
           2.846059403341381,
           2.8470008555317685
          ],
          [
           2.830387982764787,
           2.8300751493237293,
           2.8291367442133883,
           2.827573053095166,
           2.8253845521479595,
           2.8225719081836993,
           2.819135978810528,
           2.815077812645033,
           2.8103986495753936,
           2.805099921077732,
           2.799183250588408,
           2.7926504539354786,
           2.785503539833046,
           2.7777447104427155,
           2.7693763620069682,
           2.760401085559833,
           2.7508216677208663,
           2.7406410915791244,
           2.729862537674554,
           2.7184893850849767,
           2.7065252126277337,
           2.6939738001859244,
           2.680839130170211,
           2.667125389128223,
           2.652836969514781,
           2.637978471637461,
           2.6225547057934215,
           2.606570694614979,
           2.590031675643121,
           2.572943104149994,
           2.5553106562334955,
           2.5371402322093464,
           2.5184379603285167,
           2.4992102008506656,
           2.4794635505072766,
           2.459204847391564,
           2.4384411763159677,
           2.417179874682162,
           2.395428538913143,
           2.373195031502,
           2.350487488737676,
           2.3273143291742646,
           2.3036842629174092,
           2.2796063018090917,
           2.255089770600781,
           2.23014431921447,
           2.204779936201875,
           2.1790069635239204,
           2.152836112785918,
           2.126278483078567,
           2.0993455805912884,
           2.0720493401826268,
           2.044402149112679,
           2.0164168731649346,
           1.98810688540976,
           1.9594860978892112,
           1.930568996533111,
           1.9013706796495924,
           1.8719069003697029,
           1.8421941134652742,
           1.8122495270021668,
           1.7820911593369995,
           1.751737902014356,
           1.72120958917265,
           1.6905270741194782,
           1.659712313790025,
           1.628788461852942,
           1.5977799712742966,
           1.5667127071877016,
           1.535614070942235,
           1.5045131362019237,
           1.4734407979416706,
           1.4424299351117333,
           1.4115155876095498,
           1.3807351479823462,
           1.350128567959448,
           1.319738579445465,
           1.2896109289530253,
           1.2597946235665083,
           1.2303421853483214,
           1.2013099095617523,
           1.1727581201210489,
           1.144751413224619,
           1.1173588771296832,
           1.0906542724655908,
           1.064716153393409,
           1.0396279054255713,
           1.0154776710772702,
           0.9923581301662124,
           0.9703660981696743,
           0.9496019045017957,
           0.9301685140472077,
           0.912170361099929,
           0.8957118763108358,
           0.8808957053210865,
           0.8678206426880417,
           0.8565793355152292,
           0.8472558452930014,
           0.8399231895295937,
           0.8346410111186471,
           0.8314535369338212,
           0.8303879827647869,
           0.8314535369338235,
           0.8346410111186515,
           0.8399231895296002,
           0.8472558452930099,
           0.85657933551524,
           0.8678206426880541,
           0.8808957053211008,
           0.895711876310852,
           0.9121703610999466,
           0.930168514047227,
           0.9496019045018166,
           0.9703660981696963,
           0.9923581301662356,
           1.0154776710772946,
           1.0396279054255966,
           1.0647161533934353,
           1.0906542724656176,
           1.117358877129711,
           1.1447514132246475,
           1.172758120121078,
           1.2013099095617819,
           1.2303421853483512,
           1.259794623566539,
           1.2896109289530562,
           1.319738579445496,
           1.3501285679594792,
           1.380735147982378,
           1.4115155876095815,
           1.4424299351117655,
           1.4734407979417021,
           1.504513136201956,
           1.535614070942267,
           1.5667127071877338,
           1.5977799712743288,
           1.628788461852974,
           1.6597123137900567,
           1.6905270741195095,
           1.721209589172681,
           1.751737902014387,
           1.7820911593370308,
           1.8122495270021977,
           1.842194113465305,
           1.871906900369733,
           1.9013706796496224,
           1.9305689965331405,
           1.959486097889241,
           1.9881068854097894,
           2.0164168731649634,
           2.044402149112708,
           2.072049340182655,
           2.099345580591316,
           2.1262784830785946,
           2.152836112785945,
           2.1790069635239466,
           2.2047799362019016,
           2.230144319214496,
           2.255089770600806,
           2.279606301809117,
           2.3036842629174337,
           2.3273143291742886,
           2.3504874887376994,
           2.3731950315020236,
           2.3954285389131655,
           2.4171798746821844,
           2.438441176315989,
           2.459204847391585,
           2.4794635505072966,
           2.499210200850685,
           2.5184379603285363,
           2.537140232209365,
           2.555310656233514,
           2.5729431041500113,
           2.590031675643139,
           2.606570694614996,
           2.622554705793438,
           2.637978471637477,
           2.6528369695147958,
           2.6671253891282367,
           2.6808391301702246,
           2.6939738001859372,
           2.7065252126277466,
           2.718489385084989,
           2.729862537674565,
           2.740641091579135,
           2.750821667720876,
           2.760401085559842,
           2.7693763620069767,
           2.7777447104427244,
           2.785503539833054,
           2.7926504539354857,
           2.7991832505884138,
           2.805099921077738,
           2.810398649575399,
           2.815077812645037,
           2.8191359788105324,
           2.8225719081837033,
           2.825384552147962,
           2.827573053095168,
           2.8291367442133892,
           2.8300751493237297
          ],
          [
           2.812657913828239,
           2.812346157704924,
           2.811410983632947,
           2.8098526745279866,
           2.807671701988928,
           2.804868726407697,
           2.8014445971243958,
           2.7974003526291558,
           2.7927372208124974,
           2.7874566192664476,
           2.781560155639093,
           2.7750496280457053,
           2.7679270255400756,
           2.7601945286502048,
           2.7518545099830134,
           2.7429095349033634,
           2.7333623622932444,
           2.723215945397675,
           2.712473432764577,
           2.701138169286623,
           2.6892136973539285,
           2.6767037581273105,
           2.663612292942866,
           2.649943444859648,
           2.6357015603633944,
           2.6208911912405455,
           2.6055170966381693,
           2.5895842453269418,
           2.573097818186006,
           2.5560632109303967,
           2.5384860371037163,
           2.5203721313610257,
           2.5017275530693612,
           2.482558590256028,
           2.462871763937854,
           2.442673832867917,
           2.4219717987399703,
           2.400772911894925,
           2.3790846775782653,
           2.3569148628023955,
           2.334271503873499,
           2.3111629146488144,
           2.287597695597138,
           2.2635847437431917,
           2.2391332635851136,
           2.214252779083962,
           2.188953146834893,
           2.1632445705416425,
           2.137137616929289,
           2.110643233245187,
           2.0837727665145493,
           2.0565379847356406,
           2.0289511002201435,
           2.0010247953071523,
           1.972772250704661,
           1.9442071767406504,
           1.915343847837036,
           1.886197140554218,
           1.8567825755917946,
           1.8271163641724892,
           1.7972154592814482,
           1.7670976122818978,
           1.7367814354804116,
           1.7062864712704464,
           1.675633268540523,
           1.644843467092388,
           1.6139398908728284,
           1.5829466508780006,
           1.5518892586374327,
           1.5207947512211588,
           1.489691828730667,
           1.4586110052230208,
           1.4275847739649064,
           1.3966477878028727,
           1.3658370552458803,
           1.3351921525587422,
           1.304755451724943,
           1.274572363511078,
           1.244691593999746,
           1.2151654117904682,
           1.1860499215274989,
           1.157405337421712,
           1.1292962479133464,
           1.1017918595064171,
           1.074966204054855,
           1.0488982894098717,
           1.0236721684526127,
           0.9993768963781441,
           0.9761063411010806,
           0.9539588075033081,
           0.9330364339143793,
           0.9134443199721006,
           0.8952893503420766,
           0.8786786902029448,
           0.8637179471555226,
           0.8505090207462875,
           0.8391476942400219,
           0.8297210609469168,
           0.822304914600541,
           0.8169612636081998,
           0.8137361454246931,
           0.812657913828239,
           0.8137361454246953,
           0.8169612636082043,
           0.8223049146005476,
           0.8297210609469255,
           0.8391476942400327,
           0.8505090207463002,
           0.863717947155537,
           0.8786786902029611,
           0.8952893503420942,
           0.91344431997212,
           0.9330364339144003,
           0.9539588075033302,
           0.9761063411011038,
           0.9993768963781685,
           1.0236721684526382,
           1.0488982894098982,
           1.0749662040548822,
           1.101791859506445,
           1.129296247913375,
           1.1574053374217408,
           1.1860499215275286,
           1.215165411790498,
           1.2446915939997767,
           1.2745723635111086,
           1.304755451724974,
           1.3351921525587738,
           1.365837055245912,
           1.3966477878029044,
           1.4275847739649383,
           1.4586110052230528,
           1.489691828730699,
           1.5207947512211906,
           1.5518892586374646,
           1.5829466508780325,
           1.6139398908728604,
           1.6448434670924197,
           1.6756332685405546,
           1.7062864712704777,
           1.736781435480443,
           1.7670976122819289,
           1.797215459281479,
           1.82711636417252,
           1.8567825755918252,
           1.8861971405542481,
           1.9153438478370657,
           1.9442071767406797,
           1.9727722507046903,
           2.001024795307181,
           2.0289511002201723,
           2.056537984735668,
           2.0837727665145773,
           2.1106432332452147,
           2.1371376169293157,
           2.163244570541669,
           2.1889531468349186,
           2.214252779083987,
           2.239133263585139,
           2.263584743743217,
           2.287597695597162,
           2.311162914648839,
           2.3342715038735227,
           2.356914862802418,
           2.3790846775782883,
           2.400772911894947,
           2.421971798739992,
           2.442673832867938,
           2.462871763937875,
           2.4825585902560476,
           2.5017275530693803,
           2.5203721313610448,
           2.538486037103734,
           2.5560632109304144,
           2.573097818186023,
           2.5895842453269586,
           2.605517096638186,
           2.6208911912405615,
           2.63570156036341,
           2.649943444859663,
           2.66361229294288,
           2.6767037581273234,
           2.6892136973539413,
           2.7011381692866356,
           2.7124734327645883,
           2.723215945397686,
           2.7333623622932546,
           2.742909534903373,
           2.7518545099830223,
           2.760194528650213,
           2.767927025540083,
           2.7750496280457115,
           2.7815601556390996,
           2.7874566192664534,
           2.7927372208125023,
           2.7974003526291606,
           2.8014445971244,
           2.8048687264076997,
           2.80767170198893,
           2.809852674527988,
           2.811410983632949,
           2.812346157704925
          ],
          [
           2.7941416508447414,
           2.793831034406159,
           2.7928992784347084,
           2.791346662983863,
           2.789173654878197,
           2.7863809078172355,
           2.782969262522197,
           2.7789397469269748,
           2.774293576415123,
           2.769032154105049,
           2.763157071185983,
           2.7566701073078375,
           2.7495732310284517,
           2.7418686003222934,
           2.7335585631551687,
           2.7246456581300778,
           2.7151326152099555,
           2.7050223565236675,
           2.6943179972623565,
           2.6830228466739574,
           2.6711404091645217,
           2.6586743855158788,
           2.645628674230117,
           2.6320073730124114,
           2.6178147804048715,
           2.603055397585323,
           2.587733930346316,
           2.5718552912711563,
           2.555424602125386,
           2.5384471964839905,
           2.520928622616589,
           2.50287464665507,
           2.484291256070613,
           2.465184663489675,
           2.4455613108815784,
           2.4254278741535886,
           2.4047912681930796,
           2.3836586524004533,
           2.36203743676099,
           2.3399352885088875,
           2.317360139442299,
           2.2943201939544595,
           2.270823937852946,
           2.2468801480468437,
           2.222497903190279,
           2.197686595380423,
           2.1724559430188446,
           2.1468160049571634,
           2.1207771960613884,
           2.0943503043443608,
           2.06754650983253,
           2.0403774053520234,
           2.012855019439904,
           1.9849918416098662,
           1.9568008502276097,
           1.9282955432800846,
           1.899489972354931,
           1.8703987801820618,
           1.841037242128667,
           1.811421312082248,
           1.7815676732037167,
           1.751493794084268,
           1.721217990895564,
           1.6907594961825023,
           1.660138535010917,
           1.629376409248046,
           1.5984955908198633,
           1.5675198248541917,
           1.536474243678376,
           1.5053854926904395,
           1.4742818691563013,
           1.4431934749936237,
           1.4121523845726813,
           1.38119282847981,
           1.350351394027607,
           1.319667243029907,
           1.2891823469523882,
           1.2589417389559951,
           1.22899378151399,
           1.199390447136856,
           1.1701876082037095,
           1.1414453298866953,
           1.1132281575747764,
           1.0856053869707563,
           1.058651301089697,
           1.0324453537184954,
           1.007072273585504,
           0.982622057758127,
           0.9591898170635653,
           0.9368754313159937,
           0.9157829688671679,
           0.8960198248625251,
           0.8776955372588654,
           0.8609202509254623,
           0.8458028195396502,
           0.8324485632448624,
           0.8209567364626352,
           0.8114178020755941,
           0.8039106502843698,
           0.7984999355733673,
           0.7952337252536517,
           0.7941416508447416,
           0.7952337252536541,
           0.7984999355733717,
           0.8039106502843766,
           0.8114178020756029,
           0.820956736462646,
           0.8324485632448752,
           0.8458028195396647,
           0.8609202509254787,
           0.8776955372588836,
           0.8960198248625446,
           0.915782968867189,
           0.9368754313160161,
           0.9591898170635887,
           0.9826220577581516,
           1.0070722735855293,
           1.032445353718522,
           1.0586513010897243,
           1.0856053869707845,
           1.113228157574805,
           1.1414453298867246,
           1.1701876082037392,
           1.1993904471368864,
           1.2289937815140204,
           1.2589417389560258,
           1.2891823469524195,
           1.3196672430299385,
           1.3503513940276388,
           1.3811928284798418,
           1.412152384572713,
           1.4431934749936555,
           1.4742818691563335,
           1.5053854926904713,
           1.5364742436784082,
           1.5675198248542235,
           1.5984955908198952,
           1.6293764092480778,
           1.6601385350109488,
           1.6907594961825336,
           1.7212179908955958,
           1.751493794084299,
           1.7815676732037475,
           1.8114213120822784,
           1.8410372421286973,
           1.8703987801820918,
           1.8994899723549608,
           1.928295543280114,
           1.9568008502276388,
           1.9849918416098948,
           2.012855019439933,
           2.0403774053520514,
           2.0675465098325576,
           2.0943503043443883,
           2.120777196061415,
           2.14681600495719,
           2.172455943018871,
           2.1976865953804485,
           2.222497903190305,
           2.2468801480468685,
           2.2708239378529704,
           2.2943201939544835,
           2.3173601394423224,
           2.3399352885089106,
           2.362037436761012,
           2.383658652400475,
           2.4047912681931014,
           2.425427874153609,
           2.445561310881599,
           2.4651846634896946,
           2.4842912560706325,
           2.5028746466550897,
           2.5209286226166068,
           2.5384471964840087,
           2.555424602125403,
           2.5718552912711727,
           2.5877339303463325,
           2.6030553975853374,
           2.6178147804048866,
           2.632007373012426,
           2.64562867423013,
           2.6586743855158916,
           2.6711404091645345,
           2.683022846673969,
           2.694317997262368,
           2.7050223565236777,
           2.7151326152099653,
           2.724645658130088,
           2.7335585631551775,
           2.7418686003223014,
           2.7495732310284597,
           2.7566701073078446,
           2.7631570711859896,
           2.7690321541050547,
           2.774293576415128,
           2.7789397469269788,
           2.7829692625222013,
           2.786380907817238,
           2.789173654878199,
           2.791346662983865,
           2.7928992784347098,
           2.7938310344061597
          ],
          [
           2.7748571071028776,
           2.7745476938080476,
           2.773619546276754,
           2.7720729415879215,
           2.7699083416044017,
           2.7671263930705985,
           2.763727927750444,
           2.759713962607058,
           2.755085700025798,
           2.749844528082822,
           2.7439920208617075,
           2.7375299388211016,
           2.730460229216851,
           2.722785026582542,
           2.7145066532728834,
           2.705627620074952,
           2.6961506268928583,
           2.6860785635120656,
           2.675414510450253,
           2.6641617399023345,
           2.652323716788078,
           2.639904099911592,
           2.626906743242909,
           2.6133356973329067,
           2.599195210873936,
           2.5844897324197427,
           2.5692239122796097,
           2.55340260460313,
           2.537030869673638,
           2.520113976430108,
           2.502657405239308,
           2.4846668509421646,
           2.466148226200703,
           2.4471076651746,
           2.427551527559296,
           2.407486403020947,
           2.3869191160670713,
           2.3658567313958114,
           2.344306559771213,
           2.322276164476922,
           2.2997733684062625,
           2.2768062618528804,
           2.2533832110730407,
           2.2295128676984324,
           2.2052041790869534,
           2.180466399708626,
           2.1553091036745857,
           2.129742198529201,
           2.1037759404388914,
           2.0774209509263857,
           2.050688235316107,
           2.0235892030753777,
           1.9961356902573646,
           1.9683399842754783,
           1.9402148512654824,
           1.9117735663212279,
           1.8830299469229999,
           1.853998389914233,
           1.8246939124231898,
           1.7951321971713634,
           1.7653296426601597,
           1.7353034187819856,
           1.705071528461341,
           1.6746528759957378,
           1.6440673428349164,
           1.6133358716091102,
           1.5824805592917723,
           1.5515247604571667,
           1.5204932016654522,
           1.4894121080729354,
           1.4583093434166472,
           1.4272145645515242,
           1.396159391713128,
           1.3651775956226977,
           1.3343053024226124,
           1.3035812172004495,
           1.2730468664915977,
           1.2427468595965734,
           1.212729167750444,
           1.1830454190655944,
           1.1537512056492607,
           1.1249063972751834,
           1.096575453358192,
           1.068827721636837,
           1.0417377078267436,
           1.0153852955269802,
           0.9898558898924207,
           0.9652404522213179,
           0.9416353860625001,
           0.9191422294358086,
           0.8978671033762783,
           0.8779198657704792,
           0.8594129232447789,
           0.8424596647795874,
           0.8271725006664733,
           0.8136605205117275,
           0.8020268237654401,
           0.7923656229150374,
           0.7847592674083388,
           0.7792753773722848,
           0.7759643007585023,
           0.7748571071028774,
           0.7759643007585045,
           0.7792753773722895,
           0.7847592674083456,
           0.7923656229150463,
           0.8020268237654512,
           0.8136605205117404,
           0.8271725006664882,
           0.8424596647796041,
           0.859412923244797,
           0.877919865770499,
           0.8978671033762995,
           0.919142229435831,
           0.9416353860625237,
           0.9652404522213427,
           0.9898558898924465,
           1.0153852955270068,
           1.041737707826771,
           1.0688277216368651,
           1.0965754533582206,
           1.1249063972752127,
           1.1537512056492905,
           1.1830454190656245,
           1.2127291677504743,
           1.2427468595966045,
           1.2730468664916288,
           1.303581217200481,
           1.334305302422644,
           1.3651775956227294,
           1.39615939171316,
           1.4272145645515564,
           1.4583093434166792,
           1.4894121080729672,
           1.5204932016654842,
           1.5515247604571987,
           1.5824805592918039,
           1.613335871609142,
           1.6440673428349482,
           1.6746528759957693,
           1.705071528461372,
           1.7353034187820167,
           1.7653296426601905,
           1.7951321971713936,
           1.82469391242322,
           1.8539983899142631,
           1.8830299469230296,
           1.9117735663212574,
           1.9402148512655113,
           1.968339984275507,
           1.9961356902573926,
           2.0235892030754057,
           2.050688235316135,
           2.077420950926413,
           2.1037759404389185,
           2.1297421985292275,
           2.155309103674612,
           2.1804663997086515,
           2.2052041790869787,
           2.2295128676984572,
           2.2533832110730647,
           2.2768062618529044,
           2.299773368406286,
           2.3222761644769445,
           2.3443065597712356,
           2.3658567313958336,
           2.386919116067093,
           2.407486403020968,
           2.4275515275593165,
           2.4471076651746198,
           2.466148226200723,
           2.4846668509421823,
           2.5026574052393267,
           2.520113976430126,
           2.537030869673655,
           2.5534026046031464,
           2.569223912279626,
           2.5844897324197587,
           2.5991952108739507,
           2.6133356973329205,
           2.6269067432429227,
           2.6399040999116052,
           2.6523237167880906,
           2.664161739902346,
           2.6754145104502642,
           2.686078563512076,
           2.6961506268928677,
           2.705627620074961,
           2.714506653272892,
           2.72278502658255,
           2.7304602292168583,
           2.7375299388211087,
           2.7439920208617137,
           2.749844528082827,
           2.755085700025803,
           2.7597139626070626,
           2.7637279277504483,
           2.7671263930706016,
           2.7699083416044044,
           2.772072941587923,
           2.7736195462767554,
           2.7745476938080484
          ],
          [
           2.754822939153244,
           2.754514793611523,
           2.7535904483125035,
           2.7520501772526673,
           2.7498944371531624,
           2.747123867550951,
           2.743739290927688,
           2.7397417128776125,
           2.7351323223161086,
           2.7299124917309987,
           2.7240837774790303,
           2.7176479201304504,
           2.710606844865009,
           2.702962661923205,
           2.694717667117088,
           2.6858743424054725,
           2.6764353565389802,
           2.6664035657809495,
           2.655782014710915,
           2.644573937118063,
           2.632782756992853,
           2.620412089625833,
           2.607465742823589,
           2.593947718252787,
           2.579862212924323,
           2.5652136208308294,
           2.550006534752084,
           2.5342457482443046,
           2.517936257830925,
           2.501083265414168,
           2.4836921809286943,
           2.4657686252607234,
           2.4473184334583955,
           2.4283476582617625,
           2.4088625739836873,
           2.388869680776192,
           2.368375709320318,
           2.347387625981614,
           2.325912638477762,
           2.3039582021098086,
           2.2815320266140073,
           2.258642083697413,
           2.2352966153272695,
           2.211504142851933,
           2.187273477039684,
           2.1626137291314333,
           2.13753432301413,
           2.1120450086338187,
           2.0861558767808446,
           2.0598773753950037,
           2.0332203275554908,
           2.0061959513397354,
           1.9788158817567125,
           1.9510921949845295,
           1.9230374351691066,
           1.8946646440711685,
           1.8659873938826708,
           1.8370198235717368,
           1.8077766791574512,
           1.7782733583628973,
           1.7485259601469496,
           1.7185513396728611,
           1.6883671693348419,
           1.6579920065326685,
           1.6274453689587278,
           1.596747818241281,
           1.5659210528711414,
           1.5349880114246806,
           1.5039729871814285,
           1.4729017553155253,
           1.4418017139109855,
           1.410702040102899,
           1.3796338626686497,
           1.3486304523690744,
           1.3177274312476317,
           1.286963001907393,
           1.2563781974631703,
           1.2260171523604542,
           1.1959273935017896,
           1.1661601500472636,
           1.1367706787648968,
           1.1078185997887633,
           1.0793682349748366,
           1.051488937599851,
           1.0242553978122206,
           0.9977479029418678,
           0.9720525255174246,
           0.9472612047813816,
           0.9234716800237357,
           0.9007872268897914,
           0.879316142105601,
           0.8591709194522459,
           0.8404670624408146,
           0.8233214894429368,
           0.8078505073807252,
           0.7941673620695323,
           0.782379416836076,
           0.7725850633237384,
           0.7648705233177812,
           0.7593067486325954,
           0.7559466564064744,
           0.754822939153244,
           0.7559466564064767,
           0.7593067486326001,
           0.7648705233177882,
           0.7725850633237474,
           0.7823794168360872,
           0.7941673620695454,
           0.8078505073807403,
           0.8233214894429536,
           0.8404670624408328,
           0.859170919452266,
           0.8793161421056224,
           0.9007872268898143,
           0.9234716800237596,
           0.9472612047814066,
           0.9720525255174505,
           0.9977479029418946,
           1.0242553978122482,
           1.0514889375998795,
           1.0793682349748657,
           1.1078185997887928,
           1.1367706787649265,
           1.166160150047294,
           1.1959273935018202,
           1.2260171523604853,
           1.2563781974632013,
           1.2869630019074243,
           1.3177274312476632,
           1.3486304523691062,
           1.3796338626686813,
           1.4107020401029309,
           1.4418017139110177,
           1.4729017553155574,
           1.50397298718146,
           1.5349880114247125,
           1.5659210528711733,
           1.5967478182413126,
           1.6274453689587594,
           1.6579920065327,
           1.6883671693348732,
           1.7185513396728924,
           1.7485259601469805,
           1.7782733583629278,
           1.8077766791574814,
           1.8370198235717672,
           1.8659873938827005,
           1.8946646440711978,
           1.9230374351691355,
           1.9510921949845583,
           1.9788158817567407,
           2.006195951339763,
           2.0332203275555187,
           2.059877375395031,
           2.086155876780871,
           2.112045008633845,
           2.1375343230141564,
           2.162613729131458,
           2.187273477039709,
           2.211504142851958,
           2.235296615327294,
           2.258642083697437,
           2.281532026614031,
           2.3039582021098313,
           2.3259126384777837,
           2.347387625981636,
           2.3683757093203393,
           2.388869680776213,
           2.4088625739837077,
           2.4283476582617816,
           2.447318433458415,
           2.465768625260742,
           2.483692180928712,
           2.501083265414186,
           2.5179362578309425,
           2.534245748244321,
           2.5500065347520997,
           2.5652136208308454,
           2.5798622129243376,
           2.5939477182528012,
           2.607465742823602,
           2.6204120896258454,
           2.632782756992866,
           2.644573937118075,
           2.655782014710926,
           2.6664035657809597,
           2.6764353565389905,
           2.6858743424054827,
           2.6947176671170965,
           2.702962661923213,
           2.7106068448650165,
           2.717647920130457,
           2.7240837774790365,
           2.729912491731005,
           2.7351323223161135,
           2.7397417128776165,
           2.7437392909276914,
           2.747123867550954,
           2.749894437153165,
           2.752050177252669,
           2.753590448312505,
           2.7545147936115235
          ],
          [
           2.7340585287594465,
           2.733751716789235,
           2.7328313711433374,
           2.731297762632682,
           2.729151342664703,
           2.7263927433277906,
           2.7230227775107423,
           2.7190424390584655,
           2.7144529029655273,
           2.709255525609557,
           2.7034518450268727,
           2.6970435812331415,
           2.6900326365922953,
           2.6824210962374084,
           2.6742112285477004,
           2.66540548568638,
           2.6560065042045586,
           2.6460171057171067,
           2.6354402976569267,
           2.6242792741148318,
           2.612537416772981,
           2.6002182959406066,
           2.5873256717016986,
           2.5738634951852677,
           2.55983590996987,
           2.545247253635247,
           2.530102059475227,
           2.5144050583874353,
           2.4981611809569055,
           2.4813755597524225,
           2.4640535318562926,
           2.446200641650352,
           2.4278226438833355,
           2.408925507047282,
           2.3895154170935475,
           2.369598781522123,
           2.3491822338815043,
           2.3282726387203008,
           2.306877097036118,
           2.2850029522721718,
           2.2626577969175234,
           2.239849479772947,
           2.2165861139512533,
           2.1928760856885554,
           2.1687280640515327,
           2.144151011635344,
           2.1191541963576648,
           2.0937472044664056,
           2.0679399548923185,
           2.0417427150929894,
           2.015166118551928,
           1.9882211841158552,
           1.9609193373750495,
           1.9332724343161394,
           1.9052927875042749,
           1.8769931950826027,
           1.8483869729117401,
           1.8194879902109795,
           1.7903107091066444,
           1.7608702285418936,
           1.7311823330566758,
           1.7012635470070585,
           1.6711311948599845,
           1.6408034682730634,
           1.6102995007491958,
           1.579639450742544,
           1.548844594184831,
           1.5179374274979034,
           1.4869417822576987,
           1.4558829527726591,
           1.424787837931006,
           1.393685098748365,
           1.3626053330990824,
           1.3315812691258122,
           1.3006479787715004,
           1.269843112737131,
           1.2392071578993347,
           1.2087837177739618,
           1.1786198159200414,
           1.1487662211608038,
           1.1192777920527357,
           1.0902138360376266,
           1.061638476025644,
           1.0336210136276718,
           1.006236273734549,
           0.9795649095133035,
           0.9536936401170352,
           0.9287153855924464,
           0.9047292549637331,
           0.8818403349785232,
           0.8601592197121666,
           0.8398012169242983,
           0.8208851681452298,
           0.803531828808767,
           0.7878617752662782,
           0.7739928394270986,
           0.7620371194740508,
           0.7520976739481352,
           0.7442650698269092,
           0.7386140123376855,
           0.735200321870619,
           0.7340585287594465,
           0.7352003218706213,
           0.7386140123376903,
           0.7442650698269162,
           0.7520976739481444,
           0.762037119474062,
           0.7739928394271118,
           0.7878617752662932,
           0.8035318288087839,
           0.8208851681452485,
           0.8398012169243185,
           0.8601592197121882,
           0.8818403349785462,
           0.9047292549637572,
           0.9287153855924716,
           0.9536936401170614,
           0.9795649095133304,
           1.006236273734577,
           1.0336210136277002,
           1.0616384760256732,
           1.090213836037656,
           1.119277792052766,
           1.1487662211608343,
           1.178619815920072,
           1.2087837177739928,
           1.2392071578993662,
           1.2698431127371628,
           1.3006479787715322,
           1.331581269125844,
           1.3626053330991144,
           1.3936850987483969,
           1.424787837931038,
           1.4558829527726913,
           1.4869417822577304,
           1.5179374274979351,
           1.5488445941848628,
           1.5796394507425755,
           1.610299500749227,
           1.6408034682730948,
           1.6711311948600158,
           1.7012635470070894,
           1.7311823330567067,
           1.7608702285419242,
           1.7903107091066748,
           1.819487990211009,
           1.84838697291177,
           1.8769931950826317,
           1.9052927875043038,
           1.933272434316168,
           1.960919337375078,
           1.988221184115883,
           2.0151661185519556,
           2.0417427150930165,
           2.0679399548923456,
           2.093747204466432,
           2.1191541963576905,
           2.1441510116353695,
           2.168728064051558,
           2.1928760856885803,
           2.2165861139512772,
           2.239849479772971,
           2.2626577969175465,
           2.2850029522721944,
           2.30687709703614,
           2.3282726387203225,
           2.3491822338815265,
           2.3695987815221438,
           2.389515417093568,
           2.4089255070473015,
           2.4278226438833546,
           2.4462006416503708,
           2.4640535318563104,
           2.4813755597524403,
           2.4981611809569224,
           2.5144050583874513,
           2.5301020594752432,
           2.5452472536352624,
           2.5598359099698853,
           2.5738634951852823,
           2.587325671701712,
           2.6002182959406195,
           2.6125374167729936,
           2.6242792741148437,
           2.6354402976569373,
           2.646017105717117,
           2.6560065042045684,
           2.665405485686389,
           2.6742112285477093,
           2.682421096237417,
           2.690032636592303,
           2.697043581233149,
           2.703451845026879,
           2.7092555256095623,
           2.714452902965532,
           2.7190424390584704,
           2.7230227775107467,
           2.7263927433277937,
           2.7291513426647054,
           2.7312977626326833,
           2.732831371143339,
           2.733751716789236
          ],
          [
           2.712583964147493,
           2.71227855283529,
           2.7113624080693657,
           2.70983579737711,
           2.707699166688795,
           2.704953140415106,
           2.701598521556862,
           2.6976362918481303,
           2.6930676119342847,
           2.6878938215869232,
           2.682116439957947,
           2.6757371658755154,
           2.6687578781849726,
           2.661180636138333,
           2.6530076798363473,
           2.6442414307276847,
           2.634884492170317,
           2.6249396500607336,
           2.6144098735372854,
           2.603298315764578,
           2.591608314806612,
           2.5793433945971245,
           2.566507266016479,
           2.553103828085381,
           2.5391371692867315,
           2.52461156902809,
           2.5095314992584257,
           2.49390162625425,
           2.477726812591719,
           2.4610121193229553,
           2.4437628083767207,
           2.425984345205579,
           2.4076824017039815,
           2.3888628594242194,
           2.3695318131199716,
           2.3496955746503088,
           2.329360677280458,
           2.308533880419509,
           2.2872221748395423,
           2.265432788425487,
           2.2431731925103926,
           2.2204511088568366,
           2.197274517351934,
           2.173651664491002,
           2.1495910727334437,
           2.1251015508239544,
           2.100192205182908,
           2.074872452481881,
           2.0491520335338675,
           2.023041028643081,
           1.9965498745765342,
           1.9696893833390714,
           1.9424707629555131,
           1.9149056404883875,
           1.8870060875476926,
           1.8587846485806743,
           1.8302543722651918,
           1.8014288463702666,
           1.7723222364924853,
           1.742949329127515,
           1.7133255795927032,
           1.683467165380116,
           1.6533910455899277,
           1.6231150271722903,
           1.592657838791959,
           1.5620392132240977,
           1.5312799792915044,
           1.50040216446212,
           1.4694291093393301,
           1.4383855953933846,
           1.407297987395596,
           1.3761943921208808,
           1.345104834968552,
           1.3140614562014674,
           1.283098728499349,
           1.2522536974351486,
           1.221566246275562,
           1.1910793861270572,
           1.1608395718298115,
           1.1308970430569103,
           1.1013061886952378,
           1.0721259306329096,
           1.0434201203961722,
           1.015257938487067,
           0.9877142815861722,
           0.9608701168371454,
           0.9348127751231604,
           0.9096361466210662,
           0.8854407322642416,
           0.8623334947315368,
           0.8404274434255042,
           0.81984088152371,
           0.8006962422698848,
           0.7831184495724989,
           0.7672327583035924,
           0.7531620654494301,
           0.7410237355636666,
           0.7309260504477049,
           0.7229644664600324,
           0.7172179310492498,
           0.7137455571420285,
           0.7125839641474928,
           0.7137455571420308,
           0.7172179310492547,
           0.7229644664600395,
           0.7309260504477142,
           0.7410237355636782,
           0.7531620654494435,
           0.7672327583036077,
           0.7831184495725162,
           0.8006962422699039,
           0.8198408815237305,
           0.8404274434255262,
           0.8623334947315601,
           0.885440732264266,
           0.9096361466210915,
           0.9348127751231867,
           0.9608701168371726,
           0.9877142815862002,
           1.0152579384870957,
           1.0434201203962015,
           1.0721259306329394,
           1.1013061886952678,
           1.130897043056941,
           1.1608395718298423,
           1.1910793861270885,
           1.2215662462755936,
           1.25225369743518,
           1.283098728499381,
           1.3140614562014994,
           1.345104834968584,
           1.376194392120913,
           1.407297987395628,
           1.4383855953934164,
           1.469429109339362,
           1.5004021644621517,
           1.531279979291536,
           1.562039213224129,
           1.5926578387919903,
           1.6231150271723211,
           1.6533910455899583,
           1.6834671653801467,
           1.7133255795927338,
           1.7429493291275453,
           1.7723222364925155,
           1.801428846370296,
           1.8302543722652214,
           1.8587846485807038,
           1.8870060875477217,
           1.9149056404884162,
           1.942470762955541,
           1.9696893833390992,
           1.9965498745765617,
           2.0230410286431075,
           2.049152033533894,
           2.0748724524819075,
           2.1001922051829336,
           2.12510155082398,
           2.149591072733469,
           2.173651664491026,
           2.197274517351958,
           2.2204511088568606,
           2.2431731925104157,
           2.2654327884255094,
           2.2872221748395645,
           2.3085338804195312,
           2.329360677280479,
           2.3496955746503287,
           2.369531813119991,
           2.388862859424239,
           2.4076824017040015,
           2.4259843452055976,
           2.4437628083767384,
           2.4610121193229726,
           2.4777268125917353,
           2.493901626254267,
           2.509531499258442,
           2.5246115690281057,
           2.5391371692867466,
           2.553103828085395,
           2.566507266016493,
           2.5793433945971374,
           2.5916083148066242,
           2.6032983157645897,
           2.614409873537296,
           2.6249396500607443,
           2.6348844921703267,
           2.6442414307276936,
           2.6530076798363558,
           2.6611806361383414,
           2.66875787818498,
           2.675737165875522,
           2.6821164399579533,
           2.6878938215869286,
           2.69306761193429,
           2.6976362918481347,
           2.7015985215568654,
           2.704953140415109,
           2.707699166688797,
           2.709835797377112,
           2.7113624080693675,
           2.712278552835291
          ],
          [
           2.6904200205717324,
           2.6901160783314433,
           2.689204339656389,
           2.687685068697926,
           2.6855587057548775,
           2.682825867343938,
           2.6794873462993833,
           2.6755441119032293,
           2.6709973100473423,
           2.6658482634293246,
           2.6600984717844205,
           2.6537496121560085,
           2.646803539207713,
           2.6392622855805383,
           2.631128062298921,
           2.622403259230077,
           2.613090445601498,
           2.6031923705820756,
           2.592711963932871,
           2.5816523367342294,
           2.570016782196644,
           2.557808776563534,
           2.545031980114939,
           2.5316902382820565,
           2.5177875828835465,
           2.5033282334956306,
           2.488316598969227,
           2.472757279108686,
           2.456655066528189,
           2.440014948703461,
           2.422842110238287,
           2.405141935367289,
           2.3869200107186357,
           2.3681821283628297,
           2.3489342891764267,
           2.3291827065526043,
           2.3089338104938797,
           2.2881942521260497,
           2.2669709086766936,
           2.2452708889662634,
           2.22310153946512,
           2.2004704509758084,
           2.1773854660065064,
           2.153854686909096,
           2.129886484863721,
           2.1054895098011377,
           2.08067270136488,
           2.055445301027252,
           2.02981686548675,
           2.003797281489835,
           1.9773967822372835,
           1.9506259655549174,
           1.9234958140306317,
           1.896017717344688,
           1.8682034970485428,
           1.840065434079557,
           1.8116162993351494,
           1.7828693876709754,
           1.753838555734004,
           1.7245382640936233,
           1.694983624192794,
           1.6651904507074355,
           1.6351753199764445,
           1.604955635247587,
           1.5745496995765893,
           1.5439767973184164,
           1.5132572852610708,
           1.4824126945728235,
           1.4514658448624695,
           1.4204409717867095,
           1.3893638697753434,
           1.3582620515774972,
           1.3271649264515235,
           1.2961039989139795,
           1.2651130900099155,
           1.2342285830402935,
           1.203489695545033,
           1.1729387790404338,
           1.1426216474786304,
           1.112587934543454,
           1.0828914786043864,
           1.05359073227086,
           1.0247491908433666,
           0.996435830336704,
           0.9687255409261782,
           0.9416995354175403,
           0.9154457044953112,
           0.8900588810199973,
           0.8656409647259329,
           0.8423008469288003,
           0.8201540635034907,
           0.7993220954719371,
           0.7799312330393686,
           0.7621109247473883,
           0.7459915530080861,
           0.7317016146770142,
           0.7193643426037368,
           0.7090938794289857,
           0.7009912006563921,
           0.6951400660821635,
           0.6916033379055702,
           0.6904200205717321,
           0.6916033379055727,
           0.6951400660821683,
           0.7009912006563993,
           0.7090938794289952,
           0.7193643426037486,
           0.7317016146770278,
           0.7459915530081017,
           0.7621109247474058,
           0.7799312330393877,
           0.7993220954719579,
           0.8201540635035128,
           0.8423008469288237,
           0.8656409647259574,
           0.8900588810200228,
           0.9154457044953375,
           0.9416995354175677,
           0.9687255409262063,
           0.9964358303367329,
           1.0247491908433959,
           1.0535907322708895,
           1.0828914786044168,
           1.1125879345434846,
           1.1426216474786615,
           1.1729387790404648,
           1.2034896955450647,
           1.234228583040325,
           1.2651130900099472,
           1.2961039989140113,
           1.3271649264515553,
           1.3582620515775292,
           1.3893638697753754,
           1.4204409717867412,
           1.451465844862501,
           1.4824126945728555,
           1.5132572852611024,
           1.5439767973184482,
           1.5745496995766208,
           1.6049556352476182,
           1.6351753199764756,
           1.6651904507074666,
           1.6949836241928247,
           1.7245382640936533,
           1.7538385557340337,
           1.7828693876710053,
           1.811616299335179,
           1.8400654340795861,
           1.8682034970485715,
           1.8960177173447161,
           1.9234958140306602,
           1.950625965554945,
           1.9773967822373106,
           2.0037972814898617,
           2.0298168654867768,
           2.0554453010272784,
           2.080672701364906,
           2.105489509801163,
           2.129886484863746,
           2.1538546869091206,
           2.1773854660065304,
           2.200470450975832,
           2.2231015394651426,
           2.2452708889662856,
           2.2669709086767162,
           2.2881942521260714,
           2.3089338104939006,
           2.329182706552625,
           2.3489342891764466,
           2.3681821283628497,
           2.3869200107186552,
           2.405141935367307,
           2.422842110238305,
           2.4400149487034777,
           2.4566550665282056,
           2.4727572791087025,
           2.4883165989692433,
           2.503328233495646,
           2.517787582883561,
           2.5316902382820703,
           2.545031980114953,
           2.5578087765635473,
           2.5700167821966566,
           2.581652336734241,
           2.5927119639328815,
           2.6031923705820854,
           2.613090445601508,
           2.622403259230086,
           2.63112806229893,
           2.6392622855805463,
           2.6468035392077205,
           2.653749612156015,
           2.6600984717844263,
           2.66584826342933,
           2.6709973100473476,
           2.675544111903234,
           2.6794873462993873,
           2.6828258673439414,
           2.6855587057548806,
           2.687685068697928,
           2.68920433965639,
           2.6901160783314437
          ],
          [
           2.6675881402161385,
           2.6672857368485308,
           2.666378613637786,
           2.664867031272602,
           2.662751424275853,
           2.6600324010676863,
           2.6567107440549664,
           2.6527874097481456,
           2.648263528906998,
           2.643140406716996,
           2.637419522998437,
           2.6311025324508193,
           2.6241912649353494,
           2.616687725798858,
           2.608594096242864,
           2.59991273374196,
           2.590646172516229,
           2.580797124062886,
           2.570368477752979,
           2.559363301499549,
           2.547784842504381,
           2.5356365280911746,
           2.522921966633816,
           2.509644948589268,
           2.495809447645608,
           2.4814196219967872,
           2.4664798157568537,
           2.4509945605276893,
           2.4349685771357192,
           2.4184067775546434,
           2.4013142670329763,
           2.383696346447123,
           2.365558514902863,
           2.3469064726105193,
           2.327746124061723,
           2.3080835815386798,
           2.287925168990143,
           2.267277426311987,
           2.2461471140744242,
           2.224541218742553,
           2.2024669584420873,
           2.179931789327992,
           2.1569434126202705,
           2.1335097823785376,
           2.109639114095329,
           2.085339894197416,
           2.0606208905550134,
           2.0354911641106517,
           2.009960081752996,
           1.9840373305761436,
           1.95773293368222,
           1.9310572677046618,
           1.9040210822517896,
           1.8766355214954433,
           1.8489121481580588,
           1.8208629701839865,
           1.7925004704177057,
           1.7638376396533955,
           1.7348880134677487,
           1.7056657133017041,
           1.676185492317675,
           1.6464627866276993,
           1.6165137725656364,
           1.5863554307639014,
           1.5560056178931625,
           1.525483147032577,
           1.4948078777590694,
           1.4640008171768961,
           1.4330842332528266,
           1.4020817819761993,
           1.371018650024001,
           1.339921714773992,
           1.3088197236658539,
           1.2777434950492408,
           1.2467261427605816,
           1.2158033267116177,
           1.1850135317152806,
           1.1543983765676067,
           1.1240029549780435,
           1.0938762092008232,
           1.0640713360431908,
           1.0346462231525986,
           1.005663910914743,
           0.977193071686882,
           0.9493084931716074,
           0.9220915462176346,
           0.895630608959644,
           0.8700214088319286,
           0.8453672317002925,
           0.8217789336652706,
           0.7993746771757945,
           0.7782793010775254,
           0.7586232274053685,
           0.7405408106512965,
           0.7241680533279217,
           0.7096396502464709,
           0.6970853864836866,
           0.6866259995776086,
           0.6783687171556345,
           0.6724027807156032,
           0.6687953414785627,
           0.6675881402161384,
           0.6687953414785652,
           0.6724027807156082,
           0.6783687171556421,
           0.6866259995776184,
           0.6970853864836986,
           0.7096396502464848,
           0.7241680533279377,
           0.7405408106513144,
           0.7586232274053878,
           0.7782793010775463,
           0.7993746771758168,
           0.8217789336652942,
           0.8453672317003174,
           0.8700214088319543,
           0.8956306089596706,
           0.9220915462176622,
           0.9493084931716357,
           0.9771930716869109,
           1.0056639109147725,
           1.0346462231526286,
           1.064071336043221,
           1.0938762092008538,
           1.1240029549780746,
           1.1543983765676382,
           1.185013531715312,
           1.2158033267116493,
           1.246726142760613,
           1.2777434950492725,
           1.308819723665886,
           1.3399217147740239,
           1.371018650024033,
           1.4020817819762312,
           1.4330842332528586,
           1.4640008171769276,
           1.4948078777591007,
           1.5254831470326082,
           1.5560056178931936,
           1.5863554307639323,
           1.616513772565667,
           1.64646278662773,
           1.6761854923177057,
           1.7056657133017343,
           1.7348880134677784,
           1.763837639653425,
           1.7925004704177347,
           1.8208629701840156,
           1.8489121481580877,
           1.8766355214954715,
           1.9040210822518173,
           1.9310572677046893,
           1.957732933682247,
           1.9840373305761703,
           2.0099600817530225,
           2.035491164110678,
           2.060620890555039,
           2.085339894197441,
           2.1096391140953537,
           2.133509782378562,
           2.156943412620294,
           2.1799317893280157,
           2.20246695844211,
           2.2245412187425755,
           2.2461471140744464,
           2.267277426312009,
           2.2879251689901645,
           2.3080835815386997,
           2.3277461240617425,
           2.3469064726105393,
           2.365558514902882,
           2.383696346447141,
           2.401314267032994,
           2.4184067775546607,
           2.434968577135736,
           2.4509945605277057,
           2.4664798157568697,
           2.4814196219968023,
           2.4958094476456227,
           2.509644948589282,
           2.522921966633829,
           2.5356365280911874,
           2.547784842504393,
           2.559363301499561,
           2.5703684777529903,
           2.580797124062897,
           2.5906461725162386,
           2.599912733741969,
           2.608594096242872,
           2.6166877257988665,
           2.6241912649353565,
           2.631102532450826,
           2.6374195229984427,
           2.6431404067170017,
           2.648263528907003,
           2.6527874097481496,
           2.656710744054971,
           2.6600324010676895,
           2.6627514242758554,
           2.6648670312726037,
           2.666378613637787,
           2.667285736848531
          ],
          [
           2.644110411450382,
           2.6438096182025697,
           2.6429073241706975,
           2.6414037865004354,
           2.6392994338046516,
           2.6365948662190424,
           2.633290855481075,
           2.629388345033272,
           2.624888450152209,
           2.6197924581049254,
           2.6141018283347592,
           2.6078181926789963,
           2.6009433556210846,
           2.5934792945805505,
           2.5854281602441773,
           2.576792276942459,
           2.5675741430758,
           2.5577764315954648,
           2.547401990544822,
           2.5364538436670414,
           2.5249351910860374,
           2.5128494100681884,
           2.500200055873111,
           2.4869908627026422,
           2.4732257447581065,
           2.4589087974169637,
           2.4440442985410726,
           2.428636709930055,
           2.412690678934602,
           2.3962110402461074,
           2.3792028178807016,
           2.361671227377604,
           2.343621678233838,
           2.3250597765996366,
           2.3059913282614555,
           2.2864223419424063,
           2.266359032953127,
           2.2458078272297133,
           2.22477536579936,
           2.2032685097189044,
           2.1812943455365175,
           2.1588601913325065,
           2.135973603401626,
           2.1126423836465036,
           2.088874587759985,
           2.064678534283383,
           2.0400628146380653,
           2.015036304239583,
           1.9896081748169092,
           1.9637879080745062,
           1.9375853108521062,
           1.9110105319566357,
           1.8840740808629024,
           1.8567868485049013,
           1.8291601304083576,
           1.8012056524478404,
           1.7729355995490808,
           1.7443626476996095,
           1.7154999996792357,
           1.686361424977016,
           1.6569613044240987,
           1.6273146801431664,
           1.597437311496159,
           1.5673457378036812,
           1.5370573487130517,
           1.5065904632085019,
           1.4759644183873968,
           1.4451996692713474,
           1.4143179010807614,
           1.3833421555752041,
           1.3522969732480397,
           1.3212085533584685,
           1.2901049339808428,
           1.2590161944395866,
           1.2279746826621323,
           1.1970152700980572,
           1.166175636885162,
           1.1354965898428586,
           1.1050224155702097,
           1.0748012703244954,
           1.0448856073269517,
           1.0153326405146113,
           0.9862048413112525,
           0.957570461453015,
           0.9295040699501186,
           0.9020870855342268,
           0.8754082770734827,
           0.8495641931575716,
           0.8246594683025467,
           0.800806937363558,
           0.7781274728548825,
           0.7567494441200094,
           0.7368076862625865,
           0.7184418656624971,
           0.7017941443773023,
           0.6870060847756931,
           0.6742148036838644,
           0.6635484826277044,
           0.6551214595326919,
           0.6490292488971289,
           0.6453439337118383,
           0.6441104114503821,
           0.6453439337118408,
           0.6490292488971339,
           0.6551214595326992,
           0.6635484826277143,
           0.6742148036838768,
           0.6870060847757072,
           0.7017941443773186,
           0.7184418656625151,
           0.7368076862626062,
           0.7567494441200309,
           0.7781274728549051,
           0.8008069373635819,
           0.8246594683025718,
           0.8495641931575977,
           0.8754082770735095,
           0.9020870855342547,
           0.9295040699501469,
           0.9575704614530444,
           0.9862048413112822,
           1.0153326405146414,
           1.0448856073269823,
           1.0748012703245262,
           1.105022415570241,
           1.1354965898428901,
           1.1661756368851937,
           1.197015270098089,
           1.227974682662164,
           1.2590161944396183,
           1.290104933980875,
           1.3212085533585003,
           1.3522969732480714,
           1.383342155575236,
           1.4143179010807936,
           1.445199669271379,
           1.4759644183874283,
           1.5065904632085332,
           1.5370573487130827,
           1.567345737803712,
           1.5974373114961897,
           1.6273146801431966,
           1.656961304424129,
           1.686361424977046,
           1.7154999996792653,
           1.7443626476996386,
           1.77293559954911,
           1.8012056524478692,
           1.8291601304083864,
           1.8567868485049297,
           1.8840740808629302,
           1.911010531956663,
           1.9375853108521333,
           1.9637879080745333,
           1.9896081748169359,
           2.015036304239609,
           2.040062814638091,
           2.064678534283408,
           2.0888745877600097,
           2.1126423836465276,
           2.13597360340165,
           2.15886019133253,
           2.18129434553654,
           2.2032685097189266,
           2.2247753657993816,
           2.2458078272297346,
           2.266359032953148,
           2.2864223419424263,
           2.305991328261475,
           2.325059776599656,
           2.3436216782338573,
           2.3616712273776215,
           2.379202817880719,
           2.3962110402461247,
           2.4126906789346183,
           2.428636709930072,
           2.444044298541089,
           2.458908797416979,
           2.473225744758121,
           2.486990862702656,
           2.5002000558731243,
           2.5128494100682017,
           2.5249351910860502,
           2.5364538436670525,
           2.547401990544833,
           2.557776431595475,
           2.5675741430758094,
           2.576792276942468,
           2.5854281602441858,
           2.5934792945805585,
           2.600943355621092,
           2.607818192679003,
           2.6141018283347655,
           2.6197924581049308,
           2.624888450152214,
           2.6293883450332762,
           2.6332908554810786,
           2.6365948662190455,
           2.639299433804654,
           2.641403786500438,
           2.6429073241706984,
           2.6438096182025705
          ],
          [
           2.620009547460759,
           2.6197104370855606,
           2.618813190466457,
           2.6173180611323854,
           2.6152254716632686,
           2.6125360137380453,
           2.609250448202911,
           2.6053697051607583,
           2.6008948840831216,
           2.5958272539462364,
           2.590168253393132,
           2.5839194909240315,
           2.5770827451176674,
           2.569659964886518,
           2.5616532697693275,
           2.5530649502647504,
           2.5438974682103748,
           2.5341534572118736,
           2.523835723127597,
           2.512947244614441,
           2.501491173741499,
           2.489470836678651,
           2.476889734468011,
           2.463751543886952,
           2.4500601184123316,
           2.4358194892965277,
           2.4210338667669578,
           2.405707641361993,
           2.3898453854174426,
           2.373451854719316,
           2.3565319903401356,
           2.339090920677922,
           2.3211339637189594,
           2.3026666295476894,
           2.2836946231295907,
           2.2642238473956615,
           2.2442604066602785,
           2.223810610407662,
           2.2028809774861062,
           2.1814782407535422,
           2.1596093522229154,
           2.1372814887614506,
           2.1145020584041236,
           2.091278707348741,
           2.0676193277080324,
           2.0435320661031713,
           2.0190253331934067,
           1.994107814248067,
           1.9687884808803955,
           1.9430766040776195,
           1.9169817686787092,
           1.890513889470644,
           1.863683229096125,
           1.8365004179908693,
           1.8089764765974068,
           1.7811228401351844,
           1.7529513862443755,
           1.7244744658637774,
           1.6957049377523654,
           1.6666562071203226,
           1.6373422688996984,
           1.6077777562584004,
           1.5779779950451809,
           1.5479590649490167,
           1.5177378682652283,
           1.4873322072842432,
           1.4567608714585822,
           1.4260437356606481,
           1.3952018710191951,
           1.3642576700162967,
           1.333234987738506,
           1.3021593014034587,
           1.2710578905216803,
           1.2399600402944202,
           1.2088972710782762,
           1.1779035969447662,
           1.1470158164956545,
           1.1162738391153575,
           1.0857210496820306,
           1.055404714322888,
           1.0253764289540157,
           0.9956926109103011,
           0.9664150317087814,
           0.937611385592666,
           0.9093558835951464,
           0.8817298559994712,
           0.8548223367797825,
           0.8287305914518402,
           0.803560534488487,
           0.7794269642146028,
           0.7564535227962815,
           0.7347722686944448,
           0.7145227325970478,
           0.6958503213179239,
           0.6789039454580885,
           0.6638327848795388,
           0.6507821791119833,
           0.6398887404007461,
           0.6312749279024387,
           0.625043471421722,
           0.6212721573940071,
           0.6200095474607589,
           0.6212721573940095,
           0.6250434714217272,
           0.6312749279024464,
           0.639888740400756,
           0.6507821791119957,
           0.6638327848795532,
           0.678903945458105,
           0.6958503213179423,
           0.7145227325970678,
           0.7347722686944663,
           0.7564535227963045,
           0.779426964214627,
           0.8035605344885122,
           0.8287305914518667,
           0.8548223367798097,
           0.8817298559994992,
           0.9093558835951752,
           0.9376113855926953,
           0.9664150317088114,
           0.9956926109103313,
           1.0253764289540463,
           1.0554047143229188,
           1.085721049682062,
           1.1162738391153888,
           1.147015816495686,
           1.1779035969447982,
           1.2088972710783081,
           1.239960040294452,
           1.271057890521712,
           1.3021593014034905,
           1.3332349877385377,
           1.3642576700163287,
           1.3952018710192269,
           1.4260437356606799,
           1.4567608714586138,
           1.487332207284274,
           1.5177378682652596,
           1.5479590649490476,
           1.5779779950452113,
           1.6077777562584308,
           1.6373422688997288,
           1.6666562071203526,
           1.6957049377523954,
           1.7244744658638065,
           1.7529513862444046,
           1.7811228401352135,
           1.8089764765974354,
           1.8365004179908977,
           1.8636832290961527,
           1.8905138894706712,
           1.916981768678736,
           1.943076604077646,
           1.9687884808804215,
           1.9941078142480932,
           2.0190253331934325,
           2.0435320661031966,
           2.067619327708057,
           2.091278707348765,
           2.114502058404147,
           2.1372814887614746,
           2.159609352222938,
           2.181478240753564,
           2.202880977486128,
           2.223810610407684,
           2.2442604066602994,
           2.264223847395681,
           2.2836946231296107,
           2.302666629547709,
           2.3211339637189785,
           2.33909092067794,
           2.3565319903401534,
           2.373451854719333,
           2.389845385417459,
           2.4057076413620093,
           2.4210338667669737,
           2.4358194892965424,
           2.4500601184123467,
           2.463751543886966,
           2.476889734468025,
           2.4894708366786644,
           2.5014911737415115,
           2.5129472446144527,
           2.523835723127608,
           2.534153457211884,
           2.543897468210384,
           2.5530649502647593,
           2.561653269769336,
           2.5696599648865264,
           2.5770827451176754,
           2.5839194909240377,
           2.590168253393138,
           2.595827253946242,
           2.6008948840831265,
           2.605369705160762,
           2.6092504482029146,
           2.6125360137380484,
           2.6152254716632712,
           2.6173180611323876,
           2.6188131904664584,
           2.619710437085562
          ],
          [
           2.5953088642766495,
           2.595011511091647,
           2.594119534815856,
           2.592633185294853,
           2.5905528789644965,
           2.5878791988912404,
           2.5846128948295095,
           2.5807548832970904,
           2.5763062476697565,
           2.5712682382966605,
           2.5656422726383155,
           2.559429935429303,
           2.552632978868207,
           2.5452533228375764,
           2.537293055157159,
           2.5287544318739994,
           2.5196398775934536,
           2.509951985855637,
           2.499693519562316,
           2.488867411459803,
           2.4774767646840203,
           2.4655248533745304,
           2.4530151233650495,
           2.4399511929587314,
           2.426336853797372,
           2.4121760718346135,
           2.3974729884242683,
           2.3822319215360257,
           2.3664573671120803,
           2.3501540005796,
           2.333326678535541,
           2.315980440622029,
           2.298120511612452,
           2.2797523037305853,
           2.2608814192274336,
           2.2415136532431967,
           2.221654996984748,
           2.201311641252388,
           2.1804899803534346,
           2.159196616444436,
           2.1374383643486206,
           2.1152222569005485,
           2.0925555508760643,
           2.069445733572495,
           2.0459005301118576,
           2.0219279115486453,
           1.9975361038737778,
           1.9727335980176792,
           1.9475291609683687,
           1.921931848135196,
           1.8959510171056175,
           1.869596342961611,
           1.8428778353441893,
           1.8158058574795644,
           1.7883911474091667,
           1.7606448416986378,
           1.7325785019385957,
           1.704204144393293,
           1.6755342732029848,
           1.6465819176029557,
           1.6173606736877852,
           1.5878847513248406,
           1.5581690269075934,
           1.5282291027387016,
           1.4980813739466805,
           1.4677431039701596,
           1.4372325097922043,
           1.4065688582758427,
           1.3757725751425454,
           1.3448653683493317,
           1.3138703678580534,
           1.2828122840515535,
           1.2517175873330884,
           1.2206147117416806,
           1.1895342857160696,
           1.1585093934255677,
           1.1275758703288228,
           1.0967726367775326,
           1.066142073486708,
           1.035730442451908,
           1.0055883562729702,
           0.9757712976564104,
           0.9463401888605681,
           0.917362007681503,
           0.8889104418211219,
           0.8610665666022159,
           0.8339195213909372,
           0.807567147134238,
           0.7821165306164805,
           0.7576843802492633,
           0.7343971340546209,
           0.7123906749323666,
           0.691809505287459,
           0.6728052192849518,
           0.6555341159829252,
           0.640153832106251,
           0.6268189505952501,
           0.6156756663764271,
           0.6068557583043644,
           0.6004703023181654,
           0.5966037229025231,
           0.5953088642766493,
           0.5966037229025258,
           0.6004703023181708,
           0.6068557583043722,
           0.6156756663764376,
           0.6268189505952626,
           0.6401538321062656,
           0.655534115982942,
           0.6728052192849705,
           0.6918095052874793,
           0.7123906749323884,
           0.7343971340546444,
           0.7576843802492879,
           0.7821165306165061,
           0.8075671471342647,
           0.8339195213909646,
           0.8610665666022441,
           0.8889104418211509,
           0.9173620076815325,
           0.9463401888605981,
           0.9757712976564406,
           1.005588356273001,
           1.0357304424519391,
           1.0661420734867393,
           1.0967726367775643,
           1.1275758703288543,
           1.1585093934255997,
           1.1895342857161015,
           1.2206147117417125,
           1.25171758733312,
           1.2828122840515854,
           1.3138703678580852,
           1.3448653683493634,
           1.375772575142577,
           1.4065688582758742,
           1.4372325097922354,
           1.467743103970191,
           1.4980813739467116,
           1.5282291027387325,
           1.558169026907624,
           1.5878847513248713,
           1.6173606736878154,
           1.6465819176029854,
           1.6755342732030145,
           1.7042041443933222,
           1.7325785019386246,
           1.7606448416986666,
           1.7883911474091951,
           1.8158058574795921,
           1.842877835344217,
           1.8695963429616378,
           1.8959510171056444,
           1.9219318481352223,
           1.947529160968395,
           1.9727335980177045,
           1.9975361038738033,
           2.02192791154867,
           2.045900530111882,
           2.0694457335725187,
           2.092555550876088,
           2.115222256900571,
           2.1374383643486428,
           2.159196616444458,
           2.1804899803534563,
           2.2013116412524094,
           2.221654996984768,
           2.2415136532432167,
           2.2608814192274527,
           2.279752303730605,
           2.298120511612471,
           2.3159804406220466,
           2.3333266785355584,
           2.350154000579617,
           2.3664573671120968,
           2.382231921536042,
           2.397472988424284,
           2.412176071834629,
           2.426336853797386,
           2.4399511929587447,
           2.4530151233650628,
           2.465524853374543,
           2.4774767646840328,
           2.488867411459815,
           2.499693519562327,
           2.5099519858556474,
           2.519639877593463,
           2.5287544318740083,
           2.5372930551571677,
           2.545253322837585,
           2.552632978868214,
           2.55942993542931,
           2.5656422726383212,
           2.571268238296666,
           2.576306247669762,
           2.580754883297095,
           2.5846128948295135,
           2.587879198891243,
           2.590552878964499,
           2.5926331852948548,
           2.5941195348158574,
           2.595011511091647
          ],
          [
           2.5700322582137654,
           2.569736738159855,
           2.568850260030364,
           2.5673730699283928,
           2.5653055780471488,
           2.56264835870246,
           2.559402150379167,
           2.555567855792296,
           2.5511465419641737,
           2.546139440318909,
           2.5405479467959755,
           2.534373621984902,
           2.52761819128342,
           2.5202835450817336,
           2.5123717389759395,
           2.503884994014013,
           2.4948256969781646,
           2.485196400707837,
           2.474999824468073,
           2.4642388543685017,
           2.4529165438387666,
           2.4410361141668107,
           2.4286009551071333,
           2.4156146255668527,
           2.4020808543782173,
           2.3880035411671106,
           2.373386757328083,
           2.3582347471175122,
           2.342551928877722,
           2.326342896406219,
           2.309612420485683,
           2.292365450592021,
           2.2746071167996127,
           2.2563427319049607,
           2.237577793792224,
           2.2183179880667216,
           2.1985691909853466,
           2.178337472716085,
           2.1576291009624717,
           2.136450544992898,
           2.114808480119318,
           2.0927097926750964,
           2.0701615855476354,
           2.04717118432808,
           2.0237461441479545,
           1.999894257281157,
           1.9756235615994677,
           1.9509423499808367,
           1.925859180782327,
           1.9003828895040202,
           1.8745226017866625,
           1.8482877479046769,
           1.8216880789377563,
           1.794733684829035,
           1.7674350145662587,
           1.7398028987550909,
           1.7118485748913164,
           1.6835837156820765,
           1.6550204608162251,
           1.6261714526415976,
           1.5970498762735428,
           1.5676695047359326,
           1.5380447498246381,
           1.5081907194859214,
           1.4781232826203925,
           1.4478591423593747,
           1.4174159190171383,
           1.3868122441021034,
           1.356067866975414,
           1.3252037759786766,
           1.2942423361162438,
           1.2632074456722677,
           1.2321247144684326,
           1.2010216668215676,
           1.16992797263387,
           1.1388757104281753,
           1.1078996665027636,
           1.077037674686086,
           1.0463310013619547,
           1.0158247804204816,
           0.9855685024375523,
           0.9556165615065918,
           0.9260288614747472,
           0.8968714805068865,
           0.8682173884301205,
           0.8401472045784729,
           0.8127499741095368,
           0.7861239271632824,
           0.7603771669729843,
           0.7356282095982628,
           0.7120062695305037,
           0.6896511536236052,
           0.6687125945547384,
           0.649348831590431,
           0.6317242421379647,
           0.6160058573569881,
           0.6023586749630251,
           0.5909398234201264,
           0.5818918314172218,
           0.5753354892630542,
           0.5713630021406526,
           0.5700322582137655,
           0.5713630021406554,
           0.5753354892630597,
           0.58189183141723,
           0.590939823420137,
           0.602358674963038,
           0.6160058573570032,
           0.631724242137982,
           0.6493488315904502,
           0.6687125945547591,
           0.6896511536236275,
           0.7120062695305274,
           0.7356282095982877,
           0.7603771669730103,
           0.7861239271633093,
           0.8127499741095644,
           0.8401472045785013,
           0.8682173884301495,
           0.8968714805069162,
           0.9260288614747773,
           0.9556165615066224,
           0.9855685024375834,
           1.015824780420513,
           1.046331001361986,
           1.0770376746861174,
           1.1078996665027956,
           1.138875710428207,
           1.169927972633902,
           1.2010216668215998,
           1.2321247144684646,
           1.2632074456722997,
           1.2942423361162756,
           1.3252037759787085,
           1.3560678669754453,
           1.386812244102135,
           1.4174159190171698,
           1.4478591423594065,
           1.4781232826204236,
           1.5081907194859525,
           1.5380447498246692,
           1.567669504735963,
           1.5970498762735728,
           1.6261714526416275,
           1.6550204608162546,
           1.6835837156821063,
           1.7118485748913455,
           1.739802898755119,
           1.7674350145662872,
           1.794733684829063,
           1.8216880789377836,
           1.848287747904704,
           1.8745226017866894,
           1.9003828895040467,
           1.925859180782353,
           1.9509423499808622,
           1.9756235615994928,
           1.9998942572811815,
           2.023746144147979,
           2.0471711843281035,
           2.0701615855476585,
           2.092709792675119,
           2.1148084801193403,
           2.13645054499292,
           2.157629100962493,
           2.1783374727161062,
           2.198569190985367,
           2.2183179880667416,
           2.237577793792244,
           2.2563427319049794,
           2.2746071167996313,
           2.2923654505920386,
           2.3096124204857,
           2.326342896406236,
           2.3425519288777386,
           2.358234747117528,
           2.373386757328099,
           2.3880035411671257,
           2.4020808543782315,
           2.415614625566867,
           2.428600955107146,
           2.4410361141668226,
           2.4529165438387786,
           2.4642388543685136,
           2.474999824468083,
           2.485196400707847,
           2.4948256969781744,
           2.503884994014023,
           2.5123717389759483,
           2.5202835450817416,
           2.5276181912834272,
           2.5343736219849085,
           2.5405479467959813,
           2.546139440318915,
           2.551146541964178,
           2.5555678557923005,
           2.5594021503791704,
           2.562648358702463,
           2.565305578047151,
           2.5673730699283945,
           2.5688502600303655,
           2.5697367381598557
          ],
          [
           2.5442041827560096,
           2.5439105734552077,
           2.543029826321016,
           2.541562183662887,
           2.5395080493460624,
           2.536867988816225,
           2.5336427291348267,
           2.529833159025953,
           2.525440328935784,
           2.520465451106021,
           2.5149098996628743,
           2.508775210723516,
           2.502063082522183,
           2.494775375558447,
           2.4869141127704766,
           2.4784814797365025,
           2.4694798249080585,
           2.4599116598790003,
           2.4497796596947445,
           2.4390866632066603,
           2.427835673477071,
           2.416029858240914,
           2.403672550430727,
           2.390767248772334,
           2.377317618459365,
           2.3633274919155878,
           2.3488008696549625,
           2.333741921250361,
           2.318154986423026,
           2.3020445762661335,
           2.285415374617196,
           2.268272239595657,
           2.250620205323743,
           2.2324644838506145,
           2.2138104673020305,
           2.1946637302802166,
           2.175030032541348,
           2.154915321981175,
           2.13432573796278,
           2.113267615024384,
           2.091747487009546,
           2.069772091667089,
           2.047348375773753,
           2.024483500838994,
           2.0011848494586193,
           1.9774600323922356,
           1.9533168964489067,
           1.928763533276171,
           1.9038082891598243,
           1.8784597759559234,
           1.852726883292519,
           1.8266187921970607,
           1.80014499032658,
           1.7733152890021007,
           1.7461398422767525,
           1.7186291682993955,
           1.6907941732728915,
           1.662646178349304,
           1.6341969498542561,
           1.6054587332905317,
           1.5764442916380859,
           1.5471669485454735,
           1.5176406370980637,
           1.4878799549533224,
           1.4579002267552583,
           1.427717574881478,
           1.397348999740148,
           1.366812471023817,
           1.336127031545982,
           1.3053129155381786,
           1.2743916835737643,
           1.2433863766125206,
           1.21232169202978,
           1.1812241849049363,
           1.1501224982935292,
           1.1190476266854623,
           1.088033217341388,
           1.0571159146682865,
           1.0263357531918302,
           0.9957366049252803,
           0.9653666868970929,
           0.9352791340954949,
           0.9055326418465997,
           0.8761921792781453,
           0.8473297715019986,
           0.8190253417656588,
           0.7913675951701882,
           0.7644549115450329,
           0.738396195541054,
           0.7133116059352216,
           0.6893330531328616,
           0.6666043149125014,
           0.6452805791771662,
           0.6255271865131192,
           0.6075173277982023,
           0.5914284717398446,
           0.5774373761732325,
           0.5657136938318382,
           0.5564124213719951,
           0.5496657334453466,
           0.5455750272374141,
           0.5442041827560096,
           0.5455750272374169,
           0.5496657334453523,
           0.5564124213720033,
           0.5657136938318491,
           0.5774373761732459,
           0.5914284717398601,
           0.60751732779822,
           0.6255271865131387,
           0.6452805791771872,
           0.6666043149125241,
           0.6893330531328857,
           0.7133116059352468,
           0.7383961955410802,
           0.7644549115450601,
           0.7913675951702163,
           0.8190253417656875,
           0.847329771502028,
           0.8761921792781753,
           0.90553264184663,
           0.9352791340955255,
           0.9653666868971241,
           0.9957366049253115,
           1.0263357531918618,
           1.0571159146683182,
           1.0880332173414198,
           1.1190476266854943,
           1.1501224982935612,
           1.1812241849049683,
           1.2123216920298119,
           1.2433863766125524,
           1.2743916835737958,
           1.3053129155382104,
           1.3361270315460136,
           1.3668124710238487,
           1.3973489997401796,
           1.4277175748815092,
           1.4579002267552894,
           1.487879954953353,
           1.5176406370980942,
           1.5471669485455037,
           1.576444291638116,
           1.6054587332905614,
           1.6341969498542854,
           1.662646178349333,
           1.6907941732729204,
           1.7186291682994241,
           1.7461398422767804,
           1.7733152890021284,
           1.8001449903266074,
           1.8266187921970878,
           1.8527268832925456,
           1.8784597759559498,
           1.90380828915985,
           1.9287635332761965,
           1.953316896448932,
           1.97746003239226,
           2.0011848494586433,
           2.024483500839018,
           2.047348375773776,
           2.069772091667112,
           2.0917474870095685,
           2.1132676150244056,
           2.134325737962801,
           2.1549153219811963,
           2.1750300325413687,
           2.1946637302802365,
           2.21381046730205,
           2.2324644838506336,
           2.250620205323762,
           2.268272239595675,
           2.2854153746172132,
           2.3020445762661508,
           2.318154986423042,
           2.3337419212503767,
           2.348800869654978,
           2.3633274919156024,
           2.37731761845938,
           2.390767248772348,
           2.40367255043074,
           2.416029858240926,
           2.4278356734770834,
           2.439086663206672,
           2.449779659694755,
           2.4599116598790096,
           2.4694798249080674,
           2.4784814797365113,
           2.4869141127704846,
           2.4947753755584547,
           2.50206308252219,
           2.508775210723522,
           2.5149098996628805,
           2.5204654511060265,
           2.5254403289357885,
           2.5298331590259573,
           2.5336427291348307,
           2.5368679888162275,
           2.5395080493460647,
           2.541562183662888,
           2.543029826321017,
           2.5439105734552085
          ],
          [
           2.5178496248983073,
           2.517558005710538,
           2.5166832276371602,
           2.515225529151207,
           2.513185307718656,
           2.5105631198151914,
           2.507359680950455,
           2.503575865700543,
           2.49921270774978,
           2.4942713999430106,
           2.488753294349921,
           2.482659902343147,
           2.4759928946922214,
           2.4687541016756893,
           2.4609455132140394,
           2.4525692790264384,
           2.443627708814605,
           2.4341232724775552,
           2.4240586003613633,
           2.4134364835485407,
           2.402259874192138,
           2.3905318859002045,
           2.3782557941768467,
           2.3654350369267685,
           2.3520732150309063,
           2.3381740930015473,
           2.3237415997262123,
           2.3087798293105424,
           2.293293042031498,
           2.277285665413396,
           2.260762295440604,
           2.2437276979222256,
           2.226186810025738,
           2.2081447419984097,
           2.1896067790973817,
           2.170578383751627,
           2.151065197981603,
           2.1310730461053584,
           2.110607937763134,
           2.08967607129626,
           2.0682838375203354,
           2.046437823937468,
           2.0241448194377307,
           2.0014118195461585,
           1.978246032278561,
           1.9546548846773701,
           1.9306460301078228,
           1.906227356405099,
           1.881406994974894,
           1.8561933309634568,
           1.8305950146287124,
           1.804620974061955,
           1.7782804294302412,
           1.7515829089333326,
           1.7245382666965212,
           1.697156702852367,
           1.6694487861011824,
           1.641425479082723,
           1.6130981669411042,
           1.584478689522587,
           1.5555793777129787,
           1.5264130944996412,
           1.4969932814343714,
           1.4673340112800046,
           1.4374500477481111,
           1.4073569133806059,
           1.3770709667980068,
           1.3466094907353843,
           1.315990792518169,
           1.285234318898796,
           1.2543607874867795,
           1.2233923373644102,
           1.1923527018925615,
           1.1612674071796487,
           1.1301640002126287,
           1.099072311228743,
           1.068024755529675,
           1.0370566805830852,
           1.0062067648784168,
           0.9755174755339293,
           0.945035591976432,
           0.9148128029570904,
           0.8849063834579849,
           0.8553799562895695,
           0.8263043398113048,
           0.797758477436201,
           0.7698304353450692,
           0.7426184407887607,
           0.716231912907616,
           0.6907924095135087,
           0.6664343755429825,
           0.6433055319754889,
           0.6215666907373535,
           0.6013907290853966,
           0.5829604208603095,
           0.5664648249908265,
           0.5520940037997788,
           0.540032014490757,
           0.5304484000483831,
           0.5234887767064987,
           0.5192654961487824,
           0.5178496248983072,
           0.5192654961487854,
           0.5234887767065046,
           0.5304484000483916,
           0.5400320144907682,
           0.5520940037997925,
           0.5664648249908422,
           0.5829604208603275,
           0.6013907290854165,
           0.621566690737375,
           0.643305531975512,
           0.666434375543007,
           0.6907924095135344,
           0.7162319129076425,
           0.7426184407887881,
           0.7698304353450977,
           0.7977584774362301,
           0.8263043398113344,
           0.8553799562895995,
           0.8849063834580154,
           0.9148128029571212,
           0.9450355919764633,
           0.9755174755339608,
           1.0062067648784483,
           1.037056680583117,
           1.0680247555297067,
           1.099072311228775,
           1.1301640002126607,
           1.1612674071796807,
           1.1923527018925935,
           1.2233923373644422,
           1.2543607874868115,
           1.2852343188988278,
           1.3159907925182008,
           1.3466094907354158,
           1.3770709667980379,
           1.4073569133806367,
           1.437450047748142,
           1.4673340112800348,
           1.4969932814344016,
           1.5264130944996717,
           1.5555793777130087,
           1.5844786895226164,
           1.6130981669411333,
           1.6414254790827516,
           1.6694487861012115,
           1.6971567028523955,
           1.7245382666965494,
           1.75158290893336,
           1.778280429430268,
           1.804620974061982,
           1.8305950146287386,
           1.8561933309634826,
           1.8814069949749195,
           1.9062273564051246,
           1.9306460301078479,
           1.9546548846773948,
           1.978246032278585,
           2.001411819546182,
           2.0241448194377534,
           2.0464378239374907,
           2.0682838375203576,
           2.0896760712962816,
           2.1106079377631555,
           2.1310730461053797,
           2.151065197981623,
           2.1705783837516464,
           2.189606779097401,
           2.208144741998429,
           2.2261868100257565,
           2.243727697922243,
           2.2607622954406215,
           2.2772856654134124,
           2.293293042031514,
           2.308779829310558,
           2.323741599726228,
           2.338174093001562,
           2.35207321503092,
           2.365435036926782,
           2.3782557941768596,
           2.390531885900217,
           2.4022598741921497,
           2.4134364835485522,
           2.424058600361374,
           2.434123272477566,
           2.4436277088146143,
           2.4525692790264473,
           2.4609455132140483,
           2.4687541016756978,
           2.4759928946922285,
           2.4826599023431535,
           2.4887532943499266,
           2.494271399943016,
           2.4992127077497845,
           2.503575865700547,
           2.507359680950459,
           2.510563119815194,
           2.5131853077186577,
           2.515225529151209,
           2.5166832276371616,
           2.517558005710539
          ],
          [
           2.4909940809733033,
           2.4907045330518467,
           2.4898359674878137,
           2.488388618883895,
           2.4863628782502745,
           2.48375929301353,
           2.480578567029813,
           2.4768215606030264,
           2.472489290508925,
           2.4675829300263272,
           2.462103808976792,
           2.4560534137744283,
           2.449433387487711,
           2.4422455299154695,
           2.434491797679506,
           2.4261743043366004,
           2.4172953205130017,
           2.407857274064854,
           2.397862750268413,
           2.387314492044307,
           2.3762154002205875,
           2.3645685338397806,
           2.3523771105157505,
           2.3396445068467506,
           2.3263742588917355,
           2.3125700627177266,
           2.298235775026857,
           2.2833754138726157,
           2.2679931594758083,
           2.252093355151895,
           2.2356805083625684,
           2.2187592919058625,
           2.201334545260605,
           2.1834112761027664,
           2.1649946620132146,
           2.1460900523985496,
           2.1267029706491565,
           2.106839116561377,
           2.086504369053814,
           2.065704789211308,
           2.044446623694109,
           2.022736308554271,
           2.0005804735064467,
           1.9779859467060428,
           1.9549597600943882,
           1.9315091553780674,
           1.9076415907182749,
           1.8833647482158984,
           1.8586865422893897,
           1.833615129055509,
           1.8081589168379832,
           1.7823265779463917,
           1.7561270618874802,
           1.729569610194142,
           1.7026637730839491,
           1.6754194281900439,
           1.647846801643135,
           1.6199564918251654,
           1.591759496163979,
           1.5632672413952544,
           1.5344916177845498,
           1.5054450178802827,
           1.476140380459891,
           1.4465912404387606,
           1.4168117856376277,
           1.3868169214524535,
           1.356622344645259,
           1.3262446276796367,
           1.2957013152660226,
           1.2650110350653456,
           1.2341936248321035,
           1.2032702786666434,
           1.1722637154989892,
           1.1411983734503635,
           1.1101006343196451,
           1.0789990831235765,
           1.0479248083791841,
           1.0169117496423905,
           0.9859970996796316,
           0.9552217694945979,
           0.9246309251639879,
           0.8942746058953791,
           0.8642084326538679,
           0.834494415721298,
           0.8052018670667613,
           0.7764084185663972,
           0.7482011387131424,
           0.7206777268835503,
           0.6939477434236265,
           0.6681338034071571,
           0.6433726196239726,
           0.6198157248866877,
           0.5976296365120494,
           0.5769951536308704,
           0.5581054165001744,
           0.5411623340432717,
           0.5263710415322794,
           0.5139322296313581,
           0.504032519192909,
           0.49683352745046633,
           0.49246078831703244,
           0.49099408097330355,
           0.49246078831703544,
           0.49683352745047227,
           0.5040325191929179,
           0.5139322296313696,
           0.5263710415322934,
           0.5411623340432881,
           0.5581054165001929,
           0.5769951536308908,
           0.5976296365120715,
           0.6198157248867111,
           0.6433726196239977,
           0.6681338034071831,
           0.6939477434236535,
           0.7206777268835781,
           0.748201138713171,
           0.7764084185664264,
           0.8052018670667912,
           0.8344944157213283,
           0.8642084326538987,
           0.8942746058954101,
           0.9246309251640193,
           0.9552217694946296,
           0.9859970996796632,
           1.0169117496424225,
           1.0479248083792159,
           1.0789990831236083,
           1.1101006343196769,
           1.1411983734503954,
           1.172263715499021,
           1.2032702786666751,
           1.2341936248321355,
           1.2650110350653774,
           1.2957013152660541,
           1.3262446276796678,
           1.35662234464529,
           1.3868169214524844,
           1.4168117856376585,
           1.4465912404387913,
           1.476140380459921,
           1.505445017880313,
           1.5344916177845798,
           1.5632672413952835,
           1.5917594961640082,
           1.619956491825194,
           1.6478468016431636,
           1.675419428190072,
           1.7026637730839769,
           1.7295696101941695,
           1.7561270618875076,
           1.7823265779464186,
           1.8081589168380097,
           1.8336151290555347,
           1.8586865422894154,
           1.8833647482159237,
           1.9076415907182998,
           1.9315091553780916,
           1.954959760094412,
           1.9779859467060663,
           2.0005804735064694,
           2.022736308554294,
           2.0444466236941308,
           2.06570478921133,
           2.086504369053835,
           2.106839116561398,
           2.126702970649177,
           2.146090052398569,
           2.1649946620132337,
           2.1834112761027846,
           2.201334545260623,
           2.2187592919058807,
           2.235680508362585,
           2.252093355151912,
           2.2679931594758247,
           2.2833754138726308,
           2.298235775026872,
           2.3125700627177403,
           2.3263742588917493,
           2.3396445068467644,
           2.3523771105157634,
           2.3645685338397926,
           2.376215400220599,
           2.387314492044318,
           2.3978627502684233,
           2.407857274064864,
           2.4172953205130105,
           2.4261743043366093,
           2.4344917976795144,
           2.442245529915477,
           2.4494333874877174,
           2.456053413774435,
           2.4621038089767975,
           2.467582930026333,
           2.47248929050893,
           2.4768215606030304,
           2.480578567029817,
           2.4837592930135326,
           2.4863628782502762,
           2.488388618883897,
           2.489835967487814,
           2.4907045330518476
          ],
          [
           2.463663531985308,
           2.4633761383305512,
           2.462514034268815,
           2.461077450507829,
           2.459066771560991,
           2.4564825357484668,
           2.453325435199379,
           2.449596315855766,
           2.4452961774791464,
           2.4404261736607777,
           2.4349876118368723,
           2.428981953310281,
           2.422410813280382,
           2.4152759608831538,
           2.407579319243706,
           2.3993229655437913,
           2.390509131107149,
           2.3811402015058576,
           2.3712187166912466,
           2.3607473711532667,
           2.3497290141127,
           2.3381666497510083,
           2.3260634374831586,
           2.3134226922793153,
           2.3002478850418973,
           2.2865426430452076,
           2.2723107504455733,
           2.2575561488707776,
           2.2422829380985116,
           2.226495376834589,
           2.2101978836028215,
           2.193395037759771,
           2.176091580648991,
           2.1582924169110154,
           2.140002615967158,
           2.1212274136972082,
           2.10197221433342,
           2.0822425925957506,
           2.0620442960962446,
           2.0413832480437333,
           2.020265550283779,
           1.998697486713019,
           1.9766855271118742,
           1.9542363314451061,
           1.9313567546859258,
           1.9080538522265176,
           1.8843348859460372,
           1.86020733101649,
           1.8356788835376827,
           1.8107574691048294,
           1.7854512524266541,
           1.759768648128344,
           1.733718332892757,
           1.7073092591154113,
           1.6805506702744417,
           1.65345211824658,
           1.6260234828350155,
           1.5982749938156504,
           1.5702172558558074,
           1.5418612767151987,
           1.5132184992044047,
           1.4843008374530908,
           1.455120718130901,
           1.425691127370973,
           1.3960256642725086,
           1.3661386020084612,
           1.336044957741627,
           1.305760572762516,
           1.2753022045114564,
           1.2446876324427547,
           1.2139357800387085,
           1.1830668556953938,
           1.1521025156910212,
           1.121066053022605,
           1.089982616569239,
           1.0588794658207603,
           1.0277862673062033,
           0.9967354398674017,
           0.9657625570369296,
           0.9349068159615782,
           0.9042115834911286,
           0.873725031096367,
           0.8435008709659574,
           0.8135992055923523,
           0.7840875018134352,
           0.7550416967431254,
           0.7265474359885522,
           0.698701432142091,
           0.6716129112125211,
           0.6454050832071881,
           0.6202165268842551,
           0.5962023145949414,
           0.5735346202617746,
           0.5524024566683953,
           0.5330100928437123,
           0.515573640454186,
           0.5003153218623142,
           0.4874551084274461,
           0.47719980336259293,
           0.469730242539843,
           0.4651879951493533,
           0.46366353198530824,
           0.46518799514935644,
           0.4697302425398492,
           0.4771998033626021,
           0.48745510842745804,
           0.5003153218623287,
           0.5155736404542027,
           0.5330100928437312,
           0.5524024566684161,
           0.5735346202617971,
           0.5962023145949655,
           0.6202165268842804,
           0.6454050832072145,
           0.6716129112125484,
           0.6987014321421191,
           0.7265474359885811,
           0.755041696743155,
           0.7840875018134652,
           0.8135992055923831,
           0.8435008709659882,
           0.8737250310963981,
           0.90421158349116,
           0.93490681596161,
           0.9657625570369611,
           0.9967354398674334,
           1.027786267306235,
           1.058879465820792,
           1.089982616569271,
           1.121066053022637,
           1.152102515691053,
           1.1830668556954256,
           1.2139357800387403,
           1.2446876324427862,
           1.275302204511488,
           1.3057605727625472,
           1.336044957741658,
           1.3661386020084918,
           1.396025664272539,
           1.4256911273710031,
           1.4551207181309311,
           1.4843008374531212,
           1.5132184992044342,
           1.541861276715228,
           1.5702172558558363,
           1.598274993815679,
           1.626023482835044,
           1.6534521182466082,
           1.6805506702744692,
           1.7073092591154384,
           1.7337183328927839,
           1.7597686481283707,
           1.7854512524266803,
           1.810757469104855,
           1.835678883537708,
           1.860207331016515,
           1.884334885946062,
           1.9080538522265418,
           1.9313567546859496,
           1.9542363314451296,
           1.9766855271118966,
           1.9986974867130414,
           2.0202655502838014,
           2.0413832480437546,
           2.062044296096265,
           2.082242592595771,
           2.10197221433344,
           2.121227413697228,
           2.1400026159671772,
           2.1582924169110345,
           2.1760915806490093,
           2.1933950377597884,
           2.210197883602838,
           2.226495376834605,
           2.242282938098528,
           2.2575561488707927,
           2.272310750445588,
           2.2865426430452223,
           2.300247885041911,
           2.3134226922793286,
           2.3260634374831715,
           2.33816664975102,
           2.3497290141127114,
           2.360747371153278,
           2.3712187166912573,
           2.3811402015058674,
           2.390509131107158,
           2.3993229655438006,
           2.4075793192437134,
           2.415275960883161,
           2.4224108132803885,
           2.428981953310288,
           2.4349876118368785,
           2.440426173660783,
           2.4452961774791513,
           2.44959631585577,
           2.453325435199383,
           2.4564825357484694,
           2.4590667715609937,
           2.46107745050783,
           2.4625140342688154,
           2.4633761383305517
          ],
          [
           2.4358844184753514,
           2.435599263986433,
           2.4347438761194473,
           2.4333184816723055,
           2.431323458636922,
           2.428759336192618,
           2.425626794697468,
           2.4219266656782192,
           2.417659931819549,
           2.4128277269536382,
           2.407431336051226,
           2.4014721952155136,
           2.3949518916805084,
           2.387872163815602,
           2.3802349011384667,
           2.372042144338554,
           2.363296085313821,
           2.3539990672235573,
           2.344153584560559,
           2.3337622832462173,
           2.322827960752503,
           2.311353566255246,
           2.2993422008235624,
           2.2867971176508317,
           2.2737217223331423,
           2.260119573201802,
           2.245994381717171,
           2.2313500129318387,
           2.216190486032064,
           2.2005199749672912,
           2.1843428091786627,
           2.1676634744386094,
           2.1504866138149454,
           2.1328170287743644,
           2.1146596804419198,
           2.096019691034949,
           2.0769023454920155,
           2.057313093319837,
           2.037257550683876,
           2.01674150277132,
           1.995770906458648,
           1.9743518933199498,
           1.95249077301661,
           1.9301940371141257,
           1.9074683633776528,
           1.8843206206045573,
           1.8607578740599355,
           1.8367873915898472,
           1.8124166504971428,
           1.7876533452764485,
           1.7625053963183368,
           1.7369809597083363,
           1.7110884382645082,
           1.6848364939783531,
           1.6582340620482736,
           1.6312903667233802,
           1.6040149392087995,
           1.5764176379227466,
           1.548508671441534,
           1.5202986245226806,
           1.4917984876599395,
           1.4630196906992674,
           1.4339741411337348,
           1.404674267800933,
           1.3751330708318084,
           1.3453641788491033,
           1.315381914591467,
           1.2852013703516796,
           1.2548384948712126,
           1.224310193636926,
           1.1936344448889258,
           1.1628304340831588,
           1.1319187100717574,
           1.1009213668839049,
           1.0698622557271786,
           1.0387672327020465,
           1.0076644487480277,
           0.9765846895333633,
           0.9455617743671828,
           0.9146330247440355,
           0.8838398147853079,
           0.853228217528545,
           0.8228497625557016,
           0.792762321526732,
           0.7630311382579315,
           0.733730018181718,
           0.7049426869769839,
           0.6767643177967729,
           0.6493032078429702,
           0.622682553936221,
           0.597042228026931,
           0.5725403816668249,
           0.5493546090498588,
           0.5276822723143895,
           0.5077394533787666,
           0.48975787822788,
           0.47397912749168836,
           0.4606455968772346,
           0.4499881033900563,
           0.4422107915230523,
           0.43747497266625884,
           0.4358844184753516,
           0.4374749726662622,
           0.4422107915230588,
           0.4499881033900658,
           0.46064559687724704,
           0.4739791274917034,
           0.4897578782278973,
           0.5077394533787861,
           0.5276822723144109,
           0.549354609049882,
           0.5725403816668494,
           0.5970422280269568,
           0.6226825539362479,
           0.6493032078429981,
           0.6767643177968016,
           0.7049426869770133,
           0.7337300181817478,
           0.763031138257962,
           0.7927623215267627,
           0.8228497625557327,
           0.8532282175285762,
           0.8838398147853395,
           0.9146330247440673,
           0.9455617743672147,
           0.9765846895333953,
           1.00766444874806,
           1.0387672327020787,
           1.0698622557272106,
           1.1009213668839368,
           1.1319187100717891,
           1.1628304340831905,
           1.1936344448889578,
           1.2243101936369576,
           1.254838494871244,
           1.2852013703517107,
           1.3153819145914978,
           1.345364178849134,
           1.375133070831839,
           1.4046742678009634,
           1.4339741411337648,
           1.4630196906992972,
           1.491798487659969,
           1.5202986245227097,
           1.548508671441563,
           1.576417637922775,
           1.6040149392088277,
           1.6312903667234082,
           1.658234062048301,
           1.68483649397838,
           1.7110884382645353,
           1.736980959708363,
           1.7625053963183628,
           1.7876533452764742,
           1.8124166504971682,
           1.8367873915898718,
           1.8607578740599597,
           1.8843206206045808,
           1.9074683633776761,
           1.9301940371141488,
           1.9524907730166323,
           1.9743518933199717,
           1.9957709064586697,
           2.0167415027713416,
           2.0372575506838975,
           2.0573130933198573,
           2.076902345492035,
           2.0960196910349684,
           2.114659680441939,
           2.132817028774383,
           2.1504866138149636,
           2.167663474438627,
           2.1843428091786796,
           2.200519974967308,
           2.21619048603208,
           2.2313500129318533,
           2.245994381717185,
           2.2601195732018167,
           2.273721722333156,
           2.2867971176508446,
           2.299342200823575,
           2.3113535662552573,
           2.3228279607525146,
           2.333762283246228,
           2.3441535845605697,
           2.353999067223567,
           2.3632960853138303,
           2.372042144338563,
           2.3802349011384747,
           2.3878721638156097,
           2.394951891680515,
           2.4014721952155202,
           2.407431336051231,
           2.412827726953643,
           2.417659931819554,
           2.4219266656782237,
           2.4256267946974717,
           2.428759336192621,
           2.431323458636925,
           2.4333184816723064,
           2.4347438761194478,
           2.435599263986433
          ],
          [
           2.4076836149416687,
           2.407400786465547,
           2.4065523753326272,
           2.4051386044263503,
           2.403159845209497,
           2.400616617710043,
           2.3975095905018775,
           2.3938395806809614,
           2.389607553837598,
           2.384814624025728,
           2.379462053730274,
           2.3735512538337855,
           2.3670837835838103,
           2.360061350562627,
           2.352485810661194,
           2.3443591680594213,
           2.335683575215078,
           2.3264613328639934,
           2.3166948900344293,
           2.3063868440788897,
           2.295539940726942,
           2.28415707416303,
           2.2722412871336792,
           2.2597957710889585,
           2.2468238663635822,
           2.233329062403588,
           2.2193149980451876,
           2.204785461853048,
           2.189744392526068,
           2.174195879379569,
           2.1581441629137816,
           2.1415936354795964,
           2.1245488420537653,
           2.1070144811370795,
           2.088995405790594,
           2.070496624826683,
           2.0515233041736436,
           2.032080768434768,
           2.0121745026652667,
           1.9918101543932554,
           1.9709935359141866,
           1.9497306268917607,
           1.928027577302463,
           1.9058907107656167,
           1.8833265283062337,
           1.8603417126041346,
           1.8369431327899108,
           1.8131378498564954,
           1.788933122764502,
           1.7643364153303995,
           1.7393554039991617,
           1.7139979866176496,
           1.688272292341943,
           1.6621866928316118,
           1.6357498149069771,
           1.6089705548724107,
           1.5818580947403473,
           1.554421920627869,
           1.5266718436415139,
           1.4986180236176398,
           1.4702709961468692,
           1.441641703383659,
           1.412741529228317,
           1.383582339571532,
           1.354176528414228,
           1.3245370708224453,
           1.2946775838531241,
           1.2646123967984186,
           1.2343566323510782,
           1.2039263006008534,
           1.1733384081430804,
           1.142611085029209,
           1.111763732831466,
           1.080817197749507,
           1.0497939734785577,
           1.0187184395121867,
           0.9876171416971087,
           0.9565191232220408,
           0.9254563158350141,
           0.8944640029624126,
           0.8635813685469649,
           0.8328521477896366,
           0.8023253984576852,
           0.7720564137670443,
           0.7421077996080876,
           0.7125507392607048,
           0.6834664663948098,
           0.6549479599084291,
           0.6271018586569348,
           0.600050565406803,
           0.5739344605218766,
           0.5489140683278052,
           0.5251719038405442,
           0.5029135693066624,
           0.4823674755989215,
           0.46378236598861367,
           0.4474216963054832,
           0.43355400808105604,
           0.42243888676180524,
           0.41430904447208855,
           0.40935042796552285,
           0.4076836149416689,
           0.4093504279655262,
           0.4143090444720953,
           0.4224388867618152,
           0.433554008081069,
           0.44742169630549883,
           0.4637823659886316,
           0.48236747559894166,
           0.5029135693066845,
           0.5251719038405679,
           0.5489140683278303,
           0.5739344605219029,
           0.6000505654068302,
           0.627101858656963,
           0.654947959908458,
           0.6834664663948394,
           0.7125507392607348,
           0.7421077996081182,
           0.7720564137670751,
           0.8023253984577166,
           0.8328521477896679,
           0.8635813685469964,
           0.8944640029624443,
           0.9254563158350461,
           0.9565191232220728,
           0.9876171416971407,
           1.0187184395122186,
           1.0497939734785895,
           1.0808171977495387,
           1.1117637328314978,
           1.1426110850292406,
           1.173338408143112,
           1.2039263006008847,
           1.2343566323511095,
           1.26461239679845,
           1.2946775838531548,
           1.324537070822476,
           1.3541765284142584,
           1.3835823395715618,
           1.412741529228347,
           1.4416417033836888,
           1.4702709961468987,
           1.498618023617669,
           1.5266718436415427,
           1.5544219206278977,
           1.5818580947403753,
           1.6089705548724382,
           1.6357498149070044,
           1.6621866928316387,
           1.6882722923419697,
           1.713997986617676,
           1.7393554039991876,
           1.764336415330425,
           1.788933122764527,
           1.81313784985652,
           1.836943132789935,
           1.8603417126041581,
           1.883326528306257,
           1.9058907107656393,
           1.9280275773024853,
           1.9497306268917831,
           1.9709935359142083,
           1.9918101543932765,
           2.0121745026652875,
           2.0320807684347884,
           2.0515233041736636,
           2.0704966248267023,
           2.088995405790613,
           2.1070144811370977,
           2.124548842053783,
           2.1415936354796137,
           2.158144162913798,
           2.1741958793795857,
           2.1897443925260838,
           2.2047854618530627,
           2.2193149980452023,
           2.233329062403602,
           2.246823866363596,
           2.259795771088972,
           2.2722412871336912,
           2.2841570741630415,
           2.2955399407269534,
           2.3063868440789004,
           2.316694890034439,
           2.326461332864003,
           2.3356835752150875,
           2.3443591680594302,
           2.3524858106612023,
           2.360061350562634,
           2.3670837835838174,
           2.373551253833792,
           2.3794620537302795,
           2.3848146240257333,
           2.3896075538376027,
           2.393839580680966,
           2.397509590501882,
           2.400616617710046,
           2.4031598452094998,
           2.4051386044263516,
           2.4065523753326286,
           2.407400786465547
          ],
          [
           2.379088403840359,
           2.378807990217782,
           2.3779668223431627,
           2.3765651191914614,
           2.3746032457064574,
           2.372081712779245,
           2.3690011772186144,
           2.365362441713807,
           2.361166454790265,
           2.3564143107591686,
           2.3511072496616934,
           2.3452466572091,
           2.3388340647199244,
           2.3318711490557402,
           2.3243597325571397,
           2.3163017829818164,
           2.307699413446834,
           2.2985548823774185,
           2.28887059346489,
           2.2786490956366197,
           2.267893083041222,
           2.256605395052538,
           2.244789016296344,
           2.2324470767041373,
           2.2195828515988123,
           2.206199761817543,
           2.192301373877774,
           2.177891400192819,
           2.162973699344287,
           2.1475522764193347,
           2.131631283421593,
           2.115215019765617,
           2.098307932865777,
           2.0809146188317427,
           2.0630398232840927,
           2.0446884423051332,
           2.0258655235417526,
           2.0065762674791445,
           1.9868260289064492,
           1.966620318597931,
           1.945964805236208,
           1.924865317607326,
           1.9033278471012725,
           1.881358550555786,
           1.8589637534862873,
           1.8361499537503876,
           1.8129238257019435,
           1.789292224897132,
           1.76526219342365,
           1.7408409659341881,
           1.7160359764769069,
           1.6908548662291516,
           1.6653054922563537,
           1.6393959374364016,
           1.613134521711232,
           1.586529814852555,
           1.5595906509582265,
           1.5323261449306507,
           1.5047457112298037,
           1.4768590852422887,
           1.4486763476657936,
           1.4202079523773496,
           1.3914647583362032,
           1.3624580661707308,
           1.3331996602172238,
           1.303701856920806,
           1.27397756068059,
           1.2440403284290256,
           1.2139044444873752,
           1.18358500754547,
           1.1530980319867874,
           1.122460566234857,
           1.091690831352905,
           1.0608083838086655,
           1.029834307148498,
           0.9987914383431054,
           0.9677046358109918,
           0.9366010976410148,
           0.9055107403719844,
           0.8744666508959403,
           0.8435056266757504,
           0.8126688225271431,
           0.7820025256789703,
           0.7515590845605936,
           0.7213980204525156,
           0.6915873541289014,
           0.6622051807175285,
           0.6333415230985431,
           0.6051004837341832,
           0.5776026912329583,
           0.5509879926671949,
           0.5254182636739153,
           0.5010800806889836,
           0.4781868086711063,
           0.4569793983798226,
           0.4377248834036149,
           0.42071130138394697,
           0.40623770959162353,
           0.3945983850149023,
           0.38606144983546276,
           0.3808440584936737,
           0.37908840384035897,
           0.3808440584936773,
           0.38606144983546997,
           0.3945983850149127,
           0.406237709591637,
           0.4207113013839632,
           0.43772488340363347,
           0.45697939837984336,
           0.47818680867112895,
           0.5010800806890079,
           0.5254182636739408,
           0.5509879926672218,
           0.5776026912329861,
           0.605100483734212,
           0.6333415230985723,
           0.6622051807175584,
           0.6915873541289317,
           0.7213980204525465,
           0.7515590845606248,
           0.7820025256790017,
           0.8126688225271745,
           0.843505626675782,
           0.8744666508959722,
           0.9055107403720164,
           0.9366010976410469,
           0.9677046358110236,
           0.9987914383431373,
           1.0298343071485299,
           1.0608083838086972,
           1.0916908313529368,
           1.1224605662348883,
           1.153098031986819,
           1.1835850075455012,
           1.2139044444874063,
           1.2440403284290564,
           1.273977560680621,
           1.3037018569208367,
           1.333199660217254,
           1.3624580661707606,
           1.3914647583362327,
           1.4202079523773792,
           1.4486763476658229,
           1.4768590852423176,
           1.5047457112298321,
           1.532326144930679,
           1.5595906509582547,
           1.5865298148525824,
           1.613134521711259,
           1.6393959374364284,
           1.6653054922563801,
           1.6908548662291776,
           1.7160359764769326,
           1.7408409659342137,
           1.765262193423675,
           1.7892922248971566,
           1.812923825701968,
           1.836149953750411,
           1.8589637534863102,
           1.8813585505558086,
           1.9033278471012944,
           1.924865317607348,
           1.9459648052362293,
           1.966620318597952,
           1.9868260289064696,
           2.006576267479165,
           2.0258655235417726,
           2.0446884423051523,
           2.0630398232841114,
           2.080914618831761,
           2.098307932865795,
           2.115215019765634,
           2.1316312834216093,
           2.147552276419351,
           2.1629736993443034,
           2.177891400192834,
           2.192301373877789,
           2.206199761817557,
           2.2195828515988256,
           2.23244707670415,
           2.244789016296356,
           2.2566053950525498,
           2.2678930830412334,
           2.2786490956366303,
           2.2888705934648996,
           2.2985548823774278,
           2.307699413446843,
           2.3163017829818253,
           2.324359732557147,
           2.3318711490557478,
           2.3388340647199315,
           2.345246657209106,
           2.3511072496616987,
           2.356414310759173,
           2.3611664547902698,
           2.3653624417138115,
           2.369001177218618,
           2.3720817127792477,
           2.37460324570646,
           2.3765651191914627,
           2.377966822343163,
           2.378807990217783
          ],
          [
           2.35012644919137,
           2.3498485412991577,
           2.349014889318964,
           2.347625708334343,
           2.3456813567986816,
           2.343182336506617,
           2.340129292554432,
           2.3365230132898795,
           2.3323644302519804,
           2.3276546181014863,
           2.3223947945428463,
           2.316586320238635,
           2.3102306987175925,
           2.303329576277537,
           2.2958847418846404,
           2.2878981270707017,
           2.279371805830266,
           2.270307994519659,
           2.260709051760232,
           2.2505774783483754,
           2.2399159171751277,
           2.228727153158522,
           2.217014113192141,
           2.204779866113724,
           2.192027622698079,
           2.1787607356789906,
           2.1649826998053396,
           2.1506971519371807,
           2.1359078711881563,
           2.1206187791213242,
           2.104833940006216,
           2.0885575611458522,
           2.071793993283371,
           2.054547731099037,
           2.036823413809618,
           2.0186258258835,
           1.9999598978864748,
           1.9808307074749045,
           1.9612434805549648,
           1.9412035926289626,
           1.9207165703523,
           1.8997880933276248,
           1.8784239961660834,
           1.8566302708494462,
           1.8344130694313334,
           1.8117787071208415,
           1.7887336657977497,
           1.7652845980152594,
           1.7414383315540456,
           1.71720187460048,
           1.6925824216324312,
           1.6675873601083224,
           1.6422242780694565,
           1.61650097278239,
           1.590425460567786,
           1.5640059879853068,
           1.5372510445713423,
           1.5101693773586011,
           1.4827700074447365,
           1.4550622489225653,
           1.4270557305384883,
           1.3987604205103359,
           1.3701866550133093,
           1.341345170935804,
           1.312247143619152,
           1.2829042304311244,
           1.2533286211877208,
           1.2235330966382105,
           1.1935310964729633,
           1.1633367986129806,
           1.132965211907518,
           1.102432284818468,
           1.0717550332282764,
           1.0409516911983174,
           1.0100418893597738,
           0.9790468666799069,
           0.9479897226635456,
           0.9168957186838492,
           0.8857926391609461,
           0.8547112258061387,
           0.8236857012150184,
           0.7927544018153876,
           0.7619605446236938,
           0.7313531574427795,
           0.7009882079124414,
           0.6709299727976419,
           0.6412526941530529,
           0.6120425717166029,
           0.5834001376905206,
           0.5554430450685289,
           0.5283092640635748,
           0.5021606076669815,
           0.47718637495532557,
           0.45360668216808464,
           0.4316747224229887,
           0.41167675637674606,
           0.39392816032314487,
           0.3787635541855669,
           0.366519291688535,
           0.35750791231804374,
           0.35198677612435086,
           0.3501264491913699,
           0.35198677612435475,
           0.3575079123180513,
           0.3665192916885459,
           0.37876355418558105,
           0.39392816032316197,
           0.41167675637676543,
           0.43167472242301025,
           0.4536066821681082,
           0.4771863749553505,
           0.5021606076670078,
           0.5283092640636023,
           0.5554430450685572,
           0.5834001376905495,
           0.6120425717166326,
           0.641252694153083,
           0.6709299727976725,
           0.7009882079124725,
           0.7313531574428109,
           0.7619605446237254,
           0.7927544018154192,
           0.8236857012150502,
           0.8547112258061706,
           0.8857926391609781,
           0.9168957186838813,
           0.9479897226635775,
           0.979046866679939,
           1.0100418893598058,
           1.040951691198349,
           1.071755033228308,
           1.1024322848184995,
           1.1329652119075493,
           1.1633367986130119,
           1.1935310964729942,
           1.2235330966382414,
           1.2533286211877515,
           1.2829042304311546,
           1.3122471436191823,
           1.3413451709358335,
           1.370186655013339,
           1.3987604205103654,
           1.4270557305385174,
           1.455062248922594,
           1.4827700074447647,
           1.510169377358629,
           1.5372510445713696,
           1.564005987985334,
           1.590425460567813,
           1.6165009727824164,
           1.6422242780694827,
           1.6675873601083484,
           1.692582421632457,
           1.717201874600505,
           1.74143833155407,
           1.7652845980152834,
           1.7887336657977733,
           1.8117787071208649,
           1.8344130694313565,
           1.8566302708494686,
           1.8784239961661056,
           1.8997880933276468,
           1.9207165703523212,
           1.9412035926289835,
           1.961243480554985,
           1.9808307074749243,
           1.9999598978864943,
           2.018625825883519,
           2.036823413809637,
           2.054547731099055,
           2.071793993283389,
           2.088557561145869,
           2.104833940006232,
           2.1206187791213402,
           2.1359078711881723,
           2.1506971519371954,
           2.1649826998053543,
           2.1787607356790044,
           2.1920276226980926,
           2.2047798661137366,
           2.2170141131921532,
           2.228727153158534,
           2.2399159171751397,
           2.250577478348386,
           2.260709051760242,
           2.2703079945196687,
           2.279371805830275,
           2.28789812707071,
           2.295884741884648,
           2.3033295762775445,
           2.3102306987175996,
           2.316586320238642,
           2.322394794542852,
           2.3276546181014917,
           2.332364430251985,
           2.336523013289884,
           2.3401292925544355,
           2.34318233650662,
           2.3456813567986843,
           2.347625708334344,
           2.349014889318965,
           2.349848541299158
          ],
          [
           2.3208257698153467,
           2.3205504606043106,
           2.319724603380472,
           2.3183484093645106,
           2.3164222305671953,
           2.313946559754027,
           2.3109220303961,
           2.3073494166075657,
           2.303229633070187,
           2.298563734945566,
           2.293352917775792,
           2.2875985173733313,
           2.281302009701162,
           2.274465010744259,
           2.2670892763737114,
           2.259176702204905,
           2.2507293234513703,
           2.241749314776103,
           2.2322389901423496,
           2.222200802666076,
           2.2116373444725888,
           2.200551346560039,
           2.188945678672824,
           2.17682334918823,
           2.164187505020017,
           2.151041431543032,
           2.1373885525433844,
           2.123232430199173,
           2.108576765097348,
           2.093425396292827,
           2.0777823014167165,
           2.0616515968412052,
           2.0450375379095647,
           2.0279445192406347,
           2.0103770751182535,
           1.9923398799772931,
           1.9738377489993402,
           1.9548756388326103,
           1.9354586484524454,
           1.9155920201807461,
           1.8952811408849757,
           1.8745315433799763,
           1.8533489080588128,
           1.8317390647822782,
           1.8097079950606194,
           1.787261834565535,
           1.764406876015732,
           1.7411495724853054,
           1.7174965411911962,
           1.693454567824062,
           1.6690306114963032,
           1.644231810391965,
           1.6190654882160829,
           1.5935391615560761,
           1.5676605482855022,
           1.5414375771613225,
           1.5148783987904777,
           1.4879913981707817,
           1.4607852090458433,
           1.433268730355118,
           1.4054511451096579,
           1.3773419420834863,
           1.348950940781915,
           1.3202883202343336,
           1.291364652263395,
           1.262190940009389,
           1.232778662643312,
           1.2031398273914566,
           1.173287030226807,
           1.1432335268690101,
           1.1129933160889505,
           1.0825812377535575,
           1.0520130885938603,
           1.0213057593630699,
           0.9904773979082444,
           0.9595476037555775,
           0.928537661165058,
           0.8974708193205012,
           0.8663726304803927,
           0.8352713596407747,
           0.8041984826952728,
           0.7731892943845113,
           0.7422836526873205,
           0.7115268928894009,
           0.6809709524770171,
           0.6506757571730515,
           0.6207109283967516,
           0.5911578819299531,
           0.5621123938472687,
           0.5336877073252008,
           0.5060182326042485,
           0.479263834381288,
           0.45361457737784777,
           0.42929556923402823,
           0.4065711476449374,
           0.3857470645987657,
           0.3671685539627527,
           0.3512114436499713,
           0.33826333116914303,
           0.32869315917419645,
           0.3228110719999002,
           0.3208257698153465,
           0.3228110719999043,
           0.32869315917420444,
           0.33826333116915464,
           0.35121144364998635,
           0.36716855396277065,
           0.38574706459878594,
           0.4065711476449598,
           0.42929556923405243,
           0.45361457737787336,
           0.4792638343813149,
           0.5060182326042765,
           0.5336877073252296,
           0.5621123938472983,
           0.5911578819299832,
           0.6207109283967821,
           0.6506757571730823,
           0.6809709524770484,
           0.7115268928894323,
           0.7422836526873523,
           0.7731892943845431,
           0.8041984826953047,
           0.8352713596408066,
           0.8663726304804246,
           0.8974708193205331,
           0.9285376611650901,
           0.9595476037556091,
           0.990477397908276,
           1.0213057593631016,
           1.0520130885938916,
           1.0825812377535888,
           1.1129933160889818,
           1.1432335268690412,
           1.1732870302268377,
           1.2031398273914875,
           1.2327786626433426,
           1.262190940009419,
           1.291364652263425,
           1.3202883202343632,
           1.3489509407819442,
           1.3773419420835156,
           1.4054511451096867,
           1.4332687303551461,
           1.4607852090458715,
           1.4879913981708095,
           1.514878398790505,
           1.5414375771613493,
           1.5676605482855288,
           1.5935391615561023,
           1.619065488216109,
           1.6442318103919908,
           1.6690306114963285,
           1.6934545678240867,
           1.7174965411912206,
           1.7411495724853296,
           1.7644068760157559,
           1.7872618345655582,
           1.809707995060642,
           1.8317390647823009,
           1.8533489080588346,
           1.8745315433799976,
           1.8952811408849968,
           1.9155920201807668,
           1.9354586484524658,
           1.9548756388326303,
           1.9738377489993593,
           1.9923398799773115,
           2.010377075118272,
           2.0279445192406524,
           2.045037537909582,
           2.061651596841222,
           2.077782301416733,
           2.0934253962928424,
           2.1085767650973635,
           2.123232430199188,
           2.137388552543399,
           2.151041431543047,
           2.16418750502003,
           2.176823349188242,
           2.188945678672836,
           2.2005513465600504,
           2.2116373444725994,
           2.2222008026660864,
           2.23223899014236,
           2.2417493147761127,
           2.2507293234513788,
           2.259176702204913,
           2.267089276373719,
           2.274465010744266,
           2.2813020097011685,
           2.287598517373338,
           2.2933529177757976,
           2.2985637349455708,
           2.3032296330701914,
           2.3073494166075696,
           2.3109220303961036,
           2.3139465597540307,
           2.316422230567198,
           2.318348409364512,
           2.3197246033804735,
           2.320550460604311
          ],
          [
           2.2912147122272306,
           2.2909420967550034,
           2.2901243194738483,
           2.288761587781947,
           2.286854247314998,
           2.2844027819044554,
           2.281407813519393,
           2.277870102192298,
           2.273790545929216,
           2.269170180604759,
           2.264010179842595,
           2.258311854882145,
           2.2520766544323254,
           2.245306164513295,
           2.2380021082872963,
           2.2301663458798178,
           2.2218008741924504,
           2.212907826708972,
           2.2034894732963806,
           2.1935482200027523,
           2.1830866088540546,
           2.1721073176522325,
           2.1606131597771516,
           2.14860708399526,
           2.136092174278119,
           2.1230716496343143,
           2.1095488639585893,
           2.0955273059025186,
           2.081010598771428,
           2.066002500452853,
           2.050506903382349,
           2.0345278345531512,
           2.018069455576888,
           2.0011360628033716,
           1.9837320875084221,
           1.965862096159705,
           1.9475307907717547,
           1.9287430093626823,
           1.9095037265265826,
           1.8898180541373928,
           1.8696912422019023,
           1.8491286798818865,
           1.8281358967078882,
           1.8067185640101484,
           1.7848824965955632,
           1.7626336547034689,
           1.7399781462775776,
           1.7169222295966124,
           1.693472316312253,
           1.6696349749500758,
           1.6454169349373806,
           1.6208250912314177,
           1.595866509632782,
           1.570548432881989,
           1.5448782876528027,
           1.5188636925743215,
           1.4925124674356167,
           1.465832643752638,
           1.4388324769079848,
           1.4115204601110483,
           1.3839053404703416,
           1.3559961375231002,
           1.3278021646316212,
           1.299333053733782,
           1.2705987840300517,
           1.2416097153050978,
           1.2123766267239873,
           1.182910762117558,
           1.1532238829871175,
           1.123328330726003,
           1.09323709988846,
           1.0629639247525746,
           1.0325233819466881,
           1.0019310125677567,
           0.9712034680544555,
           0.9403586851383329,
           0.9094160965493756,
           0.878396885884648,
           0.8473242972731624,
           0.8162240133332669,
           0.7851246186088534,
           0.7540581704259819,
           0.723060905226409,
           0.6921741162569697,
           0.6614452484025054,
           0.6309292682874562,
           0.6006903826840755,
           0.5708041953644859,
           0.5413604102099444,
           0.5124662025002124,
           0.48425038176841045,
           0.4568684402682984,
           0.43050848725461094,
           0.4053978532096673,
           0.3818097218282178,
           0.3600684026081096,
           0.3405507248139088,
           0.3236796528690784,
           0.3099052442892084,
           0.29966892981846016,
           0.2933516242666591,
           0.29121471222723055,
           0.2933516242666635,
           0.2996689298184687,
           0.30990524428922084,
           0.3236796528690943,
           0.3405507248139276,
           0.3600684026081308,
           0.3818097218282411,
           0.40539785320969235,
           0.4305084872546374,
           0.4568684402683261,
           0.484250381768439,
           0.5124662025002417,
           0.5413604102099744,
           0.5708041953645163,
           0.6006903826841065,
           0.6309292682874875,
           0.6614452484025369,
           0.6921741162570013,
           0.7230609052264408,
           0.7540581704260138,
           0.7851246186088854,
           0.8162240133332989,
           0.8473242972731944,
           0.8783968858846798,
           0.9094160965494075,
           0.9403586851383646,
           0.9712034680544871,
           1.0019310125677883,
           1.0325233819467194,
           1.0629639247526057,
           1.0932370998884908,
           1.1233283307260336,
           1.1532238829871482,
           1.1829107621175887,
           1.2123766267240175,
           1.2416097153051278,
           1.2705987840300814,
           1.2993330537338112,
           1.3278021646316502,
           1.3559961375231293,
           1.3839053404703703,
           1.4115204601110767,
           1.4388324769080125,
           1.465832643752666,
           1.492512467435644,
           1.5188636925743486,
           1.5448782876528293,
           1.570548432882015,
           1.595866509632808,
           1.620825091231443,
           1.645416934937406,
           1.6696349749501003,
           1.693472316312277,
           1.7169222295966362,
           1.7399781462776012,
           1.7626336547034915,
           1.7848824965955858,
           1.8067185640101708,
           1.8281358967079098,
           1.8491286798819078,
           1.8696912422019234,
           1.8898180541374137,
           1.9095037265266026,
           1.928743009362702,
           1.9475307907717738,
           1.9658620961597233,
           1.9837320875084403,
           2.0011360628033894,
           2.018069455576905,
           2.034527834553168,
           2.0505069033823653,
           2.066002500452869,
           2.081010598771443,
           2.0955273059025328,
           2.1095488639586035,
           2.1230716496343276,
           2.1360921742781325,
           2.1486070839952722,
           2.160613159777164,
           2.172107317652244,
           2.1830866088540657,
           2.1935482200027625,
           2.2034894732963903,
           2.2129078267089817,
           2.2218008741924584,
           2.230166345879826,
           2.2380021082873043,
           2.245306164513303,
           2.2520766544323316,
           2.2583118548821512,
           2.2640101798426007,
           2.2691701806047644,
           2.2737905459292205,
           2.277870102192302,
           2.281407813519396,
           2.284402781904458,
           2.2868542473150004,
           2.2887615877819494,
           2.290124319473849,
           2.2909420967550043
          ],
          [
           2.2613219232128388,
           2.261052098670769,
           2.2602426929238297,
           2.2588939096002534,
           2.257006088048534,
           2.2545797032897212,
           2.2516153659508977,
           2.248113822180107,
           2.2440759535430828,
           2.2395027769022113,
           2.234395444278242,
           2.228755242695358,
           2.2225835940103136,
           2.2158820547264284,
           2.208652315793375,
           2.200896202393768,
           2.1926156737177194,
           2.1838128227266336,
           2.174489875907694,
           2.16464919302061,
           2.1542932668384065,
           2.1434247228841925,
           2.1320463191660814,
           2.1201609459126534,
           2.107771625311591,
           2.0948815112544312,
           2.0814938890906536,
           2.0676121753946917,
           2.053239917749843,
           2.0383807945534658,
           2.023038614848346,
           2.0072173181856656,
           1.9909209745255914,
           1.9741537841822072,
           1.9569200778202733,
           1.9392243165121728,
           1.921071091864393,
           1.9024651262240122,
           1.8834112729769314,
           1.863914516951047,
           1.8439799749392176,
           1.8236128963587694,
           1.802818664066457,
           1.7816027953502895,
           1.759970943122513,
           1.7379288973413303,
           1.715482586692793,
           1.692638080568719,
           1.669401591381654,
           1.6457794772638967,
           1.6217782452046139,
           1.5974045546872813,
           1.5726652218993094,
           1.5475672245970542,
           1.5221177077227868,
           1.4963239898860248,
           1.4701935708404443,
           1.4437341401099724,
           1.4169535869444219,
           1.389860011817113,
           1.3624617397155083,
           1.3347673355224845,
           1.3067856218423037,
           1.2785256996940053,
           1.2499969725787676,
           1.2212091745305476,
           1.1921724028858114,
           1.1628971566645645,
           1.1333943816490821,
           1.1036755234889934,
           1.073752590464945,
           1.0436382279253291,
           1.0133458068942793,
           0.9828895299642044,
           0.9522845583722703,
           0.9215471651700232,
           0.890694920698995,
           0.8597469182765212,
           0.8287240502009137,
           0.7976493470723883,
           0.7665483972219032,
           0.7354498680463213,
           0.7043861576648622,
           0.6733942140600785,
           0.6425165704084074,
           0.611802660440474,
           0.5813104972760597,
           0.55110882400413,
           0.5212798744398598,
           0.4919229163099149,
           0.4631587806709582,
           0.43513559558291176,
           0.40803590553031316,
           0.38208520343551944,
           0.35756150586634755,
           0.33480476664537745,
           0.3142234069395449,
           0.29629294029139064,
           0.2815391502536509,
           0.27049761004323264,
           0.26364634465734405,
           0.2613219232128388,
           0.2636463446573488,
           0.27049761004324197,
           0.28153915025366427,
           0.29629294029140757,
           0.3142234069395648,
           0.33480476664539977,
           0.35756150586637186,
           0.3820852034355455,
           0.4080359055303404,
           0.4351355955829401,
           0.4631587806709874,
           0.4919229163099449,
           0.5212798744398902,
           0.5511088240041608,
           0.5813104972760909,
           0.6118026604405054,
           0.642516570408439,
           0.6733942140601102,
           0.704386157664894,
           0.7354498680463533,
           0.766548397221935,
           0.7976493470724203,
           0.8287240502009455,
           0.8597469182765531,
           0.8906949206990269,
           0.9215471651700549,
           0.952284558372302,
           0.9828895299642358,
           1.0133458068943106,
           1.04363822792536,
           1.0737525904649756,
           1.1036755234890243,
           1.1333943816491125,
           1.1628971566645947,
           1.1921724028858414,
           1.221209174530577,
           1.249996972578797,
           1.2785256996940344,
           1.3067856218423328,
           1.3347673355225131,
           1.3624617397155367,
           1.389860011817141,
           1.4169535869444496,
           1.4437341401099997,
           1.4701935708404714,
           1.4963239898860514,
           1.5221177077228132,
           1.5475672245970802,
           1.5726652218993347,
           1.5974045546873064,
           1.6217782452046385,
           1.6457794772639212,
           1.669401591381678,
           1.6926380805687427,
           1.7154825866928163,
           1.737928897341353,
           1.7599709431225354,
           1.7816027953503117,
           1.8028186640664783,
           1.8236128963587905,
           1.843979974939238,
           1.863914516951067,
           1.8834112729769512,
           1.902465126224032,
           1.921071091864412,
           1.9392243165121907,
           1.956920077820291,
           1.9741537841822245,
           1.9909209745256082,
           2.007217318185682,
           2.023038614848362,
           2.0383807945534813,
           2.053239917749858,
           2.067612175394706,
           2.0814938890906673,
           2.0948815112544454,
           2.107771625311604,
           2.1201609459126654,
           2.1320463191660934,
           2.1434247228842036,
           2.1542932668384176,
           2.1646491930206206,
           2.174489875907703,
           2.183812822726643,
           2.1926156737177283,
           2.2008962023937766,
           2.208652315793382,
           2.215882054726435,
           2.2225835940103202,
           2.2287552426953647,
           2.234395444278247,
           2.239502776902216,
           2.244075953543087,
           2.248113822180111,
           2.2516153659509013,
           2.254579703289724,
           2.257006088048536,
           2.2588939096002547,
           2.2602426929238306,
           2.2610520986707696
          ],
          [
           2.2311763221149477,
           2.2309093878481483,
           2.230108651692398,
           2.228774313570975,
           2.2269067066538426,
           2.224506297304493,
           2.2215736850057617,
           2.2181096022648163,
           2.2141149144976087,
           2.209590619893151,
           2.204537849258031,
           2.1989578658416757,
           2.192852065142933,
           2.186221974698632,
           2.179069253854877,
           2.171395693521901,
           2.1632032159134473,
           2.1544938742716977,
           2.1452698525789575,
           2.135533465257361,
           2.1252871568580627,
           2.114533501741497,
           2.103275203750477,
           2.091515095878078,
           2.079256139932463,
           2.066501426201036,
           2.0532541731165628,
           2.039517726928169,
           2.025295561380455,
           2.0105912774043113,
           1.9954086028233975,
           1.979751392080714,
           1.9636236259901618,
           1.947029411518565,
           1.929972981604241,
           1.912458695018933,
           1.8944910362806988,
           1.8760746156262935,
           1.8572141690525956,
           1.837914558437829,
           1.818180771754678,
           1.7980179233889453,
           1.7774312545791757,
           1.756426133994712,
           1.7350080584720105,
           1.7131826539317456,
           1.690955676502394,
           1.6683330138796337,
           1.6453206869551316,
           1.6219248517532623,
           1.5981518017200715,
           1.574007970415597,
           1.5494999346686325,
           1.5246344182624345,
           1.499418296230987,
           1.4738585998586393,
           1.4479625224916284,
           1.4217374262887374,
           1.3951908500607826,
           1.3683305183755996,
           1.34116435213774,
           1.3137004808914792,
           1.2859472571436283,
           1.2579132730610714,
           1.229607379969556,
           1.2010387111683893,
           1.1722167086846282,
           1.1431511547256463,
           1.1138522087577936,
           1.0843304513505987,
           1.054596936192885,
           1.0246632520254264,
           0.9945415966658442,
           0.9642448658538839,
           0.9337867603573654,
           0.9031819157026831,
           0.8724460600988658,
           0.8415962077065852,
           0.8106508964943328,
           0.7796304827040447,
           0.7485575076677792,
           0.7174571577224165,
           0.6863578447419709,
           0.6552919440133649,
           0.6242967387378288,
           0.5934156375885974,
           0.5626997551336788,
           0.532209976585664,
           0.5020196705486509,
           0.47221826804067923,
           0.44291599262838516,
           0.4142500977208591,
           0.3863930185098688,
           0.3595628146405218,
           0.33403602292804924,
           0.3101622710177559,
           0.28837823344633323,
           0.2692151409804246,
           0.2532890274749414,
           0.24125852092660144,
           0.23373826277265083,
           0.23117632211494746,
           0.23373826277265605,
           0.24125852092661162,
           0.25328902747495596,
           0.2692151409804428,
           0.28837823344635444,
           0.31016227101777943,
           0.3340360229280747,
           0.3595628146405488,
           0.38639301850989693,
           0.4142500977208881,
           0.4429159926284151,
           0.4722182680407096,
           0.5020196705486818,
           0.5322099765856951,
           0.5626997551337102,
           0.5934156375886289,
           0.6242967387378606,
           0.6552919440133967,
           0.6863578447420029,
           0.7174571577224483,
           0.748557507667811,
           0.7796304827040765,
           0.8106508964943645,
           0.8415962077066169,
           0.8724460600988974,
           0.9031819157027146,
           0.9337867603573968,
           0.9642448658539151,
           0.9945415966658752,
           1.024663252025457,
           1.0545969361929157,
           1.0843304513506293,
           1.1138522087578238,
           1.1431511547256765,
           1.172216708684658,
           1.2010387111684186,
           1.2296073799695855,
           1.2579132730611002,
           1.2859472571436572,
           1.3137004808915078,
           1.3411643521377683,
           1.3683305183756276,
           1.3951908500608101,
           1.4217374262887645,
           1.447962522491655,
           1.4738585998586657,
           1.4994182962310132,
           1.5246344182624605,
           1.549499934668658,
           1.5740079704156218,
           1.5981518017200962,
           1.6219248517532865,
           1.645320686955155,
           1.6683330138796575,
           1.6909556765024174,
           1.713182653931768,
           1.7350080584720329,
           1.7564261339947338,
           1.7774312545791968,
           1.7980179233889664,
           1.8181807717546983,
           1.837914558437849,
           1.8572141690526154,
           1.8760746156263128,
           1.8944910362807177,
           1.9124586950189513,
           1.9299729816042588,
           1.947029411518582,
           1.9636236259901787,
           1.9797513920807304,
           1.995408602823413,
           2.010591277404327,
           2.02529556138047,
           2.039517726928183,
           2.0532541731165765,
           2.0665014262010493,
           2.0792561399324754,
           2.09151509587809,
           2.103275203750489,
           2.114533501741508,
           2.1252871568580733,
           2.1355334652573714,
           2.1452698525789673,
           2.1544938742717066,
           2.1632032159134553,
           2.171395693521909,
           2.179069253854884,
           2.1862219746986393,
           2.1928520651429393,
           2.1989578658416815,
           2.2045378492580365,
           2.209590619893156,
           2.2141149144976136,
           2.21810960226482,
           2.221573685005765,
           2.2245062973044956,
           2.226906706653845,
           2.228774313570977,
           2.230108651692399,
           2.230909387848149
          ],
          [
           2.200807072855696,
           2.2005431303752183,
           2.1997513683696606,
           2.1984319831350216,
           2.1965853017925676,
           2.1942117822308176,
           2.1913120130244974,
           2.187886713330645,
           2.183936732762079,
           2.1794630512385362,
           2.1744667788157925,
           2.168949155493185,
           2.1629115509999868,
           2.1563554645611562,
           2.149282524643064,
           2.1416944886798674,
           2.1335932427812723,
           2.1249808014225295,
           2.1158593071175913,
           2.1062310300764597,
           2.0960983678478677,
           2.0854638449485567,
           2.074330112480549,
           2.062699947737957,
           2.0505762538050303,
           2.037962059147326,
           2.0248605171980896,
           2.0112749059421318,
           1.9972086274997702,
           1.9826652077136402,
           1.9676482957415127,
           1.9521616636585928,
           1.936209206073155,
           1.9197949397598202,
           1.9029230033152544,
           1.8855976568416501,
           1.86782328166395,
           1.8496043800875275,
           1.830945575203823,
           1.8118516107523803,
           1.7923273510487934,
           1.7723777809892816,
           1.7520080061440249,
           1.7312232529529785,
           1.7100288690397718,
           1.6884303236614076,
           1.6664332083140003,
           1.644043237517639,
           1.6212662498068624,
           1.5981082089571315,
           1.5745752054822924,
           1.5506734584434236,
           1.5264093176157965,
           1.501789266068207,
           1.476819923217794,
           1.4515080484340415,
           1.4258605452782278,
           1.3998844664796635,
           1.3735870197680957,
           1.3469755747034653,
           1.320057670670491,
           1.2928410262375296,
           1.265333550118109,
           1.2375433540211975,
           1.2094787677348977,
           1.1811483568606473,
           1.1525609437048325,
           1.123725631946761,
           1.094651835842377,
           1.0653493149000752,
           1.035828215189282,
           1.006099118728378,
           0.9761731027652457,
           0.9460618112369736,
           0.9157775413100986,
           0.8853333487070206,
           0.8547431765837574,
           0.8240220141303465,
           0.7931860929456176,
           0.76225313177247,
           0.7312426436230927,
           0.7001763240398889,
           0.6690785457504688,
           0.6379769940400476,
           0.606903489878065,
           0.575895065787688,
           0.5449953849334804,
           0.5142566301997963,
           0.4837420416893244,
           0.45352935405698547,
           0.42371548629465383,
           0.39442297127194503,
           0.3658087761748317,
           0.33807632234898355,
           0.3114915441416491,
           0.2864034113187981,
           0.26326774804366343,
           0.24266904291519736,
           0.2253265806990873,
           0.2120593544183678,
           0.20367911969311972,
           0.200807072855696,
           0.20367911969312558,
           0.21205935441837906,
           0.22532658069910316,
           0.24266904291521701,
           0.263267748043686,
           0.286403411318823,
           0.31149154414167574,
           0.33807632234901147,
           0.3658087761748607,
           0.3944229712719748,
           0.42371548629468425,
           0.45352935405701633,
           0.48374204168935553,
           0.5142566301998278,
           0.5449953849335122,
           0.5758950657877199,
           0.6069034898780968,
           0.6379769940400796,
           0.6690785457505007,
           0.7001763240399208,
           0.7312426436231244,
           0.7622531317725019,
           0.7931860929456493,
           0.8240220141303781,
           0.854743176583789,
           0.8853333487070518,
           0.9157775413101298,
           0.9460618112370048,
           0.9761731027652766,
           1.0060991187284085,
           1.0358282151893123,
           1.0653493149001056,
           1.0946518358424069,
           1.1237256319467908,
           1.152560943704862,
           1.1811483568606767,
           1.2094787677349266,
           1.2375433540212262,
           1.2653335501181378,
           1.2928410262375578,
           1.3200576706705187,
           1.3469755747034928,
           1.3735870197681228,
           1.3998844664796901,
           1.4258605452782545,
           1.4515080484340674,
           1.4768199232178199,
           1.5017892660682322,
           1.5264093176158215,
           1.5506734584434483,
           1.5745752054823166,
           1.5981082089571552,
           1.621266249806886,
           1.644043237517662,
           1.666433208314023,
           1.68843032366143,
           1.7100288690397936,
           1.7312232529530003,
           1.7520080061440457,
           1.7723777809893024,
           1.7923273510488136,
           1.8118516107524005,
           1.8309455752038424,
           1.8496043800875466,
           1.8678232816639688,
           1.8855976568416684,
           1.9029230033152724,
           1.9197949397598366,
           1.9362092060731715,
           1.9521616636586085,
           1.967648295741528,
           1.9826652077136553,
           1.9972086274997853,
           2.011274905942146,
           2.0248605171981033,
           2.0379620591473393,
           2.050576253805043,
           2.0626999477379693,
           2.0743301124805607,
           2.0854638449485674,
           2.0960983678478784,
           2.10623103007647,
           2.115859307117601,
           2.1249808014225384,
           2.1335932427812807,
           2.1416944886798754,
           2.149282524643071,
           2.1563554645611633,
           2.162911550999993,
           2.1689491554931912,
           2.1744667788157974,
           2.179463051238541,
           2.183936732762084,
           2.1878867133306494,
           2.1913120130245014,
           2.1942117822308203,
           2.19658530179257,
           2.198431983135023,
           2.1997513683696615,
           2.2005431303752188
          ],
          [
           2.170243555722376,
           2.169982708708371,
           2.1692002319235852,
           2.1678963181272315,
           2.166071288543137,
           2.16372559279751,
           2.1608598088319546,
           2.157474642791864,
           2.153570928890367,
           2.1491496292480545,
           2.1442118337087335,
           2.1387587596315316,
           2.1327917516596955,
           2.1263122814664914,
           2.1193219474786678,
           2.1118224745779894,
           2.103815713781426,
           2.0953036419006295,
           2.0862883611814156,
           2.0767720989240397,
           2.066757207085134,
           2.056246161862277,
           2.045241563262253,
           2.0337461346541725,
           2.021762722308767,
           2.0092942949252586,
           1.9963439431474064,
           1.9829148790704607,
           1.9690104357409517,
           1.9546340666514481,
           1.9397893452326442,
           1.9244799643453931,
           1.908709735775596,
           1.892482589735179,
           1.8758025743727562,
           1.8586738552980044,
           1.8411007151242254,
           1.823087553034128,
           1.8046388843744632,
           1.7857593402858352,
           1.766453667374818,
           1.7467267274364098,
           1.7265834972359113,
           1.7060290683605073,
           1.685068647152243,
           1.6637075547356672,
           1.6419512271553103,
           1.6198052156403082,
           1.59727518701603,
           1.5743669242855154,
           1.5510863274069966,
           1.5274394142978427,
           1.503432322100076,
           1.479071308748286,
           1.4543627548874851,
           1.4293131661964886,
           1.40392917618195,
           1.3782175495196585,
           1.3521851860334966,
           1.3258391254190958,
           1.299186552839411,
           1.2722348055439763,
           1.2449913806936024,
           1.217463944609103,
           1.1896603437080266,
           1.1615886174496248,
           1.133257013678326,
           1.104674006843651,
           1.075848319684842,
           1.0467889491081388,
           1.0175051971624631,
           0.9880067082471549,
           0.9583035139793088,
           0.9284060875299647,
           0.8983254097377241,
           0.8680730499664965,
           0.8376612655484796,
           0.8071031248248994,
           0.7764126603802171,
           0.7456050612248093,
           0.7146969156545505,
           0.683706520651319,
           0.652654279500347,
           0.6215632175558994,
           0.5904596579423854,
           0.5593741161922218,
           0.5283424980888615,
           0.49740772245182296,
           0.46662194665944295,
           0.4360496571170005,
           0.40577201421349784,
           0.37589303212871383,
           0.3465484533545605,
           0.3179185645063372,
           0.29024666256412046,
           0.2638652042127198,
           0.23923109850635393,
           0.2169680445793053,
           0.19790278742323775,
           0.18305822363980156,
           0.17353674920942846,
           0.17024355572237582,
           0.17353674920943515,
           0.1830582236398143,
           0.19790278742325537,
           0.21696804457932672,
           0.23923109850637822,
           0.2638652042127461,
           0.2902466625641483,
           0.31791856450636624,
           0.34654845335459034,
           0.37589303212874425,
           0.4057720142135289,
           0.4360496571170317,
           0.4666219466594744,
           0.49740772245185483,
           0.5283424980888932,
           0.5593741161922536,
           0.5904596579424174,
           0.6215632175559314,
           0.652654279500379,
           0.6837065206513507,
           0.7146969156545823,
           0.745605061224841,
           0.7764126603802486,
           0.8071031248249309,
           0.8376612655485111,
           0.8680730499665278,
           0.8983254097377549,
           0.9284060875299958,
           0.9583035139793393,
           0.9880067082471852,
           1.0175051971624933,
           1.0467889491081688,
           1.0758483196848716,
           1.1046740068436804,
           1.1332570136783553,
           1.161588617449654,
           1.1896603437080553,
           1.217463944609131,
           1.2449913806936304,
           1.2722348055440043,
           1.2991865528394388,
           1.3258391254191229,
           1.3521851860335234,
           1.3782175495196851,
           1.403929176181976,
           1.4293131661965146,
           1.4543627548875107,
           1.4790713087483114,
           1.503432322100101,
           1.527439414297867,
           1.5510863274070208,
           1.5743669242855391,
           1.597275187016053,
           1.619805215640331,
           1.641951227155333,
           1.6637075547356894,
           1.6850686471522645,
           1.7060290683605286,
           1.7265834972359317,
           1.7467267274364306,
           1.7664536673748379,
           1.7857593402858547,
           1.8046388843744823,
           1.8230875530341466,
           1.8411007151242436,
           1.858673855298022,
           1.8758025743727735,
           1.8924825897351956,
           1.9087097357756124,
           1.924479964345409,
           1.9397893452326593,
           1.9546340666514632,
           1.9690104357409663,
           1.982914879070475,
           1.9963439431474204,
           2.0092942949252715,
           2.0217627223087797,
           2.0337461346541845,
           2.0452415632622643,
           2.0562461618622883,
           2.0667572070851445,
           2.0767720989240495,
           2.086288361181425,
           2.0953036419006383,
           2.103815713781435,
           2.1118224745779974,
           2.119321947478675,
           2.1263122814664985,
           2.1327917516597017,
           2.138758759631537,
           2.144211833708739,
           2.1491496292480594,
           2.1535709288903715,
           2.1574746427918674,
           2.1608598088319577,
           2.1637255927975128,
           2.1660712885431392,
           2.1678963181272337,
           2.1692002319235866,
           2.169982708708372
          ],
          [
           2.1395153389439,
           2.13925769323853,
           2.138484819235409,
           2.1371969062603497,
           2.135394269812521,
           2.1330773514987214,
           2.1302467189414616,
           2.1269030656609584,
           2.1230472109311704,
           2.1186800996100383,
           2.1138028019441215,
           2.108416513347866,
           2.102522554157757,
           2.096122369361656,
           2.089217528303673,
           2.08180972436493,
           2.073900774620667,
           2.065492619474132,
           2.056587322267803,
           2.047187068872497,
           2.037294167255016,
           2.0269110470250244,
           2.0160402589619344,
           2.0046844745226453,
           1.9928464853310748,
           1.980529202650517,
           1.9677356568399529,
           1.9544689967955746,
           1.9407324893788973,
           1.9265295188329872,
           1.9118635861884834,
           1.8967383086612906,
           1.8811574190439952,
           1.8651247650933154,
           1.8486443089161169,
           1.83172012635686,
           1.8143564063896247,
           1.796557450518275,
           1.7783276721887231,
           1.7596715962177492,
           1.7405938582433897,
           1.7210992042025328,
           1.7011924898421007,
           1.6808786802710372,
           1.6601628495612857,
           1.6390501804070743,
           1.617545963853123,
           1.5956555991039172,
           1.5733845934279418,
           1.5507385621728766,
           1.5277232289101432,
           1.504344425730089,
           1.480608093712453,
           1.4565202836007523,
           1.432087156713985,
           1.4073149861346947,
           1.3822101582192066,
           1.3567791744839608,
           1.3310286539316587,
           1.3049653358927438,
           1.2785960834721166,
           1.2519278877084805,
           1.2249678725751572,
           1.1977233009775947,
           1.1702015819353964,
           1.1424102791772122,
           1.1143571214274344,
           1.0860500147271683,
           1.0574970572121878,
           1.0287065568725442,
           0.9996870529488414,
           0.9704473417879738,
           0.9409965081986077,
           0.9113439636306487,
           0.8814994928766182,
           0.851473311488666,
           0.8212761367684706,
           0.7909192760834819,
           0.7604147374852119,
           0.7297753692894374,
           0.6990150376241978,
           0.6681488542574414,
           0.6371934717321541,
           0.6061674696519027,
           0.5750918659438099,
           0.5439908017647396,
           0.5128924711052603,
           0.4818304004580236,
           0.45084523734705645,
           0.4199872910396109,
           0.38932020448324617,
           0.358926357168198,
           0.32891495997180104,
           0.2994343927043629,
           0.27069127185572567,
           0.24298010580290869,
           0.21672892723412993,
           0.19256616480760083,
           0.17140536528373174,
           0.15450920126827933,
           0.1434117753067263,
           0.13951533894389997,
           0.1434117753067342,
           0.15450920126829398,
           0.17140536528375155,
           0.19256616480762437,
           0.216728927234156,
           0.2429801058029365,
           0.27069127185575476,
           0.29943439270439287,
           0.3289149599718316,
           0.358926357168229,
           0.38932020448327764,
           0.4199872910396425,
           0.4508452373470882,
           0.4818304004580555,
           0.5128924711052921,
           0.5439908017647715,
           0.5750918659438419,
           0.6061674696519346,
           0.6371934717321861,
           0.6681488542574733,
           0.6990150376242293,
           0.729775369289469,
           0.7604147374852434,
           0.7909192760835131,
           0.8212761367685016,
           0.851473311488697,
           0.881499492876649,
           0.9113439636306794,
           0.940996508198638,
           0.9704473417880038,
           0.9996870529488714,
           1.0287065568725742,
           1.057497057212217,
           1.0860500147271974,
           1.1143571214274632,
           1.1424102791772408,
           1.1702015819354248,
           1.197723300977623,
           1.2249678725751851,
           1.2519278877085083,
           1.2785960834721437,
           1.3049653358927706,
           1.3310286539316853,
           1.356779174483987,
           1.3822101582192325,
           1.4073149861347205,
           1.4320871567140103,
           1.4565202836007771,
           1.4806080937124777,
           1.5043444257301133,
           1.527723228910167,
           1.5507385621729004,
           1.5733845934279649,
           1.5956555991039396,
           1.6175459638531453,
           1.639050180407096,
           1.660162849561307,
           1.6808786802710582,
           1.7011924898421213,
           1.721099204202553,
           1.7405938582434095,
           1.7596715962177687,
           1.7783276721887418,
           1.7965574505182937,
           1.814356406389643,
           1.8317201263568776,
           1.8486443089161344,
           1.865124765093332,
           1.8811574190440117,
           1.8967383086613063,
           1.9118635861884985,
           1.9265295188330018,
           1.940732489378912,
           1.9544689967955882,
           1.9677356568399662,
           1.9805292026505301,
           1.9928464853310872,
           2.004684474522657,
           2.016040258961946,
           2.026911047025035,
           2.0372941672550264,
           2.047187068872507,
           2.0565873222678124,
           2.0654926194741408,
           2.073900774620675,
           2.081809724364938,
           2.0892175283036796,
           2.0961223693616633,
           2.1025225541577632,
           2.1084165133478723,
           2.113802801944127,
           2.1186800996100428,
           2.123047210931175,
           2.1269030656609624,
           2.130246718941465,
           2.133077351498724,
           2.1353942698125232,
           2.1371969062603506,
           2.13848481923541,
           2.1392576932385303
          ],
          [
           2.1086521500854514,
           2.108397813674154,
           2.1076348664477087,
           2.1063634944147585,
           2.104584007544061,
           2.1022968396960513,
           2.099502548527108,
           2.0962018153665825,
           2.092395445066694,
           2.0880843658254036,
           2.0832696289824026,
           2.0779524087883794,
           2.072134002147746,
           2.065815828335041,
           2.058999428685242,
           2.0516864662582512,
           2.0438787254778576,
           2.035578111745495,
           2.026786651029163,
           2.0175064894279067,
           2.007739892712297,
           1.997489245841384,
           1.9867570524566691,
           1.9755459343536523,
           1.9638586309316068,
           1.9516979986222724,
           1.9390670102982268,
           1.9259687546617827,
           1.9124064356153225,
           1.8983833716140894,
           1.883902995002554,
           1.8689688513355796,
           1.8535845986857509,
           1.8377540069383684,
           1.821480957075778,
           1.8047694404528736,
           1.7876235580658515,
           1.7700475198164898,
           1.7520456437745213,
           1.7336223554409769,
           1.7147821870156965,
           1.6955297766726476,
           1.6758698678471091,
           1.6558073085393403,
           1.6353470506399537,
           1.614494149282907,
           1.593253762232884,
           1.571631149314754,
           1.5496316718939407,
           1.5272607924178327,
           1.5045240740298973,
           1.4814271802699694,
           1.4579758748763316,
           1.4341760217077058,
           1.4100335848063117,
           1.3855546286267149,
           1.3607453184594887,
           1.3356119210838744,
           1.3101608056898426,
           1.2843984451175061,
           1.258331417470992,
           1.2319664081750843,
           1.205310212556682,
           1.1783697390500474,
           1.1511520131458088,
           1.1236641822297886,
           1.0959135214904405,
           1.0679074411148495,
           1.0396534950454057,
           1.0111593916357313,
           0.982433006629726,
           0.9534823989977822,
           0.9243158303076293,
           0.8949417884953512,
           0.8653690171508925,
           0.8356065517642006,
           0.8056637648249919,
           0.7755504222767199,
           0.7452767546602534,
           0.7148535474430082,
           0.6842922566609866,
           0.6536051583255622,
           0.6228055434037586,
           0.5919079751009939,
           0.5609286325022239,
           0.5298857757264104,
           0.4988003848744527,
           0.4676970520027044,
           0.4366052486841881,
           0.40556116298449996,
           0.3746104197546398,
           0.3438122056264122,
           0.3132456878772634,
           0.2830202841535057,
           0.2532925759512606,
           0.2242949587181136,
           0.19638527842528866,
           0.17013328589069254,
           0.14646504420861173,
           0.1268639015328373,
           0.1134805669365201,
           0.10865215008545126,
           0.11348056693652982,
           0.12686390153285465,
           0.1464650442086343,
           0.1701332858907184,
           0.19638527842531667,
           0.2242949587181429,
           0.2532925759512908,
           0.2830202841535365,
           0.3132456878772947,
           0.3438122056264437,
           0.37461041975467163,
           0.4055611629845318,
           0.43660524868422007,
           0.46769705200273637,
           0.4988003848744847,
           0.5298857757264422,
           0.5609286325022559,
           0.5919079751010258,
           0.6228055434037904,
           0.6536051583255938,
           0.6842922566610181,
           0.7148535474430396,
           0.7452767546602846,
           0.7755504222767509,
           0.8056637648250227,
           0.8356065517642313,
           0.8653690171509231,
           0.8949417884953815,
           0.9243158303076594,
           0.9534823989978121,
           0.9824330066297555,
           1.0111593916357609,
           1.039653495045435,
           1.0679074411148783,
           1.0959135214904692,
           1.123664182229817,
           1.1511520131458368,
           1.1783697390500751,
           1.2053102125567094,
           1.2319664081751118,
           1.258331417471019,
           1.284398445117533,
           1.310160805689869,
           1.3356119210839006,
           1.3607453184595144,
           1.38555462862674,
           1.4100335848063366,
           1.4341760217077306,
           1.457975874876356,
           1.4814271802699934,
           1.5045240740299208,
           1.527260792417856,
           1.5496316718939636,
           1.5716311493147763,
           1.5932537622329062,
           1.6144941492829286,
           1.635347050639975,
           1.6558073085393612,
           1.675869867847129,
           1.6955297766726674,
           1.7147821870157158,
           1.7336223554409957,
           1.7520456437745402,
           1.7700475198165082,
           1.7876235580658695,
           1.8047694404528907,
           1.8214809570757944,
           1.837754006938385,
           1.8535845986857669,
           1.8689688513355953,
           1.883902995002569,
           1.8983833716141036,
           1.9124064356153367,
           1.925968754661797,
           1.9390670102982406,
           1.9516979986222855,
           1.9638586309316188,
           1.975545934353664,
           1.9867570524566807,
           1.9974892458413949,
           2.0077398927123067,
           2.017506489427917,
           2.0267866510291723,
           2.035578111745504,
           2.0438787254778656,
           2.051686466258259,
           2.0589994286852495,
           2.065815828335048,
           2.072134002147752,
           2.077952408788385,
           2.083269628982408,
           2.0880843658254085,
           2.092395445066698,
           2.096201815366586,
           2.0995025485271115,
           2.102296839696054,
           2.1045840075440627,
           2.1063634944147602,
           2.10763486644771,
           2.108397813674155
          ],
          [
           2.077683847288983,
           2.077432930268605,
           2.0766802401522964,
           2.0754259597604587,
           2.0736703937468923,
           2.0714139685285065,
           2.0686572321869687,
           2.065400854342343,
           2.0616456259987648,
           2.057392459362253,
           2.0526423876307356,
           2.047396564756409,
           2.041656265180546,
           2.0354228835409045,
           2.0286979343518876,
           2.021483051657636,
           2.013779988658248,
           2.0055906173093447,
           1.9969169278952075,
           1.9877610285757663,
           1.9781251449077013,
           1.9680116193399813,
           1.9574229106841696,
           1.9463615935598653,
           1.934830357815679,
           1.922832007926178,
           1.9103694623652707,
           1.8974457529565523,
           1.8840640242011641,
           1.8702275325837854,
           1.855939645857429,
           1.841203842307768,
           1.8260237099977967,
           1.8104029459937203,
           1.7943453555730204,
           1.777854851415791,
           1.760935452780507,
           1.7435912846655464,
           1.725826576957908,
           1.7076456635707502,
           1.6890529815715434,
           1.6700530703028593,
           1.6506505704980547,
           1.6308502233943878,
           1.6106568698464452,
           1.5900754494431104,
           1.569110999631764,
           1.547768654853895,
           1.5260536456969063,
           1.50397129806759,
           1.4815270323935512,
           1.458726362859837,
           1.435574896689135,
           1.4120783334752762,
           1.3882424645813483,
           1.3640731726156547,
           1.3395764310010172,
           1.314758303655689,
           1.2896249448074462,
           1.2641825989664548,
           1.2384376010874047,
           1.2123963769573933,
           1.186065443853393,
           1.1594514115222267,
           1.1325609835472368,
           1.1054009591799012,
           1.0779782357322767,
           1.050299811648401,
           1.0223727904010336,
           0.9942043853961917,
           0.9658019261143826,
           0.937172865777568,
           0.9083247909094553,
           0.8792654332600911,
           0.8500026847029849,
           0.8205446158968858,
           0.7908994997531138,
           0.7610758410894376,
           0.7310824143215636,
           0.7009283117008893,
           0.6706230055388579,
           0.6401764291966963,
           0.6095990835709638,
           0.5789021786975019,
           0.5480978244582538,
           0.5171992910810442,
           0.48622137064929893,
           0.4551808877485268,
           0.4240974352353271,
           0.3929944583122999,
           0.361900892564264,
           0.3308537107495535,
           0.2999020132885049,
           0.269113846197701,
           0.23858805564629446,
           0.2084759102047767,
           0.17902268124499734,
           0.15065207437261527,
           0.12414521725601123,
           0.10101549176322236,
           0.08412710413868502,
           0.07768384728898271,
           0.08412710413869776,
           0.10101549176324356,
           0.12414521725603711,
           0.15065207437264366,
           0.1790226812450272,
           0.20847591020480738,
           0.23858805564632565,
           0.26911384619773254,
           0.29990201328853666,
           0.3308537107495853,
           0.361900892564296,
           0.3929944583123319,
           0.424097435235359,
           0.45518088774855864,
           0.48622137064933074,
           0.5171992910810761,
           0.5480978244582856,
           0.5789021786975336,
           0.6095990835709953,
           0.6401764291967276,
           0.6706230055388891,
           0.7009283117009204,
           0.7310824143215946,
           0.7610758410894684,
           0.7908994997531442,
           0.8205446158969161,
           0.8500026847030151,
           0.879265433260121,
           0.9083247909094849,
           0.9371728657775974,
           0.9658019261144121,
           0.9942043853962208,
           1.0223727904010622,
           1.05029981164843,
           1.077978235732305,
           1.1054009591799292,
           1.1325609835472645,
           1.1594514115222543,
           1.1860654438534204,
           1.2123963769574204,
           1.2384376010874314,
           1.2641825989664812,
           1.2896249448074724,
           1.3147583036557147,
           1.3395764310010425,
           1.36407317261568,
           1.3882424645813731,
           1.4120783334753004,
           1.4355748966891593,
           1.4587263628598606,
           1.4815270323935747,
           1.5039712980676125,
           1.526053645696929,
           1.5477686548539171,
           1.5691109996317858,
           1.5900754494431317,
           1.610656869846466,
           1.6308502233944082,
           1.6506505704980747,
           1.6700530703028793,
           1.6890529815715627,
           1.707645663570769,
           1.7258265769579266,
           1.7435912846655646,
           1.7609354527805248,
           1.7778548514158081,
           1.794345355573037,
           1.8104029459937365,
           1.8260237099978132,
           1.841203842307783,
           1.8559396458574442,
           1.8702275325837998,
           1.8840640242011781,
           1.897445752956566,
           1.9103694623652843,
           1.9228320079261907,
           1.934830357815691,
           1.9463615935598768,
           1.9574229106841807,
           1.968011619339992,
           1.9781251449077115,
           1.9877610285757759,
           1.996916927895217,
           2.005590617309353,
           2.0137799886582566,
           2.021483051657644,
           2.0286979343518947,
           2.035422883540911,
           2.041656265180552,
           2.047396564756415,
           2.052642387630741,
           2.0573924593622577,
           2.0616456259987688,
           2.0654008543423465,
           2.068657232186972,
           2.0714139685285087,
           2.073670393746894,
           2.0754259597604605,
           2.0766802401522977,
           2.077432930268606
          ],
          [
           2.046640390387394,
           2.0463930049195245,
           2.0456509084451677,
           2.0444142807378283,
           2.042683421372528,
           2.0404587496545936,
           2.0377408045199967,
           2.0345302444072697,
           2.0308278471010524,
           2.026634509547313,
           2.0219512476403136,
           2.0167791959813886,
           2.01111960760962,
           2.0049738537045023,
           1.9983434232607078,
           1.9912299227350538,
           1.9836350756658152,
           1.9755607222645064,
           1.9670088189802934,
           1.9579814380371863,
           1.9484807669442064,
           1.938509107978695,
           1.9280688776429904,
           1.9171626060946738,
           1.9057929365506276,
           1.8939626246651637,
           1.8816745378824788,
           1.8689316547637391,
           1.8557370642891,
           1.842093965134999,
           1.8280056649270755,
           1.8134755794691115,
           1.7985072319484035,
           1.7831042521180203,
           1.7672703754564274,
           1.7510094423050115,
           1.7343253969840706,
           1.7172222868878948,
           1.6997042615596165,
           1.6817755717465759,
           1.6634405684370117,
           1.6447037018789827,
           1.6255695205825091,
           1.606042670306032,
           1.5861278930284215,
           1.5658300259078952,
           1.54515400022938,
           1.524104840342042,
           1.5026876625889296,
           1.4809076742309342,
           1.458770172367585,
           1.436280542857545,
           1.4134442592420986,
           1.3902668816754349,
           1.3667540558661153,
           1.3429115120348263,
           1.3187450638943825,
           1.2942606076589596,
           1.2694641210907813,
           1.2443616625939868,
           1.2189593703672366,
           1.1932634616288522,
           1.1672802319310467,
           1.1410160545831944,
           1.1144773802083334,
           1.0876707364623577,
           1.0606027279519956,
           1.0332800363960497,
           1.0057094210850166,
           0.977897719707851,
           0.949851849632191,
           0.9215788097471891,
           0.8930856830079315,
           0.8643796398598242,
           0.8354679427737486,
           0.8063579521932471,
           0.7770571342906336,
           0.7475730710601234,
           0.7179134734581942,
           0.6880861985572949,
           0.6580992720434933,
           0.6279609179153195,
           0.5976795980141573,
           0.5672640651709626,
           0.5367234355105766,
           0.5060672881829178,
           0.475305805124542,
           0.44444997051548324,
           0.41351186142824875,
           0.38250508162463576,
           0.3514454271109602,
           0.3203519404441344,
           0.2892486444090381,
           0.25816752123272335,
           0.22715390855681877,
           0.19627691452318813,
           0.1656511531458827,
           0.1354867286134469,
           0.10621893567428393,
           0.0788959717476695,
           0.0564613407296469,
           0.04664039038739381,
           0.056461340729665334,
           0.07889597174769589,
           0.1062189356743133,
           0.13548672861347758,
           0.16565115314591403,
           0.19627691452321977,
           0.2271539085568506,
           0.25816752123275527,
           0.2892486444090701,
           0.3203519404441663,
           0.35144542711099214,
           0.3825050816246676,
           0.4135118614282805,
           0.4444499705155149,
           0.47530580512457365,
           0.5060672881829494,
           0.536723435510608,
           0.567264065170994,
           0.5976795980141886,
           0.6279609179153505,
           0.6580992720435241,
           0.6880861985573257,
           0.7179134734582248,
           0.7475730710601537,
           0.7770571342906638,
           0.8063579521932772,
           0.8354679427737782,
           0.8643796398598538,
           0.8930856830079607,
           0.9215788097472182,
           0.9498518496322201,
           0.9778977197078798,
           1.005709421085045,
           1.033280036396078,
           1.0606027279520236,
           1.0876707364623854,
           1.114477380208361,
           1.1410160545832215,
           1.1672802319310736,
           1.1932634616288789,
           1.2189593703672628,
           1.2443616625940128,
           1.2694641210908069,
           1.2942606076589849,
           1.3187450638944076,
           1.3429115120348512,
           1.36675405586614,
           1.390266881675459,
           1.413444259242122,
           1.4362805428575682,
           1.4587701723676079,
           1.4809076742309566,
           1.5026876625889516,
           1.524104840342064,
           1.5451540002294015,
           1.5658300259079163,
           1.5861278930284424,
           1.6060426703060522,
           1.6255695205825287,
           1.6447037018790023,
           1.6634405684370306,
           1.6817755717465945,
           1.6997042615596345,
           1.7172222868879126,
           1.734325396984088,
           1.7510094423050284,
           1.7672703754564436,
           1.783104252118036,
           1.7985072319484192,
           1.8134755794691266,
           1.8280056649270902,
           1.842093965135013,
           1.8557370642891138,
           1.868931654763752,
           1.881674537882492,
           1.8939626246651764,
           1.9057929365506396,
           1.9171626060946851,
           1.9280688776430017,
           1.9385091079787056,
           1.9484807669442163,
           1.957981438037196,
           1.967008818980302,
           1.9755607222645148,
           1.983635075665823,
           1.9912299227350612,
           1.9983434232607147,
           2.0049738537045094,
           2.0111196076096256,
           2.016779195981394,
           2.021951247640318,
           2.0266345095473173,
           2.030827847101057,
           2.0345302444072733,
           2.03774080452,
           2.0404587496545963,
           2.042683421372529,
           2.0444142807378296,
           2.045650908445169,
           2.0463930049195254
          ],
          [
           2.015551811920327,
           2.015308072168038,
           2.014576911875888,
           2.0133585079237917,
           2.011653155064166,
           2.0094612658507756,
           2.006783370539147,
           2.003620116958571,
           1.9999722703557254,
           1.9958407132099627,
           1.9912264450203017,
           1.9861305820641844,
           1.9805543571280546,
           1.9744991192098302,
           1.9679663331933404,
           1.9609575794948124,
           1.9534745536815032,
           1.9455190660625628,
           1.9370930412522451,
           1.9281985177055725,
           1.9188376472265702,
           1.90901269444921,
           1.898726036291181,
           1.8879801613806457,
           1.8767776694561167,
           1.8651212707396247,
           1.8530137852833333,
           1.840458142289774,
           1.8274573794058917,
           1.8140146419910828,
           1.80013318235942,
           1.7858163589962819,
           1.7710676357495947,
           1.7558905809959124,
           1.7402888667815686,
           1.7242662679391503,
           1.7078266611795387,
           1.6909740241597948,
           1.6737124345271537,
           1.656046068939431,
           1.6379792020621349,
           1.6195162055426096,
           1.600661546961536,
           1.5814197887621475,
           1.5617955871575286,
           1.5417936910163845,
           1.5214189407277023,
           1.500676267044738,
           1.4795706899088086,
           1.4581073172533872,
           1.4362913437890503,
           1.4141280497698678,
           1.3916227997418753,
           1.3687810412743369,
           1.3456083036745705,
           1.322110196687206,
           1.2982924091788255,
           1.2741607078090882,
           1.2497209356895531,
           1.2249790110316137,
           1.1999409257851636,
           1.1746127442698635,
           1.1490006018012116,
           1.123110703314004,
           1.0969493219862612,
           1.0705227978673026,
           1.0438375365144161,
           1.0169000076435313,
           0.9897167438005322,
           0.9622943390614079,
           0.9346394477714682,
           0.9067587833364728,
           0.8786591170819642,
           0.8503472772016405,
           0.8218301478216588,
           0.7931146682159068,
           0.7642078322183711,
           0.7351166878939451,
           0.7058483375502198,
           0.6764099382026242,
           0.6468087026479046,
           0.6170519013626804,
           0.5871468655347942,
           0.5571009916715537,
           0.5269217484374283,
           0.4966166866992647,
           0.46619345427745984,
           0.4356598177556238,
           0.4050236951449999,
           0.37429320572298064,
           0.34347674794473804,
           0.3125831250101649,
           0.2816217549885953,
           0.2506030390826793,
           0.21953904506541447,
           0.18844487023225975,
           0.15734162333824003,
           0.12626380760020356,
           0.09528107871029981,
           0.06458197524021321,
           0.03499056506635985,
           0.015551811920326975,
           0.0349905650663887,
           0.06458197524024448,
           0.09528107871033158,
           0.1262638076002355,
           0.15734162333827206,
           0.18844487023229173,
           0.21953904506544644,
           0.2506030390827112,
           0.2816217549886272,
           0.31258312501019664,
           0.3434767479447698,
           0.3742932057230123,
           0.4050236951450314,
           0.4356598177556552,
           0.46619345427749115,
           0.496616686699296,
           0.5269217484374595,
           0.5571009916715846,
           0.5871468655348251,
           0.617051901362711,
           0.646808702647935,
           0.6764099382026545,
           0.7058483375502499,
           0.7351166878939752,
           0.7642078322184009,
           0.7931146682159365,
           0.8218301478216881,
           0.8503472772016698,
           0.8786591170819931,
           0.9067587833365015,
           0.9346394477714969,
           0.9622943390614362,
           0.9897167438005603,
           1.0169000076435593,
           1.0438375365144437,
           1.07052279786733,
           1.0969493219862883,
           1.1231107033140306,
           1.149000601801238,
           1.1746127442698895,
           1.1999409257851896,
           1.2249790110316394,
           1.2497209356895784,
           1.2741607078091133,
           1.2982924091788504,
           1.3221101966872302,
           1.3456083036745947,
           1.3687810412743604,
           1.3916227997418986,
           1.4141280497698907,
           1.436291343789073,
           1.4581073172534094,
           1.4795706899088306,
           1.5006762670447595,
           1.5214189407277234,
           1.5417936910164052,
           1.561795587157549,
           1.5814197887621673,
           1.600661546961555,
           1.6195162055426287,
           1.6379792020621535,
           1.6560460689394492,
           1.6737124345271717,
           1.6909740241598124,
           1.7078266611795558,
           1.7242662679391667,
           1.7402888667815848,
           1.755890580995928,
           1.7710676357496105,
           1.7858163589962968,
           1.8001331823594342,
           1.8140146419910967,
           1.8274573794059055,
           1.8404581422897868,
           1.8530137852833461,
           1.8651212707396374,
           1.8767776694561285,
           1.8879801613806566,
           1.8987260362911917,
           1.9090126944492203,
           1.9188376472265805,
           1.928198517705582,
           1.937093041252254,
           1.945519066062571,
           1.9534745536815108,
           1.9609575794948202,
           1.9679663331933472,
           1.9744991192098367,
           1.9805543571280604,
           1.9861305820641895,
           1.9912264450203068,
           1.9958407132099674,
           1.9999722703557297,
           2.0036201169585746,
           2.00678337053915,
           2.009461265850778,
           2.011653155064168,
           2.013358507923793,
           2.014576911875889,
           2.0153080721680383
          ],
          [
           1.984448188079625,
           1.984208210125671,
           1.9834883343188103,
           1.9822887348100366,
           1.980609701804299,
           1.9784516414904478,
           1.9758150759431954,
           1.9727006429971,
           1.9691090960926088,
           1.9650413040942085,
           1.960498251080718,
           1.9554810361077821,
           1.949990872942625,
           1.9440290897711314,
           1.9375971288773306,
           1.9306965462953618,
           1.9233290114340176,
           1.915496306673948,
           1.9072003269376467,
           1.8984430792323095,
           1.889226682165703,
           1.8795533654351537,
           1.8694254692897954,
           1.8588454439662199,
           1.8478158490976702,
           1.8363393530969352,
           1.824418732513114,
           1.8120568713624106,
           1.7992567604331464,
           1.7860214965651744,
           1.7723542819038907,
           1.7582584231290463,
           1.7437373306585762,
           1.7287945178276645,
           1.7134336000432764,
           1.6976582939144014,
           1.6814724163582602,
           1.6648798836827359,
           1.6478847106453056,
           1.6304910094887612,
           1.612702988954018,
           1.5945249532703274,
           1.575961301123226,
           1.5570165246005678,
           1.5376952081170097,
           1.518002027317335,
           1.4979417479590322,
           1.4775192247745692,
           1.4567394003138223,
           1.4356073037671828,
           1.414128049769868,
           1.392306837188036,
           1.370148947887346,
           1.3476597454846706,
           1.324844674083735,
           1.3017092569955553,
           1.2782590954446378,
           1.254499867262037,
           1.2304373255665044,
           1.2060772974351486,
           1.18142568256524,
           1.1564884519290537,
           1.1312716464239716,
           1.1057813755204604,
           1.08002381591104,
           1.0540052101639719,
           1.0277318653861662,
           1.0012101519008,
           0.9744465019463607,
           0.9474474084054428,
           0.920219423573665,
           0.8927691579817442,
           0.8651032792872667,
           0.8372285112572957,
           0.809151632869119,
           0.7808794775647089,
           0.752418932705724,
           0.7237769392913461,
           0.6949604920227617,
           0.6659766398283963,
           0.6368324870072837,
           0.6075351952106676,
           0.5780919865743191,
           0.548510148452543,
           0.5187970404165403,
           0.48896010451032074,
           0.4590068802857543,
           0.42894502700558984,
           0.3987823568691663,
           0.36852688567723396,
           0.33818691200183604,
           0.3077711447422415,
           0.2772889165297407,
           0.24675055767283513,
           0.2161680900256433,
           0.1855566105049646,
           0.154937317358543,
           0.12434500048331784,
           0.09385010320576674,
           0.06364352007630433,
           0.03455790642377664,
           0.01555181192037493,
           0.03455790642380496,
           0.06364352007633506,
           0.09385010320579798,
           0.12434500048334926,
           0.15493731735857447,
           0.18555661050499606,
           0.21616809002567472,
           0.2467505576728665,
           0.277288916529772,
           0.3077711447422728,
           0.33818691200186723,
           0.36852688567726516,
           0.39878235686919733,
           0.4289450270056207,
           0.4590068802857852,
           0.48896010451035143,
           0.5187970404165709,
           0.5485101484525734,
           0.5780919865743497,
           0.6075351952106978,
           0.6368324870073137,
           0.6659766398284263,
           0.6949604920227914,
           0.7237769392913757,
           0.7524189327057532,
           0.7808794775647382,
           0.8091516328691479,
           0.8372285112573244,
           0.8651032792872951,
           0.8927691579817724,
           0.920219423573693,
           0.9474474084054709,
           0.9744465019463883,
           1.0012101519008274,
           1.0277318653861933,
           1.0540052101639987,
           1.0800238159110667,
           1.1057813755204866,
           1.1312716464239976,
           1.15648845192908,
           1.1814256825652656,
           1.2060772974351737,
           1.230437325566529,
           1.2544998672620618,
           1.278259095444662,
           1.301709256995579,
           1.324844674083759,
           1.347659745484694,
           1.370148947887369,
           1.3923068371880583,
           1.41412804976989,
           1.4356073037672048,
           1.4567394003138436,
           1.4775192247745905,
           1.4979417479590533,
           1.5180020273173553,
           1.5376952081170299,
           1.5570165246005876,
           1.575961301123245,
           1.5945249532703465,
           1.6127029889540365,
           1.6304910094887797,
           1.6478847106453232,
           1.6648798836827534,
           1.6814724163582773,
           1.6976582939144178,
           1.7134336000432926,
           1.7287945178276802,
           1.7437373306585915,
           1.7582584231290608,
           1.7723542819039049,
           1.7860214965651884,
           1.79925676043316,
           1.8120568713624234,
           1.8244187325131265,
           1.8363393530969472,
           1.8478158490976817,
           1.858845443966231,
           1.8694254692898058,
           1.8795533654351637,
           1.8892266821657127,
           1.8984430792323184,
           1.9072003269376554,
           1.9154963066739565,
           1.9233290114340251,
           1.9306965462953691,
           1.937597128877337,
           1.944029089771138,
           1.9499908729426307,
           1.9554810361077875,
           1.960498251080723,
           1.9650413040942127,
           1.9691090960926123,
           1.9727006429971035,
           1.975815075943199,
           1.97845164149045,
           1.9806097018043007,
           1.9822887348100382,
           1.9834883343188114,
           1.9842082101256717
          ],
          [
           1.9533596096125583,
           1.9531235113569188,
           1.9524152737936227,
           1.95123506851996,
           1.9495831814861666,
           1.9474600129275648,
           1.9448660772696003,
           1.9418020030057939,
           1.938268532548666,
           1.934266522053673,
           1.9297969412162235,
           1.9248608730418448,
           1.9194595135895838,
           1.9135941716887246,
           1.90726626862894,
           1.9004773378239779,
           1.8932290244490095,
           1.8855230850517828,
           1.8773613871377188,
           1.868745908729119,
           1.859678737898651,
           1.850162072277307,
           1.8401982185370303,
           1.8297895918482296,
           1.8189387153124155,
           1.8076482193702061,
           1.7959208411849763,
           1.783759424002434,
           1.771166916486437,
           1.7581463720313872,
           1.7447009480515558,
           1.7308339052477322,
           1.7165486068516136,
           1.701848517848388,
           1.6867372041779973,
           1.6712183319156189,
           1.6552956664319376,
           1.638973071533846,
           1.6222545085862523,
           1.6051440356157665,
           1.5876458063970857,
           1.569764069523,
           1.5515031674590385,
           1.5328675355838763,
           1.51386170121677,
           1.4944902826334185,
           1.474757988071833,
           1.4546696147299916,
           1.434230047757295,
           1.413444259242099,
           1.3923173071979322,
           1.3708543345513726,
           1.3490605681350047,
           1.3269413176894056,
           1.3045019748787223,
           1.2817480123251639,
           1.2586849826686077,
           1.2353185176586061,
           1.2116543272873677,
           1.1876981989738642,
           1.1634559968111293,
           1.1389336608911587,
           1.1141372067247017,
           1.0890727247768022,
           1.06374638014336,
           1.0381644123995188,
           1.0123331356576097,
           0.9862589388811568,
           0.9599482865125795,
           0.9334077194864937,
           0.9066438567188763,
           0.8796633971862173,
           0.8524731227399873,
           0.8250799018429193,
           0.7974906944684063,
           0.7697125584779316,
           0.7417526578913759,
           0.7136182736020836,
           0.6853168172787591,
           0.656855849463442,
           0.628243103255214,
           0.5994865155188078,
           0.5705942683635906,
           0.5415748448419135,
           0.512437104646035,
           0.4831903884237107,
           0.453844663842918,
           0.4244107338786864,
           0.39490054008591996,
           0.36532761484953047,
           0.3357077745805047,
           0.3060602165485044,
           0.27640931992897283,
           0.2467877351345704,
           0.21724196556811634,
           0.18784310465697424,
           0.15870913183992696,
           0.13005579167224057,
           0.10232691659149741,
           0.07657472911209624,
           0.055656444964064175,
           0.04664039038744172,
           0.0556564449640812,
           0.07657472911212099,
           0.10232691659152518,
           0.13005579167226966,
           0.15870913183995675,
           0.18784310465700435,
           0.21724196556814662,
           0.24678773513460078,
           0.27640931992900325,
           0.30606021654853494,
           0.33570777458053525,
           0.3653276148495609,
           0.3949005400859503,
           0.4244107338787167,
           0.4538446638429482,
           0.4831903884237409,
           0.5124371046460651,
           0.5415748448419434,
           0.5705942683636206,
           0.5994865155188375,
           0.6282431032552434,
           0.6568558494634712,
           0.6853168172787882,
           0.7136182736021125,
           0.7417526578914048,
           0.7697125584779603,
           0.7974906944684347,
           0.8250799018429478,
           0.8524731227400153,
           0.8796633971862452,
           0.9066438567189039,
           0.9334077194865211,
           0.9599482865126067,
           0.9862589388811835,
           1.0123331356576364,
           1.0381644123995453,
           1.0637463801433864,
           1.089072724776828,
           1.1141372067247275,
           1.1389336608911844,
           1.1634559968111546,
           1.1876981989738888,
           1.211654327287392,
           1.2353185176586303,
           1.2586849826686315,
           1.2817480123251874,
           1.3045019748787456,
           1.3269413176894285,
           1.3490605681350276,
           1.3708543345513948,
           1.3923173071979542,
           1.4134442592421206,
           1.434230047757316,
           1.4546696147300122,
           1.4747579880718533,
           1.4944902826334385,
           1.5138617012167899,
           1.5328675355838954,
           1.5515031674590571,
           1.5697640695230188,
           1.5876458063971037,
           1.6051440356157842,
           1.6222545085862696,
           1.638973071533863,
           1.6552956664319545,
           1.6712183319156348,
           1.686737204178013,
           1.7018485178484033,
           1.7165486068516291,
           1.7308339052477468,
           1.7447009480515698,
           1.758146372031401,
           1.7711669164864505,
           1.7837594240024468,
           1.795920841184989,
           1.8076482193702181,
           1.8189387153124268,
           1.8297895918482405,
           1.8401982185370407,
           1.8501620722773169,
           1.8596787378986603,
           1.868745908729128,
           1.8773613871377277,
           1.885523085051791,
           1.893229024449017,
           1.900477337823985,
           1.9072662686289468,
           1.9135941716887308,
           1.919459513589589,
           1.9248608730418506,
           1.9297969412162284,
           1.9342665220536779,
           1.9382685325486702,
           1.9418020030057976,
           1.944866077269603,
           1.947460012927567,
           1.9495831814861682,
           1.951235068519961,
           1.9524152737936238,
           1.9531235113569194
          ],
          [
           1.9223161527109696,
           1.9220840537454653,
           1.921387813262703,
           1.9202276004910215,
           1.9186036974346135,
           1.9165164988089893,
           1.9139665119506812,
           1.9109543567012277,
           1.9074807652655057,
           1.9035465820444988,
           1.8991527634425747,
           1.8943003776494018,
           1.8889906043966227,
           1.8832247346894186,
           1.8770041705131433,
           1.870330424515186,
           1.8632051196622768,
           1.855629988873438,
           1.8476068746288365,
           1.8391377285547874,
           1.8302246109852065,
           1.820869690499818,
           1.8110752434394708,
           1.8008436533989276,
           1.790177410697543,
           1.7790791118282738,
           1.7675514588855066,
           1.7555972589722355,
           1.7432194235871683,
           1.7304209679923959,
           1.7172050105623207,
           1.7035747721146026,
           1.6895335752239637,
           1.6750848435197665,
           1.6602321009683862,
           1.6449789711414942,
           1.629329176471495,
           1.6132865374954914,
           1.5968549720893115,
           1.580038494693299,
           1.5628412155317772,
           1.5452673398283208,
           1.5273211670192315,
           1.509007089967921,
           1.4903295941832557,
           1.4712932570453072,
           1.4519027470424468,
           1.4321628230242434,
           1.412078333475277,
           1.3916542158157217,
           1.3708954957354242,
           1.3498072865692436,
           1.328394788722625,
           1.3066632891578394,
           1.2846181609530238,
           1.2622648629482232,
           1.2396089394950778,
           1.2166560203297696,
           1.1934118205923914,
           1.1698821410202456,
           1.1460728683478223,
           1.121989975952663,
           1.097639524794199,
           1.0730276647024277,
           1.0481606360853806,
           1.023044772139432,
           0.9976865016654148,
           0.9720923526173847,
           0.9462689565411426,
           0.9202230540983172,
           0.8939615019215221,
           0.8674912811105163,
           0.840819507763328,
           0.8139534460468405,
           0.7869005244580032,
           0.7596683561231339,
           0.7322647642481706,
           0.7046978141950985,
           0.6769758541601857,
           0.6491075671287246,
           0.6211020377701301,
           0.5929688393559663,
           0.5647181478485078,
           0.5363608933613414,
           0.5079089637884712,
           0.4793754824429344,
           0.4507751925693774,
           0.4221249992352788,
           0.39344474803596746,
           0.36475836879282164,
           0.3360955970262795,
           0.30749463769560664,
           0.2790064176498935,
           0.25070161795497375,
           0.2226827737112165,
           0.19510602818587053,
           0.16822211773740697,
           0.14245709281519472,
           0.11857543344057674,
           0.0979951128816957,
           0.08322896995955179,
           0.07768384728903052,
           0.08322896995956279,
           0.09799511288171439,
           0.11857543344059991,
           0.1424570928152204,
           0.16822211773743417,
           0.1951060281858986,
           0.22268277371124515,
           0.2507016179550027,
           0.2790064176499227,
           0.307494637695636,
           0.3360955970263089,
           0.36475836879285106,
           0.39344474803599694,
           0.42212499923530816,
           0.4507751925694069,
           0.4793754824429638,
           0.5079089637885005,
           0.5363608933613706,
           0.564718147848537,
           0.5929688393559953,
           0.6211020377701589,
           0.6491075671287535,
           0.6769758541602141,
           0.7046978141951269,
           0.7322647642481986,
           0.7596683561231621,
           0.7869005244580309,
           0.8139534460468685,
           0.8408195077633556,
           0.8674912811105436,
           0.8939615019215492,
           0.920223054098344,
           0.9462689565411693,
           0.9720923526174111,
           0.997686501665441,
           1.0230447721394578,
           1.0481606360854063,
           1.073027664702453,
           1.097639524794224,
           1.1219899759526881,
           1.1460728683478472,
           1.1698821410202698,
           1.1934118205924156,
           1.2166560203297931,
           1.2396089394951013,
           1.2622648629482462,
           1.2846181609530465,
           1.3066632891578618,
           1.3283947887226473,
           1.3498072865692656,
           1.3708954957354458,
           1.3916542158157428,
           1.4120783334752978,
           1.4321628230242638,
           1.4519027470424668,
           1.4712932570453268,
           1.490329594183275,
           1.50900708996794,
           1.5273211670192497,
           1.5452673398283392,
           1.562841215531795,
           1.5800384946933164,
           1.5968549720893286,
           1.6132865374955083,
           1.6293291764715112,
           1.64497897114151,
           1.6602321009684016,
           1.6750848435197816,
           1.6895335752239786,
           1.703574772114617,
           1.7172050105623342,
           1.7304209679924092,
           1.743219423587181,
           1.755597258972248,
           1.7675514588855186,
           1.7790791118282854,
           1.790177410697554,
           1.800843653398938,
           1.8110752434394812,
           1.8208696904998276,
           1.8302246109852158,
           1.8391377285547963,
           1.8476068746288448,
           1.855629988873446,
           1.8632051196622843,
           1.870330424515193,
           1.8770041705131495,
           1.883224734689425,
           1.8889906043966285,
           1.8943003776494074,
           1.899152763442579,
           1.9035465820445032,
           1.9074807652655097,
           1.9109543567012308,
           1.9139665119506846,
           1.9165164988089918,
           1.918603697434615,
           1.9202276004910228,
           1.921387813262704,
           1.922084053745466
          ],
          [
           1.8913478499145011,
           1.8911198713720405,
           1.8904359914328037,
           1.8892963771492082,
           1.8877013069018866,
           1.8856511703396326,
           1.8831464682953998,
           1.8801878126784242,
           1.8767759263425723,
           1.872911642931034,
           1.8685959066974984,
           1.8638297723039874,
           1.8586144045955333,
           1.8529510783519247,
           1.8468411780167633,
           1.8402861974041171,
           1.8332877393830715,
           1.8258475155405254,
           1.8179673458226115,
           1.8096491581551615,
           1.8008949880436758,
           1.7917069781533048,
           1.782087377869408,
           1.7720385428392917,
           1.761562934495811,
           1.7506631195635738,
           1.739341769548556,
           1.727601660212034,
           1.7154456710298085,
           1.7028767846378219,
           1.6898980862653512,
           1.6765127631571202,
           1.6627241039857823,
           1.6485354982564078,
           1.6339504357047767,
           1.6189725056914852,
           1.6036053965940948,
           1.587852895199831,
           1.5717188861016076,
           1.5552073511005162,
           1.5383223686182876,
           1.5210681131236876,
           1.503448854577303,
           1.4854689578997713,
           1.4671328824691818,
           1.4484451816541457,
           1.4294105023899566,
           1.4100335848063128,
           1.3903192619162963,
           1.3702724593777638,
           1.3498981953399851,
           1.32920158039036,
           1.3081878176184008,
           1.2868622028169545,
           1.2652301248439504,
           1.243297066171907,
           1.2210686036571694,
           1.1985504095665103,
           1.17574825290559,
           1.1526680011020418,
           1.1293156221060279,
           1.1056971869833991,
           1.0818188730916547,
           1.0576869679474656,
           1.0333078739174961,
           1.0086881138928316,
           0.9838343381430724,
           0.9587533325911066,
           0.9334520288064518,
           0.907937516087457,
           0.8822170560954158,
           0.85629810062331,
           0.8301883132373874,
           0.8038955957333481,
           0.777428120617598,
           0.7507943711816735,
           0.7240031912183291,
           0.6970638470792297,
           0.6699861056666695,
           0.6427803331877288,
           0.6154576212308556,
           0.5880299491807888,
           0.560510395517074,
           0.5329134156850264,
           0.5052552118374279,
           0.4775542311843767,
           0.4498318471810216,
           0.4221133050213538,
           0.39442905614170526,
           0.3668166764534946,
           0.3393236787606555,
           0.3120117250485197,
           0.2849630798327658,
           0.25829073037060424,
           0.23215462121165034,
           0.20678819608712037,
           0.18254216743311008,
           0.15995547822852046,
           0.13986128265278458,
           0.12350603786810706,
           0.11255048287859502,
           0.10865215008549892,
           0.11255048287860289,
           0.12350603786812141,
           0.13986128265280354,
           0.15995547822854256,
           0.18254216743313428,
           0.206788196087146,
           0.2321546212116769,
           0.25829073037063144,
           0.2849630798327935,
           0.31201172504854763,
           0.33932367876068376,
           0.3668166764535229,
           0.3944290561417336,
           0.4221133050213822,
           0.4498318471810501,
           0.47755423118440515,
           0.5052552118374565,
           0.5329134156850549,
           0.5605103955171026,
           0.588029949180817,
           0.6154576212308837,
           0.6427803331877567,
           0.6699861056666975,
           0.6970638470792575,
           0.7240031912183567,
           0.7507943711817009,
           0.7774281206176252,
           0.8038955957333753,
           0.8301883132374144,
           0.8562981006233367,
           0.8822170560954423,
           0.9079375160874833,
           0.9334520288064779,
           0.9587533325911325,
           0.9838343381430981,
           1.0086881138928572,
           1.0333078739175212,
           1.0576869679474905,
           1.0818188730916793,
           1.1056971869834238,
           1.1293156221060523,
           1.1526680011020654,
           1.1757482529056136,
           1.1985504095665336,
           1.2210686036571923,
           1.2432970661719296,
           1.2652301248439726,
           1.2868622028169765,
           1.3081878176184225,
           1.3292015803903816,
           1.349898195340006,
           1.3702724593777844,
           1.3903192619163165,
           1.410033584806333,
           1.4294105023899764,
           1.4484451816541648,
           1.467132882469201,
           1.48546895789979,
           1.503448854577321,
           1.5210681131237054,
           1.5383223686183052,
           1.555207351100533,
           1.5717188861016245,
           1.5878528951998476,
           1.6036053965941108,
           1.6189725056915005,
           1.6339504357047918,
           1.6485354982564224,
           1.662724103985797,
           1.6765127631571344,
           1.6898980862653648,
           1.702876784637835,
           1.7154456710298214,
           1.727601660212046,
           1.7393417695485682,
           1.7506631195635853,
           1.761562934495822,
           1.772038542839302,
           1.782087377869418,
           1.7917069781533144,
           1.8008949880436849,
           1.8096491581551704,
           1.81796734582262,
           1.8258475155405332,
           1.833287739383079,
           1.840286197404124,
           1.8468411780167697,
           1.8529510783519307,
           1.858614404595539,
           1.8638297723039925,
           1.8685959066975033,
           1.8729116429310382,
           1.8767759263425763,
           1.8801878126784275,
           1.8831464682954027,
           1.885651170339635,
           1.8877013069018882,
           1.8892963771492093,
           1.8904359914328048,
           1.8911198713720407
          ],
          [
           1.8604846610560526,
           1.8602609254319147,
           1.8595897735885636,
           1.858471370602289,
           1.8569059915639357,
           1.8548940215244951,
           1.8524359554190473,
           1.8495323979691545,
           1.84618406356385,
           1.8423917761193969,
           1.8381564689180272,
           1.8334791844259024,
           1.8283610740905827,
           1.822803398118325,
           1.8168075252315734,
           1.8103749324070615,
           1.8035072045949714,
           1.7962060344196702,
           1.7884732218625898,
           1.7803106739278733,
           1.7717204042914865,
           1.7627045329345554,
           1.753265285761785,
           1.743404994205877,
           1.73312609481899,
           1.7224311288523664,
           1.711322741825378,
           1.6998036830853789,
           1.6878768053598827,
           1.675545064302762,
           1.6628115180363299,
           1.6496793266913872,
           1.6361517519475248,
           1.622232156576247,
           1.607924003989758,
           1.5932308577985914,
           1.5781563813816202,
           1.5627043374724316,
           1.5468785877664986,
           1.5306830925541595,
           1.5141219103850214,
           1.4971991977701378,
           1.479919208929125,
           1.462286295590336,
           1.444304906853314,
           1.4259795891240057,
           1.4073149861346965,
           1.3883158390623362,
           1.3689869867609255,
           1.34933336612596,
           1.3293600126116767,
           1.3090720609250488,
           1.2884747459242876,
           1.267573403754084,
           1.2463734732551526,
           1.2248804976919876,
           1.2031001268502983,
           1.1810381195646957,
           1.1587003467480992,
           1.1360927950075494,
           1.1132215709470994,
           1.0900929062779403,
           1.0667131638797318,
           1.0430888449863682,
           1.0192265977054968,
           0.9951332271258683,
           0.9708157073223734,
           0.9462811956384949,
           0.9215370497139302,
           0.8965908478366936,
           0.8714504133411883,
           0.8461238439561864,
           0.8206195472422839,
           0.7949462835648672,
           0.7691132184502225,
           0.7431299867026967,
           0.7170067713668007,
           0.6907544015661125,
           0.6643844745352561,
           0.637909508918098,
           0.6113431388324015,
           0.5847003615893318,
           0.5579978567377881,
           0.5312544009285315,
           0.5044914129495655,
           0.4777336776903207,
           0.4510103191032491,
           0.4243561241309168,
           0.39781336784197835,
           0.37143436375195515,
           0.3452850765706766,
           0.3194503084993052,
           0.294041233695389,
           0.2692064398716408,
           0.24514814436981208,
           0.2221457514701003,
           0.20058881508743606,
           0.18101890044813926,
           0.16417024236184158,
           0.15097542114639959,
           0.14246751607540087,
           0.13951533894394746,
           0.1424675160754069,
           0.1509754211464109,
           0.16417024236185718,
           0.1810189004481581,
           0.2005888150874573,
           0.2221457514701233,
           0.24514814436983634,
           0.2692064398716659,
           0.29404123369541485,
           0.31945030849933154,
           0.3452850765707034,
           0.37143436375198213,
           0.3978133678420056,
           0.42435612413094415,
           0.45101031910327655,
           0.47773367769034825,
           0.504491412949593,
           0.5312544009285589,
           0.5579978567378158,
           0.5847003615893592,
           0.6113431388324289,
           0.6379095089181251,
           0.664384474535283,
           0.6907544015661394,
           0.7170067713668276,
           0.7431299867027236,
           0.7691132184502492,
           0.7949462835648937,
           0.8206195472423101,
           0.8461238439562125,
           0.8714504133412142,
           0.8965908478367196,
           0.9215370497139558,
           0.9462811956385202,
           0.9708157073223986,
           0.9951332271258932,
           1.0192265977055217,
           1.0430888449863929,
           1.066713163879756,
           1.090092906277964,
           1.1132215709471234,
           1.1360927950075728,
           1.1587003467481223,
           1.1810381195647186,
           1.203100126850321,
           1.2248804976920098,
           1.2463734732551748,
           1.2675734037541055,
           1.2884747459243087,
           1.3090720609250697,
           1.3293600126116973,
           1.3493333661259805,
           1.3689869867609454,
           1.388315839062356,
           1.4073149861347158,
           1.4259795891240246,
           1.4443049068533325,
           1.4622862955903542,
           1.4799192089291429,
           1.4971991977701555,
           1.5141219103850387,
           1.5306830925541766,
           1.5468785877665154,
           1.5627043374724476,
           1.5781563813816357,
           1.5932308577986065,
           1.607924003989773,
           1.6222321565762614,
           1.6361517519475393,
           1.649679326691401,
           1.6628115180363432,
           1.675545064302775,
           1.6878768053598951,
           1.6998036830853906,
           1.7113227418253896,
           1.7224311288523775,
           1.7331260948190008,
           1.743404994205887,
           1.7532652857617947,
           1.762704532934565,
           1.7717204042914954,
           1.780310673927882,
           1.7884732218625976,
           1.7962060344196775,
           1.8035072045949785,
           1.8103749324070686,
           1.8168075252315796,
           1.8228033981183307,
           1.8283610740905882,
           1.8334791844259075,
           1.8381564689180314,
           1.842391776119401,
           1.8461840635638536,
           1.8495323979691578,
           1.8524359554190502,
           1.8548940215244976,
           1.8569059915639374,
           1.8584713706022904,
           1.8595897735885645,
           1.8602609254319156
          ],
          [
           1.8297564442775769,
           1.829537075219973,
           1.828879022485321,
           1.82778244937856,
           1.8262476280428137,
           1.8242749394117967,
           1.821864873143342,
           1.819018027534189,
           1.81573510941623,
           1.8120169340344674,
           1.8078644249069606,
           1.8032786136671102,
           1.798260639888677,
           1.7928117508939796,
           1.7869333015457922,
           1.7806267540235072,
           1.7738936775842156,
           1.766735748309419,
           1.7591547488381758,
           1.7511525680875613,
           1.742731200961436,
           1.7338927480485922,
           1.7246394153114937,
           1.7149735137669262,
           1.7048974591600285,
           1.6944137716333263,
           1.68352507539255,
           1.672234098371228,
           1.6605436718962436,
           1.6484567303567803,
           1.6359763108793535,
           1.6231055530119205,
           1.6098476984203856,
           1.5962060906012052,
           1.5821841746142202,
           1.567785496840309,
           1.553013704769023,
           1.5378725468219554,
           1.5223658722183273,
           1.5064976308900462,
           1.4902718734544342,
           1.473692751253857,
           1.4567645164726932,
           1.4394915223434719,
           1.4218782234556007,
           1.403929176181952,
           1.3856490392407221,
           1.3670425744124537,
           1.348114647435006,
           1.3288702291026457,
           1.309314396599366,
           1.2894523351012035,
           1.2692893396877605,
           1.2488308176096141,
           1.2280822909659104,
           1.2070493998555205,
           1.1857379060759485,
           1.1641536974571074,
           1.1423027929325844,
           1.1201913484697112,
           1.0978256640023258,
           1.075212191537522,
           1.0523575446410731,
           1.0292685095470675,
           1.0059520581874979,
           0.982415363499526,
           0.9586658174450035,
           0.934711052272643,
           0.9105589656732448,
           0.8862177506295507,
           0.8616959309537098,
           0.8370024037491737,
           0.8121464903462602,
           0.7871379976634685,
           0.7619872924694223,
           0.7367053917033763,
           0.7113040729109051,
           0.6857960100423418,
           0.6601949414515695,
           0.6345158790718697,
           0.6087753706457084,
           0.5829918308482807,
           0.5571859626019477,
           0.5313812974507258,
           0.5056048944441487,
           0.4798882518535642,
           0.4542685070484547,
           0.42879002957972256,
           0.40350655446570943,
           0.3784840613123524,
           0.353804685004525,
           0.3295720479593975,
           0.30591852577550027,
           0.28301506333331355,
           0.26108414188908113,
           0.2404160927365794,
           0.22138757660360522,
           0.20447766310364965,
           0.19027041647098925,
           0.17942417549892867,
           0.17258506318879716,
           0.17024355572242306,
           0.1725850631888019,
           0.17942417549893785,
           0.1902704164710022,
           0.20447766310366572,
           0.22138757660362376,
           0.24041609273659992,
           0.26108414188910306,
           0.28301506333333654,
           0.30591852577552425,
           0.32957204795942213,
           0.35380468500455015,
           0.37848406131237794,
           0.4035065544657353,
           0.42879002957974865,
           0.4542685070484809,
           0.4798882518535907,
           0.5056048944441752,
           0.5313812974507522,
           0.5571859626019743,
           0.5829918308483072,
           0.6087753706457348,
           0.6345158790718961,
           0.660194941451596,
           0.6857960100423681,
           0.7113040729109311,
           0.7367053917034023,
           0.7619872924694483,
           0.7871379976634945,
           0.8121464903462858,
           0.837002403749199,
           0.8616959309537352,
           0.8862177506295759,
           0.9105589656732698,
           0.9347110522726676,
           0.958665817445028,
           0.98241536349955,
           1.005952058187522,
           1.0292685095470913,
           1.0523575446410967,
           1.0752121915375454,
           1.097825664002349,
           1.1201913484697341,
           1.142302792932607,
           1.1641536974571296,
           1.1857379060759707,
           1.2070493998555423,
           1.2280822909659321,
           1.2488308176096354,
           1.2692893396877811,
           1.289452335101224,
           1.3093143965993863,
           1.3288702291026657,
           1.3481146474350258,
           1.367042574412473,
           1.3856490392407412,
           1.4039291761819703,
           1.4218782234556189,
           1.4394915223434899,
           1.4567645164727105,
           1.473692751253874,
           1.4902718734544511,
           1.5064976308900628,
           1.5223658722183437,
           1.5378725468219714,
           1.553013704769038,
           1.5677854968403242,
           1.5821841746142347,
           1.5962060906012197,
           1.6098476984203995,
           1.6231055530119338,
           1.6359763108793663,
           1.6484567303567927,
           1.6605436718962558,
           1.6722340983712398,
           1.6835250753925615,
           1.6944137716333374,
           1.704897459160039,
           1.7149735137669357,
           1.7246394153115032,
           1.7338927480486013,
           1.7427312009614448,
           1.7511525680875697,
           1.7591547488381833,
           1.7667357483094266,
           1.7738936775842225,
           1.7806267540235137,
           1.7869333015457982,
           1.7928117508939854,
           1.798260639888682,
           1.803278613667115,
           1.807864424906965,
           1.8120169340344716,
           1.8157351094162337,
           1.8190180275341923,
           1.821864873143345,
           1.824274939411799,
           1.8262476280428153,
           1.8277824493785613,
           1.828879022485322,
           1.8295370752199736
          ],
          [
           1.799192927144257,
           1.798978049211264,
           1.7983334693286899,
           1.7972593492377964,
           1.7957559584808667,
           1.7938236743615752,
           1.791462981889705,
           1.7886744737104159,
           1.7854588500183186,
           1.7818169184566877,
           1.7777495940021952,
           1.7732578988356247,
           1.7683429621990892,
           1.7630060202403643,
           1.7572484158450132,
           1.751071598457079,
           1.744477123889205,
           1.7374666541231523,
           1.730041957101781,
           1.7222049065136904,
           1.7139574815718424,
           1.7053017667876218,
           1.6962399517419644,
           1.6867743308553307,
           1.6769073031585142,
           1.6666413720664714,
           1.6559791451575911,
           1.6449233339610931,
           1.6334767537555195,
           1.621642323381616,
           1.6094230650732528,
           1.596822104310448,
           1.5838426696990056,
           1.5704880928817941,
           1.556761808487267,
           1.542667354121489,
           1.5282083704106602,
           1.5133886011019766,
           1.4982118932316184,
           1.482682197369747,
           1.466803567953631,
           1.4505801637214455,
           1.434016248260912,
           1.4171161906888254,
           1.3998844664796657,
           1.3823256584639725,
           1.36444445802005,
           1.346245666485894,
           1.3277341968221088,
           1.3089150755611059,
           1.289793445083141,
           1.2703745662659296,
           1.2506638215618338,
           1.2306667185651587,
           1.210388894142183,
           1.1898361192085058,
           1.1690143042524892,
           1.1479295057205074,
           1.126587933399954,
           1.1049959589602514,
           1.0831601258413508,
           1.061087160714559,
           1.0387839867833955,
           1.0162577392443892,
           0.9935157832915338,
           0.9705657351264687,
           0.9474154865330172,
           0.9240732336943017,
           0.9005475110793958,
           0.8768472314123571,
           0.8529817329699055,
           0.828960835748594,
           0.8047949084159676,
           0.7804949484366451,
           0.7560726783749793,
           0.7315406621630317,
           0.7069124461425075,
           0.6822027310180113,
           0.6574275825992906,
           0.6326046915011094,
           0.6077536949997189,
           0.5828965782698543,
           0.5580581775899062,
           0.5332668152644012,
           0.5085551055735221,
           0.48396098378076574,
           0.4595290270176313,
           0.4353121576581478,
           0.41137384723756265,
           0.38779097157586423,
           0.36465750206442804,
           0.3420892436482521,
           0.3202298216848617,
           0.29925802326097917,
           0.2793963075839985,
           0.2609196315221456,
           0.24416243547021146,
           0.22951951371347962,
           0.21743390069660629,
           0.20836363091251806,
           0.20272308218564059,
           0.20080707285574295,
           0.20272308218564453,
           0.20836363091252566,
           0.21743390069661725,
           0.22951951371349338,
           0.24416243547022765,
           0.2609196315221638,
           0.2793963075840183,
           0.2992580232610002,
           0.3202298216848838,
           0.3420892436482749,
           0.36465750206445163,
           0.38779097157588827,
           0.4113738472375871,
           0.4353121576581725,
           0.45952902701765636,
           0.48396098378079094,
           0.5085551055735476,
           0.5332668152644267,
           0.5580581775899318,
           0.5828965782698797,
           0.6077536949997444,
           0.632604691501135,
           0.657427582599316,
           0.6822027310180367,
           0.7069124461425328,
           0.7315406621630571,
           0.7560726783750044,
           0.7804949484366701,
           0.8047949084159923,
           0.8289608357486188,
           0.8529817329699301,
           0.8768472314123816,
           0.9005475110794201,
           0.9240732336943257,
           0.9474154865330412,
           0.9705657351264925,
           0.9935157832915574,
           1.0162577392444125,
           1.0387839867834188,
           1.061087160714582,
           1.0831601258413734,
           1.1049959589602738,
           1.126587933399976,
           1.147929505720529,
           1.1690143042525107,
           1.1898361192085272,
           1.210388894142204,
           1.2306667185651794,
           1.2506638215618542,
           1.2703745662659496,
           1.2897934450831605,
           1.3089150755611254,
           1.327734196822128,
           1.346245666485913,
           1.3644444580200685,
           1.3823256584639905,
           1.3998844664796837,
           1.417116190688843,
           1.434016248260929,
           1.4505801637214624,
           1.4668035679536475,
           1.4826821973697633,
           1.4982118932316342,
           1.5133886011019921,
           1.5282083704106753,
           1.5426673541215035,
           1.5567618084872812,
           1.570488092881808,
           1.5838426696990198,
           1.596822104310461,
           1.6094230650732655,
           1.6216423233816286,
           1.6334767537555317,
           1.6449233339611045,
           1.6559791451576025,
           1.6666413720664823,
           1.6769073031585244,
           1.6867743308553405,
           1.696239951741974,
           1.7053017667876307,
           1.713957481571851,
           1.7222049065136988,
           1.7300419571017889,
           1.7374666541231598,
           1.744477123889212,
           1.7510715984570853,
           1.7572484158450195,
           1.7630060202403701,
           1.768342962199094,
           1.7732578988356293,
           1.7777495940021997,
           1.7818169184566914,
           1.785458850018322,
           1.788674473710419,
           1.791462981889708,
           1.7938236743615772,
           1.7957559584808684,
           1.7972593492377977,
           1.7983334693286905,
           1.7989780492112648
          ],
          [
           1.768823677885006,
           1.7686134162648366,
           1.7679826848682982,
           1.7669316440811527,
           1.765460561192537,
           1.7635698103643949,
           1.7612598725889375,
           1.7585313356343901,
           1.755384893979362,
           1.7518213487362584,
           1.7478416075642327,
           1.74344668457226,
           1.7386377002130258,
           1.7334158811683902,
           1.7277825602273194,
           1.7217391761572765,
           1.7152872735701818,
           1.7084285027841861,
           1.7011646196826453,
           1.6934974855718299,
           1.6854290670390755,
           1.6769614358132663,
           1.6680967686297408,
           1.6588373471019326,
           1.649185557602307,
           1.6391438911554255,
           1.6287149433462709,
           1.6179014142472992,
           1.6067061083680676,
           1.5951319346316921,
           1.5831819063828663,
           1.5708591414326913,
           1.5581668621461584,
           1.5451083955787774,
           1.531687173669603,
           1.5179067334987493,
           1.5037707176184216,
           1.4892828744675963,
           1.4744470588816854,
           1.4592672327099323,
           1.4437474655548652,
           1.4278919356499555,
           1.4117049308937075,
           1.3951908500607852,
           1.3783542042135355,
           1.361199618340399,
           1.3437318332513732,
           1.3259557077648831,
           1.3078762212253106,
           1.289498476396118,
           1.2708277027801114,
           1.2518692604261257,
           1.2326286442904533,
           1.2131114892319799,
           1.1933235757324825,
           1.173270836448317,
           1.1529593637172053,
           1.132395418164566,
           1.111585438578562,
           1.0905360532525388,
           1.0692540930288994,
           1.0477466063209817,
           1.0260208764407903,
           1.0040844416225059,
           0.9819451182071051,
           0.9596110275453328,
           0.9370906272887325,
           0.914392747876566,
           0.891526635196734,
           0.8685020006095711,
           0.8453290797852525,
           0.8220187021322258,
           0.7985823730031807,
           0.7750323713793994,
           0.751381866383416,
           0.727645056791971,
           0.7038373387659164,
           0.6799755083451209,
           0.6560780069572982,
           0.6321652203658912,
           0.6082598442675206,
           0.5843873333098799,
           0.5605764548347808,
           0.5368599743818142,
           0.5132755071380543,
           0.48986657824495,
           0.46668394512614897,
           0.4437872462425822,
           0.42124705134452706,
           0.39914739476940786,
           0.37758886822474064,
           0.3566923187013234,
           0.336603115649757,
           0.317495778463767,
           0.2995784320427257,
           0.2830960200378134,
           0.2683304293674949,
           0.25559480086063013,
           0.24521880127332674,
           0.23752246495676277,
           0.2327794646468593,
           0.23117632211499411,
           0.2327794646468626,
           0.2375224649567692,
           0.2452188012733361,
           0.25559480086064207,
           0.268330429367509,
           0.2830960200378296,
           0.2995784320427435,
           0.317495778463786,
           0.33660311564977724,
           0.35669231870134455,
           0.3775888682247625,
           0.3991473947694303,
           0.42124705134455004,
           0.44378724624260557,
           0.4666839451261728,
           0.48986657824497404,
           0.5132755071380786,
           0.5368599743818385,
           0.5605764548348053,
           0.5843873333099044,
           0.608259844267545,
           0.6321652203659157,
           0.6560780069573228,
           0.6799755083451454,
           0.7038373387659409,
           0.7276450567919953,
           0.7513818663834403,
           0.7750323713794237,
           0.7985823730032047,
           0.8220187021322499,
           0.8453290797852763,
           0.8685020006095948,
           0.8915266351967576,
           0.9143927478765894,
           0.9370906272887557,
           0.9596110275453558,
           0.9819451182071278,
           1.0040844416225285,
           1.0260208764408127,
           1.0477466063210041,
           1.0692540930289214,
           1.0905360532525605,
           1.1115854385785833,
           1.1323954181645872,
           1.1529593637172262,
           1.173270836448338,
           1.193323575732503,
           1.213111489232,
           1.2326286442904733,
           1.2518692604261452,
           1.2708277027801307,
           1.2894984763961368,
           1.3078762212253292,
           1.3259557077649016,
           1.3437318332513912,
           1.3611996183404165,
           1.3783542042135528,
           1.3951908500608026,
           1.4117049308937237,
           1.4278919356499722,
           1.4437474655548812,
           1.4592672327099483,
           1.474447058881701,
           1.4892828744676114,
           1.5037707176184365,
           1.5179067334987635,
           1.5316871736696167,
           1.5451083955787908,
           1.558166862146172,
           1.5708591414327042,
           1.5831819063828783,
           1.5951319346317039,
           1.6067061083680794,
           1.6179014142473105,
           1.628714943346282,
           1.6391438911554361,
           1.649185557602317,
           1.6588373471019422,
           1.6680967686297503,
           1.6769614358132752,
           1.6854290670390837,
           1.6934974855718379,
           1.7011646196826529,
           1.708428502784193,
           1.7152872735701885,
           1.721739176157283,
           1.7277825602273253,
           1.7334158811683957,
           1.738637700213031,
           1.7434466845722647,
           1.747841607564237,
           1.7518213487362628,
           1.7553848939793653,
           1.7585313356343932,
           1.7612598725889401,
           1.7635698103643966,
           1.7654605611925382,
           1.7669316440811538,
           1.7679826848682991,
           1.7686134162648368
          ],
          [
           1.7386780767871148,
           1.7384725569785728,
           1.737856050633068,
           1.7368287169868275,
           1.735390821419807,
           1.7335427354352166,
           1.7312849366311749,
           1.728618008664821,
           1.725542641209287,
           1.7220596299040685,
           1.7181698762994049,
           1.7138743877954024,
           1.709174277576746,
           1.7040707645439745,
           1.6985651732424076,
           1.6926589337899745,
           1.6863535818053181,
           1.6796507583377405,
           1.6725522098007028,
           1.6650597879108044,
           1.657175449634368,
           1.6489012571439814,
           1.6402393777876105,
           1.6311920840731657,
           1.62176175367171,
           1.611950869442845,
           1.6017620194861726,
           1.5911978972231633,
           1.5802613015142084,
           1.5689551368161725,
           1.557282413386321,
           1.5452462475391588,
           1.532849861963446,
           1.5200965861074591,
           1.5069898566414988,
           1.4935332180076843,
           1.4797303230682328,
           1.465584933864767,
           1.4511009225026767,
           1.436282272176294,
           1.4211330783525604,
           1.4056575501330972,
           1.3898600118171158,
           1.3737449046904995,
           1.3573167890697162,
           1.340580346633033,
           1.3235403830758994,
           1.3062018311324426,
           1.2885697540108698,
           1.2706493492973798,
           1.252445953391067,
           1.233965046541489,
           1.215212258571293,
           1.1961933753788156,
           1.176914346330289,
           1.1573812926685392,
           1.1376005170854375,
           1.1175785146294077,
           1.097321985147791,
           1.0768378474977212,
           1.0561332557994838,
           1.0352156180545067,
           1.0140926175078395,
           0.9927722372043247,
           0.9712627882712311,
           0.9495729425611193,
           0.9277117704111617,
           0.9056887844240074,
           0.8835139903568305,
           0.8611979464272111,
           0.8387518326167467,
           0.816187531888033,
           0.7935177256431943,
           0.7707560062616595,
           0.7479170101852128,
           0.7250165757990514,
           0.7020719313248897,
           0.6791019191398774,
           0.6561272644151043,
           0.6331708977888345,
           0.6102583440157172,
           0.5874181912240529,
           0.5646826586094486,
           0.542088284085346,
           0.5196767574822472,
           0.4974959290126743,
           0.47560102618980676,
           0.4540561138227307,
           0.43293582859163676,
           0.41232740767722575,
           0.392333002831457,
           0.3730722161044706,
           0.35468469561918975,
           0.3373324704505834,
           0.321201466951016,
           0.30650133840785204,
           0.2934624110028499,
           0.28232835348881613,
           0.2733433922773871,
           0.2667338552374925,
           0.26268568838862255,
           0.2613219232128851,
           0.2626856883886254,
           0.266733855237498,
           0.2733433922773951,
           0.28232835348882646,
           0.29346241100286236,
           0.3065013384078664,
           0.32120146695103186,
           0.33733247045060066,
           0.3546846956192082,
           0.37307221610449004,
           0.3923330028314772,
           0.4123274076772466,
           0.43293582859165824,
           0.45405611382275274,
           0.47560102618982913,
           0.49749592901269696,
           0.5196767574822702,
           0.5420882840853692,
           0.5646826586094719,
           0.5874181912240765,
           0.6102583440157406,
           0.6331708977888582,
           0.6561272644151278,
           0.6791019191399009,
           0.7020719313249132,
           0.725016575799075,
           0.7479170101852363,
           0.7707560062616831,
           0.7935177256432177,
           0.8161875318880564,
           0.8387518326167699,
           0.861197946427234,
           0.8835139903568533,
           0.90568878442403,
           0.9277117704111844,
           0.9495729425611418,
           0.9712627882712533,
           0.9927722372043468,
           1.014092617507861,
           1.0352156180545284,
           1.0561332557995053,
           1.0768378474977423,
           1.097321985147812,
           1.1175785146294284,
           1.137600517085458,
           1.1573812926685596,
           1.176914346330309,
           1.1961933753788354,
           1.2152122585713123,
           1.2339650465415082,
           1.2524459533910854,
           1.2706493492973985,
           1.288569754010888,
           1.3062018311324606,
           1.3235403830759171,
           1.3405803466330504,
           1.3573167890697335,
           1.3737449046905161,
           1.389860011817132,
           1.4056575501331132,
           1.4211330783525762,
           1.4362822721763095,
           1.4511009225026916,
           1.4655849338647817,
           1.4797303230682473,
           1.493533218007698,
           1.5069898566415123,
           1.5200965861074722,
           1.5328498619634594,
           1.545246247539171,
           1.557282413386333,
           1.5689551368161843,
           1.58026130151422,
           1.5911978972231742,
           1.6017620194861835,
           1.6119508694428555,
           1.6217617536717202,
           1.6311920840731753,
           1.6402393777876196,
           1.6489012571439896,
           1.6571754496343762,
           1.6650597879108122,
           1.6725522098007104,
           1.6796507583377476,
           1.686353581805325,
           1.692658933789981,
           1.6985651732424134,
           1.7040707645439799,
           1.709174277576751,
           1.713874387795407,
           1.7181698762994093,
           1.7220596299040722,
           1.7255426412092905,
           1.7286180086648242,
           1.7312849366311778,
           1.7335427354352184,
           1.7353908214198086,
           1.7368287169868288,
           1.737856050633069,
           1.7384725569785733
          ],
          [
           1.7087852877727236,
           1.7085846352226046,
           1.7079827303353632,
           1.7069797313983996,
           1.7055759022176296,
           1.7037716121080413,
           1.7015673358808754,
           1.698963653827798,
           1.6959612517025864,
           1.6925609207009615,
           1.6887635574393012,
           1.6845701639331458,
           1.6799818475765047,
           1.6749998211231445,
           1.6696254026711894,
           1.6638600156525345,
           1.657705188828752,
           1.6511625562953685,
           1.6442338574966089,
           1.6369209372529197,
           1.6292257458038573,
           1.6211503388691835,
           1.6126968777313309,
           1.6038676293427234,
           1.5946649664618113,
           1.5850913678220875,
           1.5751494183387962,
           1.5648418093585643,
           1.5541713389577136,
           1.543140912295666,
           1.5317535420305177,
           1.5200123488046535,
           1.5079205618091285,
           1.495481519436522,
           1.482698670033064,
           1.4695755727620583,
           1.4561158985920313,
           1.442323431424586,
           1.4282020693787227,
           1.4137558262504095,
           1.398988833168455,
           1.3839053404703447,
           1.3685097198246534,
           1.3528064666300388,
           1.3368002027246744,
           1.320495679444411,
           1.3038977810730439,
           1.2870115287338992,
           1.269842084778699,
           1.2523947577374346,
           1.2346750079019813,
           1.2166884536266238,
           1.1984408784407743,
           1.179938239083296,
           1.1611866745842951,
           1.142192516539526,
           1.122962300745108,
           1.1035027803867885,
           1.083820941009193,
           1.063924017527357,
           1.0438195135864063,
           1.0235152236269216,
           1.0030192580749016,
           0.9823400721483564,
           0.9614864988598182,
           0.940467786898427,
           0.9192936442003578,
           0.8979742881665874,
           0.8765205036677329,
           0.8549437101934537,
           0.8332560397665694,
           0.8114704275591748,
           0.78960071753096,
           0.7676617858721997,
           0.7456696855910951,
           0.7236418162551552,
           0.7015971236985031,
           0.6795563354612029,
           0.6575422388506024,
           0.6355800098191632,
           0.6136976023339532,
           0.5919262095362706,
           0.5703008096690161,
           0.5488608113064143,
           0.5276508135256294,
           0.5067214967379489,
           0.48613065799110267,
           0.4659443991306087,
           0.4462384649081141,
           0.4270997074917641,
           0.40862761912574136,
           0.3909358200409304,
           0.37415330820672,
           0.35842516799119367,
           0.343912301754706,
           0.33078961560088455,
           0.31924201180434897,
           0.30945760630600544,
           0.30161791213581746,
           0.2958853852461819,
           0.29238965885845336,
           0.29121471222727646,
           0.29238965885845575,
           0.2958853852461867,
           0.30161791213582445,
           0.3094576063060145,
           0.3192420118043599,
           0.33078961560089726,
           0.34391230175472026,
           0.35842516799120927,
           0.3741533082067367,
           0.3909358200409482,
           0.40862761912575996,
           0.4270997074917834,
           0.446238464908134,
           0.4659443991306292,
           0.4861306579911236,
           0.5067214967379703,
           0.5276508135256511,
           0.5488608113064362,
           0.5703008096690384,
           0.5919262095362928,
           0.6136976023339755,
           0.6355800098191857,
           0.6575422388506249,
           0.6795563354612254,
           0.7015971236985259,
           0.7236418162551779,
           0.7456696855911177,
           0.7676617858722222,
           0.7896007175309823,
           0.8114704275591972,
           0.8332560397665917,
           0.854943710193476,
           0.876520503667755,
           0.8979742881666093,
           0.9192936442003797,
           0.9404677868984486,
           0.9614864988598397,
           0.9823400721483777,
           1.0030192580749226,
           1.023515223626943,
           1.0438195135864272,
           1.0639240175273774,
           1.0838209410092132,
           1.1035027803868085,
           1.122962300745128,
           1.1421925165395457,
           1.1611866745843147,
           1.179938239083315,
           1.1984408784407932,
           1.2166884536266422,
           1.2346750079019995,
           1.2523947577374526,
           1.2698420847787169,
           1.2870115287339168,
           1.303897781073061,
           1.3204956794444278,
           1.3368002027246908,
           1.352806466630055,
           1.3685097198246694,
           1.3839053404703605,
           1.3989888331684706,
           1.4137558262504244,
           1.4282020693787374,
           1.4423234314246007,
           1.4561158985920455,
           1.4695755727620714,
           1.4826986700330769,
           1.4954815194365352,
           1.5079205618091414,
           1.520012348804666,
           1.5317535420305297,
           1.5431409122956776,
           1.554171338957725,
           1.564841809358575,
           1.5751494183388068,
           1.5850913678220977,
           1.594664966461821,
           1.6038676293427327,
           1.61269687773134,
           1.621150338869192,
           1.6292257458038655,
           1.6369209372529272,
           1.644233857496616,
           1.6511625562953753,
           1.6577051888287582,
           1.6638600156525407,
           1.6696254026711952,
           1.67499982112315,
           1.6799818475765096,
           1.6845701639331503,
           1.6887635574393052,
           1.692560920700965,
           1.69596125170259,
           1.6989636538278006,
           1.7015673358808778,
           1.7037716121080433,
           1.7055759022176304,
           1.706979731398401,
           1.7079827303353643,
           1.7085846352226057
          ],
          [
           1.679174230184608,
           1.6789785698787643,
           1.6783916414713091,
           1.6774136024928932,
           1.6760447154960607,
           1.6742853480576705,
           1.6721359727827423,
           1.6695971673101933,
           1.6666696143210584,
           1.6633541015499547,
           1.6596515218006613,
           1.6555628729668836,
           1.6510892580594023,
           1.6462318852409994,
           1.6409920678707384,
           1.6353712245593688,
           1.6293708792378385,
           1.6229926612411405,
           1.616238305409956,
           1.6091096522128363,
           1.6016086478919607,
           1.5937373446358378,
           1.5854979007826555,
           1.576892581058407,
           1.5679237568543174,
           1.5585939065485948,
           1.5489056158780514,
           1.5388615783657125,
           1.528464595811195,
           1.5177175788513515,
           1.5066235475994678,
           1.4951856323722243,
           1.4834070745146075,
           1.4712912273340941,
           1.4588415571566908,
           1.4460616445188186,
           1.4329551855106286,
           1.4195259932881283,
           1.4057779997735242,
           1.3917152575654665,
           1.37734194208349,
           1.3626623539738663,
           1.3476809218074426,
           1.3324022051038242,
           1.3168308977206071,
           1.300971831651303,
           1.2848299812812636,
           1.268410468157392,
           1.2517185663348704,
           1.234759708372691,
           1.2175394920596228,
           1.2000636879636364,
           1.182338247910925,
           1.1643693145159164,
           1.1461632319013004,
           1.1277265577676514,
           1.1090660769961103,
           1.0901888169954912,
           1.071102065037761,
           1.0518133878639933,
           1.0323306538876438,
           1.0126620583745445,
           0.9928161520408378,
           0.97280187358292,
           0.9526285867393666,
           0.9323061225862945,
           0.9118448278875196,
           0.8912556204626885,
           0.8705500527042809,
           0.8497403845726678,
           0.8288396676326268,
           0.8078618419708204,
           0.7868218481583263,
           0.7657357568021835,
           0.7446209186716973,
           0.7234961388944164,
           0.7023818792959315,
           0.6813004936043561,
           0.6602765009423331,
           0.6393369037584871,
           0.6185115570519325,
           0.5978335963220719,
           0.5773399319717831,
           0.5570718176494407,
           0.537075498837081,
           0.5174029452809608,
           0.4981126657463056,
           0.4792705948407624,
           0.4609510276694986,
           0.44323755686375943,
           0.4262239359155469,
           0.41001475104982776,
           0.39472573104707437,
           0.3804834642827445,
           0.3674242354601611,
           0.3556916620046311,
           0.3454328345324344,
           0.33679278726159967,
           0.3299073749789821,
           0.32489501032326334,
           0.3218481501913122,
           0.3208257698153919,
           0.32184815019131435,
           0.32489501032326756,
           0.3299073749789882,
           0.33679278726160766,
           0.34543283453244417,
           0.35569166200464253,
           0.36742423546017394,
           0.3804834642827585,
           0.39472573104708963,
           0.4100147510498441,
           0.426223935915564,
           0.4432375568637772,
           0.4609510276695172,
           0.47927059484078155,
           0.4981126657463252,
           0.5174029452809809,
           0.5370754988371013,
           0.5570718176494613,
           0.5773399319718042,
           0.597833596322093,
           0.6185115570519538,
           0.6393369037585085,
           0.6602765009423547,
           0.6813004936043776,
           0.7023818792959533,
           0.723496138894438,
           0.744620918671719,
           0.7657357568022052,
           0.7868218481583481,
           0.8078618419708419,
           0.8288396676326484,
           0.8497403845726892,
           0.8705500527043021,
           0.8912556204627097,
           0.9118448278875406,
           0.9323061225863155,
           0.9526285867393876,
           0.9728018735829406,
           0.9928161520408585,
           1.0126620583745647,
           1.0323306538876642,
           1.051813387864013,
           1.0711020650377805,
           1.0901888169955107,
           1.1090660769961296,
           1.1277265577676705,
           1.1461632319013193,
           1.1643693145159348,
           1.1823382479109432,
           1.2000636879636544,
           1.2175394920596405,
           1.2347597083727082,
           1.2517185663348878,
           1.268410468157409,
           1.2848299812812805,
           1.3009718316513195,
           1.3168308977206233,
           1.3324022051038398,
           1.347680921807458,
           1.3626623539738816,
           1.377341942083505,
           1.3917152575654814,
           1.4057779997735382,
           1.419525993288142,
           1.4329551855106422,
           1.446061644518832,
           1.4588415571567042,
           1.4712912273341068,
           1.48340707451462,
           1.4951856323722363,
           1.5066235475994794,
           1.5177175788513628,
           1.5284645958112062,
           1.5388615783657227,
           1.5489056158780616,
           1.5585939065486047,
           1.5679237568543267,
           1.5768925810584158,
           1.5854979007826642,
           1.5937373446358458,
           1.6016086478919684,
           1.6091096522128434,
           1.6162383054099632,
           1.6229926612411472,
           1.6293708792378445,
           1.635371224559375,
           1.6409920678707437,
           1.6462318852410045,
           1.651089258059407,
           1.655562872966888,
           1.659651521800665,
           1.6633541015499582,
           1.6666696143210618,
           1.669597167310196,
           1.672135972782745,
           1.6742853480576725,
           1.676044715496062,
           1.677413602492894,
           1.6783916414713098,
           1.6789785698787647
          ],
          [
           1.649873550808585,
           1.6496830068133512,
           1.6491114271445573,
           1.6481589687558407,
           1.646825893246389,
           1.6451125668758912,
           1.643019460586001,
           1.6405471500288478,
           1.6376963156032884,
           1.6344677424997682,
           1.6308623207548145,
           1.6268810453163878,
           1.6225250161214861,
           1.617795438187615,
           1.6126936217199344,
           1.6072209822361427,
           1.601379040711386,
           1.595169423745751,
           1.588593863757202,
           1.58165419920311,
           1.5743523748338808,
           1.566690441982557,
           1.5586705588946634,
           1.5502949911030335,
           1.541566111852822,
           1.532486402582467,
           1.523058453466954,
           1.5132849640304027,
           1.5031687438357184,
           1.492712713259879,
           1.4819199043643214,
           1.4707934618709073,
           1.459336644255067,
           1.4475528249689853,
           1.4354454938090873,
           1.4230182584436721,
           1.4102748461183023,
           1.3972191055585454,
           1.3838550090919077,
           1.3701866550133135,
           1.3562182702213432,
           1.3419542131556499,
           1.3273989770696266,
           1.3125571936765266,
           1.2974336372119375,
           1.2820332289608325,
           1.266361042303517,
           1.2504223083417132,
           1.234222422173939,
           1.2177669498984145,
           1.2010616364320856,
           1.1841124142462898,
           1.1669254131332512,
           1.1495069711333599,
           1.131863646771323,
           1.114002232770225,
           1.0959297714367278,
           1.077653571938635,
           1.0591812297284622,
           1.0405206484042526,
           1.0216800643425012,
           1.0026680744887237,
           0.9834936677500904,
           0.9641662605029976,
           0.944695736808035,
           0.9250924940172726,
           0.9053674945661773,
           0.885532324866961,
           0.8655992623641783,
           0.8455813519794882,
           0.8254924933631391,
           0.8053475405872554,
           0.785162416162052,
           0.764954241531119,
           0.7447414865042801,
           0.724544140411026,
           0.7043839080934146,
           0.6842844341851387,
           0.6642715594107192,
           0.6443736128335037,
           0.6246217440032052,
           0.6050502986827,
           0.5856972410932758,
           0.5666046241552133,
           0.5478191066654721,
           0.5293925122736334,
           0.5113824188814045,
           0.4938527579602553,
           0.47687439044307317,
           0.4605256085616527,
           0.4448924909136683,
           0.4300690116985085,
           0.41615677671860996,
           0.4032642334010368,
           0.39150518848840044,
           0.3809964779585228,
           0.3718546845047546,
           0.36419190190660217,
           0.358110706054426,
           0.35369869231078294,
           0.3510231347253015,
           0.3501264491914149,
           0.35102313472530333,
           0.35369869231078654,
           0.35811070605443146,
           0.3641919019066092,
           0.37185468450476333,
           0.3809964779585329,
           0.39150518848841187,
           0.4032642334010495,
           0.41615677671862383,
           0.43006901169852324,
           0.4448924909136839,
           0.4605256085616692,
           0.4768743904430903,
           0.4938527579602731,
           0.5113824188814228,
           0.5293925122736524,
           0.5478191066654912,
           0.5666046241552327,
           0.5856972410932958,
           0.6050502986827202,
           0.6246217440032253,
           0.644373612833524,
           0.6642715594107397,
           0.6842844341851593,
           0.7043839080934352,
           0.7245441404110468,
           0.7447414865043007,
           0.7649542415311399,
           0.7851624161620726,
           0.8053475405872761,
           0.8254924933631598,
           0.8455813519795089,
           0.8655992623641988,
           0.8855323248669814,
           0.9053674945661978,
           0.9250924940172927,
           0.9446957368080551,
           0.9641662605030175,
           0.9834936677501103,
           1.0026680744887435,
           1.0216800643425208,
           1.040520648404272,
           1.0591812297284815,
           1.077653571938654,
           1.0959297714367466,
           1.1140022327702435,
           1.1318636467713412,
           1.1495069711333779,
           1.1669254131332687,
           1.184112414246307,
           1.201061636432103,
           1.2177669498984316,
           1.234222422173956,
           1.2504223083417296,
           1.2663610423035334,
           1.2820332289608483,
           1.2974336372119535,
           1.3125571936765421,
           1.3273989770696415,
           1.3419542131556648,
           1.3562182702213577,
           1.3701866550133277,
           1.3838550090919215,
           1.3972191055585592,
           1.4102748461183157,
           1.4230182584436848,
           1.4354454938091,
           1.4475528249689975,
           1.4593366442550793,
           1.4707934618709189,
           1.4819199043643325,
           1.4927127132598899,
           1.5031687438357288,
           1.5132849640304127,
           1.5230584534669638,
           1.5324864025824767,
           1.5415661118528314,
           1.5502949911030421,
           1.5586705588946719,
           1.5666904419825647,
           1.5743523748338886,
           1.581654199203117,
           1.588593863757209,
           1.5951694237457574,
           1.601379040711392,
           1.6072209822361485,
           1.6126936217199395,
           1.6177954381876198,
           1.6225250161214906,
           1.6268810453163915,
           1.6308623207548183,
           1.6344677424997718,
           1.6376963156032918,
           1.6405471500288504,
           1.6430194605860036,
           1.6451125668758932,
           1.6468258932463902,
           1.6481589687558418,
           1.6491114271445582,
           1.649683006813352
          ],
          [
           1.6209115961595966,
           1.6207262911103486,
           1.620170428140774,
           1.6192441637908928,
           1.617947758979189,
           1.6162815790305933,
           1.6142460937162562,
           1.611841877305725,
           1.609069608632316,
           1.6059300711726556,
           1.6024241531415666,
           1.5985528476036752,
           1.594317252603331,
           1.5897185713146618,
           1.5847581122138215,
           1.579437289275755,
           1.5737576221980742,
           1.567720736654941,
           1.561328364584183,
           1.5545823445111975,
           1.5474846219136102,
           1.5400372496310346,
           1.5322423883247653,
           1.5241023069927127,
           1.5156193835454395,
           1.5067961054497643,
           1.497635070447051,
           1.4881389873540412,
           1.4783106769548868,
           1.4681530729939474,
           1.4576692232798962,
           1.4468622909127915,
           1.435735555647,
           1.42429241540422,
           1.4125363879523853,
           1.4004711127679368,
           1.38810035310086,
           1.3754279982640196,
           1.3624580661707346,
           1.3491947061472214,
           1.3356422020495733,
           1.3218049757183588,
           1.3076875908077723,
           1.2932947570306126,
           1.278631334865297,
           1.2637023407766597,
           1.2485129530086123,
           1.2330685180138763,
           1.2173745575941362,
           1.2014367768332068,
           1.1852610729163116,
           1.1688535449405841,
           1.152220504835568,
           1.1353684895281253,
           1.1183042745040184,
           1.1010348889388613,
           1.0835676325945178,
           1.0659100947038105,
           1.0480701750970807,
           1.0300561078593053,
           1.0118764878467557,
           0.9935403004383183,
           0.9750569549494069,
           0.9564363221967258,
           0.9376887767710189,
           0.9188252446532834,
           0.899857256898801,
           0.8807970102136626,
           0.8616574353610089,
           0.8424522744594491,
           0.823196168373911,
           0.8039047555484942,
           0.7845947837892684,
           0.7652842366677135,
           0.7459924763747889,
           0.7267404049988947,
           0.7075506463090292,
           0.6884477501686274,
           0.6694584216442379,
           0.6506117766469667,
           0.6319396254704895,
           0.6134767847537469,
           0.5952614170471432,
           0.5773353951004447,
           0.5597446849707415,
           0.5425397377744509,
           0.5257758740529664,
           0.5095136369749016,
           0.49381908074534625,
           0.4787639486660153,
           0.4644256817932125,
           0.4508871853573158,
           0.4382362684606327,
           0.4265646669225628,
           0.41596656482759303,
           0.40653655359969804,
           0.3983670139171719,
           0.3915449778826607,
           0.3861486223205339,
           0.38224364516503717,
           0.3798798623178239,
           0.3790884038404034,
           0.37987986231782545,
           0.38224364516504034,
           0.3861486223205386,
           0.39154497788266696,
           0.3983670139171796,
           0.40653655359970714,
           0.41596656482760336,
           0.4265646669225742,
           0.43823626846064523,
           0.4508871853573293,
           0.46442568179322674,
           0.4787639486660304,
           0.493819080745362,
           0.509513636974918,
           0.5257758740529835,
           0.5425397377744684,
           0.5597446849707594,
           0.5773353951004631,
           0.5952614170471618,
           0.6134767847537658,
           0.6319396254705085,
           0.6506117766469859,
           0.6694584216442573,
           0.6884477501686469,
           0.7075506463090487,
           0.7267404049989146,
           0.7459924763748088,
           0.7652842366677334,
           0.7845947837892882,
           0.8039047555485139,
           0.8231961683739308,
           0.8424522744594689,
           0.8616574353610286,
           0.8807970102136823,
           0.8998572568988207,
           0.9188252446533026,
           0.9376887767710382,
           0.9564363221967451,
           0.9750569549494261,
           0.9935403004383374,
           1.0118764878467743,
           1.030056107859324,
           1.0480701750970989,
           1.0659100947038285,
           1.0835676325945358,
           1.101034888938879,
           1.1183042745040361,
           1.135368489528143,
           1.1522205048355854,
           1.1688535449406012,
           1.1852610729163282,
           1.201436776833223,
           1.2173745575941524,
           1.2330685180138923,
           1.248512953008628,
           1.263702340776675,
           1.278631334865312,
           1.2932947570306275,
           1.3076875908077867,
           1.3218049757183734,
           1.3356422020495873,
           1.3491947061472354,
           1.3624580661707484,
           1.375427998264033,
           1.3881003531008727,
           1.4004711127679494,
           1.4125363879523973,
           1.424292415404232,
           1.4357355556470117,
           1.4468622909128028,
           1.457669223279907,
           1.4681530729939583,
           1.478310676954897,
           1.488138987354051,
           1.4976350704470607,
           1.5067961054497736,
           1.5156193835454481,
           1.524102306992721,
           1.5322423883247736,
           1.5400372496310422,
           1.5474846219136176,
           1.5545823445112046,
           1.5613283645841893,
           1.5677207366549475,
           1.5737576221980802,
           1.5794372892757609,
           1.5847581122138268,
           1.5897185713146667,
           1.5943172526033353,
           1.5985528476036794,
           1.6024241531415706,
           1.605930071172659,
           1.6090696086323186,
           1.6118418773057277,
           1.6142460937162584,
           1.6162815790305955,
           1.6179477589791904,
           1.6192441637908939,
           1.620170428140775,
           1.620726291110349
          ],
          [
           1.5923163850582873,
           1.5921364395920017,
           1.5915966552801437,
           1.5906971883918752,
           1.5894382994031087,
           1.5878203530378037,
           1.5858438183264594,
           1.5835092686824728,
           1.5808173819972469,
           1.577768940755141,
           1.574364832169565,
           1.5706060483417528,
           1.5664936864439853,
           1.5620289489292876,
           1.5572131437698926,
           1.5520476847270461,
           1.5465340916550352,
           1.5406739908426523,
           1.5344691153956656,
           1.5279213056642322,
           1.5210325097196415,
           1.5138047838851891,
           1.5062402933265087,
           1.4983413127072123,
           1.4901102269162942,
           1.48154953187439,
           1.4726618354267091,
           1.4634498583312474,
           1.4539164353517449,
           1.444064516465831,
           1.4338971681998438,
           1.423417575103003,
           1.412629041374915,
           1.4015349926618472,
           1.3901389780388074,
           1.3784446721962855,
           1.3664558778524984,
           1.3541765284142324,
           1.3416106909118644,
           1.328762569236953,
           1.3156365077139172,
           1.302236995040834,
           1.2885686686383275,
           1.2746363194499548,
           1.2604448972424698,
           1.2459995164599502,
           1.2313054626920976,
           1.2163681998241265,
           1.2011933779437,
           1.1857868420894513,
           1.1701546419358617,
           1.1543030425208842,
           1.1382385361357885,
           1.1219678555115644,
           1.105497988453,
           1.0888361940905598,
           1.0719900209417,
           1.054967326997588,
           1.0377763020786746,
           1.0204254927336267,
           1.0029238299911094,
           0.9852806603132656,
           0.9675057801438857,
           0.949609474493598,
           0.9316025600592747,
           0.9134964334354979,
           0.8953031250424031,
           0.8770353594663318,
           0.8587066229867882,
           0.8403312391439504,
           0.8219244532832118,
           0.8035025270934049,
           0.7850828442281266,
           0.7666840281570338,
           0.7483260734247288,
           0.7300304914828258,
           0.7118204721836794,
           0.6937210618515853,
           0.6757593585381191,
           0.6579647245686475,
           0.640369015727134,
           0.6230068253181434,
           0.6059157397809799,
           0.5891366003855718,
           0.5727137626755613,
           0.5566953416059462,
           0.5411334256451377,
           0.5260842374442658,
           0.5116082121349236,
           0.4977699572575277,
           0.4846380514665881,
           0.47228463371649704,
           0.4607847323918513,
           0.4502152871598218,
           0.4406538278668761,
           0.432176797031939,
           0.4248575367060542,
           0.41876400562558724,
           0.4139563441465969,
           0.4104844539298572,
           0.40838579522351004,
           0.4076836149417127,
           0.4083857952235115,
           0.41048445392986005,
           0.41395634414660115,
           0.41876400562559285,
           0.424857536706061,
           0.43217679703194717,
           0.44065382786688545,
           0.4502152871598321,
           0.4607847323918627,
           0.4722846337165093,
           0.4846380514666012,
           0.4977699572575416,
           0.5116082121349381,
           0.526084237444281,
           0.5411334256451533,
           0.5566953416059626,
           0.572713762675578,
           0.5891366003855888,
           0.6059157397809973,
           0.6230068253181612,
           0.6403690157271519,
           0.6579647245686657,
           0.6757593585381374,
           0.6937210618516038,
           0.7118204721836979,
           0.7300304914828446,
           0.7483260734247477,
           0.7666840281570527,
           0.7850828442281454,
           0.8035025270934237,
           0.8219244532832306,
           0.8403312391439692,
           0.8587066229868071,
           0.8770353594663507,
           0.8953031250424218,
           0.9134964334355167,
           0.9316025600592933,
           0.9496094744936163,
           0.9675057801439041,
           0.9852806603132841,
           1.0029238299911276,
           1.0204254927336445,
           1.0377763020786925,
           1.0549673269976059,
           1.0719900209417175,
           1.0888361940905766,
           1.1054979884530172,
           1.1219678555115813,
           1.138238536135805,
           1.1543030425209007,
           1.170154641935878,
           1.1857868420894673,
           1.2011933779437158,
           1.2163681998241418,
           1.231305462692113,
           1.2459995164599649,
           1.2604448972424842,
           1.2746363194499692,
           1.2885686686383415,
           1.3022369950408477,
           1.3156365077139305,
           1.328762569236966,
           1.3416106909118772,
           1.3541765284142453,
           1.3664558778525109,
           1.3784446721962975,
           1.3901389780388191,
           1.4015349926618588,
           1.4126290413749263,
           1.4234175751030136,
           1.4338971681998545,
           1.4440645164658417,
           1.4539164353517549,
           1.4634498583312567,
           1.472661835426719,
           1.4815495318743994,
           1.4901102269163031,
           1.4983413127072205,
           1.5062402933265162,
           1.5138047838851967,
           1.521032509719649,
           1.5279213056642391,
           1.534469115395672,
           1.5406739908426585,
           1.546534091655041,
           1.5520476847270517,
           1.5572131437698975,
           1.5620289489292922,
           1.5664936864439893,
           1.570606048341757,
           1.5743648321695687,
           1.5777689407551443,
           1.5808173819972497,
           1.5835092686824752,
           1.585843818326462,
           1.5878203530378059,
           1.58943829940311,
           1.5906971883918763,
           1.5915966552801444,
           1.592136439592002
          ],
          [
           1.5641155815246053,
           1.5639411136535022,
           1.5634177620752183,
           1.5625456829056605,
           1.561325136374213,
           1.5597564868784088,
           1.5578402030612115,
           1.5555768579116451,
           1.5529671288897304,
           1.5500117980769357,
           1.5467117523535496,
           1.5430679836046741,
           1.5390815889567555,
           1.534753771046873,
           1.5300858383272828,
           1.5250792054080275,
           1.5197353934407483,
           1.5140560305471975,
           1.5080428522963312,
           1.5016977022342604,
           1.495022532471813,
           1.4880194043349158,
           1.4806904890835497,
           1.4730380687056066,
           1.4650645367926012,
           1.4567723995048776,
           1.4481642766347198,
           1.439242902776585,
           1.4300111286146087,
           1.4204719223385318,
           1.4106283712002983,
           1.4004836832248146,
           1.3900411890897033,
           1.379304344190387,
           1.3682767309084987,
           1.3569620611034594,
           1.345364178849108,
           1.3334870634395393,
           1.3213348326908427,
           1.3089117465682436,
           1.2962222111712896,
           1.2832707831132253,
           1.2700621743346026,
           1.2566012573955379,
           1.242893071295898,
           1.2289428278781525,
           1.2147559188737227,
           1.2003379236604863,
           1.18569461780673,
           1.1708319824854034,
           1.1557562148521006,
           1.140473739490925,
           1.1249912210443993,
           1.10931557815701,
           1.0934539988769998,
           1.0774139576777937,
           1.0612032342791455,
           1.0448299344689158,
           1.0283025131495216,
           1.011629799858689,
           0.994821027042372,
           0.9778858613886809,
           0.9608344385654274,
           0.943677401740411,
           0.9264259443026545,
           0.909091857243995,
           0.8916875817030998,
           0.8742262672169165,
           0.8567218362661233,
           0.8391890557387861,
           0.8216436159666363,
           0.8041022180061848,
           0.7865826698355034,
           0.7691039921077291,
           0.7516865340319084,
           0.7343520998245407,
           0.7171240859701167,
           0.7000276292192732,
           0.6830897648052793,
           0.6663395937322009,
           0.6498084571321295,
           0.6335301145480324,
           0.617540921512105,
           0.6018799998966767,
           0.5865893921657134,
           0.5717141878256765,
           0.5573026070903475,
           0.543406023142894,
           0.5300789006318612,
           0.5173786245797453,
           0.5053651913338372,
           0.494100732411007,
           0.48364884416277426,
           0.47407370231396445,
           0.46543895170840266,
           0.45780637868414,
           0.45123439616058636,
           0.4457763981681066,
           0.4414790679868843,
           0.4383807475989366,
           0.4365099903346202,
           0.4358844184753947,
           0.4365099903346215,
           0.43838074759893914,
           0.441479067986888,
           0.4457763981681116,
           0.4512343961605925,
           0.45780637868414725,
           0.46543895170841104,
           0.4740737023139737,
           0.48364884416278464,
           0.49410073241101815,
           0.5053651913338493,
           0.5173786245797579,
           0.5300789006318747,
           0.5434060231429081,
           0.5573026070903622,
           0.5717141878256916,
           0.5865893921657289,
           0.6018799998966927,
           0.6175409215121215,
           0.6335301145480492,
           0.6498084571321463,
           0.666339593732218,
           0.6830897648052965,
           0.7000276292192906,
           0.7171240859701343,
           0.7343520998245585,
           0.7516865340319263,
           0.769103992107747,
           0.7865826698355213,
           0.8041022180062026,
           0.8216436159666544,
           0.8391890557388041,
           0.8567218362661412,
           0.8742262672169344,
           0.8916875817031178,
           0.909091857244013,
           0.9264259443026722,
           0.9436774017404288,
           0.9608344385654449,
           0.9778858613886986,
           0.9948210270423893,
           1.0116297998587063,
           1.0283025131495387,
           1.0448299344689327,
           1.061203234279162,
           1.0774139576778103,
           1.0934539988770162,
           1.109315578157026,
           1.1249912210444155,
           1.1404737394909408,
           1.155756214852116,
           1.170831982485419,
           1.1856946178067453,
           1.2003379236605014,
           1.2147559188737376,
           1.2289428278781669,
           1.2428930712959123,
           1.256601257395552,
           1.270062174334616,
           1.2832707831132386,
           1.2962222111713029,
           1.3089117465682565,
           1.3213348326908552,
           1.3334870634395515,
           1.34536417884912,
           1.356962061103471,
           1.36827673090851,
           1.3793043441903983,
           1.3900411890897144,
           1.400483683224825,
           1.4106283712003085,
           1.420471922338542,
           1.4300111286146187,
           1.439242902776594,
           1.4481642766347291,
           1.4567723995048867,
           1.4650645367926096,
           1.4730380687056148,
           1.4806904890835573,
           1.488019404334923,
           1.49502253247182,
           1.5016977022342668,
           1.5080428522963376,
           1.5140560305472037,
           1.5197353934407536,
           1.5250792054080327,
           1.5300858383272877,
           1.5347537710468777,
           1.53908158895676,
           1.5430679836046781,
           1.5467117523535532,
           1.5500117980769388,
           1.5529671288897338,
           1.5555768579116476,
           1.5578402030612142,
           1.5597564868784104,
           1.5613251363742144,
           1.5625456829056614,
           1.563417762075219,
           1.5639411136535026
          ],
          [
           1.5363364680146492,
           1.5361675924382945,
           1.5356610177215406,
           1.5348168999147793,
           1.5336354991469654,
           1.5321171796934667,
           1.5302624100718418,
           1.5280717631663567,
           1.5255459163822604,
           1.5226856518311216,
           1.5194918565487403,
           1.5159655227474598,
           1.512107748104933,
           1.5079197360917331,
           1.5034027963404748,
           1.4985583450594668,
           1.4933879054942416,
           1.4878931084407085,
           1.482075692814063,
           1.4759375062780227,
           1.469480505939436,
           1.4627067591138092,
           1.455618444167857,
           1.4482178514457744,
           1.4405073842865865,
           1.4324895601406413,
           1.4241670117940979,
           1.415542488711104,
           1.406618858504308,
           1.3973991085453616,
           1.3878863477282077,
           1.3780838083991895,
           1.367994848469378,
           1.357622953726027,
           1.3469717403617214,
           1.336044957741632,
           1.3248464914312992,
           1.313380366509627,
           1.3016507511942452,
           1.2896619608091358,
           1.2774184621274787,
           1.2649248781260316,
           1.2521859931911012,
           1.2392067588203113,
           1.2259922998689732,
           1.2125479213949584,
           1.1988791161616426,
           1.1849915728647622,
           1.170891185155978,
           1.1565840615436669,
           1.1420765362599823,
           1.1273751811926862,
           1.1124868189906774,
           1.097418537463656,
           1.082177705409023,
           1.0667719900130108,
           1.0512093759882501,
           1.0354981866265274,
           1.0196471069634336,
           1.0036652092709286,
           0.987561981114444,
           0.9713473562329332,
           0.9550317485229363,
           0.938626089430876,
           0.9221418690808262,
           0.9055911814869994,
           0.8889867742199562,
           0.8723421029113281,
           0.8556713909913438,
           0.8389896950535723,
           0.822312976227926,
           0.8056581779107692,
           0.789043310143032,
           0.7724875408347255,
           0.7560112938960761,
           0.7396363541378393,
           0.7233859785293859,
           0.7072850130326973,
           0.6913600137400423,
           0.6756393704064283,
           0.6601534296567919,
           0.6449346141345081,
           0.6300175326184654,
           0.6154390746569179,
           0.6012384815524494,
           0.5874573836189075,
           0.574139791599121,
           0.5613320281263943,
           0.5490825833605446,
           0.5374418777559852,
           0.5264619147534537,
           0.5161958075448835,
           0.5066971674999631,
           0.4980193478714069,
           0.490214545335525,
           0.4833327737345893,
           0.47742073848230865,
           0.47252065521106457,
           0.468669070433332,
           0.46589575281955525,
           0.46422272864131964,
           0.4636635319853507,
           0.4642227286413208,
           0.46589575281955753,
           0.4686690704333354,
           0.472520655211069,
           0.47742073848231414,
           0.48333277373459593,
           0.49021454533553255,
           0.4980193478714154,
           0.5066971674999725,
           0.5161958075448937,
           0.5264619147534646,
           0.5374418777559968,
           0.5490825833605568,
           0.5613320281264071,
           0.5741397915991344,
           0.5874573836189214,
           0.6012384815524638,
           0.6154390746569327,
           0.6300175326184808,
           0.6449346141345237,
           0.6601534296568077,
           0.6756393704064444,
           0.6913600137400585,
           0.7072850130327137,
           0.7233859785294025,
           0.7396363541378562,
           0.7560112938960928,
           0.7724875408347425,
           0.7890433101430488,
           0.8056581779107863,
           0.8223129762279431,
           0.8389896950535896,
           0.855671390991361,
           0.8723421029113453,
           0.8889867742199733,
           0.9055911814870163,
           0.9221418690808433,
           0.9386260894308929,
           0.955031748522953,
           0.9713473562329499,
           0.9875619811144605,
           1.0036652092709453,
           1.0196471069634498,
           1.0354981866265438,
           1.0512093759882664,
           1.0667719900130268,
           1.0821777054090387,
           1.0974185374636714,
           1.112486818990693,
           1.1273751811927013,
           1.1420765362599972,
           1.1565840615436815,
           1.1708911851559924,
           1.1849915728647764,
           1.198879116161657,
           1.2125479213949724,
           1.2259922998689867,
           1.2392067588203246,
           1.2521859931911141,
           1.2649248781260445,
           1.2774184621274913,
           1.2896619608091484,
           1.3016507511942574,
           1.313380366509639,
           1.3248464914313107,
           1.3360449577416431,
           1.3469717403617325,
           1.3576229537260376,
           1.367994848469389,
           1.3780838083991998,
           1.3878863477282173,
           1.3973991085453712,
           1.4066188585043178,
           1.4155424887111128,
           1.4241670117941065,
           1.4324895601406498,
           1.4405073842865947,
           1.448217851445782,
           1.4556184441678641,
           1.4627067591138159,
           1.469480505939443,
           1.475937506278029,
           1.482075692814069,
           1.487893108440714,
           1.4933879054942467,
           1.498558345059472,
           1.5034027963404795,
           1.5079197360917376,
           1.512107748104937,
           1.5159655227474638,
           1.5194918565487436,
           1.5226856518311245,
           1.5255459163822636,
           1.5280717631663596,
           1.5302624100718443,
           1.5321171796934685,
           1.5336354991469672,
           1.53481689991478,
           1.5356610177215408,
           1.5361675924382947
          ],
          [
           1.5090059190266547,
           1.5088427463803,
           1.5083532804485538,
           1.5075376772693572,
           1.5063961969593629,
           1.5049292037944746,
           1.503137166323448,
           1.5010206575153895,
           1.498580354942253,
           1.495817040997694,
           1.492731603153898,
           1.489325034258287,
           1.4855984328722993,
           1.4815530036547362,
           1.477190057792502,
           1.472511013481901,
           1.4675173964640205,
           1.4622108406181178,
           1.4565930886173504,
           1.4506659926516299,
           1.4444315152228688,
           1.437891730018406,
           1.431048822868965,
           1.4239050927981034,
           1.416462953170782,
           1.4087249329493972,
           1.4006936780664123,
           1.3923719529235725,
           1.3837626420286313,
           1.3748687517815328,
           1.3656934124231115,
           1.3562398801606066,
           1.3465115394856173,
           1.3365119057016013,
           1.3262446276796418,
           1.3157134908629753,
           1.304922420542721,
           1.293875485429402,
           1.282576901547195,
           1.2710310364804511,
           1.2592424140048546,
           1.2472157191387514,
           1.2349558036536017,
           1.2224676920863091,
           1.209756588300356,
           1.1968278826472303,
           1.1836871597846685,
           1.1703402072137483,
           1.156793024602887,
           1.143051833973412,
           1.1291230908285674,
           1.1150134963156568,
           1.100730010519538,
           1.0862798669948859,
           1.071670588654556,
           1.0569100051419833,
           1.04200627182684,
           1.0269678905750683,
           1.0118037324567921,
           0.9965230625683533,
           0.9811355671575307,
           0.9656513832535784,
           0.9500811310155326,
           0.9344359490226818,
           0.9187275327392521,
           0.9029681763900926,
           0.8871708184839531,
           0.8713490912138561,
           0.8555173739476007,
           0.8396908509924337,
           0.823885573772395,
           0.8081185274898994,
           0.7924077022486695,
           0.7767721684858871,
           0.7612321563886563,
           0.7458091387433604,
           0.7305259163746648,
           0.7154067049609159,
           0.7004772215511027,
           0.6857647685421571,
           0.6712983121928764,
           0.6571085519450319,
           0.6432279758937656,
           0.6296908967108367,
           0.616533461206436,
           0.6037936255739987,
           0.591511087286482,
           0.5797271637307646,
           0.5684846071530535,
           0.5578273455610624,
           0.5478001401422652,
           0.5384481517787275,
           0.5298164126084026,
           0.5219492034570852,
           0.5148893443453678,
           0.5086774129302872,
           0.5033509141492295,
           0.498943432660162,
           0.4954838068208166,
           0.49299536769469166,
           0.4914952877738419,
           0.49099408097334535,
           0.4914952877738429,
           0.49299536769469365,
           0.4954838068208196,
           0.49894343266016605,
           0.5033509141492345,
           0.5086774129302932,
           0.5148893443453747,
           0.5219492034570928,
           0.5298164126084112,
           0.5384481517787368,
           0.5478001401422752,
           0.557827345561073,
           0.5684846071530648,
           0.5797271637307764,
           0.5915110872864945,
           0.6037936255740117,
           0.6165334612064495,
           0.6296908967108504,
           0.6432279758937798,
           0.6571085519450464,
           0.6712983121928912,
           0.6857647685421722,
           0.7004772215511179,
           0.7154067049609313,
           0.7305259163746803,
           0.7458091387433762,
           0.761232156388672,
           0.7767721684859034,
           0.7924077022486855,
           0.8081185274899155,
           0.8238855737724111,
           0.83969085099245,
           0.8555173739476168,
           0.8713490912138722,
           0.8871708184839694,
           0.9029681763901088,
           0.9187275327392683,
           0.9344359490226979,
           0.9500811310155488,
           0.9656513832535946,
           0.9811355671575466,
           0.996523062568369,
           1.0118037324568079,
           1.0269678905750839,
           1.0420062718268552,
           1.0569100051419984,
           1.0716705886545712,
           1.0862798669949008,
           1.1007300105195525,
           1.1150134963156715,
           1.1291230908285816,
           1.1430518339734261,
           1.1567930246029008,
           1.1703402072137623,
           1.183687159784682,
           1.1968278826472434,
           1.2097565883003694,
           1.222467692086322,
           1.2349558036536141,
           1.247215719138764,
           1.2592424140048668,
           1.2710310364804631,
           1.2825769015472068,
           1.2938754854294132,
           1.3049224205427323,
           1.3157134908629862,
           1.3262446276796525,
           1.3365119057016117,
           1.3465115394856277,
           1.3562398801606166,
           1.3656934124231208,
           1.3748687517815419,
           1.3837626420286404,
           1.392371952923581,
           1.4006936780664208,
           1.4087249329494054,
           1.4164629531707897,
           1.423905092798111,
           1.4310488228689722,
           1.4378917300184124,
           1.4444315152228755,
           1.450665992651636,
           1.4565930886173561,
           1.4622108406181233,
           1.4675173964640256,
           1.472511013481906,
           1.4771900577925063,
           1.4815530036547406,
           1.4855984328723033,
           1.4893250342582907,
           1.492731603153901,
           1.4958170409976972,
           1.4985803549422558,
           1.501020657515392,
           1.5031371663234503,
           1.5049292037944766,
           1.506396196959364,
           1.507537677269358,
           1.5083532804485544,
           1.5088427463803005
          ],
          [
           1.4821503751016516,
           1.481993011139136,
           1.4815209712584887,
           1.4807344114987728,
           1.4796335919864443,
           1.4782188770278082,
           1.476490735239338,
           1.474449739716725,
           1.4720965682438063,
           1.4694320035427793,
           1.4664569335673832,
           1.4631723518410227,
           1.4595793578421103,
           1.4556791574392072,
           1.451473063378888,
           1.4469624958295986,
           1.4421489829851417,
           1.4370341617318392,
           1.4316197783838198,
           1.4259076894913512,
           1.4198998627276134,
           1.4135983778598316,
           1.4070054278112574,
           1.4001233198210825,
           1.39295447671004,
           1.3855014382601505,
           1.3777668627178459,
           1.3697535284305438,
           1.3614643356276495,
           1.3529023083579597,
           1.34407059659652,
           1.3349724785351544,
           1.3256113630721758,
           1.3159907925181746,
           1.306114445536307,
           1.2959861403371655,
           1.2856098381501244,
           1.2749896469950346,
           1.2641298257802909,
           1.2530347887556574,
           1.2417091103507973,
           1.230157530433251,
           1.218384960022648,
           1.2063964875012538,
           1.1941973853645618,
           1.1817931175595175,
           1.1691893474622275,
           1.1563919465515493,
           1.143407003839894,
           1.130240836127866,
           1.1168999991550141,
           1.103391299725007,
           1.0897218088899083,
           1.0758988762849357,
           1.0619301457120565,
           1.0478235720779343,
           1.0335874397990081,
           1.0192303827936824,
           1.0047614061885282,
           0.9901899098717999,
           0.975525714033042,
           0.9607790868316937,
           0.9459607743397068,
           0.9310820329025815,
           0.9161546640588526,
           0.9011910521487236,
           0.8862042047267039,
           0.8712077958688722,
           0.8562162124304236,
           0.8412446032606936,
           0.826308931317471,
           0.8114260285361748,
           0.7966136531977208,
           0.7818905493963192,
           0.7672765080291395,
           0.7527924285073141,
           0.7384603801155283,
           0.7243036616190581,
           0.7103468573271142,
           0.6966158873661853,
           0.6831380493965847,
           0.6699420484246552,
           0.6570580107347863,
           0.6445174773127422,
           0.6323533714917547,
           0.6205999349792433,
           0.6092926259884482,
           0.5984679730000816,
           0.5881633778283045,
           0.5784168622909727,
           0.5692667540172464,
           0.5607513088825292,
           0.5529082703175774,
           0.5457743693012078,
           0.5393847731171185,
           0.5337724957074154,
           0.5289677873178764,
           0.5249975256004719,
           0.5218846338269671,
           0.5196475537733528,
           0.5182998006521728,
           0.5178496248983484,
           0.5182998006521738,
           0.5196475537733547,
           0.5218846338269699,
           0.5249975256004754,
           0.528967787317881,
           0.5337724957074207,
           0.5393847731171246,
           0.5457743693012148,
           0.5529082703175852,
           0.5607513088825377,
           0.5692667540172555,
           0.5784168622909824,
           0.588163377828315,
           0.5984679730000925,
           0.6092926259884596,
           0.6205999349792553,
           0.6323533714917671,
           0.6445174773127549,
           0.6570580107347994,
           0.6699420484246686,
           0.6831380493965983,
           0.6966158873661994,
           0.7103468573271284,
           0.7243036616190726,
           0.7384603801155429,
           0.7527924285073289,
           0.7672765080291543,
           0.7818905493963343,
           0.796613653197736,
           0.8114260285361901,
           0.8263089313174862,
           0.841244603260709,
           0.856216212430439,
           0.8712077958688875,
           0.8862042047267195,
           0.901191052148739,
           0.9161546640588683,
           0.9310820329025968,
           0.9459607743397221,
           0.960779086831709,
           0.9755257140330572,
           0.9901899098718149,
           1.0047614061885433,
           1.019230382793697,
           1.0335874397990228,
           1.0478235720779487,
           1.0619301457120711,
           1.07589887628495,
           1.0897218088899223,
           1.103391299725021,
           1.116899999155028,
           1.1302408361278795,
           1.1434070038399073,
           1.1563919465515624,
           1.1691893474622406,
           1.1817931175595302,
           1.1941973853645742,
           1.2063964875012663,
           1.2183849600226597,
           1.2301575304332633,
           1.241709110350809,
           1.2530347887556688,
           1.264129825780302,
           1.274989646995046,
           1.285609838150135,
           1.2959861403371757,
           1.3061144455363172,
           1.3159907925181848,
           1.3256113630721857,
           1.3349724785351638,
           1.3440705965965292,
           1.3529023083579685,
           1.3614643356276581,
           1.3697535284305522,
           1.3777668627178543,
           1.385501438260158,
           1.3929544767100472,
           1.4001233198210896,
           1.4070054278112643,
           1.4135983778598382,
           1.4198998627276194,
           1.4259076894913572,
           1.4316197783838254,
           1.4370341617318445,
           1.4421489829851468,
           1.4469624958296032,
           1.4514730633788924,
           1.4556791574392112,
           1.4595793578421141,
           1.463172351841026,
           1.4664569335673863,
           1.4694320035427826,
           1.4720965682438087,
           1.474449739716727,
           1.4764907352393402,
           1.47821887702781,
           1.4796335919864454,
           1.480734411498774,
           1.4815209712584896,
           1.4819930111391364
          ],
          [
           1.45579581724395,
           1.4556443619541495,
           1.4551900480810867,
           1.45443303163431,
           1.4533735726982997,
           1.452012035535762,
           1.4503488887331337,
           1.4483847053891974,
           1.4461201633479634,
           1.443556045477271,
           1.4406932399948111,
           1.437532740843593,
           1.4340756481191597,
           1.4303231685511897,
           1.4262766160424432,
           1.4219374122683752,
           1.4173070873410964,
           1.4123872805417634,
           1.407179741125906,
           1.4016863292066277,
           1.3959090167211112,
           1.389849888486367,
           1.3835111433507021,
           1.3768950954479997,
           1.3700041755625043,
           1.3628409326125228,
           1.3554080352621662,
           1.3477082736710708,
           1.339744561392887,
           1.3315199374342646,
           1.3230375684870699,
           1.314300751347654,
           1.3053129155381842,
           1.2960776261463225,
           1.2865985869009149,
           1.2768796435028686,
           1.2669247872319993,
           1.256738158852394,
           1.2463240528407271,
           1.235686921964014,
           1.2248313822354915,
           1.2137622182796919,
           1.2024843891403363,
           1.191003034567402,
           1.1793234818226717,
           1.1674512530461763,
           1.1553920732292988,
           1.1431518788438026,
           1.1307368271797673,
           1.118153306449296,
           1.1054079467168643,
           1.0925076317213311,
           1.079459511658799,
           1.0662710169997023,
           1.0529498734175478,
           1.0395041179105777,
           1.0259421162010356,
           1.0122725814995668,
           0.9985045947242235,
           0.9846476262643091,
           0.9707115593784323,
           0.9567067153131319,
           0.9426438802226678,
           0.9285343339612226,
           0.9143898808049234,
           0.9002228821415842,
           0.8860462911395399,
           0.8718736893717557,
           0.8577193253256344,
           0.843598154670429,
           0.8295258820803249,
           0.8155190043193172,
           0.8015948541808392,
           0.7877716447374393,
           0.7740685131903322,
           0.7605055634121977,
           0.7471039060465281,
           0.7338856947614208,
           0.7208741569548701,
           0.7080936168746219,
           0.6955695087542187,
           0.683328377188341,
           0.6713978615913233,
           0.6598066612265905,
           0.6485844769943199,
           0.6377619259620723,
           0.6273704245704208,
           0.617442036603171,
           0.6080092824454578,
           0.5991049069284672,
           0.590761604233775,
           0.5830116999404128,
           0.5758867923474024,
           0.5694173576495684,
           0.5636323262808878,
           0.5585586405962413,
           0.5542208068030755,
           0.5506404563926804,
           0.5478359339484672,
           0.5458219288375323,
           0.5446091677021763,
           0.54420418275605,
           0.544609167702177,
           0.5458219288375339,
           0.5478359339484697,
           0.5506404563926838,
           0.5542208068030795,
           0.5585586405962462,
           0.5636323262808934,
           0.5694173576495747,
           0.5758867923474095,
           0.5830116999404206,
           0.5907616042337833,
           0.5991049069284761,
           0.6080092824454671,
           0.6174420366031809,
           0.6273704245704312,
           0.6377619259620833,
           0.6485844769943312,
           0.6598066612266021,
           0.6713978615913354,
           0.6833283771883536,
           0.6955695087542314,
           0.7080936168746349,
           0.7208741569548833,
           0.7338856947614343,
           0.7471039060465418,
           0.7605055634122115,
           0.7740685131903462,
           0.7877716447374534,
           0.8015948541808533,
           0.8155190043193317,
           0.8295258820803394,
           0.8435981546704435,
           0.857719325325649,
           0.8718736893717701,
           0.8860462911395547,
           0.9002228821415987,
           0.914389880804938,
           0.9285343339612371,
           0.9426438802226823,
           0.9567067153131465,
           0.9707115593784468,
           0.9846476262643235,
           0.9985045947242376,
           1.0122725814995808,
           1.0259421162010496,
           1.0395041179105915,
           1.0529498734175617,
           1.0662710169997156,
           1.0794595116588126,
           1.0925076317213445,
           1.1054079467168774,
           1.1181533064493088,
           1.1307368271797802,
           1.1431518788438153,
           1.1553920732293115,
           1.1674512530461887,
           1.1793234818226837,
           1.191003034567414,
           1.2024843891403478,
           1.2137622182797034,
           1.2248313822355026,
           1.2356869219640252,
           1.246324052840738,
           1.2567381588524045,
           1.2669247872320097,
           1.2768796435028786,
           1.2865985869009247,
           1.296077626146332,
           1.3053129155381937,
           1.3143007513476628,
           1.3230375684870785,
           1.3315199374342732,
           1.3397445613928953,
           1.347708273671079,
           1.355408035262174,
           1.3628409326125304,
           1.3700041755625116,
           1.3768950954480066,
           1.383511143350709,
           1.3898498884863733,
           1.3959090167211174,
           1.4016863292066333,
           1.4071797411259115,
           1.4123872805417685,
           1.4173070873411011,
           1.42193741226838,
           1.4262766160424472,
           1.4303231685511937,
           1.434075648119163,
           1.4375327408435963,
           1.4406932399948138,
           1.4435560454772736,
           1.446120163347966,
           1.4483847053891996,
           1.4503488887331362,
           1.4520120355357633,
           1.4533735726983008,
           1.4544330316343108,
           1.4551900480810873,
           1.45564436195415
          ],
          [
           1.4299677417861951,
           1.4298222884428535,
           1.4293859803722586,
           1.428658973475123,
           1.4276415276608299,
           1.4263340069601764,
           1.4247368796841076,
           1.422850718629348,
           1.4206762013320846,
           1.4182141103711627,
           1.4154653337224943,
           1.4124308651666975,
           1.409111804752281,
           1.4055093593169898,
           1.4016248430702711,
           1.3974596782401525,
           1.3930153957881988,
           1.3882936361965823,
           1.3832961503317296,
           1.3780248003894076,
           1.3724815609266103,
           1.366668519986056,
           1.3605878803196596,
           1.3542419607178797,
           1.3476331974524525,
           1.34076414584066,
           1.3336374819399544,
           1.3262560043825202,
           1.3186226363601248,
           1.3107404277704633,
           1.302612557537122,
           1.2942423361162498,
           1.2856332082040887,
           1.2767887556606372,
           1.2677127006659243,
           1.2584089091266801,
           1.2488813943525638,
           1.2391343210225987,
           1.2291720094640446,
           1.218998940267627,
           1.2086197592648307,
           1.1980392828948685,
           1.1872625039909386,
           1.1762945980174937,
           1.1651409297924662,
           1.1538070607306656,
           1.1422987566469738,
           1.130621996160364,
           1.1187829797422506,
           1.1067881394551184,
           1.0946441494297894,
           1.0823579371319634,
           1.0699366954707665,
           1.0573878958038425,
           1.0447193018949061,
           1.0319389848805036,
           1.0190553393027724,
           1.0060771002640772,
           0.9930133617571765,
           0.9798735962207543,
           0.9666676753642774,
           0.9534058922977399,
           0.94009898499032,
           0.9267581610666021,
           0.9133951239290096,
           0.900022100169448,
           0.8866518682008329,
           0.8732977879988802,
           0.8599738317948925,
           0.8466946154997624,
           0.8334754305663614,
           0.8203322759102115,
           0.8072818894051397,
           0.7943417783499137,
           0.781530248162374,
           0.7688664283985145,
           0.7563702950153421,
           0.7440626875993108,
           0.7319653200694856,
           0.7201007831412811,
           0.7084925366103402,
           0.6971648892979965,
           0.686142964304937,
           0.6754526470677649,
           0.6651205136285488,
           0.6551737365390056,
           0.6456399659611873,
           0.6365471838298183,
           0.6279235294411093,
           0.6197970955572519,
           0.612195695082782,
           0.6051465995800558,
           0.5986762523247166,
           0.5928099602082236,
           0.5875715704911072,
           0.5829831400833387,
           0.5790646065357186,
           0.5758334711109545,
           0.5733045050079809,
           0.5714894899021989,
           0.5703970033454606,
           0.570032258213805,
           0.5703970033454613,
           0.5714894899022005,
           0.5733045050079831,
           0.5758334711109575,
           0.5790646065357221,
           0.5829831400833432,
           0.5875715704911123,
           0.5928099602082293,
           0.598676252324723,
           0.6051465995800628,
           0.6121956950827896,
           0.6197970955572599,
           0.6279235294411178,
           0.6365471838298274,
           0.645639965961197,
           0.6551737365390157,
           0.6651205136285593,
           0.6754526470677757,
           0.6861429643049483,
           0.697164889298008,
           0.7084925366103519,
           0.7201007831412932,
           0.7319653200694977,
           0.7440626875993233,
           0.7563702950153549,
           0.7688664283985275,
           0.7815302481623871,
           0.7943417783499271,
           0.8072818894051528,
           0.8203322759102248,
           0.833475430566375,
           0.8466946154997761,
           0.859973831794906,
           0.8732977879988938,
           0.8866518682008467,
           0.9000221001694618,
           0.9133951239290234,
           0.9267581610666159,
           0.9400989849903335,
           0.9534058922977536,
           0.9666676753642909,
           0.979873596220768,
           0.9930133617571901,
           1.0060771002640907,
           1.0190553393027855,
           1.031938984880517,
           1.0447193018949192,
           1.0573878958038554,
           1.0699366954707794,
           1.0823579371319763,
           1.0946441494298018,
           1.1067881394551307,
           1.1187829797422626,
           1.130621996160376,
           1.1422987566469858,
           1.1538070607306772,
           1.1651409297924775,
           1.1762945980175052,
           1.1872625039909495,
           1.1980392828948796,
           1.2086197592648413,
           1.2189989402676378,
           1.2291720094640548,
           1.239134321022609,
           1.2488813943525738,
           1.2584089091266897,
           1.2677127006659337,
           1.2767887556606465,
           1.285633208204098,
           1.2942423361162583,
           1.3026125575371303,
           1.3107404277704713,
           1.3186226363601328,
           1.326256004382528,
           1.3336374819399621,
           1.3407641458406676,
           1.3476331974524596,
           1.3542419607178862,
           1.3605878803196663,
           1.3666685199860624,
           1.372481560926616,
           1.3780248003894129,
           1.3832961503317345,
           1.3882936361965874,
           1.3930153957882032,
           1.397459678240157,
           1.4016248430702751,
           1.4055093593169936,
           1.4091118047522846,
           1.4124308651667006,
           1.4154653337224974,
           1.4182141103711656,
           1.4206762013320868,
           1.4228507186293498,
           1.4247368796841098,
           1.4263340069601775,
           1.427641527660831,
           1.4286589734751243,
           1.4293859803722595,
           1.429822288442854
          ],
          [
           1.404691135723312,
           1.4045517698690921,
           1.404133724185038,
           1.403437154330944,
           1.4024623198198465,
           1.401209584138526,
           1.3996794149171004,
           1.397872384148585,
           1.3957891684595651,
           1.3934305494334072,
           1.390797413987682,
           1.3878907548077806,
           1.384711670838974,
           1.3812613678394914,
           1.3775411589974875,
           1.3735524656151208,
           1.369296817863288,
           1.3647758556109504,
           1.3599913293333439,
           1.3549451011037956,
           1.3496391456742824,
           1.3440755516503233,
           1.3382565227662893,
           1.3321843792677133,
           1.325861559407739,
           1.319290621065416,
           1.312474243494175,
           1.3054152292094647,
           1.298116506025235,
           1.2905811292496947,
           1.2828122840515594,
           1.2748132880088525,
           1.2665875938532034,
           1.2581387924235583,
           1.2494706158441884,
           1.240586940942983,
           1.2314917929271014,
           1.222189349334257,
           1.2126839442791435,
           1.2029800730157956,
           1.1930823968380362,
           1.1829957483415516,
           1.1727251370725555,
           1.1622757555894856,
           1.1516529859656197,
           1.1408624067619915,
           1.1299098005013923,
           1.118801161675639,
           1.1075427053195315,
           1.0961408761860598,
           1.0846023585582976,
           1.0729340867340424,
           1.0611432562194854,
           1.0492373356679265,
           1.0372240795986547,
           1.0251115419294328,
           1.012908090353351,
           1.000622421586938,
           0.9882635775110435,
           0.97584096221884,
           0.963364359975938,
           0.9508439540856547,
           0.9382903466374083,
           0.925714579097475,
           0.9131281536783002,
           0.9005430553944825,
           0.8879717746796729,
           0.8754273303981215,
           0.8629232930365409,
           0.8504738078055017,
           0.83809361731378,
           0.8257980834032365,
           0.8136032076452386,
           0.8015256499020318,
           0.7895827442478967,
           0.7777925114260434,
           0.7661736668894777,
           0.7547456233400222,
           0.7435284865431435,
           0.7325430430626726,
           0.7218107384362742,
           0.7113536442091472,
           0.701194412171736,
           0.6913562141213213,
           0.6818626655034284,
           0.6727377314046801,
           0.6640056135821936,
           0.6556906175429852,
           0.6478169991442185,
           0.6404087907800609,
           0.6334896079535425,
           0.6270824378909208,
           0.6212094128164496,
           0.6158915715261906,
           0.6111486139236479,
           0.6069986541363735,
           0.6034579786400925,
           0.6005408163910112,
           0.598259128229155,
           0.5966224227032567,
           0.5956376049441885,
           0.5953088642766879,
           0.5956376049441893,
           0.596622422703258,
           0.5982591282291571,
           0.6005408163910138,
           0.603457978640096,
           0.6069986541363775,
           0.6111486139236526,
           0.6158915715261957,
           0.6212094128164554,
           0.6270824378909271,
           0.6334896079535494,
           0.6404087907800684,
           0.6478169991442264,
           0.6556906175429936,
           0.6640056135822023,
           0.6727377314046894,
           0.6818626655034381,
           0.6913562141213313,
           0.7011944121717463,
           0.7113536442091579,
           0.7218107384362851,
           0.7325430430626838,
           0.743528486543155,
           0.7547456233400338,
           0.7661736668894895,
           0.7777925114260554,
           0.7895827442479089,
           0.8015256499020441,
           0.8136032076452512,
           0.8257980834032492,
           0.8380936173137927,
           0.8504738078055146,
           0.8629232930365538,
           0.8754273303981343,
           0.8879717746796859,
           0.9005430553944954,
           0.9131281536783133,
           0.9257145790974879,
           0.9382903466374212,
           0.9508439540856678,
           0.9633643599759509,
           0.9758409622188527,
           0.9882635775110562,
           1.0006224215869506,
           1.0129080903533636,
           1.0251115419294452,
           1.0372240795986671,
           1.0492373356679385,
           1.0611432562194973,
           1.0729340867340544,
           1.0846023585583093,
           1.0961408761860718,
           1.1075427053195432,
           1.1188011616756504,
           1.1299098005014037,
           1.1408624067620023,
           1.1516529859656308,
           1.1622757555894963,
           1.1727251370725662,
           1.1829957483415618,
           1.1930823968380464,
           1.2029800730158053,
           1.2126839442791535,
           1.2221893493342668,
           1.2314917929271108,
           1.2405869409429922,
           1.2494706158441975,
           1.258138792423567,
           1.2665875938532123,
           1.2748132880088605,
           1.2828122840515677,
           1.2905811292497025,
           1.2981165060252426,
           1.305415229209472,
           1.312474243494182,
           1.319290621065423,
           1.3258615594077456,
           1.3321843792677195,
           1.3382565227662953,
           1.3440755516503293,
           1.3496391456742882,
           1.3549451011038007,
           1.3599913293333488,
           1.364775855610955,
           1.3692968178632925,
           1.3735524656151248,
           1.3775411589974913,
           1.3812613678394952,
           1.3847116708389775,
           1.3878907548077837,
           1.3907974139876849,
           1.3934305494334098,
           1.3957891684595674,
           1.3978723841485872,
           1.3996794149171026,
           1.401209584138527,
           1.4024623198198474,
           1.403437154330945,
           1.4041337241850385,
           1.4045517698690924
          ],
          [
           1.3799904525392033,
           1.3798572509059837,
           1.379457697741456,
           1.37879194827616,
           1.377860261311584,
           1.3766629993464767,
           1.3752006287545278,
           1.373473720014278,
           1.3714829479923534,
           1.3692290922813926,
           1.3667130375942782,
           1.363935774216565,
           1.360898398519269,
           1.357602113534467,
           1.3540482295964544,
           1.3502381650515218,
           1.346173447039724,
           1.3418557123523582,
           1.3372867083692273,
           1.3324682940801142,
           1.3274024411953107,
           1.3220912353504215,
           1.316536877411126,
           1.3107416848840132,
           1.304708093440094,
           1.298438658558088,
           1.2919360572951413,
           1.2852030901931526,
           1.2782426833295168,
           1.2710578905216863,
           1.2636518956956162,
           1.2560280154288535,
           1.2481897016797268,
           1.2401405447148672,
           1.2318842762480535,
           1.2234247728041987,
           1.214766059323124,
           1.2059123130186398,
           1.1968678675093105,
           1.1876372172382046,
           1.1782250221997934,
           1.1686361129930731,
           1.1588754962208336,
           1.1489483602558366,
           1.138860081395418,
           1.1286162304267193,
           1.1182225796253027,
           1.1076851102103056,
           1.0970100202794935,
           1.086203733247489,
           1.075272906810071,
           1.0642244424566205,
           1.0530654955514887,
           1.0418034860031284,
           1.0304461095371598,
           1.019001349585965,
           1.0074774898027585,
           0.9958831272021367,
           0.9842271859216803,
           0.9725189315899214,
           0.9607679862746921,
           0.948984343972113,
           0.9371783865799401,
           0.9253609002792378,
           0.913543092224948,
           0.9017366074184048,
           0.8899535456027362,
           0.87820647798493,
           0.8665084635456244,
           0.8548730646491098,
           0.8433143616112221,
           0.8318469658216965,
           0.8204860309502219,
           0.8092472616922738,
           0.7981469194326689,
           0.7872018241229968,
           0.7764293515856808,
           0.765847425375188,
           0.7554745022496172,
           0.7453295502383173,
           0.7354320182392706,
           0.725801796050836,
           0.7164591637442568,
           0.7074247293252395,
           0.698719353724538,
           0.6903640623084886,
           0.6823799423196656,
           0.674788025952298,
           0.6676091591407661,
           0.6608638565919467,
           0.6545721441171725,
           0.6487533899038328,
           0.6434261269890796,
           0.6386078698294421,
           0.6343149284637993,
           0.6305622243006994,
           0.6273631119792253,
           0.6247292120113075,
           0.6226702589739831,
           0.6211939698546166,
           0.6203059367474075,
           0.6200095474607966,
           0.6203059367474082,
           0.6211939698546178,
           0.6226702589739849,
           0.6247292120113098,
           0.6273631119792283,
           0.6305622243007031,
           0.6343149284638036,
           0.6386078698294467,
           0.643426126989085,
           0.6487533899038386,
           0.6545721441171787,
           0.6608638565919535,
           0.6676091591407732,
           0.6747880259523057,
           0.6823799423196736,
           0.6903640623084971,
           0.698719353724547,
           0.7074247293252486,
           0.7164591637442663,
           0.7258017960508458,
           0.7354320182392806,
           0.7453295502383277,
           0.7554745022496278,
           0.7658474253751988,
           0.7764293515856918,
           0.787201824123008,
           0.7981469194326802,
           0.8092472616922854,
           0.8204860309502334,
           0.8318469658217083,
           0.8433143616112339,
           0.8548730646491218,
           0.8665084635456364,
           0.8782064779849421,
           0.8899535456027484,
           0.9017366074184167,
           0.9135430922249603,
           0.9253609002792499,
           0.9371783865799521,
           0.9489843439721253,
           0.9607679862747043,
           0.9725189315899334,
           0.9842271859216923,
           0.9958831272021487,
           1.0074774898027703,
           1.019001349585977,
           1.0304461095371713,
           1.0418034860031398,
           1.0530654955515002,
           1.064224442456632,
           1.0752729068100824,
           1.0862037332475003,
           1.0970100202795046,
           1.1076851102103165,
           1.1182225796253136,
           1.12861623042673,
           1.1388600813954282,
           1.1489483602558466,
           1.1588754962208436,
           1.168636112993083,
           1.1782250221998032,
           1.187637217238214,
           1.1968678675093196,
           1.2059123130186489,
           1.214766059323133,
           1.2234247728042071,
           1.2318842762480622,
           1.2401405447148757,
           1.2481897016797352,
           1.2560280154288612,
           1.263651895695624,
           1.2710578905216936,
           1.2782426833295246,
           1.2852030901931595,
           1.2919360572951482,
           1.298438658558095,
           1.3047080934401,
           1.3107416848840192,
           1.3165368774111312,
           1.3220912353504266,
           1.3274024411953163,
           1.3324682940801194,
           1.337286708369232,
           1.3418557123523627,
           1.346173447039728,
           1.3502381650515265,
           1.3540482295964582,
           1.3576021135344705,
           1.360898398519272,
           1.363935774216568,
           1.3667130375942806,
           1.369229092281395,
           1.3714829479923556,
           1.3734737200142801,
           1.3752006287545298,
           1.3766629993464778,
           1.3778602613115853,
           1.3787919482761606,
           1.3794576977414563,
           1.3798572509059837
          ],
          [
           1.355889588549581,
           1.3557626179184155,
           1.3553817575342837,
           1.35474716195115,
           1.3538590888452955,
           1.3527178991452278,
           1.3513240572143543,
           1.3496781310872166,
           1.3477807927603285,
           1.3456328185388877,
           1.3432350894408813,
           1.3405885916603473,
           1.3376944170918232,
           1.3345537639182543,
           1.3311679372649277,
           1.3275383499222644,
           1.3236665231405953,
           1.319554087500354,
           1.3152027838614302,
           1.3106144643957467,
           1.3057910937074821,
           1.3007347500456954,
           1.2954476266144923,
           1.2899320329862596,
           1.284190396623888,
           1.2782252645183316,
           1.2720393049482914,
           1.2656353093692518,
           1.2590161944395928,
           1.252185004191969,
           1.245144912358666,
           1.2378992248601544,
           1.2304513824666108,
           1.2228049636427007,
           1.21496368758648,
           1.2069314174738324,
           1.198712163920402,
           1.1903100886735325,
           1.1817295085472506,
           1.1729748996138347,
           1.1640509016659768,
           1.1549623229639434,
           1.1457141452824986,
           1.1363115292725798,
           1.1267598201528664,
           1.1170645537463397,
           1.107231462876756,
           1.0972664841395088,
           1.0871757650606688,
           1.076965671656959,
           1.066642796407988,
           1.056213966650184,
           1.0456862533993858,
           1.0350669806059503,
           1.0243637348423118,
           1.0135843754181335,
           1.0027370449123036,
           0.9918301801039576,
           0.9808725232761798,
           0.9698731338559509,
           0.9588414003419444,
           0.9477870524577743,
           0.9367201734519675,
           0.9256512124470229,
           0.9145909967181922,
           0.9035507437577799,
           0.8925420729526289,
           0.8815770166708256,
           0.8706680305183736,
           0.8598280024876931,
           0.8490702606772895,
           0.8384085792161848,
           0.827857181978105,
           0.8174307436197986,
           0.8071443874262957,
           0.7970136793949271,
           0.7870546179414823,
           0.7772836185685081,
           0.7677174928005145,
           0.7583734206674521,
           0.7492689160104907,
           0.7404217838976584,
           0.7318500694764086,
           0.7235719976609922,
           0.7156059031597508,
           0.707970150495671,
           0.7006830438662307,
           0.6937627269274507,
           0.6872270728715482,
           0.6810935654940099,
           0.6753791723070105,
           0.6701002111406354,
           0.6652722120659069,
           0.6609097768548425,
           0.6570264385402583,
           0.6536345239273353,
           0.6507450221154975,
           0.6483674621902037,
           0.6465098032213307,
           0.6451783395459396,
           0.6443776240148199,
           0.6441104114504189,
           0.6443776240148205,
           0.6451783395459407,
           0.6465098032213322,
           0.6483674621902058,
           0.6507450221155001,
           0.6536345239273386,
           0.657026438540262,
           0.6609097768548469,
           0.6652722120659118,
           0.6701002111406408,
           0.675379172307016,
           0.6810935654940159,
           0.6872270728715546,
           0.6937627269274576,
           0.700683043866238,
           0.7079701504956788,
           0.7156059031597588,
           0.7235719976610006,
           0.7318500694764174,
           0.7404217838976676,
           0.7492689160104999,
           0.7583734206674615,
           0.7677174928005243,
           0.777283618568518,
           0.7870546179414925,
           0.7970136793949374,
           0.8071443874263062,
           0.8174307436198093,
           0.8278571819781158,
           0.8384085792161955,
           0.8490702606773005,
           0.8598280024877043,
           0.8706680305183848,
           0.8815770166708365,
           0.8925420729526403,
           0.9035507437577912,
           0.9145909967182038,
           0.9256512124470342,
           0.9367201734519788,
           0.9477870524577859,
           0.9588414003419556,
           0.9698731338559622,
           0.980872523276191,
           0.991830180103969,
           1.002737044912315,
           1.0135843754181446,
           1.024363734842323,
           1.0350669806059611,
           1.0456862533993967,
           1.0562139666501946,
           1.0666427964079988,
           1.0769656716569693,
           1.0871757650606795,
           1.0972664841395188,
           1.107231462876766,
           1.1170645537463497,
           1.1267598201528763,
           1.1363115292725898,
           1.1457141452825077,
           1.1549623229639527,
           1.1640509016659861,
           1.1729748996138438,
           1.1817295085472592,
           1.1903100886735414,
           1.1987121639204106,
           1.2069314174738406,
           1.214963687586488,
           1.2228049636427087,
           1.2304513824666188,
           1.2378992248601617,
           1.245144912358673,
           1.2521850041919764,
           1.2590161944395997,
           1.2656353093692583,
           1.2720393049482979,
           1.2782252645183383,
           1.284190396623894,
           1.2899320329862651,
           1.2954476266144976,
           1.3007347500457005,
           1.3057910937074872,
           1.3106144643957511,
           1.3152027838614344,
           1.3195540875003582,
           1.323666523140599,
           1.3275383499222684,
           1.3311679372649314,
           1.3345537639182576,
           1.3376944170918261,
           1.3405885916603504,
           1.3432350894408838,
           1.3456328185388902,
           1.3477807927603307,
           1.3496781310872186,
           1.3513240572143561,
           1.3527178991452293,
           1.3538590888452966,
           1.3547471619511506,
           1.3553817575342844,
           1.3557626179184157
          ],
          [
           1.3324118597838257,
           1.3322911757895615,
           1.3319291749878472,
           1.3313260109480365,
           1.3304819397062155,
           1.329397319896312,
           1.328072612934379,
           1.3265083832567899,
           1.3247052986132835,
           1.3226641304160336,
           1.3203857541461166,
           1.3178711498189923,
           1.3151214025108249,
           1.3121377029477264,
           1.3089213481602173,
           1.305473742205475,
           1.3017963969601711,
           1.2978909329869686,
           1.2937590804780223,
           1.289402680279094,
           1.284823684998189,
           1.280024160202902,
           1.2750062857109818,
           1.2697723569789177,
           1.264324786593683,
           1.2586661058730972,
           1.2527989665806014,
           1.2467261427605878,
           1.2404505327007778,
           1.233975161028482,
           1.227303180947946,
           1.2204378766263255,
           1.213382665736195,
           1.2061411021628259,
           1.198716878884803,
           1.1911138310368572,
           1.1833359391640723,
           1.1753873326768745,
           1.1672722935164113,
           1.15899526004008,
           1.1505608311370352,
           1.1419737705834938,
           1.1332390116475357,
           1.1243616619528527,
           1.11534700861049,
           1.1062005236270342,
           1.0969278695968925,
           1.087534905685231,
           1.0780276939067657,
           1.0684125057038536,
           1.0586958288251826,
           1.0488843745037069,
           1.0389850849292717,
           1.0290051410075334,
           1.018951970392171,
           1.0088332557719812,
           0.9986569433880427,
           0.9884312517487014,
           0.9781646805014441,
           0.9678660194107394,
           0.9575443573794329,
           0.9472090914381721,
           0.9368699356124631,
           0.9265369295601826,
           0.9162204468536029,
           0.9059312027591039,
           0.8956802613447366,
           0.8854790417206672,
           0.8753393231903372,
           0.8652732490611273,
           0.8552933288326882,
           0.8454124384493811,
           0.8356438182710425,
           0.8260010683844373,
           0.8164981408473518,
           0.807149328429661,
           0.7979692493925619,
           0.7889728278304103,
           0.7801752690915554,
           0.7715920297977186,
           0.7632387819986172,
           0.755131371032585,
           0.74728576671777,
           0.7397180075748733,
           0.7324441378836303,
           0.725480137503016,
           0.7188418445401684,
           0.7125448711346667,
           0.7066045128308649,
           0.7010356522373452,
           0.6958526579130437,
           0.6910692796658457,
           0.6866985416910963,
           0.682752635202364,
           0.679242812401676,
           0.676179283787615,
           0.6735711208939892,
           0.671426166577881,
           0.6697509549250908,
           0.6685506427085953,
           0.6678289541216008,
           0.6675881402161743,
           0.6678289541216013,
           0.6685506427085963,
           0.6697509549250923,
           0.6714261665778829,
           0.6735711208939915,
           0.676179283787618,
           0.6792428124016794,
           0.6827526352023677,
           0.6866985416911007,
           0.6910692796658504,
           0.695852657913049,
           0.7010356522373508,
           0.7066045128308708,
           0.712544871134673,
           0.7188418445401752,
           0.7254801375030232,
           0.7324441378836377,
           0.7397180075748809,
           0.747285766717778,
           0.7551313710325931,
           0.7632387819986255,
           0.7715920297977271,
           0.7801752690915644,
           0.7889728278304194,
           0.7979692493925711,
           0.8071493284296706,
           0.8164981408473615,
           0.8260010683844474,
           0.8356438182710524,
           0.8454124384493911,
           0.8552933288326984,
           0.8652732490611377,
           0.8753393231903478,
           0.8854790417206775,
           0.895680261344747,
           0.9059312027591144,
           0.9162204468536136,
           0.9265369295601932,
           0.9368699356124739,
           0.9472090914381829,
           0.9575443573794435,
           0.9678660194107499,
           0.9781646805014546,
           0.988431251748712,
           0.998656943388053,
           1.0088332557719915,
           1.0189519703921817,
           1.0290051410075436,
           1.0389850849292819,
           1.0488843745037169,
           1.0586958288251929,
           1.0684125057038634,
           1.0780276939067757,
           1.087534905685241,
           1.0969278695969022,
           1.1062005236270438,
           1.1153470086104995,
           1.1243616619528618,
           1.1332390116475448,
           1.1419737705835027,
           1.150560831137044,
           1.1589952600400886,
           1.1672722935164197,
           1.175387332676883,
           1.1833359391640805,
           1.191113831036865,
           1.1987168788848106,
           1.2061411021628334,
           1.2133826657362023,
           1.2204378766263326,
           1.2273031809479529,
           1.2339751610284886,
           1.2404505327007842,
           1.2467261427605942,
           1.2527989665806076,
           1.2586661058731035,
           1.2643247865936886,
           1.2697723569789228,
           1.275006285710987,
           1.280024160202907,
           1.2848236849981938,
           1.2894026802790988,
           1.2937590804780266,
           1.2978909329869728,
           1.301796396960175,
           1.3054737422054787,
           1.3089213481602204,
           1.3121377029477295,
           1.3151214025108278,
           1.3178711498189948,
           1.3203857541461193,
           1.3226641304160358,
           1.3247052986132855,
           1.3265083832567917,
           1.328072612934381,
           1.3293973198963132,
           1.3304819397062164,
           1.3313260109480372,
           1.3319291749878477,
           1.3322911757895617
          ],
          [
           1.309579979428233,
           1.309465625315556,
           1.3091226137073928,
           1.3085510968192071,
           1.307751328429737,
           1.3067236640107667,
           1.3054685609094516,
           1.303986578583858,
           1.3022783788925385,
           1.3003447264391872,
           1.2981864889735861,
           1.2958046378502603,
           1.2932002485464555,
           1.2903745012412453,
           1.2873286814577953,
           1.2840641807709967,
           1.280582497582915,
           1.2768852379686997,
           1.2729741165958248,
           1.268850957719755,
           1.2645176962593543,
           1.259976378955585,
           1.2552291656172787,
           1.250278330457995,
           1.2451262635282128,
           1.2397754722473464,
           1.2342285830402997,
           1.2284883430835154,
           1.2225576221656926,
           1.2164394146685698,
           1.2101368416733758,
           1.2036531531987473,
           1.1969917305760809,
           1.1901560889684453,
           1.1831498800392928,
           1.1759768947773002,
           1.1686410664837033,
           1.161146473928476,
           1.1534973446816226,
           1.145698058625694,
           1.1377531516553836,
           1.1296673195697058,
           1.1214454221617514,
           1.1130924875103931,
           1.104613716477491,
           1.096014487413118,
           1.0873003610700889,
           1.078477085727541,
           1.0695506025214767,
           1.0605270509780047,
           1.0514127747424074,
           1.0422143274941253,
           1.0329384790341858,
           1.0235922215274533,
           1.0141827758773025,
           1.0047175982047962,
           0.9952043863981512,
           0.9856510866910997,
           0.9760659002206182,
           0.9664572895053419,
           0.9568339847757064,
           0.9472049900754336,
           0.9375795890413131,
           0.927967350254311,
           0.918378132039863,
           0.9088220865787727,
           0.899309663172536,
           0.8898516104882706,
           0.8804589775889028,
           0.8711431135341889,
           0.8619156653178288,
           0.8527885738859015,
           0.8437740679627159,
           0.8348846553926655,
           0.8261331116917427,
           0.8175324654910634,
           0.8090959805483104,
           0.8008371340028101,
           0.7927695905575168,
           0.7849071722881086,
           0.7772638238072945,
           0.7698535725529236,
           0.7626904840229913,
           0.7557886118503273,
           0.7491619426954249,
           0.7428243360377133,
           0.7367894590630863,
           0.7310707169772979,
           0.7256811792185143,
           0.7206335021943904,
           0.7159398493248735,
           0.7116118093258438,
           0.7076603138140242,
           0.7040955554430021,
           0.700926907886073,
           0.698162849056417,
           0.6958108889920065,
           0.6938775038260189,
           0.6923680772095285,
           0.691286850450299,
           0.690636882480591,
           0.690420020571767,
           0.6906368824805914,
           0.6912868504502999,
           0.6923680772095298,
           0.6938775038260208,
           0.6958108889920086,
           0.6981628490564197,
           0.7009269078860761,
           0.7040955554430056,
           0.7076603138140282,
           0.711611809325848,
           0.7159398493248781,
           0.7206335021943954,
           0.7256811792185196,
           0.7310707169773035,
           0.7367894590630925,
           0.7428243360377198,
           0.7491619426954317,
           0.7557886118503342,
           0.7626904840229988,
           0.7698535725529312,
           0.7772638238073022,
           0.7849071722881166,
           0.7927695905575249,
           0.8008371340028184,
           0.8090959805483191,
           0.8175324654910722,
           0.8261331116917516,
           0.8348846553926746,
           0.8437740679627251,
           0.8527885738859108,
           0.8619156653178383,
           0.8711431135341985,
           0.8804589775889123,
           0.8898516104882804,
           0.8993096631725458,
           0.9088220865787825,
           0.9183781320398728,
           0.9279673502543206,
           0.937579589041323,
           0.9472049900754437,
           0.9568339847757162,
           0.9664572895053518,
           0.9760659002206281,
           0.9856510866911095,
           0.995204386398161,
           1.004717598204806,
           1.0141827758773123,
           1.0235922215274629,
           1.0329384790341953,
           1.042214327494135,
           1.0514127747424167,
           1.0605270509780138,
           1.0695506025214858,
           1.07847708572755,
           1.087300361070098,
           1.0960144874131268,
           1.1046137164774998,
           1.1130924875104018,
           1.1214454221617596,
           1.1296673195697144,
           1.1377531516553918,
           1.1456980586257017,
           1.1534973446816306,
           1.1611464739284838,
           1.1686410664837108,
           1.1759768947773073,
           1.1831498800393,
           1.1901560889684524,
           1.1969917305760878,
           1.203653153198754,
           1.2101368416733824,
           1.2164394146685762,
           1.2225576221656989,
           1.2284883430835214,
           1.2342285830403057,
           1.2397754722473522,
           1.2451262635282183,
           1.250278330458,
           1.2552291656172834,
           1.2599763789555896,
           1.2645176962593592,
           1.2688509577197595,
           1.2729741165958288,
           1.2768852379687032,
           1.2805824975829183,
           1.284064180771,
           1.2873286814577987,
           1.2903745012412486,
           1.2932002485464582,
           1.2958046378502628,
           1.2981864889735883,
           1.3003447264391892,
           1.3022783788925403,
           1.30398657858386,
           1.3054685609094532,
           1.3067236640107676,
           1.3077513284297382,
           1.3085510968192076,
           1.309122613707393,
           1.3094656253155563
          ],
          [
           1.2874160358524733,
           1.2873080411921152,
           1.2869841073466637,
           1.2864443847480778,
           1.2856891241999893,
           1.284718677003533,
           1.283533495134061,
           1.282134131469294,
           1.2805212400696269,
           1.278695576511458,
           1.2766579982745783,
           1.2744094651848155,
           1.2719510399132927,
           1.269283888533825,
           1.266409281140137,
           1.2633285925247635,
           1.2600433029216402,
           1.2565549988145825,
           1.252865373814,
           1.2489762296043627,
           1.2448894769651089,
           1.2406071368678424,
           1.2361313416528217,
           1.231464336287914,
           1.226608479713325,
           1.2215662462755685,
           1.2163402272542732,
           1.2109331324855441,
           1.205347792085714,
           1.1995871582794106,
           1.1936543073359316,
           1.1875524416179801,
           1.1812848917468182,
           1.1748551188878915,
           1.1682667171609011,
           1.1615234161782129,
           1.1546290837153075,
           1.1475877285167526,
           1.1404035032408633,
           1.1330807075458178,
           1.125623791319484,
           1.1180373580545946,
           1.11032616837014,
           1.10249514367893,
           1.0945493700001865,
           1.0864941019147178,
           1.078334766658712,
           1.0700769683503968,
           1.0617264923417407,
           1.0532893096849851,
           1.044771581701037,
           1.0361796646336023,
           1.0275201143693582,
           1.0187996912003825,
           1.0100253646004713,
           1.0012043179817953,
           0.9923439533925836,
           0.9834518961100671,
           0.9745359990757997,
           0.9656043471126128,
           0.9566652608538652,
           0.9477273003062868,
           0.9387992679576187,
           0.9298902113294117,
           0.9210094248638566,
           0.9121664510214358,
           0.9033710804536452,
           0.8946333511022175,
           0.8859635460633869,
           0.8773721900430855,
           0.868870044216894,
           0.8604680992975104,
           0.8521775666030064,
           0.8440098669117485,
           0.8359766168853296,
           0.8280896128398884,
           0.8203608116496731,
           0.8128023085754985,
           0.8054263118257697,
           0.7982451136799333,
           0.7912710580343942,
           0.7845165042698801,
           0.7779937873875125,
           0.7717151744187756,
           0.765692817182178,
           0.7599387015362623,
           0.7544645933638611,
           0.7492819816146772,
           0.7444020188303829,
           0.7398354596758594,
           0.735592598098737,
           0.7316832038333559,
           0.7281164590505612,
           0.724900896027066,
           0.7220443367631779,
           0.719553835511451,
           0.717435625187787,
           0.715695068618028,
           0.7143366155255092,
           0.7133637660881095,
           0.7127790417881408,
           0.7125839641475267,
           0.7127790417881411,
           0.7133637660881101,
           0.7143366155255104,
           0.7156950686180296,
           0.7174356251877889,
           0.7195538355114535,
           0.7220443367631808,
           0.7249008960270692,
           0.7281164590505648,
           0.7316832038333599,
           0.7355925980987412,
           0.7398354596758637,
           0.7444020188303876,
           0.7492819816146824,
           0.7544645933638666,
           0.7599387015362681,
           0.7656928171821841,
           0.771715174418782,
           0.777993787387519,
           0.784516504269887,
           0.7912710580344013,
           0.7982451136799407,
           0.8054263118257771,
           0.8128023085755062,
           0.8203608116496809,
           0.8280896128398965,
           0.8359766168853379,
           0.8440098669117568,
           0.8521775666030146,
           0.8604680992975189,
           0.8688700442169026,
           0.8773721900430944,
           0.8859635460633957,
           0.8946333511022265,
           0.9033710804536543,
           0.9121664510214449,
           0.9210094248638658,
           0.929890211329421,
           0.9387992679576281,
           0.9477273003062961,
           0.9566652608538743,
           0.965604347112622,
           0.9745359990758089,
           0.9834518961100764,
           0.9923439533925928,
           1.0012043179818044,
           1.0100253646004804,
           1.0187996912003918,
           1.027520114369367,
           1.0361796646336112,
           1.044771581701046,
           1.0532893096849938,
           1.061726492341749,
           1.0700769683504052,
           1.0783347666587206,
           1.086494101914726,
           1.0945493700001947,
           1.1024951436789379,
           1.1103261683701477,
           1.1180373580546026,
           1.1256237913194915,
           1.1330807075458253,
           1.1404035032408706,
           1.14758772851676,
           1.1546290837153146,
           1.1615234161782197,
           1.168266717160908,
           1.174855118887898,
           1.181284891746825,
           1.1875524416179863,
           1.1936543073359378,
           1.1995871582794166,
           1.20534779208572,
           1.2109331324855497,
           1.216340227254279,
           1.221566246275574,
           1.2266084797133299,
           1.2314643362879187,
           1.2361313416528263,
           1.2406071368678468,
           1.244889476965113,
           1.2489762296043665,
           1.2528653738140039,
           1.256554998814586,
           1.2600433029216436,
           1.2633285925247666,
           1.2664092811401402,
           1.2692838885338278,
           1.2719510399132954,
           1.274409465184818,
           1.2766579982745807,
           1.2786955765114603,
           1.2805212400696289,
           1.2821341314692953,
           1.2835334951340622,
           1.2847186770035341,
           1.28568912419999,
           1.2864443847480784,
           1.2869841073466641,
           1.2873080411921154
          ],
          [
           1.2659414712405206,
           1.2658398506164779,
           1.265535038123436,
           1.2650271819224537,
           1.264316529028012,
           1.2634034254273159,
           1.2622883162477652,
           1.2609717459730423,
           1.2594543587083935,
           1.257736898495813,
           1.255820209679953,
           1.2537052373257243,
           1.2513930276886733,
           1.248884728739339,
           1.2461815907429272,
           1.243284966895766,
           1.2401963140200998,
           1.236917193318941,
           1.2334492711927678,
           1.2297943201199981,
           1.225954219603263,
           1.2219309571836008,
           1.21772662952479,
           1.2133434435701187,
           1.2087837177739684,
           1.2040498834106301,
           1.1991444859628437,
           1.1940701865925574,
           1.1888297636964187,
           1.1834261145484946,
           1.1778622570326678,
           1.1721413314670848,
           1.1662666025229123,
           1.1602414612395107,
           1.154069427137915,
           1.1477541504342637,
           1.141299414354484,
           1.1347091375511447,
           1.1279873766229087,
           1.1211383287364345,
           1.1141663343499086,
           1.1070758800365808,
           1.0998716014057417,
           1.092558286117507,
           1.0851408769865198,
           1.077624475168244,
           1.0700143434198919,
           1.062315909426157,
           1.0545347691778082,
           1.0466766903888196,
           1.0387476159350146,
           1.0307536672942086,
           1.0227011479644696,
           1.0145965468333922,
           1.0064465414671633,
           0.9982580012836534,
           0.990037990568798,
           0.9817937712901134,
           0.9735328056553169,
           0.9652627583576955,
           0.9569914984430987,
           0.948727100726244,
           0.9404778466764712,
           0.9322522246852005,
           0.9240589296192502,
           0.9159068615559388,
           0.907805123587689,
           0.8997630185758373,
           0.8917900447257432,
           0.8838958898483472,
           0.8760904241673392,
           0.8683836915264173,
           0.8607858988481352,
           0.8533074036949734,
           0.8459586997850157,
           0.8387504003194551,
           0.8316932189876188,
           0.8247979485278092,
           0.8180754367395137,
           0.8115365598648874,
           0.8051921932852487,
           0.799053179511911,
           0.7931302934901251,
           0.7874342052801432,
           0.7819754402301483,
           0.776764336811429,
           0.7718110023458694,
           0.7671252669183622,
           0.7627166358306408,
           0.7585942410164456,
           0.7547667918987904,
           0.7512425262260796,
           0.7480291614725159,
           0.7451338474271396,
           0.7425631206226448,
           0.7403228612676532,
           0.7384182533426896,
           0.7368537484994595,
           0.7356330343646077,
           0.7347590077930711,
           0.7342337535433784,
           0.7340585287594793,
           0.7342337535433787,
           0.7347590077930719,
           0.7356330343646088,
           0.736853748499461,
           0.7384182533426914,
           0.7403228612676555,
           0.7425631206226474,
           0.7451338474271426,
           0.7480291614725192,
           0.751242526226083,
           0.754766791898794,
           0.7585942410164497,
           0.7627166358306453,
           0.7671252669183669,
           0.7718110023458745,
           0.7767643368114343,
           0.7819754402301539,
           0.787434205280149,
           0.7931302934901312,
           0.7990531795119173,
           0.805192193285255,
           0.811536559864894,
           0.8180754367395204,
           0.8247979485278162,
           0.8316932189876259,
           0.8387504003194626,
           0.8459586997850232,
           0.8533074036949809,
           0.8607858988481429,
           0.8683836915264251,
           0.8760904241673472,
           0.8838958898483553,
           0.8917900447257513,
           0.8997630185758454,
           0.9078051235876973,
           0.9159068615559471,
           0.9240589296192587,
           0.9322522246852087,
           0.9404778466764797,
           0.9487271007262527,
           0.9569914984431073,
           0.965262758357704,
           0.9735328056553254,
           0.981793771290122,
           0.9900379905688065,
           0.9982580012836618,
           1.0064465414671715,
           1.0145965468334004,
           1.022701147964478,
           1.030753667294217,
           1.0387476159350226,
           1.0466766903888276,
           1.0545347691778162,
           1.062315909426165,
           1.0700143434198999,
           1.0776244751682518,
           1.0851408769865276,
           1.0925582861175145,
           1.099871601405749,
           1.107075880036588,
           1.1141663343499157,
           1.1211383287364416,
           1.1279873766229158,
           1.134709137551152,
           1.1412994143544906,
           1.14775415043427,
           1.1540694271379215,
           1.160241461239517,
           1.1662666025229185,
           1.1721413314670908,
           1.1778622570326738,
           1.1834261145485,
           1.1888297636964242,
           1.1940701865925627,
           1.1991444859628488,
           1.204049883410635,
           1.208783717773973,
           1.2133434435701234,
           1.2177266295247937,
           1.221930957183605,
           1.2259542196032671,
           1.229794320120002,
           1.2334492711927711,
           1.2369171933189445,
           1.2401963140201029,
           1.243284966895769,
           1.2461815907429303,
           1.2488847287393414,
           1.2513930276886756,
           1.2537052373257263,
           1.255820209679955,
           1.257736898495815,
           1.2594543587083953,
           1.260971745973044,
           1.2622883162477667,
           1.263403425427317,
           1.264316529028013,
           1.2650271819224541,
           1.2655350381234363,
           1.2658398506164779
          ],
          [
           1.2451770608467245,
           1.2450818125276055,
           1.2447961160127106,
           1.244320116651435,
           1.2436540567661911,
           1.2427982757627,
           1.241753210284753,
           1.2405193944137598,
           1.2390974599135294,
           1.237488136520812,
           1.235692252282218,
           1.2337107339382274,
           1.2315446073550913,
           1.229194998005514,
           1.2266631314990828,
           1.2239503341634996,
           1.2210580336777388,
           1.2179877597583244,
           1.214741144899996,
           1.211319925172068,
           1.2077259410718642,
           1.2039611384366198,
           1.2000275694153035,
           1.1959273935017962,
           1.1916628786308934,
           1.1872364023385669,
           1.182650452987893,
           1.1779076310619996,
           1.1730106505253064,
           1.1679623402542214,
           1.16276564553832,
           1.1574236296528548,
           1.1519394755032355,
           1.1463164873418408,
           1.140558092557232,
           1.1346678435354478,
           1.1286494195926324,
           1.1225066289777434,
           1.1162434109434896,
           1.1098638378829746,
           1.1033721175287485,
           1.0967725952100735,
           1.0900697561632102,
           1.0832682278883854,
           1.076372782545821,
           1.0693883393817523,
           1.062319967173754,
           1.0551728866828898,
           1.0479524730981855,
           1.0406642584567303,
           1.0333139340202377,
           1.025907352586231,
           1.0184505307090634,
           1.0109496508027813,
           1.0034110630943662,
           0.9958412873921342,
           0.9882470146300507,
           0.980635108144429,
           0.9730126046349176,
           0.965386714756915,
           0.9577648232875485,
           0.9501544888022131,
           0.9425634427933982,
           0.9349995881582586,
           0.9274709969761274,
           0.9199859074921113,
           0.9125527202181178,
           0.90517999305833,
           0.8978764353624242,
           0.8906509008069328,
           0.8835123790033058,
           0.8764699857306724,
           0.8695329516923168,
           0.8627106096977527,
           0.8560123801772841,
           0.8494477549434116,
           0.8430262791236387,
           0.8367575312024411,
           0.8306511011266232,
           0.8247165664481769,
           0.8189634665021817,
           0.8134012746442881,
           0.8080393686027976,
           0.8028869990340609,
           0.7979532564065213,
           0.793247036377652,
           0.7887770038686034,
           0.784551556082669,
           0.7805787847546832,
           0.7768664379579464,
           0.7734218818319499,
           0.7702520626266272,
           0.7673634694856949,
           0.7647620984114698,
           0.7624534178651139,
           0.7604423364584489,
           0.7587331731854986,
           0.7573296306231999,
           0.7562347715011751,
           0.755450999000297,
           0.754980041089729,
           0.7548229391532756,
           0.7549800410897294,
           0.7554509990002977,
           0.7562347715011761,
           0.7573296306232012,
           0.7587331731855003,
           0.7604423364584509,
           0.7624534178651161,
           0.7647620984114725,
           0.7673634694856977,
           0.7702520626266304,
           0.7734218818319532,
           0.7768664379579501,
           0.7805787847546872,
           0.7845515560826734,
           0.7887770038686079,
           0.7932470363776569,
           0.7979532564065264,
           0.8028869990340661,
           0.8080393686028031,
           0.8134012746442937,
           0.8189634665021874,
           0.824716566448183,
           0.8306511011266294,
           0.8367575312024473,
           0.8430262791236454,
           0.8494477549434184,
           0.856012380177291,
           0.8627106096977597,
           0.8695329516923239,
           0.8764699857306795,
           0.8835123790033131,
           0.8906509008069403,
           0.8978764353624317,
           0.9051799930583375,
           0.9125527202181255,
           0.919985907492119,
           0.9274709969761352,
           0.9349995881582662,
           0.942563442793406,
           0.9501544888022209,
           0.9577648232875564,
           0.9653867147569226,
           0.9730126046349254,
           0.9806351081444368,
           0.9882470146300586,
           0.995841287392142,
           1.0034110630943742,
           1.010949650802789,
           1.0184505307090708,
           1.0259073525862386,
           1.033313934020245,
           1.0406642584567378,
           1.047952473098193,
           1.055172886682897,
           1.0623199671737615,
           1.0693883393817591,
           1.0763727825458282,
           1.0832682278883925,
           1.0900697561632169,
           1.0967725952100804,
           1.1033721175287552,
           1.1098638378829813,
           1.116243410943496,
           1.12250662897775,
           1.1286494195926386,
           1.1346678435354538,
           1.140558092557238,
           1.1463164873418465,
           1.1519394755032413,
           1.1574236296528606,
           1.1627656455383253,
           1.1679623402542265,
           1.1730106505253115,
           1.1779076310620045,
           1.182650452987898,
           1.1872364023385718,
           1.1916628786308978,
           1.1959273935018004,
           1.200027569415308,
           1.203961138436624,
           1.207725941071868,
           1.2113199251720717,
           1.2147411448999992,
           1.2179877597583275,
           1.2210580336777417,
           1.2239503341635025,
           1.2266631314990852,
           1.2291949980055168,
           1.2315446073550937,
           1.2337107339382296,
           1.2356922522822202,
           1.237488136520814,
           1.239097459913531,
           1.2405193944137611,
           1.2417532102847546,
           1.2427982757627012,
           1.2436540567661913,
           1.2443201166514357,
           1.2447961160127112,
           1.245081812527606
          ],
          [
           1.2251428928970922,
           1.225053997507049,
           1.2247873586470075,
           1.2243431182670026,
           1.2237215130163663,
           1.2229228743427496,
           1.2219476286309885,
           1.220796297382034,
           1.2194694974322358,
           1.217967941213342,
           1.2162924370536101,
           1.2144438895205083,
           1.2124232998055195,
           1.2102317661516155,
           1.2078704843240216,
           1.2053407481249134,
           1.2026439499527424,
           1.1997815814068906,
           1.1967552339383987,
           1.193566599547493,
           1.1902174715286642,
           1.186709745264018,
           1.183045419065601,
           1.1792265950673648,
           1.1752554801673747,
           1.1711343870207915,
           1.1668657350840566,
           1.162452051710598,
           1.157895973298218,
           1.153200246488155,
           1.1483677294155963,
           1.1434013930111755,
           1.138304322352704,
           1.1330797180660481,
           1.1277308977736822,
           1.1222612975890194,
           1.1166744736541139,
           1.1109741037177694,
           1.1051639887504465,
           1.0992480545916565,
           1.0932303536247088,
           1.0871150664727924,
           1.0809065037093724,
           1.0746091075747577,
           1.0682274536894918,
           1.0617662527538367,
           1.055230352221151,
           1.0486247379313218,
           1.0419545356886326,
           1.0352250127665066,
           1.02844157931948,
           1.0216097896804772,
           1.014735343519049,
           1.0078240868336212,
           1.000882012748057,
           0.9939152620799024,
           0.9869301236446334,
           0.9799330342570356,
           0.9729305783875428,
           0.9659294874279991,
           0.9589366385178907,
           0.9519590528787097,
           0.9450038936007588,
           0.9380784628235205,
           0.931190198247724,
           0.9243466689145604,
           0.9175555701852325,
           0.9108247178522889,
           0.9041620413131162,
           0.897575575735708,
           0.8910734531475175,
           0.8846638923800413,
           0.8783551878049083,
           0.8721556968018439,
           0.8660738259051354,
           0.8601180155832581,
           0.8542967236163163,
           0.8486184070480038,
           0.8430915027029794,
           0.8377244062769299,
           0.8325254500251315,
           0.8275028790959291,
           0.8226648265780991,
           0.8180192873552482,
           0.8135740908859623,
           0.8093368730548521,
           0.8053150472664805,
           0.801515774980751,
           0.7979459359140076,
           0.7946120981540841,
           0.7915204884590417,
           0.7886769630275319,
           0.7860869790428248,
           0.783755567301765,
           0.7816873062436527,
           0.7798862976916859,
           0.7783561446108136,
           0.7770999311704241,
           0.7761202053782482,
           0.775418964523456,
           0.7749976436326381,
           0.7748571071029079,
           0.7749976436326386,
           0.7754189645234567,
           0.7761202053782491,
           0.7770999311704252,
           0.7783561446108151,
           0.7798862976916876,
           0.7816873062436547,
           0.7837555673017671,
           0.7860869790428273,
           0.7886769630275348,
           0.7915204884590445,
           0.7946120981540874,
           0.7979459359140111,
           0.8015157749807548,
           0.8053150472664845,
           0.8093368730548564,
           0.8135740908859669,
           0.8180192873552529,
           0.822664826578104,
           0.8275028790959343,
           0.8325254500251367,
           0.8377244062769353,
           0.8430915027029849,
           0.8486184070480096,
           0.8542967236163223,
           0.8601180155832642,
           0.8660738259051417,
           0.8721556968018502,
           0.8783551878049147,
           0.884663892380048,
           0.8910734531475242,
           0.8975755757357148,
           0.9041620413131229,
           0.9108247178522958,
           0.9175555701852397,
           0.9243466689145673,
           0.9311901982477311,
           0.9380784628235276,
           0.9450038936007662,
           0.9519590528787172,
           0.9589366385178979,
           0.9659294874280062,
           0.97293057838755,
           0.9799330342570427,
           0.9869301236446405,
           0.9939152620799095,
           1.0008820127480642,
           1.0078240868336281,
           1.0147353435190558,
           1.0216097896804843,
           1.028441579319487,
           1.0352250127665137,
           1.0419545356886393,
           1.048624737931329,
           1.055230352221158,
           1.0617662527538434,
           1.0682274536894985,
           1.0746091075747641,
           1.0809065037093786,
           1.0871150664727989,
           1.0932303536247148,
           1.0992480545916627,
           1.1051639887504525,
           1.1109741037177754,
           1.1166744736541196,
           1.122261297589025,
           1.1277308977736877,
           1.1330797180660537,
           1.1383043223527096,
           1.1434013930111804,
           1.148367729415601,
           1.1532002464881599,
           1.1578959732982228,
           1.1624520517106025,
           1.1668657350840612,
           1.171134387020796,
           1.175255480167379,
           1.1792265950673686,
           1.1830454190656048,
           1.1867097452640218,
           1.190217471528668,
           1.1935665995474962,
           1.1967552339384018,
           1.1997815814068935,
           1.202643949952745,
           1.205340748124916,
           1.207870484324024,
           1.210231766151618,
           1.2124232998055215,
           1.2144438895205103,
           1.216292437053612,
           1.2179679412133437,
           1.2194694974322373,
           1.220796297382035,
           1.22194762863099,
           1.2229228743427505,
           1.2237215130163668,
           1.2243431182670033,
           1.224787358647008,
           1.2250539975070494
          ],
          [
           1.205858349155229,
           1.2057757683623092,
           1.2055280719527088,
           1.2051153978510445,
           1.2045379759888288,
           1.20379612839026,
           1.2028902692924501,
           1.201820905300214,
           1.2005886355755675,
           1.1991941520621279,
           1.197638239744611,
           1.1959217769436696,
           1.1940457356463163,
           1.192011181872204,
           1.1898192760760329,
           1.1874712735863688,
           1.1849685250811421,
           1.1823124771000924,
           1.1795046725944038,
           1.1765467515137338,
           1.1734404514308119,
           1.1701876082037161,
           1.1667901566758738,
           1.163250131413743,
           1.1595696674820328,
           1.155751001256198,
           1.1517964712717923,
           1.147708519110113,
           1.1434896903193588,
           1.139142635370315,
           1.1346701106453152,
           1.1300749794589506,
           1.1253602131086593,
           1.1205288919529752,
           1.1155842065147876,
           1.1105294586065149,
           1.1053680624735671,
           1.1001035459519155,
           1.094739551634934,
           1.0892798380439976,
           1.0837282807965325,
           1.0780888737643792,
           1.0723657302143945,
           1.0665630839222047,
           1.0606852902489303,
           1.0547368271694944,
           1.0487222962398433,
           1.0426464234890163,
           1.036514060220505,
           1.0303301837057535,
           1.0240998977509495,
           1.0178284331164662,
           1.0115211477664194,
           1.0051835269238296,
           0.9988211829048225,
           0.9924398547031736,
           0.9860454072943364,
           0.9796438306258906,
           0.973241238259139,
           0.9668438656244216,
           0.9604580678505846,
           0.9540903171270622,
           0.9477471995551706,
           0.9414354114435944,
           0.9351617550016939,
           0.9289331333832693,
           0.9227565450328423,
           0.9166390772864741,
           0.910587899179681,
           0.9046102534162764,
           0.8987134474540144,
           0.8929048436658719,
           0.8871918485397625,
           0.8815819008845202,
           0.8760824590162154,
           0.8707009869063399,
           0.8654449392821726,
           0.8603217456797402,
           0.855338793461245,
           0.8505034098215704,
           0.8458228428224758,
           0.841304241508196,
           0.8369546351722469,
           0.8327809118620558,
           0.8287897962253592,
           0.8249878268197974,
           0.8213813330244342,
           0.8179764117086352,
           0.8147789038294142,
           0.8117943711425187,
           0.8090280732247344,
           0.8064849450146354,
           0.8041695750858923,
           0.8020861848708204,
           0.8002386090518285,
           0.7986302773344918,
           0.7972641978080114,
           0.7961429420867635,
           0.7952686324105528,
           0.7946429308612872,
           0.7942670308303844,
           0.794141650844771,
           0.7942670308303846,
           0.7946429308612877,
           0.7952686324105535,
           0.7961429420867644,
           0.7972641978080127,
           0.7986302773344933,
           0.8002386090518302,
           0.8020861848708224,
           0.8041695750858946,
           0.806484945014638,
           0.809028073224737,
           0.8117943711425217,
           0.8147789038294173,
           0.8179764117086387,
           0.8213813330244377,
           0.8249878268198014,
           0.8287897962253633,
           0.8327809118620599,
           0.8369546351722515,
           0.8413042415082006,
           0.8458228428224804,
           0.8505034098215752,
           0.8553387934612499,
           0.8603217456797453,
           0.8654449392821778,
           0.8707009869063455,
           0.876082459016221,
           0.881581900884526,
           0.8871918485397683,
           0.8929048436658777,
           0.8987134474540203,
           0.9046102534162825,
           0.9105878991796871,
           0.9166390772864803,
           0.9227565450328487,
           0.9289331333832754,
           0.9351617550017004,
           0.9414354114436008,
           0.9477471995551772,
           0.9540903171270688,
           0.960458067850591,
           0.966843865624428,
           0.9732412382591455,
           0.9796438306258972,
           0.9860454072943432,
           0.9924398547031801,
           0.9988211829048291,
           1.005183526923836,
           1.0115211477664259,
           1.0178284331164726,
           1.0240998977509557,
           1.0303301837057597,
           1.0365140602205112,
           1.0426464234890225,
           1.0487222962398497,
           1.0547368271695003,
           1.0606852902489363,
           1.0665630839222104,
           1.0723657302144003,
           1.0780888737643852,
           1.0837282807965383,
           1.0892798380440034,
           1.0947395516349396,
           1.1001035459519208,
           1.1053680624735727,
           1.11052945860652,
           1.1155842065147927,
           1.12052889195298,
           1.1253602131086642,
           1.1300749794589553,
           1.13467011064532,
           1.1391426353703196,
           1.1434896903193634,
           1.1477085191101173,
           1.1517964712717967,
           1.1557510012562022,
           1.1595696674820368,
           1.1632501314137464,
           1.1667901566758774,
           1.1701876082037195,
           1.1734404514308152,
           1.1765467515137369,
           1.1795046725944067,
           1.1823124771000952,
           1.1849685250811446,
           1.1874712735863715,
           1.1898192760760349,
           1.1920111818722061,
           1.194045735646318,
           1.1959217769436714,
           1.1976382397446128,
           1.1991941520621294,
           1.2005886355755688,
           1.2018209053002151,
           1.2028902692924517,
           1.203796128390261,
           1.2045379759888295,
           1.2051153978510447,
           1.2055280719527093,
           1.2057757683623096
          ],
          [
           1.187342086171733,
           1.1872657614138327,
           1.1870368315505901,
           1.186655429827572,
           1.1861217783680427,
           1.1854361882439555,
           1.1845990595753704,
           1.1836108816583129,
           1.1824722331211077,
           1.181183782109215,
           1.1797462864985881,
           1.1781605941375803,
           1.1764276431174043,
           1.1745484620711424,
           1.172524170501276,
           1.1703559791356841,
           1.1680451903120175,
           1.1655931983903163,
           1.1630014901936838,
           1.1602716454767672,
           1.1574053374217184,
           1.1544043331612266,
           1.1512704943281031,
           1.1480057776307906,
           1.144612235454032,
           1.1410920164837761,
           1.1374473663552347,
           1.1336806283228,
           1.1297942439503208,
           1.1257907538199818,
           1.121672798257766,
           1.1174431180731677,
           1.1131045553104926,
           1.1086600540087022,
           1.104112660966355,
           1.0994655265077418,
           1.0947219052458175,
           1.0898851568369914,
           1.0849587467222488,
           1.0799462468484289,
           1.0748513363628018,
           1.0696778022733213,
           1.0644295400661277,
           1.0591105542710018,
           1.0537249589645457,
           1.04827697819986,
           1.042770946350442,
           1.0372113083549022,
           1.0316026198479296,
           1.0259495471616817,
           1.0202568671805117,
           1.0145294670305816,
           1.0087723435845612,
           1.0029906027601836,
           0.9971894585900213,
           0.9913742320384125,
           0.9855503495400517,
           0.9797233412333887,
           0.9738988388606488,
           0.9680825733050671,
           0.9622803717348002,
           0.9564981543220286,
           0.9507419305049825,
           0.9450177947600963,
           0.9393319218512456,
           0.933690561523097,
           0.928100032606078,
           0.9225667165013832,
           0.9170970500158477,
           0.9116975175184912,
           0.9063746423931253,
           0.9011349777646757,
           0.8959850964808435,
           0.8909315803354779,
           0.8859810085255612,
           0.8811399453400636,
           0.876414927086103,
           0.8718124482658374,
           0.8673389470262901,
           0.8630007899138189,
           0.8588042559750937,
           0.8547555202571485,
           0.8508606367701975,
           0.8471255209882546,
           0.8435559319740358,
           0.8401574542258815,
           0.8369354793553119,
           0.8338951877140472,
           0.8310415300986262,
           0.8283792096688454,
           0.8259126642228801,
           0.8236460489768306,
           0.8215832199993638,
           0.8197277184528613,
           0.8180827557908702,
           0.8166512000575896,
           0.8154355634285241,
           0.8144379911223356,
           0.8136602518023683,
           0.8131037295724874,
           0.8127694176559459,
           0.8126579138282671,
           0.812769417655946,
           0.813103729572488,
           0.813660251802369,
           0.8144379911223366,
           0.8154355634285253,
           0.8166512000575907,
           0.8180827557908718,
           0.8197277184528631,
           0.821583219999366,
           0.8236460489768328,
           0.8259126642228826,
           0.8283792096688479,
           0.831041530098629,
           0.8338951877140504,
           0.8369354793553151,
           0.840157454225885,
           0.8435559319740394,
           0.8471255209882582,
           0.8508606367702015,
           0.8547555202571527,
           0.8588042559750978,
           0.8630007899138235,
           0.8673389470262945,
           0.8718124482658421,
           0.8764149270861078,
           0.8811399453400685,
           0.8859810085255663,
           0.890931580335483,
           0.8959850964808486,
           0.9011349777646811,
           0.9063746423931307,
           0.9116975175184965,
           0.9170970500158533,
           0.9225667165013888,
           0.9281000326060839,
           0.9336905615231028,
           0.9393319218512516,
           0.9450177947601021,
           0.9507419305049882,
           0.9564981543220346,
           0.9622803717348062,
           0.9680825733050729,
           0.9738988388606546,
           0.9797233412333947,
           0.9855503495400576,
           0.9913742320384182,
           0.9971894585900271,
           1.0029906027601894,
           1.0087723435845672,
           1.0145294670305876,
           1.0202568671805174,
           1.0259495471616875,
           1.031602619847935,
           1.0372113083549082,
           1.0427709463504475,
           1.0482769781998655,
           1.0537249589645512,
           1.059110554271007,
           1.064429540066133,
           1.0696778022733269,
           1.0748513363628072,
           1.0799462468484342,
           1.084958746722254,
           1.0898851568369967,
           1.0947219052458224,
           1.0994655265077464,
           1.1041126609663596,
           1.1086600540087068,
           1.1131045553104972,
           1.117443118073172,
           1.12167279825777,
           1.1257907538199858,
           1.1297942439503248,
           1.1336806283228038,
           1.1374473663552385,
           1.14109201648378,
           1.1446122354540358,
           1.1480057776307941,
           1.1512704943281062,
           1.1544043331612297,
           1.1574053374217212,
           1.16027164547677,
           1.1630014901936865,
           1.165593198390319,
           1.16804519031202,
           1.1703559791356861,
           1.172524170501278,
           1.1745484620711446,
           1.1764276431174063,
           1.1781605941375821,
           1.1797462864985897,
           1.1811837821092164,
           1.182472233121109,
           1.1836108816583137,
           1.1845990595753715,
           1.1854361882439566,
           1.186121778368043,
           1.1866554298275727,
           1.1870368315505908,
           1.1872657614138333
          ],
          [
           1.1696120172351863,
           1.1695418685059997,
           1.1693314649475264,
           1.1689809344580584,
           1.1684904902381796,
           1.167860430845886,
           1.1670911402736894,
           1.1661830880476551,
           1.1651368293482731,
           1.163953005153077,
           1.1626323424008633,
           1.1611756541773535,
           1.1595838399221021,
           1.1578578856564137,
           1.1559988642319778,
           1.1540079355999004,
           1.1518863470997267,
           1.1496354337679935,
           1.1472566186657802,
           1.1447514132246255,
           1.142121417610091,
           1.1393683211021393,
           1.1364939024913738,
           1.1335000304900484,
           1.1303886641566068,
           1.1271618533323406,
           1.123821739088568,
           1.1203705541825366,
           1.1168106235200144,
           1.113144364622299,
           1.1093742880950928,
           1.105502998096398,
           1.1015331928002619,
           1.0974676648528496,
           1.0933093018169335,
           1.0890610866004868,
           1.084726097864606,
           1.08030751040552,
           1.0758085955049135,
           1.07123272124225,
           1.066583352762183,
           1.0618640524895095,
           1.05707848028347,
           1.0522303935224686,
           1.0473236471095693,
           1.0423621933883251,
           1.0373500819576995,
           1.03229145937398,
           1.0271905687267304,
           1.0220517490749084,
           1.0168794347283912,
           1.0116781543592015,
           1.006452529925825,
           1.0012072753930772,
           0.9959471952290999,
           0.9906771826601878,
           0.9854022176633522,
           0.9801273646757769,
           0.9748577699996669,
           0.9695986588804476,
           0.9643553322358565,
           0.9591331630132252,
           0.9539375921521787,
           0.9487741241301422,
           0.9436483220684495,
           0.9385658023775416,
           0.9335322289207484,
           0.9285533066775128,
           0.9236347748886499,
           0.9187823996684059,
           0.9140019660706696,
           0.9092992695997727,
           0.904680107159869,
           0.9001502674409481,
           0.8957155207441087,
           0.8913816082537942,
           0.8871542307702633,
           0.8830390369215941,
           0.8790416108809833,
           0.87516745962193,
           0.8714219997510204,
           0.8678105439653814,
           0.8643382871893377,
           0.8610102924522657,
           0.8578314765769868,
           0.8548065957551004,
           0.8519402310923175,
           0.8492367742129127,
           0.8467004130177542,
           0.844335117694798,
           0.8421446270843101,
           0.8401324355032713,
           0.8383017801342769,
           0.8366556290836928,
           0.8351966702117604,
           0.8339273008337333,
           0.8328496183859603,
           0.8319654121441085,
           0.8312761560725427,
           0.8307830028743062,
           0.8304867793003529,
           0.8303879827648137,
           0.830486779300353,
           0.8307830028743066,
           0.8312761560725433,
           0.8319654121441092,
           0.8328496183859613,
           0.8339273008337345,
           0.8351966702117617,
           0.8366556290836945,
           0.8383017801342787,
           0.8401324355032733,
           0.8421446270843124,
           0.8443351176948002,
           0.8467004130177567,
           0.8492367742129153,
           0.8519402310923204,
           0.8548065957551035,
           0.85783147657699,
           0.861010292452269,
           0.8643382871893411,
           0.867810543965385,
           0.8714219997510241,
           0.875167459621934,
           0.8790416108809872,
           0.8830390369215982,
           0.8871542307702677,
           0.8913816082537986,
           0.8957155207441132,
           0.9001502674409527,
           0.9046801071598737,
           0.9092992695997774,
           0.9140019660706744,
           0.9187823996684109,
           0.9236347748886549,
           0.9285533066775177,
           0.9335322289207535,
           0.9385658023775467,
           0.943648322068455,
           0.9487741241301476,
           0.9539375921521841,
           0.9591331630132306,
           0.964355332235862,
           0.9695986588804529,
           0.9748577699996723,
           0.9801273646757823,
           0.9854022176633577,
           0.9906771826601932,
           0.9959471952291055,
           1.0012072753930825,
           1.0064525299258302,
           1.0116781543592068,
           1.0168794347283965,
           1.0220517490749137,
           1.0271905687267355,
           1.0322914593739854,
           1.0373500819577046,
           1.0423621933883305,
           1.0473236471095744,
           1.0522303935224737,
           1.0570784802834747,
           1.0618640524895144,
           1.066583352762188,
           1.071232721242255,
           1.0758085955049181,
           1.0803075104055246,
           1.0847260978646105,
           1.089061086600491,
           1.093309301816938,
           1.0974676648528539,
           1.1015331928002663,
           1.105502998096402,
           1.1093742880950965,
           1.1131443646223027,
           1.1168106235200181,
           1.1203705541825402,
           1.1238217390885716,
           1.127161853332344,
           1.13038866415661,
           1.1335000304900515,
           1.1364939024913767,
           1.1393683211021421,
           1.1421214176100938,
           1.1447514132246281,
           1.1472566186657827,
           1.1496354337679957,
           1.1518863470997287,
           1.1540079355999027,
           1.1559988642319794,
           1.1578578856564157,
           1.159583839922104,
           1.1611756541773548,
           1.1626323424008647,
           1.1639530051530784,
           1.1651368293482744,
           1.166183088047656,
           1.1670911402736905,
           1.1678604308458864,
           1.16849049023818,
           1.1689809344580586,
           1.1693314649475268,
           1.169541868506
          ],
          [
           1.152685295042207,
           1.1526212197615529,
           1.1524290345447585,
           1.152108861275091,
           1.1516609031171832,
           1.1510854445557532,
           1.1503828514496828,
           1.149553571101327,
           1.1485981323408772,
           1.1475171456255748,
           1.1463113031535075,
           1.1449813789916814,
           1.1435282292180138,
           1.1419527920768135,
           1.1402560881472807,
           1.1384392205244587,
           1.1365033750120235,
           1.1344498203261837,
           1.1322799083099033,
           1.1299950741565283,
           1.1275968366418145,
           1.125086798363219,
           1.1224666459851875,
           1.119738150489036,
           1.116903167425851,
           1.1139636371706843,
           1.110921585176115,
           1.1077791222230577,
           1.10453844466648,
           1.1012018346734591,
           1.097771660450739,
           1.0942503764587055,
           1.0906405236083696,
           1.0869447294376648,
           1.0831657082630073,
           1.079306261301725,
           1.0753692767605694,
           1.0713577298851278,
           1.0672746829645212,
           1.0631232852853236,
           1.0589067730281685,
           1.054628469100006,
           1.0502917828944627,
           1.0459002099722117,
           1.0414573316527174,
           1.0369668145081314,
           1.032432409749547,
           1.0278579524952198,
           1.023247360909763,
           1.018604635202735,
           1.0139338564744362,
           1.0092391853961695,
           1.0045248607116453,
           0.9997951975457033,
           0.9950545855060322,
           0.9903074865631332,
           0.9855584326934174,
           0.9808120232700293,
           0.9760729221858017,
           0.971345854692662,
           0.9666356039418494,
           0.961947007209502,
           0.9572849517925096,
           0.9526543705600828,
           0.9480602371472143,
           0.9435075607771765,
           0.9390013807014023,
           0.934546760246562,
           0.9301487804603783,
           0.9258125333497643,
           0.9215431147071901,
           0.9173456165238243,
           0.9132251189909615,
           0.9091866820944974,
           0.9052353368107986,
           0.9013760759161714,
           0.8976138444262701,
           0.8939535296861634,
           0.8903999511363653,
           0.8869578497848767,
           0.8836318774201452,
           0.8804265856047407,
           0.8773464144944294,
           0.8743956815320888,
           0.8715785700705009,
           0.868899117982364,
           0.8663612063198076,
           0.8639685480891713,
           0.8617246772097336,
           0.8596329377273557,
           0.8576964733555557,
           0.8559182174172705,
           0.854300883260449,
           0.8528469552195747,
           0.8515586801932308,
           0.8504380599048632,
           0.8494868439099782,
           0.8487065234081599,
           0.8480983259125467,
           0.8476632108228402,
           0.8474018659406182,
           0.847314704957793,
           0.8474018659406183,
           0.8476632108228405,
           0.8480983259125471,
           0.8487065234081606,
           0.8494868439099791,
           0.8504380599048643,
           0.851558680193232,
           0.8528469552195762,
           0.8543008832604506,
           0.8559182174172723,
           0.8576964733555577,
           0.8596329377273577,
           0.8617246772097358,
           0.8639685480891738,
           0.8663612063198103,
           0.8688991179823667,
           0.8715785700705037,
           0.8743956815320917,
           0.8773464144944326,
           0.8804265856047441,
           0.8836318774201485,
           0.8869578497848801,
           0.8903999511363688,
           0.8939535296861671,
           0.8976138444262738,
           0.9013760759161754,
           0.9052353368108025,
           0.9091866820945014,
           0.9132251189909657,
           0.9173456165238286,
           0.9215431147071944,
           0.9258125333497689,
           0.9301487804603826,
           0.9345467602465665,
           0.939001380701407,
           0.943507560777181,
           0.9480602371472191,
           0.9526543705600877,
           0.9572849517925144,
           0.9619470072095069,
           0.9666356039418544,
           0.9713458546926668,
           0.9760729221858064,
           0.9808120232700341,
           0.9855584326934224,
           0.990307486563138,
           0.9950545855060371,
           0.9997951975457082,
           1.00452486071165,
           1.0092391853961744,
           1.0139338564744411,
           1.0186046352027396,
           1.0232473609097679,
           1.0278579524952243,
           1.0324324097495516,
           1.036966814508136,
           1.041457331652722,
           1.0459002099722163,
           1.0502917828944671,
           1.0546284691000105,
           1.0589067730281727,
           1.063123285285328,
           1.0672746829645254,
           1.071357729885132,
           1.0753692767605734,
           1.0793062613017288,
           1.0831657082630113,
           1.0869447294376686,
           1.0906405236083734,
           1.094250376458709,
           1.0977716604507424,
           1.1012018346734622,
           1.1045384446664837,
           1.1077791222230609,
           1.1109215851761183,
           1.1139636371706876,
           1.1169031674258536,
           1.1197381504890387,
           1.1224666459851904,
           1.1250867983632213,
           1.127596836641817,
           1.1299950741565306,
           1.1322799083099055,
           1.1344498203261857,
           1.1365033750120253,
           1.1384392205244604,
           1.1402560881472823,
           1.1419527920768153,
           1.1435282292180151,
           1.144981378991683,
           1.1463113031535084,
           1.1475171456255762,
           1.1485981323408783,
           1.1495535711013276,
           1.1503828514496837,
           1.1510854445557537,
           1.1516609031171832,
           1.1521088612750914,
           1.152429034544759,
           1.152621219761553
          ],
          [
           1.1365782951033216,
           1.1365201670978964,
           1.1363458214860913,
           1.1360553734858239,
           1.1356490151419425,
           1.1351270153486195,
           1.1344897198805204,
           1.1337375514325725,
           1.1328710096680918,
           1.1318906712749857,
           1.1307971900296714,
           1.1295912968683048,
           1.1282737999648353,
           1.1268455848153431,
           1.125307614328032,
           1.1236609289181787,
           1.1219066466072514,
           1.1200459631253126,
           1.1180801520157417,
           1.116010564741183,
           1.1138386307895316,
           1.111565857778637,
           1.1091938315582803,
           1.1067242163078344,
           1.10415875462787,
           1.1014992676238125,
           1.0987476549795718,
           1.0959058950188962,
           1.0929760447519963,
           1.0899602399047765,
           1.0868606949277964,
           1.0836797029818355,
           1.0804196358967,
           1.0770829440996383,
           1.0736721565094467,
           1.0701898803920777,
           1.0666388011732306,
           1.0630216822031044,
           1.0593413644681517,
           1.055600766244326,
           1.0518028826859698,
           1.0479507853441081,
           1.0440476216075565,
           1.0400966140598507,
           1.0361010597446434,
           1.0320643293318073,
           1.0279898661761087,
           1.0238811852599385,
           1.0197418720112097,
           1.0155755809871865,
           1.011386034414667,
           1.0071770205766362,
           1.0029523920352323,
           0.9987160636806284,
           0.9944720105952499,
           0.9902242657226097,
           0.9859769173299863,
           0.9817341062541745,
           0.9775000229196364,
           0.973278904118578,
           0.9690750295427709,
           0.9648927180573703,
           0.9607363237075236,
           0.9566102314492618,
           0.9525188525970167,
           0.9484666199811091,
           0.9444579828097418,
           0.9404974012313965,
           0.9365893405950719,
           0.932738265407557,
           0.9289486329888524,
           0.9252248868289936,
           0.9215714496518315,
           0.9179927161938372,
           0.9144930457086531,
           0.9110767542109439,
           0.9077481064760541,
           0.904511307815048,
           0.9013704956478593,
           0.8983297309004743,
           0.8953929892552769,
           0.8925641522868588,
           0.8898469985186909,
           0.8872451944390082,
           0.8847622855170473,
           0.8824016872633065,
           0.8801666763797602,
           0.8780603820478473,
           0.8760857774035747,
           0.8742456712501177,
           0.8725427000588796,
           0.8709793203099931,
           0.8695578012227372,
           0.8682802179252139,
           0.8671484451109477,
           0.8661641512277435,
           0.8653287932412711,
           0.8646436120123688,
           0.864109628323076,
           0.8637276395819227,
           0.8634982172340773,
           0.8634217048966784,
           0.8634982172340775,
           0.8637276395819231,
           0.8641096283230767,
           0.8646436120123693,
           0.865328793241272,
           0.8661641512277444,
           0.8671484451109487,
           0.8682802179252153,
           0.8695578012227385,
           0.8709793203099949,
           0.8725427000588813,
           0.8742456712501195,
           0.8760857774035766,
           0.8780603820478494,
           0.8801666763797623,
           0.8824016872633088,
           0.8847622855170497,
           0.8872451944390107,
           0.8898469985186936,
           0.8925641522868617,
           0.8953929892552799,
           0.8983297309004773,
           0.9013704956478624,
           0.9045113078150512,
           0.9077481064760575,
           0.9110767542109474,
           0.9144930457086565,
           0.9179927161938409,
           0.9215714496518352,
           0.9252248868289974,
           0.9289486329888563,
           0.9327382654075609,
           0.9365893405950759,
           0.9404974012314005,
           0.944457982809746,
           0.9484666199811131,
           0.9525188525970211,
           0.956610231449266,
           0.9607363237075278,
           0.9648927180573748,
           0.9690750295427754,
           0.9732789041185823,
           0.9775000229196409,
           0.9817341062541787,
           0.9859769173299906,
           0.9902242657226141,
           0.9944720105952544,
           0.9987160636806328,
           1.0029523920352366,
           1.0071770205766406,
           1.0113860344146712,
           1.015575580987191,
           1.019741872011214,
           1.023881185259943,
           1.027989866176113,
           1.0320643293318115,
           1.0361010597446474,
           1.0400966140598547,
           1.0440476216075605,
           1.0479507853441121,
           1.0518028826859736,
           1.0556007662443299,
           1.0593413644681555,
           1.0630216822031084,
           1.0666388011732344,
           1.0701898803920813,
           1.0736721565094502,
           1.077082944099642,
           1.0804196358967038,
           1.0836797029818384,
           1.0868606949277995,
           1.0899602399047799,
           1.0929760447519994,
           1.0959058950188991,
           1.0987476549795747,
           1.1014992676238153,
           1.1041587546278728,
           1.1067242163078366,
           1.1091938315582828,
           1.1115658577786391,
           1.1138386307895338,
           1.1160105647411853,
           1.118080152015744,
           1.1200459631253143,
           1.121906646607253,
           1.1236609289181807,
           1.1253076143280334,
           1.1268455848153447,
           1.1282737999648367,
           1.129591296868306,
           1.1307971900296727,
           1.1318906712749868,
           1.1328710096680927,
           1.1337375514325734,
           1.1344897198805215,
           1.13512701534862,
           1.1356490151419427,
           1.136055373485824,
           1.1363458214860918,
           1.1365201670978964
          ],
          [
           1.1213065999007172,
           1.1212542685225173,
           1.1210973103668491,
           1.1208358333718849,
           1.12047001743915,
           1.1200001144402691,
           1.1194264482262122,
           1.118749414638809,
           1.117969481524273,
           1.11708718874839,
           1.1161031482129666,
           1.1150180438730641,
           1.113832631754471,
           1.112547739970796,
           1.1111642687394747,
           1.1096831903959166,
           1.1081055494049104,
           1.106432462368337,
           1.104665118028123,
           1.1028047772632732,
           1.1008527730797166,
           1.0988105105915722,
           1.0966794669923325,
           1.0944611915143303,
           1.0921573053747056,
           1.089769501705975,
           1.08729954546912,
           1.0847492733469801,
           1.0821205936155502,
           1.0794154859906215,
           1.076636001447003,
           1.0737842620073899,
           1.0708624604977224,
           1.0678728602656904,
           1.0648177948588076,
           1.0616996676582633,
           1.0585209514645275,
           1.055284188030452,
           1.0519919875373596,
           1.0486470280093816,
           1.0452520546610449,
           1.0418098791728645,
           1.0383233788894517,
           1.0347954959343952,
           1.0312292362359383,
           1.0276276684572365,
           1.0239939228247585,
           1.0203311898481853,
           1.0166427189249636,
           1.0129318168225099,
           1.0092018460309005,
           1.0054562229787851,
           1.0016984161051625,
           0.997931943779634,
           0.9941603720637469,
           0.9903873123061017,
           0.9866164185640159,
           0.9828513848447206,
           0.9790959421593117,
           0.9753538553830264,
           0.9716289199158098,
           0.9679249581376678,
           0.9642458156538887,
           0.9605953573259335,
           0.9569774630846076,
           0.9533960235230549,
           0.9498549352681573,
           0.9463580961300899,
           0.9429094000310502,
           0.9395127317155985,
           0.9361719612465368,
           0.932890938291905,
           0.9296734862103859,
           0.926523395944253,
           0.9234444197309013,
           0.9204402646459937,
           0.9175145859932983,
           0.9146709805583672,
           0.911912979745313,
           0.9092440426180178,
           0.9066675488691718,
           0.9041867917425253,
           0.901804970935648,
           0.8995251855122547,
           0.8973504268547945,
           0.8952835716894314,
           0.8933273752167701,
           0.8914844643826453,
           0.8897573313240067,
           0.8881483270253078,
           0.8866596552208914,
           0.8852933665785873,
           0.8840513531991021,
           0.8829353434647937,
           0.8819468972700494,
           0.8810874016637577,
           0.8803580669322734,
           0.8797599231488423,
           0.8792938172127093,
           0.8789604103980804,
           0.8787601764298264,
           0.8786934000992829,
           0.8787601764298265,
           0.8789604103980807,
           0.8792938172127095,
           0.8797599231488428,
           0.880358066932274,
           0.8810874016637585,
           0.8819468972700503,
           0.8829353434647947,
           0.8840513531991033,
           0.8852933665785887,
           0.8866596552208929,
           0.8881483270253091,
           0.8897573313240085,
           0.8914844643826473,
           0.893327375216772,
           0.8952835716894338,
           0.8973504268547966,
           0.899525185512257,
           0.9018049709356505,
           0.9041867917425278,
           0.9066675488691742,
           0.9092440426180205,
           0.9119129797453158,
           0.9146709805583702,
           0.917514585993301,
           0.9204402646459969,
           0.9234444197309044,
           0.9265233959442561,
           0.9296734862103891,
           0.9328909382919083,
           0.9361719612465402,
           0.9395127317156019,
           0.9429094000310538,
           0.9463580961300934,
           0.9498549352681611,
           0.9533960235230583,
           0.9569774630846114,
           0.9605953573259371,
           0.9642458156538923,
           0.9679249581376715,
           0.9716289199158136,
           0.9753538553830303,
           0.9790959421593158,
           0.9828513848447245,
           0.9866164185640198,
           0.9903873123061054,
           0.9941603720637509,
           0.9979319437796378,
           1.0016984161051663,
           1.005456222978789,
           1.009201846030904,
           1.0129318168225134,
           1.0166427189249674,
           1.020331189848189,
           1.0239939228247625,
           1.02762766845724,
           1.0312292362359419,
           1.0347954959343988,
           1.0383233788894553,
           1.041809879172868,
           1.0452520546610484,
           1.0486470280093851,
           1.051991987537363,
           1.0552841880304553,
           1.0585209514645308,
           1.0616996676582662,
           1.0648177948588107,
           1.0678728602656935,
           1.0708624604977255,
           1.0737842620073927,
           1.076636001447006,
           1.0794154859906244,
           1.0821205936155531,
           1.0847492733469828,
           1.0872995454691228,
           1.0897695017059774,
           1.092157305374708,
           1.0944611915143323,
           1.0966794669923348,
           1.0988105105915742,
           1.1008527730797188,
           1.1028047772632752,
           1.1046651180281246,
           1.1064324623683386,
           1.1081055494049117,
           1.1096831903959177,
           1.1111642687394763,
           1.1125477399707975,
           1.1138326317544722,
           1.1150180438730652,
           1.1161031482129677,
           1.1170871887483909,
           1.1179694815242738,
           1.1187494146388095,
           1.119426448226213,
           1.1200001144402696,
           1.1204700174391498,
           1.1208358333718853,
           1.1210973103668493,
           1.1212542685225177
          ],
          [
           1.106884983813195,
           1.1068382732234892,
           1.1066981748213962,
           1.1064647887065002,
           1.1061382817064451,
           1.1057188873693231,
           1.1052069059528036,
           1.1046027044097704,
           1.103906716370178,
           1.1031194421187789,
           1.1022414485682877,
           1.101273369227494,
           1.1002159041637547,
           1.0990698199592248,
           1.0978359496601047,
           1.0965151927181127,
           1.0951085149232884,
           1.0936169483271687,
           1.0920415911552703,
           1.090383607707728,
           1.0886442282468325,
           1.086824748870119,
           1.0849265313675438,
           1.0829510030611702,
           1.0808996566256888,
           1.0787740498879472,
           1.076575805603572,
           1.0743066112086044,
           1.0719682185439634,
           1.0695624435503936,
           1.0670911659314177,
           1.0645563287816688,
           1.0619599381778242,
           1.0593040627292047,
           1.0565908330849563,
           1.0538224413945583,
           1.0510011407182551,
           1.0481292443838404,
           1.0452091252860567,
           1.0422432151247292,
           1.0392340035775813,
           1.0361840374035367,
           1.0330959194721587,
           1.0299723077147516,
           1.0268159139925046,
           1.023629502876956,
           1.0204158903379408,
           1.0171779423341105,
           1.0139185733010365,
           1.0106407445318766,
           1.0073474624455507,
           1.0040417767374026,
           1.0007267784073457,
           0.9974055976605911,
           0.9940814016761582,
           0.990757392238543,
           0.9874368032281186,
           0.9841228979661167,
           0.9808189664103362,
           0.9775283221981171,
           0.9742542995335444,
           0.9710002499163437,
           0.9677695387105126,
           0.9645655415513491,
           0.9613916405902698,
           0.9582512205775776,
           0.9551476647841964,
           0.9520843507643263,
           0.9490646459619554,
           0.946091903165249,
           0.9431694558139522,
           0.9403006131661402,
           0.9374886553318938,
           0.9347368281827634,
           0.93204833814721,
           0.9294263469035678,
           0.9268739659834275,
           0.9243942512997146,
           0.9219901976150814,
           0.9196647329675538,
           0.91742071307165,
           0.9152609157143936,
           0.9131880351667838,
           0.9112046766322905,
           0.9093133507548777,
           0.9075164682098074,
           0.9058163344011038,
           0.9042151442900015,
           0.9027149773789563,
           0.9013177928758668,
           0.9000254250629903,
           0.8988395788946855,
           0.8977618258475053,
           0.8967936000453527,
           0.8959361946813591,
           0.8951907587568826,
           0.8945582941565293,
           0.8940396530764207,
           0.8936355358210488,
           0.8933464889820101,
           0.8931729040097101,
           0.893115016186805,
           0.8931729040097101,
           0.8933464889820103,
           0.8936355358210494,
           0.8940396530764212,
           0.89455829415653,
           0.8951907587568834,
           0.89593619468136,
           0.8967936000453536,
           0.8977618258475065,
           0.8988395788946865,
           0.9000254250629915,
           0.9013177928758681,
           0.9027149773789579,
           0.9042151442900029,
           0.9058163344011056,
           0.9075164682098094,
           0.9093133507548796,
           0.9112046766322925,
           0.9131880351667859,
           0.915260915714396,
           0.9174207130716521,
           0.9196647329675562,
           0.9219901976150839,
           0.9243942512997172,
           0.92687396598343,
           0.9294263469035705,
           0.9320483381472129,
           0.9347368281827662,
           0.9374886553318966,
           0.940300613166143,
           0.9431694558139552,
           0.9460919031652522,
           0.9490646459619584,
           0.9520843507643293,
           0.9551476647841998,
           0.9582512205775806,
           0.9613916405902732,
           0.9645655415513523,
           0.967769538710516,
           0.9710002499163471,
           0.9742542995335477,
           0.9775283221981205,
           0.9808189664103395,
           0.9841228979661204,
           0.9874368032281221,
           0.9907573922385463,
           0.9940814016761618,
           0.9974055976605944,
           1.000726778407349,
           1.004041776737406,
           1.007347462445554,
           1.0106407445318797,
           1.0139185733010398,
           1.0171779423341138,
           1.0204158903379443,
           1.0236295028769593,
           1.026815913992508,
           1.0299723077147547,
           1.0330959194721616,
           1.0361840374035396,
           1.0392340035775847,
           1.042243215124732,
           1.0452091252860596,
           1.0481292443838435,
           1.0510011407182582,
           1.0538224413945612,
           1.0565908330849592,
           1.0593040627292076,
           1.061959938177827,
           1.0645563287816715,
           1.0670911659314202,
           1.069562443550396,
           1.0719682185439658,
           1.0743066112086066,
           1.0765758056035746,
           1.0787740498879497,
           1.080899656625691,
           1.0829510030611724,
           1.0849265313675456,
           1.086824748870121,
           1.0886442282468343,
           1.0903836077077298,
           1.092041591155272,
           1.09361694832717,
           1.0951085149232898,
           1.096515192718114,
           1.097835949660106,
           1.099069819959226,
           1.1002159041637558,
           1.1012733692274952,
           1.1022414485682885,
           1.1031194421187798,
           1.103906716370179,
           1.1046027044097715,
           1.1052069059528045,
           1.1057188873693233,
           1.1061382817064456,
           1.1064647887065002,
           1.106698174821396,
           1.1068382732234892
          ],
          [
           1.0933273988229149,
           1.0932861074695746,
           1.0931622640035132,
           1.0929559602026107,
           1.0926673490166492,
           1.0922966445471753,
           1.09184412201909,
           1.0913101177437514,
           1.0906950290732993,
           1.089999314345868,
           1.0892234928212625,
           1.0883681446066311,
           1.087433910571583,
           1.0864214922521365,
           1.08533165174281,
           1.0841652115760996,
           1.082923054588509,
           1.0816061237722148,
           1.0802154221113867,
           1.0787520124020826,
           1.0772170170545696,
           1.075611617876826,
           1.0739370558378987,
           1.0721946308096926,
           1.070385701285683,
           1.0685116840749411,
           1.0665740539697652,
           1.064574343385117,
           1.0625141419679536,
           1.0603950961744513,
           1.058218908813002,
           1.0559873385507705,
           1.0537021993814908,
           1.051365360052069,
           1.0489787434454647,
           1.0465443259172171,
           1.0440641365828736,
           1.0415402565534908,
           1.03897481811628,
           1.0363700038573687,
           1.0337280457235865,
           1.0310512240200855,
           1.0283418663405504,
           1.0256023464266875,
           1.022835082953643,
           1.0200425382379505,
           1.0172272168646084,
           1.0143916642298667,
           1.0115384649963288,
           1.0086702414570066,
           1.0057896518050229,
           1.0028993883057418,
           1.0000021753682158,
           0.9971007675129784,
           0.9941979472333772,
           0.9912965227478518,
           0.9883993256407952,
           0.9855092083899135,
           0.9826290417783168,
           0.9797617121899255,
           0.9769101187871807,
           0.9740771705704813,
           0.9712657833192611,
           0.9684788764151457,
           0.965719369548208,
           0.9629901793079507,
           0.9602942156613137,
           0.9576343783207003,
           0.9550135530057592,
           0.9524346076034351,
           0.9499003882316086,
           0.9474137152124831,
           0.9449773789627328,
           0.9425941358083041,
           0.9402667037326419,
           0.9379977580680035,
           0.9357899271403992,
           0.9336457878795671,
           0.9315678614062253,
           0.92955860860966,
           0.927620425729456,
           0.9257556399558987,
           0.923966505064203,
           0.922255197098298,
           0.9206238101203695,
           0.9190743520427468,
           0.9176087405589884,
           0.9162287991911877,
           0.9149362534705587,
           0.9137327272682618,
           0.9126197392932182,
           0.911598699773289,
           0.9106709073357069,
           0.9098375461019931,
           0.9090996830118365,
           0.9084582653894809,
           0.907914118765142,
           0.9074679449628127,
           0.907120320464541,
           0.9068716950598998,
           0.9067223907879016,
           0.9066726011770851,
           0.9067223907879016,
           0.9068716950599001,
           0.9071203204645413,
           0.907467944962813,
           0.9079141187651426,
           0.9084582653894816,
           0.9090996830118373,
           0.9098375461019939,
           0.9106709073357077,
           0.91159869977329,
           0.9126197392932193,
           0.913732727268263,
           0.9149362534705601,
           0.9162287991911893,
           0.9176087405589897,
           0.9190743520427486,
           0.9206238101203711,
           0.9222551970982996,
           0.923966505064205,
           0.9257556399559008,
           0.927620425729458,
           0.9295586086096621,
           0.9315678614062274,
           0.9336457878795691,
           0.9357899271404013,
           0.9379977580680058,
           0.9402667037326444,
           0.9425941358083064,
           0.9449773789627353,
           0.9474137152124855,
           0.9499003882316112,
           0.9524346076034376,
           0.9550135530057619,
           0.957634378320703,
           0.9602942156613165,
           0.9629901793079536,
           0.9657193695482108,
           0.9684788764151485,
           0.9712657833192639,
           0.9740771705704844,
           0.9769101187871836,
           0.9797617121899284,
           0.9826290417783198,
           0.9855092083899167,
           0.9883993256407982,
           0.991296522747855,
           0.9941979472333803,
           0.9971007675129815,
           1.0000021753682187,
           1.0028993883057447,
           1.0057896518050258,
           1.0086702414570095,
           1.0115384649963317,
           1.0143916642298696,
           1.0172272168646115,
           1.0200425382379534,
           1.022835082953646,
           1.0256023464266901,
           1.0283418663405528,
           1.0310512240200882,
           1.0337280457235893,
           1.0363700038573713,
           1.0389748181162826,
           1.0415402565534935,
           1.044064136582876,
           1.0465443259172198,
           1.0489787434454672,
           1.0513653600520714,
           1.0537021993814932,
           1.0559873385507728,
           1.058218908813004,
           1.0603950961744537,
           1.0625141419679558,
           1.064574343385119,
           1.0665740539697675,
           1.0685116840749431,
           1.070385701285685,
           1.0721946308096941,
           1.0739370558379004,
           1.0756116178768278,
           1.0772170170545714,
           1.0787520124020842,
           1.080215422111388,
           1.0816061237722159,
           1.08292305458851,
           1.0841652115761007,
           1.0853316517428109,
           1.0864214922521378,
           1.0874339105715838,
           1.0883681446066318,
           1.0892234928212632,
           1.0899993143458686,
           1.0906950290733004,
           1.0913101177437519,
           1.0918441220190909,
           1.0922966445471756,
           1.0926673490166496,
           1.0929559602026109,
           1.0931622640035135,
           1.093286107469575
          ],
          [
           1.0806469610177518,
           1.0806108613328942,
           1.0805025899699563,
           1.0803222299977973,
           1.0800699198443315,
           1.0797458532661495,
           1.079350279305795,
           1.0788835022364907,
           1.0783458814940583,
           1.0777378315957267,
           1.0770598220454426,
           1.0763123772252647,
           1.075496076272341,
           1.0746115529409233,
           1.073659495448804,
           1.0726406463074987,
           1.0715558021354379,
           1.0704058134533663,
           1.0691915844610798,
           1.0679140727945684,
           1.0665742892625658,
           1.0651732975614334,
           1.0637122139672497,
           1.0621922070038894,
           1.0606144970858276,
           1.0589803561343132,
           1.0572911071654998,
           1.05554812384905,
           1.0537528300356467,
           1.051906699251794,
           1.0500112541602034,
           1.0480680659840058,
           1.046078753892958,
           1.044044984349747,
           1.0419684704144376,
           1.0398509710050503,
           1.0376942901121966,
           1.0355002759656584,
           1.0332708201507441,
           1.0310078566722185,
           1.0287133609635768,
           1.026389348839402,
           1.0240378753885333,
           1.021661033805765,
           1.0192609541598094,
           1.0168398020952627,
           1.0143997774663476,
           1.0119431129002627,
           1.0094720722880095,
           1.006988949200661,
           1.0044960652291224,
           1.0019957682455578,
           0.9994904305847775,
           0.996982447144054,
           0.9944742334000017,
           0.9919682233413627,
           0.9894668673167696,
           0.9869726297968092,
           0.9844879870499846,
           0.9820154247324908,
           0.9795574353920362,
           0.9771165158863179,
           0.9746951647171301,
           0.9722958792815095,
           0.9699211530417512,
           0.9675734726165967,
           0.9652553147963754,
           0.9629691434853935,
           0.9607174065753843,
           0.9585025327543749,
           0.9563269282558876,
           0.9541929735539413,
           0.9521030200099101,
           0.9500593864778457,
           0.9480643558754576,
           0.9461201717284898,
           0.9442290346967939,
           0.9423930990909116,
           0.9406144693884962,
           0.9388951967603668,
           0.9372372756164244,
           0.9356426401820562,
           0.934113161115993,
           0.9326506421808768,
           0.9312568169780201,
           0.9299333457580036,
           0.9286818123188523,
           0.9275037210035417,
           0.9264004938085331,
           0.9253734676148846,
           0.9244238915532725,
           0.9235529245139319,
           0.9227616328121462,
           0.9220509880194258,
           0.9214218649699611,
           0.9208750399512947,
           0.9204111890874382,
           0.9200308869218777,
           0.9197346052070584,
           0.919522711906027,
           0.9193954704109533,
           0.9193530389822482,
           0.9193954704109535,
           0.9195227119060272,
           0.9197346052070586,
           0.9200308869218781,
           0.9204111890874386,
           0.9208750399512953,
           0.9214218649699618,
           0.9220509880194264,
           0.922761632812147,
           0.9235529245139328,
           0.9244238915532734,
           0.9253734676148856,
           0.9264004938085342,
           0.927503721003543,
           0.9286818123188536,
           0.9299333457580049,
           0.9312568169780217,
           0.9326506421808783,
           0.9341131611159946,
           0.9356426401820579,
           0.9372372756164262,
           0.9388951967603686,
           0.9406144693884979,
           0.9423930990909134,
           0.9442290346967959,
           0.9461201717284919,
           0.9480643558754596,
           0.9500593864778479,
           0.9521030200099122,
           0.9541929735539435,
           0.9563269282558897,
           0.9585025327543771,
           0.9607174065753865,
           0.9629691434853958,
           0.9652553147963778,
           0.9675734726165992,
           0.9699211530417539,
           0.972295879281512,
           0.9746951647171327,
           0.9771165158863203,
           0.9795574353920388,
           0.9820154247324935,
           0.9844879870499874,
           0.9869726297968119,
           0.9894668673167722,
           0.9919682233413651,
           0.9944742334000044,
           0.9969824471440565,
           0.99949043058478,
           1.0019957682455605,
           1.004496065229125,
           1.0069889492006634,
           1.0094720722880122,
           1.0119431129002652,
           1.0143997774663502,
           1.0168398020952651,
           1.019260954159812,
           1.0216610338057672,
           1.0240378753885353,
           1.0263893488394045,
           1.0287133609635792,
           1.0310078566722207,
           1.0332708201507466,
           1.0355002759656609,
           1.0376942901121986,
           1.0398509710050523,
           1.0419684704144399,
           1.044044984349749,
           1.0460787538929601,
           1.0480680659840078,
           1.0500112541602051,
           1.0519066992517958,
           1.053752830035649,
           1.0555481238490516,
           1.0572911071655016,
           1.0589803561343147,
           1.0606144970858293,
           1.062192207003891,
           1.0637122139672512,
           1.065173297561435,
           1.0665742892625674,
           1.0679140727945697,
           1.0691915844610809,
           1.0704058134533674,
           1.071555802135439,
           1.0726406463074998,
           1.0736594954488048,
           1.0746115529409244,
           1.0754960762723416,
           1.0763123772252652,
           1.0770598220454433,
           1.0777378315957271,
           1.078345881494059,
           1.078883502236491,
           1.0793502793057959,
           1.0797458532661497,
           1.0800699198443315,
           1.0803222299977973,
           1.0805025899699563,
           1.0806108613328942
          ],
          [
           1.0688559379023295,
           1.068824776245451,
           1.0687313159731842,
           1.0685756311730623,
           1.0683578452990394,
           1.0680781311335004,
           1.067736710733912,
           1.0673338553639382,
           1.0668698854088032,
           1.0663451702746467,
           1.0657601282715374,
           1.065115226479803,
           1.0644109805992459,
           1.0636479547807942,
           1.0628267614400728,
           1.0619480610523289,
           1.061012561928111,
           1.0600210199690314,
           1.0589742384029066,
           1.0578730674975123,
           1.0567184042521442,
           1.0555111920661233,
           1.0542524203833348,
           1.0529431243118452,
           1.0515843842175876,
           1.0501773252910587,
           1.048723117085933,
           1.0472229730284375,
           1.0456781498963024,
           1.0440899472660532,
           1.042459706927366,
           1.040788812263177,
           1.0390786875941989,
           1.0373307974864605,
           1.0355466460204628,
           1.033727776020516,
           1.031875768242803,
           1.0299922405207005,
           1.0280788468658721,
           1.026137276523653,
           1.0241692529812427,
           1.0221765329272323,
           1.0201609051610108,
           1.0181241894506206,
           1.0160682353376727,
           1.0139949208879673,
           1.01190615138653,
           1.0098038579758388,
           1.0076899962360946,
           1.0055665447064759,
           1.003435503346439,
           1.001298891936217,
           0.9991587484158337,
           0.9970171271620747,
           0.9948760972030276,
           0.9927377403699922,
           0.9906041493867375,
           0.9884774258963146,
           0.9863596784258436,
           0.9842530202899478,
           0.9821595674337645,
           0.980081436216736,
           0.978020741138672,
           0.9759795925098821,
           0.9739600940674951,
           0.9719643405404037,
           0.9699944151656211,
           0.9680523871591803,
           0.9661403091450645,
           0.964260214546019,
           0.9624141149404567,
           0.9606039973900419,
           0.9588318217428891,
           0.9570995179176841,
           0.9554089831743776,
           0.9537620793774418,
           0.9521606302580123,
           0.9506064186815357,
           0.9491011839278399,
           0.9476466189908017,
           0.946244367905019,
           0.9448960231071031,
           0.9436031228393753,
           0.9423671486038772,
           0.9411895226747015,
           0.9400716056766977,
           0.9390146942386031,
           0.9380200187286113,
           0.9370887410802946,
           0.9362219527166463,
           0.9354206725798273,
           0.934685845273937,
           0.9340183393278491,
           0.933418945584792,
           0.9328883757249687,
           0.9324272609270625,
           0.9320361506739898,
           0.9317155117077385,
           0.9314657271375638,
           0.9312870957052101,
           0.931179831210213,
           0.9311440620976705,
           0.9311798312102131,
           0.9312870957052101,
           0.9314657271375638,
           0.9317155117077388,
           0.93203615067399,
           0.9324272609270631,
           0.9328883757249693,
           0.9334189455847925,
           0.9340183393278498,
           0.9346858452739376,
           0.935420672579828,
           0.936221952716647,
           0.9370887410802955,
           0.9380200187286125,
           0.9390146942386042,
           0.9400716056766989,
           0.9411895226747027,
           0.9423671486038784,
           0.9436031228393768,
           0.9448960231071046,
           0.9462443679050203,
           0.9476466189908033,
           0.9491011839278414,
           0.9506064186815372,
           0.9521606302580139,
           0.9537620793774436,
           0.9554089831743793,
           0.9570995179176858,
           0.9588318217428907,
           0.9606039973900437,
           0.9624141149404585,
           0.9642602145460207,
           0.9661403091450665,
           0.9680523871591822,
           0.969994415165623,
           0.9719643405404057,
           0.9739600940674973,
           0.975979592509884,
           0.9780207411386741,
           0.9800814362167383,
           0.9821595674337666,
           0.9842530202899498,
           0.9863596784258457,
           0.9884774258963169,
           0.9906041493867397,
           0.9927377403699942,
           0.9948760972030298,
           0.9970171271620769,
           0.9991587484158359,
           1.001298891936219,
           1.003435503346441,
           1.005566544706478,
           1.0076899962360968,
           1.009803857975841,
           1.011906151386532,
           1.0139949208879693,
           1.016068235337675,
           1.0181241894506226,
           1.0201609051610125,
           1.0221765329272343,
           1.0241692529812447,
           1.0261372765236547,
           1.0280788468658741,
           1.0299922405207027,
           1.031875768242805,
           1.0337277760205175,
           1.0355466460204645,
           1.0373307974864623,
           1.0390786875942006,
           1.0407888122631785,
           1.0424597069273676,
           1.044089947266055,
           1.0456781498963041,
           1.0472229730284388,
           1.0487231170859346,
           1.0501773252910602,
           1.051584384217589,
           1.0529431243118466,
           1.054252420383336,
           1.0555111920661244,
           1.0567184042521456,
           1.0578730674975134,
           1.0589742384029077,
           1.0600210199690323,
           1.0610125619281119,
           1.0619480610523298,
           1.0628267614400735,
           1.063647954780795,
           1.0644109805992463,
           1.0651152264798034,
           1.065760128271538,
           1.0663451702746471,
           1.066869885408804,
           1.0673338553639384,
           1.0677367107339126,
           1.0680781311335006,
           1.0683578452990394,
           1.0685756311730623,
           1.0687313159731842,
           1.0688247762454512
          ],
          [
           1.0579657365300008,
           1.0579392333990796,
           1.0578597456646475,
           1.057727338293165,
           1.057542119533591,
           1.0573042408746058,
           1.0570138969845915,
           1.0566713256342322,
           1.056276807601569,
           1.0558306665592976,
           1.0553332689440642,
           1.0547850238074747,
           1.0541863826484956,
           1.0535378392268904,
           1.0528399293572916,
           1.0520932306834823,
           1.051298362432414,
           1.0504559851474566,
           1.0495668004003467,
           1.0486315504812502,
           1.0476510180663416,
           1.046626025862246,
           1.045557436226683,
           1.0444461507645963,
           1.0432931098990381,
           1.0420992924160446,
           1.040865714982708,
           1.0395934316376332,
           1.0382835332529323,
           1.0369371469669015,
           1.035555435586495,
           1.0341395969587026,
           1.0326908633099188,
           1.0312105005523833,
           1.0296998075567674,
           1.0281601153899753,
           1.0265927865172328,
           1.024999213967543,
           1.0233808204615937,
           1.0217390575012246,
           1.02007540441958,
           1.0183913673911,
           1.0166884784005394,
           1.0149682941702398,
           1.013232395044935,
           1.0114823838334184,
           1.0097198846064679,
           1.0079465414504927,
           1.0061640171764479,
           1.0043739919836492,
           1.0025781620782208,
           1.0007782382460093,
           0.9989759443799223,
           0.9971730159617648,
           0.9953711984987906,
           0.9935722459153286,
           0.9917779188999895,
           0.9899899832091403,
           0.9882102079274846,
           0.9864403636867891,
           0.9846822208439708,
           0.9829375476199695,
           0.9812081082010273,
           0.9794956608042144,
           0.9778019557092571,
           0.9761287332589451,
           0.9744777218306236,
           0.9728506357815087,
           0.9712491733707846,
           0.9696750146616875,
           0.9681298194069954,
           0.9666152249215787,
           0.9651328439458849,
           0.963684262504445,
           0.9622710377636953,
           0.9608946958936059,
           0.9595567299377921,
           0.958258597696949,
           0.9570017196306115,
           0.955787476782373,
           0.9546172087338102,
           0.9534922115924639,
           0.9524137360192882,
           0.9513829853010348,
           0.9504011134730519,
           0.9494692234979791,
           0.9485883655057777,
           0.9477595351004724,
           0.9469836717388876,
           0.9462616571865363,
           0.9455943140556607,
           0.9449824044302444,
           0.9444266285825914,
           0.9439276237858327,
           0.9434859632264408,
           0.9431021550205354,
           0.9427766413374402,
           0.9425097976336009,
           0.9423019319996043,
           0.9421532846226551,
           0.9420640273664519,
           0.9420342634699993,
           0.9420640273664519,
           0.9421532846226552,
           0.9423019319996047,
           0.942509797633601,
           0.9427766413374404,
           0.9431021550205357,
           0.9434859632264413,
           0.9439276237858333,
           0.9444266285825921,
           0.9449824044302451,
           0.9455943140556614,
           0.9462616571865369,
           0.9469836717388885,
           0.9477595351004732,
           0.9485883655057787,
           0.9494692234979801,
           0.9504011134730529,
           0.9513829853010358,
           0.9524137360192894,
           0.953492211592465,
           0.9546172087338115,
           0.9557874767823742,
           0.9570017196306128,
           0.9582585976969502,
           0.9595567299377934,
           0.9608946958936074,
           0.9622710377636967,
           0.9636842625044466,
           0.9651328439458864,
           0.9666152249215801,
           0.968129819406997,
           0.9696750146616891,
           0.9712491733707863,
           0.9728506357815102,
           0.9744777218306252,
           0.9761287332589466,
           0.9778019557092588,
           0.979495660804216,
           0.9812081082010289,
           0.9829375476199714,
           0.9846822208439726,
           0.986440363686791,
           0.9882102079274866,
           0.9899899832091421,
           0.9917779188999915,
           0.9935722459153303,
           0.9953711984987927,
           0.9971730159617666,
           0.9989759443799242,
           1.000778238246011,
           1.0025781620782224,
           1.004373991983651,
           1.0061640171764497,
           1.0079465414504947,
           1.0097198846064697,
           1.01148238383342,
           1.013232395044937,
           1.0149682941702416,
           1.0166884784005412,
           1.0183913673911018,
           1.0200754044195814,
           1.0217390575012262,
           1.0233808204615953,
           1.0249992139675448,
           1.0265927865172344,
           1.0281601153899766,
           1.0296998075567692,
           1.0312105005523848,
           1.0326908633099203,
           1.0341395969587042,
           1.0355554355864964,
           1.0369371469669029,
           1.0382835332529339,
           1.0395934316376345,
           1.0408657149827096,
           1.042099292416046,
           1.0432931098990395,
           1.0444461507645975,
           1.0455574362266842,
           1.046626025862247,
           1.0476510180663425,
           1.0486315504812513,
           1.0495668004003473,
           1.050455985147457,
           1.0512983624324146,
           1.0520932306834831,
           1.052839929357292,
           1.053537839226891,
           1.054186382648496,
           1.054785023807475,
           1.0553332689440647,
           1.0558306665592982,
           1.0562768076015696,
           1.0566713256342326,
           1.0570138969845921,
           1.057304240874606,
           1.057542119533591,
           1.0577273382931653,
           1.0578597456646477,
           1.0579392333990798
          ],
          [
           1.0479868924672608,
           1.0479647429965895,
           1.047898313205298,
           1.0477876589466204,
           1.047632873279501,
           1.047434086423872,
           1.0471914656979535,
           1.0469052154374712,
           1.0465755768966742,
           1.0462028281310034,
           1.0457872838612332,
           1.0453292953188884,
           1.0448292500727006,
           1.0442875718358637,
           1.0437047202537966,
           1.0430811906721198,
           1.042417513884516,
           1.0417142558601253,
           1.040972017450104,
           1.040191434072952,
           1.0393731753781958,
           1.0385179448879949,
           1.0376264796162167,
           1.0366995496645122,
           1.0357379577949124,
           1.0347425389784386,
           1.0337141599192228,
           1.032653718553614,
           1.0315621435237388,
           1.0304403936249853,
           1.0292894572268614,
           1.028110351666694,
           1.0269041226156208,
           1.0256718434163425,
           1.0244146143921027,
           1.0231335621263746,
           1.0218298387127518,
           1.020504620974548,
           1.0191591096536454,
           1.017794528568142,
           1.016412123738386,
           1.0150131624810246,
           1.0135989324707138,
           1.0121707407692042,
           1.0107299128215457,
           1.0092777914192175,
           1.007815735630048,
           1.0063451196948492,
           1.004867331890765,
           1.0033837733614033,
           1.0018958569139058,
           1.0004050057831968,
           0.9989126523637387,
           0.9974202369092289,
           0.9959292062007655,
           0.9944410121841278,
           0.992957110576924,
           0.9914789594464817,
           0.9900080177594763,
           0.988545743904427,
           0.9870935941883104,
           0.9856530213086913,
           0.9842254728028946,
           0.9828123894758939,
           0.9814152038087252,
           0.9800353383493879,
           0.9786742040883283,
           0.9773331988207538,
           0.9760137054981599,
           0.9747170905716025,
           0.9734447023293692,
           0.9721978692318558,
           0.9709778982465631,
           0.9697860731862656,
           0.9686236530535074,
           0.9674918703946938,
           0.9663919296671417,
           0.9653250056225375,
           0.9642922417103259,
           0.9632947485046233,
           0.9623336021582867,
           0.9614098428878156,
           0.9605244734927807,
           0.9596784579134767,
           0.9588727198304859,
           0.9581081413098175,
           0.9573855614972272,
           0.9567057753652752,
           0.9560695325165863,
           0.9554775360466862,
           0.9549304414696628,
           0.954428855709776,
           0.9539733361619801,
           0.9535643898241598,
           0.9532024725036913,
           0.9528879881007528,
           0.9526212879705753,
           0.9524026703666187,
           0.9522323799664077,
           0.9521106074815152,
           0.9520374893529249,
           0.9520131075327393,
           0.9520374893529249,
           0.9521106074815153,
           0.9522323799664079,
           0.952402670366619,
           0.9526212879705754,
           0.9528879881007533,
           0.9532024725036916,
           0.95356438982416,
           0.9539733361619807,
           0.9544288557097765,
           0.9549304414696632,
           0.9554775360466866,
           0.9560695325165871,
           0.9567057753652759,
           0.9573855614972281,
           0.9581081413098184,
           0.9588727198304868,
           0.9596784579134775,
           0.9605244734927819,
           0.9614098428878165,
           0.9623336021582876,
           0.9632947485046242,
           0.964292241710327,
           0.9653250056225385,
           0.9663919296671429,
           0.967491870394695,
           0.9686236530535085,
           0.9697860731862669,
           0.9709778982465644,
           0.972197869231857,
           0.9734447023293705,
           0.9747170905716038,
           0.9760137054981614,
           0.9773331988207551,
           0.9786742040883298,
           0.9800353383493893,
           0.9814152038087266,
           0.9828123894758952,
           0.984225472802896,
           0.9856530213086927,
           0.987093594188312,
           0.9885457439044286,
           0.9900080177594779,
           0.9914789594464831,
           0.9929571105769256,
           0.9944410121841293,
           0.9959292062007672,
           0.9974202369092302,
           0.9989126523637402,
           1.0004050057831981,
           1.0018958569139074,
           1.0033837733614048,
           1.0048673318907666,
           1.0063451196948507,
           1.0078157356300494,
           1.009277791419219,
           1.010729912821547,
           1.0121707407692055,
           1.0135989324707149,
           1.015013162481026,
           1.0164121237383876,
           1.0177945285681433,
           1.019159109653647,
           1.0205046209745494,
           1.021829838712753,
           1.023133562126376,
           1.024414614392104,
           1.0256718434163439,
           1.0269041226156221,
           1.0281103516666952,
           1.0292894572268627,
           1.0304403936249864,
           1.0315621435237399,
           1.032653718553615,
           1.033714159919224,
           1.0347425389784397,
           1.0357379577949135,
           1.036699549664513,
           1.0376264796162173,
           1.0385179448879958,
           1.0393731753781965,
           1.0401914340729526,
           1.0409720174501047,
           1.0417142558601258,
           1.0424175138845166,
           1.0430811906721205,
           1.0437047202537972,
           1.0442875718358644,
           1.044829250072701,
           1.0453292953188889,
           1.0457872838612337,
           1.0462028281310038,
           1.046575576896675,
           1.0469052154374714,
           1.0471914656979542,
           1.0474340864238723,
           1.0476328732795008,
           1.0477876589466206,
           1.0478983132052981,
           1.04796474299659
          ],
          [
           1.038929059601267,
           1.0389109343601124,
           1.038856574275301,
           1.0387660262540048,
           1.0386393684455555,
           1.038476710197483,
           1.0382781919939086,
           1.0380439853762333,
           1.0377742928460423,
           1.0374693477501367,
           1.0371294141475773,
           1.036754786658618,
           1.036345790295387,
           1.0359027802741576,
           1.0354261418090405,
           1.0349162898869082,
           1.03437366902336,
           1.0337987529995083,
           1.0331920445793714,
           1.0325540752076339,
           1.0318854046875365,
           1.0311866208386369,
           1.0304583391341864,
           1.029701202317857,
           1.0289158799995408,
           1.0281030682299561,
           1.0272634890537722,
           1.026397890040985,
           1.0255070437962561,
           1.0245917474459516,
           1.0236528221025996,
           1.022691112306515,
           1.0217074854443295,
           1.0207028311441877,
           1.019678060647378,
           1.01863410615619,
           1.0175719201577946,
           1.0164924747239834,
           1.0153967607866106,
           1.0142857873886146,
           1.0131605809105328,
           1.0120221842724395,
           1.0108716561112894,
           1.0097100699336763,
           1.0085385132440658,
           1.0073580866486038,
           1.0061699029346465,
           1.0049750861262208,
           1.0037747705156654,
           1.002570099671776,
           1.0013622254248202,
           1.0001523068288791,
           0.9989415091020104,
           0.997731002544824,
           0.9965219614381169,
           0.9953155629203033,
           0.9941129858454422,
           0.9929154096227564,
           0.9917240130386111,
           0.9905399730620142,
           0.9893644636347705,
           0.9881986544475299,
           0.9870437097030379,
           0.985900786867997,
           0.984771035415029,
           0.9836555955563185,
           0.9825555969706024,
           0.981472157525255,
           0.9804063819953014,
           0.9793593607812722,
           0.9783321686278847,
           0.9773258633456195,
           0.976341484537315,
           0.9753800523319821,
           0.9744425661280869,
           0.9735300033486114,
           0.9726433182102407,
           0.9717834405090713,
           0.9709512744252604,
           0.9701476973490639,
           0.9693735587307252,
           0.9686296789566774,
           0.9679168482545313,
           0.9672358256292909,
           0.9665873378332343,
           0.9659720783718492,
           0.9653907065481799,
           0.9648438465478871,
           0.964332086567251,
           0.9638559779862899,
           0.9634160345890663,
           0.9630127318331677,
           0.9626465061702469,
           0.9623177544193886,
           0.9620268331949501,
           0.9617740583903989,
           0.9615597047195205,
           0.9613840053162399,
           0.9612471513941364,
           0.9611492919665827,
           0.9610905336282716,
           0.9610709403987331,
           0.9610905336282716,
           0.9611492919665828,
           0.9612471513941365,
           0.9613840053162401,
           0.9615597047195207,
           0.9617740583903992,
           0.9620268331949505,
           0.9623177544193889,
           0.9626465061702474,
           0.9630127318331682,
           0.9634160345890668,
           0.9638559779862904,
           0.9643320865672513,
           0.9648438465478876,
           0.9653907065481806,
           0.96597207837185,
           0.966587337833235,
           0.9672358256292916,
           0.9679168482545321,
           0.9686296789566782,
           0.9693735587307258,
           0.9701476973490647,
           0.9709512744252612,
           0.9717834405090723,
           0.9726433182102415,
           0.9735300033486124,
           0.974442566128088,
           0.9753800523319831,
           0.9763414845373161,
           0.9773258633456205,
           0.9783321686278859,
           0.9793593607812733,
           0.9804063819953025,
           0.981472157525256,
           0.9825555969706036,
           0.9836555955563195,
           0.9847710354150302,
           0.9859007868679982,
           0.9870437097030393,
           0.9881986544475312,
           0.9893644636347718,
           0.9905399730620156,
           0.9917240130386125,
           0.9929154096227575,
           0.9941129858454435,
           0.9953155629203048,
           0.9965219614381182,
           0.9977310025448252,
           0.9989415091020116,
           1.0001523068288802,
           1.0013622254248213,
           1.002570099671777,
           1.0037747705156668,
           1.004975086126222,
           1.0061699029346478,
           1.007358086648605,
           1.008538513244067,
           1.0097100699336774,
           1.0108716561112903,
           1.0120221842724406,
           1.013160580910534,
           1.0142857873886155,
           1.0153967607866117,
           1.016492474723985,
           1.0175719201577957,
           1.018634106156191,
           1.0196780606473792,
           1.0207028311441886,
           1.0217074854443307,
           1.0226911123065159,
           1.0236528221026007,
           1.0245917474459525,
           1.0255070437962575,
           1.0263978900409858,
           1.0272634890537733,
           1.028103068229957,
           1.0289158799995417,
           1.0297012023178576,
           1.0304583391341873,
           1.0311866208386375,
           1.0318854046875372,
           1.0325540752076345,
           1.0331920445793716,
           1.0337987529995087,
           1.0343736690233607,
           1.0349162898869089,
           1.0354261418090407,
           1.035902780274158,
           1.0363457902953872,
           1.0367547866586184,
           1.0371294141475778,
           1.0374693477501369,
           1.0377742928460425,
           1.0380439853762333,
           1.0382781919939088,
           1.038476710197483,
           1.0386393684455555,
           1.0387660262540048,
           1.0388565742753013,
           1.0389109343601128
          ],
          [
           1.0308010008003263,
           1.0307865469009239,
           1.0307431979705137,
           1.030670992304323,
           1.0305699937005268,
           1.030440291419423,
           1.0302820001262505,
           1.0300952598176158,
           1.0298802357314902,
           1.0296371182407347,
           1.029366122730088,
           1.0290674894565708,
           1.0287414833932185,
           1.0283883940560834,
           1.0280085353144104,
           1.027602245183907,
           1.0271698856030096,
           1.0267118421920456,
           1.0262285239952003,
           1.025720363205168,
           1.0251878148703937,
           1.024631356584789,
           1.0240514881598146,
           1.0234487312788216,
           1.0228236291335444,
           1.022176746042638,
           1.021508667052162,
           1.020819997517914,
           1.0201113626695204,
           1.0193834071562085,
           1.0186367945741777,
           1.0178722069755173,
           1.0170903443586121,
           1.016291924140001,
           1.015477680607669,
           1.0146483643557633,
           1.013804741700748,
           1.0129475940790318,
           1.01207771742612,
           1.0111959215373747,
           1.0103030294104824,
           1.0093998765697656,
           1.0084873103724932,
           1.0075661892973882,
           1.0066373822155532,
           1.0057017676440732,
           1.0047602329825958,
           1.0038136737332188,
           1.00286299270406,
           1.0019090991969293,
           1.0009529081795565,
           0.999995339442885,
           0.9990373167439746,
           0.9980797669351177,
           0.9971236190798117,
           0.9961698035562824,
           0.9952192511493079,
           0.9942728921311396,
           0.9933316553323676,
           0.9923964672036357,
           0.9914682508691565,
           0.9905479251730349,
           0.989636403719458,
           0.9887345939078582,
           0.9878433959642102,
           0.9869637019696731,
           0.9860963948878309,
           0.9852423475918357,
           0.9844024218928036,
           0.983577467570848,
           0.9827683214101848,
           0.9819758062397707,
           0.9812007299809773,
           0.9804438847038298,
           0.9797060456933646,
           0.9789879705276863,
           0.9782903981693202,
           0.977614048071471,
           0.9769596193008047,
           0.9763277896783805,
           0.9757192149403526,
           0.975134527920056,
           0.9745743377530837,
           0.9740392291069369,
           0.9735297614368136,
           0.9730464682690665,
           0.9725898565138317,
           0.9721604058082819,
           0.971758567891919,
           0.9713847660152609,
           0.971039394383232,
           0.9707228176344822,
           0.9704353703578196,
           0.9701773566468416,
           0.9699490496937877,
           0.9697506914235514,
           0.9695824921686955,
           0.9694446303862331,
           0.9693372524168384,
           0.9692604722870534,
           0.9692143715549582,
           0.9691989991996738,
           0.9692143715549583,
           0.9692604722870535,
           0.9693372524168387,
           0.9694446303862331,
           0.9695824921686955,
           0.9697506914235517,
           0.969949049693788,
           0.9701773566468419,
           0.9704353703578199,
           0.9707228176344823,
           0.9710393943832322,
           0.9713847660152612,
           0.9717585678919192,
           0.9721604058082826,
           0.9725898565138321,
           0.9730464682690672,
           0.9735297614368141,
           0.9740392291069374,
           0.9745743377530843,
           0.9751345279200566,
           0.9757192149403532,
           0.9763277896783811,
           0.9769596193008052,
           0.9776140480714717,
           0.978290398169321,
           0.978987970527687,
           0.9797060456933654,
           0.9804438847038306,
           0.981200729980978,
           0.9819758062397713,
           0.9827683214101854,
           0.9835774675708489,
           0.9844024218928044,
           0.9852423475918364,
           0.9860963948878317,
           0.986963701969674,
           0.9878433959642111,
           0.9887345939078592,
           0.9896364037194592,
           0.9905479251730359,
           0.9914682508691574,
           0.9923964672036368,
           0.9933316553323687,
           0.9942728921311407,
           0.9952192511493088,
           0.9961698035562833,
           0.9971236190798126,
           0.9980797669351188,
           0.9990373167439753,
           0.9999953394428859,
           1.0009529081795574,
           1.0019090991969302,
           1.002862992704061,
           1.0038136737332197,
           1.0047602329825969,
           1.005701767644074,
           1.006637382215554,
           1.0075661892973893,
           1.008487310372494,
           1.0093998765697665,
           1.0103030294104833,
           1.0111959215373754,
           1.0120777174261208,
           1.0129475940790327,
           1.0138047417007492,
           1.0146483643557642,
           1.01547768060767,
           1.0162919241400017,
           1.0170903443586128,
           1.0178722069755182,
           1.0186367945741783,
           1.019383407156209,
           1.020111362669521,
           1.0208199975179144,
           1.0215086670521627,
           1.0221767460426388,
           1.022823629133545,
           1.0234487312788223,
           1.024051488159815,
           1.0246313565847893,
           1.0251878148703941,
           1.0257203632051681,
           1.0262285239952005,
           1.026711842192046,
           1.0271698856030098,
           1.0276022451839077,
           1.0280085353144106,
           1.0283883940560838,
           1.0287414833932187,
           1.029067489456571,
           1.0293661227300883,
           1.029637118240735,
           1.0298802357314907,
           1.0300952598176156,
           1.0302820001262507,
           1.030440291419423,
           1.0305699937005266,
           1.030670992304323,
           1.0307431979705137,
           1.0307865469009243
          ],
          [
           1.0236105794363861,
           1.02359942195341,
           1.0235659595692972,
           1.0235102224713435,
           1.0234322609478625,
           1.023332145352411,
           1.0232099660536986,
           1.0230658333711717,
           1.0228998774962588,
           1.0227122483992723,
           1.0225031157219457,
           1.0222726686555959,
           1.0220211158048909,
           1.0217486850372104,
           1.0214556233175744,
           1.0211421965291303,
           1.0208086892791743,
           1.0204554046906937,
           1.0200826641794132,
           1.0196908072163342,
           1.019280191075752,
           1.0188511905687443,
           1.0184041977621283,
           1.0179396216828829,
           1.0174578880080423,
           1.0169594387400713,
           1.0164447318677405,
           1.0159142410125215,
           1.01536845506054,
           1.0148078777801257,
           1.0142330274250093,
           1.0136444363232306,
           1.0130426504518313,
           1.0124282289974194,
           1.0118017439027045,
           1.0111637793991197,
           1.0105149315256619,
           1.0098558076340944,
           1.0091870258806808,
           1.0085092147046293,
           1.0078230122934546,
           1.0071290660354777,
           1.0064280319597099,
           1.0057205741633886,
           1.0050073642274557,
           1.0042890806202935,
           1.0035664080900581,
           1.002840037045977,
           1.0021106629290017,
           1.0013789855722428,
           1.0006457085516192,
           0.9999115385272196,
           0.9991771845758636,
           0.9984433575154071,
           0.9977107692213544,
           0.99698013193637,
           0.9962521575733166,
           0.9955275570124744,
           0.9948070393936239,
           0.9940913114037103,
           0.9933810765608282,
           0.9926770344953036,
           0.9919798802286744,
           0.9912903034513901,
           0.9906089878000975,
           0.9899366101353814,
           0.9892738398208715,
           0.9886213380046425,
           0.9879797569038508,
           0.9873497390935858,
           0.9867319168009127,
           0.9861269112051164,
           0.985535331745159,
           0.9849577754353814,
           0.9843948261904854,
           0.9838470541608387,
           0.9833150150791566,
           0.9827992496196045,
           0.9823002827703718,
           0.9818186232207653,
           0.9813547627638517,
           0.9809091757156837,
           0.980482318352118,
           0.9800746283642251,
           0.9796865243332666,
           0.9793184052261948,
           0.9789706499126042,
           0.9786436167040324,
           0.9783376429164806,
           0.9780530444569809,
           0.9777901154350099,
           0.9775491277994967,
           0.9773303310021381,
           0.9771339516876805,
           0.9769601934117856,
           0.9768092363870399,
           0.97668123725762,
           0.9765763289030664,
           0.9764946202715633,
           0.9764361962430662,
           0.9764011175225523,
           0.9763894205636138,
           0.9764011175225524,
           0.9764361962430663,
           0.9764946202715633,
           0.9765763289030663,
           0.9766812372576203,
           0.9768092363870401,
           0.9769601934117857,
           0.9771339516876808,
           0.9773303310021383,
           0.977549127799497,
           0.9777901154350104,
           0.9780530444569813,
           0.9783376429164811,
           0.9786436167040329,
           0.9789706499126044,
           0.9793184052261952,
           0.9796865243332671,
           0.9800746283642257,
           0.9804823183521184,
           0.9809091757156841,
           0.9813547627638523,
           0.9818186232207657,
           0.9823002827703724,
           0.9827992496196049,
           0.9833150150791571,
           0.9838470541608393,
           0.9843948261904859,
           0.9849577754353821,
           0.9855353317451596,
           0.9861269112051169,
           0.9867319168009132,
           0.9873497390935864,
           0.9879797569038514,
           0.988621338004643,
           0.9892738398208724,
           0.989936610135382,
           0.9906089878000982,
           0.9912903034513908,
           0.991979880228675,
           0.9926770344953044,
           0.9933810765608287,
           0.994091311403711,
           0.9948070393936248,
           0.9955275570124751,
           0.9962521575733173,
           0.9969801319363708,
           0.9977107692213553,
           0.9984433575154078,
           0.9991771845758641,
           0.9999115385272203,
           1.0006457085516198,
           1.0013789855722435,
           1.0021106629290026,
           1.0028400370459774,
           1.003566408090059,
           1.0042890806202942,
           1.0050073642274564,
           1.0057205741633892,
           1.0064280319597105,
           1.0071290660354781,
           1.0078230122934553,
           1.00850921470463,
           1.0091870258806814,
           1.0098558076340953,
           1.0105149315256625,
           1.0111637793991204,
           1.0118017439027052,
           1.01242822899742,
           1.013042650451832,
           1.0136444363232313,
           1.01423302742501,
           1.0148078777801264,
           1.0153684550605406,
           1.0159142410125217,
           1.0164447318677412,
           1.016959438740072,
           1.0174578880080427,
           1.0179396216828833,
           1.0184041977621288,
           1.0188511905687445,
           1.0192801910757525,
           1.0196908072163346,
           1.0200826641794136,
           1.020455404690694,
           1.0208086892791748,
           1.0211421965291307,
           1.0214556233175747,
           1.0217486850372106,
           1.0220211158048909,
           1.0222726686555959,
           1.0225031157219457,
           1.0227122483992725,
           1.0228998774962592,
           1.0230658333711717,
           1.023209966053699,
           1.023332145352411,
           1.0234322609478628,
           1.0235102224713433,
           1.023565959569297,
           1.02359942195341
          ],
          [
           1.0173647517777304,
           1.0173564954743755,
           1.0173317341499462,
           1.0172904905554678,
           1.0172328025897117,
           1.017158723269789,
           1.017068320689991,
           1.0169616779688802,
           1.0168388931846362,
           1.0167000792986738,
           1.016545364067539,
           1.0163748899431002,
           1.0161888139610515,
           1.0159873076177475,
           1.015770556735388,
           1.015538761315587,
           1.0152921353813442,
           1.0150309068074592,
           1.0147553171394212,
           1.014465621400816,
           1.014162087889295,
           1.0138449979611552,
           1.0135146458045914,
           1.013171338201673,
           1.0128153942791203,
           1.0124471452479518,
           1.012066934132081,
           1.0116751154859562,
           1.0112720551013352,
           1.0108581297033035,
           1.0104337266356442,
           1.0099992435356895,
           1.0095550879987798,
           1.0091016772324792,
           1.0086394377006955,
           1.0081688047578758,
           1.0076902222734487,
           1.0072041422467057,
           1.0067110244123236,
           1.0062113358367393,
           1.005705550505608,
           1.0051941489025893,
           1.0046776175797105,
           1.0041564487195869,
           1.00363113968978,
           1.003102192589597,
           1.0025701137896523,
           1.0020354134645162,
           1.0014986051188126,
           1.000960205107121,
           1.0004207321480716,
           0.9998807068330302,
           0.9993406511297908,
           0.9988010878817045,
           0.9982625403027001,
           0.9977255314686537,
           0.9971905838055966,
           0.9966582185752534,
           0.9961289553584273,
           0.9956033115367591,
           0.9950818017734036,
           0.9945649374931813,
           0.9940532263627782,
           0.9935471717715738,
           0.9930472723137007,
           0.9925540212719365,
           0.9920679061040529,
           0.9915894079322494,
           0.9911190010363042,
           0.9906571523510945,
           0.9902043209691316,
           0.9897609576487688,
           0.9893275043287452,
           0.9889043936497228,
           0.9884920484834875,
           0.9880908814704717,
           0.9877012945662653,
           0.9873236785977707,
           0.9869584128296569,
           0.9866058645417621,
           0.9862663886180799,
           0.985940327147962,
           0.9856280090401549,
           0.9853297496502765,
           0.9850458504223198,
           0.9847765985447635,
           0.9845222666218408,
           0.9842831123605058,
           0.9840593782736103,
           0.9838512913997903,
           0.9836590630405208,
           0.9834828885147919,
           0.9833229469318178,
           0.9831794009821646,
           0.9830523967476625,
           0.9829420635304229,
           0.9828485137012608,
           0.9827718425677879,
           0.9827121282624022,
           0.9826694316503732,
           0.9826437962581871,
           0.9826352482222696,
           0.982643796258187,
           0.9826694316503732,
           0.9827121282624022,
           0.982771842567788,
           0.9828485137012609,
           0.9829420635304229,
           0.9830523967476626,
           0.9831794009821649,
           0.983322946931818,
           0.983482888514792,
           0.983659063040521,
           0.9838512913997906,
           0.9840593782736107,
           0.9842831123605059,
           0.9845222666218413,
           0.9847765985447638,
           0.9850458504223201,
           0.9853297496502768,
           0.9856280090401552,
           0.9859403271479623,
           0.9862663886180802,
           0.9866058645417625,
           0.9869584128296572,
           0.9873236785977709,
           0.9877012945662658,
           0.9880908814704722,
           0.988492048483488,
           0.9889043936497232,
           0.9893275043287455,
           0.9897609576487694,
           0.990204320969132,
           0.990657152351095,
           0.9911190010363046,
           0.9915894079322498,
           0.9920679061040535,
           0.9925540212719367,
           0.9930472723137014,
           0.9935471717715745,
           0.9940532263627786,
           0.9945649374931818,
           0.9950818017734041,
           0.9956033115367597,
           0.996128955358428,
           0.996658218575254,
           0.997190583805597,
           0.9977255314686542,
           0.9982625403027007,
           0.9988010878817052,
           0.9993406511297913,
           0.9998807068330309,
           1.000420732148072,
           1.0009602051071216,
           1.0014986051188133,
           1.0020354134645166,
           1.0025701137896528,
           1.0031021925895978,
           1.0036311396897803,
           1.0041564487195873,
           1.004677617579711,
           1.0051941489025897,
           1.0057055505056087,
           1.00621133583674,
           1.0067110244123243,
           1.0072041422467064,
           1.0076902222734492,
           1.0081688047578763,
           1.008639437700696,
           1.0091016772324797,
           1.0095550879987802,
           1.00999924353569,
           1.0104337266356447,
           1.010858129703304,
           1.0112720551013357,
           1.0116751154859565,
           1.0120669341320816,
           1.0124471452479522,
           1.012815394279121,
           1.0131713382016732,
           1.0135146458045916,
           1.0138449979611552,
           1.0141620878892952,
           1.0144656214008165,
           1.0147553171394215,
           1.0150309068074594,
           1.0152921353813444,
           1.0155387613155873,
           1.0157705567353883,
           1.015987307617748,
           1.0161888139610518,
           1.0163748899431004,
           1.0165453640675393,
           1.016700079298674,
           1.0168388931846364,
           1.0169616779688804,
           1.0170683206899913,
           1.017158723269789,
           1.0172328025897117,
           1.0172904905554678,
           1.0173317341499462,
           1.0173564954743757
          ],
          [
           1.0120695602592384,
           1.0120637916076622,
           1.0120464910365554,
           1.012017674692304,
           1.0119773694706233,
           1.0119256129941692,
           1.0118624535812126,
           1.0117879502053786,
           1.0117021724464759,
           1.0116052004324323,
           1.0114971247723612,
           1.0113780464807847,
           1.0112480768930492,
           1.0111073375719668,
           1.010955960205718,
           1.0107940864970697,
           1.0106218680439474,
           1.0104394662114207,
           1.0102470519951567,
           1.0100448058764053,
           1.009832917668584,
           1.0096115863555324,
           1.0093810199215192,
           1.0091414351730794,
           1.0088930575527773,
           1.0086361209449828,
           1.0083708674737693,
           1.008097547293036,
           1.0078164183689697,
           1.007527746254967,
           1.007231803859143,
           1.0069288712045619,
           1.0066192351823293,
           1.0063031892976986,
           1.0059810334093406,
           1.0056530734619509,
           1.0053196212123559,
           1.0049809939493068,
           1.0046375142071446,
           1.0042895094735327,
           1.0039373118914634,
           1.0035812579557564,
           1.0032216882042606,
           1.0028589469040015,
           1.002493381732507,
           1.002125343454564,
           1.0017551855946614,
           1.0013832641053853,
           1.0010099370320453,
           1.0006355641738116,
           1.0002605067416575,
           0.999885127013411,
           0.999509787986221,
           0.9991348530267588,
           0.9987606855194823,
           0.9983876485132955,
           0.9980161043669458,
           0.9976464143935087,
           0.997278938504318,
           0.9969140348527028,
           0.9965520594779,
           0.9961933659495255,
           0.9958383050129745,
           0.9954872242361481,
           0.9951404676578908,
           0.9947983754385349,
           0.9944612835129555,
           0.9941295232465324,
           0.9938034210944248,
           0.9934832982645678,
           0.9931694703847925,
           0.9928622471744806,
           0.9925619321211596,
           0.9922688221624443,
           0.9919832073737276,
           0.9917053706620231,
           0.9914355874663571,
           0.9911741254651026,
           0.9909212442906449,
           0.9906771952517612,
           0.99044222106409,
           0.9902165555890576,
           0.9900004235816249,
           0.9897940404472023,
           0.9895976120080737,
           0.9894113342796639,
           0.9892353932569623,
           0.9890699647114136,
           0.988915213998567,
           0.9887712958767624,
           0.9886383543371231,
           0.9885165224450976,
           0.9884059221937921,
           0.9883066643693057,
           0.9882188484282723,
           0.9881425623877919,
           0.9880778827279142,
           0.9880248743068268,
           0.9879835902888693,
           0.9879540720854882,
           0.9879363493092181,
           0.9879304397407617,
           0.987936349309218,
           0.9879540720854882,
           0.9879835902888694,
           0.988024874306827,
           0.9880778827279142,
           0.9881425623877919,
           0.9882188484282725,
           0.9883066643693059,
           0.9884059221937922,
           0.9885165224450978,
           0.9886383543371232,
           0.9887712958767625,
           0.988915213998567,
           0.9890699647114138,
           0.9892353932569624,
           0.9894113342796642,
           0.989597612008074,
           0.9897940404472024,
           0.9900004235816254,
           0.9902165555890579,
           0.9904422210640902,
           0.9906771952517615,
           0.9909212442906452,
           0.991174125465103,
           0.9914355874663573,
           0.9917053706620234,
           0.9919832073737279,
           0.9922688221624446,
           0.9925619321211598,
           0.9928622471744808,
           0.9931694703847928,
           0.9934832982645682,
           0.9938034210944251,
           0.9941295232465324,
           0.9944612835129558,
           0.9947983754385352,
           0.9951404676578912,
           0.9954872242361487,
           0.9958383050129748,
           0.9961933659495258,
           0.9965520594779004,
           0.996914034852703,
           0.9972789385043186,
           0.9976464143935091,
           0.998016104366946,
           0.998387648513296,
           0.9987606855194827,
           0.9991348530267592,
           0.9995097879862214,
           0.9998851270134115,
           1.0002605067416577,
           1.0006355641738118,
           1.0010099370320458,
           1.0013832641053857,
           1.0017551855946618,
           1.0021253434545645,
           1.0024933817325075,
           1.0028589469040017,
           1.0032216882042608,
           1.0035812579557568,
           1.0039373118914636,
           1.004289509473533,
           1.004637514207145,
           1.0049809939493073,
           1.0053196212123559,
           1.005653073461951,
           1.0059810334093409,
           1.006303189297699,
           1.00661923518233,
           1.006928871204562,
           1.0072318038591435,
           1.0075277462549672,
           1.00781641836897,
           1.008097547293036,
           1.0083708674737697,
           1.008636120944983,
           1.0088930575527775,
           1.0091414351730796,
           1.0093810199215194,
           1.0096115863555326,
           1.0098329176685843,
           1.0100448058764055,
           1.0102470519951567,
           1.0104394662114207,
           1.0106218680439474,
           1.01079408649707,
           1.010955960205718,
           1.0111073375719672,
           1.0112480768930494,
           1.0113780464807847,
           1.0114971247723612,
           1.0116052004324325,
           1.011702172446476,
           1.0117879502053788,
           1.0118624535812129,
           1.0119256129941692,
           1.011977369470623,
           1.0120176746923042,
           1.0120464910365556,
           1.0120637916076625
          ],
          [
           1.0077301276367194,
           1.0077264171130342,
           1.007715289049741,
           1.0076967539670425,
           1.0076708293883272,
           1.0076375398247492,
           1.0075969167536565,
           1.0075489985908768,
           1.007493830656877,
           1.0074314651368244,
           1.0073619610345608,
           1.0072853841205343,
           1.0072018068737052,
           1.0071113084174745,
           1.0070139744496651,
           1.0069098971666082,
           1.0067991751813767,
           1.0066819134362206,
           1.0065582231092576,
           1.0064282215154838,
           1.0062920320021644,
           1.006149783838674,
           1.0060016121008601,
           1.0058476575500073,
           1.005688066506482,
           1.0055229907181433,
           1.0053525872236129,
           1.005177018210495,
           1.00499645086865,
           1.00481105723862,
           1.0046210140553193,
           1.004426502587103,
           1.0042277084703255,
           1.0040248215395189,
           1.0038180356533126,
           1.0036075485162304,
           1.0033935614964966,
           1.0031762794399979,
           1.0029559104805417,
           1.0027326658465663,
           1.002506759664454,
           1.0022784087586114,
           1.0020478324484798,
           1.0018152523426422,
           1.001580892130207,
           1.0013449773696408,
           1.0011077352752367,
           1.000869394501405,
           1.0006301849249755,
           1.000390337425708,
           1.0001500836652133,
           0.999909655864482,
           0.9996692865802358,
           0.9994292084803051,
           0.9991896541182512,
           0.9989508557074499,
           0.9987130448948555,
           0.9984764525346697,
           0.9982413084621411,
           0.9980078412677242,
           0.9977762780718258,
           0.9975468443003751,
           0.9973197634614478,
           0.9970952569231822,
           0.9968735436932222,
           0.996654840199924,
           0.9964393600755653,
           0.9962273139417954,
           0.99601890919756,
           0.9958143498097415,
           0.9956138361067508,
           0.9954175645753001,
           0.995225727660598,
           0.9950385135701918,
           0.9948561060816875,
           0.9946786843545746,
           0.9945064227463793,
           0.9943394906333618,
           0.9941780522359781,
           0.9940222664493137,
           0.9938722866787009,
           0.9937282606807128,
           0.9935903304097418,
           0.993458631870343,
           0.9933332949755331,
           0.9932144434112198,
           0.993102194506935,
           0.9929966591130353,
           0.9928979414845226,
           0.9928061391716426,
           0.9927213429173909,
           0.9926436365620663,
           0.9925730969549957,
           0.9925097938735373,
           0.9924537899494773,
           0.9924051406029115,
           0.9923638939836973,
           0.992330090920557,
           0.9923037648778954,
           0.9922849419203928,
           0.9922736406854145,
           0.9922698723632805,
           0.9922736406854146,
           0.9922849419203928,
           0.9923037648778955,
           0.9923300909205569,
           0.9923638939836974,
           0.9924051406029116,
           0.9924537899494775,
           0.9925097938735373,
           0.992573096954996,
           0.9926436365620666,
           0.9927213429173909,
           0.9928061391716427,
           0.9928979414845227,
           0.9929966591130354,
           0.9931021945069353,
           0.9932144434112198,
           0.9933332949755332,
           0.9934586318703432,
           0.9935903304097421,
           0.993728260680713,
           0.993872286678701,
           0.9940222664493139,
           0.9941780522359782,
           0.9943394906333619,
           0.9945064227463795,
           0.9946786843545748,
           0.9948561060816877,
           0.995038513570192,
           0.9952257276605981,
           0.9954175645753002,
           0.9956138361067508,
           0.9958143498097417,
           0.9960189091975602,
           0.9962273139417955,
           0.9964393600755658,
           0.9966548401999242,
           0.9968735436932226,
           0.9970952569231825,
           0.9973197634614479,
           0.9975468443003752,
           0.997776278071826,
           0.9980078412677245,
           0.9982413084621413,
           0.9984764525346699,
           0.9987130448948558,
           0.9989508557074502,
           0.9991896541182514,
           0.9994292084803051,
           0.9996692865802359,
           0.9999096558644822,
           1.0001500836652135,
           1.0003903374257082,
           1.0006301849249757,
           1.0008693945014053,
           1.0011077352752369,
           1.0013449773696408,
           1.0015808921302072,
           1.0018152523426427,
           1.00204783244848,
           1.0022784087586116,
           1.0025067596644541,
           1.0027326658465667,
           1.0029559104805421,
           1.003176279439998,
           1.0033935614964968,
           1.0036075485162304,
           1.0038180356533128,
           1.004024821539519,
           1.004227708470326,
           1.0044265025871033,
           1.0046210140553196,
           1.00481105723862,
           1.0049964508686502,
           1.0051770182104953,
           1.0053525872236133,
           1.0055229907181436,
           1.0056880665064822,
           1.0058476575500075,
           1.0060016121008601,
           1.006149783838674,
           1.0062920320021647,
           1.0064282215154838,
           1.0065582231092578,
           1.0066819134362206,
           1.006799175181377,
           1.0069098971666082,
           1.007013974449665,
           1.0071113084174745,
           1.0072018068737052,
           1.0072853841205343,
           1.0073619610345608,
           1.0074314651368246,
           1.0074938306568773,
           1.0075489985908768,
           1.007596916753657,
           1.0076375398247492,
           1.007670829388327,
           1.0076967539670423,
           1.0077152890497407,
           1.0077264171130342
          ],
          [
           1.0043506520309784,
           1.0043485566575947,
           1.0043422725383675,
           1.0043318056742314,
           1.0043171660606258,
           1.0042983676783217,
           1.00427542848059,
           1.0042483703767193,
           1.004217219211897,
           1.00418200474347,
           1.004142760613602,
           1.004099524318346,
           1.0040523371731633,
           1.0040012442749078,
           1.0039462944603073,
           1.0038875402609773,
           1.0038250378550007,
           1.0037588470151053,
           1.0036890310534932,
           1.0036156567633479,
           1.003538794357084,
           1.0034585174013717,
           1.003374902749,
           1.0032880304676257,
           1.0031979837654696,
           1.0031048489140189,
           1.0030087151677953,
           1.0029096746812605,
           1.0028078224229189,
           1.0027032560866984,
           1.0025960760006714,
           1.0024863850332018,
           1.0023742884965892,
           1.0022598940482979,
           1.0021433115898466,
           1.0020246531634538,
           1.0019040328465187,
           1.0017815666440364,
           1.0016573723790345,
           1.0015315695811302,
           1.0014042793733056,
           1.0012756243569993,
           1.0011457284956198,
           1.0010147169965795,
           1.000882716191964,
           1.0007498534179378,
           1.000616256892997,
           1.0004820555951883,
           1.0003473791383966,
           1.0002123576478268,
           1.0000771216347906,
           0.9999418018709196,
           0.9998065292619196,
           0.9996714347209937,
           0.9995366490420525,
           0.9994023027728306,
           0.9992685260880405,
           0.9991354486626853,
           0.9990031995456508,
           0.9988719070337119,
           0.9987416985460705,
           0.9986127004995579,
           0.9984850381846224,
           0.9983588356422342,
           0.9982342155418283,
           0.9981112990604161,
           0.997990205762987,
           0.997871053484329,
           0.9977539582123861,
           0.9976390339732832,
           0.9975263927181339,
           0.9974161442117555,
           0.9973083959234086,
           0.9972032529196806,
           0.9971008177596274,
           0.997001190392287,
           0.9969044680566802,
           0.9968107451844036,
           0.9967201133049248,
           0.9966326609536857,
           0.9965484735831118,
           0.9964676334766319,
           0.996390219665801,
           0.9963163078506192,
           0.9962459703231406,
           0.9961792758944527,
           0.9961162898251157,
           0.9960570737591334,
           0.9960016856615385,
           0.9959501797596589,
           0.9959026064881349,
           0.9958590124377467,
           0.9958194403081185,
           0.9957839288643465,
           0.9957525128976039,
           0.9957252231897694,
           0.9957020864821203,
           0.995683125448123,
           0.9956683586703593,
           0.9956578006216074,
           0.9956514616501074,
           0.9956493479690216,
           0.9956514616501075,
           0.9956578006216076,
           0.9956683586703593,
           0.9956831254481231,
           0.9957020864821202,
           0.9957252231897695,
           0.9957525128976039,
           0.9957839288643465,
           0.9958194403081185,
           0.9958590124377467,
           0.9959026064881349,
           0.9959501797596592,
           0.9960016856615386,
           0.9960570737591334,
           0.9961162898251158,
           0.9961792758944528,
           0.9962459703231406,
           0.9963163078506193,
           0.9963902196658012,
           0.9964676334766323,
           0.9965484735831119,
           0.9966326609536857,
           0.9967201133049249,
           0.9968107451844037,
           0.9969044680566802,
           0.9970011903922871,
           0.9971008177596276,
           0.9972032529196807,
           0.9973083959234086,
           0.9974161442117555,
           0.9975263927181339,
           0.9976390339732832,
           0.9977539582123862,
           0.997871053484329,
           0.9979902057629872,
           0.9981112990604161,
           0.9982342155418285,
           0.9983588356422343,
           0.9984850381846228,
           0.998612700499558,
           0.9987416985460708,
           0.9988719070337119,
           0.9990031995456509,
           0.9991354486626853,
           0.9992685260880408,
           0.9994023027728307,
           0.9995366490420529,
           0.999671434720994,
           0.9998065292619195,
           0.9999418018709196,
           1.0000771216347908,
           1.0002123576478268,
           1.0003473791383968,
           1.0004820555951888,
           1.0006162568929975,
           1.0007498534179378,
           1.0008827161919642,
           1.0010147169965795,
           1.0011457284956198,
           1.0012756243569996,
           1.0014042793733056,
           1.0015315695811304,
           1.0016573723790345,
           1.0017815666440366,
           1.001904032846519,
           1.0020246531634538,
           1.0021433115898468,
           1.0022598940482979,
           1.0023742884965894,
           1.0024863850332018,
           1.0025960760006714,
           1.0027032560866984,
           1.002807822422919,
           1.0029096746812605,
           1.0030087151677956,
           1.003104848914019,
           1.0031979837654696,
           1.0032880304676255,
           1.003374902749,
           1.0034585174013717,
           1.0035387943570842,
           1.003615656763348,
           1.003689031053493,
           1.0037588470151053,
           1.0038250378550004,
           1.0038875402609773,
           1.003946294460307,
           1.0040012442749078,
           1.0040523371731633,
           1.004099524318346,
           1.004142760613602,
           1.00418200474347,
           1.004217219211897,
           1.0042483703767193,
           1.0042754284805904,
           1.004298367678322,
           1.0043171660606258,
           1.0043318056742312,
           1.0043422725383675,
           1.004348556657595
          ],
          [
           1.0019344028664037,
           1.001933468967583,
           1.0019306681693885,
           1.0019260031657715,
           1.0019194784438221,
           1.0019111002795276,
           1.0019008767318403,
           1.00188881763506,
           1.0018749345895346,
           1.0018592409506928,
           1.001841751816413,
           1.001822484012743,
           1.0018014560779807,
           1.001778688245132,
           1.0017542024227613,
           1.001728022174247,
           1.0017001726954697,
           1.0016706807909392,
           1.0016395748483993,
           1.0016068848119128,
           1.0015726421534683,
           1.0015368798431232,
           1.0014996323177137,
           1.0014609354481583,
           1.0014208265053857,
           1.0013793441249175,
           1.0013365282701328,
           1.0012924201942566,
           1.0012470624010987,
           1.0012004986045806,
           1.0011527736870902,
           1.001103933656697,
           1.0010540256032705,
           1.001003097653543,
           1.0009511989251492,
           1.0008983794796993,
           1.000844690274914,
           1.0007901831158754,
           1.0007349106054348,
           1.000678926093824,
           1.0006222836275152,
           1.0005650378973832,
           1.0005072441862097,
           1.000448958315584,
           1.000390236592252,
           1.000331135753957,
           1.000271712914831,
           1.0002120255103824,
           1.0001521312421366,
           1.0000920880219786,
           1.0000319539162548,
           0.9999717870896841,
           0.9999116457491323,
           0.9998515880873078,
           0.9997916722264277,
           0.9997319561619148,
           0.9996724977061724,
           0.9996133544325012,
           0.9995545836192047,
           0.9994962421939442,
           0.9994383866783919,
           0.9993810731332446,
           0.9993243571036435,
           0.999268293565062,
           0.9992129368697101,
           0.9991583406935113,
           0.9991045579837032,
           0.9990516409071182,
           0.9989996407991901,
           0.9989486081137434,
           0.9988985923736138,
           0.998849642122149,
           0.9988018048756411,
           0.9987551270767371,
           0.9987096540488768,
           0.9986654299518016,
           0.9986224977381839,
           0.9985808991114186,
           0.9985406744846197,
           0.9985018629408677,
           0.9984645021947451,
           0.9984286285552011,
           0.998394276889784,
           0.9983614805902806,
           0.9983302715397923,
           0.9983006800812897,
           0.9982727349876735,
           0.998246463433373,
           0.9982218909675151,
           0.9981990414886887,
           0.9981779372213335,
           0.9981585986937743,
           0.9981410447179299,
           0.9981252923707098,
           0.9981113569771265,
           0.9980992520951354,
           0.9980889895022217,
           0.9980805791837445,
           0.9980740293230564,
           0.9980693462934033,
           0.9980665346516153,
           0.9980655971335964,
           0.9980665346516154,
           0.9980693462934034,
           0.9980740293230563,
           0.9980805791837444,
           0.9980889895022217,
           0.9980992520951355,
           0.9981113569771266,
           0.9981252923707098,
           0.9981410447179299,
           0.9981585986937743,
           0.9981779372213333,
           0.9981990414886887,
           0.9982218909675151,
           0.9982464634333732,
           0.9982727349876735,
           0.9983006800812899,
           0.9983302715397921,
           0.9983614805902804,
           0.9983942768897841,
           0.9984286285552011,
           0.9984645021947454,
           0.9985018629408677,
           0.9985406744846196,
           0.9985808991114185,
           0.9986224977381839,
           0.9986654299518016,
           0.9987096540488768,
           0.9987551270767373,
           0.998801804875641,
           0.9988496421221491,
           0.9988985923736139,
           0.9989486081137435,
           0.99899964079919,
           0.9990516409071182,
           0.9991045579837032,
           0.9991583406935113,
           0.9992129368697104,
           0.9992682935650621,
           0.9993243571036436,
           0.9993810731332448,
           0.9994383866783921,
           0.9994962421939443,
           0.9995545836192048,
           0.9996133544325012,
           0.9996724977061724,
           0.9997319561619148,
           0.9997916722264281,
           0.9998515880873078,
           0.9999116457491324,
           0.9999717870896841,
           1.000031953916255,
           1.0000920880219786,
           1.0001521312421364,
           1.0002120255103826,
           1.000271712914831,
           1.000331135753957,
           1.0003902365922521,
           1.000448958315584,
           1.0005072441862095,
           1.0005650378973834,
           1.0006222836275154,
           1.0006789260938238,
           1.0007349106054348,
           1.0007901831158754,
           1.000844690274914,
           1.000898379479699,
           1.0009511989251494,
           1.001003097653543,
           1.0010540256032707,
           1.001103933656697,
           1.0011527736870902,
           1.0012004986045806,
           1.0012470624010987,
           1.0012924201942566,
           1.0013365282701328,
           1.0013793441249175,
           1.0014208265053859,
           1.001460935448158,
           1.0014996323177134,
           1.001536879843123,
           1.0015726421534683,
           1.0016068848119128,
           1.0016395748483993,
           1.0016706807909392,
           1.0017001726954695,
           1.0017280221742473,
           1.0017542024227613,
           1.001778688245132,
           1.0018014560779804,
           1.001822484012743,
           1.0018417518164133,
           1.0018592409506928,
           1.0018749345895346,
           1.00188881763506,
           1.0019008767318405,
           1.0019111002795273,
           1.001919478443822,
           1.0019260031657715,
           1.0019306681693887,
           1.0019334689675834
          ],
          [
           1.0004837177080108,
           1.0004834838382894,
           1.000482782455051,
           1.0004816142358564,
           1.0004799803092497,
           1.000477882253672,
           1.0004753220959437,
           1.0004723023093158,
           1.000468825811089,
           1.0004648959598093,
           1.0004605165520353,
           1.000455691818687,
           1.000450426420976,
           1.0004447254459188,
           1.0004385944014438,
           1.0004320392110904,
           1.00042506620831,
           1.000417682130369,
           1.000409894111865,
           1.0004017096778606,
           1.0003931367366377,
           1.0003841835720846,
           1.0003748588357209,
           1.0003651715383655,
           1.0003551310414596,
           1.0003447470480498,
           1.0003340295934415,
           1.0003229890355325,
           1.000311636044831,
           1.0002999815941747,
           1.0002880369481553,
           1.0002758136522605,
           1.0002633235217444,
           1.0002505786302356,
           1.0002375912980934,
           1.0002243740805268,
           1.0002109397554828,
           1.00019730131132,
           1.0001834719342744,
           1.0001694649957351,
           1.000155294039337,
           1.0001409727678874,
           1.0001265150301335,
           1.0001119348073897,
           1.000097246200033,
           1.000082463413881,
           1.0000676007464662,
           1.0000526725732204,
           1.0000376933335768,
           1.0000226775170145,
           1.000007639649046,
           0.9999925942771707,
           0.999977555956804,
           0.999962539237196,
           0.9999475586473529,
           0.999932628681977,
           0.9999177637874355,
           0.9999029783477758,
           0.9998882866707968,
           0.9998737029741916,
           0.9998592413717773,
           0.9998449158598193,
           0.9998307403034712,
           0.9998167284233359,
           0.9998028937821669,
           0.9997892497717188,
           0.9997758095997625,
           0.9997625862772773,
           0.999749592605829,
           0.9997368411651515,
           0.9997243443009429,
           0.9997121141128821,
           0.9997001624428877,
           0.9996885008636218,
           0.9996771406672557,
           0.9996660928545038,
           0.9996553681239428,
           0.9996449768616189,
           0.9996349291309596,
           0.9996252346629979,
           0.9996159028469165,
           0.9996069427209242,
           0.9995983629634732,
           0.9995901718848226,
           0.9995823774189612,
           0.9995749871158943,
           0.9995680081343047,
           0.999561447234589,
           0.9995553107722867,
           0.999549604691898,
           0.9995443345211028,
           0.9995395053653842,
           0.9995351219030625,
           0.9995311883807442,
           0.9995277086091906,
           0.9995246859596113,
           0.9995221233603837,
           0.9995200232942038,
           0.9995183877956709,
           0.9995172184493079,
           0.9995165163880192,
           0.9995162822919892,
           0.9995165163880191,
           0.9995172184493077,
           0.9995183877956707,
           0.9995200232942036,
           0.9995221233603837,
           0.9995246859596115,
           0.9995277086091905,
           0.9995311883807443,
           0.9995351219030625,
           0.9995395053653842,
           0.9995443345211029,
           0.9995496046918979,
           0.9995553107722868,
           0.9995614472345891,
           0.9995680081343047,
           0.9995749871158945,
           0.999582377418961,
           0.9995901718848225,
           0.9995983629634733,
           0.9996069427209245,
           0.9996159028469165,
           0.9996252346629978,
           0.9996349291309596,
           0.9996449768616189,
           0.9996553681239428,
           0.9996660928545039,
           0.9996771406672557,
           0.9996885008636218,
           0.9997001624428876,
           0.9997121141128822,
           0.999724344300943,
           0.9997368411651518,
           0.9997495926058289,
           0.9997625862772771,
           0.9997758095997625,
           0.9997892497717186,
           0.9998028937821668,
           0.9998167284233359,
           0.9998307403034713,
           0.9998449158598195,
           0.9998592413717773,
           0.9998737029741916,
           0.9998882866707969,
           0.9999029783477761,
           0.9999177637874355,
           0.9999326286819769,
           0.9999475586473532,
           0.999962539237196,
           0.9999775559568042,
           0.9999925942771707,
           1.0000076396490458,
           1.0000226775170145,
           1.0000376933335768,
           1.0000526725732204,
           1.0000676007464664,
           1.0000824634138807,
           1.0000972462000328,
           1.0001119348073897,
           1.0001265150301335,
           1.0001409727678876,
           1.0001552940393372,
           1.000169464995735,
           1.0001834719342744,
           1.0001973013113201,
           1.0002109397554828,
           1.0002243740805266,
           1.0002375912980934,
           1.0002505786302356,
           1.0002633235217446,
           1.0002758136522605,
           1.000288036948155,
           1.0002999815941747,
           1.000311636044831,
           1.0003229890355325,
           1.0003340295934418,
           1.0003447470480498,
           1.0003551310414596,
           1.0003651715383655,
           1.0003748588357209,
           1.0003841835720844,
           1.0003931367366377,
           1.0004017096778606,
           1.000409894111865,
           1.0004176821303687,
           1.00042506620831,
           1.0004320392110906,
           1.0004385944014436,
           1.0004447254459188,
           1.0004504264209757,
           1.000455691818687,
           1.000460516552035,
           1.0004648959598093,
           1.000468825811089,
           1.0004723023093158,
           1.000475322095944,
           1.000477882253672,
           1.0004799803092497,
           1.0004816142358561,
           1.000482782455051,
           1.0004834838382894
          ]
         ]
        }
       ],
       "layout": {
        "autosize": false,
        "height": 500,
        "margin": {
         "b": 65,
         "l": 65,
         "r": 50,
         "t": 90
        },
        "scene": {
         "xaxis": {
          "showbackground": false,
          "title": {
           "text": "kx"
          }
         },
         "yaxis": {
          "showbackground": false,
          "title": {
           "text": "ky"
          }
         },
         "zaxis": {
          "showbackground": false,
          "title": {
           "text": "E [t]"
          }
         }
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "width": 800
       }
      },
      "text/html": [
       "<div>                            <div id=\"30bb0bb8-b77f-4805-9683-d11d56288ffb\" class=\"plotly-graph-div\" style=\"height:500px; width:800px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"30bb0bb8-b77f-4805-9683-d11d56288ffb\")) {                    Plotly.newPlot(                        \"30bb0bb8-b77f-4805-9683-d11d56288ffb\",                        [{\"colorbar\": {\"x\": 0.75}, \"colorscale\": [[0.0, \"rgb(253, 253, 204)\"], [0.09090909090909091, \"rgb(206, 236, 179)\"], [0.18181818181818182, \"rgb(156, 219, 165)\"], [0.2727272727272727, \"rgb(111, 201, 163)\"], [0.36363636363636365, \"rgb(86, 177, 163)\"], [0.45454545454545453, \"rgb(76, 153, 160)\"], [0.5454545454545454, \"rgb(68, 130, 155)\"], [0.6363636363636364, \"rgb(62, 108, 150)\"], [0.7272727272727273, \"rgb(62, 82, 143)\"], [0.8181818181818182, \"rgb(64, 60, 115)\"], [0.9090909090909091, \"rgb(54, 43, 77)\"], [1.0, \"rgb(39, 26, 44)\"]], \"opacity\": 0.9, \"type\": \"surface\", \"x\": [[-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151]], \"y\": [[-3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793], [-3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478], [-3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632], [-3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483], [-3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333], [-2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184], [-2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035], [-2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885], [-2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736], [-2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586], [-2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437], [-2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288], [-2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014], [-2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699], [-2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384], [-2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069], [-2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754], [-2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439], [-2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124], [-2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092], [-2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943], [-2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793], [-2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644], [-2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495], [-2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345], [-2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196], [-2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046], [-2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897], [-2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748], [-2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866], [-2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345], [-2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203], [-2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715], [-2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654], [-2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085], [-2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877], [-2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455], [-1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403], [-1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253], [-1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104], [-1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955], [-1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805], [-1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656], [-1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506], [-1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357], [-1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207], [-1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058], [-1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909], [-1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676], [-1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361], [-1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046], [-1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731], [-1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162], [-1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012], [-1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863], [-1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713], [-1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564], [-1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414], [-1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265], [-1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116], [-1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966], [-1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817], [-1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667], [-1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518], [-1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369], [-1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322], [-1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007], [-1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692], [-1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377], [-0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621], [-0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472], [-0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323], [-0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173], [-0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024], [-0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874], [-0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725], [-0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576], [-0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426], [-0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277], [-0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127], [-0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978], [-0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828], [-0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679], [-0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653], [-0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338], [-0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231], [-0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814], [-0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932], [-0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825], [-0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633], [-0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837], [-0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343], [-0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185], [-0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355], [-0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886], [-0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366], [-0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872], [-0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378], [-0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884], [-0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896], [-0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954], [1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14], [0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093], [0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587], [0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081], [0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575], [0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907], [0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564], [0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058], [0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552], [0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046], [0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654], [0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034], [0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953], [0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023], [0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517], [0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401], [0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505], [0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137], [0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849], [0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999], [0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148], [0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298], [0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447], [0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596], [0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746], [0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895], [0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045], [0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194], [0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344], [0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493], [0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642], [0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792], [0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941], [1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409], [1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724], [1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039], [1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539], [1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688], [1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838], [1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987], [1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137], [1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286], [1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435], [1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585], [1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734], [1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884], [1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033], [1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182], [1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332], [1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481], [1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763], [1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078], [1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393], [1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708], [1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228], [1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378], [1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527], [1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677], [1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826], [1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975], [1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125], [1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274], [1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424], [1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573], [1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723], [2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487], [2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802], [2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117], [2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432], [2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747], [2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062], [2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377], [2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692], [2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067], [2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217], [2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366], [2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516], [2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665], [2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814], [2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964], [2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113], [2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263], [2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841], [2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156], [2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471], [2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786], [2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101], [2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416], [2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731], [2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046], [2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607], [2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757], [2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906], [2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056], [2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205], [2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354], [2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504], [3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653], [3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803], [3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195], [3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151]], \"z\": [[-1.0, -1.0, -0.9999999999999999, -1.0, -1.0000000000000002, -1.0, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0000000000000002, -1.0, -1.0000000000000002, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0000000000000002, -1.0, -0.9999999999999999, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0000000000000002, -1.0, -1.0, -1.0, -1.0000000000000002, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -1.0000000000000002, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0000000000000002, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0000000000000002, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0000000000000002, -1.0, -1.0000000000000002, -1.0, -1.0, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0000000000000002, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0000000000000002, -1.0, -0.9999999999999998, -0.9999999999999999, -0.9999999999999999, -0.9999999999999999, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -0.9999999999999999, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0, -0.9999999999999999, -1.0, -1.0, -0.9999999999999999, -1.0, -0.9999999999999998, -1.0, -1.0, -1.0, -0.9999999999999999, -0.9999999999999999, -1.0, -1.0, -1.0, -1.0, -0.9999999999999999, -1.0000000000000002], [-1.0004837177080117, -1.0004834838382903, -1.0004827824550522, -1.0004816142358575, -1.0004799803092508, -1.0004778822536728, -1.0004753220959446, -1.000472302309317, -1.00046882581109, -1.0004648959598101, -1.000460516552036, -1.000455691818688, -1.0004504264209768, -1.0004447254459197, -1.0004385944014447, -1.0004320392110913, -1.0004250662083112, -1.0004176821303699, -1.000409894111866, -1.0004017096778615, -1.0003931367366383, -1.0003841835720853, -1.0003748588357217, -1.0003651715383663, -1.0003551310414602, -1.0003447470480504, -1.0003340295934422, -1.0003229890355332, -1.0003116360448314, -1.0002999815941753, -1.0002880369481557, -1.0002758136522611, -1.000263323521745, -1.0002505786302363, -1.0002375912980939, -1.0002243740805272, -1.0002109397554833, -1.0001973013113203, -1.0001834719342748, -1.0001694649957356, -1.0001552940393375, -1.0001409727678876, -1.000126515030134, -1.00011193480739, -1.0000972462000333, -1.0000824634138812, -1.0000676007464664, -1.0000526725732204, -1.0000376933335768, -1.0000226775170145, -1.000007639649046, -0.9999925942771707, -0.999977555956804, -0.999962539237196, -0.9999475586473529, -0.9999326286819769, -0.9999177637874352, -0.9999029783477758, -0.9998882866707965, -0.9998737029741914, -0.999859241371777, -0.999844915859819, -0.999830740303471, -0.9998167284233356, -0.9998028937821662, -0.9997892497717181, -0.9997758095997621, -0.999762586277277, -0.9997495926058284, -0.9997368411651512, -0.9997243443009424, -0.9997121141128815, -0.9997001624428871, -0.9996885008636212, -0.999677140667255, -0.9996660928545031, -0.9996553681239421, -0.9996449768616181, -0.999634929130959, -0.9996252346629971, -0.9996159028469157, -0.9996069427209235, -0.9995983629634723, -0.9995901718848216, -0.9995823774189602, -0.9995749871158935, -0.9995680081343037, -0.9995614472345881, -0.9995553107722857, -0.9995496046918969, -0.9995443345211019, -0.9995395053653833, -0.9995351219030616, -0.9995311883807432, -0.9995277086091896, -0.9995246859596103, -0.9995221233603827, -0.9995200232942028, -0.9995183877956699, -0.9995172184493069, -0.9995165163880182, -0.9995162822919882, -0.9995165163880181, -0.9995172184493067, -0.9995183877956697, -0.9995200232942029, -0.9995221233603827, -0.9995246859596104, -0.9995277086091895, -0.9995311883807433, -0.9995351219030617, -0.9995395053653834, -0.9995443345211018, -0.999549604691897, -0.9995553107722859, -0.9995614472345881, -0.9995680081343037, -0.9995749871158937, -0.9995823774189603, -0.9995901718848217, -0.9995983629634725, -0.9996069427209237, -0.9996159028469156, -0.9996252346629972, -0.9996349291309587, -0.999644976861618, -0.9996553681239421, -0.9996660928545033, -0.999677140667255, -0.9996885008636212, -0.999700162442887, -0.9997121141128816, -0.9997243443009423, -0.999736841165151, -0.9997495926058283, -0.9997625862772768, -0.9997758095997622, -0.9997892497717181, -0.9998028937821665, -0.9998167284233355, -0.9998307403034709, -0.999844915859819, -0.9998592413717768, -0.9998737029741915, -0.9998882866707967, -0.9999029783477759, -0.9999177637874352, -0.9999326286819769, -0.999947558647353, -0.9999625392371958, -0.9999775559568042, -0.9999925942771707, -1.0000076396490458, -1.0000226775170145, -1.0000376933335768, -1.0000526725732204, -1.0000676007464666, -1.000082463413881, -1.000097246200033, -1.00011193480739, -1.000126515030134, -1.0001409727678878, -1.0001552940393375, -1.0001694649957353, -1.0001834719342746, -1.0001973013113206, -1.0002109397554833, -1.000224374080527, -1.0002375912980939, -1.0002505786302363, -1.0002633235217453, -1.0002758136522611, -1.0002880369481557, -1.0002999815941753, -1.0003116360448316, -1.0003229890355332, -1.0003340295934424, -1.0003447470480504, -1.0003551310414602, -1.0003651715383661, -1.0003748588357217, -1.0003841835720853, -1.0003931367366383, -1.0004017096778615, -1.0004098941118658, -1.0004176821303696, -1.000425066208311, -1.0004320392110915, -1.0004385944014444, -1.0004447254459197, -1.0004504264209766, -1.0004556918186878, -1.0004605165520362, -1.0004648959598104, -1.00046882581109, -1.0004723023093167, -1.0004753220959448, -1.0004778822536728, -1.0004799803092506, -1.0004816142358572, -1.0004827824550522, -1.0004834838382903], [-1.0019344028664054, -1.0019334689675852, -1.0019306681693905, -1.0019260031657735, -1.0019194784438241, -1.0019111002795296, -1.0019008767318422, -1.0018888176350618, -1.0018749345895364, -1.0018592409506948, -1.001841751816415, -1.001822484012745, -1.0018014560779824, -1.001778688245134, -1.001754202422763, -1.0017280221742488, -1.0017001726954713, -1.0016706807909412, -1.0016395748484008, -1.0016068848119142, -1.0015726421534699, -1.0015368798431248, -1.001499632317715, -1.0014609354481598, -1.0014208265053872, -1.0013793441249188, -1.001336528270134, -1.0012924201942581, -1.0012470624010998, -1.001200498604582, -1.0011527736870913, -1.001103933656698, -1.0010540256032716, -1.0010030976535438, -1.00095119892515, -1.0008983794797002, -1.0008446902749146, -1.000790183115876, -1.0007349106054357, -1.0006789260938245, -1.0006222836275158, -1.0005650378973838, -1.0005072441862102, -1.0004489583155847, -1.0003902365922523, -1.0003311357539575, -1.0002717129148313, -1.0002120255103826, -1.0001521312421366, -1.0000920880219788, -1.0000319539162548, -0.9999717870896841, -0.9999116457491323, -0.9998515880873076, -0.9997916722264277, -0.9997319561619146, -0.999672497706172, -0.9996133544325008, -0.9995545836192044, -0.9994962421939436, -0.9994383866783915, -0.999381073133244, -0.9993243571036429, -0.9992682935650614, -0.9992129368697094, -0.9991583406935104, -0.9991045579837022, -0.9990516409071173, -0.998999640799189, -0.9989486081137423, -0.9988985923736127, -0.9988496421221478, -0.9988018048756399, -0.998755127076736, -0.9987096540488756, -0.9986654299518002, -0.9986224977381825, -0.9985808991114171, -0.998540674484618, -0.9985018629408662, -0.9984645021947437, -0.9984286285551993, -0.9983942768897826, -0.9983614805902787, -0.9983302715397906, -0.998300680081288, -0.9982727349876717, -0.9982464634333712, -0.9982218909675131, -0.9981990414886867, -0.9981779372213314, -0.9981585986937724, -0.998141044717928, -0.9981252923707079, -0.9981113569771244, -0.9980992520951336, -0.9980889895022197, -0.9980805791837425, -0.9980740293230544, -0.9980693462934015, -0.9980665346516133, -0.9980655971335944, -0.9980665346516134, -0.9980693462934014, -0.9980740293230546, -0.9980805791837424, -0.9980889895022197, -0.9980992520951337, -0.9981113569771245, -0.998125292370708, -0.998141044717928, -0.9981585986937724, -0.9981779372213314, -0.9981990414886868, -0.9982218909675133, -0.9982464634333712, -0.9982727349876719, -0.998300680081288, -0.9983302715397906, -0.9983614805902788, -0.9983942768897827, -0.9984286285551995, -0.9984645021947437, -0.9985018629408662, -0.9985406744846181, -0.998580899111417, -0.9986224977381826, -0.9986654299518003, -0.9987096540488756, -0.9987551270767359, -0.9988018048756397, -0.9988496421221479, -0.9988985923736128, -0.9989486081137424, -0.9989996407991891, -0.9990516409071172, -0.9991045579837022, -0.9991583406935105, -0.9992129368697095, -0.9992682935650613, -0.999324357103643, -0.9993810731332439, -0.9994383866783915, -0.9994962421939436, -0.9995545836192044, -0.9996133544325008, -0.999672497706172, -0.9997319561619146, -0.9997916722264278, -0.9998515880873076, -0.9999116457491322, -0.9999717870896841, -1.000031953916255, -1.0000920880219788, -1.0001521312421366, -1.0002120255103828, -1.0002717129148315, -1.0003311357539575, -1.0003902365922523, -1.0004489583155844, -1.0005072441862102, -1.000565037897384, -1.000622283627516, -1.0006789260938247, -1.0007349106054357, -1.0007901831158763, -1.0008446902749148, -1.0008983794797002, -1.00095119892515, -1.001003097653544, -1.0010540256032718, -1.001103933656698, -1.0011527736870915, -1.001200498604582, -1.0012470624011, -1.001292420194258, -1.0013365282701343, -1.001379344124919, -1.0014208265053874, -1.0014609354481596, -1.0014996323177152, -1.0015368798431248, -1.00157264215347, -1.0016068848119142, -1.001639574848401, -1.001670680790941, -1.0017001726954713, -1.001728022174249, -1.0017542024227628, -1.001778688245134, -1.0018014560779824, -1.001822484012745, -1.001841751816415, -1.0018592409506948, -1.0018749345895366, -1.0018888176350618, -1.0019008767318425, -1.0019111002795293, -1.001919478443824, -1.0019260031657735, -1.0019306681693905, -1.0019334689675852], [-1.0043506520309813, -1.0043485566575978, -1.0043422725383706, -1.0043318056742343, -1.004317166060629, -1.0042983676783248, -1.004275428480593, -1.0042483703767222, -1.0042172192118999, -1.0041820047434729, -1.0041427606136046, -1.0040995243183488, -1.0040523371731662, -1.0040012442749104, -1.00394629446031, -1.00388754026098, -1.003825037855003, -1.003758847015108, -1.0036890310534956, -1.0036156567633503, -1.0035387943570864, -1.0034585174013742, -1.0033749027490022, -1.003288030467628, -1.0031979837654716, -1.0031048489140209, -1.0030087151677975, -1.0029096746812625, -1.0028078224229209, -1.0027032560867002, -1.0025960760006731, -1.0024863850332033, -1.0023742884965907, -1.0022598940482994, -1.0021433115898482, -1.0020246531634553, -1.00190403284652, -1.0017815666440375, -1.0016573723790354, -1.0015315695811313, -1.0014042793733064, -1.0012756243570002, -1.0011457284956204, -1.00101471699658, -1.0008827161919647, -1.0007498534179382, -1.0006162568929975, -1.0004820555951888, -1.0003473791383968, -1.0002123576478268, -1.0000771216347908, -0.9999418018709196, -0.9998065292619194, -0.9996714347209935, -0.9995366490420523, -0.9994023027728302, -0.9992685260880401, -0.9991354486626847, -0.99900319954565, -0.998871907033711, -0.9987416985460698, -0.998612700499557, -0.9984850381846213, -0.998358835642233, -0.9982342155418271, -0.9981112990604146, -0.9979902057629857, -0.9978710534843277, -0.9977539582123846, -0.9976390339732815, -0.997526392718132, -0.9974161442117535, -0.9973083959234067, -0.9972032529196787, -0.9971008177596252, -0.997001190392285, -0.9969044680566781, -0.9968107451844015, -0.9967201133049225, -0.9966326609536833, -0.9965484735831095, -0.9964676334766295, -0.9963902196657984, -0.9963163078506165, -0.9962459703231379, -0.99617927589445, -0.996116289825113, -0.9960570737591306, -0.9960016856615358, -0.9959501797596564, -0.9959026064881321, -0.9958590124377437, -0.9958194403081156, -0.9957839288643436, -0.995752512897601, -0.9957252231897666, -0.9957020864821172, -0.9956831254481202, -0.9956683586703563, -0.9956578006216044, -0.9956514616501044, -0.9956493479690186, -0.9956514616501045, -0.9956578006216046, -0.9956683586703563, -0.9956831254481201, -0.9957020864821174, -0.9957252231897665, -0.9957525128976011, -0.9957839288643436, -0.9958194403081159, -0.9958590124377438, -0.9959026064881321, -0.9959501797596564, -0.996001685661536, -0.9960570737591308, -0.996116289825113, -0.9961792758944502, -0.9962459703231381, -0.9963163078506168, -0.9963902196657987, -0.9964676334766296, -0.9965484735831095, -0.9966326609536834, -0.9967201133049226, -0.9968107451844014, -0.9969044680566782, -0.997001190392285, -0.9971008177596256, -0.9972032529196788, -0.9973083959234067, -0.9974161442117537, -0.9975263927181323, -0.9976390339732818, -0.9977539582123847, -0.9978710534843277, -0.9979902057629859, -0.9981112990604146, -0.9982342155418272, -0.9983588356422332, -0.9984850381846216, -0.9986127004995571, -0.9987416985460696, -0.9988719070337111, -0.9990031995456502, -0.9991354486626849, -0.9992685260880404, -0.9994023027728303, -0.9995366490420524, -0.9996714347209937, -0.9998065292619195, -0.9999418018709196, -1.000077121634791, -1.000212357647827, -1.000347379138397, -1.000482055595189, -1.000616256892998, -1.0007498534179384, -1.000882716191965, -1.0010147169965802, -1.0011457284956204, -1.0012756243570005, -1.0014042793733067, -1.0015315695811313, -1.0016573723790356, -1.001781566644038, -1.00190403284652, -1.0020246531634551, -1.0021433115898484, -1.0022598940482994, -1.002374288496591, -1.0024863850332033, -1.0025960760006731, -1.0027032560867002, -1.002807822422921, -1.0029096746812625, -1.0030087151677978, -1.0031048489140213, -1.0031979837654719, -1.0032880304676277, -1.0033749027490024, -1.0034585174013742, -1.0035387943570866, -1.0036156567633503, -1.0036890310534956, -1.003758847015108, -1.003825037855003, -1.0038875402609801, -1.0039462944603097, -1.0040012442749107, -1.0040523371731662, -1.0040995243183486, -1.0041427606136046, -1.004182004743473, -1.0042172192118999, -1.0042483703767222, -1.0042754284805933, -1.004298367678325, -1.0043171660606287, -1.004331805674234, -1.0043422725383704, -1.0043485566575978], [-1.0077301276367234, -1.007726417113038, -1.0077152890497447, -1.0076967539670463, -1.0076708293883312, -1.0076375398247532, -1.0075969167536605, -1.0075489985908808, -1.0074938306568808, -1.007431465136828, -1.0073619610345645, -1.0072853841205378, -1.007201806873709, -1.007111308417478, -1.0070139744496684, -1.0069098971666117, -1.0067991751813805, -1.006681913436224, -1.006558223109261, -1.0064282215154872, -1.0062920320021675, -1.006149783838677, -1.0060016121008633, -1.0058476575500104, -1.005688066506485, -1.0055229907181462, -1.0053525872236155, -1.0051770182104978, -1.0049964508686524, -1.0048110572386224, -1.0046210140553218, -1.0044265025871055, -1.0042277084703277, -1.0040248215395209, -1.0038180356533146, -1.0036075485162321, -1.0033935614964984, -1.0031762794399997, -1.0029559104805434, -1.0027326658465676, -1.0025067596644552, -1.0022784087586125, -1.002047832448481, -1.0018152523426433, -1.0015808921302078, -1.0013449773696412, -1.001107735275237, -1.0008693945014056, -1.0006301849249757, -1.0003903374257082, -1.0001500836652133, -0.9999096558644818, -0.9996692865802356, -0.9994292084803047, -0.9991896541182508, -0.9989508557074495, -0.9987130448948549, -0.998476452534669, -0.9982413084621402, -0.9980078412677231, -0.9977762780718248, -0.9975468443003739, -0.9973197634614464, -0.9970952569231808, -0.9968735436932208, -0.9966548401999225, -0.9964393600755636, -0.9962273139417936, -0.9960189091975579, -0.9958143498097395, -0.9956138361067485, -0.9954175645752977, -0.9952257276605956, -0.9950385135701892, -0.9948561060816848, -0.994678684354572, -0.9945064227463765, -0.9943394906333591, -0.994178052235975, -0.9940222664493108, -0.9938722866786979, -0.9937282606807096, -0.9935903304097385, -0.9934586318703398, -0.9933332949755297, -0.9932144434112163, -0.9931021945069317, -0.9929966591130316, -0.9928979414845192, -0.9928061391716391, -0.9927213429173872, -0.9926436365620627, -0.992573096954992, -0.9925097938735336, -0.9924537899494735, -0.9924051406029076, -0.9923638939836935, -0.9923300909205531, -0.9923037648778917, -0.992284941920389, -0.9922736406854106, -0.9922698723632766, -0.9922736406854107, -0.992284941920389, -0.9923037648778915, -0.9923300909205532, -0.9923638939836935, -0.9924051406029076, -0.9924537899494738, -0.9925097938735336, -0.9925730969549921, -0.9926436365620629, -0.9927213429173871, -0.992806139171639, -0.9928979414845192, -0.9929966591130317, -0.9931021945069317, -0.9932144434112166, -0.9933332949755298, -0.9934586318703398, -0.9935903304097389, -0.9937282606807099, -0.9938722866786978, -0.9940222664493109, -0.9941780522359751, -0.9943394906333591, -0.9945064227463768, -0.9946786843545723, -0.9948561060816851, -0.9950385135701896, -0.9952257276605958, -0.9954175645752978, -0.9956138361067488, -0.9958143498097398, -0.9960189091975581, -0.9962273139417938, -0.9964393600755638, -0.9966548401999226, -0.9968735436932209, -0.997095256923181, -0.9973197634614467, -0.997546844300374, -0.9977762780718249, -0.9980078412677235, -0.9982413084621404, -0.9984764525346692, -0.9987130448948551, -0.9989508557074496, -0.999189654118251, -0.9994292084803049, -0.9996692865802357, -0.999909655864482, -1.0001500836652135, -1.0003903374257084, -1.0006301849249761, -1.0008693945014058, -1.0011077352752376, -1.0013449773696415, -1.001580892130208, -1.0018152523426436, -1.0020478324484812, -1.0022784087586127, -1.0025067596644552, -1.0027326658465678, -1.0029559104805434, -1.0031762794399999, -1.0033935614964984, -1.0036075485162321, -1.0038180356533148, -1.004024821539521, -1.004227708470328, -1.0044265025871055, -1.004621014055322, -1.0048110572386224, -1.0049964508686529, -1.005177018210498, -1.0053525872236158, -1.0055229907181464, -1.0056880665064851, -1.0058476575500104, -1.0060016121008633, -1.006149783838677, -1.0062920320021678, -1.0064282215154872, -1.006558223109261, -1.0066819134362242, -1.0067991751813803, -1.0069098971666117, -1.0070139744496684, -1.0071113084174783, -1.0072018068737087, -1.007285384120538, -1.0073619610345645, -1.0074314651368281, -1.007493830656881, -1.0075489985908805, -1.0075969167536607, -1.007637539824753, -1.007670829388331, -1.0076967539670463, -1.0077152890497447, -1.0077264171130382], [-1.0120695602592433, -1.0120637916076674, -1.0120464910365605, -1.012017674692309, -1.0119773694706282, -1.0119256129941743, -1.0118624535812175, -1.0117879502053835, -1.0117021724464808, -1.0116052004324372, -1.0114971247723659, -1.0113780464807893, -1.011248076893054, -1.0111073375719715, -1.0109559602057228, -1.0107940864970741, -1.0106218680439518, -1.0104394662114249, -1.010247051995161, -1.0100448058764095, -1.009832917668588, -1.0096115863555366, -1.009381019921523, -1.0091414351730834, -1.008893057552781, -1.0086361209449861, -1.0083708674737726, -1.0080975472930394, -1.0078164183689728, -1.00752774625497, -1.0072318038591461, -1.0069288712045648, -1.0066192351823322, -1.0063031892977012, -1.005981033409343, -1.005653073461953, -1.005319621212358, -1.004980993949309, -1.0046375142071469, -1.0042895094735342, -1.0039373118914652, -1.0035812579557577, -1.003221688204262, -1.0028589469040026, -1.0024933817325081, -1.0021253434545652, -1.0017551855946623, -1.001383264105386, -1.0010099370320458, -1.0006355641738118, -1.0002605067416577, -0.999885127013411, -0.9995097879862208, -0.9991348530267585, -0.9987606855194818, -0.9983876485132949, -0.9980161043669449, -0.9976464143935078, -0.997278938504317, -0.9969140348527016, -0.9965520594778987, -0.9961933659495238, -0.9958383050129729, -0.9954872242361464, -0.9951404676578888, -0.9947983754385327, -0.9944612835129532, -0.9941295232465298, -0.9938034210944222, -0.9934832982645653, -0.9931694703847898, -0.9928622471744777, -0.9925619321211566, -0.992268822162441, -0.9919832073737243, -0.9917053706620197, -0.9914355874663535, -0.991174125465099, -0.9909212442906412, -0.9906771952517575, -0.9904422210640861, -0.9902165555890536, -0.9900004235816209, -0.9897940404471981, -0.9895976120080695, -0.9894113342796595, -0.9892353932569579, -0.9890699647114093, -0.9889152139985623, -0.9887712958767577, -0.9886383543371184, -0.9885165224450928, -0.9884059221937873, -0.988306664369301, -0.9882188484282675, -0.9881425623877867, -0.9880778827279092, -0.9880248743068218, -0.9879835902888645, -0.9879540720854832, -0.9879363493092131, -0.9879304397407567, -0.987936349309213, -0.9879540720854832, -0.9879835902888645, -0.988024874306822, -0.9880778827279091, -0.988142562387787, -0.9882188484282675, -0.9883066643693011, -0.9884059221937874, -0.9885165224450929, -0.9886383543371186, -0.9887712958767577, -0.9889152139985625, -0.9890699647114095, -0.9892353932569581, -0.9894113342796599, -0.9895976120080696, -0.9897940404471983, -0.9900004235816211, -0.9902165555890537, -0.9904422210640863, -0.9906771952517577, -0.9909212442906414, -0.9911741254650993, -0.9914355874663537, -0.9917053706620199, -0.9919832073737246, -0.9922688221624414, -0.9925619321211568, -0.9928622471744778, -0.9931694703847901, -0.9934832982645656, -0.9938034210944224, -0.99412952324653, -0.9944612835129537, -0.994798375438533, -0.9951404676578892, -0.9954872242361468, -0.9958383050129731, -0.9961933659495243, -0.9965520594778992, -0.996914034852702, -0.9972789385043175, -0.9976464143935083, -0.9980161043669451, -0.9983876485132953, -0.9987606855194824, -0.9991348530267588, -0.9995097879862211, -0.9998851270134115, -1.000260506741658, -1.0006355641738123, -1.0010099370320462, -1.0013832641053864, -1.0017551855946627, -1.0021253434545654, -1.0024933817325083, -1.0028589469040028, -1.0032216882042622, -1.0035812579557581, -1.0039373118914654, -1.0042895094735347, -1.004637514207147, -1.0049809939493095, -1.0053196212123583, -1.0056530734619533, -1.0059810334093435, -1.0063031892977017, -1.0066192351823327, -1.006928871204565, -1.0072318038591463, -1.0075277462549703, -1.0078164183689733, -1.0080975472930396, -1.008370867473773, -1.0086361209449868, -1.0088930575527812, -1.0091414351730834, -1.0093810199215232, -1.0096115863555368, -1.0098329176685883, -1.0100448058764095, -1.010247051995161, -1.0104394662114249, -1.0106218680439518, -1.0107940864970741, -1.0109559602057225, -1.0111073375719717, -1.011248076893054, -1.0113780464807893, -1.0114971247723659, -1.0116052004324374, -1.011702172446481, -1.0117879502053837, -1.011862453581218, -1.0119256129941743, -1.011977369470628, -1.012017674692309, -1.0120464910365605, -1.0120637916076674], [-1.0173647517777364, -1.0173564954743815, -1.0173317341499521, -1.0172904905554738, -1.017232802589718, -1.017158723269795, -1.0170683206899969, -1.0169616779688861, -1.016838893184642, -1.0167000792986798, -1.0165453640675448, -1.016374889943106, -1.0161888139610575, -1.015987307617753, -1.0157705567353934, -1.0155387613155924, -1.0152921353813495, -1.0150309068074646, -1.0147553171394266, -1.0144656214008212, -1.0141620878892996, -1.01384499796116, -1.0135146458045958, -1.0131713382016774, -1.0128153942791247, -1.0124471452479562, -1.0120669341320851, -1.01167511548596, -1.0112720551013392, -1.0108581297033072, -1.0104337266356478, -1.009999243535693, -1.0095550879987831, -1.0091016772324823, -1.0086394377006986, -1.0081688047578787, -1.0076902222734514, -1.0072041422467084, -1.006711024412326, -1.0062113358367415, -1.0057055505056103, -1.005194148902591, -1.0046776175797123, -1.0041564487195884, -1.0036311396897812, -1.0031021925895982, -1.0025701137896532, -1.0020354134645169, -1.0014986051188133, -1.0009602051071214, -1.0004207321480718, -0.9998807068330302, -0.9993406511297905, -0.9988010878817043, -0.9982625403026995, -0.9977255314686531, -0.9971905838055957, -0.9966582185752523, -0.996128955358426, -0.9956033115367577, -0.9950818017734018, -0.9945649374931794, -0.994053226362776, -0.9935471717715716, -0.9930472723136985, -0.9925540212719338, -0.9920679061040502, -0.9915894079322465, -0.9911190010363011, -0.9906571523510913, -0.9902043209691282, -0.9897609576487653, -0.9893275043287415, -0.9889043936497189, -0.9884920484834837, -0.9880908814704678, -0.9877012945662611, -0.9873236785977663, -0.9869584128296525, -0.9866058645417575, -0.9862663886180753, -0.985940327147957, -0.98562800904015, -0.9853297496502714, -0.9850458504223146, -0.9847765985447582, -0.9845222666218356, -0.9842831123605003, -0.984059378273605, -0.9838512913997847, -0.9836590630405152, -0.9834828885147863, -0.9833229469318119, -0.9831794009821588, -0.9830523967476568, -0.982942063530417, -0.9828485137012549, -0.9827718425677819, -0.9827121282623962, -0.9826694316503672, -0.9826437962581811, -0.9826352482222636, -0.982643796258181, -0.9826694316503675, -0.9827121282623962, -0.982771842567782, -0.982848513701255, -0.982942063530417, -0.983052396747657, -0.983179400982159, -0.983322946931812, -0.9834828885147864, -0.9836590630405152, -0.9838512913997849, -0.9840593782736051, -0.9842831123605007, -0.9845222666218358, -0.9847765985447587, -0.985045850422315, -0.9853297496502716, -0.9856280090401504, -0.9859403271479575, -0.9862663886180756, -0.9866058645417579, -0.9869584128296527, -0.9873236785977667, -0.9877012945662615, -0.9880908814704682, -0.988492048483484, -0.9889043936497195, -0.9893275043287418, -0.9897609576487658, -0.9902043209691287, -0.9906571523510918, -0.9911190010363017, -0.9915894079322468, -0.9920679061040507, -0.9925540212719344, -0.9930472723136989, -0.9935471717715723, -0.9940532263627767, -0.9945649374931801, -0.9950818017734023, -0.9956033115367582, -0.9961289553584265, -0.9966582185752529, -0.9971905838055961, -0.9977255314686535, -0.9982625403027002, -0.9988010878817047, -0.9993406511297911, -0.9998807068330309, -1.0004207321480723, -1.0009602051071218, -1.0014986051188137, -1.0020354134645175, -1.0025701137896537, -1.0031021925895989, -1.0036311396897817, -1.0041564487195889, -1.0046776175797125, -1.0051941489025915, -1.0057055505056107, -1.006211335836742, -1.0067110244123265, -1.0072041422467088, -1.0076902222734518, -1.0081688047578792, -1.008639437700699, -1.0091016772324828, -1.0095550879987838, -1.0099992435356935, -1.0104337266356485, -1.0108581297033077, -1.0112720551013397, -1.0116751154859605, -1.0120669341320858, -1.0124471452479566, -1.0128153942791251, -1.0131713382016776, -1.0135146458045963, -1.0138449979611601, -1.0141620878893, -1.0144656214008216, -1.0147553171394266, -1.0150309068074646, -1.0152921353813498, -1.0155387613155926, -1.0157705567353938, -1.0159873076177532, -1.0161888139610573, -1.0163748899431062, -1.016545364067545, -1.0167000792986798, -1.0168388931846422, -1.0169616779688861, -1.017068320689997, -1.0171587232697947, -1.0172328025897175, -1.0172904905554738, -1.0173317341499521, -1.0173564954743817], [-1.0236105794363932, -1.0235994219534166, -1.0235659595693036, -1.0235102224713504, -1.0234322609478697, -1.023332145352418, -1.0232099660537055, -1.0230658333711784, -1.0228998774962654, -1.022712248399279, -1.0225031157219524, -1.0222726686556023, -1.022021115804897, -1.0217486850372166, -1.0214556233175804, -1.0211421965291365, -1.0208086892791806, -1.0204554046906995, -1.020082664179419, -1.01969080721634, -1.0192801910757576, -1.0188511905687496, -1.0184041977621339, -1.0179396216828884, -1.0174578880080474, -1.0169594387400764, -1.0164447318677454, -1.0159142410125261, -1.0153684550605444, -1.0148078777801304, -1.0142330274250138, -1.0136444363232346, -1.013042650451835, -1.0124282289974231, -1.011801743902708, -1.011163779399123, -1.010514931525665, -1.0098558076340975, -1.0091870258806834, -1.008509214704632, -1.0078230122934568, -1.0071290660354797, -1.0064280319597116, -1.0057205741633901, -1.0050073642274573, -1.0042890806202949, -1.0035664080900593, -1.0028400370459776, -1.0021106629290026, -1.0013789855722433, -1.0006457085516194, -0.9999115385272196, -0.9991771845758634, -0.9984433575154067, -0.9977107692213539, -0.9969801319363691, -0.9962521575733155, -0.9955275570124731, -0.9948070393936226, -0.9940913114037087, -0.9933810765608262, -0.9926770344953015, -0.9919798802286721, -0.9912903034513877, -0.9906089878000949, -0.9899366101353786, -0.9892738398208685, -0.9886213380046391, -0.9879797569038474, -0.987349739093582, -0.9867319168009089, -0.9861269112051123, -0.9855353317451548, -0.984957775435377, -0.9843948261904809, -0.983847054160834, -0.9833150150791518, -0.9827992496195994, -0.9823002827703666, -0.98181862322076, -0.9813547627638464, -0.9809091757156781, -0.9804823183521123, -0.9800746283642193, -0.9796865243332606, -0.9793184052261886, -0.978970649912598, -0.9786436167040264, -0.9783376429164745, -0.9780530444569746, -0.9777901154350037, -0.9775491277994902, -0.9773303310021315, -0.9771339516876738, -0.9769601934117788, -0.9768092363870331, -0.9766812372576132, -0.9765763289030596, -0.9764946202715563, -0.9764361962430593, -0.9764011175225454, -0.9763894205636069, -0.9764011175225455, -0.9764361962430594, -0.9764946202715565, -0.9765763289030596, -0.9766812372576136, -0.9768092363870333, -0.9769601934117789, -0.977133951687674, -0.9773303310021317, -0.9775491277994904, -0.9777901154350038, -0.9780530444569749, -0.9783376429164747, -0.9786436167040266, -0.9789706499125984, -0.9793184052261893, -0.9796865243332611, -0.9800746283642198, -0.9804823183521127, -0.9809091757156785, -0.9813547627638467, -0.9818186232207606, -0.9823002827703672, -0.9827992496195999, -0.9833150150791522, -0.9838470541608346, -0.9843948261904814, -0.9849577754353778, -0.9855353317451554, -0.9861269112051129, -0.9867319168009094, -0.9873497390935828, -0.9879797569038479, -0.9886213380046397, -0.9892738398208691, -0.9899366101353793, -0.9906089878000955, -0.9912903034513882, -0.9919798802286728, -0.9926770344953025, -0.993381076560827, -0.9940913114037093, -0.9948070393936234, -0.9955275570124738, -0.9962521575733162, -0.9969801319363699, -0.9977107692213546, -0.9984433575154076, -0.9991771845758639, -0.9999115385272203, -1.00064570855162, -1.001378985572244, -1.0021106629290033, -1.0028400370459785, -1.0035664080900601, -1.0042890806202958, -1.0050073642274582, -1.0057205741633908, -1.0064280319597123, -1.0071290660354806, -1.0078230122934575, -1.0085092147046326, -1.0091870258806843, -1.0098558076340982, -1.0105149315256656, -1.0111637793991235, -1.0118017439027085, -1.0124282289974238, -1.013042650451836, -1.0136444363232353, -1.0142330274250142, -1.0148078777801306, -1.015368455060545, -1.0159142410125266, -1.016444731867746, -1.016959438740077, -1.017457888008048, -1.0179396216828887, -1.018404197762134, -1.0188511905687503, -1.019280191075758, -1.0196908072163404, -1.0200826641794194, -1.0204554046907, -1.0208086892791808, -1.0211421965291367, -1.0214556233175807, -1.0217486850372168, -1.0220211158048975, -1.0222726686556025, -1.0225031157219526, -1.0227122483992792, -1.0228998774962659, -1.0230658333711786, -1.0232099660537062, -1.023332145352418, -1.0234322609478694, -1.0235102224713504, -1.023565959569304, -1.023599421953417], [-1.030801000800334, -1.0307865469009319, -1.0307431979705217, -1.0306709923043307, -1.0305699937005346, -1.0304402914194308, -1.0302820001262583, -1.0300952598176234, -1.029880235731498, -1.0296371182407422, -1.0293661227300959, -1.029067489456578, -1.0287414833932258, -1.0283883940560907, -1.0280085353144177, -1.0276022451839142, -1.0271698856030167, -1.0267118421920525, -1.026228523995207, -1.0257203632051743, -1.0251878148704001, -1.024631356584795, -1.0240514881598208, -1.0234487312788276, -1.0228236291335502, -1.0221767460426436, -1.0215086670521676, -1.0208199975179193, -1.0201113626695255, -1.0193834071562131, -1.0186367945741825, -1.0178722069755222, -1.0170903443586163, -1.0162919241400052, -1.015477680607673, -1.014648364355767, -1.0138047417007516, -1.0129475940790351, -1.012077717426123, -1.0111959215373776, -1.0103030294104853, -1.009399876569768, -1.0084873103724956, -1.0075661892973904, -1.006637382215555, -1.0057017676440747, -1.004760232982597, -1.00381367373322, -1.0028629927040609, -1.0019090991969297, -1.000952908179557, -0.9999953394428852, -0.9990373167439743, -0.9980797669351175, -0.9971236190798111, -0.9961698035562815, -0.9952192511493068, -0.9942728921311383, -0.9933316553323661, -0.9923964672036341, -0.9914682508691544, -0.9905479251730327, -0.9896364037194556, -0.9887345939078556, -0.9878433959642071, -0.9869637019696699, -0.9860963948878273, -0.985242347591832, -0.9844024218927996, -0.9835774675708439, -0.9827683214101804, -0.981975806239766, -0.9812007299809726, -0.9804438847038248, -0.9797060456933595, -0.9789879705276809, -0.9782903981693147, -0.9776140480714653, -0.9769596193007988, -0.9763277896783744, -0.9757192149403464, -0.9751345279200496, -0.9745743377530772, -0.9740392291069303, -0.9735297614368067, -0.9730464682690597, -0.9725898565138247, -0.9721604058082749, -0.9717585678919116, -0.9713847660152536, -0.9710393943832245, -0.9707228176344745, -0.9704353703578121, -0.970177356646834, -0.96994904969378, -0.9697506914235436, -0.9695824921686877, -0.9694446303862251, -0.9693372524168307, -0.9692604722870456, -0.9692143715549503, -0.9691989991996659, -0.9692143715549504, -0.9692604722870456, -0.9693372524168307, -0.9694446303862253, -0.9695824921686877, -0.969750691423544, -0.9699490496937804, -0.9701773566468342, -0.9704353703578125, -0.9707228176344751, -0.9710393943832248, -0.971384766015254, -0.971758567891912, -0.9721604058082753, -0.9725898565138252, -0.9730464682690602, -0.9735297614368074, -0.9740392291069307, -0.9745743377530778, -0.9751345279200503, -0.975719214940347, -0.976327789678375, -0.9769596193007994, -0.9776140480714659, -0.9782903981693154, -0.9789879705276818, -0.9797060456933603, -0.9804438847038257, -0.9812007299809733, -0.9819758062397668, -0.9827683214101812, -0.9835774675708447, -0.9844024218928006, -0.9852423475918329, -0.9860963948878284, -0.9869637019696708, -0.9878433959642081, -0.9887345939078563, -0.9896364037194564, -0.9905479251730336, -0.9914682508691552, -0.9923964672036348, -0.9933316553323672, -0.9942728921311395, -0.9952192511493076, -0.9961698035562824, -0.997123619079812, -0.9980797669351184, -0.9990373167439753, -0.9999953394428861, -1.0009529081795578, -1.0019090991969308, -1.002862992704062, -1.0038136737332208, -1.0047602329825984, -1.0057017676440754, -1.0066373822155559, -1.0075661892973913, -1.0084873103724965, -1.009399876569769, -1.0103030294104862, -1.0111959215373785, -1.0120777174261242, -1.0129475940790362, -1.0138047417007527, -1.0146483643557678, -1.015477680607674, -1.0162919241400061, -1.0170903443586174, -1.0178722069755228, -1.018636794574183, -1.019383407156214, -1.0201113626695264, -1.02081999751792, -1.0215086670521683, -1.0221767460426445, -1.0228236291335508, -1.0234487312788283, -1.0240514881598213, -1.0246313565847958, -1.0251878148704006, -1.0257203632051748, -1.0262285239952071, -1.026711842192053, -1.0271698856030167, -1.0276022451839146, -1.028008535314418, -1.0283883940560912, -1.0287414833932262, -1.0290674894565786, -1.029366122730096, -1.0296371182407424, -1.0298802357314982, -1.0300952598176234, -1.0302820001262585, -1.0304402914194308, -1.0305699937005346, -1.0306709923043307, -1.0307431979705215, -1.030786546900932], [-1.038929059601276, -1.0389109343601213, -1.03885657427531, -1.0387660262540137, -1.0386393684455644, -1.0384767101974919, -1.0382781919939172, -1.0380439853762418, -1.037774292846051, -1.0374693477501453, -1.0371294141475857, -1.0367547866586264, -1.0363457902953952, -1.0359027802741658, -1.0354261418090485, -1.0349162898869162, -1.0343736690233678, -1.033798752999516, -1.033192044579379, -1.0325540752076412, -1.0318854046875439, -1.031186620838644, -1.0304583391341935, -1.0297012023178638, -1.0289158799995475, -1.0281030682299626, -1.0272634890537784, -1.0263978900409911, -1.0255070437962621, -1.0245917474459574, -1.023652822102605, -1.0226911123065203, -1.0217074854443347, -1.0207028311441924, -1.0196780606473828, -1.0186341061561945, -1.0175719201577988, -1.0164924747239876, -1.0153967607866141, -1.014285787388618, -1.013160580910536, -1.0120221842724422, -1.010871656111292, -1.0097100699336785, -1.008538513244068, -1.0073580866486058, -1.0061699029346483, -1.0049750861262219, -1.0037747705156665, -1.0025700996717766, -1.001362225424821, -1.0001523068288793, -0.9989415091020104, -0.9977310025448236, -0.9965219614381162, -0.9953155629203024, -0.994112985845441, -0.9929154096227549, -0.9917240130386096, -0.9905399730620124, -0.9893644636347684, -0.9881986544475273, -0.9870437097030352, -0.9859007868679939, -0.9847710354150255, -0.983655595556315, -0.9825555969705985, -0.9814721575252509, -0.9804063819952973, -0.9793593607812675, -0.97833216862788, -0.9773258633456146, -0.9763414845373097, -0.9753800523319766, -0.9744425661280812, -0.9735300033486055, -0.9726433182102346, -0.971783440509065, -0.9709512744252538, -0.9701476973490573, -0.9693735587307183, -0.9686296789566702, -0.9679168482545238, -0.9672358256292833, -0.9665873378332268, -0.9659720783718414, -0.9653907065481722, -0.9648438465478791, -0.9643320865672428, -0.9638559779862816, -0.9634160345890581, -0.9630127318331594, -0.9626465061702385, -0.9623177544193801, -0.9620268331949416, -0.9617740583903902, -0.9615597047195117, -0.9613840053162309, -0.9612471513941276, -0.9611492919665738, -0.9610905336282627, -0.9610709403987242, -0.9610905336282627, -0.961149291966574, -0.9612471513941279, -0.9613840053162311, -0.9615597047195119, -0.9617740583903905, -0.9620268331949419, -0.9623177544193804, -0.962646506170239, -0.9630127318331596, -0.9634160345890584, -0.9638559779862822, -0.9643320865672433, -0.9648438465478796, -0.9653907065481729, -0.9659720783718422, -0.9665873378332275, -0.967235825629284, -0.9679168482545246, -0.9686296789566711, -0.969373558730719, -0.970147697349058, -0.9709512744252545, -0.9717834405090657, -0.9726433182102355, -0.9735300033486065, -0.9744425661280822, -0.9753800523319776, -0.9763414845373108, -0.9773258633456156, -0.9783321686278811, -0.9793593607812686, -0.9804063819952982, -0.9814721575252519, -0.9825555969705996, -0.983655595556316, -0.9847710354150269, -0.9859007868679951, -0.9870437097030363, -0.9881986544475286, -0.9893644636347695, -0.9905399730620136, -0.9917240130386107, -0.9929154096227559, -0.9941129858454422, -0.9953155629203037, -0.9965219614381176, -0.9977310025448247, -0.9989415091020116, -1.0001523068288805, -1.0013622254248218, -1.0025700996717777, -1.0037747705156679, -1.0049750861262234, -1.0061699029346494, -1.007358086648607, -1.0085385132440692, -1.0097100699336796, -1.0108716561112931, -1.0120221842724435, -1.013160580910537, -1.014285787388619, -1.0153967607866152, -1.0164924747239887, -1.0175719201577997, -1.0186341061561954, -1.0196780606473836, -1.0207028311441935, -1.0217074854443358, -1.0226911123065212, -1.0236528221026062, -1.0245917474459583, -1.0255070437962632, -1.026397890040992, -1.0272634890537795, -1.0281030682299632, -1.0289158799995484, -1.0297012023178644, -1.0304583391341942, -1.0311866208386447, -1.0318854046875445, -1.0325540752076419, -1.0331920445793794, -1.0337987529995165, -1.0343736690233685, -1.0349162898869169, -1.0354261418090487, -1.0359027802741665, -1.0363457902953956, -1.0367547866586269, -1.0371294141475862, -1.0374693477501458, -1.0377742928460514, -1.038043985376242, -1.0382781919939175, -1.0384767101974917, -1.0386393684455641, -1.0387660262540137, -1.0388565742753102, -1.0389109343601217], [-1.0479868924672706, -1.0479647429965993, -1.0478983132053077, -1.0477876589466302, -1.0476328732795106, -1.0474340864238818, -1.047191465697963, -1.046905215437481, -1.046575576896684, -1.046202828131013, -1.0457872838612428, -1.0453292953188975, -1.0448292500727097, -1.0442875718358728, -1.0437047202538057, -1.0430811906721287, -1.0424175138845246, -1.041714255860134, -1.0409720174501125, -1.0401914340729599, -1.0393731753782038, -1.0385179448880029, -1.0376264796162245, -1.0366995496645197, -1.03573795779492, -1.034742538978446, -1.0337141599192299, -1.0326537185536209, -1.0315621435237452, -1.0304403936249915, -1.0292894572268676, -1.0281103516666998, -1.0269041226156266, -1.025671843416348, -1.024414614392108, -1.0231335621263797, -1.0218298387127562, -1.0205046209745523, -1.0191591096536496, -1.0177945285681456, -1.0164121237383896, -1.0150131624810277, -1.0135989324707169, -1.0121707407692069, -1.0107299128215481, -1.0092777914192197, -1.0078157356300497, -1.0063451196948507, -1.0048673318907662, -1.0033837733614042, -1.0018958569139063, -1.000405005783197, -0.9989126523637387, -0.9974202369092284, -0.9959292062007649, -0.994441012184127, -0.992957110576923, -0.9914789594464803, -0.9900080177594746, -0.988545743904425, -0.9870935941883081, -0.9856530213086885, -0.9842254728028917, -0.9828123894758906, -0.9814152038087217, -0.9800353383493842, -0.9786742040883242, -0.9773331988207493, -0.9760137054981554, -0.9747170905715975, -0.9734447023293641, -0.9721978692318503, -0.9709778982465573, -0.9697860731862595, -0.9686236530535011, -0.9674918703946872, -0.966391929667135, -0.9653250056225305, -0.9642922417103188, -0.9632947485046158, -0.962333602158279, -0.9614098428878078, -0.9605244734927729, -0.9596784579134685, -0.9588727198304776, -0.9581081413098089, -0.9573855614972185, -0.9567057753652665, -0.9560695325165773, -0.9554775360466772, -0.9549304414696537, -0.9544288557097667, -0.9539733361619709, -0.9535643898241503, -0.9532024725036818, -0.9528879881007433, -0.9526212879705657, -0.952402670366609, -0.9522323799663981, -0.9521106074815056, -0.9520374893529151, -0.9520131075327295, -0.9520374893529151, -0.9521106074815057, -0.9522323799663983, -0.9524026703666093, -0.9526212879705658, -0.9528879881007437, -0.9532024725036822, -0.9535643898241507, -0.9539733361619714, -0.9544288557097672, -0.9549304414696541, -0.9554775360466776, -0.9560695325165781, -0.9567057753652671, -0.9573855614972192, -0.9581081413098098, -0.9588727198304785, -0.9596784579134693, -0.9605244734927739, -0.9614098428878088, -0.96233360215828, -0.9632947485046168, -0.9642922417103197, -0.9653250056225315, -0.9663919296671362, -0.9674918703946885, -0.9686236530535022, -0.9697860731862608, -0.9709778982465584, -0.9721978692318515, -0.9734447023293654, -0.9747170905715989, -0.9760137054981568, -0.9773331988207506, -0.9786742040883257, -0.9800353383493855, -0.9814152038087232, -0.9828123894758919, -0.9842254728028931, -0.9856530213086899, -0.9870935941883094, -0.9885457439044263, -0.9900080177594761, -0.9914789594464817, -0.9929571105769243, -0.9944410121841284, -0.9959292062007665, -0.99742023690923, -0.9989126523637402, -1.0004050057831986, -1.001895856913908, -1.0033837733614057, -1.0048673318907677, -1.0063451196948523, -1.0078157356300514, -1.009277791419221, -1.0107299128215494, -1.0121707407692084, -1.0135989324707182, -1.0150131624810292, -1.016412123738391, -1.0177945285681471, -1.019159109653651, -1.0205046209745539, -1.0218298387127578, -1.0231335621263808, -1.0244146143921091, -1.0256718434163494, -1.0269041226156277, -1.0281103516667012, -1.0292894572268687, -1.0304403936249926, -1.0315621435237465, -1.0326537185536215, -1.0337141599192312, -1.034742538978447, -1.0357379577949208, -1.0366995496645208, -1.0376264796162251, -1.0385179448880038, -1.0393731753782047, -1.0401914340729608, -1.0409720174501131, -1.0417142558601347, -1.0424175138845253, -1.0430811906721293, -1.0437047202538061, -1.0442875718358735, -1.04482925007271, -1.0453292953188977, -1.0457872838612434, -1.0462028281310134, -1.0465755768966842, -1.046905215437481, -1.0471914656979635, -1.0474340864238818, -1.0476328732795106, -1.0477876589466304, -1.0478983132053081, -1.0479647429965997], [-1.0579657365300115, -1.0579392333990898, -1.0578597456646581, -1.0577273382931753, -1.0575421195336017, -1.0573042408746167, -1.057013896984602, -1.0566713256342428, -1.0562768076015792, -1.0558306665593078, -1.0553332689440744, -1.0547850238074845, -1.0541863826485056, -1.0535378392269001, -1.0528399293573012, -1.0520932306834918, -1.0512983624324235, -1.0504559851474657, -1.0495668004003558, -1.0486315504812593, -1.0476510180663503, -1.0466260258622546, -1.0455574362266917, -1.0444461507646048, -1.0432931098990463, -1.0420992924160524, -1.0408657149827156, -1.0395934316376407, -1.0382835332529396, -1.0369371469669086, -1.0355554355865018, -1.0341395969587093, -1.032690863309925, -1.0312105005523893, -1.0296998075567732, -1.0281601153899806, -1.026592786517238, -1.024999213967548, -1.0233808204615984, -1.0217390575012286, -1.0200754044195837, -1.0183913673911036, -1.016688478400543, -1.014968294170243, -1.0132323950449376, -1.0114823838334208, -1.00971988460647, -1.0079465414504944, -1.0061640171764492, -1.0043739919836503, -1.0025781620782215, -1.0007782382460098, -0.9989759443799225, -0.9971730159617646, -0.9953711984987903, -0.9935722459153277, -0.9917779188999885, -0.9899899832091388, -0.9882102079274827, -0.986440363686787, -0.9846822208439683, -0.9829375476199668, -0.981208108201024, -0.9794956608042109, -0.9778019557092532, -0.9761287332589409, -0.9744777218306191, -0.972850635781504, -0.9712491733707794, -0.9696750146616823, -0.9681298194069897, -0.9666152249215726, -0.9651328439458788, -0.9636842625044385, -0.9622710377636885, -0.9608946958935989, -0.9595567299377847, -0.9582585976969414, -0.9570017196306038, -0.955787476782365, -0.9546172087338021, -0.9534922115924553, -0.9524137360192796, -0.9513829853010258, -0.9504011134730427, -0.9494692234979699, -0.9485883655057684, -0.947759535100463, -0.946983671738878, -0.9462616571865263, -0.9455943140556509, -0.9449824044302344, -0.944426628582581, -0.9439276237858225, -0.9434859632264305, -0.943102155020525, -0.9427766413374296, -0.9425097976335903, -0.9423019319995939, -0.9421532846226445, -0.9420640273664412, -0.9420342634699886, -0.9420640273664412, -0.9421532846226447, -0.942301931999594, -0.9425097976335904, -0.9427766413374301, -0.9431021550205253, -0.943485963226431, -0.9439276237858231, -0.9444266285825816, -0.944982404430235, -0.9455943140556515, -0.946261657186527, -0.9469836717388788, -0.9477595351004637, -0.9485883655057692, -0.9494692234979709, -0.9504011134730439, -0.9513829853010269, -0.9524137360192808, -0.9534922115924565, -0.9546172087338031, -0.9557874767823662, -0.9570017196306051, -0.9582585976969427, -0.9595567299377861, -0.9608946958936003, -0.9622710377636899, -0.9636842625044401, -0.9651328439458802, -0.9666152249215744, -0.9681298194069914, -0.9696750146616838, -0.9712491733707812, -0.9728506357815054, -0.9744777218306209, -0.9761287332589426, -0.9778019557092551, -0.9794956608042126, -0.9812081082010258, -0.9829375476199684, -0.9846822208439703, -0.9864403636867889, -0.9882102079274846, -0.9899899832091406, -0.9917779188999901, -0.9935722459153294, -0.9953711984987921, -0.9971730159617663, -0.9989759443799242, -1.0007782382460115, -1.0025781620782233, -1.004373991983652, -1.006164017176451, -1.0079465414504964, -1.0097198846064719, -1.0114823838334226, -1.0132323950449393, -1.0149682941702445, -1.0166884784005445, -1.0183913673911054, -1.0200754044195854, -1.0217390575012304, -1.0233808204616, -1.0249992139675497, -1.0265927865172397, -1.028160115389982, -1.0296998075567747, -1.0312105005523908, -1.0326908633099265, -1.0341395969587104, -1.035555435586503, -1.0369371469669098, -1.038283533252941, -1.039593431637642, -1.040865714982717, -1.0420992924160537, -1.0432931098990474, -1.044446150764606, -1.0455574362266926, -1.0466260258622557, -1.0476510180663516, -1.0486315504812604, -1.0495668004003567, -1.0504559851474666, -1.051298362432424, -1.0520932306834927, -1.0528399293573019, -1.053537839226901, -1.0541863826485063, -1.0547850238074854, -1.0553332689440749, -1.0558306665593082, -1.0562768076015798, -1.056671325634243, -1.0570138969846026, -1.0573042408746167, -1.0575421195336014, -1.0577273382931758, -1.0578597456646583, -1.0579392333990902], [-1.0688559379023412, -1.0688247762454626, -1.0687313159731957, -1.0685756311730739, -1.068357845299051, -1.068078131133512, -1.0677367107339235, -1.0673338553639495, -1.066869885408815, -1.0663451702746582, -1.0657601282715488, -1.0651152264798143, -1.0644109805992565, -1.0636479547808053, -1.0628267614400837, -1.0619480610523393, -1.0610125619281214, -1.0600210199690414, -1.0589742384029168, -1.057873067497522, -1.056718404252154, -1.0555111920661329, -1.054252420383344, -1.0529431243118546, -1.0515843842175963, -1.0501773252910673, -1.0487231170859412, -1.0472229730284457, -1.0456781498963104, -1.044089947266061, -1.0424597069273733, -1.040788812263184, -1.0390786875942057, -1.0373307974864672, -1.035546646020469, -1.0337277760205217, -1.0318757682428088, -1.029992240520706, -1.0280788468658772, -1.0261372765236578, -1.024169252981247, -1.0221765329272365, -1.0201609051610148, -1.0181241894506239, -1.0160682353376758, -1.01399492088797, -1.0119061513865324, -1.009803857975841, -1.0076899962360961, -1.0055665447064774, -1.00343550334644, -1.0012988919362174, -0.999158748415834, -0.9970171271620745, -0.9948760972030272, -0.9927377403699913, -0.9906041493867361, -0.9884774258963133, -0.9863596784258416, -0.9842530202899454, -0.982159567433762, -0.980081436216733, -0.9780207411386687, -0.9759795925098784, -0.973960094067491, -0.9719643405403993, -0.9699944151656162, -0.9680523871591753, -0.9661403091450591, -0.964260214546013, -0.9624141149404507, -0.9606039973900354, -0.9588318217428823, -0.957099517917677, -0.9554089831743703, -0.9537620793774343, -0.9521606302580043, -0.9506064186815274, -0.9491011839278314, -0.9476466189907932, -0.94624436790501, -0.9448960231070939, -0.9436031228393659, -0.9423671486038675, -0.9411895226746916, -0.9400716056766876, -0.9390146942385927, -0.9380200187286011, -0.937088741080284, -0.9362219527166356, -0.9354206725798163, -0.9346858452739261, -0.9340183393278378, -0.9334189455847807, -0.9328883757249576, -0.9324272609270511, -0.9320361506739782, -0.9317155117077269, -0.931465727137552, -0.9312870957051983, -0.9311798312102013, -0.9311440620976589, -0.9311798312102013, -0.9312870957051986, -0.9314657271375522, -0.9317155117077273, -0.9320361506739786, -0.9324272609270515, -0.932888375724958, -0.9334189455847813, -0.9340183393278386, -0.9346858452739267, -0.9354206725798172, -0.9362219527166363, -0.9370887410802848, -0.9380200187286021, -0.9390146942385938, -0.9400716056766888, -0.9411895226746929, -0.9423671486038687, -0.9436031228393674, -0.9448960231070954, -0.9462443679050114, -0.9476466189907945, -0.949101183927833, -0.9506064186815288, -0.9521606302580059, -0.9537620793774361, -0.9554089831743721, -0.9570995179176789, -0.9588318217428841, -0.9606039973900372, -0.9624141149404525, -0.964260214546015, -0.966140309145061, -0.9680523871591772, -0.9699944151656184, -0.9719643405404013, -0.9739600940674932, -0.9759795925098803, -0.9780207411386708, -0.9800814362167352, -0.982159567433764, -0.9842530202899474, -0.9863596784258438, -0.9884774258963155, -0.9906041493867384, -0.9927377403699935, -0.9948760972030294, -0.9970171271620767, -0.9991587484158361, -1.0012988919362196, -1.003435503346442, -1.0055665447064794, -1.0076899962360983, -1.009803857975843, -1.0119061513865344, -1.013994920887972, -1.016068235337678, -1.018124189450626, -1.0201609051610165, -1.0221765329272383, -1.0241692529812492, -1.0261372765236596, -1.0280788468658792, -1.029992240520708, -1.0318757682428106, -1.0337277760205237, -1.035546646020471, -1.037330797486469, -1.0390786875942075, -1.0407888122631856, -1.0424597069273749, -1.0440899472660625, -1.045678149896312, -1.0472229730284468, -1.048723117085943, -1.0501773252910689, -1.0515843842175978, -1.0529431243118557, -1.0542524203833454, -1.055511192066134, -1.0567184042521554, -1.0578730674975234, -1.0589742384029177, -1.0600210199690425, -1.061012561928122, -1.0619480610523404, -1.0628267614400844, -1.0636479547808062, -1.0644109805992572, -1.0651152264798147, -1.0657601282715494, -1.0663451702746587, -1.0668698854088157, -1.0673338553639498, -1.0677367107339244, -1.0680781311335121, -1.068357845299051, -1.068575631173074, -1.068731315973196, -1.068824776245463], [-1.0806469610177643, -1.0806108613329068, -1.0805025899699687, -1.08032222999781, -1.0800699198443438, -1.079745853266162, -1.0793502793058074, -1.0788835022365029, -1.0783458814940705, -1.0777378315957384, -1.0770598220454544, -1.0763123772252765, -1.0754960762723524, -1.074611552940935, -1.0736594954488157, -1.07264064630751, -1.0715558021354492, -1.0704058134533774, -1.0691915844610906, -1.067914072794579, -1.0665742892625762, -1.0651732975614436, -1.06371221396726, -1.0621922070038992, -1.0606144970858375, -1.0589803561343225, -1.057291107165509, -1.055548123849059, -1.0537528300356553, -1.0519066992518025, -1.0500112541602113, -1.0480680659840136, -1.0460787538929655, -1.0440449843497541, -1.0419684704144445, -1.0398509710050567, -1.0376942901122026, -1.0355002759656644, -1.0332708201507497, -1.0310078566722238, -1.0287133609635817, -1.0263893488394065, -1.0240378753885373, -1.0216610338057686, -1.0192609541598132, -1.0168398020952658, -1.0143997774663502, -1.0119431129002652, -1.0094720722880115, -1.0069889492006625, -1.0044960652291237, -1.0019957682455587, -0.9994904305847779, -0.996982447144054, -0.9944742334000013, -0.9919682233413618, -0.9894668673167685, -0.9869726297968078, -0.9844879870499829, -0.9820154247324884, -0.9795574353920337, -0.9771165158863148, -0.9746951647171266, -0.9722958792815056, -0.969921153041747, -0.967573472616592, -0.9652553147963704, -0.9629691434853882, -0.9607174065753784, -0.9585025327543689, -0.9563269282558811, -0.9541929735539347, -0.952103020009903, -0.9500593864778384, -0.9480643558754498, -0.9461201717284818, -0.9442290346967855, -0.942393099090903, -0.9406144693884873, -0.9388951967603576, -0.937237275616415, -0.9356426401820463, -0.934113161115983, -0.9326506421808665, -0.9312568169780095, -0.9299333457579929, -0.9286818123188412, -0.9275037210035305, -0.9264004938085216, -0.925373467614873, -0.9244238915532608, -0.9235529245139199, -0.9227616328121342, -0.9220509880194137, -0.921421864969949, -0.9208750399512825, -0.9204111890874259, -0.9200308869218654, -0.919734605207046, -0.9195227119060144, -0.9193954704109407, -0.9193530389822356, -0.9193954704109409, -0.9195227119060146, -0.9197346052070462, -0.9200308869218656, -0.9204111890874263, -0.9208750399512831, -0.9214218649699495, -0.9220509880194144, -0.922761632812135, -0.9235529245139208, -0.9244238915532617, -0.9253734676148739, -0.9264004938085227, -0.9275037210035317, -0.9286818123188425, -0.9299333457579941, -0.931256816978011, -0.9326506421808681, -0.9341131611159846, -0.935642640182048, -0.9372372756164166, -0.9388951967603594, -0.9406144693884891, -0.9423930990909046, -0.9442290346967874, -0.9461201717284838, -0.9480643558754518, -0.9500593864778404, -0.952103020009905, -0.9541929735539367, -0.9563269282558833, -0.9585025327543711, -0.9607174065753806, -0.9629691434853905, -0.9652553147963726, -0.9675734726165943, -0.9699211530417495, -0.9722958792815081, -0.9746951647171291, -0.9771165158863174, -0.9795574353920362, -0.9820154247324911, -0.9844879870499854, -0.9869726297968103, -0.9894668673167709, -0.9919682233413645, -0.994474233400004, -0.9969824471440565, -0.9994904305847805, -1.0019957682455611, -1.0044960652291262, -1.006988949200665, -1.0094720722880142, -1.0119431129002676, -1.014399777466353, -1.0168398020952683, -1.0192609541598157, -1.021661033805771, -1.0240378753885395, -1.026389348839409, -1.028713360963584, -1.031007856672226, -1.0332708201507521, -1.0355002759656666, -1.037694290112205, -1.0398509710050587, -1.0419684704144467, -1.0440449843497561, -1.0460787538929677, -1.0480680659840154, -1.0500112541602131, -1.0519066992518045, -1.0537528300356573, -1.0555481238490605, -1.057291107165511, -1.058980356134324, -1.060614497085839, -1.062192207003901, -1.0637122139672612, -1.0651732975614452, -1.0665742892625776, -1.0679140727945806, -1.069191584461092, -1.0704058134533783, -1.0715558021354503, -1.072640646307511, -1.0736594954488166, -1.074611552940936, -1.0754960762723533, -1.0763123772252772, -1.0770598220454553, -1.0777378315957393, -1.078345881494071, -1.0788835022365035, -1.079350279305808, -1.0797458532661621, -1.0800699198443442, -1.0803222299978097, -1.0805025899699687, -1.0806108613329066], [-1.0933273988229284, -1.0932861074695879, -1.0931622640035266, -1.092955960202624, -1.092667349016663, -1.0922966445471884, -1.0918441220191033, -1.0913101177437647, -1.0906950290733126, -1.089999314345881, -1.0892234928212754, -1.0883681446066438, -1.0874339105715958, -1.086421492252149, -1.085331651742822, -1.0841652115761118, -1.082923054588521, -1.0816061237722265, -1.0802154221113982, -1.078752012402094, -1.077217017054581, -1.0756116178768373, -1.0739370558379095, -1.072194630809703, -1.0703857012856934, -1.0685116840749513, -1.0665740539697752, -1.0645743433851265, -1.062514141967963, -1.0603950961744604, -1.0582189088130107, -1.055987338550779, -1.053702199381499, -1.0513653600520767, -1.0489787434454723, -1.0465443259172245, -1.0440641365828802, -1.0415402565534975, -1.0389748181162861, -1.0363700038573744, -1.0337280457235918, -1.0310512240200904, -1.0283418663405548, -1.0256023464266917, -1.0228350829536468, -1.020042538237954, -1.0172272168646115, -1.0143916642298691, -1.011538464996331, -1.0086702414570086, -1.0057896518050244, -1.0028993883057429, -1.0000021753682165, -0.9971007675129786, -0.994197947233377, -0.9912965227478514, -0.9883993256407944, -0.9855092083899122, -0.9826290417783149, -0.979761712189923, -0.9769101187871779, -0.9740771705704784, -0.9712657833192575, -0.9684788764151419, -0.9657193695482036, -0.962990179307946, -0.9602942156613083, -0.9576343783206948, -0.9550135530057531, -0.9524346076034288, -0.9499003882316018, -0.947413715212476, -0.9449773789627254, -0.9425941358082963, -0.9402667037326338, -0.937997758067995, -0.9357899271403903, -0.9336457878795579, -0.9315678614062158, -0.9295586086096501, -0.927620425729446, -0.9257556399558884, -0.9239665050641924, -0.9222551970982868, -0.9206238101203582, -0.9190743520427355, -0.9176087405589766, -0.9162287991911757, -0.9149362534705465, -0.9137327272682496, -0.9126197392932058, -0.9115986997732765, -0.9106709073356939, -0.9098375461019801, -0.9090996830118235, -0.9084582653894677, -0.9079141187651288, -0.9074679449627994, -0.9071203204645277, -0.9068716950598864, -0.9067223907878882, -0.9066726011770717, -0.9067223907878882, -0.9068716950598866, -0.907120320464528, -0.9074679449627999, -0.9079141187651294, -0.9084582653894685, -0.9090996830118243, -0.9098375461019811, -0.9106709073356949, -0.9115986997732775, -0.9126197392932068, -0.9137327272682508, -0.9149362534705479, -0.9162287991911772, -0.917608740558978, -0.919074352042737, -0.92062381012036, -0.9222551970982885, -0.9239665050641942, -0.9257556399558904, -0.9276204257294478, -0.929558608609652, -0.9315678614062178, -0.9336457878795599, -0.9357899271403924, -0.9379977580679972, -0.9402667037326361, -0.9425941358082986, -0.9449773789627277, -0.9474137152124785, -0.9499003882316045, -0.9524346076034313, -0.9550135530057559, -0.9576343783206972, -0.9602942156613113, -0.9629901793079488, -0.9657193695482065, -0.9684788764151446, -0.9712657833192604, -0.9740771705704812, -0.9769101187871808, -0.9797617121899259, -0.9826290417783178, -0.9855092083899152, -0.9883993256407971, -0.9912965227478543, -0.9941979472333801, -0.9971007675129817, -1.0000021753682193, -1.0028993883057458, -1.005789651805027, -1.0086702414570115, -1.011538464996334, -1.0143916642298723, -1.0172272168646144, -1.0200425382379568, -1.0228350829536497, -1.0256023464266946, -1.0283418663405575, -1.0310512240200933, -1.0337280457235947, -1.036370003857377, -1.0389748181162888, -1.0415402565535, -1.0440641365828829, -1.0465443259172267, -1.0489787434454747, -1.0513653600520791, -1.0537021993815014, -1.0559873385507812, -1.0582189088130127, -1.0603950961744626, -1.0625141419679651, -1.0645743433851285, -1.0665740539697772, -1.0685116840749533, -1.0703857012856952, -1.0721946308097048, -1.073937055837911, -1.075611617876839, -1.0772170170545827, -1.0787520124020957, -1.0802154221113998, -1.0816061237722279, -1.0829230545885222, -1.084165211576113, -1.0853316517428233, -1.0864214922521505, -1.0874339105715967, -1.0883681446066447, -1.089223492821276, -1.089999314345882, -1.0906950290733133, -1.0913101177437647, -1.0918441220191042, -1.0922966445471889, -1.092667349016663, -1.0929559602026244, -1.093162264003527, -1.0932861074695885], [-1.1068849838132095, -1.1068382732235034, -1.1066981748214104, -1.1064647887065144, -1.1061382817064596, -1.1057188873693375, -1.1052069059528182, -1.1046027044097848, -1.1039067163701926, -1.103119442118793, -1.1022414485683019, -1.1012733692275078, -1.1002159041637687, -1.0990698199592381, -1.0978359496601182, -1.0965151927181258, -1.0951085149233013, -1.0936169483271816, -1.0920415911552832, -1.0903836077077405, -1.0886442282468445, -1.086824748870131, -1.0849265313675553, -1.0829510030611817, -1.0808996566256996, -1.0787740498879583, -1.0765758056035826, -1.0743066112086146, -1.0719682185439736, -1.0695624435504032, -1.067091165931427, -1.064556328781678, -1.0619599381778329, -1.0593040627292136, -1.0565908330849647, -1.053822441394566, -1.0510011407182627, -1.0481292443838475, -1.0452091252860634, -1.0422432151247354, -1.0392340035775873, -1.036184037403542, -1.0330959194721638, -1.0299723077147562, -1.026815913992509, -1.0236295028769598, -1.0204158903379443, -1.0171779423341134, -1.0139185733010392, -1.0106407445318788, -1.0073474624455525, -1.0040417767374037, -1.0007267784073466, -0.9974055976605916, -0.9940814016761582, -0.9907573922385423, -0.9874368032281178, -0.9841228979661155, -0.9808189664103342, -0.9775283221981148, -0.9742542995335416, -0.9710002499163405, -0.967769538710509, -0.9645655415513448, -0.9613916405902652, -0.9582512205775726, -0.9551476647841912, -0.9520843507643205, -0.9490646459619492, -0.9460919031652423, -0.9431694558139451, -0.9403006131661327, -0.9374886553318859, -0.934736828182755, -0.9320483381472013, -0.9294263469035589, -0.926873965983418, -0.9243942512997049, -0.9219901976150713, -0.9196647329675435, -0.9174207130716391, -0.9152609157143826, -0.9131880351667724, -0.9112046766322788, -0.9093133507548656, -0.9075164682097951, -0.9058163344010913, -0.9042151442899887, -0.9027149773789436, -0.9013177928758536, -0.9000254250629768, -0.8988395788946718, -0.8977618258474916, -0.8967936000453389, -0.8959361946813452, -0.8951907587568686, -0.8945582941565152, -0.8940396530764065, -0.8936355358210345, -0.8933464889819956, -0.8931729040096956, -0.8931150161867906, -0.8931729040096958, -0.8933464889819961, -0.8936355358210348, -0.894039653076407, -0.8945582941565157, -0.8951907587568694, -0.895936194681346, -0.8967936000453398, -0.8977618258474926, -0.898839578894673, -0.9000254250629782, -0.9013177928758549, -0.902714977378945, -0.9042151442899904, -0.905816334401093, -0.907516468209797, -0.9093133507548676, -0.9112046766322809, -0.9131880351667747, -0.9152609157143848, -0.9174207130716414, -0.9196647329675457, -0.9219901976150737, -0.9243942512997073, -0.9268739659834206, -0.9294263469035615, -0.9320483381472041, -0.9347368281827578, -0.9374886553318887, -0.9403006131661354, -0.9431694558139481, -0.9460919031652454, -0.9490646459619523, -0.9520843507643235, -0.9551476647841942, -0.9582512205775757, -0.9613916405902686, -0.9645655415513482, -0.9677695387105124, -0.9710002499163439, -0.9742542995335449, -0.9775283221981181, -0.9808189664103378, -0.9841228979661188, -0.9874368032281212, -0.9907573922385459, -0.9940814016761618, -0.9974055976605949, -1.00072677840735, -1.0040417767374072, -1.0073474624455558, -1.010640744531882, -1.0139185733010427, -1.017177942334117, -1.0204158903379477, -1.023629502876963, -1.0268159139925122, -1.0299723077147593, -1.033095919472167, -1.0361840374035451, -1.0392340035775904, -1.0422432151247385, -1.0452091252860665, -1.0481292443838506, -1.0510011407182656, -1.0538224413945687, -1.0565908330849674, -1.059304062729216, -1.0619599381778357, -1.0645563287816806, -1.0670911659314295, -1.0695624435504059, -1.071968218543976, -1.074306611208617, -1.076575805603585, -1.0787740498879606, -1.080899656625702, -1.0829510030611837, -1.0849265313675573, -1.0868247488701328, -1.0886442282468465, -1.0903836077077422, -1.0920415911552848, -1.093616948327183, -1.0951085149233029, -1.0965151927181271, -1.0978359496601195, -1.0990698199592397, -1.1002159041637696, -1.1012733692275092, -1.1022414485683028, -1.103119442118794, -1.1039067163701932, -1.1046027044097853, -1.105206905952819, -1.105718887369338, -1.1061382817064596, -1.1064647887065149, -1.1066981748214106, -1.1068382732235038], [-1.1213065999007323, -1.1212542685225326, -1.1210973103668642, -1.1208358333719002, -1.1204700174391649, -1.120000114440284, -1.119426448226227, -1.1187494146388237, -1.1179694815242875, -1.1170871887484046, -1.116103148212981, -1.1150180438730786, -1.1138326317544853, -1.1125477399708101, -1.111164268739489, -1.1096831903959303, -1.1081055494049241, -1.1064324623683508, -1.1046651180281364, -1.1028047772632865, -1.1008527730797297, -1.0988105105915846, -1.096679466992345, -1.0944611915143423, -1.0921573053747173, -1.0897695017059867, -1.0872995454691314, -1.0847492733469912, -1.0821205936155611, -1.079415485990632, -1.0766360014470133, -1.0737842620073996, -1.0708624604977317, -1.0678728602656995, -1.0648177948588164, -1.0616996676582717, -1.0585209514645355, -1.0552841880304595, -1.051991987537367, -1.0486470280093885, -1.0452520546610513, -1.0418098791728707, -1.0383233788894575, -1.0347954959344003, -1.031229236235943, -1.0276276684572407, -1.0239939228247625, -1.0203311898481886, -1.0166427189249665, -1.0129318168225123, -1.0092018460309025, -1.0054562229787867, -1.0016984161051636, -0.9979319437796347, -0.9941603720637471, -0.9903873123061014, -0.9866164185640153, -0.9828513848447192, -0.9790959421593101, -0.9753538553830243, -0.971628919915807, -0.9679249581376643, -0.9642458156538849, -0.9605953573259294, -0.956977463084603, -0.9533960235230499, -0.9498549352681518, -0.9463580961300838, -0.942909400031044, -0.9395127317155916, -0.9361719612465296, -0.9328909382918971, -0.9296734862103777, -0.9265233959442444, -0.9234444197308924, -0.9204402646459844, -0.9175145859932884, -0.914670980558357, -0.9119129797453026, -0.909244042618007, -0.9066675488691603, -0.9041867917425136, -0.9018049709356359, -0.8995251855122425, -0.897350426854782, -0.8952835716894186, -0.8933273752167569, -0.8914844643826318, -0.8897573313239932, -0.8881483270252938, -0.8866596552208773, -0.8852933665785732, -0.8840513531990876, -0.882935343464779, -0.8819468972700346, -0.8810874016637429, -0.8803580669322585, -0.8797599231488273, -0.879293817212694, -0.8789604103980652, -0.8787601764298112, -0.8786934000992677, -0.8787601764298113, -0.8789604103980655, -0.8792938172126944, -0.8797599231488278, -0.8803580669322589, -0.8810874016637437, -0.8819468972700355, -0.8829353434647802, -0.884051353199089, -0.8852933665785745, -0.8866596552208789, -0.8881483270252953, -0.8897573313239949, -0.8914844643826338, -0.893327375216759, -0.8952835716894209, -0.8973504268547841, -0.8995251855122448, -0.9018049709356386, -0.9041867917425163, -0.9066675488691629, -0.9092440426180096, -0.9119129797453052, -0.9146709805583598, -0.9175145859932914, -0.9204402646459874, -0.9234444197308955, -0.9265233959442477, -0.9296734862103809, -0.9328909382919006, -0.936171961246533, -0.939512731715595, -0.9429094000310473, -0.9463580961300874, -0.9498549352681556, -0.9533960235230533, -0.9569774630846067, -0.960595357325933, -0.9642458156538888, -0.9679249581376684, -0.971628919915811, -0.975353855383028, -0.9790959421593141, -0.9828513848447231, -0.9866164185640192, -0.9903873123061052, -0.9941603720637511, -0.9979319437796385, -1.0016984161051674, -1.0054562229787904, -1.0092018460309062, -1.012931816822516, -1.0166427189249705, -1.0203311898481924, -1.0239939228247663, -1.0276276684572445, -1.0312292362359468, -1.034795495934404, -1.0383233788894608, -1.041809879172874, -1.0452520546610546, -1.048647028009392, -1.0519919875373702, -1.0552841880304629, -1.0585209514645388, -1.0616996676582746, -1.0648177948588198, -1.0678728602657026, -1.0708624604977348, -1.0737842620074025, -1.0766360014470162, -1.0794154859906346, -1.082120593615564, -1.084749273346994, -1.0872995454691343, -1.0897695017059892, -1.0921573053747198, -1.0944611915143445, -1.0966794669923474, -1.0988105105915866, -1.1008527730797317, -1.1028047772632885, -1.1046651180281382, -1.1064324623683524, -1.1081055494049254, -1.109683190395932, -1.1111642687394903, -1.1125477399708115, -1.1138326317544864, -1.1150180438730797, -1.1161031482129822, -1.1170871887484055, -1.1179694815242887, -1.1187494146388246, -1.119426448226228, -1.1200001144402847, -1.1204700174391649, -1.1208358333719002, -1.1210973103668644, -1.1212542685225328], [-1.1365782951033379, -1.1365201670979124, -1.1363458214861075, -1.1360553734858398, -1.1356490151419587, -1.1351270153486357, -1.1344897198805366, -1.1337375514325885, -1.1328710096681076, -1.1318906712750014, -1.130797190029687, -1.1295912968683204, -1.1282737999648507, -1.126845584815358, -1.125307614328047, -1.1236609289181938, -1.1219066466072658, -1.1200459631253268, -1.1180801520157562, -1.116010564741197, -1.1138386307895454, -1.1115658577786505, -1.1091938315582934, -1.106724216307847, -1.1041587546278826, -1.1014992676238249, -1.0987476549795838, -1.0959058950189082, -1.0929760447520078, -1.0899602399047879, -1.0868606949278072, -1.0836797029818457, -1.0804196358967104, -1.077082944099648, -1.0736721565094562, -1.0701898803920866, -1.066638801173239, -1.0630216822031129, -1.0593413644681595, -1.0556007662443334, -1.0518028826859767, -1.0479507853441148, -1.0440476216075627, -1.0400966140598564, -1.0361010597446485, -1.032064329331812, -1.027989866176113, -1.0238811852599425, -1.0197418720112132, -1.0155755809871894, -1.0113860344146695, -1.0071770205766382, -1.0029523920352337, -0.9987160636806293, -0.9944720105952504, -0.9902242657226097, -0.9859769173299856, -0.9817341062541733, -0.9775000229196349, -0.9732789041185761, -0.9690750295427684, -0.9648927180573674, -0.96073632370752, -0.9566102314492579, -0.9525188525970123, -0.9484666199811042, -0.9444579828097363, -0.9404974012313904, -0.9365893405950655, -0.9327382654075499, -0.928948632988845, -0.9252248868289857, -0.921571449651823, -0.9179927161938282, -0.9144930457086438, -0.9110767542109341, -0.907748106476044, -0.9045113078150373, -0.9013704956478482, -0.8983297309004629, -0.895392989255265, -0.8925641522868466, -0.8898469985186783, -0.8872451944389953, -0.884762285517034, -0.8824016872632929, -0.8801666763797461, -0.8780603820478332, -0.8760857774035602, -0.8742456712501031, -0.8725427000588647, -0.8709793203099782, -0.8695578012227219, -0.8682802179251986, -0.8671484451109319, -0.8661641512277275, -0.8653287932412553, -0.864643612012353, -0.86410962832306, -0.8637276395819067, -0.8634982172340612, -0.8634217048966623, -0.8634982172340613, -0.863727639581907, -0.8641096283230607, -0.8646436120123534, -0.8653287932412561, -0.8661641512277286, -0.867148445110933, -0.8682802179251998, -0.8695578012227232, -0.8709793203099797, -0.8725427000588665, -0.874245671250105, -0.8760857774035623, -0.8780603820478353, -0.8801666763797484, -0.8824016872632955, -0.8847622855170366, -0.887245194438998, -0.8898469985186811, -0.8925641522868496, -0.895392989255268, -0.8983297309004659, -0.9013704956478513, -0.9045113078150405, -0.9077481064760473, -0.9110767542109377, -0.9144930457086473, -0.9179927161938319, -0.9215714496518268, -0.9252248868289894, -0.928948632988849, -0.9327382654075539, -0.9365893405950694, -0.9404974012313942, -0.9444579828097404, -0.9484666199811081, -0.9525188525970164, -0.9566102314492619, -0.9607363237075243, -0.9648927180573716, -0.9690750295427728, -0.9732789041185804, -0.9775000229196392, -0.9817341062541779, -0.9859769173299899, -0.9902242657226139, -0.9944720105952548, -0.9987160636806337, -1.002952392035238, -1.0071770205766424, -1.0113860344146737, -1.0155755809871936, -1.0197418720112172, -1.0238811852599468, -1.0279898661761175, -1.0320643293318161, -1.036101059744653, -1.0400966140598602, -1.0440476216075665, -1.0479507853441188, -1.0518028826859804, -1.0556007662443374, -1.0593413644681633, -1.0630216822031167, -1.066638801173243, -1.0701898803920904, -1.0736721565094598, -1.0770829440996517, -1.0804196358967137, -1.083679702981849, -1.0868606949278103, -1.089960239904791, -1.092976044752011, -1.0959058950189111, -1.0987476549795867, -1.1014992676238278, -1.1041587546278855, -1.1067242163078497, -1.109193831558296, -1.1115658577786527, -1.1138386307895474, -1.1160105647411993, -1.118080152015758, -1.1200459631253288, -1.1219066466072676, -1.1236609289181954, -1.1253076143280485, -1.1268455848153598, -1.128273799964852, -1.1295912968683215, -1.1307971900296883, -1.1318906712750025, -1.1328710096681087, -1.1337375514325891, -1.1344897198805373, -1.135127015348636, -1.1356490151419587, -1.13605537348584, -1.136345821486108, -1.1365201670979126], [-1.152685295042224, -1.15262121976157, -1.1524290345447756, -1.1521088612751078, -1.1516609031172, -1.1510854445557697, -1.1503828514496992, -1.1495535711013436, -1.1485981323408938, -1.1475171456255913, -1.1463113031535237, -1.1449813789916976, -1.1435282292180295, -1.1419527920768298, -1.1402560881472963, -1.1384392205244744, -1.1365033750120386, -1.1344498203261988, -1.1322799083099182, -1.129995074156543, -1.127596836641829, -1.125086798363233, -1.1224666459852017, -1.1197381504890496, -1.1169031674258643, -1.1139636371706976, -1.110921585176128, -1.1077791222230702, -1.1045384446664923, -1.1012018346734709, -1.0977716604507506, -1.0942503764587166, -1.0906405236083805, -1.0869447294376753, -1.0831657082630175, -1.0793062613017346, -1.0753692767605785, -1.071357729885137, -1.0672746829645297, -1.0631232852853316, -1.058906773028176, -1.0546284691000134, -1.0502917828944693, -1.0459002099722179, -1.0414573316527234, -1.0369668145081368, -1.0324324097495516, -1.0278579524952238, -1.0232473609097668, -1.0186046352027383, -1.0139338564744391, -1.0092391853961717, -1.004524860711647, -0.9997951975457047, -0.9950545855060329, -0.9903074865631336, -0.9855584326934171, -0.9808120232700284, -0.9760729221858003, -0.9713458546926601, -0.9666356039418471, -0.9619470072094991, -0.9572849517925061, -0.9526543705600787, -0.9480602371472099, -0.9435075607771712, -0.9390013807013967, -0.9345467602465558, -0.9301487804603715, -0.9258125333497573, -0.9215431147071824, -0.9173456165238161, -0.9132251189909528, -0.909186682094488, -0.9052353368107888, -0.9013760759161613, -0.8976138444262594, -0.8939535296861524, -0.8903999511363537, -0.8869578497848648, -0.8836318774201329, -0.880426585604728, -0.8773464144944163, -0.8743956815320754, -0.871578570070487, -0.8688991179823498, -0.8663612063197932, -0.8639685480891566, -0.8617246772097185, -0.8596329377273403, -0.85769647335554, -0.8559182174172548, -0.854300883260433, -0.8528469552195586, -0.8515586801932143, -0.8504380599048467, -0.8494868439099614, -0.8487065234081431, -0.8480983259125298, -0.8476632108228233, -0.8474018659406012, -0.847314704957776, -0.8474018659406015, -0.8476632108228237, -0.8480983259125302, -0.8487065234081437, -0.8494868439099623, -0.8504380599048477, -0.8515586801932156, -0.8528469552195599, -0.8543008832604346, -0.8559182174172564, -0.857696473355542, -0.8596329377273424, -0.8617246772097206, -0.863968548089159, -0.8663612063197959, -0.8688991179823525, -0.8715785700704898, -0.8743956815320784, -0.8773464144944195, -0.8804265856047313, -0.8836318774201362, -0.8869578497848682, -0.8903999511363573, -0.8939535296861559, -0.8976138444262632, -0.9013760759161653, -0.9052353368107929, -0.9091866820944924, -0.9132251189909569, -0.9173456165238204, -0.9215431147071866, -0.9258125333497617, -0.930148780460376, -0.9345467602465602, -0.9390013807014013, -0.943507560777176, -0.9480602371472145, -0.9526543705600836, -0.9572849517925108, -0.9619470072095039, -0.9666356039418521, -0.9713458546926648, -0.9760729221858052, -0.9808120232700333, -0.9855584326934219, -0.9903074865631383, -0.9950545855060378, -0.9997951975457093, -1.0045248607116517, -1.0092391853961766, -1.013933856474444, -1.018604635202743, -1.0232473609097716, -1.0278579524952287, -1.0324324097495563, -1.0369668145081412, -1.0414573316527278, -1.0459002099722225, -1.0502917828944738, -1.0546284691000176, -1.0589067730281805, -1.0631232852853358, -1.067274682964534, -1.0713577298851409, -1.0753692767605827, -1.0793062613017386, -1.0831657082630213, -1.086944729437679, -1.0906405236083843, -1.0942503764587201, -1.0977716604507541, -1.1012018346734744, -1.1045384446664959, -1.1077791222230735, -1.1109215851761314, -1.1139636371707007, -1.1169031674258671, -1.1197381504890525, -1.1224666459852044, -1.1250867983632358, -1.1275968366418314, -1.1299950741565452, -1.1322799083099204, -1.1344498203262008, -1.1365033750120406, -1.1384392205244762, -1.1402560881472978, -1.1419527920768313, -1.143528229218031, -1.1449813789916992, -1.146311303153525, -1.1475171456255926, -1.1485981323408947, -1.1495535711013443, -1.1503828514497005, -1.1510854445557703, -1.1516609031172005, -1.1521088612751083, -1.1524290345447759, -1.15262121976157], [-1.1696120172352042, -1.1695418685060175, -1.1693314649475441, -1.1689809344580762, -1.1684904902381976, -1.1678604308459035, -1.1670911402737074, -1.1661830880476727, -1.1651368293482907, -1.1639530051530946, -1.1626323424008806, -1.1611756541773706, -1.1595838399221194, -1.1578578856564306, -1.1559988642319943, -1.1540079355999169, -1.1518863470997431, -1.1496354337680095, -1.1472566186657962, -1.144751413224641, -1.1421214176101062, -1.1393683211021544, -1.1364939024913887, -1.133500030490063, -1.1303886641566212, -1.1271618533323546, -1.1238217390885816, -1.1203705541825502, -1.1168106235200275, -1.1131443646223118, -1.1093742880951052, -1.10550299809641, -1.1015331928002734, -1.0974676648528607, -1.0933093018169444, -1.089061086600497, -1.084726097864616, -1.0803075104055295, -1.0758085955049228, -1.071232721242259, -1.0665833527621913, -1.0618640524895173, -1.0570784802834774, -1.0522303935224755, -1.0473236471095757, -1.0423621933883311, -1.0373500819577046, -1.032291459373985, -1.0271905687267344, -1.0220517490749121, -1.0168794347283945, -1.0116781543592044, -1.0064525299258271, -1.001207275393079, -0.995947195229101, -0.9906771826601883, -0.9854022176633522, -0.9801273646757763, -0.9748577699996658, -0.969598658880446, -0.9643553322358541, -0.9591331630132222, -0.9539375921521753, -0.9487741241301383, -0.9436483220684451, -0.9385658023775364, -0.9335322289207427, -0.9285533066775064, -0.9236347748886431, -0.9187823996683987, -0.9140019660706618, -0.9092992695997643, -0.9046801071598601, -0.9001502674409387, -0.8957155207440988, -0.8913816082537838, -0.8871542307702523, -0.8830390369215827, -0.8790416108809713, -0.8751674596219177, -0.8714219997510075, -0.8678105439653682, -0.8643382871893239, -0.8610102924522516, -0.8578314765769722, -0.8548065957550857, -0.8519402310923024, -0.8492367742128971, -0.8467004130177384, -0.8443351176947816, -0.8421446270842938, -0.8401324355032547, -0.8383017801342599, -0.8366556290836757, -0.8351966702117429, -0.8339273008337159, -0.8328496183859426, -0.8319654121440908, -0.8312761560725249, -0.8307830028742883, -0.830486779300335, -0.8303879827647959, -0.8304867793003351, -0.8307830028742889, -0.8312761560725256, -0.8319654121440915, -0.8328496183859437, -0.833927300833717, -0.8351966702117445, -0.8366556290836774, -0.8383017801342618, -0.8401324355032567, -0.8421446270842962, -0.8443351176947841, -0.8467004130177408, -0.8492367742128998, -0.8519402310923052, -0.8548065957550888, -0.8578314765769754, -0.861010292452255, -0.8643382871893275, -0.8678105439653718, -0.8714219997510112, -0.8751674596219216, -0.8790416108809754, -0.8830390369215867, -0.8871542307702566, -0.8913816082537882, -0.8957155207441033, -0.9001502674409434, -0.9046801071598648, -0.909299269599769, -0.9140019660706667, -0.9187823996684036, -0.9236347748886482, -0.9285533066775115, -0.9335322289207479, -0.9385658023775417, -0.9436483220684505, -0.9487741241301437, -0.9539375921521808, -0.9591331630132276, -0.9643553322358597, -0.9695986588804513, -0.9748577699996713, -0.9801273646757817, -0.9854022176633577, -0.9906771826601937, -0.9959471952291066, -1.0012072753930843, -1.0064525299258325, -1.0116781543592095, -1.0168794347283996, -1.0220517490749175, -1.0271905687267398, -1.0322914593739903, -1.03735008195771, -1.042362193388336, -1.0473236471095808, -1.0522303935224804, -1.057078480283482, -1.0618640524895222, -1.0665833527621962, -1.0712327212422637, -1.0758085955049272, -1.0803075104055342, -1.0847260978646205, -1.0890610866005015, -1.0933093018169486, -1.097467664852865, -1.1015331928002778, -1.1055029980964137, -1.109374288095109, -1.1131443646223156, -1.1168106235200312, -1.1203705541825535, -1.1238217390885854, -1.127161853332358, -1.1303886641566245, -1.1335000304900662, -1.1364939024913916, -1.139368321102157, -1.1421214176101093, -1.144751413224644, -1.1472566186657984, -1.1496354337680117, -1.1518863470997454, -1.1540079355999189, -1.1559988642319963, -1.1578578856564326, -1.1595838399221212, -1.1611756541773721, -1.162632342400882, -1.163953005153096, -1.165136829348292, -1.1661830880476738, -1.1670911402737085, -1.1678604308459044, -1.1684904902381978, -1.1689809344580766, -1.1693314649475448, -1.169541868506018], [-1.1873420861717516, -1.1872657614138513, -1.1870368315506088, -1.1866554298275906, -1.1861217783680613, -1.1854361882439741, -1.1845990595753888, -1.183610881658331, -1.1824722331211257, -1.1811837821092332, -1.1797462864986061, -1.1781605941375983, -1.176427643117422, -1.1745484620711597, -1.1725241705012934, -1.1703559791357014, -1.1680451903120346, -1.1655931983903334, -1.1630014901937005, -1.1602716454767834, -1.1574053374217343, -1.1544043331612424, -1.1512704943281187, -1.1480057776308061, -1.1446122354540471, -1.1410920164837908, -1.1374473663552491, -1.1336806283228142, -1.1297942439503346, -1.1257907538199952, -1.121672798257779, -1.1174431180731805, -1.113104555310505, -1.1086600540087141, -1.1041126609663663, -1.0994655265077529, -1.094721905245828, -1.0898851568370018, -1.0849587467222588, -1.0799462468484382, -1.0748513363628107, -1.06967780227333, -1.0644295400661357, -1.059110554271009, -1.0537249589645525, -1.0482769781998664, -1.0427709463504475, -1.0372113083549077, -1.0316026198479342, -1.025949547161686, -1.0202568671805152, -1.0145294670305849, -1.008772343584564, -1.0029906027601856, -0.9971894585900226, -0.9913742320384133, -0.9855503495400519, -0.9797233412333884, -0.9738988388606479, -0.9680825733050655, -0.9622803717347981, -0.956498154322026, -0.9507419305049791, -0.9450177947600925, -0.9393319218512413, -0.933690561523092, -0.9281000326060724, -0.9225667165013771, -0.9170970500158411, -0.9116975175184837, -0.9063746423931174, -0.9011349777646671, -0.8959850964808346, -0.8909315803354683, -0.8859810085255512, -0.8811399453400529, -0.8764149270860918, -0.8718124482658258, -0.8673389470262779, -0.8630007899138064, -0.8588042559750804, -0.854755520257135, -0.8508606367701834, -0.84712552098824, -0.8435559319740208, -0.8401574542258662, -0.8369354793552961, -0.8338951877140313, -0.8310415300986098, -0.8283792096688285, -0.825912664222863, -0.8236460489768133, -0.8215832199993462, -0.8197277184528435, -0.8180827557908521, -0.8166512000575713, -0.8154355634285059, -0.8144379911223173, -0.8136602518023498, -0.813103729572469, -0.8127694176559273, -0.8126579138282485, -0.8127694176559274, -0.8131037295724693, -0.8136602518023504, -0.8144379911223181, -0.8154355634285068, -0.8166512000575726, -0.8180827557908538, -0.8197277184528453, -0.8215832199993482, -0.8236460489768155, -0.8259126642228656, -0.8283792096688313, -0.8310415300986126, -0.8338951877140344, -0.8369354793552993, -0.8401574542258697, -0.8435559319740243, -0.8471255209882437, -0.8508606367701874, -0.854755520257139, -0.8588042559750846, -0.8630007899138107, -0.8673389470262823, -0.8718124482658304, -0.8764149270860967, -0.8811399453400579, -0.8859810085255562, -0.8909315803354735, -0.8959850964808397, -0.9011349777646726, -0.9063746423931227, -0.9116975175184893, -0.9170970500158466, -0.9225667165013828, -0.9281000326060782, -0.9336905615230978, -0.939331921851247, -0.9450177947600983, -0.9507419305049851, -0.9564981543220319, -0.9622803717348041, -0.9680825733050715, -0.973898838860654, -0.9797233412333944, -0.985550349540058, -0.9913742320384193, -0.9971894585900286, -1.0029906027601914, -1.00877234358457, -1.0145294670305907, -1.020256867180521, -1.025949547161692, -1.03160261984794, -1.0372113083549135, -1.0427709463504535, -1.048276978199872, -1.053724958964558, -1.0591105542710146, -1.064429540066141, -1.0696778022733353, -1.0748513363628158, -1.0799462468484433, -1.0849587467222637, -1.0898851568370067, -1.094721905245833, -1.0994655265077575, -1.1041126609663712, -1.1086600540087188, -1.1131045553105094, -1.1174431180731847, -1.121672798257783, -1.1257907538199994, -1.1297942439503388, -1.133680628322818, -1.137447366355253, -1.1410920164837945, -1.1446122354540504, -1.1480057776308092, -1.1512704943281218, -1.1544043331612455, -1.1574053374217375, -1.1602716454767863, -1.1630014901937031, -1.1655931983903356, -1.1680451903120368, -1.1703559791357032, -1.1725241705012954, -1.1745484620711621, -1.1764276431174239, -1.1781605941375999, -1.1797462864986075, -1.1811837821092348, -1.1824722331211273, -1.183610881658332, -1.18459905957539, -1.1854361882439748, -1.1861217783680613, -1.186655429827591, -1.1870368315506092, -1.187265761413852], [-1.2058583491552484, -1.2057757683623287, -1.2055280719527284, -1.2051153978510638, -1.204537975988848, -1.2037961283902792, -1.2028902692924694, -1.2018209053002327, -1.2005886355755864, -1.1991941520621465, -1.1976382397446297, -1.195921776943688, -1.1940457356463345, -1.1920111818722223, -1.189819276076051, -1.1874712735863868, -1.18496852508116, -1.18231247710011, -1.179504672594421, -1.1765467515137509, -1.1734404514308285, -1.1701876082037326, -1.1667901566758903, -1.163250131413759, -1.1595696674820488, -1.1557510012562136, -1.1517964712718076, -1.147708519110128, -1.1434896903193732, -1.1391426353703291, -1.134670110645329, -1.130074979458964, -1.1253602131086722, -1.1205288919529877, -1.1155842065147996, -1.1105294586065264, -1.1053680624735784, -1.1001035459519262, -1.0947395516349443, -1.0892798380440076, -1.083728280796542, -1.0780888737643883, -1.072365730214403, -1.0665630839222127, -1.0606852902489379, -1.0547368271695012, -1.0487222962398497, -1.0426464234890223, -1.0365140602205103, -1.0303301837057581, -1.0240998977509537, -1.01782843311647, -1.0115211477664223, -1.005183526923832, -0.9988211829048241, -0.992439854703175, -0.9860454072943373, -0.9796438306258906, -0.9732412382591386, -0.9668438656244203, -0.9604580678505829, -0.9540903171270598, -0.9477471995551677, -0.9414354114435907, -0.9351617550016896, -0.9289331333832643, -0.9227565450328369, -0.9166390772864681, -0.9105878991796742, -0.9046102534162691, -0.8987134474540065, -0.8929048436658633, -0.8871918485397534, -0.8815819008845105, -0.8760824590162052, -0.8707009869063291, -0.865444939282161, -0.8603217456797283, -0.8553387934612324, -0.8505034098215574, -0.8458228428224623, -0.8413042415081821, -0.8369546351722326, -0.8327809118620408, -0.8287897962253438, -0.8249878268197817, -0.821381333024418, -0.8179764117086187, -0.8147789038293971, -0.8117943711425014, -0.8090280732247167, -0.8064849450146175, -0.804169575085874, -0.8020861848708019, -0.8002386090518099, -0.7986302773344729, -0.7972641978079923, -0.7961429420867443, -0.7952686324105336, -0.7946429308612679, -0.794267030830365, -0.7941416508447515, -0.7942670308303652, -0.7946429308612684, -0.7952686324105342, -0.7961429420867452, -0.7972641978079935, -0.7986302773344744, -0.8002386090518117, -0.8020861848708039, -0.8041695750858765, -0.80648494501462, -0.8090280732247193, -0.8117943711425044, -0.8147789038294003, -0.8179764117086221, -0.8213813330244216, -0.8249878268197854, -0.8287897962253479, -0.8327809118620452, -0.836954635172237, -0.8413042415081866, -0.8458228428224669, -0.8505034098215624, -0.8553387934612374, -0.8603217456797334, -0.8654449392821664, -0.8707009869063347, -0.8760824590162107, -0.8815819008845163, -0.8871918485397592, -0.8929048436658692, -0.8987134474540124, -0.9046102534162752, -0.9105878991796804, -0.9166390772864741, -0.9227565450328433, -0.9289331333832707, -0.9351617550016962, -0.9414354114435973, -0.9477471995551743, -0.9540903171270665, -0.9604580678505893, -0.9668438656244269, -0.9732412382591451, -0.9796438306258972, -0.9860454072943439, -0.9924398547031814, -0.9988211829048308, -1.0051835269238385, -1.011521147766429, -1.0178284331164762, -1.0240998977509599, -1.0303301837057646, -1.0365140602205165, -1.0426464234890285, -1.0487222962398557, -1.0547368271695075, -1.0606852902489436, -1.0665630839222184, -1.072365730214409, -1.0780888737643943, -1.0837282807965476, -1.0892798380440132, -1.09473955163495, -1.100103545951932, -1.1053680624735838, -1.1105294586065315, -1.1155842065148047, -1.1205288919529925, -1.1253602131086773, -1.1300749794589686, -1.1346701106453339, -1.1391426353703333, -1.1434896903193776, -1.147708519110132, -1.1517964712718118, -1.1557510012562175, -1.1595696674820526, -1.1632501314137624, -1.1667901566758936, -1.1701876082037361, -1.1734404514308319, -1.1765467515137538, -1.179504672594424, -1.1823124771001128, -1.1849685250811623, -1.1874712735863895, -1.189819276076053, -1.1920111818722243, -1.1940457356463365, -1.1959217769436898, -1.1976382397446315, -1.1991941520621483, -1.200588635575588, -1.2018209053002342, -1.2028902692924708, -1.20379612839028, -1.2045379759888488, -1.205115397851064, -1.2055280719527284, -1.205775768362329], [-1.2251428928971122, -1.2250539975070693, -1.224787358647028, -1.224343118267023, -1.2237215130163863, -1.2229228743427696, -1.2219476286310085, -1.2207962973820536, -1.2194694974322555, -1.2179679412133613, -1.2162924370536294, -1.2144438895205278, -1.2124232998055386, -1.2102317661516349, -1.2078704843240404, -1.205340748124932, -1.2026439499527606, -1.1997815814069088, -1.1967552339384167, -1.1935665995475107, -1.190217471528682, -1.1867097452640358, -1.183045419065618, -1.1792265950673817, -1.1752554801673911, -1.1711343870208077, -1.1668657350840723, -1.1624520517106136, -1.1578959732982332, -1.1532002464881699, -1.1483677294156105, -1.1434013930111895, -1.1383043223527178, -1.1330797180660614, -1.127730897773695, -1.1222612975890318, -1.1166744736541259, -1.110974103717781, -1.1051639887504576, -1.0992480545916672, -1.0932303536247188, -1.087115066472802, -1.0809065037093812, -1.0746091075747664, -1.0682274536895, -1.0617662527538445, -1.055230352221158, -1.0486247379313285, -1.0419545356886382, -1.035225012766512, -1.028441579319485, -1.0216097896804817, -1.0147353435190525, -1.0078240868336241, -1.0008820127480593, -0.9939152620799042, -0.9869301236446344, -0.979933034257036, -0.9729305783875428, -0.9659294874279983, -0.9589366385178895, -0.9519590528787079, -0.9450038936007563, -0.9380784628235171, -0.93119019824772, -0.9243466689145556, -0.9175555701852274, -0.9108247178522829, -0.9041620413131097, -0.8975755757357009, -0.8910734531475097, -0.884663892380033, -0.8783551878048992, -0.8721556968018341, -0.8660738259051252, -0.8601180155832471, -0.8542967236163048, -0.8486184070479917, -0.8430915027029666, -0.8377244062769166, -0.8325254500251176, -0.8275028790959147, -0.8226648265780843, -0.8180192873552328, -0.8135740908859465, -0.8093368730548358, -0.8053150472664637, -0.8015157749807338, -0.79794593591399, -0.7946120981540662, -0.7915204884590232, -0.7886769630275132, -0.7860869790428058, -0.7837555673017457, -0.7816873062436331, -0.7798862976916663, -0.7783561446107938, -0.7770999311704042, -0.7761202053782281, -0.775418964523436, -0.7749976436326181, -0.7748571071028877, -0.7749976436326184, -0.7754189645234365, -0.7761202053782289, -0.7770999311704052, -0.7783561446107953, -0.779886297691668, -0.7816873062436351, -0.783755567301748, -0.7860869790428083, -0.7886769630275162, -0.7915204884590262, -0.7946120981540695, -0.7979459359139935, -0.8015157749807377, -0.8053150472664677, -0.8093368730548401, -0.813574090885951, -0.8180192873552375, -0.8226648265780891, -0.8275028790959199, -0.8325254500251228, -0.837724406276922, -0.8430915027029722, -0.8486184070479975, -0.8542967236163107, -0.8601180155832533, -0.8660738259051313, -0.8721556968018406, -0.8783551878049056, -0.8846638923800396, -0.8910734531475162, -0.8975755757357077, -0.9041620413131165, -0.9108247178522898, -0.9175555701852344, -0.9243466689145627, -0.931190198247727, -0.9380784628235241, -0.9450038936007634, -0.9519590528787151, -0.9589366385178967, -0.9659294874280056, -0.97293057838755, -0.9799330342570434, -0.9869301236446416, -0.9939152620799113, -1.0008820127480667, -1.0078240868336312, -1.0147353435190594, -1.0216097896804885, -1.0284415793194919, -1.035225012766519, -1.0419545356886453, -1.0486247379313354, -1.0552303522211648, -1.0617662527538512, -1.0682274536895067, -1.0746091075747726, -1.0809065037093875, -1.0871150664728084, -1.093230353624725, -1.0992480545916734, -1.1051639887504636, -1.110974103717787, -1.1166744736541316, -1.1222612975890374, -1.1277308977737004, -1.133079718066067, -1.1383043223527232, -1.1434013930111944, -1.1483677294156154, -1.1532002464881748, -1.157895973298238, -1.162452051710618, -1.1668657350840772, -1.1711343870208122, -1.1752554801673953, -1.1792265950673855, -1.1830454190656219, -1.186709745264039, -1.1902174715286853, -1.193566599547514, -1.1967552339384198, -1.1997815814069117, -1.2026439499527635, -1.205340748124935, -1.2078704843240424, -1.210231766151637, -1.2124232998055406, -1.2144438895205296, -1.2162924370536312, -1.217967941213363, -1.2194694974322569, -1.2207962973820552, -1.2219476286310098, -1.22292287434277, -1.223721513016387, -1.2243431182670232, -1.2247873586470281, -1.2250539975070693], [-1.2451770608467454, -1.2450818125276264, -1.2447961160127314, -1.2443201166514561, -1.2436540567662118, -1.2427982757627207, -1.241753210284774, -1.2405193944137805, -1.2390974599135498, -1.2374881365208323, -1.2356922522822384, -1.2337107339382476, -1.2315446073551113, -1.2291949980055337, -1.2266631314991026, -1.2239503341635192, -1.221058033677758, -1.2179877597583433, -1.2147411449000145, -1.2113199251720868, -1.2077259410718824, -1.203961138436638, -1.2000275694153213, -1.1959273935018138, -1.1916628786309107, -1.187236402338584, -1.1826504529879096, -1.1779076310620158, -1.1730106505253222, -1.1679623402542367, -1.1627656455383348, -1.1574236296528697, -1.1519394755032495, -1.1463164873418545, -1.1405580925572456, -1.134667843535461, -1.128649419592645, -1.1225066289777557, -1.1162434109435013, -1.109863837882986, -1.1033721175287594, -1.0967725952100837, -1.0900697561632198, -1.0832682278883945, -1.0763727825458296, -1.06938833938176, -1.0623199671737618, -1.0551728866828967, -1.047952473098192, -1.0406642584567363, -1.0333139340202429, -1.0259073525862357, -1.0184505307090674, -1.0109496508027849, -1.0034110630943691, -0.9958412873921363, -0.9882470146300523, -0.9806351081444299, -0.9730126046349178, -0.9653867147569145, -0.9577648232875476, -0.9501544888022113, -0.9425634427933958, -0.9349995881582557, -0.9274709969761238, -0.919985907492107, -0.9125527202181127, -0.9051799930583243, -0.8978764353624179, -0.8906509008069259, -0.8835123790032984, -0.8764699857306639, -0.8695329516923077, -0.8627106096977432, -0.8560123801772738, -0.8494477549434007, -0.8430262791236273, -0.8367575312024289, -0.8306511011266103, -0.8247165664481636, -0.8189634665021677, -0.8134012746442735, -0.8080393686027825, -0.8028869990340453, -0.7979532564065052, -0.7932470363776353, -0.7887770038685864, -0.7845515560826515, -0.7805787847546654, -0.776866437957928, -0.773421881831931, -0.7702520626266081, -0.7673634694856754, -0.76476209841145, -0.7624534178650939, -0.7604423364584287, -0.7587331731854783, -0.7573296306231793, -0.7562347715011544, -0.7554509990002762, -0.7549800410897082, -0.7548229391532547, -0.7549800410897085, -0.7554509990002769, -0.7562347715011554, -0.7573296306231806, -0.7587331731854797, -0.7604423364584306, -0.7624534178650961, -0.7647620984114527, -0.7673634694856782, -0.7702520626266112, -0.7734218818319345, -0.7768664379579316, -0.7805787847546692, -0.7845515560826558, -0.7887770038685907, -0.7932470363776402, -0.7979532564065102, -0.8028869990340505, -0.8080393686027879, -0.8134012746442792, -0.8189634665021734, -0.8247165664481695, -0.8306511011266166, -0.8367575312024352, -0.8430262791236337, -0.8494477549434075, -0.8560123801772807, -0.8627106096977502, -0.8695329516923148, -0.8764699857306711, -0.8835123790033055, -0.8906509008069332, -0.8978764353624255, -0.9051799930583319, -0.9125527202181203, -0.9199859074921147, -0.9274709969761316, -0.9349995881582635, -0.9425634427934036, -0.9501544888022192, -0.9577648232875555, -0.9653867147569224, -0.9730126046349257, -0.9806351081444379, -0.98824701463006, -0.9958412873921441, -1.003411063094377, -1.0109496508027924, -1.018450530709075, -1.0259073525862432, -1.0333139340202504, -1.0406642584567434, -1.0479524730981995, -1.0551728866829042, -1.062319967173769, -1.0693883393817674, -1.0763727825458367, -1.0832682278884016, -1.0900697561632267, -1.0967725952100906, -1.103372117528766, -1.1098638378829926, -1.1162434109435078, -1.122506628977762, -1.1286494195926513, -1.134667843535467, -1.1405580925572514, -1.1463164873418603, -1.1519394755032555, -1.157423629652875, -1.1627656455383404, -1.167962340254242, -1.1730106505253275, -1.1779076310620207, -1.1826504529879145, -1.1872364023385886, -1.1916628786309151, -1.195927393501818, -1.2000275694153257, -1.203961138436642, -1.2077259410718864, -1.2113199251720903, -1.214741144900018, -1.2179877597583464, -1.2210580336777608, -1.2239503341635218, -1.226663131499105, -1.2291949980055366, -1.2315446073551135, -1.2337107339382496, -1.2356922522822402, -1.2374881365208341, -1.2390974599135514, -1.2405193944137816, -1.2417532102847753, -1.2427982757627218, -1.243654056766212, -1.2443201166514566, -1.244796116012732, -1.2450818125276268], [-1.2659414712405423, -1.2658398506164996, -1.2655350381234578, -1.2650271819224754, -1.2643165290280336, -1.2634034254273376, -1.262288316247787, -1.2609717459730636, -1.259454358708415, -1.2577368984958344, -1.2558202096799738, -1.2537052373257451, -1.2513930276886942, -1.2488847287393594, -1.2461815907429479, -1.2432849668957862, -1.24019631402012, -1.2369171933189609, -1.2334492711927876, -1.2297943201200177, -1.2259542196032822, -1.2219309571836199, -1.2177266295248084, -1.2133434435701371, -1.2087837177739864, -1.204049883410648, -1.1991444859628613, -1.1940701865925742, -1.1888297636964351, -1.183426114548511, -1.1778622570326838, -1.1721413314671003, -1.1662666025229274, -1.1602414612395253, -1.1540694271379295, -1.1477541504342776, -1.1412994143544972, -1.1347091375511578, -1.1279873766229211, -1.1211383287364465, -1.11416633434992, -1.1070758800365919, -1.099871601405752, -1.092558286117517, -1.0851408769865292, -1.0776244751682529, -1.0700143434199, -1.0623159094261645, -1.0545347691778153, -1.046676690388826, -1.0387476159350204, -1.030753667294214, -1.0227011479644743, -1.0145965468333962, -1.0064465414671666, -0.998258001283656, -0.9900379905688002, -0.9817937712901149, -0.9735328056553175, -0.9652627583576955, -0.9569914984430982, -0.9487271007262427, -0.9404778466764693, -0.9322522246851979, -0.924058929619247, -0.9159068615559348, -0.9078051235876843, -0.8997630185758319, -0.8917900447257369, -0.8838958898483403, -0.8760904241673317, -0.868383691526409, -0.8607858988481263, -0.8533074036949637, -0.8459586997850053, -0.8387504003194441, -0.8316932189876072, -0.824797948527797, -0.8180754367395006, -0.8115365598648737, -0.8051921932852345, -0.7990531795118961, -0.7931302934901096, -0.7874342052801272, -0.7819754402301318, -0.7767643368114118, -0.7718110023458519, -0.7671252669183442, -0.7627166358306222, -0.7585942410164266, -0.7547667918987708, -0.7512425262260597, -0.7480291614724957, -0.7451338474271193, -0.742563120622624, -0.7403228612676322, -0.7384182533426684, -0.7368537484994381, -0.735633034364586, -0.7347590077930495, -0.7342337535433566, -0.7340585287594575, -0.7342337535433571, -0.7347590077930503, -0.7356330343645873, -0.7368537484994395, -0.7384182533426702, -0.7403228612676345, -0.7425631206226265, -0.745133847427122, -0.748029161472499, -0.7512425262260631, -0.7547667918987746, -0.7585942410164307, -0.7627166358306265, -0.7671252669183488, -0.7718110023458568, -0.7767643368114171, -0.7819754402301373, -0.787434205280133, -0.7931302934901157, -0.7990531795119025, -0.8051921932852408, -0.8115365598648804, -0.8180754367395074, -0.8247979485278039, -0.8316932189876142, -0.8387504003194515, -0.8459586997850128, -0.8533074036949713, -0.860785898848134, -0.8683836915264169, -0.8760904241673396, -0.8838958898483484, -0.8917900447257452, -0.89976301857584, -0.9078051235876926, -0.9159068615559431, -0.9240589296192553, -0.9322522246852061, -0.9404778466764777, -0.9487271007262513, -0.9569914984431066, -0.965262758357704, -0.973532805655326, -0.9817937712901232, -0.9900379905688087, -0.9982580012836645, -1.006446541467175, -1.0145965468334044, -1.0227011479644827, -1.0307536672942224, -1.0387476159350284, -1.0466766903888343, -1.0545347691778233, -1.0623159094261723, -1.070014343419908, -1.0776244751682607, -1.085140876986537, -1.0925582861175243, -1.0998716014057592, -1.1070758800365992, -1.1141663343499273, -1.1211383287364534, -1.1279873766229283, -1.1347091375511646, -1.1412994143545039, -1.1477541504342839, -1.1540694271379357, -1.1602414612395318, -1.1662666025229336, -1.172141331467106, -1.1778622570326898, -1.1834261145485165, -1.1888297636964409, -1.1940701865925796, -1.1991444859628664, -1.204049883410653, -1.2087837177739913, -1.2133434435701413, -1.2177266295248124, -1.2219309571836237, -1.2259542196032862, -1.2297943201200212, -1.233449271192791, -1.2369171933189642, -1.240196314020123, -1.2432849668957895, -1.2461815907429505, -1.248884728739362, -1.2513930276886964, -1.2537052373257476, -1.255820209679976, -1.2577368984958364, -1.2594543587084166, -1.2609717459730656, -1.262288316247788, -1.2634034254273385, -1.2643165290280345, -1.2650271819224757, -1.265535038123458, -1.2658398506164996], [-1.2874160358524958, -1.2873080411921376, -1.2869841073466861, -1.2864443847481002, -1.2856891242000117, -1.2847186770035555, -1.2835334951340829, -1.2821341314693162, -1.2805212400696488, -1.27869557651148, -1.2766579982746, -1.2744094651848372, -1.2719510399133143, -1.2692838885338462, -1.2664092811401586, -1.2633285925247844, -1.260043302921661, -1.256554998814603, -1.2528653738140205, -1.2489762296043827, -1.2448894769651286, -1.240607136867862, -1.236131341652841, -1.2314643362879332, -1.2266084797133436, -1.2215662462755872, -1.2163402272542914, -1.2109331324855617, -1.2053477920857314, -1.1995871582794277, -1.1936543073359482, -1.1875524416179961, -1.1812848917468342, -1.1748551188879068, -1.168266717160916, -1.1615234161782275, -1.1546290837153217, -1.1475877285167662, -1.1404035032408764, -1.1330807075458302, -1.125623791319496, -1.1180373580546061, -1.1103261683701509, -1.1024951436789405, -1.0945493700001965, -1.0864941019147272, -1.0783347666587209, -1.070076968350405, -1.0617264923417482, -1.0532893096849922, -1.0447715817010435, -1.0361796646336083, -1.0275201143693633, -1.0187996912003872, -1.0100253646004753, -1.0012043179817989, -0.9923439533925863, -0.9834518961100691, -0.974535999075801, -0.9656043471126134, -0.9566652608538652, -0.947727300306286, -0.9387992679576173, -0.9298902113294096, -0.9210094248638538, -0.9121664510214322, -0.9033710804536407, -0.8946333511022125, -0.885963546063381, -0.8773721900430792, -0.8688700442168866, -0.8604680992975022, -0.8521775666029975, -0.844009866911739, -0.8359766168853195, -0.8280896128398774, -0.8203608116496615, -0.8128023085754861, -0.8054263118257566, -0.7982451136799197, -0.7912710580343799, -0.7845165042698651, -0.7779937873874968, -0.7717151744187594, -0.7656928171821611, -0.7599387015362448, -0.7544645933638431, -0.7492819816146588, -0.7444020188303637, -0.7398354596758399, -0.735592598098717, -0.7316832038333356, -0.7281164590505406, -0.7249008960270449, -0.7220443367631566, -0.7195538355114293, -0.717435625187765, -0.715695068618006, -0.714336615525487, -0.7133637660880872, -0.7127790417881182, -0.7125839641475042, -0.7127790417881187, -0.7133637660880878, -0.7143366155254882, -0.7156950686180076, -0.717435625187767, -0.7195538355114318, -0.7220443367631595, -0.724900896027048, -0.7281164590505441, -0.7316832038333395, -0.7355925980987214, -0.7398354596758443, -0.7444020188303686, -0.7492819816146639, -0.7544645933638486, -0.7599387015362506, -0.7656928171821673, -0.7717151744187657, -0.7779937873875035, -0.784516504269872, -0.791271058034387, -0.7982451136799269, -0.8054263118257641, -0.8128023085754938, -0.8203608116496693, -0.8280896128398855, -0.8359766168853275, -0.8440098669117474, -0.8521775666030059, -0.860468099297511, -0.8688700442168952, -0.8773721900430879, -0.88596354606339, -0.8946333511022214, -0.90337108045365, -0.9121664510214413, -0.921009424863863, -0.9298902113294187, -0.9387992679576265, -0.9477273003062953, -0.9566652608538743, -0.9656043471126227, -0.9745359990758101, -0.9834518961100784, -0.9923439533925954, -1.0012043179818078, -1.0100253646004844, -1.0187996912003965, -1.0275201143693724, -1.036179664633617, -1.0447715817010523, -1.053289309685001, -1.0617264923417569, -1.0700769683504137, -1.0783347666587295, -1.0864941019147356, -1.0945493700002047, -1.1024951436789485, -1.1103261683701589, -1.1180373580546141, -1.1256237913195037, -1.133080707545838, -1.1404035032408837, -1.1475877285167735, -1.1546290837153288, -1.1615234161782344, -1.168266717160923, -1.1748551188879135, -1.1812848917468406, -1.1875524416180026, -1.1936543073359545, -1.1995871582794337, -1.2053477920857374, -1.2109331324855672, -1.2163402272542971, -1.2215662462755923, -1.2266084797133487, -1.2314643362879378, -1.2361313416528457, -1.2406071368678662, -1.2448894769651329, -1.2489762296043867, -1.2528653738140243, -1.2565549988146067, -1.2600433029216642, -1.2633285925247877, -1.2664092811401613, -1.2692838885338493, -1.271951039913317, -1.2744094651848394, -1.2766579982746025, -1.278695576511482, -1.2805212400696508, -1.2821341314693175, -1.2835334951340847, -1.2847186770035564, -1.2856891242000124, -1.2864443847481009, -1.2869841073466866, -1.2873080411921378], [-1.309579979428256, -1.3094656253155794, -1.3091226137074161, -1.3085510968192304, -1.3077513284297604, -1.3067236640107895, -1.3054685609094747, -1.303986578583881, -1.3022783788925612, -1.3003447264392098, -1.2981864889736086, -1.2958046378502825, -1.2932002485464775, -1.2903745012412677, -1.2873286814578173, -1.284064180771018, -1.2805824975829365, -1.2768852379687206, -1.272974116595846, -1.2688509577197757, -1.264517696259375, -1.2599763789556053, -1.255229165617299, -1.2502783304580147, -1.2451262635282325, -1.2397754722473655, -1.2342285830403186, -1.228488343083534, -1.2225576221657108, -1.2164394146685875, -1.210136841673393, -1.2036531531987642, -1.1969917305760973, -1.1901560889684615, -1.1831498800393083, -1.1759768947773155, -1.1686410664837181, -1.1611464739284902, -1.1534973446816366, -1.1456980586257073, -1.1377531516553965, -1.1296673195697182, -1.1214454221617631, -1.1130924875104042, -1.1046137164775016, -1.0960144874131281, -1.0873003610700986, -1.0784770857275499, -1.069550602521485, -1.0605270509780125, -1.0514127747424145, -1.042214327494132, -1.0329384790341916, -1.0235922215274584, -1.0141827758773072, -1.0047175982048002, -0.9952043863981545, -0.9856510866911021, -0.97606590022062, -0.966457289505343, -0.9568339847757067, -0.9472049900754334, -0.937579589041312, -0.9279673502543091, -0.9183781320398605, -0.9088220865787695, -0.8993096631725321, -0.8898516104882659, -0.8804589775888972, -0.8711431135341828, -0.8619156653178217, -0.8527885738858937, -0.8437740679627074, -0.8348846553926562, -0.8261331116917326, -0.8175324654910526, -0.8090959805482989, -0.8008371340027979, -0.7927695905575037, -0.7849071722880948, -0.77726382380728, -0.7698535725529084, -0.7626904840229755, -0.7557886118503108, -0.7491619426954077, -0.7428243360376955, -0.736789459063068, -0.7310707169772789, -0.7256811792184947, -0.7206335021943704, -0.715939849324853, -0.7116118093258228, -0.707660313814003, -0.7040955554429803, -0.700926907886051, -0.6981628490563947, -0.695810888991984, -0.6938775038259961, -0.6923680772095053, -0.6912868504502759, -0.6906368824805678, -0.6904200205717438, -0.6906368824805681, -0.6912868504502768, -0.6923680772095068, -0.6938775038259979, -0.6958108889919861, -0.6981628490563973, -0.700926907886054, -0.7040955554429837, -0.7076603138140068, -0.7116118093258271, -0.7159398493248577, -0.7206335021943754, -0.7256811792185002, -0.7310707169772845, -0.7367894590630741, -0.7428243360377019, -0.7491619426954146, -0.7557886118503178, -0.7626904840229829, -0.769853572552916, -0.7772638238072878, -0.7849071722881028, -0.7927695905575118, -0.8008371340028062, -0.8090959805483074, -0.8175324654910614, -0.8261331116917415, -0.8348846553926653, -0.8437740679627166, -0.8527885738859029, -0.8619156653178311, -0.8711431135341923, -0.8804589775889069, -0.8898516104882755, -0.8993096631725419, -0.908822086578779, -0.9183781320398704, -0.927967350254319, -0.937579589041322, -0.9472049900754432, -0.9568339847757167, -0.9664572895053529, -0.97606590022063, -0.9856510866911121, -0.9952043863981643, -1.00471759820481, -1.014182775877317, -1.0235922215274682, -1.0329384790342013, -1.0422143274941416, -1.051412774742424, -1.0605270509780218, -1.069550602521494, -1.0784770857275592, -1.0873003610701075, -1.096014487413137, -1.1046137164775105, -1.113092487510413, -1.1214454221617713, -1.1296673195697267, -1.137753151655405, -1.1456980586257153, -1.1534973446816446, -1.1611464739284982, -1.1686410664837257, -1.1759768947773226, -1.1831498800393156, -1.1901560889684686, -1.1969917305761044, -1.2036531531987709, -1.2101368416733995, -1.216439414668594, -1.222557622165717, -1.22848834308354, -1.2342285830403243, -1.2397754722473713, -1.2451262635282379, -1.2502783304580196, -1.2552291656173034, -1.2599763789556098, -1.2645176962593794, -1.2688509577197802, -1.2729741165958497, -1.2768852379687243, -1.2805824975829398, -1.2840641807710218, -1.2873286814578202, -1.2903745012412706, -1.2932002485464802, -1.295804637850285, -1.2981864889736106, -1.3003447264392118, -1.302278378892563, -1.303986578583883, -1.305468560909476, -1.3067236640107904, -1.3077513284297613, -1.3085510968192309, -1.3091226137074163, -1.3094656253155794], [-1.3324118597838495, -1.3322911757895854, -1.3319291749878712, -1.3313260109480605, -1.3304819397062395, -1.3293973198963358, -1.3280726129344027, -1.3265083832568134, -1.3247052986133068, -1.3226641304160567, -1.32038575414614, -1.3178711498190152, -1.3151214025108477, -1.3121377029477492, -1.3089213481602395, -1.3054737422054972, -1.3017963969601933, -1.2978909329869905, -1.2937590804780439, -1.2894026802791156, -1.2848236849982102, -1.280024160202923, -1.2750062857110025, -1.2697723569789379, -1.2643247865937033, -1.2586661058731172, -1.252798966580621, -1.246726142760607, -1.2404505327007964, -1.2339751610285004, -1.227303180947964, -1.2204378766263433, -1.2133826657362121, -1.2061411021628428, -1.1987168788848195, -1.191113831036873, -1.1833359391640879, -1.1753873326768896, -1.1672722935164257, -1.1589952600400941, -1.150560831137049, -1.141973770583507, -1.1332390116475484, -1.1243616619528647, -1.1153470086105013, -1.1062005236270451, -1.0969278695969027, -1.0875349056852408, -1.0780276939067748, -1.068412505703862, -1.0586958288251904, -1.048884374503714, -1.0389850849292783, -1.0290051410075394, -1.0189519703921763, -1.008833255771986, -0.9986569433880463, -0.9884312517487047, -0.9781646805014464, -0.9678660194107411, -0.9575443573794338, -0.9472090914381726, -0.9368699356124627, -0.9265369295601814, -0.9162204468536009, -0.9059312027591012, -0.895680261344733, -0.8854790417206629, -0.8753393231903324, -0.8652732490611216, -0.8552933288326816, -0.8454124384493737, -0.8356438182710343, -0.8260010683844283, -0.8164981408473421, -0.8071493284296506, -0.7979692493925505, -0.7889728278303981, -0.7801752690915426, -0.7715920297977048, -0.7632387819986027, -0.7551313710325698, -0.747285766717754, -0.7397180075748567, -0.732444137883613, -0.7254801375029981, -0.7188418445401499, -0.7125448711346476, -0.706604512830845, -0.7010356522373249, -0.6958526579130229, -0.6910692796658242, -0.6866985416910745, -0.6827526352023418, -0.6792428124016535, -0.6761792837875922, -0.6735711208939659, -0.6714261665778576, -0.6697509549250672, -0.6685506427085716, -0.6678289541215771, -0.6675881402161504, -0.6678289541215776, -0.6685506427085726, -0.6697509549250686, -0.6714261665778595, -0.6735711208939683, -0.6761792837875952, -0.6792428124016568, -0.6827526352023454, -0.6866985416910788, -0.691069279665829, -0.6958526579130281, -0.7010356522373306, -0.7066045128308509, -0.7125448711346538, -0.7188418445401565, -0.7254801375030052, -0.7324441378836204, -0.7397180075748643, -0.7472857667177621, -0.755131371032578, -0.7632387819986111, -0.7715920297977134, -0.7801752690915514, -0.7889728278304072, -0.7979692493925598, -0.8071493284296601, -0.8164981408473517, -0.8260010683844382, -0.8356438182710442, -0.8454124384493837, -0.8552933288326917, -0.8652732490611317, -0.8753393231903427, -0.8854790417206733, -0.8956802613447437, -0.9059312027591119, -0.9162204468536116, -0.926536929560192, -0.9368699356124732, -0.9472090914381833, -0.9575443573794443, -0.9678660194107516, -0.9781646805014572, -0.988431251748715, -0.9986569433880569, -1.0088332557719963, -1.0189519703921868, -1.0290051410075496, -1.0389850849292883, -1.0488843745037242, -1.0586958288252006, -1.0684125057038718, -1.0780276939067845, -1.0875349056852506, -1.0969278695969127, -1.1062005236270545, -1.1153470086105108, -1.1243616619528738, -1.1332390116475572, -1.141973770583516, -1.1505608311370576, -1.1589952600401026, -1.1672722935164341, -1.175387332676898, -1.183335939164096, -1.1911138310368807, -1.198716878884827, -1.2061411021628503, -1.2133826657362197, -1.2204378766263502, -1.2273031809479709, -1.2339751610285072, -1.240450532700803, -1.246726142760613, -1.2527989665806272, -1.2586661058731232, -1.2643247865937088, -1.2697723569789434, -1.2750062857110076, -1.2800241602029279, -1.284823684998215, -1.2894026802791203, -1.2937590804780483, -1.2978909329869945, -1.3017963969601969, -1.3054737422055012, -1.3089213481602426, -1.3121377029477521, -1.3151214025108506, -1.3178711498190177, -1.3203857541461423, -1.3226641304160591, -1.3247052986133088, -1.3265083832568154, -1.3280726129344043, -1.329397319896337, -1.3304819397062402, -1.3313260109480607, -1.3319291749878712, -1.3322911757895854], [-1.3558895885496056, -1.3557626179184399, -1.3553817575343081, -1.3547471619511744, -1.3538590888453201, -1.3527178991452522, -1.3513240572143785, -1.349678131087241, -1.3477807927603527, -1.345632818538912, -1.343235089440905, -1.3405885916603715, -1.3376944170918468, -1.3345537639182776, -1.3311679372649512, -1.3275383499222877, -1.323666523140618, -1.3195540875003768, -1.3152027838614524, -1.310614464395769, -1.305791093707504, -1.300734750045717, -1.2954476266145136, -1.2899320329862807, -1.2841903966239085, -1.2782252645183525, -1.2720393049483116, -1.2656353093692716, -1.2590161944396123, -1.2521850041919882, -1.2451449123586844, -1.2378992248601726, -1.2304513824666288, -1.2228049636427183, -1.2149636875864969, -1.2069314174738488, -1.1987121639204181, -1.1903100886735485, -1.1817295085472657, -1.1729748996138496, -1.164050901665991, -1.1549623229639572, -1.145714145282512, -1.1363115292725925, -1.1267598201528786, -1.1170645537463513, -1.107231462876767, -1.097266484139519, -1.0871757650606786, -1.076965671656968, -1.0666427964079968, -1.056213966650192, -1.0456862533993931, -1.0350669806059567, -1.0243637348423178, -1.0135843754181386, -1.0027370449123083, -0.9918301801039615, -0.9808725232761829, -0.9698731338559534, -0.9588414003419461, -0.9477870524577754, -0.9367201734519676, -0.9256512124470223, -0.914590996718191, -0.9035507437577777, -0.8925420729526261, -0.8815770166708217, -0.870668030518369, -0.8598280024876878, -0.8490702606772833, -0.8384085792161776, -0.8278571819780972, -0.8174307436197898, -0.8071443874262861, -0.7970136793949166, -0.7870546179414711, -0.7772836185684963, -0.7677174928005018, -0.7583734206674385, -0.7492689160104764, -0.7404217838976433, -0.7318500694763926, -0.7235719976609755, -0.7156059031597333, -0.7079701504956529, -0.7006830438662119, -0.6937627269274311, -0.687227072871528, -0.6810935654939891, -0.6753791723069892, -0.6701002111406137, -0.6652722120658846, -0.6609097768548198, -0.6570264385402351, -0.6536345239273117, -0.6507450221154736, -0.6483674621901795, -0.6465098032213065, -0.6451783395459152, -0.6443776240147955, -0.6441104114503944, -0.6443776240147959, -0.6451783395459163, -0.646509803221308, -0.6483674621901817, -0.6507450221154762, -0.653634523927315, -0.6570264385402389, -0.6609097768548239, -0.6652722120658894, -0.6701002111406189, -0.6753791723069948, -0.6810935654939954, -0.6872270728715345, -0.693762726927438, -0.7006830438662193, -0.7079701504956607, -0.7156059031597414, -0.7235719976609838, -0.7318500694764014, -0.7404217838976523, -0.7492689160104856, -0.7583734206674481, -0.7677174928005116, -0.7772836185685061, -0.7870546179414813, -0.797013679394927, -0.8071443874262967, -0.8174307436198006, -0.827857181978108, -0.8384085792161885, -0.8490702606772943, -0.8598280024876989, -0.8706680305183803, -0.8815770166708329, -0.8925420729526373, -0.903550743757789, -0.9145909967182023, -0.9256512124470335, -0.9367201734519788, -0.9477870524577867, -0.9588414003419573, -0.9698731338559645, -0.9808725232761942, -0.9918301801039728, -1.0027370449123194, -1.0135843754181497, -1.024363734842329, -1.0350669806059676, -1.045686253399404, -1.0562139666502026, -1.0666427964080072, -1.0769656716569784, -1.087175765060689, -1.0972664841395294, -1.1072314628767772, -1.1170645537463615, -1.1267598201528886, -1.1363115292726023, -1.145714145282521, -1.1549623229639665, -1.1640509016660003, -1.1729748996138585, -1.1817295085472748, -1.1903100886735571, -1.1987121639204268, -1.2069314174738572, -1.214963687586505, -1.222804963642726, -1.2304513824666368, -1.2378992248601801, -1.2451449123586917, -1.2521850041919953, -1.2590161944396192, -1.2656353093692783, -1.272039304948318, -1.2782252645183587, -1.2841903966239148, -1.2899320329862864, -1.2954476266145194, -1.3007347500457223, -1.3057910937075092, -1.3106144643957736, -1.315202783861457, -1.319554087500381, -1.3236665231406222, -1.3275383499222917, -1.3311679372649545, -1.3345537639182812, -1.3376944170918497, -1.3405885916603741, -1.343235089440908, -1.3456328185389141, -1.347780792760355, -1.3496781310872425, -1.3513240572143803, -1.3527178991452535, -1.3538590888453208, -1.3547471619511753, -1.3553817575343088, -1.3557626179184403], [-1.3799904525392286, -1.3798572509060085, -1.379457697741481, -1.378791948276185, -1.3778602613116093, -1.3766629993465018, -1.375200628754553, -1.3734737200143028, -1.3714829479923782, -1.3692290922814172, -1.3667130375943028, -1.3639357742165896, -1.3608983985192933, -1.357602113534491, -1.3540482295964786, -1.3502381650515458, -1.3461734470397477, -1.3418557123523815, -1.3372867083692503, -1.3324682940801373, -1.3274024411953333, -1.3220912353504433, -1.3165368774111477, -1.3107416848840352, -1.3047080934401152, -1.2984386585581096, -1.291936057295162, -1.285203090193173, -1.2782426833295373, -1.271057890521706, -1.2636518956956357, -1.2560280154288725, -1.2481897016797454, -1.2401405447148857, -1.2318842762480715, -1.2234247728042158, -1.214766059323141, -1.2059123130186562, -1.1968678675093263, -1.18763721723822, -1.1782250221998083, -1.1686361129930873, -1.1588754962208476, -1.1489483602558497, -1.1388600813954308, -1.1286162304267318, -1.1182225796253142, -1.1076851102103167, -1.097010020279504, -1.086203733247499, -1.0752729068100804, -1.0642244424566292, -1.0530654955514966, -1.0418034860031358, -1.0304461095371664, -1.0190013495859713, -1.0074774898027636, -0.9958831272021412, -0.984227185921684, -0.9725189315899244, -0.9607679862746944, -0.9489843439721147, -0.9371783865799409, -0.9253609002792378, -0.9135430922249475, -0.9017366074184031, -0.8899535456027339, -0.8782064779849269, -0.8665084635456205, -0.854873064649105, -0.8433143616112164, -0.83184696582169, -0.8204860309502146, -0.8092472616922657, -0.7981469194326598, -0.787201824122987, -0.7764293515856701, -0.7658474253751764, -0.7554745022496049, -0.745329550238304, -0.7354320182392565, -0.7258017960508211, -0.7164591637442409, -0.7074247293252228, -0.6987193537245208, -0.6903640623084705, -0.6823799423196467, -0.6747880259522785, -0.6676091591407458, -0.6608638565919258, -0.6545721441171508, -0.6487533899038108, -0.6434261269890571, -0.6386078698294189, -0.6343149284637757, -0.6305622243006754, -0.6273631119792011, -0.6247292120112828, -0.6226702589739583, -0.6211939698545916, -0.6203059367473825, -0.6200095474607715, -0.6203059367473831, -0.6211939698545929, -0.62267025897396, -0.6247292120112853, -0.627363111979204, -0.6305622243006791, -0.6343149284637799, -0.6386078698294235, -0.6434261269890623, -0.6487533899038165, -0.6545721441171571, -0.6608638565919325, -0.6676091591407529, -0.674788025952286, -0.6823799423196547, -0.690364062308479, -0.6987193537245295, -0.7074247293252319, -0.7164591637442506, -0.7258017960508308, -0.7354320182392665, -0.7453295502383143, -0.7554745022496154, -0.7658474253751871, -0.7764293515856812, -0.7872018241229982, -0.7981469194326712, -0.8092472616922771, -0.8204860309502262, -0.8318469658217017, -0.8433143616112282, -0.8548730646491169, -0.8665084635456324, -0.878206477984939, -0.8899535456027461, -0.9017366074184152, -0.9135430922249596, -0.9253609002792499, -0.937178386579953, -0.9489843439721269, -0.9607679862747066, -0.9725189315899364, -0.984227185921696, -0.9958831272021532, -1.0074774898027756, -1.0190013495859829, -1.030446109537178, -1.041803486003147, -1.0530654955515082, -1.0642244424566405, -1.0752729068100915, -1.0862037332475103, -1.0970100202795148, -1.1076851102103276, -1.1182225796253251, -1.1286162304267422, -1.138860081395441, -1.14894836025586, -1.1588754962208576, -1.1686361129930973, -1.178225022199818, -1.1876372172382297, -1.1968678675093358, -1.2059123130186653, -1.2147660593231502, -1.2234247728042245, -1.23188427624808, -1.2401405447148939, -1.2481897016797538, -1.2560280154288803, -1.2636518956956435, -1.2710578905217134, -1.2782426833295444, -1.2852030901931801, -1.291936057295169, -1.298438658558116, -1.3047080934401214, -1.3107416848840412, -1.3165368774111534, -1.322091235350449, -1.327402441195339, -1.3324682940801424, -1.3372867083692552, -1.3418557123523862, -1.3461734470397517, -1.3502381650515496, -1.354048229596482, -1.357602113534495, -1.3608983985192966, -1.3639357742165923, -1.3667130375943055, -1.3692290922814196, -1.3714829479923807, -1.3734737200143048, -1.3752006287545548, -1.3766629993465032, -1.37786026131161, -1.378791948276186, -1.3794576977414816, -1.379857250906009], [-1.4046911357233376, -1.404551769869118, -1.4041337241850638, -1.40343715433097, -1.4024623198198718, -1.4012095841385512, -1.3996794149171257, -1.3978723841486103, -1.3957891684595902, -1.3934305494334318, -1.390797413987707, -1.3878907548078054, -1.3847116708389988, -1.381261367839516, -1.3775411589975122, -1.3735524656151448, -1.3692968178633123, -1.3647758556109741, -1.359991329333367, -1.3549451011038187, -1.3496391456743055, -1.3440755516503462, -1.338256522766312, -1.3321843792677355, -1.3258615594077607, -1.3192906210654374, -1.3124742434941965, -1.3054152292094858, -1.2981165060252555, -1.290581129249715, -1.2828122840515794, -1.2748132880088718, -1.2665875938532227, -1.258138792423577, -1.2494706158442068, -1.2405869409430013, -1.231491792927119, -1.2221893493342741, -1.21268394427916, -1.2029800730158116, -1.1930823968380517, -1.1829957483415667, -1.1727251370725704, -1.1622757555894996, -1.151652985965633, -1.1408624067620043, -1.1299098005014045, -1.1188011616756508, -1.1075427053195426, -1.0961408761860705, -1.0846023585583076, -1.0729340867340518, -1.061143256219494, -1.0492373356679345, -1.037224079598662, -1.0251115419294394, -1.0129080903533567, -1.0006224215869433, -0.988263577511048, -0.9758409622188436, -0.963364359975941, -0.950843954085657, -0.9382903466374097, -0.9257145790974758, -0.9131281536783002, -0.9005430553944817, -0.8879717746796714, -0.8754273303981189, -0.8629232930365376, -0.8504738078054975, -0.8380936173137751, -0.8257980834032306, -0.8136032076452319, -0.8015256499020241, -0.7895827442478881, -0.777792511426034, -0.7661736668894673, -0.7547456233400109, -0.7435284865431314, -0.7325430430626597, -0.7218107384362604, -0.7113536442091325, -0.7011944121717203, -0.691356214121305, -0.6818626655034113, -0.672737731404662, -0.6640056135821747, -0.6556906175429656, -0.6478169991441983, -0.6404087907800399, -0.6334896079535207, -0.6270824378908983, -0.6212094128164266, -0.615891571526167, -0.611148613923624, -0.606998654136349, -0.6034579786400677, -0.600540816390986, -0.5982591282291296, -0.5966224227032313, -0.595637604944163, -0.5953088642766623, -0.5956376049441636, -0.5966224227032325, -0.5982591282291317, -0.6005408163909887, -0.6034579786400711, -0.6069986541363531, -0.6111486139236285, -0.6158915715261722, -0.6212094128164325, -0.6270824378909047, -0.6334896079535276, -0.6404087907800472, -0.6478169991442061, -0.655690617542974, -0.6640056135821835, -0.6727377314046712, -0.6818626655034209, -0.6913562141213149, -0.7011944121717307, -0.7113536442091432, -0.7218107384362713, -0.7325430430626708, -0.7435284865431429, -0.7547456233400225, -0.7661736668894793, -0.7777925114260462, -0.7895827442479003, -0.8015256499020365, -0.8136032076452443, -0.8257980834032431, -0.8380936173137876, -0.8504738078055103, -0.8629232930365504, -0.8754273303981316, -0.8879717746796844, -0.9005430553944945, -0.9131281536783133, -0.9257145790974887, -0.9382903466374227, -0.9508439540856699, -0.9633643599759539, -0.9758409622188566, -0.9882635775110608, -1.000622421586956, -1.0129080903533694, -1.0251115419294519, -1.0372240795986745, -1.0492373356679467, -1.061143256219506, -1.0729340867340638, -1.0846023585583193, -1.0961408761860825, -1.1075427053195541, -1.1188011616756623, -1.129909800501416, -1.1408624067620152, -1.1516529859656441, -1.1622757555895102, -1.1727251370725806, -1.182995748341577, -1.1930823968380622, -1.2029800730158215, -1.21268394427917, -1.222189349334284, -1.2314917929271283, -1.2405869409430104, -1.2494706158442157, -1.2581387924235858, -1.2665875938532316, -1.2748132880088803, -1.2828122840515874, -1.290581129249723, -1.2981165060252633, -1.3054152292094932, -1.3124742434942036, -1.3192906210654445, -1.3258615594077674, -1.3321843792677417, -1.338256522766318, -1.3440755516503518, -1.349639145674311, -1.3549451011038243, -1.359991329333372, -1.3647758556109786, -1.3692968178633165, -1.3735524656151492, -1.377541158997516, -1.3812613678395196, -1.3847116708390022, -1.3878907548078085, -1.39079741398771, -1.3934305494334347, -1.3957891684595929, -1.3978723841486125, -1.3996794149171277, -1.4012095841385523, -1.402462319819873, -1.4034371543309705, -1.404133724185064, -1.404551769869118], [-1.4299677417862213, -1.42982228844288, -1.429385980372285, -1.4286589734751496, -1.4276415276608563, -1.4263340069602024, -1.4247368796841338, -1.4228507186293737, -1.4206762013321101, -1.4182141103711887, -1.4154653337225196, -1.412430865166723, -1.409111804752306, -1.405509359317015, -1.401624843070296, -1.3974596782401776, -1.3930153957882234, -1.3882936361966067, -1.3832961503317538, -1.3780248003894313, -1.372481560926634, -1.36666851998608, -1.3605878803196834, -1.3542419607179028, -1.3476331974524753, -1.3407641458406823, -1.3336374819399766, -1.3262560043825422, -1.318622636360146, -1.3107404277704844, -1.3026125575371428, -1.29424233611627, -1.2856332082041089, -1.2767887556606567, -1.2677127006659432, -1.2584089091266986, -1.248881394352582, -1.2391343210226164, -1.229172009464062, -1.218998940267644, -1.208619759264847, -1.1980392828948845, -1.1872625039909537, -1.1762945980175086, -1.1651409297924804, -1.1538070607306792, -1.1422987566469869, -1.1306219961603765, -1.1187829797422624, -1.1067881394551298, -1.0946441494298, -1.0823579371319734, -1.0699366954707759, -1.0573878958038512, -1.0447193018949144, -1.031938984880511, -1.019055339302779, -1.0060771002640831, -0.9930133617571819, -0.9798735962207591, -0.9666676753642811, -0.9534058922977429, -0.9400989849903221, -0.9267581610666036, -0.9133951239290101, -0.900022100169448, -0.8866518682008319, -0.8732977879988782, -0.8599738317948898, -0.8466946154997589, -0.833475430566357, -0.8203322759102062, -0.8072818894051333, -0.7943417783499067, -0.7815302481623662, -0.7688664283985056, -0.7563702950153324, -0.7440626875993, -0.7319653200694739, -0.7201007831412686, -0.7084925366103267, -0.6971648892979819, -0.6861429643049217, -0.6754526470677488, -0.6651205136285316, -0.6551737365389876, -0.6456399659611685, -0.6365471838297986, -0.6279235294410888, -0.6197970955572306, -0.61219569508276, -0.6051465995800331, -0.5986762523246933, -0.5928099602081998, -0.5875715704910828, -0.5829831400833138, -0.5790646065356932, -0.575833471110929, -0.573304505007955, -0.5714894899021729, -0.5703970033454343, -0.5700322582137787, -0.5703970033454351, -0.5714894899021743, -0.5733045050079572, -0.5758334711109319, -0.5790646065356968, -0.5829831400833183, -0.5875715704910879, -0.5928099602082054, -0.5986762523246997, -0.60514659958004, -0.6121956950827675, -0.6197970955572386, -0.6279235294410974, -0.6365471838298077, -0.6456399659611781, -0.6551737365389976, -0.6651205136285421, -0.6754526470677595, -0.686142964304933, -0.6971648892979935, -0.7084925366103384, -0.7201007831412806, -0.731965320069486, -0.7440626875993125, -0.756370295015345, -0.7688664283985187, -0.7815302481623793, -0.79434177834992, -0.8072818894051468, -0.8203322759102195, -0.8334754305663705, -0.8466946154997725, -0.8599738317949034, -0.873297787998892, -0.8866518682008458, -0.9000221001694616, -0.913395123929024, -0.9267581610666173, -0.9400989849903358, -0.9534058922977566, -0.9666676753642948, -0.9798735962207724, -0.9930133617571953, -1.0060771002640967, -1.0190553393027924, -1.031938984880524, -1.0447193018949275, -1.0573878958038643, -1.0699366954707887, -1.0823579371319862, -1.0946441494298125, -1.106788139455142, -1.1187829797422746, -1.1306219961603887, -1.1422987566469986, -1.153807060730691, -1.165140929792492, -1.17629459801752, -1.1872625039909648, -1.1980392828948956, -1.2086197592648578, -1.2189989402676542, -1.2291720094640721, -1.2391343210226267, -1.2488813943525918, -1.258408909126708, -1.2677127006659528, -1.2767887556606659, -1.285633208204118, -1.2942423361162787, -1.3026125575371512, -1.3107404277704926, -1.318622636360154, -1.32625600438255, -1.333637481939984, -1.3407641458406896, -1.3476331974524822, -1.3542419607179093, -1.3605878803196896, -1.366668519986086, -1.3724815609266399, -1.378024800389437, -1.383296150331759, -1.3882936361966118, -1.3930153957882279, -1.397459678240182, -1.4016248430703002, -1.405509359317019, -1.4091118047523095, -1.4124308651667261, -1.4154653337225227, -1.4182141103711912, -1.4206762013321128, -1.4228507186293757, -1.4247368796841355, -1.4263340069602037, -1.4276415276608572, -1.4286589734751503, -1.4293859803722857, -1.4298222884428802], [-1.4557958172439769, -1.4556443619541763, -1.4551900480811135, -1.4544330316343368, -1.4533735726983266, -1.4520120355357886, -1.4503488887331604, -1.4483847053892238, -1.4461201633479899, -1.443556045477297, -1.4406932399948373, -1.437532740843619, -1.4340756481191856, -1.4303231685512154, -1.426276616042469, -1.421937412268401, -1.4173070873411218, -1.4123872805417885, -1.407179741125931, -1.4016863292066524, -1.3959090167211359, -1.389849888486391, -1.3835111433507261, -1.3768950954480232, -1.3700041755625276, -1.362840932612546, -1.355408035262189, -1.3477082736710932, -1.3397445613929089, -1.3315199374342863, -1.3230375684870912, -1.3143007513476748, -1.3053129155382048, -1.2960776261463427, -1.2865985869009346, -1.2768796435028882, -1.2669247872320184, -1.2567381588524125, -1.246324052840745, -1.2356869219640316, -1.2248313822355086, -1.2137622182797085, -1.2024843891403525, -1.1910030345674176, -1.1793234818226868, -1.1674512530461907, -1.1553920732293128, -1.1431518788438157, -1.13073682717978, -1.1181533064493079, -1.1054079467168758, -1.092507631721342, -1.0794595116588095, -1.0662710169997118, -1.0529498734175569, -1.039504117910586, -1.025942116201043, -1.0122725814995734, -0.9985045947242295, -0.9846476262643146, -0.9707115593784369, -0.9567067153131357, -0.9426438802226709, -0.9285343339612249, -0.9143898808049249, -0.9002228821415849, -0.8860462911395398, -0.8718736893717547, -0.8577193253256323, -0.8435981546704262, -0.8295258820803212, -0.8155190043193128, -0.8015948541808336, -0.7877716447374328, -0.7740685131903248, -0.7605055634121894, -0.7471039060465189, -0.7338856947614106, -0.7208741569548589, -0.7080936168746098, -0.6955695087542058, -0.6833283771883271, -0.6713978615913083, -0.6598066612265745, -0.648584476994303, -0.6377619259620544, -0.627370424570402, -0.6174420366031512, -0.6080092824454373, -0.5991049069284459, -0.590761604233753, -0.5830116999403899, -0.5758867923473787, -0.5694173576495442, -0.563632326280863, -0.558558640596216, -0.5542208068030497, -0.5506404563926544, -0.5478359339484408, -0.5458219288375057, -0.5446091677021494, -0.5442041827560231, -0.5446091677021503, -0.5458219288375072, -0.5478359339484433, -0.5506404563926575, -0.5542208068030537, -0.5585586405962207, -0.5636323262808686, -0.5694173576495505, -0.5758867923473858, -0.5830116999403977, -0.5907616042337612, -0.5991049069284548, -0.6080092824454467, -0.6174420366031613, -0.6273704245704126, -0.6377619259620653, -0.6485844769943143, -0.6598066612265863, -0.6713978615913205, -0.6833283771883396, -0.6955695087542183, -0.7080936168746228, -0.7208741569548721, -0.7338856947614241, -0.7471039060465325, -0.7605055634122032, -0.7740685131903389, -0.787771644737447, -0.801594854180848, -0.8155190043193269, -0.8295258820803355, -0.8435981546704407, -0.857719325325647, -0.8718736893717691, -0.8860462911395545, -0.9002228821415993, -0.9143898808049394, -0.9285343339612393, -0.9426438802226854, -0.9567067153131503, -0.9707115593784512, -0.9846476262643288, -0.9985045947242436, -1.0122725814995877, -1.025942116201057, -1.0395041179105997, -1.0529498734175706, -1.0662710169997252, -1.0794595116588228, -1.0925076317213553, -1.105407946716889, -1.1181533064493208, -1.1307368271797926, -1.1431518788438286, -1.1553920732293255, -1.1674512530462031, -1.1793234818226987, -1.1910030345674296, -1.202484389140364, -1.21376221827972, -1.2248313822355197, -1.2356869219640427, -1.246324052840756, -1.2567381588524231, -1.2669247872320286, -1.276879643502898, -1.2865985869009446, -1.2960776261463522, -1.3053129155382144, -1.314300751347684, -1.3230375684871, -1.331519937434295, -1.3397445613929173, -1.3477082736711012, -1.3554080352621969, -1.3628409326125532, -1.370004175562535, -1.3768950954480301, -1.383511143350733, -1.3898498884863972, -1.395909016721142, -1.4016863292066581, -1.4071797411259366, -1.4123872805417936, -1.4173070873411264, -1.4219374122684056, -1.426276616042473, -1.4303231685512194, -1.4340756481191894, -1.4375327408436225, -1.4406932399948402, -1.4435560454773, -1.4461201633479923, -1.448384705389226, -1.4503488887331628, -1.45201203553579, -1.4533735726983275, -1.4544330316343377, -1.4551900480811142, -1.4556443619541768], [-1.482150375101679, -1.4819930111391635, -1.4815209712585165, -1.4807344114988006, -1.4796335919864712, -1.4782188770278355, -1.476490735239365, -1.474449739716752, -1.4720965682438332, -1.4694320035428061, -1.4664569335674098, -1.4631723518410493, -1.4595793578421365, -1.4556791574392336, -1.4514730633789144, -1.4469624958296246, -1.4421489829851677, -1.4370341617318647, -1.4316197783838451, -1.4259076894913765, -1.419899862727638, -1.4135983778598562, -1.407005427811282, -1.4001233198211065, -1.392954476710064, -1.3855014382601738, -1.3777668627178694, -1.369753528430567, -1.3614643356276719, -1.352902308357982, -1.3440705965965418, -1.334972478535176, -1.3256113630721968, -1.3159907925181953, -1.3061144455363276, -1.2959861403371855, -1.285609838150144, -1.274989646995054, -1.2641298257803095, -1.2530347887556754, -1.241709110350815, -1.2301575304332686, -1.2183849600226644, -1.2063964875012698, -1.1941973853645773, -1.1817931175595326, -1.1691893474622421, -1.1563919465515633, -1.1434070038399076, -1.1302408361278788, -1.1168999991550266, -1.1033912997250188, -1.0897218088899192, -1.0758988762849462, -1.0619301457120662, -1.0478235720779432, -1.0335874397990161, -1.0192303827936897, -1.0047614061885353, -0.9901899098718059, -0.9755257140330472, -0.9607790868316983, -0.9459607743397106, -0.9310820329025844, -0.9161546640588548, -0.9011910521487251, -0.8862042047267046, -0.8712077958688719, -0.8562162124304223, -0.8412446032606915, -0.8263089313174681, -0.811426028536171, -0.7966136531977162, -0.7818905493963135, -0.7672765080291328, -0.7527924285073065, -0.7384603801155197, -0.7243036616190486, -0.7103468573271036, -0.6966158873661737, -0.6831380493965722, -0.6699420484246416, -0.6570580107347717, -0.6445174773127267, -0.6323533714917381, -0.6205999349792257, -0.6092926259884296, -0.598467973000062, -0.5881633778282842, -0.5784168622909515, -0.5692667540172242, -0.5607513088825062, -0.5529082703175536, -0.5457743693011834, -0.5393847731170933, -0.5337724957073896, -0.5289677873178502, -0.5249975256004452, -0.5218846338269403, -0.5196475537733256, -0.5182998006521455, -0.517849624898321, -0.5182998006521464, -0.5196475537733274, -0.5218846338269431, -0.5249975256004489, -0.5289677873178547, -0.533772495707395, -0.5393847731170995, -0.5457743693011904, -0.5529082703175614, -0.5607513088825147, -0.5692667540172334, -0.5784168622909611, -0.5881633778282944, -0.5984679730000729, -0.609292625988441, -0.6205999349792376, -0.6323533714917505, -0.6445174773127395, -0.6570580107347849, -0.6699420484246552, -0.6831380493965857, -0.6966158873661877, -0.7103468573271178, -0.7243036616190629, -0.7384603801155344, -0.7527924285073213, -0.7672765080291478, -0.7818905493963287, -0.7966136531977313, -0.8114260285361862, -0.8263089313174833, -0.8412446032607069, -0.8562162124304378, -0.8712077958688873, -0.88620420472672, -0.9011910521487403, -0.9161546640588705, -0.9310820329025997, -0.9459607743397258, -0.9607790868317134, -0.9755257140330625, -0.9901899098718211, -1.0047614061885501, -1.0192303827937046, -1.033587439799031, -1.0478235720779578, -1.0619301457120809, -1.0758988762849604, -1.0897218088899334, -1.1033912997250326, -1.1168999991550401, -1.1302408361278924, -1.1434070038399209, -1.1563919465515766, -1.1691893474622552, -1.1817931175595453, -1.19419738536459, -1.2063964875012825, -1.2183849600226764, -1.2301575304332804, -1.241709110350827, -1.253034788755687, -1.2641298257803206, -1.2749896469950648, -1.2856098381501548, -1.295986140337196, -1.3061144455363378, -1.3159907925182055, -1.3256113630722068, -1.3349724785351853, -1.344070596596551, -1.352902308357991, -1.361464335627681, -1.3697535284305753, -1.3777668627178776, -1.3855014382601818, -1.3929544767100717, -1.4001233198211136, -1.4070054278112885, -1.4135983778598626, -1.4198998627276445, -1.425907689491382, -1.431619778383851, -1.4370341617318698, -1.4421489829851724, -1.4469624958296294, -1.4514730633789183, -1.4556791574392378, -1.4595793578421403, -1.4631723518410529, -1.4664569335674131, -1.469432003542809, -1.4720965682438358, -1.4744497397167544, -1.4764907352393675, -1.478218877027837, -1.4796335919864727, -1.4807344114988013, -1.481520971258517, -1.4819930111391637], [-1.5090059190266825, -1.5088427463803278, -1.5083532804485815, -1.507537677269385, -1.5063961969593904, -1.5049292037945021, -1.5031371663234756, -1.501020657515417, -1.4985803549422805, -1.4958170409977214, -1.492731603153925, -1.4893250342583144, -1.4855984328723262, -1.481553003654763, -1.4771900577925285, -1.4725110134819275, -1.4675173964640467, -1.4622108406181438, -1.4565930886173764, -1.4506659926516554, -1.4444315152228941, -1.437891730018431, -1.43104882286899, -1.423905092798128, -1.4164629531708062, -1.4087249329494211, -1.4006936780664359, -1.3923719529235958, -1.3837626420286546, -1.3748687517815554, -1.3656934124231337, -1.3562398801606288, -1.346511539485639, -1.3365119057016226, -1.326244627679663, -1.3157134908629957, -1.3049224205427412, -1.2938754854294212, -1.2825769015472144, -1.27103103648047, -1.2592424140048728, -1.2472157191387694, -1.234955803653619, -1.2224676920863258, -1.2097565883003722, -1.196827882647246, -1.1836871597846839, -1.1703402072137632, -1.156793024602901, -1.1430518339734255, -1.1291230908285803, -1.115013496315669, -1.1007300105195497, -1.086279866994897, -1.0716705886545665, -1.056910005141993, -1.042006271826849, -1.0269678905750765, -1.0118037324567999, -0.9965230625683601, -0.981135567157537, -0.9656513832535839, -0.9500811310155373, -0.9344359490226857, -0.9187275327392552, -0.9029681763900951, -0.8871708184839546, -0.8713490912138566, -0.8555173739476003, -0.8396908509924326, -0.8238855737723929, -0.8081185274898964, -0.7924077022486655, -0.7767721684858824, -0.7612321563886505, -0.7458091387433535, -0.730525916374657, -0.7154067049609071, -0.7004772215510929, -0.6857647685421464, -0.6712983121928647, -0.6571085519450192, -0.6432279758937516, -0.6296908967108217, -0.61653346120642, -0.6037936255739818, -0.591511087286464, -0.5797271637307455, -0.5684846071530334, -0.5578273455610413, -0.5478001401422432, -0.5384481517787046, -0.5298164126083789, -0.5219492034570606, -0.5148893443453426, -0.5086774129302613, -0.5033509141492031, -0.4989434326601351, -0.49548380682078924, -0.492995367694664, -0.49149528777381407, -0.4909940809733175, -0.49149528777381507, -0.4929953676946661, -0.49548380682079224, -0.49894343266013913, -0.503350914149208, -0.5086774129302672, -0.5148893443453494, -0.5219492034570683, -0.5298164126083873, -0.538448151778714, -0.5478001401422531, -0.557827345561052, -0.5684846071530447, -0.5797271637307573, -0.5915110872864764, -0.6037936255739946, -0.6165334612064335, -0.6296908967108354, -0.6432279758937658, -0.6571085519450335, -0.6712983121928793, -0.6857647685421614, -0.7004772215511081, -0.7154067049609226, -0.7305259163746726, -0.7458091387433694, -0.7612321563886663, -0.7767721684858984, -0.7924077022486816, -0.8081185274899125, -0.8238855737724091, -0.8396908509924488, -0.8555173739476167, -0.8713490912138727, -0.887170818483971, -0.9029681763901112, -0.9187275327392714, -0.9344359490227018, -0.9500811310155534, -0.9656513832535999, -0.9811355671575528, -0.9965230625683761, -1.0118037324568154, -1.0269678905750923, -1.0420062718268643, -1.0569100051420082, -1.0716705886545816, -1.0862798669949119, -1.1007300105195643, -1.1150134963156837, -1.1291230908285945, -1.1430518339734397, -1.156793024602915, -1.170340207213777, -1.1836871597846974, -1.1968278826472591, -1.2097565883003856, -1.2224676920863387, -1.2349558036536317, -1.247215719138782, -1.2592424140048852, -1.2710310364804818, -1.2825769015472261, -1.293875485429433, -1.3049224205427525, -1.3157134908630068, -1.3262446276796735, -1.336511905701633, -1.3465115394856493, -1.3562398801606386, -1.3656934124231432, -1.3748687517815648, -1.3837626420286637, -1.3923719529236047, -1.4006936780664445, -1.4087249329494294, -1.4164629531708142, -1.4239050927981354, -1.4310488228689968, -1.437891730018438, -1.4444315152229008, -1.4506659926516616, -1.4565930886173821, -1.462210840618149, -1.4675173964640518, -1.4725110134819324, -1.477190057792533, -1.4815530036547675, -1.4855984328723304, -1.489325034258318, -1.4927316031539284, -1.4958170409977245, -1.4985803549422831, -1.5010206575154192, -1.5031371663234778, -1.5049292037945041, -1.5063961969593915, -1.5075376772693858, -1.5083532804485822, -1.5088427463803282], [-1.5363364680146776, -1.5361675924383227, -1.5356610177215688, -1.5348168999148073, -1.533635499146994, -1.532117179693495, -1.53026241007187, -1.5280717631663852, -1.5255459163822889, -1.5226856518311493, -1.519491856548768, -1.5159655227474875, -1.5121077481049607, -1.5079197360917604, -1.5034027963405021, -1.4985583450594937, -1.4933879054942685, -1.4878931084407354, -1.48207569281409, -1.475937506278049, -1.4694805059394622, -1.4627067591138347, -1.4556184441678823, -1.4482178514457997, -1.4405073842866114, -1.4324895601406662, -1.424167011794122, -1.4155424887111279, -1.4066188585043318, -1.3973991085453852, -1.3878863477282306, -1.3780838083992124, -1.3679948484694007, -1.357622953726049, -1.346971740361743, -1.3360449577416533, -1.3248464914313198, -1.3133803665096473, -1.3016507511942652, -1.2896619608091553, -1.2774184621274975, -1.26492487812605, -1.2521859931911192, -1.2392067588203288, -1.2259922998689903, -1.2125479213949748, -1.1988791161616588, -1.1849915728647775, -1.1708911851559929, -1.1565840615436813, -1.142076536259996, -1.1273751811926993, -1.11248681899069, -1.0974185374636678, -1.0821777054090338, -1.0667719900130213, -1.0512093759882601, -1.0354981866265365, -1.019647106963442, -1.0036652092709364, -0.9875619811144508, -0.9713473562329394, -0.9550317485229418, -0.9386260894308808, -0.9221418690808301, -0.9055911814870024, -0.8889867742199583, -0.8723421029113296, -0.8556713909913445, -0.8389896950535719, -0.8223129762279249, -0.8056581779107672, -0.789043310143029, -0.7724875408347216, -0.7560112938960711, -0.7396363541378335, -0.723385978529379, -0.7072850130326893, -0.6913600137400332, -0.6756393704064184, -0.6601534296567808, -0.6449346141344959, -0.6300175326184523, -0.6154390746569036, -0.601238481552434, -0.587457383618891, -0.5741397915991034, -0.5613320281263755, -0.5490825833605248, -0.5374418777559644, -0.526461914753432, -0.5161958075448607, -0.5066971674999393, -0.4980193478713823, -0.49021454533549963, -0.48333277373456324, -0.4774207384822818, -0.47252065521103725, -0.46866907043330425, -0.4658957528195272, -0.4642227286412914, -0.4636635319853224, -0.46422272864129255, -0.4658957528195295, -0.46866907043330763, -0.4725206552110417, -0.47742073848228733, -0.48333277373456984, -0.4902145453355072, -0.49801934787139074, -0.5066971674999488, -0.5161958075448709, -0.5264619147534428, -0.5374418777559761, -0.5490825833605372, -0.5613320281263884, -0.5741397915991169, -0.5874573836189049, -0.6012384815524484, -0.6154390746569183, -0.6300175326184675, -0.6449346141345115, -0.6601534296567966, -0.6756393704064343, -0.6913600137400495, -0.7072850130327057, -0.7233859785293957, -0.7396363541378502, -0.756011293896088, -0.7724875408347386, -0.7890433101430461, -0.8056581779107841, -0.822312976227942, -0.8389896950535892, -0.8556713909913616, -0.8723421029113466, -0.8889867742199756, -0.9055911814870193, -0.9221418690808472, -0.9386260894308975, -0.9550317485229587, -0.9713473562329562, -0.9875619811144675, -1.003665209270953, -1.0196471069634585, -1.035498186626553, -1.0512093759882764, -1.066771990013037, -1.0821777054090498, -1.0974185374636833, -1.1124868189907053, -1.1273751811927144, -1.142076536260011, -1.1565840615436958, -1.1708911851560075, -1.184991572864792, -1.1988791161616728, -1.2125479213949888, -1.225992299869004, -1.2392067588203421, -1.252185993191132, -1.264924878126063, -1.2774184621275104, -1.2896619608091677, -1.3016507511942774, -1.3133803665096595, -1.3248464914313314, -1.3360449577416647, -1.346971740361754, -1.3576229537260598, -1.367994848469411, -1.3780838083992226, -1.3878863477282406, -1.3973991085453947, -1.406618858504341, -1.415542488711137, -1.424167011794131, -1.4324895601406746, -1.4405073842866198, -1.4482178514458073, -1.4556184441678899, -1.4627067591138418, -1.4694805059394687, -1.4759375062780555, -1.482075692814096, -1.4878931084407407, -1.4933879054942736, -1.498558345059499, -1.5034027963405068, -1.507919736091765, -1.5121077481049647, -1.5159655227474913, -1.5194918565487718, -1.5226856518311525, -1.5255459163822918, -1.5280717631663874, -1.5302624100718727, -1.5321171796934967, -1.5336354991469952, -1.5348168999148084, -1.5356610177215695, -1.5361675924383231], [-1.564115581524634, -1.563941113653531, -1.563417762075247, -1.5625456829056896, -1.5613251363742418, -1.5597564868784373, -1.5578402030612402, -1.5555768579116738, -1.5529671288897589, -1.5500117980769637, -1.5467117523535778, -1.543067983604702, -1.5390815889567835, -1.534753771046901, -1.5300858383273104, -1.525079205408055, -1.5197353934407756, -1.5140560305472248, -1.5080428522963578, -1.5016977022342868, -1.4950225324718396, -1.488019404334942, -1.4806904890835757, -1.4730380687056324, -1.4650645367926265, -1.456772399504903, -1.448164276634745, -1.4392429027766096, -1.430011128614633, -1.4204719223385558, -1.410628371200322, -1.400483683224838, -1.3900411890897262, -1.3793043441904096, -1.3682767309085209, -1.3569620611034812, -1.3453641788491293, -1.3334870634395601, -1.3213348326908632, -1.3089117465682638, -1.2962222111713093, -1.2832707831132444, -1.2700621743346214, -1.2566012573955563, -1.242893071295916, -1.2289428278781698, -1.2147559188737393, -1.2003379236605025, -1.1856946178067456, -1.1708319824854185, -1.155756214852115, -1.1404737394909388, -1.1249912210444126, -1.1093155781570228, -1.0934539988770116, -1.077413957677805, -1.061203234279156, -1.0448299344689258, -1.0283025131495311, -1.0116297998586976, -0.9948210270423797, -0.977885861388688, -0.9608344385654337, -0.9436774017404166, -0.9264259443026591, -0.9090918572439992, -0.8916875817031032, -0.8742262672169189, -0.8567218362661247, -0.8391890557387867, -0.8216436159666362, -0.8041022180061836, -0.7865826698355013, -0.769103992107726, -0.7516865340319044, -0.7343520998245358, -0.7171240859701107, -0.7000276292192662, -0.6830897648052713, -0.6663395937321919, -0.6498084571321193, -0.6335301145480212, -0.6175409215120927, -0.6018799998966632, -0.5865893921656987, -0.5717141878256607, -0.5573026070903305, -0.5434060231428759, -0.530078900631842, -0.5173786245797249, -0.5053651913338157, -0.4941007324109844, -0.48364884416275067, -0.47407370231393986, -0.4654389517083772, -0.4578063786841137, -0.4512343961605593, -0.44577639816807896, -0.4414790679868561, -0.43838074759890805, -0.4365099903345916, -0.43588441847536596, -0.4365099903345928, -0.43838074759891066, -0.44147906798685993, -0.4457763981680839, -0.4512343961605655, -0.457806378684121, -0.4654389517083856, -0.4740737023139492, -0.48364884416276094, -0.49410073241099567, -0.5053651913338276, -0.5173786245797376, -0.5300789006318555, -0.5434060231428899, -0.5573026070903452, -0.5717141878256758, -0.5865893921657143, -0.6018799998966792, -0.6175409215121092, -0.6335301145480378, -0.6498084571321362, -0.6663395937322089, -0.6830897648052886, -0.7000276292192837, -0.7171240859701284, -0.7343520998245535, -0.7516865340319223, -0.769103992107744, -0.7865826698355192, -0.8041022180062016, -0.8216436159666541, -0.8391890557388048, -0.8567218362661427, -0.874226267216937, -0.8916875817031209, -0.909091857244017, -0.9264259443026771, -0.9436774017404344, -0.9608344385654514, -0.9778858613887057, -0.9948210270423972, -1.011629799858715, -1.028302513149548, -1.0448299344689427, -1.061203234279173, -1.0774139576778217, -1.093453998877028, -1.1093155781570387, -1.1249912210444286, -1.1404737394909548, -1.1557562148521305, -1.1708319824854339, -1.1856946178067609, -1.2003379236605174, -1.2147559188737542, -1.228942827878184, -1.24289307129593, -1.2566012573955703, -1.2700621743346348, -1.2832707831132577, -1.2962222111713224, -1.3089117465682767, -1.3213348326908758, -1.3334870634395724, -1.3453641788491415, -1.356962061103493, -1.3682767309085322, -1.3793043441904207, -1.3900411890897373, -1.4004836832248482, -1.410628371200332, -1.4204719223385658, -1.4300111286146429, -1.439242902776619, -1.448164276634754, -1.4567723995049116, -1.465064536792635, -1.4730380687056404, -1.480690489083583, -1.488019404334949, -1.4950225324718467, -1.5016977022342932, -1.5080428522963643, -1.5140560305472306, -1.519735393440781, -1.5250792054080604, -1.5300858383273155, -1.5347537710469052, -1.5390815889567877, -1.543067983604706, -1.546711752353581, -1.550011798076967, -1.5529671288897617, -1.555576857911676, -1.5578402030612426, -1.5597564868784388, -1.561325136374243, -1.56254568290569, -1.5634177620752476, -1.5639411136535313], [-1.5923163850583166, -1.5921364395920308, -1.5915966552801728, -1.590697188391904, -1.5894382994031377, -1.5878203530378328, -1.5858438183264885, -1.583509268682502, -1.5808173819972755, -1.5777689407551698, -1.5743648321695938, -1.5706060483417819, -1.5664936864440138, -1.5620289489293155, -1.5572131437699208, -1.552047684727074, -1.546534091655063, -1.5406739908426805, -1.5344691153956929, -1.5279213056642593, -1.5210325097196686, -1.513804783885216, -1.5062402933265349, -1.4983413127072385, -1.4901102269163202, -1.4815495318744158, -1.472661835426735, -1.4634498583312723, -1.4539164353517697, -1.4440645164658559, -1.433897168199868, -1.4234175751030267, -1.4126290413749385, -1.4015349926618703, -1.3901389780388305, -1.378444672196308, -1.3664558778525204, -1.354176528414254, -1.3416106909118855, -1.3287625692369736, -1.3156365077139374, -1.3022369950408537, -1.2885686686383468, -1.2746363194499737, -1.260444897242488, -1.245999516459968, -1.231305462692115, -1.2163681998241431, -1.2011933779437163, -1.1857868420894668, -1.1701546419358768, -1.1543030425208989, -1.1382385361358023, -1.121967855511578, -1.105497988453013, -1.0888361940905718, -1.0719900209417115, -1.0549673269975992, -1.0377763020786848, -1.020425492733636, -1.002923829991118, -0.9852806603132738, -0.967505780143893, -0.9496094744936043, -0.9316025600592805, -0.9134964334355029, -0.8953031250424074, -0.8770353594663353, -0.8587066229867907, -0.840331239143952, -0.8219244532832125, -0.8035025270934048, -0.7850828442281256, -0.7666840281570318, -0.748326073424726, -0.730030491482822, -0.7118204721836744, -0.6937210618515792, -0.675759358538112, -0.6579647245686393, -0.6403690157271247, -0.6230068253181332, -0.6059157397809684, -0.5891366003855592, -0.5727137626755475, -0.5566953416059313, -0.5411334256451215, -0.5260842374442484, -0.5116082121349049, -0.4977699572575078, -0.4846380514665671, -0.4722846337164748, -0.46078473239182793, -0.4502152871597973, -0.44065382786685064, -0.4321767970319126, -0.42485753670602694, -0.4187640056255593, -0.41395634414656846, -0.4104844539298284, -0.40838579522348095, -0.4076836149416835, -0.4083857952234824, -0.41048445392983124, -0.41395634414657273, -0.418764005625565, -0.4248575367060339, -0.4321767970319208, -0.44065382786685997, -0.45021528715980763, -0.4607847323918393, -0.4722846337164871, -0.4846380514665801, -0.4977699572575217, -0.5116082121349194, -0.5260842374442636, -0.5411334256451371, -0.5566953416059475, -0.5727137626755643, -0.5891366003855762, -0.6059157397809859, -0.6230068253181509, -0.6403690157271426, -0.6579647245686575, -0.6757593585381304, -0.6937210618515978, -0.7118204721836929, -0.7300304914828407, -0.7483260734247448, -0.7666840281570508, -0.7850828442281444, -0.8035025270934237, -0.8219244532832315, -0.8403312391439709, -0.8587066229868096, -0.8770353594663539, -0.895303125042426, -0.9134964334355217, -0.9316025600592992, -0.9496094744936227, -0.9675057801439114, -0.9852806603132919, -1.0029238299911363, -1.0204254927336538, -1.0377763020787025, -1.0549673269976165, -1.0719900209417288, -1.0888361940905888, -1.1054979884530298, -1.1219678555115946, -1.1382385361358192, -1.1543030425209153, -1.170154641935893, -1.1857868420894828, -1.201193377943732, -1.2163681998241587, -1.2313054626921305, -1.2459995164599829, -1.2604448972425029, -1.2746363194499883, -1.2885686686383608, -1.3022369950408674, -1.315636507713951, -1.3287625692369867, -1.3416106909118983, -1.354176528414267, -1.3664558778525326, -1.3784446721963197, -1.390138978038842, -1.401534992661882, -1.41262904137495, -1.4234175751030376, -1.4338971681998787, -1.4440645164658656, -1.4539164353517797, -1.4634498583312823, -1.4726618354267442, -1.4815495318744252, -1.490110226916329, -1.4983413127072467, -1.506240293326543, -1.5138047838852238, -1.521032509719676, -1.527921305664266, -1.5344691153956993, -1.5406739908426863, -1.5465340916550687, -1.5520476847270794, -1.5572131437699257, -1.5620289489293206, -1.5664936864440178, -1.5706060483417856, -1.5743648321695976, -1.577768940755173, -1.5808173819972786, -1.5835092686825043, -1.585843818326491, -1.587820353037835, -1.5894382994031389, -1.5906971883919057, -1.5915966552801737, -1.5921364395920312], [-1.620911596159626, -1.6207262911103784, -1.6201704281408038, -1.6192441637909225, -1.6179477589792188, -1.616281579030623, -1.614246093716285, -1.6118418773057541, -1.609069608632345, -1.6059300711726845, -1.6024241531415957, -1.598552847603704, -1.5943172526033595, -1.5897185713146904, -1.58475811221385, -1.5794372892757838, -1.5737576221981024, -1.567720736654969, -1.5613283645842106, -1.5545823445112252, -1.5474846219136376, -1.5400372496310617, -1.5322423883247924, -1.524102306992739, -1.5156193835454659, -1.5067961054497903, -1.497635070447077, -1.4881389873540667, -1.4783106769549121, -1.4681530729939725, -1.4576692232799209, -1.446862290912816, -1.435735555647024, -1.424292415404244, -1.4125363879524087, -1.4004711127679599, -1.3881003531008826, -1.3754279982640418, -1.3624580661707564, -1.3491947061472427, -1.335642202049594, -1.3218049757183792, -1.3076875908077923, -1.2932947570306321, -1.2786313348653158, -1.263702340776678, -1.2485129530086303, -1.2330685180138936, -1.2173745575941533, -1.2014367768332233, -1.1852610729163273, -1.1688535449405995, -1.152220504835583, -1.1353684895281395, -1.1183042745040321, -1.1010348889388744, -1.08356763259453, -1.065910094703822, -1.0480701750970915, -1.0300561078593158, -1.0118764878467652, -0.9935403004383274, -0.9750569549494152, -0.9564363221967332, -0.9376887767710256, -0.9188252446532893, -0.8998572568988061, -0.8807970102136671, -0.8616574353610125, -0.8424522744594518, -0.8231961683739127, -0.803904755548495, -0.7845947837892684, -0.7652842366677127, -0.7459924763747872, -0.726740404998892, -0.7075506463090253, -0.6884477501686225, -0.6694584216442319, -0.6506117766469597, -0.6319396254704814, -0.6134767847537376, -0.5952614170471328, -0.5773353951004331, -0.5597446849707286, -0.5425397377744368, -0.5257758740529511, -0.509513636974885, -0.4938190807453283, -0.4787639486659961, -0.46442568179319194, -0.4508871853572941, -0.4382362684606097, -0.4265646669225387, -0.4159665648275677, -0.40653655359967167, -0.3983670139171446, -0.39154497788263265, -0.3861486223205051, -0.382243645165008, -0.37987986231779436, -0.3790884038403738, -0.379879862317796, -0.3822436451650112, -0.38614862232050995, -0.39154497788263887, -0.3983670139171523, -0.4065365535996808, -0.41596656482757804, -0.4265646669225501, -0.4382362684606223, -0.45088718535730754, -0.46442568179320637, -0.4787639486660112, -0.49381908074534414, -0.5095136369749015, -0.5257758740529681, -0.5425397377744543, -0.5597446849707466, -0.5773353951004515, -0.5952614170471514, -0.6134767847537566, -0.6319396254705004, -0.650611776646979, -0.6694584216442514, -0.688447750168642, -0.707550646309045, -0.7267404049989118, -0.7459924763748069, -0.7652842366677325, -0.7845947837892882, -0.8039047555485148, -0.8231961683739326, -0.8424522744594717, -0.8616574353610322, -0.8807970102136867, -0.8998572568988258, -0.9188252446533086, -0.9376887767710449, -0.9564363221967525, -0.9750569549494342, -0.9935403004383464, -1.011876487846784, -1.0300561078593344, -1.04807017509711, -1.0659100947038402, -1.083567632594548, -1.101034888938892, -1.11830427450405, -1.1353684895281568, -1.1522205048356, -1.1688535449406166, -1.185261072916344, -1.2014367768332397, -1.2173745575941695, -1.2330685180139096, -1.248512953008646, -1.2637023407766936, -1.278631334865331, -1.2932947570306472, -1.307687590807807, -1.3218049757183938, -1.335642202049608, -1.3491947061472567, -1.36245806617077, -1.375427998264055, -1.3881003531008953, -1.4004711127679725, -1.412536387952421, -1.4242924154042556, -1.4357355556470357, -1.446862290912827, -1.4576692232799318, -1.4681530729939833, -1.4783106769549226, -1.4881389873540765, -1.4976350704470867, -1.5067961054497998, -1.5156193835454748, -1.5241023069927475, -1.5322423883248004, -1.5400372496310692, -1.5474846219136449, -1.5545823445112321, -1.5613283645842173, -1.5677207366549752, -1.5737576221981082, -1.5794372892757895, -1.5847581122138554, -1.5897185713146953, -1.5943172526033642, -1.5985528476037083, -1.6024241531415997, -1.6059300711726883, -1.609069608632348, -1.611841877305757, -1.614246093716288, -1.6162815790306249, -1.6179477589792204, -1.6192441637909234, -1.6201704281408045, -1.6207262911103786], [-1.649873550808615, -1.6496830068133812, -1.6491114271445872, -1.6481589687558702, -1.646825893246419, -1.645112566875921, -1.6430194605860307, -1.6405471500288773, -1.637696315603318, -1.6344677424997978, -1.6308623207548438, -1.626881045316417, -1.6225250161215152, -1.617795438187644, -1.6126936217199632, -1.6072209822361716, -1.6013790407114146, -1.5951694237457796, -1.5885938637572306, -1.5816541992031377, -1.5743523748339086, -1.5666904419825842, -1.5586705588946907, -1.5502949911030606, -1.5415661118528492, -1.5324864025824934, -1.5230584534669802, -1.5132849640304287, -1.503168743835744, -1.4927127132599045, -1.4819199043643465, -1.470793461870932, -1.4593366442550915, -1.4475528249690095, -1.435445493809111, -1.4230182584436957, -1.4102748461183252, -1.3972191055585683, -1.38385500909193, -1.3701866550133353, -1.3562182702213645, -1.341954213155671, -1.327398977069647, -1.3125571936765468, -1.2974336372119573, -1.2820332289608516, -1.2663610423035356, -1.2504223083417314, -1.2342224221739568, -1.2177669498984318, -1.2010616364321023, -1.1841124142463058, -1.1669254131332665, -1.1495069711333747, -1.1318636467713372, -1.1140022327702386, -1.0959297714367409, -1.0776535719386477, -1.0591812297284742, -1.040520648404264, -1.021680064342512, -1.0026680744887337, -0.9834936677500995, -0.964166260503006, -0.9446957368080425, -0.9250924940172793, -0.9053674945661834, -0.8855323248669664, -0.8655992623641828, -0.8455813519794921, -0.8254924933631421, -0.8053475405872573, -0.7851624161620532, -0.7649542415311192, -0.7447414865042794, -0.7245441404110243, -0.7043839080934119, -0.6842844341851351, -0.6642715594107146, -0.6443736128334979, -0.6246217440031983, -0.605050298682692, -0.5856972410932666, -0.5666046241552029, -0.5478191066654604, -0.5293925122736205, -0.5113824188813901, -0.49385275796023975, -0.4768743904430562, -0.46052560856163444, -0.4448924909136486, -0.4300690116984874, -0.41615677671858753, -0.4032642334010131, -0.39150518848837546, -0.3809964779584966, -0.37185468450472736, -0.36419190190657397, -0.3581107060543971, -0.35369869231075335, -0.35102313472527163, -0.3501264491913849, -0.3510231347252735, -0.353698692310757, -0.3581107060544025, -0.364191901906581, -0.37185468450473597, -0.38099647795850683, -0.3915051884883869, -0.40326423340102574, -0.4161567767186014, -0.4300690116985022, -0.44489249091366423, -0.46052560856165087, -0.47687439044307334, -0.49385275796025757, -0.5113824188814086, -0.5293925122736393, -0.5478191066654796, -0.5666046241552223, -0.5856972410932865, -0.605050298682712, -0.6246217440032185, -0.6443736128335182, -0.6642715594107349, -0.6842844341851555, -0.7043839080934327, -0.7245441404110452, -0.7447414865043, -0.7649542415311401, -0.7851624161620738, -0.805347540587278, -0.8254924933631628, -0.8455813519795127, -0.8655992623642034, -0.8855323248669867, -0.9053674945662039, -0.9250924940172996, -0.9446957368080627, -0.9641662605030261, -0.9834936677501193, -1.0026680744887535, -1.0216800643425314, -1.040520648404283, -1.0591812297284933, -1.0776535719386666, -1.0959297714367597, -1.114002232770257, -1.1318636467713554, -1.1495069711333927, -1.1669254131332842, -1.184112414246323, -1.2010616364321194, -1.217766949898449, -1.2342224221739737, -1.2504223083417478, -1.266361042303552, -1.2820332289608676, -1.297433637211973, -1.312557193676562, -1.327398977069662, -1.3419542131556856, -1.3562182702213792, -1.3701866550133495, -1.383855009091944, -1.3972191055585819, -1.4102748461183388, -1.4230182584437083, -1.4354454938091237, -1.4475528249690217, -1.4593366442551037, -1.4707934618709435, -1.4819199043643578, -1.4927127132599154, -1.5031687438357548, -1.5132849640304389, -1.5230584534669904, -1.5324864025825031, -1.5415661118528583, -1.5502949911030695, -1.5586705588946992, -1.5666904419825924, -1.5743523748339163, -1.5816541992031452, -1.588593863757237, -1.5951694237457856, -1.6013790407114206, -1.6072209822361774, -1.6126936217199683, -1.6177954381876491, -1.6225250161215201, -1.626881045316421, -1.6308623207548478, -1.634467742499801, -1.6376963156033213, -1.6405471500288804, -1.6430194605860338, -1.645112566875923, -1.6468258932464204, -1.6481589687558713, -1.6491114271445881, -1.6496830068133819], [-1.6791742301846384, -1.6789785698787945, -1.6783916414713393, -1.6774136024929234, -1.6760447154960907, -1.6742853480577007, -1.6721359727827725, -1.6695971673102232, -1.6666696143210884, -1.6633541015499844, -1.6596515218006913, -1.6555628729669136, -1.651089258059432, -1.6462318852410287, -1.6409920678707677, -1.6353712245593979, -1.6293708792378674, -1.6229926612411694, -1.616238305409985, -1.6091096522128647, -1.601608647891989, -1.5937373446358656, -1.5854979007826835, -1.5768925810584347, -1.5679237568543445, -1.558593906548622, -1.5489056158780783, -1.538861578365739, -1.5284645958112215, -1.5177175788513775, -1.5066235475994936, -1.4951856323722499, -1.4834070745146324, -1.4712912273341188, -1.4588415571567153, -1.4460616445188428, -1.432955185510652, -1.4195259932881512, -1.405777999773547, -1.3917152575654892, -1.377341942083512, -1.362662353973888, -1.3476809218074637, -1.3324022051038449, -1.3168308977206273, -1.300971831651323, -1.284829981281283, -1.2684104681574109, -1.2517185663348889, -1.2347597083727087, -1.21753949205964, -1.2000636879636533, -1.1823382479109412, -1.1643693145159317, -1.1461632319013153, -1.127726557767666, -1.1090660769961243, -1.0901888169955045, -1.0711020650377736, -1.0518133878640052, -1.0323306538876553, -1.0126620583745551, -0.9928161520408478, -0.9728018735829295, -0.9526285867393752, -0.9323061225863025, -0.9118448278875266, -0.8912556204626949, -0.8705500527042863, -0.8497403845726724, -0.828839667632631, -0.8078618419708234, -0.7868218481583288, -0.7657357568021849, -0.7446209186716978, -0.7234961388944159, -0.7023818792959302, -0.6813004936043535, -0.6602765009423297, -0.6393369037584826, -0.618511557051927, -0.597833596322065, -0.5773399319717752, -0.5570718176494316, -0.5370754988370705, -0.5174029452809491, -0.4981126657462926, -0.4792705948407481, -0.46095102766948287, -0.44323755686374217, -0.4262239359155283, -0.4100147510498077, -0.3947257310470527, -0.38048346428272134, -0.36742423546013664, -0.35569166200460534, -0.34543283453240736, -0.3367927872615716, -0.3299073749789531, -0.3248950103232337, -0.3218481501912821, -0.32082576981536165, -0.3218481501912842, -0.3248950103232378, -0.32990737497895917, -0.3367927872615795, -0.34543283453241713, -0.3556916620046167, -0.3674242354601494, -0.38048346428273544, -0.39472573104706804, -0.4100147510498239, -0.42622393591554536, -0.44323755686376004, -0.46095102766950136, -0.47927059484076723, -0.4981126657463122, -0.5174029452809692, -0.537075498837091, -0.5570718176494523, -0.5773399319717962, -0.5978335963220862, -0.6185115570519482, -0.639336903758504, -0.6602765009423511, -0.6813004936043752, -0.7023818792959519, -0.7234961388944375, -0.7446209186717194, -0.7657357568022067, -0.7868218481583504, -0.8078618419708451, -0.8288396676326524, -0.849740384572694, -0.8705500527043077, -0.8912556204627161, -0.911844827887548, -0.9323061225863235, -0.9526285867393961, -0.97280187358295, -0.9928161520408685, -1.0126620583745756, -1.0323306538876753, -1.0518133878640252, -1.0711020650377934, -1.090188816995524, -1.1090660769961436, -1.127726557767685, -1.1461632319013344, -1.1643693145159504, -1.1823382479109594, -1.2000636879636712, -1.2175394920596578, -1.234759708372726, -1.2517185663349062, -1.2684104681574275, -1.2848299812812998, -1.3009718316513392, -1.3168308977206435, -1.3324022051038606, -1.3476809218074792, -1.3626623539739033, -1.377341942083527, -1.3917152575655036, -1.4057779997735609, -1.4195259932881654, -1.4329551855106655, -1.4460616445188559, -1.4588415571567284, -1.4712912273341314, -1.4834070745146448, -1.4951856323722617, -1.5066235475995051, -1.5177175788513886, -1.5284645958112322, -1.5388615783657493, -1.5489056158780885, -1.5585939065486316, -1.567923756854354, -1.5768925810584435, -1.585497900782692, -1.593737344635874, -1.6016086478919969, -1.6091096522128723, -1.616238305409992, -1.622992661241176, -1.6293708792378738, -1.6353712245594039, -1.6409920678707735, -1.646231885241034, -1.6510892580594367, -1.655562872966918, -1.659651521800695, -1.663354101549988, -1.6666696143210917, -1.6695971673102261, -1.6721359727827751, -1.6742853480577027, -1.6760447154960922, -1.6774136024929245, -1.6783916414713402, -1.6789785698787951], [-1.708785287772754, -1.7085846352226353, -1.7079827303353938, -1.7069797313984303, -1.7055759022176598, -1.7037716121080715, -1.7015673358809056, -1.6989636538278279, -1.6959612517026164, -1.6925609207009913, -1.6887635574393314, -1.6845701639331756, -1.6799818475765347, -1.6749998211231742, -1.6696254026712192, -1.6638600156525638, -1.6577051888287808, -1.6511625562953975, -1.6442338574966375, -1.6369209372529483, -1.629225745803886, -1.621150338869212, -1.6126968777313588, -1.6038676293427514, -1.5946649664618393, -1.5850913678221146, -1.5751494183388235, -1.5648418093585912, -1.5541713389577403, -1.5431409122956923, -1.5317535420305437, -1.520012348804679, -1.5079205618091538, -1.4954815194365472, -1.4826986700330884, -1.4695755727620825, -1.4561158985920555, -1.4423234314246098, -1.428202069378746, -1.4137558262504322, -1.3989888331684777, -1.383905340470367, -1.3685097198246752, -1.3528064666300599, -1.336800202724695, -1.3204956794444314, -1.3038977810730636, -1.2870115287339186, -1.2698420847787182, -1.252394757737453, -1.234675007901999, -1.216688453626641, -1.1984408784407912, -1.1799382390833124, -1.161186674584311, -1.1421925165395412, -1.1229623007451226, -1.1035027803868027, -1.0838209410092063, -1.0639240175273699, -1.0438195135864188, -1.0235152236269334, -1.0030192580749124, -0.9823400721483667, -0.9614864988598277, -0.9404677868984358, -0.9192936442003659, -0.8979742881665947, -0.8765205036677396, -0.8549437101934595, -0.8332560397665745, -0.8114704275591791, -0.7896007175309633, -0.7676617858722022, -0.7456696855910968, -0.7236418162551561, -0.701597123698503, -0.6795563354612016, -0.6575422388506001, -0.6355800098191601, -0.6136976023339489, -0.5919262095362652, -0.5703008096690096, -0.5488608113064065, -0.5276508135256205, -0.5067214967379385, -0.48613065799109095, -0.4659443991305957, -0.44623846490809965, -0.42709970749174814, -0.40862761912572393, -0.3909358200409114, -0.3741533082066993, -0.35842516799117147, -0.3439123017546822, -0.33078961560085923, -0.3192420118043222, -0.3094576063059774, -0.30161791213578837, -0.29588538524615204, -0.29238965885842294, -0.2912147122272459, -0.2923896588584253, -0.2958853852461567, -0.30161791213579536, -0.3094576063059865, -0.3192420118043332, -0.33078961560087194, -0.34391230175469645, -0.358425167991187, -0.3741533082067161, -0.3909358200409291, -0.4086276191257425, -0.4270997074917675, -0.4462384649081196, -0.4659443991306162, -0.48613065799111194, -0.5067214967379601, -0.5276508135256421, -0.5488608113064285, -0.5703008096690318, -0.5919262095362875, -0.6136976023339714, -0.6355800098191826, -0.6575422388506227, -0.6795563354612243, -0.7015971236985258, -0.7236418162551786, -0.7456696855911195, -0.7676617858722248, -0.7896007175309857, -0.8114704275592014, -0.8332560397665968, -0.8549437101934819, -0.8765205036677619, -0.8979742881666167, -0.9192936442003878, -0.9404677868984576, -0.9614864988598493, -0.982340072148388, -1.0030192580749338, -1.0235152236269545, -1.0438195135864394, -1.0639240175273905, -1.0838209410092268, -1.1035027803868227, -1.1229623007451424, -1.1421925165395608, -1.1611866745843304, -1.1799382390833315, -1.1984408784408103, -1.2166884536266596, -1.2346750079020175, -1.252394757737471, -1.269842084778736, -1.287011528733936, -1.3038977810730807, -1.3204956794444482, -1.3368002027247117, -1.352806466630076, -1.3685097198246912, -1.3839053404703827, -1.3989888331684932, -1.4137558262504473, -1.4282020693787607, -1.442323431424624, -1.4561158985920695, -1.469575572762096, -1.4826986700331017, -1.4954815194365603, -1.5079205618091664, -1.5200123488046913, -1.5317535420305555, -1.5431409122957036, -1.5541713389577514, -1.564841809358602, -1.575149418338834, -1.585091367822125, -1.5946649664618489, -1.6038676293427605, -1.6126968777313677, -1.6211503388692203, -1.629225745803894, -1.636920937252956, -1.6442338574966446, -1.6511625562954042, -1.6577051888287875, -1.66386001565257, -1.6696254026712245, -1.6749998211231796, -1.6799818475765391, -1.68457016393318, -1.688763557439335, -1.692560920700995, -1.69596125170262, -1.6989636538278305, -1.701567335880908, -1.7037716121080735, -1.705575902217661, -1.7069797313984314, -1.7079827303353943, -1.7085846352226361], [-1.7386780767871457, -1.7384725569786033, -1.7378560506330987, -1.7368287169868584, -1.735390821419838, -1.733542735435247, -1.7312849366312055, -1.7286180086648517, -1.7255426412093173, -1.722059629904099, -1.7181698762994355, -1.7138743877954328, -1.709174277576776, -1.7040707645440043, -1.6985651732424376, -1.692658933790004, -1.686353581805348, -1.67965075833777, -1.6725522098007322, -1.6650597879108335, -1.657175449634397, -1.6489012571440098, -1.6402393777876392, -1.631192084073194, -1.6217617536717381, -1.6119508694428726, -1.6017620194862001, -1.5911978972231904, -1.5802613015142353, -1.5689551368161994, -1.5572824133863472, -1.5452462475391848, -1.5328498619634718, -1.5200965861074844, -1.506989856641524, -1.493533218007709, -1.4797303230682577, -1.4655849338647913, -1.4511009225027005, -1.4362822721763175, -1.4211330783525835, -1.4056575501331199, -1.389860011817138, -1.3737449046905212, -1.3573167890697377, -1.3405803466330541, -1.32354038307592, -1.3062018311324626, -1.2885697540108894, -1.270649349297399, -1.2524459533910854, -1.2339650465415073, -1.2152122585713105, -1.1961933753788327, -1.1769143463303056, -1.1573812926685554, -1.137600517085453, -1.1175785146294224, -1.0973219851478053, -1.0768378474977347, -1.056133255799497, -1.0352156180545193, -1.0140926175078513, -0.9927722372043358, -0.9712627882712417, -0.9495729425611291, -0.9277117704111707, -0.9056887844240157, -0.8835139903568381, -0.861197946427218, -0.8387518326167529, -0.8161875318880385, -0.7935177256431991, -0.7707560062616634, -0.7479170101852156, -0.7250165757990535, -0.7020719313248908, -0.6791019191398775, -0.6561272644151036, -0.6331708977888328, -0.6102583440157144, -0.587418191224049, -0.5646826586094434, -0.5420882840853399, -0.5196767574822397, -0.4974959290126656, -0.47560102618979677, -0.4540561138227194, -0.43293582859162394, -0.4123274076772114, -0.39233300283144096, -0.37307221610445296, -0.3546846956191704, -0.3373324704505623, -0.3212014669509931, -0.3065013384078275, -0.2934624110028237, -0.2823283534887884, -0.2733433922773581, -0.26673385523746246, -0.26268568838859196, -0.26132192321285425, -0.2626856883885948, -0.266733855237468, -0.2733433922773661, -0.2823283534887987, -0.29346241100283615, -0.30650133840784183, -0.32120146695100904, -0.33733247045057957, -0.35468469561918886, -0.37307221610447233, -0.3923330028314612, -0.4123274076772322, -0.4329358285916454, -0.4540561138227413, -0.47560102618981914, -0.49749592901268824, -0.5196767574822627, -0.5420882840853631, -0.5646826586094669, -0.5874181912240726, -0.610258344015738, -0.6331708977888564, -0.656127264415127, -0.6791019191399011, -0.7020719313249143, -0.7250165757990771, -0.7479170101852393, -0.7707560062616868, -0.7935177256432224, -0.8161875318880617, -0.8387518326167761, -0.861197946427241, -0.883513990356861, -0.9056887844240383, -0.9277117704111933, -0.9495729425611515, -0.9712627882712639, -0.9927722372043579, -1.014092617507873, -1.0352156180545409, -1.0561332557995182, -1.076837847497756, -1.0973219851478262, -1.1175785146294432, -1.1376005170854733, -1.1573812926685754, -1.1769143463303253, -1.1961933753788525, -1.2152122585713299, -1.2339650465415262, -1.252445953391104, -1.2706493492974176, -1.2885697540109076, -1.3062018311324806, -1.3235403830759378, -1.3405803466330712, -1.3573167890697548, -1.3737449046905381, -1.3898600118171545, -1.4056575501331359, -1.421133078352599, -1.4362822721763329, -1.4511009225027156, -1.465584933864806, -1.479730323068272, -1.493533218007723, -1.5069898566415376, -1.520096586107498, -1.5328498619634852, -1.5452462475391975, -1.5572824133863592, -1.5689551368162111, -1.5802613015142468, -1.5911978972232013, -1.601762019486211, -1.6119508694428832, -1.6217617536717484, -1.6311920840732033, -1.640239377787648, -1.6489012571440183, -1.657175449634405, -1.6650597879108415, -1.6725522098007397, -1.679650758337777, -1.6863535818053546, -1.6926589337900106, -1.6985651732424434, -1.70407076454401, -1.709174277576781, -1.7138743877954374, -1.71816987629944, -1.7220596299041027, -1.7255426412093209, -1.7286180086648548, -1.7312849366312084, -1.733542735435249, -1.7353908214198395, -1.7368287169868593, -1.7378560506330996, -1.7384725569786041], [-1.768823677885037, -1.7686134162648677, -1.7679826848683293, -1.766931644081184, -1.7654605611925678, -1.7635698103644257, -1.7612598725889683, -1.758531335634421, -1.7553848939793926, -1.751821348736289, -1.747841607564263, -1.7434466845722905, -1.7386377002130564, -1.7334158811684204, -1.7277825602273496, -1.7217391761573064, -1.7152872735702116, -1.7084285027842157, -1.7011646196826746, -1.6934974855718592, -1.6854290670391043, -1.6769614358132952, -1.6680967686297696, -1.658837347101961, -1.6491855576023353, -1.6391438911554537, -1.6287149433462988, -1.6179014142473267, -1.606706108368095, -1.5951319346317188, -1.583181906382893, -1.570859141432718, -1.5581668621461848, -1.545108395578803, -1.5316871736696285, -1.5179067334987744, -1.5037707176184465, -1.489282874467621, -1.4744470588817098, -1.4592672327099563, -1.4437474655548885, -1.4278919356499786, -1.4117049308937302, -1.3951908500608075, -1.3783542042135575, -1.3611996183404202, -1.3437318332513943, -1.3259557077649038, -1.3078762212253308, -1.2894984763961372, -1.2708277027801307, -1.2518692604261443, -1.2326286442904717, -1.2131114892319979, -1.1933235757324996, -1.173270836448334, -1.1529593637172215, -1.1323954181645814, -1.111585438578577, -1.0905360532525534, -1.0692540930289134, -1.047746606320995, -1.026020876440803, -1.0040844416225179, -0.9819451182071164, -0.9596110275453436, -0.9370906272887426, -0.9143927478765754, -0.8915266351967428, -0.8685020006095792, -0.8453290797852597, -0.8220187021322324, -0.7985823730031862, -0.7750323713794043, -0.7513818663834202, -0.7276450567919742, -0.7038373387659189, -0.6799755083451225, -0.6560780069572989, -0.632165220365891, -0.6082598442675192, -0.5843873333098775, -0.5605764548347775, -0.5368599743818097, -0.5132755071380486, -0.489866578244943, -0.4666839451261408, -0.44378724624257254, -0.42124705134451595, -0.3991473947693952, -0.3775888682247264, -0.3566923187013075, -0.3366031156497392, -0.31749577846374727, -0.2995784320427041, -0.28309602003778994, -0.2683304293674694, -0.25559480086060293, -0.24521880127329798, -0.23752246495673277, -0.23277946464682847, -0.231176322114963, -0.23277946464683177, -0.2375224649567392, -0.24521880127330728, -0.2555948008606148, -0.26833042936748364, -0.2830960200378061, -0.2995784320427219, -0.31749577846376636, -0.3366031156497594, -0.35669231870132856, -0.3775888682247482, -0.3991473947694177, -0.42124705134453894, -0.4437872462425959, -0.4666839451261645, -0.489866578244967, -0.5132755071380728, -0.536859974381834, -0.560576454834802, -0.5843873333099021, -0.6082598442675438, -0.6321652203659154, -0.6560780069573234, -0.679975508345147, -0.7038373387659435, -0.7276450567919986, -0.7513818663834444, -0.7750323713794288, -0.7985823730032106, -0.8220187021322565, -0.8453290797852836, -0.868502000609603, -0.8915266351967664, -0.9143927478765989, -0.9370906272887658, -0.9596110275453665, -0.9819451182071394, -1.0040844416225405, -1.0260208764408254, -1.0477466063210177, -1.0692540930289351, -1.090536053252575, -1.1115854385785986, -1.1323954181646028, -1.1529593637172424, -1.1732708364483546, -1.1933235757325202, -1.2131114892320178, -1.2326286442904915, -1.2518692604261639, -1.2708277027801498, -1.2894984763961563, -1.3078762212253494, -1.3259557077649222, -1.3437318332514123, -1.361199618340438, -1.3783542042135748, -1.3951908500608246, -1.4117049308937468, -1.4278919356499948, -1.4437474655549047, -1.459267232709972, -1.474447058881725, -1.4892828744676363, -1.5037707176184614, -1.5179067334987886, -1.5316871736696422, -1.5451083955788167, -1.5581668621461984, -1.570859141432731, -1.5831819063829053, -1.595131934631731, -1.6067061083681067, -1.617901414247338, -1.62871494334631, -1.6391438911554643, -1.6491855576023455, -1.6588373471019706, -1.6680967686297792, -1.676961435813304, -1.685429067039113, -1.6934974855718674, -1.7011646196826824, -1.7084285027842228, -1.7152872735702183, -1.7217391761573129, -1.727782560227355, -1.7334158811684262, -1.7386377002130615, -1.7434466845722953, -1.7478416075642673, -1.751821348736293, -1.755384893979396, -1.7585313356344237, -1.761259872588971, -1.763569810364428, -1.7654605611925696, -1.7669316440811849, -1.7679826848683302, -1.768613416264868], [-1.7991929271442884, -1.7989780492112952, -1.7983334693287212, -1.7972593492378275, -1.7957559584808982, -1.7938236743616065, -1.7914629818897365, -1.7886744737104472, -1.7854588500183495, -1.7818169184567185, -1.7777495940022263, -1.7732578988356555, -1.7683429621991196, -1.763006020240395, -1.7572484158450437, -1.751071598457109, -1.7444771238892354, -1.7374666541231825, -1.730041957101811, -1.7222049065137204, -1.7139574815718717, -1.705301766787651, -1.6962399517419933, -1.6867743308553593, -1.6769073031585426, -1.6666413720664999, -1.655979145157619, -1.6449233339611211, -1.633476753755547, -1.6216423233816435, -1.60942306507328, -1.596822104310475, -1.5838426696990324, -1.5704880928818203, -1.5567618084872927, -1.5426673541215146, -1.5282083704106855, -1.5133886011020017, -1.4982118932316433, -1.4826821973697715, -1.466803567953655, -1.450580163721469, -1.434016248260935, -1.4171161906888483, -1.3998844664796881, -1.3823256584639942, -1.3644444580200716, -1.346245666485915, -1.3277341968221295, -1.308915075561126, -1.2897934450831607, -1.270374566265949, -1.2506638215618524, -1.230666718565177, -1.210388894142201, -1.1898361192085232, -1.169014304252506, -1.1479295057205237, -1.1265879333999698, -1.1049959589602665, -1.0831601258413655, -1.061087160714573, -1.0387839867834092, -1.0162577392444023, -0.9935157832915462, -0.9705657351264805, -0.9474154865330282, -0.9240732336943122, -0.9005475110794057, -0.8768472314123661, -0.852981732969914, -0.8289608357486017, -0.8047949084159745, -0.7804949484366512, -0.7560726783749847, -0.7315406621630366, -0.7069124461425113, -0.6822027310180144, -0.6574275825992926, -0.6326046915011108, -0.6077536949997192, -0.5828965782698535, -0.5580581775899044, -0.5332668152643985, -0.508555105573518, -0.48396098378076063, -0.45952902701762494, -0.4353121576581401, -0.4113738472375535, -0.3877909715758536, -0.36465750206441583, -0.34208924364823806, -0.3202298216848459, -0.2992580232609614, -0.27939630758397865, -0.26091963152212355, -0.24416243547018726, -0.22951951371345325, -0.217433900696578, -0.20836363091248816, -0.20272308218560967, -0.20080707285571164, -0.2027230821856136, -0.20836363091249577, -0.21743390069658897, -0.22951951371346707, -0.24416243547020344, -0.2609196315221418, -0.27939630758399847, -0.2992580232609824, -0.32022982168486797, -0.342089243648261, -0.36465750206443936, -0.38779097157587755, -0.41137384723757797, -0.43531215765816483, -0.45952902701764997, -0.4839609837807859, -0.5085551055735436, -0.5332668152644239, -0.55805817758993, -0.5828965782698791, -0.6077536949997446, -0.6326046915011362, -0.6574275825993181, -0.6822027310180397, -0.7069124461425365, -0.7315406621630618, -0.7560726783750098, -0.7804949484366763, -0.8047949084159993, -0.8289608357486264, -0.8529817329699385, -0.8768472314123906, -0.9005475110794298, -0.9240732336943361, -0.9474154865330522, -0.970565735126504, -0.9935157832915695, -1.0162577392444254, -1.0387839867834323, -1.061087160714596, -1.083160125841388, -1.104995958960289, -1.1265879333999917, -1.1479295057205454, -1.1690143042525276, -1.1898361192085447, -1.210388894142222, -1.2306667185651978, -1.2506638215618728, -1.2703745662659687, -1.2897934450831803, -1.3089150755611454, -1.3277341968221488, -1.346245666485934, -1.36444445802009, -1.3823256584640122, -1.3998844664797059, -1.4171161906888656, -1.434016248260952, -1.450580163721486, -1.4668035679536715, -1.4826821973697875, -1.4982118932316588, -1.513388601102017, -1.5282083704107003, -1.5426673541215292, -1.5567618084873072, -1.5704880928818343, -1.5838426696990462, -1.596822104310488, -1.6094230650732924, -1.621642323381656, -1.6334767537555592, -1.6449233339611324, -1.6559791451576302, -1.6666413720665108, -1.6769073031585533, -1.6867743308553693, -1.6962399517420028, -1.70530176678766, -1.7139574815718803, -1.7222049065137286, -1.7300419571018189, -1.7374666541231896, -1.744477123889242, -1.7510715984571157, -1.7572484158450494, -1.7630060202404008, -1.768342962199125, -1.7732578988356602, -1.7777495940022308, -1.7818169184567225, -1.7854588500183532, -1.78867447371045, -1.7914629818897392, -1.7938236743616087, -1.7957559584808995, -1.7972593492378286, -1.7983334693287218, -1.7989780492112961], [-1.8297564442776084, -1.8295370752200042, -1.8288790224853526, -1.8277824493785917, -1.8262476280428452, -1.824274939411828, -1.8218648731433733, -1.8190180275342203, -1.8157351094162615, -1.812016934034499, -1.8078644249069917, -1.803278613667141, -1.7982606398887075, -1.7928117508940102, -1.7869333015458229, -1.7806267540235374, -1.773893677584246, -1.7667357483094492, -1.7591547488382058, -1.7511525680875912, -1.7427312009614657, -1.733892748048622, -1.7246394153115228, -1.714973513766955, -1.7048974591600574, -1.6944137716333552, -1.6835250753925783, -1.6722340983712563, -1.6605436718962716, -1.6484567303568076, -1.635976310879381, -1.6231055530119478, -1.609847698420412, -1.5962060906012316, -1.5821841746142464, -1.567785496840335, -1.5530137047690484, -1.5378725468219807, -1.5223658722183524, -1.506497630890071, -1.4902718734544587, -1.4736927512538807, -1.4567645164727168, -1.4394915223434952, -1.4218782234556235, -1.4039291761819743, -1.3856490392407441, -1.3670425744124755, -1.3481146474350274, -1.3288702291026666, -1.3093143965993863, -1.2894523351012233, -1.2692893396877798, -1.2488308176096332, -1.228082290965929, -1.2070493998555385, -1.185737906075966, -1.1641536974571245, -1.1423027929326008, -1.1201913484697272, -1.0978256640023412, -1.0752121915375368, -1.0523575446410873, -1.0292685095470813, -1.005952058187511, -0.9824153634995385, -0.9586658174450154, -0.9347110522726542, -0.9105589656732556, -0.886217750629561, -0.8616959309537192, -0.8370024037491824, -0.8121464903462684, -0.7871379976634759, -0.7619872924694291, -0.7367053917033822, -0.7113040729109102, -0.6857960100423461, -0.6601949414515732, -0.6345158790718725, -0.6087753706457103, -0.5829918308482815, -0.5571859626019476, -0.5313812974507247, -0.5056048944441466, -0.47988825185356104, -0.4542685070484503, -0.42879002957971685, -0.40350655446570244, -0.37848406131234397, -0.353804685004515, -0.3295720479593858, -0.3059185257754867, -0.283015063333298, -0.2610841418890634, -0.24041609273655937, -0.22138757660358271, -0.20447766310362459, -0.19027041647096177, -0.17942417549889914, -0.17258506318876615, -0.17024355572239155, -0.17258506318877093, -0.17942417549890832, -0.19027041647097476, -0.20447766310364068, -0.22138757660360128, -0.24041609273657988, -0.26108414188908535, -0.28301506333332105, -0.30591852577551076, -0.3295720479594104, -0.3538046850045402, -0.37848406131236956, -0.4035065544657283, -0.42879002957974294, -0.4542685070484766, -0.4798882518535874, -0.5056048944441731, -0.5313812974507512, -0.5571859626019743, -0.5829918308483081, -0.6087753706457365, -0.6345158790718989, -0.6601949414515995, -0.6857960100423726, -0.7113040729109364, -0.7367053917034083, -0.7619872924694551, -0.7871379976635018, -0.8121464903462939, -0.8370024037492079, -0.8616959309537447, -0.8862177506295861, -0.9105589656732804, -0.9347110522726788, -0.95866581744504, -0.9824153634995628, -1.0059520581875352, -1.0292685095471052, -1.052357544641111, -1.07521219153756, -1.0978256640023645, -1.12019134846975, -1.1423027929326235, -1.164153697457147, -1.1857379060759883, -1.2070493998555603, -1.2280822909659506, -1.248830817609654, -1.2692893396878007, -1.2894523351012437, -1.3093143965994067, -1.3288702291026864, -1.3481146474350472, -1.3670425744124948, -1.3856490392407632, -1.4039291761819928, -1.4218782234556415, -1.4394915223435132, -1.4567645164727343, -1.4736927512538982, -1.4902718734544753, -1.5064976308900875, -1.5223658722183686, -1.5378725468219965, -1.5530137047690638, -1.56778549684035, -1.5821841746142609, -1.596206090601246, -1.6098476984204262, -1.6231055530119611, -1.6359763108793939, -1.6484567303568205, -1.6605436718962838, -1.6722340983712682, -1.6835250753925897, -1.6944137716333663, -1.7048974591600683, -1.7149735137669653, -1.7246394153115328, -1.733892748048631, -1.7427312009614746, -1.7511525680875997, -1.7591547488382135, -1.766735748309457, -1.7738936775842529, -1.7806267540235443, -1.7869333015458289, -1.7928117508940162, -1.7982606398887129, -1.803278613667146, -1.8078644249069962, -1.8120169340345031, -1.815735109416265, -1.8190180275342236, -1.8218648731433764, -1.82427493941183, -1.8262476280428466, -1.8277824493785928, -1.8288790224853535, -1.829537075220005], [-1.8604846610560841, -1.8602609254319462, -1.8595897735885951, -1.8584713706023206, -1.8569059915639674, -1.8548940215245266, -1.8524359554190786, -1.8495323979691858, -1.8461840635638809, -1.842391776119428, -1.838156468918058, -1.8334791844259333, -1.8283610740906138, -1.8228033981183556, -1.8168075252316038, -1.810374932407092, -1.8035072045950018, -1.7962060344197004, -1.7884732218626198, -1.7803106739279033, -1.771720404291516, -1.7627045329345852, -1.7532652857618145, -1.743404994205906, -1.733126094819019, -1.7224311288523948, -1.7113227418254062, -1.699803683085407, -1.687876805359911, -1.6755450643027898, -1.6628115180363574, -1.6496793266914147, -1.636151751947552, -1.6222321565762738, -1.6079240039897849, -1.5932308577986172, -1.578156381381646, -1.562704337472457, -1.5468785877665239, -1.5306830925541846, -1.514121910385046, -1.4971991977701622, -1.4799192089291489, -1.4622862955903595, -1.4443049068533371, -1.4259795891240286, -1.4073149861347187, -1.3883158390623582, -1.368986986760947, -1.3493333661259814, -1.3293600126116976, -1.309072060925069, -1.2884747459243076, -1.2675734037541035, -1.246373473255172, -1.224880497692006, -1.2031001268503165, -1.1810381195647135, -1.1587003467481163, -1.136092795007566, -1.1132215709471156, -1.0900929062779559, -1.066713163879747, -1.043088844986383, -1.0192265977055108, -0.9951332271258819, -0.9708157073223864, -0.9462811956385072, -0.921537049713942, -0.8965908478367048, -0.8714504133411989, -0.8461238439561963, -0.8206195472422931, -0.7949462835648758, -0.7691132184502305, -0.7431299867027039, -0.717006771366807, -0.6907544015661182, -0.664384474535261, -0.6379095089181023, -0.611343138832405, -0.5847003615893345, -0.5579978567377899, -0.5312544009285324, -0.5044914129495652, -0.47773367769031944, -0.45101031910324685, -0.42435612413091334, -0.39781336784197374, -0.37143436375194916, -0.3452850765706691, -0.3194503084992961, -0.29404123369537816, -0.26920643987162796, -0.2451481443697971, -0.22214575147008286, -0.20058881508741594, -0.18101890044811622, -0.16417024236181552, -0.1509754211463707, -0.14246751607536998, -0.1395153389439158, -0.14246751607537597, -0.15097542114638204, -0.16417024236183111, -0.18101890044813504, -0.20058881508743717, -0.22214575147010587, -0.24514814436982135, -0.2692064398716531, -0.294041233695404, -0.31945030849932243, -0.34528507657069585, -0.37143436375197614, -0.3978133678420009, -0.4243561241309407, -0.45101031910327427, -0.47773367769034697, -0.5044914129495929, -0.5312544009285598, -0.5579978567378174, -0.5847003615893618, -0.6113431388324322, -0.6379095089181294, -0.6643844745352881, -0.6907544015661453, -0.7170067713668341, -0.7431299867027308, -0.7691132184502572, -0.7949462835649022, -0.8206195472423194, -0.8461238439562225, -0.8714504133412247, -0.8965908478367307, -0.9215370497139674, -0.9462811956385325, -0.9708157073224116, -0.9951332271259068, -1.0192265977055357, -1.0430888449864073, -1.066713163879771, -1.0900929062779798, -1.1132215709471394, -1.1360927950075894, -1.1587003467481394, -1.1810381195647361, -1.2031001268503387, -1.2248804976920282, -1.2463734732551937, -1.2675734037541249, -1.2884747459243289, -1.3090720609250903, -1.3293600126117182, -1.3493333661260016, -1.368986986760967, -1.388315839062378, -1.4073149861347383, -1.4259795891240474, -1.4443049068533558, -1.4622862955903777, -1.4799192089291666, -1.4971991977701797, -1.5141219103850632, -1.5306830925542012, -1.5468785877665403, -1.5627043374724732, -1.5781563813816617, -1.5932308577986325, -1.6079240039897995, -1.622232156576288, -1.6361517519475661, -1.649679326691428, -1.6628115180363707, -1.6755450643028025, -1.6878768053599236, -1.699803683085419, -1.7113227418254182, -1.7224311288524063, -1.7331260948190295, -1.7434049942059164, -1.753265285761824, -1.7627045329345945, -1.7717204042915253, -1.7803106739279118, -1.788473221862628, -1.7962060344197077, -1.8035072045950085, -1.8103749324070988, -1.81680752523161, -1.8228033981183613, -1.828361074090619, -1.8334791844259384, -1.8381564689180627, -1.8423917761194322, -1.8461840635638849, -1.8495323979691891, -1.8524359554190815, -1.8548940215245286, -1.8569059915639687, -1.858471370602322, -1.859589773588596, -1.860260925431947], [-1.8913478499145329, -1.8911198713720723, -1.8904359914328355, -1.88929637714924, -1.887701306901918, -1.8856511703396643, -1.883146468295431, -1.8801878126784557, -1.876775926342604, -1.8729116429310653, -1.8685959066975297, -1.863829772304019, -1.8586144045955646, -1.8529510783519556, -1.8468411780167941, -1.8402861974041478, -1.8332877393831026, -1.8258475155405562, -1.8179673458226422, -1.809649158155192, -1.8008949880437055, -1.7917069781533348, -1.7820873778694377, -1.772038542839321, -1.7615629344958401, -1.7506631195636027, -1.7393417695485849, -1.7276016602120627, -1.7154456710298371, -1.70287678463785, -1.6898980862653794, -1.676512763157148, -1.6627241039858096, -1.6485354982564349, -1.6339504357048036, -1.6189725056915116, -1.603605396594121, -1.587852895199857, -1.5717188861016334, -1.5552073511005413, -1.5383223686183125, -1.5210681131237123, -1.5034488545773272, -1.4854689578997953, -1.4671328824692056, -1.448445181654169, -1.4294105023899795, -1.4100335848063354, -1.3903192619163185, -1.3702724593777855, -1.3498981953400064, -1.329201580390381, -1.3081878176184212, -1.2868622028169745, -1.26523012484397, -1.2432970661719263, -1.2210686036571878, -1.1985504095665285, -1.1757482529056078, -1.1526680011020591, -1.129315622106045, -1.1056971869834156, -1.0818188730916707, -1.057686967947481, -1.033307873917511, -1.008688113892846, -0.9838343381430862, -0.9587533325911199, -0.9334520288064646, -0.9079375160874691, -0.8822170560954273, -0.8562981006233209, -0.8301883132373978, -0.803895595733358, -0.7774281206176071, -0.750794371181682, -0.7240031912183369, -0.697063847079237, -0.669986105666676, -0.6427803331877345, -0.6154576212308607, -0.5880299491807931, -0.5605103955170775, -0.532913415685029, -0.5052552118374298, -0.4775542311843775, -0.4498318471810215, -0.4221133050213526, -0.394429056141703, -0.3668166764534911, -0.3393236787606508, -0.3120117250485135, -0.28496307983275804, -0.2582907303705947, -0.23215462121163874, -0.20678819608710633, -0.18254216743309326, -0.15995547822850043, -0.1398612826527609, -0.12350603786807961, -0.1125504828785645, -0.10865215008546714, -0.11255048287857237, -0.12350603786809393, -0.13986128265277983, -0.15995547822852252, -0.18254216743311746, -0.20678819608713195, -0.23215462121166525, -0.2582907303706219, -0.2849630798327857, -0.31201172504854147, -0.339323678760679, -0.3668166764535195, -0.39442905614173135, -0.4221133050213811, -0.44983184718104996, -0.477554231184406, -0.5052552118374583, -0.5329134156850575, -0.560510395517106, -0.5880299491808214, -0.6154576212308888, -0.6427803331877625, -0.6699861056667038, -0.6970638470792646, -0.7240031912183644, -0.7507943711817094, -0.7774281206176343, -0.8038955957333851, -0.8301883132374247, -0.8562981006233477, -0.8822170560954538, -0.9079375160874956, -0.9334520288064907, -0.9587533325911457, -0.983834338143112, -1.0086881138928714, -1.033307873917536, -1.0576869679475058, -1.0818188730916953, -1.1056971869834402, -1.1293156221060692, -1.152668001102083, -1.1757482529056316, -1.1985504095665518, -1.2210686036572111, -1.2432970661719491, -1.2652301248439923, -1.2868622028169967, -1.3081878176184432, -1.3292015803904023, -1.3498981953400273, -1.3702724593778062, -1.3903192619163387, -1.4100335848063557, -1.4294105023899994, -1.4484451816541881, -1.4671328824692247, -1.4854689578998141, -1.5034488545773455, -1.5210681131237302, -1.53832236861833, -1.5552073511005584, -1.57171888610165, -1.5878528951998736, -1.603605396594137, -1.618972505691527, -1.633950435704819, -1.6485354982564495, -1.6627241039858245, -1.6765127631571621, -1.6898980862653925, -1.7028767846378634, -1.71544567102985, -1.7276016602120747, -1.7393417695485969, -1.7506631195636142, -1.7615629344958514, -1.7720385428393315, -1.782087377869448, -1.7917069781533446, -1.8008949880437148, -1.8096491581552006, -1.8179673458226502, -1.8258475155405638, -1.8332877393831095, -1.8402861974041549, -1.8468411780168004, -1.8529510783519616, -1.8586144045955701, -1.863829772304024, -1.8685959066975342, -1.8729116429310695, -1.8767759263426078, -1.880187812678459, -1.8831464682954344, -1.8856511703396663, -1.8877013069019197, -1.889296377149241, -1.8904359914328366, -1.8911198713720725], [-1.9223161527110013, -1.922084053745497, -1.9213878132627347, -1.920227600491053, -1.9186036974346452, -1.9165164988090209, -1.9139665119507128, -1.9109543567012592, -1.9074807652655374, -1.90354658204453, -1.899152763442606, -1.8943003776494334, -1.888990604396654, -1.88322473468945, -1.8770041705131741, -1.870330424515217, -1.8632051196623074, -1.8556299888734686, -1.847606874628867, -1.8391377285548176, -1.8302246109852365, -1.820869690499848, -1.8110752434395005, -1.8008436533989571, -1.790177410697572, -1.779079111828303, -1.7675514588855354, -1.7555972589722642, -1.7432194235871967, -1.7304209679924243, -1.7172050105623486, -1.7035747721146306, -1.6895335752239913, -1.6750848435197938, -1.6602321009684131, -1.644978971141521, -1.6293291764715214, -1.6132865374955176, -1.5968549720893375, -1.5800384946933246, -1.5628412155318028, -1.5452673398283459, -1.5273211670192561, -1.5090070899679453, -1.4903295941832795, -1.4712932570453308, -1.45190274704247, -1.4321628230242662, -1.4120783334752995, -1.391654215815744, -1.3708954957354462, -1.349807286569265, -1.3283947887226462, -1.3066632891578598, -1.284618160953044, -1.262264862948243, -1.2396089394950973, -1.2166560203297885, -1.19341182059241, -1.1698821410202636, -1.1460728683478398, -1.1219899759526801, -1.0976395247942157, -1.0730276647024437, -1.0481606360853963, -1.0230447721394471, -0.9976865016654296, -0.9720923526173988, -0.9462689565411563, -0.9202230540983304, -0.8939615019215347, -0.8674912811105284, -0.8408195077633394, -0.8139534460468516, -0.7869005244580134, -0.7596683561231438, -0.7322647642481797, -0.704697814195107, -0.6769758541601936, -0.649107567128732, -0.6211020377701366, -0.5929688393559723, -0.564718147848513, -0.5363608933613458, -0.5079089637884748, -0.4793754824429374, -0.45077519256937953, -0.4221249992352799, -0.39344474803596774, -0.3647583687928208, -0.33609559702627756, -0.3074946376956036, -0.27900641764988904, -0.25070161795496776, -0.2226827737112088, -0.1951060281858607, -0.16822211773739454, -0.14245709281517907, -0.11857543344055704, -0.09799511288167106, -0.08322896995952223, -0.07768384728899864, -0.08322896995953323, -0.09799511288168976, -0.1185754334405802, -0.14245709281520474, -0.1682221177374217, -0.19510602818588874, -0.22268277371123743, -0.25070161795499674, -0.27900641764991824, -0.30749463769563296, -0.3360955970263071, -0.36475836879285034, -0.39344474803599716, -0.4221249992353094, -0.4507751925694089, -0.4793754824429667, -0.5079089637885041, -0.5363608933613752, -0.5647181478485422, -0.5929688393560012, -0.6211020377701655, -0.6491075671287606, -0.676975854160222, -0.7046978141951354, -0.7322647642482079, -0.7596683561231717, -0.7869005244580412, -0.8139534460468794, -0.8408195077633669, -0.8674912811105557, -0.8939615019215618, -0.9202230540983573, -0.9462689565411829, -0.9720923526174252, -0.9976865016654558, -1.0230447721394729, -1.0481606360854219, -1.0730276647024692, -1.0976395247942408, -1.121989975952705, -1.1460728683478645, -1.1698821410202878, -1.193411820592434, -1.2166560203298122, -1.2396089394951206, -1.262264862948266, -1.284618160953067, -1.3066632891578824, -1.3283947887226681, -1.349807286569287, -1.3708954957354673, -1.391654215815765, -1.4120783334753204, -1.4321628230242869, -1.45190274704249, -1.47129325704535, -1.490329594183299, -1.5090070899679644, -1.5273211670192743, -1.545267339828364, -1.5628412155318203, -1.5800384946933423, -1.5968549720893546, -1.6132865374955345, -1.6293291764715379, -1.6449789711415366, -1.6602321009684287, -1.675084843519809, -1.6895335752240062, -1.703574772114645, -1.7172050105623624, -1.7304209679924376, -1.7432194235872098, -1.7555972589722766, -1.7675514588855477, -1.779079111828315, -1.7901774106975836, -1.8008436533989678, -1.811075243439511, -1.8208696904998574, -1.8302246109852458, -1.8391377285548267, -1.8476068746288752, -1.8556299888734766, -1.8632051196623152, -1.8703304245152241, -1.8770041705131806, -1.8832247346894564, -1.8889906043966596, -1.894300377649439, -1.8991527634426109, -1.9035465820445348, -1.9074807652655412, -1.9109543567012623, -1.913966511950716, -1.9165164988090233, -1.9186036974346468, -1.9202276004910546, -1.9213878132627358, -1.9220840537454977], [-1.9533596096125903, -1.9531235113569507, -1.9524152737936546, -1.951235068519992, -1.9495831814861981, -1.9474600129275967, -1.944866077269632, -1.9418020030058256, -1.938268532548698, -1.934266522053705, -1.929796941216255, -1.9248608730418764, -1.919459513589615, -1.913594171688756, -1.9072662686289712, -1.9004773378240092, -1.8932290244490406, -1.8855230850518137, -1.8773613871377495, -1.8687459087291491, -1.8596787378986814, -1.8501620722773373, -1.8401982185370604, -1.8297895918482596, -1.818938715312445, -1.8076482193702357, -1.7959208411850056, -1.783759424002463, -1.7711669164864656, -1.758146372031416, -1.7447009480515845, -1.7308339052477604, -1.7165486068516416, -1.7018485178484155, -1.6867372041780249, -1.671218331915646, -1.6552956664319647, -1.6389730715338724, -1.6222545085862785, -1.6051440356157927, -1.5876458063971115, -1.5697640695230255, -1.5515031674590634, -1.5328675355839008, -1.5138617012167943, -1.4944902826334427, -1.4747579880718564, -1.4546696147300147, -1.4342300477573178, -1.4134442592421217, -1.3923173071979547, -1.3708543345513946, -1.3490605681350265, -1.326941317689427, -1.304501974878743, -1.281748012325184, -1.2586849826686277, -1.2353185176586257, -1.2116543272873865, -1.1876981989738826, -1.1634559968111478, -1.1389336608911766, -1.1141372067247193, -1.0890727247768188, -1.0637463801433764, -1.0381644123995346, -1.012333135657625, -0.9862589388811717, -0.9599482865125939, -0.9334077194865077, -0.9066438567188898, -0.8796633971862303, -0.8524731227399998, -0.8250799018429315, -0.7974906944684178, -0.7697125584779424, -0.7417526578913863, -0.7136182736020933, -0.6853168172787685, -0.6568558494634507, -0.628243103255222, -0.5994865155188154, -0.5705942683635976, -0.5415748448419198, -0.5124371046460406, -0.4831903884237157, -0.4538446638429222, -0.4244107338786899, -0.3949005400859227, -0.3653276148495324, -0.33570777458050577, -0.30606021654850457, -0.2764093199289719, -0.2467877351345683, -0.21724196556811293, -0.18784310465696927, -0.15870913183991997, -0.13005579167223102, -0.10232691659148421, -0.0765747291120776, -0.05565644496403768, -0.04664039038740978, -0.05565644496405471, -0.07657472911210234, -0.10232691659151197, -0.1300557916722601, -0.15870913183994975, -0.18784310465699938, -0.21724196556814324, -0.24678773513459876, -0.2764093199290024, -0.30606021654853505, -0.3357077745805363, -0.3653276148495628, -0.394900540085953, -0.42441073387872014, -0.45384466384295236, -0.4831903884237459, -0.5124371046460707, -0.5415748448419496, -0.5705942683636275, -0.5994865155188449, -0.6282431032552515, -0.6568558494634799, -0.6853168172787976, -0.7136182736021224, -0.7417526578914151, -0.769712558477971, -0.7974906944684461, -0.8250799018429597, -0.8524731227400278, -0.8796633971862581, -0.9066438567189173, -0.9334077194865351, -0.9599482865126211, -0.9862589388811986, -1.012333135657652, -1.038164412399561, -1.0637463801434026, -1.0890727247768448, -1.1141372067247448, -1.138933660891202, -1.1634559968111728, -1.1876981989739075, -1.2116543272874112, -1.2353185176586496, -1.2586849826686515, -1.2817480123252076, -1.3045019748787665, -1.3269413176894496, -1.3490605681350492, -1.3708543345514168, -1.3923173071979766, -1.4134442592421432, -1.4342300477573389, -1.4546696147300355, -1.474757988071877, -1.4944902826334625, -1.513861701216814, -1.53286753558392, -1.551503167459082, -1.5697640695230441, -1.5876458063971295, -1.6051440356158104, -1.6222545085862958, -1.6389730715338895, -1.6552956664319811, -1.671218331915662, -1.6867372041780406, -1.7018485178484313, -1.7165486068516567, -1.7308339052477746, -1.744700948051598, -1.7581463720314294, -1.7711669164864792, -1.783759424002476, -1.795920841185018, -1.8076482193702477, -1.8189387153124565, -1.8297895918482703, -1.8401982185370709, -1.8501620722773469, -1.859678737898691, -1.8687459087291587, -1.8773613871377581, -1.8855230850518216, -1.8932290244490482, -1.900477337824016, -1.9072662686289779, -1.9135941716887623, -1.9194595135896209, -1.9248608730418817, -1.9297969412162599, -1.9342665220537092, -1.9382685325487021, -1.9418020030058294, -1.9448660772696351, -1.9474600129275992, -1.9495831814862004, -1.9512350685199933, -1.9524152737936553, -1.9531235113569514], [-1.984448188079657, -1.984208210125703, -1.9834883343188423, -1.9822887348100686, -1.9806097018043312, -1.9784516414904794, -1.9758150759432274, -1.9727006429971317, -1.96910909609264, -1.96504130409424, -1.9604982510807496, -1.9554810361078139, -1.9499908729426565, -1.9440290897711627, -1.9375971288773617, -1.9306965462953927, -1.9233290114340484, -1.9154963066739787, -1.9072003269376776, -1.8984430792323401, -1.8892266821657335, -1.879553365435184, -1.8694254692898258, -1.8588454439662498, -1.8478158490977, -1.8363393530969647, -1.8244187325131433, -1.8120568713624399, -1.7992567604331753, -1.7860214965652033, -1.772354281903919, -1.7582584231290745, -1.7437373306586041, -1.7287945178276924, -1.7134336000433041, -1.6976582939144287, -1.6814724163582873, -1.6648798836827627, -1.6478847106453323, -1.6304910094887877, -1.6127029889540438, -1.594524953270353, -1.5759613011232514, -1.5570165246005927, -1.5376952081170343, -1.5180020273173593, -1.4979417479590564, -1.477519224774593, -1.4567394003138456, -1.435607303767206, -1.4141280497698905, -1.3923068371880583, -1.370148947887368, -1.3476597454846921, -1.324844674083756, -1.301709256995576, -1.2782590954446582, -1.254499867262057, -1.2304373255665237, -1.206077297435168, -1.1814256825652587, -1.1564884519290723, -1.1312716464239896, -1.105781375520478, -1.0800238159110571, -1.0540052101639883, -1.0277318653861824, -1.0012101519008159, -0.974446501946376, -0.9474474084054578, -0.9202194235736794, -0.892769157981758, -0.8651032792872801, -0.8372285112573088, -0.8091516328691315, -0.780879477564721, -0.7524189327057356, -0.7237769392913571, -0.6949604920227721, -0.6659766398284065, -0.6368324870072932, -0.6075351952106766, -0.5780919865743277, -0.548510148452551, -0.5187970404165477, -0.4889601045103276, -0.45900688028576075, -0.42894502700559567, -0.39878235686917146, -0.3685268856772386, -0.33818691200184, -0.3077711447422449, -0.2772889165297433, -0.2467505576728371, -0.2161680900256445, -0.18555661050496494, -0.15493731735854227, -0.12434500048331583, -0.09385010320576291, -0.06364352007629748, -0.0345579064237627, -0.015551811920342959, -0.03455790642379102, -0.06364352007632823, -0.09385010320579418, -0.12434500048334725, -0.15493731735857375, -0.1855566105049964, -0.21616809002567594, -0.24675055767286846, -0.2772889165297747, -0.3077711447422761, -0.33818691200187123, -0.3685268856772697, -0.39878235686920255, -0.42894502700562653, -0.45900688028579156, -0.48896010451035843, -0.5187970404165784, -0.5485101484525814, -0.5780919865743581, -0.6075351952107068, -0.6368324870073231, -0.6659766398284364, -0.6949604920228019, -0.7237769392913866, -0.7524189327057648, -0.7808794775647503, -0.8091516328691605, -0.8372285112573374, -0.8651032792873088, -0.8927691579817865, -0.9202194235737075, -0.9474474084054857, -0.9744465019464037, -1.0012101519008432, -1.0277318653862098, -1.0540052101640152, -1.080023815911084, -1.1057813755205042, -1.1312716464240158, -1.156488451929098, -1.1814256825652842, -1.206077297435193, -1.2304373255665488, -1.2544998672620817, -1.2782590954446826, -1.3017092569955997, -1.3248446740837798, -1.3476597454847152, -1.370148947887391, -1.3923068371880807, -1.4141280497699127, -1.4356073037672277, -1.456739400313867, -1.477519224774614, -1.4979417479590773, -1.5180020273173793, -1.5376952081170545, -1.5570165246006125, -1.5759613011232703, -1.5945249532703716, -1.6127029889540623, -1.6304910094888057, -1.6478847106453498, -1.6648798836827798, -1.6814724163583041, -1.697658293914445, -1.71343360004332, -1.7287945178277078, -1.7437373306586195, -1.758258423129089, -1.7723542819039333, -1.786021496565217, -1.799256760433189, -1.8120568713624527, -1.8244187325131562, -1.836339353096977, -1.847815849097711, -1.858845443966261, -1.869425469289836, -1.8795533654351941, -1.889226682165743, -1.898443079232349, -1.9072003269376858, -1.9154963066739872, -1.9233290114340562, -1.9306965462954004, -1.9375971288773681, -1.9440290897711694, -1.949990872942662, -1.955481036107819, -1.9604982510807545, -1.9650413040942447, -1.9691090960926443, -1.9727006429971352, -1.9758150759432307, -1.9784516414904822, -1.9806097018043327, -1.9822887348100704, -1.983488334318843, -1.9842082101257037], [-2.015551811920359, -2.01530807216807, -2.01457691187592, -2.0133585079238236, -2.011653155064198, -2.009461265850807, -2.0067833705391784, -2.003620116958603, -1.9999722703557572, -1.9958407132099947, -1.9912264450203332, -1.9861305820642159, -1.980554357128086, -1.9744991192098615, -1.9679663331933719, -1.9609575794948437, -1.953474553681534, -1.9455190660625934, -1.9370930412522762, -1.928198517705603, -1.918837647226601, -1.9090126944492405, -1.8987260362912115, -1.8879801613806755, -1.8767776694561464, -1.8651212707396543, -1.8530137852833628, -1.8404581422898028, -1.827457379405921, -1.8140146419911116, -1.8001331823594484, -1.7858163589963103, -1.771067635749623, -1.7558905809959402, -1.7402888667815963, -1.7242662679391776, -1.707826661179566, -1.690974024159822, -1.6737124345271803, -1.656046068939457, -1.6379792020621606, -1.619516205542635, -1.6006615469615613, -1.5814197887621726, -1.5617955871575535, -1.5417936910164094, -1.5214189407277265, -1.500676267044762, -1.4795706899088326, -1.4581073172534105, -1.4362913437890732, -1.4141280497698903, -1.3916227997418977, -1.3687810412743588, -1.3456083036745923, -1.322110196687227, -1.2982924091788464, -1.2741607078091088, -1.249720935689573, -1.2249790110316334, -1.199940925785183, -1.1746127442698822, -1.14900060180123, -1.123110703314022, -1.096949321986279, -1.0705227978673202, -1.043837536514433, -1.016900007643548, -0.9897167438005483, -0.9622943390614236, -0.9346394477714836, -0.9067587833364877, -0.8786591170819784, -0.8503472772016545, -0.8218301478216721, -0.79311466821592, -0.7642078322183837, -0.7351166878939576, -0.7058483375502316, -0.6764099382026356, -0.6468087026479155, -0.6170519013626908, -0.5871468655348042, -0.5571009916715634, -0.5269217484374376, -0.4966166866992735, -0.4661934542774682, -0.4356598177556318, -0.4050236951450074, -0.3742932057229879, -0.3434767479447449, -0.3125831250101714, -0.2816217549886015, -0.2506030390826852, -0.21953904506542016, -0.18844487023226536, -0.15734162333824564, -0.12626380760020947, -0.09528107871030649, -0.06458197524022186, -0.0349905650663745, -0.015551811920358946, -0.03499056506640336, -0.06458197524025314, -0.09528107871033827, -0.12626380760024136, -0.15734162333827767, -0.1884448702322973, -0.21953904506545208, -0.2506030390827171, -0.28162175498863334, -0.31258312501020313, -0.3434767479447767, -0.3742932057230195, -0.405023695145039, -0.4356598177556632, -0.46619345427749953, -0.4966166866993048, -0.5269217484374686, -0.5571009916715943, -0.5871468655348352, -0.6170519013627215, -0.646808702647946, -0.6764099382026659, -0.7058483375502617, -0.7351166878939874, -0.7642078322184135, -0.7931146682159494, -0.8218301478217016, -0.8503472772016837, -0.8786591170820074, -0.9067587833365163, -0.934639447771512, -0.9622943390614519, -0.9897167438005762, -1.0169000076435757, -1.0438375365144605, -1.0705227978673473, -1.0969493219863062, -1.1231107033140488, -1.1490006018012564, -1.1746127442699088, -1.199940925785209, -1.224979011031659, -1.2497209356895982, -1.2741607078091337, -1.2982924091788712, -1.3221101966872513, -1.3456083036746163, -1.3687810412743822, -1.391622799741921, -1.4141280497699136, -1.4362913437890958, -1.4581073172534327, -1.4795706899088543, -1.5006762670447835, -1.5214189407277476, -1.54179369101643, -1.561795587157574, -1.5814197887621926, -1.6006615469615806, -1.6195162055426544, -1.6379792020621797, -1.6560460689394754, -1.673712434527198, -1.6909740241598392, -1.7078266611795831, -1.724266267939194, -1.7402888667816123, -1.755890580995956, -1.7710676357496384, -1.7858163589963247, -1.8001331823594626, -1.8140146419911256, -1.8274573794059346, -1.840458142289816, -1.8530137852833755, -1.865121270739667, -1.876777669456158, -1.8879801613806868, -1.8987260362912222, -1.909012694449251, -1.9188376472266109, -1.9281985177056125, -1.937093041252285, -1.945519066062602, -1.953474553681542, -1.9609575794948513, -1.9679663331933783, -1.9744991192098686, -1.9805543571280917, -1.986130582064221, -1.9912264450203383, -1.995840713209999, -1.9999722703557614, -2.003620116958606, -2.0067833705391815, -2.0094612658508098, -2.0116531550642, -2.0133585079238245, -2.014576911875921, -2.0153080721680703], [-2.046640390387426, -2.0463930049195564, -2.0456509084451997, -2.0444142807378602, -2.0426834213725593, -2.0404587496546256, -2.0377408045200283, -2.034530244407302, -2.030827847101084, -2.026634509547345, -2.021951247640345, -2.01677919598142, -2.011119607609651, -2.004973853704534, -1.9983434232607389, -1.991229922735085, -1.983635075665846, -1.9755607222645375, -1.967008818980324, -1.9579814380372171, -1.9484807669442366, -1.9385091079787253, -1.9280688776430206, -1.9171626060947038, -1.9057929365506576, -1.8939626246651935, -1.8816745378825086, -1.8689316547637682, -1.855737064289129, -1.8420939651350277, -1.8280056649271041, -1.8134755794691404, -1.7985072319484319, -1.7831042521180482, -1.7672703754564554, -1.751009442305039, -1.734325396984098, -1.717222286887922, -1.6997042615596436, -1.6817755717466025, -1.663440568437038, -1.6447037018790087, -1.625569520582535, -1.6060426703060573, -1.5861278930284468, -1.56583002590792, -1.5451540002294046, -1.5241048403420663, -1.5026876625889534, -1.4809076742309577, -1.4587701723676083, -1.436280542857568, -1.413444259242121, -1.3902668816754573, -1.3667540558661373, -1.3429115120348478, -1.3187450638944038, -1.2942606076589804, -1.2694641210908018, -1.244361662594007, -1.2189593703672563, -1.1932634616288718, -1.167280231931066, -1.1410160545832133, -1.1144773802083516, -1.0876707364623757, -1.0606027279520132, -1.0332800363960666, -1.0057094210850335, -0.9778977197078674, -0.9498518496322071, -0.9215788097472046, -0.8930856830079468, -0.864379639859839, -0.8354679427737629, -0.8063579521932612, -0.7770571342906473, -0.7475730710601368, -0.7179134734582071, -0.6880861985573076, -0.6580992720435055, -0.6279609179153314, -0.5976795980141689, -0.5672640651709738, -0.5367234355105874, -0.5060672881829283, -0.4753058051245524, -0.44444997051549323, -0.4135118614282585, -0.3825050816246454, -0.35144542711096977, -0.3203519404441438, -0.28924864440904763, -0.25816752123273295, -0.22715390855682865, -0.19627691452319856, -0.16565115314589401, -0.13548672861345973, -0.10621893567429927, -0.07889597174768917, -0.056461340729673556, -0.04664039038742575, -0.05646134072969199, -0.07889597174771555, -0.10621893567432865, -0.1354867286134904, -0.16565115314592535, -0.19627691452323018, -0.2271539085568605, -0.2581675212327649, -0.28924864440907955, -0.32035194044417575, -0.3514454271110017, -0.3825050816246772, -0.41351186142829033, -0.444449970515525, -0.4753058051245839, -0.50606728818296, -0.536723435510619, -0.5672640651710052, -0.5976795980142001, -0.6279609179153623, -0.6580992720435362, -0.6880861985573383, -0.7179134734582377, -0.7475730710601671, -0.7770571342906775, -0.8063579521932913, -0.8354679427737927, -0.8643796398598685, -0.8930856830079759, -0.9215788097472337, -0.949851849632236, -0.9778977197078961, -1.005709421085062, -1.0332800363960948, -1.0606027279520411, -1.0876707364624034, -1.1144773802083792, -1.1410160545832402, -1.1672802319310929, -1.1932634616288986, -1.2189593703672825, -1.244361662594033, -1.2694641210908275, -1.294260607659006, -1.3187450638944287, -1.3429115120348727, -1.3667540558661617, -1.390266881675481, -1.4134442592421448, -1.4362805428575913, -1.4587701723676314, -1.4809076742309801, -1.5026876625889756, -1.5241048403420883, -1.545154000229426, -1.565830025907941, -1.5861278930284672, -1.6060426703060775, -1.6255695205825547, -1.6447037018790283, -1.6634405684370568, -1.6817755717466212, -1.6997042615596616, -1.7172222868879397, -1.7343253969841153, -1.7510094423050557, -1.7672703754564714, -1.7831042521180642, -1.7985072319484476, -1.813475579469155, -1.8280056649271188, -1.842093965135042, -1.8557370642891429, -1.8689316547637815, -1.8816745378825215, -1.8939626246652062, -1.9057929365506694, -1.9171626060947151, -1.928068877643032, -1.9385091079787358, -1.948480766944247, -1.9579814380372265, -1.9670088189803332, -1.975560722264546, -1.9836350756658538, -1.9912299227350923, -1.998343423260746, -2.0049738537045405, -2.011119607609657, -2.0167791959814254, -2.02195124764035, -2.0266345095473492, -2.030827847101088, -2.0345302444073052, -2.037740804520032, -2.040458749654628, -2.042683421372561, -2.0444142807378616, -2.045650908445201, -2.0463930049195573], [-2.0776838472890145, -2.077432930268637, -2.0766802401523283, -2.0754259597604907, -2.073670393746924, -2.0714139685285375, -2.0686572321870003, -2.065400854342374, -2.0616456259987963, -2.057392459362284, -2.052642387630767, -2.0473965647564403, -2.041656265180577, -2.035422883540936, -2.028697934351919, -2.021483051657667, -2.01377998865828, -2.005590617309376, -1.9969169278952386, -1.9877610285757972, -1.9781251449077317, -1.9680116193400115, -1.9574229106841996, -1.9463615935598955, -1.934830357815709, -1.9228320079262076, -1.9103694623653003, -1.897445752956582, -1.884064024201193, -1.8702275325838142, -1.855939645857458, -1.8412038423077963, -1.8260237099978252, -1.8104029459937485, -1.7943453555730486, -1.7778548514158186, -1.7609354527805345, -1.7435912846655737, -1.7258265769579353, -1.707645663570777, -1.6890529815715698, -1.6700530703028857, -1.6506505704980805, -1.6308502233944133, -1.6106568698464703, -1.5900754494431357, -1.5691109996317891, -1.5477686548539196, -1.5260536456969305, -1.5039712980676136, -1.481527032393575, -1.4587263628598603, -1.435574896689158, -1.4120783334752987, -1.3882424645813707, -1.3640731726156767, -1.3395764310010387, -1.3147583036557102, -1.2896249448074673, -1.2641825989664754, -1.238437601087425, -1.212396376957413, -1.1860654438534126, -1.159451411522246, -1.1325609835472557, -1.1054009591799199, -1.0779782357322947, -1.050299811648419, -1.0223727904010511, -0.9942043853962087, -0.9658019261143994, -0.9371728657775844, -0.9083247909094713, -0.8792654332601068, -0.8500026847030003, -0.8205446158969006, -0.7908994997531285, -0.761075841089452, -0.7310824143215777, -0.7009283117009031, -0.6706230055388714, -0.6401764291967095, -0.6095990835709767, -0.5789021786975146, -0.5480978244582663, -0.5171992910810566, -0.4862213706493111, -0.4551808877485387, -0.42409743523533905, -0.3929944583123118, -0.3619008925642759, -0.3308537107495656, -0.29990201328851734, -0.2691138461977139, -0.238588055646308, -0.20847591020479123, -0.1790226812450133, -0.15065207437263334, -0.12414521725603232, -0.10101549176324748, -0.08412710413871463, -0.07768384728901459, -0.08412710413872737, -0.1010154917632687, -0.12414521725605818, -0.15065207437266173, -0.17902268124504317, -0.20847591020482187, -0.23858805564633917, -0.26911384619774537, -0.29990201328854904, -0.3308537107495974, -0.3619008925643079, -0.3929944583123437, -0.42409743523537086, -0.45518088774857063, -0.48622137064934284, -0.5171992910810884, -0.548097824458298, -0.5789021786975461, -0.6095990835710081, -0.6401764291967407, -0.6706230055389024, -0.7009283117009342, -0.7310824143216086, -0.7610758410894827, -0.7908994997531591, -0.8205446158969311, -0.8500026847030306, -0.8792654332601368, -0.908324790909501, -0.9371728657776138, -0.9658019261144286, -0.9942043853962379, -1.02237279040108, -1.0502998116484477, -1.077978235732323, -1.1054009591799476, -1.1325609835472834, -1.1594514115222734, -1.1860654438534397, -1.2123963769574402, -1.2384376010874516, -1.2641825989665016, -1.2896249448074932, -1.314758303655736, -1.339576431001064, -1.3640731726157018, -1.3882424645813956, -1.412078333475323, -1.435574896689182, -1.458726362859884, -1.481527032393598, -1.5039712980676367, -1.5260536456969531, -1.5477686548539416, -1.5691109996318109, -1.5900754494431568, -1.6106568698464914, -1.6308502233944338, -1.6506505704981005, -1.6700530703029053, -1.6890529815715891, -1.707645663570796, -1.7258265769579535, -1.7435912846655917, -1.7609354527805523, -1.7778548514158357, -1.7943453555730653, -1.8104029459937647, -1.8260237099978414, -1.8412038423078116, -1.8559396458574728, -1.8702275325838287, -1.8840640242012074, -1.8974457529565956, -1.9103694623653136, -1.9228320079262202, -1.9348303578157209, -1.9463615935599066, -1.9574229106842107, -1.9680116193400221, -1.978125144907742, -1.9877610285758067, -1.9969169278952474, -2.0055906173093843, -2.0137799886582877, -2.021483051657675, -2.0286979343519254, -2.0354228835409427, -2.0416562651805834, -2.047396564756446, -2.052642387630772, -2.0573924593622888, -2.0616456259988003, -2.065400854342378, -2.0686572321870034, -2.07141396852854, -2.073670393746926, -2.0754259597604916, -2.076680240152329, -2.0774329302686376], [-2.108652150085483, -2.108397813674186, -2.1076348664477407, -2.1063634944147904, -2.1045840075440925, -2.102296839696083, -2.099502548527139, -2.0962018153666135, -2.092395445066725, -2.088084365825435, -2.083269628982434, -2.077952408788411, -2.072134002147777, -2.0658158283350723, -2.058999428685273, -2.051686466258282, -2.0438787254778887, -2.035578111745526, -2.026786651029194, -2.0175064894279373, -2.0077398927123267, -1.9974892458414142, -1.9867570524566995, -1.9755459343536823, -1.9638586309316368, -1.9516979986223018, -1.9390670102982563, -1.9259687546618123, -1.9124064356153516, -1.8983833716141185, -1.8839029950025827, -1.8689688513356082, -1.853584598685779, -1.837754006938397, -1.8214809570758057, -1.804769440452901, -1.7876235580658792, -1.770047519816517, -1.7520456437745489, -1.7336223554410037, -1.7147821870157232, -1.6955297766726738, -1.6758698678471349, -1.6558073085393663, -1.635347050639979, -1.6144941492829323, -1.5932537622329088, -1.5716311493147788, -1.5496316718939651, -1.5272607924178572, -1.504524074029921, -1.481427180269993, -1.4579758748763547, -1.4341760217077286, -1.4100335848063341, -1.3855546286267368, -1.3607453184595106, -1.335611921083896, -1.3101608056898641, -1.284398445117527, -1.2583314174710125, -1.2319664081751047, -1.205310212556702, -1.178369739050067, -1.1511520131458282, -1.1236641822298077, -1.0959135214904592, -1.067907441114868, -1.039653495045424, -1.011159391635749, -0.9824330066297433, -0.9534823989977994, -0.9243158303076461, -0.8949417884953678, -0.8653690171509089, -0.8356065517642165, -0.8056637648250075, -0.7755504222767353, -0.7452767546602687, -0.714853547443023, -0.6842922566610011, -0.6536051583255766, -0.6228055434037727, -0.5919079751010079, -0.5609286325022378, -0.529885775726424, -0.49880038487446643, -0.46769705200271816, -0.4366052486842019, -0.4055611629845139, -0.374610419754654, -0.34381220562642667, -0.3132456878772784, -0.2830202841535214, -0.2532925759512772, -0.2242949587181315, -0.1963852784253082, -0.17013328589071428, -0.14646504420863626, -0.12686390153286498, -0.11348056693655068, -0.10865215008548304, -0.11348056693656039, -0.12686390153288238, -0.1464650442086588, -0.17013328589074014, -0.1963852784253362, -0.2242949587181608, -0.2532925759513074, -0.2830202841535522, -0.31324568787730955, -0.3438122056264582, -0.3746104197546858, -0.40556116298454575, -0.4366052486842338, -0.46769705200275, -0.49880038487449835, -0.5298857757264561, -0.5609286325022698, -0.5919079751010398, -0.6228055434038045, -0.6536051583256082, -0.6842922566610327, -0.7148535474430544, -0.7452767546602997, -0.7755504222767663, -0.8056637648250382, -0.8356065517642474, -0.8653690171509393, -0.894941788495398, -0.9243158303076762, -0.9534823989978292, -0.9824330066297728, -1.0111593916357786, -1.039653495045453, -1.0679074411148968, -1.0959135214904878, -1.123664182229836, -1.1511520131458564, -1.178369739050095, -1.2053102125567297, -1.231966408175132, -1.2583314174710396, -1.2843984451175536, -1.3101608056898906, -1.3356119210839221, -1.3607453184595364, -1.3855546286267624, -1.4100335848063592, -1.4341760217077533, -1.4579758748763791, -1.481427180270017, -1.5045240740299446, -1.5272607924178805, -1.549631671893988, -1.5716311493148012, -1.593253762232931, -1.6144941492829537, -1.6353470506400005, -1.6558073085393872, -1.6758698678471553, -1.6955297766726938, -1.7147821870157425, -1.7336223554410228, -1.7520456437745675, -1.7700475198165355, -1.7876235580658972, -1.8047694404529186, -1.8214809570758226, -1.8377540069384135, -1.853584598685795, -1.868968851335624, -1.883902995002598, -1.8983833716141332, -1.9124064356153658, -1.9259687546618263, -1.9390670102982699, -1.9516979986223146, -1.9638586309316488, -1.975545934353694, -1.9867570524567109, -1.997489245841425, -2.0077398927123373, -2.017506489427947, -2.026786651029203, -2.0355781117455343, -2.0438787254778967, -2.05168646625829, -2.05899942868528, -2.0658158283350794, -2.072134002147783, -2.0779524087884162, -2.0832696289824395, -2.0880843658254395, -2.0923954450667295, -2.0962018153666175, -2.0995025485271426, -2.1022968396960855, -2.1045840075440947, -2.1063634944147918, -2.1076348664477416, -2.1083978136741863], [-2.139515338943932, -2.1392576932385614, -2.1384848192354404, -2.1371969062603813, -2.1353942698125525, -2.133077351498753, -2.1302467189414935, -2.12690306566099, -2.1230472109312024, -2.118680099610069, -2.113802801944153, -2.108416513347898, -2.102522554157788, -2.0961223693616877, -2.0892175283037036, -2.081809724364961, -2.073900774620698, -2.0654926194741625, -2.0565873222678337, -2.0471870688725278, -2.0372941672550464, -2.0269110470250546, -2.016040258961965, -2.004684474522675, -1.992846485331105, -1.9805292026505468, -1.9677356568399824, -1.954468996795604, -1.9407324893789268, -1.9265295188330163, -1.9118635861885123, -1.896738308661319, -1.8811574190440237, -1.8651247650933434, -1.848644308916145, -1.831720126356888, -1.8143564063896522, -1.7965574505183024, -1.7783276721887502, -1.759671596217776, -1.7405938582434164, -1.7210992042025592, -1.7011924898421267, -1.680878680271063, -1.6601628495613112, -1.6390501804070994, -1.6175459638531482, -1.5956555991039418, -1.5733845934279664, -1.550738562172901, -1.5277232289101672, -1.5043444257301128, -1.4806080937124766, -1.4565202836007756, -1.4320871567140077, -1.4073149861347174, -1.3822101582192285, -1.3567791744839828, -1.3310286539316802, -1.3049653358927649, -1.2785960834721375, -1.2519278877085012, -1.2249678725751776, -1.197723300977615, -1.170201581935416, -1.1424102791772317, -1.1143571214274537, -1.0860500147271872, -1.0574970572122062, -1.0287065568725626, -0.9996870529488595, -0.9704473417879914, -0.9409965081986251, -0.911343963630666, -0.8814994928766353, -0.8514733114886828, -0.821276136768487, -0.790919276083498, -0.7604147374852279, -0.7297753692894531, -0.6990150376242135, -0.668148854257457, -0.6371934717321694, -0.6061674696519179, -0.575091865943825, -0.5439908017647548, -0.5128924711052755, -0.481830400458039, -0.45084523734707194, -0.41998729103962656, -0.38932020448326227, -0.35892635716821447, -0.3289149599718182, -0.29943439270438094, -0.27069127185574476, -0.24298010580292917, -0.21672892723415205, -0.19256616480762503, -0.1714053652837583, -0.15450920126830833, -0.14341177530675722, -0.13951533894393164, -0.14341177530676513, -0.154509201268323, -0.17140536528377814, -0.19256616480764854, -0.21672892723417814, -0.24298010580295695, -0.27069127185577385, -0.2994343927044109, -0.3289149599718488, -0.35892635716824556, -0.38932020448329374, -0.4199872910396582, -0.45084523734710363, -0.48183040045807085, -0.5128924711053073, -0.5439908017647868, -0.575091865943857, -0.6061674696519498, -0.6371934717322014, -0.6681488542574886, -0.699015037624245, -0.7297753692894847, -0.7604147374852593, -0.7909192760835294, -0.8212761367685181, -0.8514733114887137, -0.881499492876666, -0.9113439636306966, -0.9409965081986557, -0.9704473417880215, -0.9996870529488895, -1.0287065568725924, -1.0574970572122357, -1.0860500147272163, -1.1143571214274826, -1.1424102791772603, -1.1702015819354448, -1.1977233009776431, -1.2249678725752056, -1.2519278877085287, -1.2785960834721648, -1.3049653358927917, -1.3310286539317067, -1.3567791744840088, -1.3822101582192545, -1.407314986134743, -1.432087156714033, -1.4565202836008002, -1.4806080937125012, -1.504344425730137, -1.527723228910191, -1.5507385621729244, -1.5733845934279893, -1.5956555991039645, -1.6175459638531708, -1.6390501804071211, -1.6601628495613328, -1.680878680271084, -1.701192489842147, -1.7210992042025794, -1.7405938582434362, -1.7596715962177956, -1.7783276721887689, -1.7965574505183208, -1.8143564063896704, -1.8317201263569054, -1.8486443089161624, -1.86512476509336, -1.88115741904404, -1.8967383086613347, -1.9118635861885276, -1.9265295188330311, -1.9407324893789413, -1.9544689967956177, -1.9677356568399957, -1.9805292026505597, -1.9928464853311172, -2.004684474522687, -2.0160402589619766, -2.0269110470250657, -2.037294167255057, -2.0471870688725375, -2.056587322267843, -2.065492619474171, -2.073900774620706, -2.081809724364969, -2.0892175283037107, -2.0961223693616944, -2.1025225541577943, -2.108416513347904, -2.113802801944158, -2.118680099610074, -2.123047210931207, -2.1269030656609935, -2.1302467189414966, -2.133077351498756, -2.1353942698125548, -2.1371969062603826, -2.1384848192354418, -2.139257693238562], [-2.1702435557224073, -2.1699827087084027, -2.1692002319236163, -2.167896318127263, -2.1660712885431685, -2.1637255927975416, -2.1608598088319857, -2.157474642791895, -2.1535709288903986, -2.149149629248086, -2.144211833708765, -2.1387587596315623, -2.1327917516597266, -2.1263122814665225, -2.119321947478699, -2.1118224745780205, -2.103815713781457, -2.09530364190066, -2.0862883611814462, -2.07677209892407, -2.0667572070851645, -2.056246161862308, -2.0452415632622825, -2.0337461346542023, -2.0217627223087966, -2.009294294925288, -1.9963439431474357, -1.9829148790704902, -1.9690104357409806, -1.954634066651477, -1.939789345232673, -1.9244799643454213, -1.9087097357756242, -1.8924825897352067, -1.8758025743727842, -1.8586738552980324, -1.8411007151242527, -1.8230875530341553, -1.8046388843744903, -1.785759340285862, -1.7664536673748443, -1.7467267274364362, -1.7265834972359373, -1.7060290683605333, -1.6850686471522682, -1.6637075547356925, -1.6419512271553356, -1.619805215640333, -1.5972751870160544, -1.5743669242855398, -1.5510863274070206, -1.5274394142978664, -1.5034323221000996, -1.4790713087483094, -1.4543627548875082, -1.4293131661965113, -1.4039291761819723, -1.3782175495196807, -1.3521851860335183, -1.3258391254191173, -1.2991865528394324, -1.2722348055439971, -1.2449913806936228, -1.2174639446091235, -1.1896603437080469, -1.1615886174496448, -1.1332570136783457, -1.1046740068436702, -1.0758483196848612, -1.0467889491081577, -1.0175051971624818, -0.9880067082471731, -0.9583035139793269, -0.9284060875299825, -0.8983254097377418, -0.868073049966514, -0.8376612655484968, -0.8071031248249164, -0.7764126603802339, -0.745605061224826, -0.7146969156545672, -0.6837065206513355, -0.6526542795003635, -0.6215632175559157, -0.5904596579424018, -0.5593741161922382, -0.528342498088878, -0.49740772245183973, -0.46662194665945983, -0.43604965711701776, -0.40577201421351555, -0.3758930321287321, -0.34654845335457957, -0.3179185645063572, -0.29024666256414144, -0.26386520421274223, -0.23923109850637794, -0.21696804457933114, -0.19790278742326556, -0.1830582236398312, -0.17353674920945947, -0.17024355572240732, -0.17353674920946616, -0.18305822363984392, -0.19790278742328318, -0.21696804457935256, -0.23923109850640223, -0.2638652042127685, -0.29024666256416937, -0.31791856450638617, -0.3465484533546094, -0.3758930321287625, -0.4057720142135466, -0.436049657117049, -0.4666219466594914, -0.4974077224518715, -0.5283424980889099, -0.5593741161922701, -0.5904596579424338, -0.6215632175559478, -0.6526542795003955, -0.6837065206513674, -0.7146969156545989, -0.7456050612248577, -0.7764126603802655, -0.807103124824948, -0.8376612655485282, -0.8680730499665451, -0.8983254097377726, -0.9284060875300135, -0.9583035139793574, -0.9880067082472034, -1.017505197162512, -1.0467889491081876, -1.075848319684891, -1.1046740068436998, -1.1332570136783748, -1.1615886174496737, -1.1896603437080755, -1.2174639446091517, -1.2449913806936512, -1.2722348055440253, -1.29918655283946, -1.3258391254191446, -1.3521851860335452, -1.3782175495197073, -1.4039291761819985, -1.4293131661965373, -1.4543627548875337, -1.4790713087483347, -1.5034323221001247, -1.5274394142978907, -1.5510863274070448, -1.5743669242855634, -1.5972751870160777, -1.6198052156403564, -1.6419512271553582, -1.6637075547357145, -1.68506864715229, -1.7060290683605546, -1.726583497235958, -1.7467267274364568, -1.7664536673748645, -1.7857593402858818, -1.8046388843745094, -1.823087553034174, -1.841100715124271, -1.8586738552980502, -1.8758025743728015, -1.8924825897352238, -1.9087097357756406, -1.924479964345437, -1.9397893452326882, -1.954634066651492, -1.9690104357409952, -1.9829148790705042, -1.9963439431474497, -2.0092942949253016, -2.0217627223088095, -2.0337461346542147, -2.0452415632622944, -2.056246161862319, -2.0667572070851747, -2.0767720989240797, -2.0862883611814556, -2.095303641900669, -2.103815713781465, -2.111822474578028, -2.119321947478706, -2.1263122814665296, -2.132791751659733, -2.1387587596315685, -2.14421183370877, -2.1491496292480905, -2.153570928890403, -2.1574746427918985, -2.1608598088319897, -2.1637255927975443, -2.1660712885431703, -2.167896318127265, -2.169200231923618, -2.1699827087084036], [-2.2008070728557274, -2.2005431303752494, -2.199751368369691, -2.1984319831350527, -2.1965853017925996, -2.194211782230849, -2.1913120130245294, -2.187886713330676, -2.1839367327621106, -2.1794630512385673, -2.174466778815823, -2.168949155493216, -2.162911551000018, -2.1563554645611864, -2.1492825246430947, -2.141694488679898, -2.133593242781303, -2.12498080142256, -2.115859307117622, -2.1062310300764904, -2.0960983678478984, -2.0854638449485865, -2.074330112480579, -2.0626999477379866, -2.050576253805059, -2.0379620591473557, -2.024860517198119, -2.0112749059421606, -1.997208627499799, -1.9826652077136688, -1.967648295741541, -1.9521616636586212, -1.936209206073183, -1.919794939759848, -1.9029230033152824, -1.8855976568416777, -1.8678232816639773, -1.8496043800875548, -1.8309455752038502, -1.8118516107524074, -1.7923273510488196, -1.7723777809893082, -1.7520080061440513, -1.7312232529530045, -1.710028869039797, -1.688430323661433, -1.6664332083140254, -1.6440432375176637, -1.621266249806887, -1.5981082089571554, -1.5745752054823166, -1.5506734584434474, -1.5264093176158202, -1.5017892660682304, -1.476819923217817, -1.4515080484340641, -1.4258605452782507, -1.3998844664796857, -1.3735870197681177, -1.3469755747034873, -1.3200576706705123, -1.292841026237551, -1.2653335501181302, -1.2375433540212182, -1.2094787677349181, -1.1811483568606678, -1.1525609437048525, -1.1237256319467808, -1.0946518358423964, -1.0653493149000948, -1.035828215189301, -1.0060991187283967, -0.9761731027652644, -0.9460618112369922, -0.9157775413101168, -0.8853333487070386, -0.8547431765837754, -0.8240220141303641, -0.7931860929456351, -0.7622531317724875, -0.7312426436231101, -0.7001763240399063, -0.6690785457504861, -0.637976994040065, -0.6069034898780823, -0.5758950657877057, -0.5449953849334982, -0.5142566301998142, -0.48374204168934254, -0.4535293540570041, -0.42371548629467287, -0.39442297127196474, -0.3658087761748523, -0.33807632234900503, -0.3114915441416717, -0.286403411318822, -0.26326774804368874, -0.24266904291522431, -0.22532658069911576, -0.21205935441839774, -0.20367911969315064, -0.2008070728557273, -0.20367911969315652, -0.21205935441840904, -0.22532658069913167, -0.24266904291524397, -0.2632677480437114, -0.28640341131884683, -0.3114915441416983, -0.33807632234903295, -0.3658087761748812, -0.3944229712719945, -0.42371548629470335, -0.453529354057035, -0.4837420416893738, -0.5142566301998457, -0.5449953849335298, -0.5758950657877373, -0.6069034898781144, -0.637976994040097, -0.6690785457505181, -0.7001763240399381, -0.7312426436231418, -0.7622531317725193, -0.793186092945667, -0.8240220141303957, -0.8547431765838068, -0.88533334870707, -0.9157775413101479, -0.9460618112370232, -0.9761731027652952, -1.0060991187284274, -1.0358282151893314, -1.065349314900125, -1.0946518358424264, -1.1237256319468105, -1.1525609437048818, -1.1811483568606969, -1.209478767734947, -1.2375433540212468, -1.2653335501181586, -1.2928410262375791, -1.3200576706705403, -1.3469755747035148, -1.3735870197681448, -1.3998844664797125, -1.425860545278277, -1.4515080484340903, -1.476819923217843, -1.5017892660682557, -1.526409317615845, -1.550673458443472, -1.574575205482341, -1.5981082089571794, -1.6212662498069108, -1.6440432375176872, -1.6664332083140485, -1.6884303236614555, -1.710028869039819, -1.7312232529530258, -1.7520080061440721, -1.772377780989329, -1.79232735104884, -1.8118516107524272, -1.8309455752038697, -1.8496043800875743, -1.867823281663996, -1.8855976568416954, -1.9029230033153, -1.919794939759865, -1.9362092060732001, -1.9521616636586374, -1.967648295741557, -1.9826652077136842, -1.997208627499814, -2.011274905942175, -2.0248605171981326, -2.037962059147369, -2.050576253805072, -2.062699947737999, -2.0743301124805904, -2.0854638449485976, -2.0960983678479086, -2.1062310300765006, -2.1158593071176313, -2.124980801422569, -2.133593242781312, -2.141694488679906, -2.149282524643102, -2.156355464561194, -2.162911551000024, -2.168949155493222, -2.174466778815829, -2.1794630512385726, -2.183936732762115, -2.18788671333068, -2.1913120130245325, -2.194211782230852, -2.196585301792601, -2.1984319831350545, -2.199751368369693, -2.2005431303752503], [-2.2311763221149787, -2.2309093878481794, -2.230108651692429, -2.228774313571006, -2.226906706653874, -2.224506297304524, -2.2215736850057923, -2.2181096022648474, -2.21411491449764, -2.209590619893182, -2.204537849258062, -2.198957865841707, -2.1928520651429633, -2.186221974698663, -2.179069253854907, -2.1713956935219314, -2.163203215913477, -2.154493874271728, -2.1452698525789877, -2.135533465257391, -2.1252871568580924, -2.1145335017415268, -2.1032752037505067, -2.0915150958781075, -2.079256139932492, -2.0665014262010653, -2.053254173116592, -2.0395177269281977, -2.0252955613804837, -2.0105912774043397, -1.9954086028234261, -1.9797513920807421, -1.96362362599019, -1.9470294115185924, -1.9299729816042686, -1.9124586950189606, -1.8944910362807261, -1.8760746156263206, -1.8572141690526225, -1.8379145584378556, -1.8181807717547045, -1.7980179233889717, -1.7774312545792015, -1.756426133994738, -1.735008058472036, -1.7131826539317712, -1.6909556765024194, -1.6683330138796586, -1.6453206869551564, -1.6219248517532867, -1.5981518017200957, -1.574007970415621, -1.5494999346686562, -1.524634418262458, -1.4994182962310103, -1.4738585998586624, -1.4479625224916512, -1.42173742628876, -1.395190850060805, -1.368330518375622, -1.3411643521377619, -1.313700480891501, -1.2859472571436497, -1.2579132730610927, -1.2296073799695768, -1.20103871116841, -1.1722167086846487, -1.1431511547256665, -1.1138522087578133, -1.0843304513506185, -1.0545969361929046, -1.0246632520254455, -0.9945415966658634, -0.9642448658539029, -0.9337867603573842, -0.9031819157027018, -0.8724460600988841, -0.8415962077066035, -0.8106508964943511, -0.7796304827040629, -0.7485575076677974, -0.7174571577224346, -0.686357844741989, -0.6552919440133831, -0.6242967387378472, -0.5934156375886158, -0.5626997551336975, -0.5322099765856829, -0.5020196705486704, -0.472218268040699, -0.44291599262840553, -0.41425009772088, -0.38639301850989055, -0.35956281464054446, -0.33403602292807294, -0.3101622710177808, -0.2883782334463595, -0.26921514098045224, -0.25328902747497034, -0.24125852092663153, -0.23373826277268167, -0.23117632211497857, -0.2337382627726869, -0.24125852092664166, -0.2532890274749849, -0.26921514098047045, -0.2883782334463807, -0.31016227101780436, -0.3340360229280984, -0.35956281464057144, -0.3863930185099187, -0.4142500977209091, -0.4429159926284354, -0.47221826804072936, -0.5020196705487011, -0.5322099765857142, -0.5626997551337289, -0.5934156375886475, -0.624296738737879, -0.655291944013415, -0.6863578447420211, -0.7174571577224665, -0.7485575076678292, -0.7796304827040949, -0.8106508964943829, -0.8415962077066352, -0.8724460600989158, -0.9031819157027333, -0.9337867603574155, -0.964244865853934, -0.9945415966658944, -1.0246632520254764, -1.0545969361929353, -1.084330451350649, -1.1138522087578437, -1.1431511547256965, -1.1722167086846784, -1.2010387111684395, -1.2296073799696061, -1.2579132730611213, -1.2859472571436783, -1.3137004808915294, -1.34116435213779, -1.3683305183756496, -1.3951908500608323, -1.4217374262887872, -1.447962522491678, -1.4738585998586888, -1.4994182962310363, -1.5246344182624838, -1.5494999346686815, -1.574007970415646, -1.5981518017201204, -1.621924851753311, -1.64532068695518, -1.6683330138796821, -1.6909556765024425, -1.7131826539317936, -1.7350080584720584, -1.7564261339947598, -1.7774312545792228, -1.7980179233889926, -1.8181807717547247, -1.8379145584378755, -1.8572141690526422, -1.87607461562634, -1.8944910362807448, -1.9124586950189784, -1.9299729816042868, -1.9470294115186098, -1.963623625990207, -1.9797513920807586, -1.995408602823442, -2.0105912774043553, -2.025295561380499, -2.0395177269282123, -2.053254173116606, -2.066501426201079, -2.079256139932505, -2.09151509587812, -2.103275203750519, -2.114533501741538, -2.1252871568581035, -2.135533465257401, -2.1452698525789975, -2.1544938742717368, -2.163203215913486, -2.1713956935219394, -2.1790692538549146, -2.1862219746986695, -2.19285206514297, -2.1989578658417126, -2.2045378492580676, -2.209590619893187, -2.214114914497644, -2.218109602264851, -2.221573685005796, -2.2245062973045266, -2.2269067066538755, -2.228774313571008, -2.23010865169243, -2.2309093878481803], [-2.26132192321287, -2.2610520986708, -2.2602426929238604, -2.2588939096002845, -2.257006088048565, -2.254579703289752, -2.2516153659509284, -2.248113822180138, -2.2440759535431134, -2.239502776902242, -2.2343954442782725, -2.228755242695389, -2.2225835940103447, -2.2158820547264586, -2.208652315793405, -2.2008962023937984, -2.1926156737177496, -2.1838128227266633, -2.174489875907724, -2.1646491930206397, -2.1542932668384362, -2.1434247228842214, -2.1320463191661108, -2.1201609459126827, -2.1077716253116203, -2.0948815112544605, -2.0814938890906824, -2.06761217539472, -2.0532399177498717, -2.038380794553494, -2.023038614848374, -2.007217318185694, -1.9909209745256193, -1.9741537841822352, -1.9569200778203009, -1.9392243165122003, -1.9210710918644203, -1.9024651262240393, -1.883411272976958, -1.8639145169510738, -1.8439799749392438, -1.8236128963587956, -1.802818664066483, -1.7816027953503153, -1.7599709431225388, -1.7379288973413556, -1.715482586692818, -1.692638080568744, -1.6694015913816787, -1.6457794772639212, -1.6217782452046383, -1.5974045546873052, -1.572665221899333, -1.5475672245970777, -1.52211770772281, -1.4963239898860479, -1.470193570840467, -1.4437341401099948, -1.4169535869444445, -1.3898600118171351, -1.3624617397155303, -1.3347673355225063, -1.3067856218423253, -1.2785256996940266, -1.2499969725787887, -1.2212091745305684, -1.192172402885832, -1.162897156664585, -1.1333943816491023, -1.1036755234890137, -1.0737525904649647, -1.0436382279253487, -1.013345806894299, -0.982889529964224, -0.9522845583722898, -0.9215471651700423, -0.890694920699014, -0.8597469182765402, -0.8287240502009326, -0.7976493470724071, -0.766548397221922, -0.7354498680463402, -0.704386157664881, -0.6733942140600974, -0.6425165704084265, -0.6118026604404933, -0.5813104972760792, -0.5511088240041498, -0.52127987443988, -0.4919229163099357, -0.46315878067097943, -0.43513559558293374, -0.40803590553033586, -0.38208520343554303, -0.3575615058663722, -0.33480476664540315, -0.3142234069395718, -0.2962929402914186, -0.28153915025368004, -0.2704976100432627, -0.2636463446573747, -0.2613219232128697, -0.2636463446573794, -0.270497610043272, -0.28153915025369336, -0.29629294029143555, -0.31422340693959167, -0.33480476664542547, -0.3575615058663965, -0.38208520343556907, -0.4080359055303632, -0.43513559558296205, -0.4631587806710087, -0.49192291630996554, -0.5212798744399104, -0.5511088240041806, -0.5813104972761104, -0.6118026604405247, -0.6425165704084581, -0.6733942140601292, -0.704386157664913, -0.735449868046372, -0.766548397221954, -0.7976493470724391, -0.8287240502009644, -0.8597469182765721, -0.8906949206990459, -0.921547165170074, -0.9522845583723211, -0.9828895299642553, -1.0133458068943302, -1.0436382279253797, -1.0737525904649956, -1.1036755234890445, -1.1333943816491328, -1.1628971566646151, -1.1921724028858622, -1.221209174530598, -1.249996972578818, -1.278525699694056, -1.3067856218423541, -1.3347673355225351, -1.3624617397155585, -1.3898600118171631, -1.4169535869444718, -1.4437341401100223, -1.4701935708404943, -1.4963239898860747, -1.5221177077228365, -1.5475672245971042, -1.5726652218993586, -1.5974045546873306, -1.621778245204663, -1.6457794772639456, -1.6694015913817026, -1.6926380805687675, -1.7154825866928418, -1.7379288973413785, -1.7599709431225612, -1.7816027953503375, -1.8028186640665043, -1.8236128963588172, -1.8439799749392647, -1.8639145169510938, -1.8834112729769779, -1.902465126224059, -1.921071091864439, -1.9392243165122185, -1.956920077820319, -1.9741537841822525, -1.9909209745256364, -2.0072173181857105, -2.0230386148483905, -2.0383807945535097, -2.0532399177498872, -2.0676121753947347, -2.0814938890906967, -2.094881511254474, -2.107771625311633, -2.120160945912695, -2.132046319166123, -2.1434247228842334, -2.1542932668384474, -2.1646491930206504, -2.1744898759077333, -2.1838128227266727, -2.1926156737177585, -2.200896202393807, -2.2086523157934126, -2.2158820547264657, -2.222583594010351, -2.228755242695395, -2.234395444278278, -2.239502776902247, -2.2440759535431183, -2.2481138221801418, -2.251615365950932, -2.254579703289755, -2.2570060880485667, -2.258893909600286, -2.2602426929238617, -2.2610520986708007], [-2.2912147122272613, -2.290942096755034, -2.290124319473878, -2.288761587781978, -2.286854247315029, -2.2844027819044856, -2.281407813519423, -2.2778701021923284, -2.2737905459292462, -2.2691701806047897, -2.264010179842625, -2.2583118548821752, -2.2520766544323556, -2.245306164513325, -2.2380021082873265, -2.2301663458798484, -2.22180087419248, -2.212907826709002, -2.2034894732964108, -2.193548220002782, -2.183086608854084, -2.172107317652262, -2.160613159777181, -2.1486070839952895, -2.1360921742781485, -2.123071649634343, -2.1095488639586177, -2.095527305902547, -2.0810105987714564, -2.066002500452881, -2.050506903382377, -2.0345278345531796, -2.018069455576916, -2.001136062803399, -1.9837320875084494, -1.9658620961597324, -1.9475307907717818, -1.9287430093627091, -1.9095037265266093, -1.8898180541374194, -1.8696912422019287, -1.8491286798819127, -1.8281358967079144, -1.8067185640101742, -1.7848824965955887, -1.7626336547034938, -1.7399781462776025, -1.7169222295966373, -1.6934723163122776, -1.6696349749501, -1.645416934937405, -1.6208250912314415, -1.5958665096328057, -1.5705484328820125, -1.5448782876528262, -1.5188636925743448, -1.4925124674356396, -1.465832643752661, -1.4388324769080072, -1.4115204601110707, -1.3839053404703636, -1.355996137523122, -1.3278021646316427, -1.2993330537338033, -1.270598784030073, -1.2416097153051187, -1.2123766267240081, -1.1829107621175787, -1.153223882987138, -1.1233283307260231, -1.0932370998884802, -1.0629639247525946, -1.032523381946708, -1.0019310125677765, -0.9712034680544751, -0.9403586851383525, -0.909416096549395, -0.8783968858846675, -0.8473242972731818, -0.8162240133332862, -0.7851246186088728, -0.7540581704260013, -0.7230609052264285, -0.6921741162569892, -0.6614452484025252, -0.6309292682874762, -0.6006903826840958, -0.5708041953645064, -0.5413604102099654, -0.5124662025002339, -0.48425038176843244, -0.45686844026832113, -0.4305084872546344, -0.40539785320969157, -0.381809721828243, -0.3600684026081358, -0.34055072481393606, -0.32367965286910666, -0.30990524428923755, -0.29966892981849, -0.2933516242666895, -0.29121471222726114, -0.2933516242666939, -0.29966892981849863, -0.30990524428925, -0.3236796528691226, -0.34055072481395493, -0.36006840260815703, -0.3818097218282664, -0.40539785320971666, -0.4305084872546609, -0.4568684402683488, -0.48425038176846114, -0.5124662025002632, -0.5413604102099954, -0.570804195364537, -0.6006903826841267, -0.6309292682875075, -0.6614452484025567, -0.6921741162570209, -0.7230609052264604, -0.7540581704260331, -0.7851246186089047, -0.8162240133333182, -0.8473242972732138, -0.8783968858846994, -0.9094160965494269, -0.9403586851383843, -0.9712034680545067, -1.0019310125678078, -1.0325233819467394, -1.0629639247526257, -1.0932370998885113, -1.1233283307260542, -1.1532238829871686, -1.1829107621176094, -1.2123766267240383, -1.2416097153051486, -1.2705987840301027, -1.2993330537338326, -1.3278021646316718, -1.355996137523151, -1.3839053404703923, -1.4115204601110989, -1.4388324769080352, -1.4658326437526885, -1.492512467435667, -1.5188636925743717, -1.5448782876528528, -1.5705484328820387, -1.5958665096328315, -1.6208250912314668, -1.6454169349374304, -1.669634974950125, -1.6934723163123018, -1.7169222295966613, -1.7399781462776265, -1.7626336547035169, -1.7848824965956116, -1.8067185640101961, -1.8281358967079355, -1.8491286798819337, -1.8696912422019498, -1.8898180541374399, -1.9095037265266295, -1.928743009362729, -1.947530790771801, -1.9658620961597504, -1.9837320875084674, -2.001136062803417, -2.0180694555769327, -2.034527834553196, -2.050506903382393, -2.066002500452897, -2.0810105987714715, -2.0955273059025616, -2.1095488639586324, -2.123071649634357, -2.1360921742781613, -2.1486070839953015, -2.1606131597771934, -2.172107317652274, -2.1830866088540954, -2.1935482200027923, -2.2034894732964205, -2.2129078267090114, -2.2218008741924886, -2.2301663458798564, -2.2380021082873345, -2.245306164513333, -2.2520766544323623, -2.2583118548821814, -2.264010179842631, -2.2691701806047946, -2.273790545929251, -2.277870102192332, -2.2814078135194267, -2.2844027819044888, -2.286854247315031, -2.28876158778198, -2.29012431947388, -2.290942096755035], [-2.320825769815377, -2.320550460604341, -2.3197246033805023, -2.318348409364541, -2.316422230567226, -2.3139465597540583, -2.31092203039613, -2.3073494166075963, -2.3032296330702167, -2.298563734945596, -2.293352917775822, -2.2875985173733615, -2.281302009701192, -2.2744650107442883, -2.2670892763737416, -2.2591767022049347, -2.2507293234513996, -2.241749314776133, -2.2322389901423794, -2.222200802666105, -2.2116373444726176, -2.200551346560068, -2.188945678672853, -2.176823349188259, -2.164187505020045, -2.1510414315430615, -2.137388552543413, -2.1232324301992014, -2.108576765097376, -2.0934253962928553, -2.077782301416744, -2.0616515968412332, -2.045037537909592, -2.027944519240662, -2.010377075118281, -1.9923398799773204, -1.973837748999367, -1.9548756388326374, -1.9354586484524723, -1.9155920201807728, -1.8952811408850019, -1.8745315433800023, -1.8533489080588386, -1.831739064782304, -1.8097079950606445, -1.7872618345655604, -1.7644068760157574, -1.7411495724853303, -1.7174965411912206, -1.6934545678240864, -1.6690306114963276, -1.644231810391989, -1.6190654882161064, -1.5935391615560996, -1.5676605482855255, -1.5414375771613456, -1.5148783987905008, -1.4879913981708046, -1.460785209045866, -1.4332687303551404, -1.4054511451096803, -1.3773419420835082, -1.3489509407819367, -1.3202883202343552, -1.2913646522634166, -1.2621909400094102, -1.2327786626433332, -1.2031398273914777, -1.1732870302268277, -1.1432335268690308, -1.1129933160889711, -1.082581237753578, -1.0520130885938803, -1.02130575936309, -0.9904773979082644, -0.9595476037555971, -0.9285376611650779, -0.897470819320521, -0.8663726304804124, -0.8352713596407944, -0.8041984826952927, -0.7731892943845313, -0.7422836526873406, -0.7115268928894211, -0.6809709524770375, -0.650675757173072, -0.6207109283967724, -0.5911578819299743, -0.5621123938472904, -0.533687707325223, -0.5060182326042711, -0.4792638343813113, -0.45361457737787175, -0.42929556923405304, -0.4065711476449631, -0.3857470645987922, -0.36716855396278025, -0.35121144364999973, -0.3382633311691722, -0.3286931591742262, -0.32281107199993037, -0.3208257698153768, -0.3228110719999345, -0.32869315917423414, -0.3382633311691838, -0.35121144365001467, -0.3671685539627981, -0.38574706459881253, -0.40657114764498553, -0.42929556923407725, -0.4536145773778974, -0.47926383438133824, -0.5060182326042992, -0.5336877073252518, -0.5621123938473199, -0.5911578819300044, -0.620710928396803, -0.650675757173103, -0.6809709524770687, -0.7115268928894525, -0.7422836526873724, -0.7731892943845631, -0.8041984826953246, -0.8352713596408263, -0.8663726304804443, -0.897470819320553, -0.9285376611651098, -0.9595476037556291, -0.990477397908296, -1.0213057593631216, -1.0520130885939118, -1.0825812377536093, -1.1129933160890024, -1.1432335268690617, -1.1732870302268583, -1.2031398273915084, -1.2327786626433637, -1.2621909400094402, -1.2913646522634463, -1.3202883202343847, -1.3489509407819662, -1.3773419420835373, -1.405451145109709, -1.4332687303551688, -1.4607852090458942, -1.4879913981708324, -1.5148783987905283, -1.5414375771613729, -1.5676605482855526, -1.5935391615561258, -1.6190654882161326, -1.6442318103920148, -1.6690306114963527, -1.693454567824111, -1.7174965411912453, -1.7411495724853545, -1.7644068760157814, -1.7872618345655837, -1.8097079950606678, -1.8317390647823262, -1.8533489080588603, -1.874531543380024, -1.895281140885023, -1.9155920201807932, -1.9354586484524927, -1.9548756388326574, -1.9738377489993864, -1.9923398799773386, -2.010377075118299, -2.0279445192406804, -2.04503753790961, -2.06165159684125, -2.0777823014167605, -2.093425396292871, -2.1085767650973914, -2.1232324301992165, -2.1373885525434275, -2.1510414315430757, -2.1641875050200587, -2.1768233491882714, -2.1889456786728654, -2.20055134656008, -2.2116373444726287, -2.2222008026661153, -2.2322389901423896, -2.241749314776142, -2.2507293234514085, -2.259176702204943, -2.267089276373749, -2.2744650107442963, -2.2813020097011987, -2.2875985173733677, -2.2933529177758274, -2.298563734945601, -2.3032296330702215, -2.3073494166076, -2.3109220303961338, -2.313946559754061, -2.316422230567228, -2.3183484093645426, -2.3197246033805037, -2.3205504606043417], [-2.3501264491914, -2.3498485412991874, -2.349014889318994, -2.347625708334373, -2.345681356798712, -2.343182336506647, -2.3401292925544617, -2.3365230132899097, -2.33236443025201, -2.327654618101516, -2.322394794542876, -2.3165863202386654, -2.3102306987176227, -2.3033295762775663, -2.29588474188467, -2.2878981270707315, -2.279371805830295, -2.2703079945196882, -2.2607090517602617, -2.2505774783484047, -2.239915917175157, -2.2287271531585513, -2.2170141131921692, -2.204779866113753, -2.1920276226981072, -2.178760735679019, -2.1649826998053676, -2.1506971519372087, -2.1359078711881847, -2.120618779121352, -2.1048339400062437, -2.0885575611458798, -2.0717939932833986, -2.0545477310990643, -2.0368234138096453, -2.018625825883527, -1.9999598978865014, -1.9808307074749312, -1.9612434805549912, -1.941203592628989, -1.9207165703523257, -1.899788093327651, -1.8784239961661093, -1.8566302708494717, -1.8344130694313587, -1.8117787071208666, -1.7887336657977746, -1.765284598015284, -1.74143833155407, -1.7172018746005042, -1.6925824216324556, -1.6675873601083466, -1.6422242780694805, -1.6165009727824133, -1.5904254605678094, -1.5640059879853299, -1.5372510445713654, -1.5101693773586238, -1.4827700074447592, -1.4550622489225877, -1.4270557305385108, -1.3987604205103579, -1.3701866550133313, -1.3413451709358255, -1.3122471436191736, -1.2829042304311458, -1.253328621187742, -1.2235330966382316, -1.1935310964729842, -1.1633367986130014, -1.1329652119075386, -1.1024322848184887, -1.0717550332282968, -1.0409516911983379, -1.0100418893597942, -0.9790468666799272, -0.9479897226635657, -0.9168957186838694, -0.8857926391609663, -0.8547112258061589, -0.8236857012150388, -0.7927544018154079, -0.7619605446237143, -0.7313531574428002, -0.7009882079124623, -0.6709299727976629, -0.6412526941530742, -0.6120425717166246, -0.5834001376905427, -0.5554430450685516, -0.528309264063598, -0.5021606076670052, -0.47718637495535, -0.45360668216810984, -0.4316747224230146, -0.41167675637677276, -0.39392816032317246, -0.3787635541855952, -0.3665192916885639, -0.3575079123180733, -0.35198677612438073, -0.3501264491913999, -0.35198677612438456, -0.35750791231808077, -0.3665192916885749, -0.37876355418560936, -0.3939281603231895, -0.41167675637679224, -0.43167472242303623, -0.45360668216813327, -0.477186374955375, -0.5021606076670315, -0.5283092640636254, -0.5554430450685799, -0.5834001376905718, -0.6120425717166542, -0.6412526941531044, -0.6709299727976936, -0.7009882079124933, -0.7313531574428316, -0.7619605446237459, -0.7927544018154397, -0.8236857012150706, -0.8547112258061909, -0.8857926391609983, -0.9168957186839014, -0.9479897226635976, -0.979046866679959, -1.010041889359826, -1.0409516911983694, -1.0717550332283283, -1.10243228481852, -1.13296521190757, -1.1633367986130327, -1.193531096473015, -1.2235330966382625, -1.2533286211877726, -1.282904230431176, -1.3122471436192036, -1.3413451709358553, -1.3701866550133608, -1.3987604205103872, -1.4270557305385398, -1.4550622489226164, -1.4827700074447874, -1.5101693773586518, -1.537251044571393, -1.5640059879853572, -1.5904254605678365, -1.61650097278244, -1.6422242780695064, -1.6675873601083724, -1.692582421632481, -1.7172018746005295, -1.7414383315540949, -1.7652845980153085, -1.7887336657977986, -1.81177870712089, -1.8344130694313818, -1.8566302708494942, -1.878423996166131, -1.8997880933276725, -1.920716570352347, -1.9412035926290094, -1.9612434805550116, -1.9808307074749512, -1.999959897886521, -2.0186258258835457, -2.0368234138096635, -2.0545477310990825, -2.0717939932834164, -2.0885575611458966, -2.10483394000626, -2.120618779121368, -2.1359078711882002, -2.1506971519372238, -2.1649826998053827, -2.1787607356790333, -2.1920276226981206, -2.204779866113766, -2.2170141131921817, -2.228727153158563, -2.2399159171751686, -2.2505774783484154, -2.2607090517602715, -2.2703079945196976, -2.2793718058303045, -2.2878981270707395, -2.2958847418846777, -2.3033295762775743, -2.3102306987176293, -2.3165863202386716, -2.3223947945428813, -2.3276546181015214, -2.332364430252015, -2.3365230132899133, -2.3401292925544657, -2.34318233650665, -2.345681356798714, -2.347625708334374, -2.3490148893189953, -2.3498485412991883], [-2.3790884038403886, -2.378807990217812, -2.377966822343191, -2.376565119191491, -2.3746032457064876, -2.372081712779275, -2.3690011772186437, -2.365362441713837, -2.361166454790294, -2.356414310759198, -2.3511072496617227, -2.3452466572091293, -2.338834064719954, -2.3318711490557695, -2.3243597325571685, -2.3163017829818457, -2.307699413446863, -2.2985548823774473, -2.2888705934649187, -2.278649095636648, -2.2678930830412507, -2.2566053950525666, -2.2447890162963726, -2.232447076704166, -2.2195828515988403, -2.2061997618175706, -2.1923013738778017, -2.177891400192847, -2.1629736993443145, -2.147552276419362, -2.13163128342162, -2.1152150197656447, -2.0983079328658043, -2.0809146188317698, -2.06303982328412, -2.04468844230516, -2.0258655235417793, -2.006576267479171, -1.9868260289064752, -1.9666203185979574, -1.9459648052362335, -1.9248653176073516, -1.903327847101298, -1.881358550555811, -1.8589637534863122, -1.8361499537504122, -1.8129238257019684, -1.7892922248971566, -1.7652621934236743, -1.7408409659342123, -1.7160359764769308, -1.6908548662291754, -1.665305492256377, -1.6393959374364253, -1.6131345217112552, -1.5865298148525782, -1.5595906509582496, -1.5323261449306733, -1.5047457112298264, -1.4768590852423111, -1.4486763476658155, -1.4202079523773716, -1.3914647583362252, -1.3624580661707524, -1.3331996602172453, -1.3037018569208276, -1.2739775606806114, -1.2440403284290464, -1.2139044444873963, -1.1835850075454908, -1.1530980319868078, -1.1224605662348774, -1.0916908313529257, -1.0608083838086857, -1.0298343071485183, -0.9987914383431258, -0.967704635811012, -0.9366010976410354, -0.9055107403720049, -0.8744666508959609, -0.8435056266757709, -0.8126688225271637, -0.7820025256789912, -0.7515590845606146, -0.7213980204525368, -0.6915873541289226, -0.6622051807175503, -0.6333415230985651, -0.6051004837342058, -0.5776026912329811, -0.5509879926672183, -0.5254182636739393, -0.5010800806890082, -0.4781868086711316, -0.45697939837984863, -0.4377248834036417, -0.42071130138397445, -0.4062377095916518, -0.394598385014931, -0.386061449835492, -0.3808440584937032, -0.37908840384038855, -0.38084405849370684, -0.3860614498354991, -0.39459838501494143, -0.4062377095916653, -0.42071130138399077, -0.43772488340366034, -0.4569793983798695, -0.4781868086711544, -0.5010800806890326, -0.5254182636739649, -0.5509879926672453, -0.577602691233009, -0.6051004837342343, -0.6333415230985944, -0.6622051807175802, -0.6915873541289531, -0.7213980204525676, -0.7515590845606458, -0.7820025256790226, -0.8126688225271953, -0.8435056266758026, -0.8744666508959927, -0.9055107403720367, -0.9366010976410672, -0.9677046358110439, -0.9987914383431576, -1.0298343071485503, -1.0608083838087177, -1.0916908313529574, -1.122460566234909, -1.1530980319868396, -1.183585007545522, -1.2139044444874274, -1.2440403284290775, -1.2739775606806423, -1.303701856920858, -1.3331996602172755, -1.3624580661707824, -1.3914647583362547, -1.4202079523774012, -1.4486763476658446, -1.4768590852423402, -1.5047457112298548, -1.5323261449307017, -1.5595906509582773, -1.5865298148526057, -1.6131345217112825, -1.639395937436452, -1.6653054922564037, -1.6908548662292016, -1.7160359764769566, -1.7408409659342376, -1.7652621934236992, -1.7892922248971812, -1.8129238257019928, -1.836149953750436, -1.8589637534863355, -1.881358550555834, -1.9033278471013204, -1.924865317607374, -1.9459648052362553, -1.9666203185979783, -1.9868260289064956, -2.006576267479191, -2.025865523541799, -2.044688442305179, -2.0630398232841385, -2.080914618831788, -2.098307932865822, -2.115215019765661, -2.131631283421637, -2.147552276419378, -2.1629736993443305, -2.1778914001928618, -2.192301373877817, -2.2061997618175853, -2.219582851598854, -2.232447076704179, -2.244789016296385, -2.256605395052578, -2.2678930830412622, -2.278649095636659, -2.288870593464929, -2.2985548823774566, -2.3076994134468722, -2.3163017829818546, -2.324359732557176, -2.331871149055777, -2.3388340647199612, -2.3452466572091355, -2.3511072496617285, -2.3564143107592033, -2.361166454790299, -2.365362441713841, -2.369001177218648, -2.3720817127792775, -2.3746032457064894, -2.376565119191493, -2.377966822343193, -2.3788079902178123], [-2.407683614941698, -2.407400786465576, -2.4065523753326565, -2.405138604426379, -2.4031598452095264, -2.400616617710072, -2.3975095905019073, -2.393839580680991, -2.3896075538376276, -2.384814624025757, -2.379462053730303, -2.3735512538338144, -2.3670837835838396, -2.3600613505626558, -2.3524858106612228, -2.34435916805945, -2.335683575215107, -2.326461332864022, -2.3166948900344577, -2.3063868440789177, -2.29553994072697, -2.2841570741630584, -2.272241287133707, -2.259795771088987, -2.2468238663636106, -2.233329062403616, -2.2193149980452156, -2.2047854618530756, -2.189744392526095, -2.1741958793795964, -2.1581441629138087, -2.1415936354796234, -2.124548842053792, -2.107014481137106, -2.088995405790621, -2.0704966248267094, -2.0515233041736702, -2.032080768434794, -2.012174502665293, -1.991810154393281, -1.9709935359142121, -1.9497306268917862, -1.9280275773024882, -1.9058907107656413, -1.8833265283062588, -1.860341712604159, -1.8369431327899355, -1.8131378498565196, -1.7889331227645262, -1.7643364153304235, -1.7393554039991856, -1.7139979866176733, -1.688272292341967, -1.6621866928316353, -1.6357498149070002, -1.6089705548724336, -1.58185809474037, -1.554421920627892, -1.5266718436415365, -1.4986180236176625, -1.4702709961468914, -1.441641703383681, -1.412741529228339, -1.3835823395715536, -1.3541765284142497, -1.3245370708224669, -1.2946775838531452, -1.2646123967984397, -1.2343566323510993, -1.2039263006008745, -1.1733384081431013, -1.1426110850292297, -1.1117637328314867, -1.0808171977495273, -1.0497939734785782, -1.0187184395122073, -0.987617141697129, -0.9565191232220615, -0.9254563158350347, -0.8944640029624333, -0.8635813685469855, -0.8328521477896573, -0.8023253984577065, -0.7720564137670652, -0.742107799608109, -0.7125507392607264, -0.6834664663948319, -0.6549479599084516, -0.6271018586569576, -0.6000505654068261, -0.5739344605219003, -0.5489140683278294, -0.5251719038405691, -0.502913569306688, -0.48236747559894755, -0.4637823659886404, -0.4474216963055106, -0.433554008081084, -0.4224388867618337, -0.41430904447211747, -0.40935042796555193, -0.4076836149416981, -0.4093504279655554, -0.4143090444721242, -0.42243888676184366, -0.43355400808109684, -0.44742169630552625, -0.46378236598865835, -0.4823674755989677, -0.5029135693067099, -0.5251719038405926, -0.5489140683278545, -0.5739344605219266, -0.6000505654068534, -0.6271018586569858, -0.6549479599084804, -0.6834664663948614, -0.7125507392607566, -0.7421077996081396, -0.7720564137670963, -0.8023253984577376, -0.8328521477896889, -0.8635813685470173, -0.8944640029624651, -0.9254563158350666, -0.9565191232220934, -0.9876171416971611, -1.0187184395122393, -1.04979397347861, -1.0808171977495593, -1.1117637328315184, -1.1426110850292612, -1.1733384081431326, -1.2039263006009058, -1.2343566323511304, -1.2646123967984708, -1.2946775838531763, -1.3245370708224973, -1.35417652841428, -1.3835823395715836, -1.4127415292283687, -1.4416417033837106, -1.4702709961469207, -1.4986180236176914, -1.5266718436415654, -1.5544219206279202, -1.5818580947403977, -1.6089705548724613, -1.6357498149070273, -1.6621866928316622, -1.6882722923419935, -1.7139979866176995, -1.7393554039992114, -1.764336415330449, -1.7889331227645513, -1.8131378498565442, -1.8369431327899597, -1.860341712604183, -1.8833265283062823, -1.9058907107656644, -1.9280275773025106, -1.9497306268918082, -1.9709935359142339, -1.991810154393302, -2.0121745026653133, -2.0320807684348146, -2.0515233041736898, -2.0704966248267285, -2.0889954057906395, -2.1070144811371243, -2.12454884205381, -2.1415936354796403, -2.158144162913825, -2.1741958793796132, -2.1897443925261113, -2.20478546185309, -2.2193149980452302, -2.2333290624036306, -2.246823866363624, -2.2597957710889998, -2.272241287133719, -2.28415707416307, -2.295539940726982, -2.306386844078929, -2.316694890034468, -2.3264613328640316, -2.3356835752151164, -2.344359168059459, -2.352485810661231, -2.360061350562663, -2.3670837835838463, -2.3735512538338206, -2.379462053730309, -2.384814624025762, -2.3896075538376316, -2.3938395806809956, -2.397509590501911, -2.4006166177100754, -2.403159845209529, -2.405138604426381, -2.406552375332658, -2.407400786465576], [-2.4358844184753803, -2.435599263986462, -2.434743876119476, -2.4333184816723343, -2.431323458636951, -2.428759336192647, -2.425626794697497, -2.4219266656782485, -2.417659931819578, -2.4128277269536667, -2.4074313360512543, -2.4014721952155424, -2.394951891680537, -2.387872163815631, -2.380234901138495, -2.3720421443385824, -2.3632960853138494, -2.3539990672235853, -2.344153584560587, -2.333762283246245, -2.3228279607525306, -2.3113535662552733, -2.2993422008235904, -2.2867971176508592, -2.27372172233317, -2.2601195732018295, -2.245994381717198, -2.2313500129318657, -2.2161904860320907, -2.2005199749673183, -2.18434280917869, -2.167663474438636, -2.1504866138149716, -2.1328170287743906, -2.114659680441946, -2.096019691034975, -2.076902345492041, -2.0573130933198622, -2.037257550683902, -2.0167415027713456, -1.9957709064586735, -1.9743518933199748, -1.9524907730166348, -1.9301940371141504, -1.9074683633776774, -1.8843206206045817, -1.8607578740599597, -1.8367873915898711, -1.8124166504971668, -1.7876533452764725, -1.7625053963183606, -1.7369809597083599, -1.7110884382645317, -1.6848364939783762, -1.6582340620482965, -1.631290366723403, -1.604014939208822, -1.5764176379227688, -1.5485086714415568, -1.520298624522703, -1.4917984876599617, -1.4630196906992894, -1.4339741411337565, -1.4046742678009547, -1.3751330708318301, -1.3453641788491246, -1.3153819145914882, -1.2852013703517007, -1.2548384948712337, -1.2243101936369472, -1.193634444888947, -1.1628304340831794, -1.131918710071778, -1.1009213668839255, -1.0698622557271993, -1.0387672327020674, -1.0076644487480484, -0.9765846895333842, -0.9455617743672035, -0.9146330247440565, -0.8838398147853288, -0.853228217528566, -0.8228497625557228, -0.7927623215267533, -0.7630311382579532, -0.7337300181817398, -0.7049426869770062, -0.6767643177967955, -0.6493032078429932, -0.6226825539362444, -0.5970422280269547, -0.5725403816668492, -0.5493546090498836, -0.5276822723144149, -0.5077394533787926, -0.4897578782279066, -0.4739791274917155, -0.4606455968772624, -0.4499881033900844, -0.4422107915230808, -0.43747497266628754, -0.43588441847538034, -0.43747497266629076, -0.44221079152308734, -0.44998810339009393, -0.46064559687727485, -0.47397912749173055, -0.48975787822792394, -0.507739453378812, -0.5276822723144363, -0.5493546090499067, -0.5725403816668737, -0.5970422280269806, -0.6226825539362711, -0.649303207843021, -0.6767643177968239, -0.7049426869770353, -0.7337300181817696, -0.7630311382579834, -0.792762321526784, -0.8228497625557539, -0.8532282175285973, -0.8838398147853603, -0.9146330247440881, -0.9455617743672352, -0.976584689533416, -1.0076644487480804, -1.0387672327020994, -1.0698622557272315, -1.1009213668839575, -1.1319187100718098, -1.1628304340832114, -1.1936344448889786, -1.2243101936369787, -1.2548384948712648, -1.2852013703517318, -1.315381914591519, -1.3453641788491553, -1.3751330708318603, -1.4046742678009847, -1.4339741411337865, -1.463019690699319, -1.4917984876599912, -1.520298624522732, -1.5485086714415854, -1.5764176379227974, -1.6040149392088503, -1.6312903667234313, -1.658234062048324, -1.6848364939784035, -1.7110884382645584, -1.7369809597083863, -1.7625053963183865, -1.7876533452764978, -1.812416650497192, -1.836787391589896, -1.8607578740599842, -1.8843206206046055, -1.9074683633777008, -1.9301940371141735, -1.9524907730166572, -1.974351893319997, -1.9957709064586948, -2.0167415027713664, -2.0372575506839223, -2.057313093319883, -2.0769023454920608, -2.096019691034994, -2.1146596804419646, -2.132817028774409, -2.1504866138149903, -2.167663474438654, -2.1843428091787067, -2.200519974967335, -2.216190486032107, -2.2313500129318804, -2.245994381717213, -2.260119573201844, -2.2737217223331836, -2.2867971176508726, -2.2993422008236024, -2.3113535662552853, -2.3228279607525426, -2.3337622832462555, -2.3441535845605976, -2.3539990672235955, -2.3632960853138587, -2.3720421443385913, -2.3802349011385027, -2.3878721638156386, -2.394951891680544, -2.401472195215549, -2.40743133605126, -2.4128277269536724, -2.4176599318195824, -2.421926665678253, -2.4256267946975005, -2.4287593361926496, -2.4313234586369536, -2.4333184816723357, -2.4347438761194766, -2.435599263986462], [-2.4636635319853366, -2.4633761383305792, -2.462514034268843, -2.4610774505078568, -2.4590667715610195, -2.456482535748495, -2.4533254351994076, -2.449596315855794, -2.4452961774791744, -2.4404261736608057, -2.4349876118369003, -2.4289819533103096, -2.4224108132804094, -2.415275960883181, -2.407579319243734, -2.3993229655438193, -2.3905091311071764, -2.3811402015058856, -2.371218716691274, -2.3607473711532942, -2.349729014112727, -2.338166649751035, -2.3260634374831857, -2.3134226922793424, -2.300247885041924, -2.2865426430452347, -2.2723107504456, -2.2575561488708034, -2.2422829380985387, -2.2264953768346154, -2.2101978836028473, -2.1933950377597977, -2.1760915806490173, -2.1582924169110416, -2.140002615967184, -2.1212274136972344, -2.101972214333445, -2.082242592595776, -2.0620442960962695, -2.0413832480437586, -2.020265550283805, -1.9986974867130438, -1.9766855271118986, -1.9542363314451308, -1.9313567546859502, -1.908053852226542, -1.8843348859460614, -1.860207331016514, -1.8356788835377065, -1.8107574691048531, -1.7854512524266777, -1.7597686481283674, -1.7337183328927803, -1.7073092591154344, -1.6805506702744646, -1.6534521182466029, -1.6260234828350382, -1.5982749938156728, -1.5702172558558294, -1.5418612767152209, -1.5132184992044266, -1.4843008374531128, -1.4551207181309227, -1.4256911273709942, -1.39602566427253, -1.3661386020084825, -1.3360449577416482, -1.305760572762537, -1.2753022045114772, -1.2446876324427756, -1.2139357800387294, -1.183066855695415, -1.1521025156910418, -1.121066053022626, -1.0899826165692597, -1.0588794658207807, -1.027786267306224, -0.9967354398674223, -0.9657625570369504, -0.9349068159615991, -0.9042115834911496, -0.8737250310963881, -0.8435008709659785, -0.813599205592374, -0.7840875018134568, -0.7550416967431474, -0.7265474359885744, -0.6987014321421134, -0.671612911212544, -0.6454050832072113, -0.6202165268842789, -0.5962023145949659, -0.5735346202617995, -0.5524024566684206, -0.5330100928437382, -0.5155736404542124, -0.5003153218623412, -0.48745510842747347, -0.47719980336262063, -0.46973024253987106, -0.46518799514938153, -0.46366353198533655, -0.4651879951493847, -0.4697302425398772, -0.47719980336262985, -0.48745510842748546, -0.5003153218623557, -0.5155736404542292, -0.5330100928437572, -0.5524024566684415, -0.5735346202618219, -0.5962023145949897, -0.6202165268843043, -0.6454050832072379, -0.6716129112125714, -0.6987014321421418, -0.7265474359886034, -0.755041696743177, -0.784087501813487, -0.8135992055924044, -0.8435008709660095, -0.8737250310964192, -0.9042115834911809, -0.9349068159616306, -0.9657625570369821, -0.9967354398674542, -1.0277862673062559, -1.0588794658208127, -1.0899826165692919, -1.121066053022658, -1.1521025156910738, -1.1830668556954465, -1.2139357800387611, -1.2446876324428071, -1.2753022045115088, -1.3057605727625683, -1.3360449577416793, -1.3661386020085133, -1.3960256642725608, -1.4256911273710247, -1.455120718130953, -1.4843008374531428, -1.5132184992044564, -1.54186127671525, -1.5702172558558585, -1.5982749938157015, -1.6260234828350666, -1.6534521182466306, -1.6805506702744923, -1.7073092591154615, -1.7337183328928072, -1.759768648128394, -1.7854512524267039, -1.810757469104879, -1.835678883537732, -1.8602073310165388, -1.8843348859460862, -1.908053852226566, -1.931356754685974, -1.954236331445154, -1.9766855271119215, -1.9986974867130662, -2.0202655502838267, -2.04138324804378, -2.0620442960962904, -2.0822425925957964, -2.1019722143334656, -2.121227413697253, -2.140002615967203, -2.1582924169110607, -2.1760915806490355, -2.193395037759815, -2.210197883602865, -2.2264953768346314, -2.2422829380985543, -2.2575561488708193, -2.272310750445615, -2.2865426430452493, -2.300247885041938, -2.3134226922793557, -2.3260634374831985, -2.3381666497510474, -2.349729014112739, -2.360747371153305, -2.371218716691285, -2.3811402015058953, -2.3905091311071858, -2.399322965543828, -2.407579319243742, -2.415275960883189, -2.422410813280417, -2.428981953310316, -2.4349876118369065, -2.440426173660811, -2.4452961774791793, -2.449596315855798, -2.453325435199411, -2.456482535748498, -2.4590667715610217, -2.4610774505078585, -2.462514034268844, -2.46337613833058], [-2.4909940809733313, -2.4907045330518747, -2.4898359674878416, -2.488388618883923, -2.486362878250302, -2.4837592930135575, -2.480578567029841, -2.4768215606030535, -2.472489290508953, -2.467582930026355, -2.4621038089768197, -2.456053413774456, -2.449433387487738, -2.4422455299154966, -2.434491797679533, -2.426174304336628, -2.417295320513029, -2.407857274064881, -2.3978627502684398, -2.3873144920443345, -2.376215400220615, -2.364568533839808, -2.3523771105157776, -2.3396445068467777, -2.326374258891762, -2.312570062717753, -2.2982357750268836, -2.283375413872642, -2.2679931594758345, -2.252093355151921, -2.235680508362594, -2.2187592919058887, -2.2013345452606305, -2.1834112761027917, -2.16499466201324, -2.146090052398575, -2.1267029706491822, -2.1068391165614027, -2.086504369053839, -2.0657047892113334, -2.0444466236941334, -2.0227363085542955, -2.0005804735064707, -1.9779859467060674, -1.9549597600944126, -1.9315091553780914, -1.9076415907182989, -1.8833647482159221, -1.8586865422894134, -1.8336151290555323, -1.8081589168380061, -1.782326577946415, -1.7561270618875031, -1.7295696101941649, -1.7026637730839715, -1.6754194281900665, -1.6478468016431573, -1.6199564918251874, -1.591759496164001, -1.5632672413952764, -1.5344916177845718, -1.5054450178803043, -1.4761403804599122, -1.4465912404387822, -1.4168117856376492, -1.3868169214524748, -1.35662234464528, -1.3262446276796573, -1.2957013152660435, -1.2650110350653665, -1.2341936248321244, -1.203270278666664, -1.1722637154990099, -1.141198373450384, -1.1101006343196658, -1.0789990831235972, -1.0479248083792048, -1.0169117496424114, -0.9859970996796523, -0.9552217694946188, -0.9246309251640091, -0.8942746058954003, -0.8642084326538892, -0.8344944157213195, -0.8052018670667832, -0.7764084185664192, -0.7482011387131646, -0.7206777268835728, -0.6939477434236494, -0.6681338034071804, -0.6433726196239965, -0.619815724886712, -0.5976296365120741, -0.5769951536308955, -0.5581054165002001, -0.5411623340432979, -0.5263710415323061, -0.5139322296313852, -0.5040325191929363, -0.496833527450494, -0.49246078831706025, -0.4909940809733314, -0.49246078831706325, -0.4968335274504999, -0.5040325191929452, -0.5139322296313967, -0.5263710415323201, -0.5411623340433143, -0.5581054165002185, -0.5769951536309159, -0.5976296365120961, -0.6198157248867354, -0.6433726196240215, -0.6681338034072064, -0.6939477434236765, -0.7206777268836007, -0.7482011387131933, -0.7764084185664484, -0.8052018670668131, -0.8344944157213499, -0.86420843265392, -0.8942746058954312, -0.9246309251640403, -0.9552217694946504, -0.9859970996796841, -1.0169117496424434, -1.0479248083792367, -1.0789990831236291, -1.1101006343196977, -1.141198373450416, -1.1722637154990416, -1.2032702786666958, -1.234193624832156, -1.2650110350653982, -1.2957013152660752, -1.3262446276796889, -1.3566223446453114, -1.3868169214525057, -1.41681178563768, -1.4465912404388126, -1.4761403804599427, -1.5054450178803347, -1.5344916177846013, -1.5632672413953057, -1.5917594961640302, -1.6199564918252165, -1.6478468016431858, -1.6754194281900945, -1.7026637730839993, -1.7295696101941922, -1.7561270618875302, -1.782326577946442, -1.8081589168380325, -1.8336151290555582, -1.858686542289439, -1.8833647482159475, -1.9076415907183235, -1.9315091553781154, -1.9549597600944362, -1.9779859467060907, -2.000580473506494, -2.022736308554318, -2.0444466236941556, -2.0657047892113547, -2.08650436905386, -2.106839116561423, -2.1267029706492027, -2.146090052398595, -2.164994662013259, -2.1834112761028104, -2.201334545260649, -2.218759291905906, -2.2356805083626115, -2.2520933551519375, -2.267993159475851, -2.2833754138726574, -2.2982357750268987, -2.3125700627177674, -2.326374258891776, -2.339644506846791, -2.3523771105157896, -2.3645685338398197, -2.3762154002206266, -2.387314492044345, -2.3978627502684504, -2.407857274064891, -2.417295320513038, -2.426174304336637, -2.434491797679541, -2.4422455299155046, -2.449433387487745, -2.4560534137744625, -2.462103808976825, -2.46758293002636, -2.4724892905089577, -2.476821560603058, -2.4805785670298444, -2.48375929301356, -2.486362878250304, -2.4883886188839246, -2.489835967487842, -2.490704533051875], [-2.5178496248983344, -2.5175580057105655, -2.5166832276371878, -2.5152255291512344, -2.5131853077186825, -2.510563119815218, -2.507359680950482, -2.50357586570057, -2.499212707749807, -2.4942713999430377, -2.4887532943499475, -2.4826599023431735, -2.475992894692248, -2.468754101675717, -2.4609455132140665, -2.4525692790264646, -2.4436277088146316, -2.434123272477582, -2.42405860036139, -2.4134364835485673, -2.4022598741921644, -2.3905318859002316, -2.3782557941768725, -2.3654350369267942, -2.3520732150309325, -2.338174093001573, -2.3237415997262385, -2.308779829310568, -2.293293042031524, -2.2772856654134217, -2.26076229544063, -2.243727697922251, -2.226186810025763, -2.2081447419984346, -2.1896067790974065, -2.1705783837516512, -2.151065197981628, -2.1310730461053833, -2.1106079377631586, -2.0896760712962843, -2.06828383752036, -2.046437823937492, -2.0241448194377543, -2.001411819546183, -1.978246032278585, -1.9546548846773943, -1.9306460301078465, -1.9062273564051226, -1.881406994974917, -1.8561933309634797, -1.8305950146287349, -1.804620974061978, -1.7782804294302634, -1.751582908933355, -1.7245382666965436, -1.6971567028523893, -1.6694487861012044, -1.6414254790827447, -1.6130981669411262, -1.5844786895226086, -1.555579377713, -1.5264130944996628, -1.4969932814343925, -1.4673340112800257, -1.4374500477481322, -1.407356913380627, -1.3770709667980274, -1.3466094907354051, -1.31599079251819, -1.2852343188988167, -1.2543607874868004, -1.2233923373644309, -1.192352701892582, -1.1612674071796691, -1.1301640002126494, -1.0990723112287637, -1.0680247555296956, -1.0370566805831058, -1.0062067648784374, -0.9755174755339502, -0.9450355919764529, -0.9148128029571114, -0.884906383458006, -0.8553799562895908, -0.8263043398113263, -0.7977584774362231, -0.7698304353450915, -0.7426184407887831, -0.7162319129076388, -0.6907924095135319, -0.6664343755430062, -0.643305531975513, -0.6215666907373779, -0.6013907290854216, -0.5829604208603348, -0.5664648249908523, -0.552094003799805, -0.5400320144907836, -0.53044840004841, -0.5234887767065259, -0.5192654961488097, -0.5178496248983345, -0.5192654961488126, -0.5234887767065317, -0.5304484000484185, -0.5400320144907949, -0.5520940037998187, -0.566464824990868, -0.5829604208603529, -0.6013907290854414, -0.6215666907373995, -0.643305531975536, -0.6664343755430306, -0.6907924095135575, -0.7162319129076654, -0.7426184407888108, -0.7698304353451197, -0.797758477436252, -0.8263043398113561, -0.8553799562896209, -0.8849063834580366, -0.9148128029571422, -0.9450355919764841, -0.9755174755339815, -1.0062067648784692, -1.0370566805831376, -1.0680247555297273, -1.0990723112287955, -1.1301640002126812, -1.1612674071797011, -1.1923527018926139, -1.2233923373644628, -1.2543607874868319, -1.2852343188988484, -1.3159907925182215, -1.3466094907354367, -1.3770709667980587, -1.4073569133806578, -1.437450047748163, -1.4673340112800564, -1.4969932814344231, -1.5264130944996932, -1.5555793777130302, -1.5844786895226384, -1.6130981669411553, -1.6414254790827738, -1.669448786101233, -1.6971567028524177, -1.7245382666965714, -1.7515829089333825, -1.778280429430291, -1.8046209740620052, -1.8305950146287615, -1.856193330963506, -1.8814069949749426, -1.9062273564051477, -1.9306460301078714, -1.9546548846774183, -1.9782460322786088, -2.001411819546206, -2.0241448194377774, -2.0464378239375147, -2.068283837520382, -2.0896760712963065, -2.11060793776318, -2.131073046105404, -2.1510651979816484, -2.1705783837516717, -2.189606779097426, -2.2081447419984532, -2.2261868100257813, -2.2437276979222687, -2.2607622954406463, -2.2772856654134386, -2.29329304203154, -2.3087798293105837, -2.3237415997262536, -2.3381740930015877, -2.3520732150309467, -2.365435036926808, -2.378255794176886, -2.3905318859002436, -2.4022598741921763, -2.4134364835485784, -2.4240586003614006, -2.4341232724775916, -2.443627708814641, -2.4525692790264744, -2.4609455132140745, -2.4687541016757244, -2.4759928946922556, -2.4826599023431806, -2.4887532943499533, -2.494271399943043, -2.499212707749812, -2.5035758657005744, -2.507359680950486, -2.510563119815221, -2.5131853077186856, -2.515225529151236, -2.5166832276371887, -2.517558005710566], [-2.5442041827560367, -2.5439105734552343, -2.543029826321043, -2.5415621836629136, -2.539508049346089, -2.536867988816251, -2.5336427291348538, -2.529833159025979, -2.5254403289358107, -2.5204654511060474, -2.514909899662902, -2.5087752107235426, -2.502063082522209, -2.494775375558473, -2.486914112770503, -2.478481479736529, -2.469479824908085, -2.4599116598790256, -2.4497796596947707, -2.439086663206687, -2.427835673477097, -2.41602985824094, -2.4036725504307532, -2.390767248772361, -2.377317618459391, -2.363327491915613, -2.3488008696549882, -2.333741921250386, -2.318154986423052, -2.3020445762661588, -2.285415374617221, -2.2682722395956825, -2.250620205323768, -2.2324644838506393, -2.2138104673020553, -2.1946637302802405, -2.1750300325413723, -2.1549153219811994, -2.134325737962804, -2.113267615024408, -2.0917474870095702, -2.0697720916671125, -2.0473483757737765, -2.0244835008390174, -2.001184849458643, -1.977460032392259, -1.95331689644893, -1.9287635332761943, -1.9038082891598471, -1.8784597759559463, -1.8527268832925416, -1.8266187921970833, -1.8001449903266025, -1.773315289002123, -1.7461398422767747, -1.7186291682994175, -1.6907941732729133, -1.6626461783493256, -1.6341969498542779, -1.6054587332905534, -1.5764442916381072, -1.5471669485454946, -1.5176406370980848, -1.4878799549533435, -1.4579002267552794, -1.427717574881499, -1.397348999740169, -1.3668124710238376, -1.3361270315460025, -1.3053129155381993, -1.2743916835737847, -1.2433863766125413, -1.2123216920298003, -1.1812241849049567, -1.1501224982935496, -1.119047626685483, -1.0880332173414087, -1.0571159146683071, -1.026335753191851, -0.995736604925301, -0.9653666868971138, -0.9352791340955159, -0.9055326418466207, -0.8761921792781666, -0.84732977150202, -0.8190253417656805, -0.7913675951702105, -0.7644549115450553, -0.7383961955410765, -0.7133116059352447, -0.6893330531328852, -0.6666043149125254, -0.6452805791771903, -0.6255271865131439, -0.6075173277982274, -0.5914284717398701, -0.5774373761732585, -0.5657136938318644, -0.5564124213720216, -0.5496657334453733, -0.5455750272374409, -0.5442041827560364, -0.5455750272374437, -0.549665733445379, -0.5564124213720298, -0.5657136938318754, -0.5774373761732717, -0.5914284717398856, -0.6075173277982451, -0.6255271865131633, -0.6452805791772114, -0.6666043149125479, -0.6893330531329093, -0.7133116059352699, -0.7383961955411029, -0.7644549115450824, -0.7913675951702384, -0.8190253417657094, -0.8473297715020495, -0.8761921792781965, -0.9055326418466512, -0.9352791340955466, -0.9653666868971449, -0.9957366049253322, -1.0263357531918824, -1.0571159146683389, -1.0880332173414402, -1.1190476266855147, -1.1501224982935816, -1.1812241849049887, -1.2123216920298323, -1.2433863766125728, -1.2743916835738165, -1.305312915538231, -1.336127031546034, -1.3668124710238694, -1.3973489997402, -1.42771757488153, -1.4579002267553103, -1.4878799549533739, -1.5176406370981155, -1.5471669485455253, -1.5764442916381374, -1.605458733290583, -1.6341969498543072, -1.6626461783493547, -1.6907941732729421, -1.7186291682994461, -1.7461398422768026, -1.7733152890021506, -1.8001449903266298, -1.82661879219711, -1.8527268832925685, -1.8784597759559727, -1.9038082891598729, -1.9287635332762196, -1.953316896448955, -1.9774600323922833, -2.001184849458667, -2.0244835008390414, -2.0473483757737996, -2.0697720916671356, -2.091747487009592, -2.1132676150244296, -2.134325737962825, -2.1549153219812207, -2.1750300325413927, -2.1946637302802605, -2.2138104673020744, -2.2324644838506584, -2.250620205323787, -2.2682722395957, -2.285415374617238, -2.3020445762661756, -2.318154986423068, -2.333741921250402, -2.348800869655004, -2.363327491915629, -2.377317618459405, -2.3907672487723732, -2.403672550430766, -2.4160298582409525, -2.427835673477109, -2.439086663206698, -2.4497796596947814, -2.4599116598790363, -2.469479824908094, -2.4784814797365375, -2.4869141127705108, -2.4947753755584805, -2.5020630825222163, -2.508775210723549, -2.5149098996629076, -2.5204654511060527, -2.525440328935816, -2.529833159025984, -2.5336427291348578, -2.5368679888162546, -2.5395080493460918, -2.5415621836629145, -2.5430298263210442, -2.543910573455235], [-2.570032258213792, -2.569736738159881, -2.5688502600303904, -2.567373069928419, -2.565305578047175, -2.562648358702486, -2.5594021503791935, -2.5555678557923223, -2.5511465419642, -2.546139440318935, -2.540547946796002, -2.534373621984928, -2.527618191283446, -2.5202835450817593, -2.5123717389759657, -2.5038849940140393, -2.494825696978191, -2.4851964007078626, -2.4749998244680986, -2.464238854368528, -2.4529165438387923, -2.441036114166836, -2.428600955107159, -2.415614625566879, -2.4020808543782426, -2.388003541167136, -2.3733867573281087, -2.358234747117537, -2.342551928877747, -2.326342896406244, -2.309612420485708, -2.2923654505920457, -2.274607116799637, -2.256342731904985, -2.2375777937922483, -2.2183179880667456, -2.1985691909853706, -2.178337472716109, -2.1576291009624953, -2.1364505449929214, -2.1148084801193416, -2.09270979267512, -2.0701615855476585, -2.047171184328103, -2.023746144147978, -1.9998942572811798, -1.9756235615994906, -1.9509423499808594, -1.9258591807823493, -1.9003828895040427, -1.874522601786685, -1.8482877479046986, -1.8216880789377785, -1.7947336848290567, -1.7674350145662807, -1.7398028987551122, -1.7118485748913381, -1.6835837156820985, -1.6550204608162464, -1.6261714526416189, -1.5970498762735639, -1.5676695047359535, -1.538044749824659, -1.508190719485942, -1.4781232826204131, -1.4478591423593956, -1.417415919017159, -1.3868122441021236, -1.3560678669754342, -1.325203775978697, -1.294242336116264, -1.2632074456722882, -1.2321247144684528, -1.201021666821588, -1.1699279726338903, -1.1388757104281957, -1.107899666502784, -1.0770376746861063, -1.046331001361975, -1.0158247804205023, -0.9855685024375732, -0.9556165615066127, -0.9260288614747682, -0.8968714805069076, -0.8682173884301418, -0.8401472045784946, -0.8127499741095585, -0.7861239271633046, -0.7603771669730068, -0.7356282095982857, -0.7120062695305268, -0.6896511536236288, -0.6687125945547623, -0.6493488315904554, -0.6317242421379895, -0.6160058573570131, -0.6023586749630505, -0.590939823420152, -0.5818918314172479, -0.5753354892630804, -0.5713630021406789, -0.5700322582137918, -0.5713630021406816, -0.5753354892630859, -0.5818918314172559, -0.5909398234201627, -0.6023586749630634, -0.6160058573570283, -0.6317242421380067, -0.6493488315904744, -0.668712594554783, -0.6896511536236511, -0.7120062695305505, -0.7356282095983104, -0.7603771669730328, -0.7861239271633315, -0.8127499741095864, -0.840147204578523, -0.868217388430171, -0.8968714805069373, -0.9260288614747983, -0.9556165615066432, -0.9855685024376041, -1.0158247804205334, -1.0463310013620066, -1.077037674686138, -1.1078996665028158, -1.1388757104282274, -1.1699279726339225, -1.20102166682162, -1.232124714468485, -1.26320744567232, -1.294242336116296, -1.3252037759787285, -1.3560678669754658, -1.3868122441021553, -1.41741591901719, -1.447859142359427, -1.4781232826204442, -1.508190719485973, -1.5380447498246896, -1.5676695047359839, -1.597049876273594, -1.6261714526416484, -1.655020460816276, -1.6835837156821276, -1.711848574891367, -1.7398028987551406, -1.7674350145663087, -1.794733684829085, -1.8216880789378058, -1.848287747904726, -1.8745226017867116, -1.900382889504069, -1.9258591807823755, -1.9509423499808851, -1.9756235615995157, -1.9998942572812046, -2.023746144148002, -2.0471711843281266, -2.070161585547682, -2.0927097926751426, -2.1148084801193643, -2.1364505449929436, -2.157629100962517, -2.17833747271613, -2.198569190985391, -2.2183179880667656, -2.2375777937922674, -2.2563427319050042, -2.2746071167996558, -2.292365450592063, -2.3096124204857253, -2.3263428964062602, -2.342551928877763, -2.3582347471175535, -2.373386757328124, -2.388003541167151, -2.402080854378257, -2.4156146255668918, -2.428600955107172, -2.4410361141668484, -2.4529165438388048, -2.4642388543685394, -2.474999824468109, -2.485196400707873, -2.4948256969782, -2.503884994014048, -2.512371738975974, -2.5202835450817673, -2.527618191283453, -2.534373621984935, -2.540547946796008, -2.5461394403189406, -2.551146541964205, -2.5555678557923267, -2.5594021503791975, -2.5626483587024897, -2.565305578047177, -2.5673730699284203, -2.568850260030392, -2.569736738159882], [-2.595308864276675, -2.595011511091673, -2.594119534815882, -2.5926331852948787, -2.5905528789645222, -2.5878791988912653, -2.584612894829535, -2.5807548832971157, -2.5763062476697822, -2.571268238296686, -2.5656422726383403, -2.5594299354293284, -2.5526329788682323, -2.545253322837602, -2.5372930551571846, -2.5287544318740243, -2.519639877593478, -2.509951985855662, -2.4996935195623413, -2.488867411459828, -2.477476764684045, -2.4655248533745557, -2.453015123365074, -2.4399511929587554, -2.426336853797397, -2.4121760718346383, -2.3974729884242927, -2.3822319215360506, -2.3664573671121047, -2.3501540005796238, -2.3333266785355655, -2.3159804406220523, -2.298120511612476, -2.2797523037306093, -2.2608814192274567, -2.2415136532432203, -2.2216549969847716, -2.2013116412524116, -2.1804899803534576, -2.159196616444459, -2.137438364348643, -2.115222256900571, -2.092555550876087, -2.069445733572518, -2.0459005301118802, -2.0219279115486675, -1.9975361038738002, -1.9727335980177012, -1.947529160968391, -1.921931848135218, -1.8959510171056388, -1.8695963429616327, -1.8428778353442108, -1.8158058574795857, -1.7883911474091883, -1.7606448416986593, -1.7325785019386166, -1.7042041443933136, -1.6755342732030054, -1.6465819176029766, -1.6173606736878057, -1.5878847513248613, -1.5581690269076136, -1.5282291027387218, -1.4980813739467012, -1.4677431039701798, -1.4372325097922243, -1.4065688582758629, -1.3757725751425653, -1.3448653683493514, -1.3138703678580734, -1.2828122840515734, -1.2517175873331081, -1.2206147117417006, -1.1895342857160895, -1.158509393425588, -1.1275758703288428, -1.0967726367775528, -1.0661420734867282, -1.0357304424519282, -1.0055883562729906, -0.9757712976564308, -0.9463401888605888, -0.9173620076815238, -0.8889104418211431, -0.8610665666022372, -0.8339195213909587, -0.8075671471342598, -0.7821165306165028, -0.7576843802492857, -0.7343971340546438, -0.7123906749323897, -0.6918095052874825, -0.6728052192849756, -0.6555341159829494, -0.6401538321062754, -0.6268189505952749, -0.6156756663764523, -0.6068557583043898, -0.600470302318191, -0.5966037229025488, -0.595308864276675, -0.5966037229025514, -0.6004703023181963, -0.6068557583043975, -0.6156756663764626, -0.6268189505952875, -0.6401538321062902, -0.6555341159829662, -0.6728052192849944, -0.6918095052875027, -0.7123906749324117, -0.7343971340546671, -0.7576843802493103, -0.7821165306165282, -0.8075671471342865, -0.8339195213909862, -0.8610665666022655, -0.888910441821172, -0.9173620076815534, -0.9463401888606188, -0.9757712976564611, -1.0055883562730215, -1.0357304424519593, -1.0661420734867595, -1.0967726367775843, -1.1275758703288743, -1.1585093934256196, -1.1895342857161215, -1.2206147117417323, -1.25171758733314, -1.2828122840516056, -1.3138703678581056, -1.3448653683493834, -1.375772575142597, -1.4065688582758944, -1.4372325097922558, -1.4677431039702111, -1.498081373946732, -1.5282291027387527, -1.5581690269076445, -1.587884751324892, -1.6173606736878359, -1.6465819176030063, -1.6755342732030352, -1.7042041443933431, -1.7325785019386455, -1.7606448416986877, -1.7883911474092165, -1.8158058574796134, -1.8428778353442385, -1.8695963429616596, -1.8959510171056657, -1.921931848135244, -1.9475291609684169, -1.972733598017727, -1.9975361038738253, -2.0219279115486923, -2.0459005301119046, -2.069445733572542, -2.0925555508761104, -2.1152222569005947, -2.137438364348666, -2.1591966164444814, -2.180489980353479, -2.201311641252433, -2.221654996984792, -2.2415136532432407, -2.260881419227477, -2.279752303730628, -2.2981205116124945, -2.3159804406220705, -2.333326678535583, -2.3501540005796415, -2.3664573671121216, -2.382231921536066, -2.3974729884243082, -2.4121760718346534, -2.426336853797411, -2.439951192958769, -2.453015123365087, -2.4655248533745677, -2.477476764684057, -2.488867411459839, -2.4996935195623524, -2.5099519858556727, -2.5196398775934883, -2.5287544318740336, -2.537293055157193, -2.54525332283761, -2.55263297886824, -2.559429935429335, -2.565642272638346, -2.5712682382966916, -2.5763062476697867, -2.5807548832971205, -2.584612894829539, -2.5878791988912684, -2.5905528789645245, -2.5926331852948805, -2.5941195348158828, -2.595011511091673], [-2.620009547460784, -2.619710437085586, -2.6188131904664824, -2.6173180611324107, -2.6152254716632934, -2.61253601373807, -2.609250448202936, -2.605369705160783, -2.6008948840831465, -2.595827253946261, -2.5901682533931565, -2.583919490924056, -2.5770827451176928, -2.5696599648865432, -2.5616532697693524, -2.5530649502647753, -2.5438974682103987, -2.5341534572118976, -2.523835723127621, -2.512947244614465, -2.5014911737415235, -2.4894708366786755, -2.4768897344680356, -2.463751543886976, -2.4500601184123565, -2.4358194892965517, -2.421033866766982, -2.405707641362017, -2.3898453854174666, -2.3734518547193395, -2.3565319903401596, -2.339090920677945, -2.3211339637189825, -2.302666629547713, -2.283694623129614, -2.264223847395684, -2.2442604066603016, -2.2238106104076847, -2.202880977486129, -2.1814782407535644, -2.159609352222938, -2.137281488761473, -2.114502058404146, -2.091278707348763, -2.0676193277080546, -2.043532066103194, -2.0190253331934285, -1.994107814248089, -1.9687884808804172, -1.9430766040776413, -1.9169817686787303, -1.890513889470665, -1.8636832290961458, -1.8365004179908908, -1.808976476597428, -1.7811228401352057, -1.752951386244396, -1.7244744658637976, -1.6957049377523863, -1.6666562071203432, -1.6373422688997186, -1.6077777562584203, -1.5779779950452009, -1.5479590649490367, -1.5177378682652485, -1.4873322072842632, -1.456760871458602, -1.4260437356606683, -1.3952018710192151, -1.3642576700163167, -1.3332349877385257, -1.3021593014034785, -1.2710578905216998, -1.23996004029444, -1.208897271078296, -1.177903596944786, -1.147015816495674, -1.1162738391153773, -1.0857210496820506, -1.0554047143229082, -1.025376428954036, -0.9956926109103215, -0.9664150317088019, -0.9376113855926866, -0.9093558835951673, -0.8817298559994922, -0.8548223367798037, -0.828730591451862, -0.8035605344885087, -0.779426964214625, -0.756453522796304, -0.7347722686944677, -0.714522732597071, -0.6958503213179472, -0.6789039454581123, -0.6638327848795629, -0.6507821791120075, -0.6398887404007706, -0.6312749279024634, -0.6250434714217471, -0.6212721573940321, -0.620009547460784, -0.6212721573940347, -0.6250434714217521, -0.6312749279024712, -0.6398887404007808, -0.6507821791120201, -0.6638327848795774, -0.6789039454581287, -0.6958503213179656, -0.7145227325970909, -0.7347722686944892, -0.756453522796327, -0.7794269642146493, -0.8035605344885342, -0.8287305914518882, -0.8548223367798309, -0.88172985599952, -0.909355883595196, -0.937611385592716, -0.9664150317088319, -0.9956926109103517, -1.0253764289540666, -1.0554047143229388, -1.085721049682082, -1.116273839115409, -1.1470158164957058, -1.177903596944818, -1.208897271078328, -1.2399600402944717, -1.2710578905217316, -1.3021593014035102, -1.3332349877385579, -1.3642576700163485, -1.3952018710192466, -1.4260437356606999, -1.4567608714586338, -1.4873322072842947, -1.5177378682652798, -1.5479590649490678, -1.5779779950452317, -1.6077777562584512, -1.6373422688997488, -1.6666562071203732, -1.6957049377524158, -1.7244744658638274, -1.752951386244425, -1.7811228401352341, -1.8089764765974565, -1.8365004179909186, -1.8636832290961736, -1.8905138894706925, -1.9169817686787574, -1.9430766040776677, -1.9687884808804432, -1.9941078142481148, -2.019025333193454, -2.043532066103218, -2.0676193277080785, -2.091278707348787, -2.114502058404169, -2.1372814887614964, -2.1596093522229607, -2.181478240753587, -2.2028809774861506, -2.2238106104077064, -2.2442604066603224, -2.2642238473957046, -2.283694623129634, -2.3026666295477325, -2.321133963719001, -2.3390909206779633, -2.3565319903401765, -2.373451854719357, -2.389845385417483, -2.405707641362033, -2.4210338667669977, -2.4358194892965663, -2.4500601184123707, -2.46375154388699, -2.476889734468049, -2.4894708366786884, -2.501491173741535, -2.5129472446144767, -2.5238357231276316, -2.534153457211908, -2.543897468210409, -2.5530649502647846, -2.5616532697693604, -2.5696599648865512, -2.5770827451177, -2.5839194909240626, -2.590168253393163, -2.595827253946267, -2.6008948840831514, -2.6053697051607876, -2.60925044820294, -2.6125360137380733, -2.6152254716632966, -2.6173180611324125, -2.6188131904664833, -2.619710437085587], [-2.6441104114504066, -2.643809618202594, -2.642907324170722, -2.64140378650046, -2.639299433804676, -2.636594866219067, -2.6332908554810994, -2.629388345033296, -2.6248884501522336, -2.61979245810495, -2.614101828334783, -2.6078181926790203, -2.6009433556211086, -2.5934792945805745, -2.5854281602442013, -2.5767922769424834, -2.567574143075824, -2.5577764315954887, -2.547401990544846, -2.5364538436670654, -2.5249351910860613, -2.512849410068213, -2.5002000558731345, -2.486990862702666, -2.47322574475813, -2.458908797416987, -2.444044298541096, -2.428636709930079, -2.412690678934625, -2.3962110402461305, -2.3792028178807243, -2.361671227377627, -2.3436216782338612, -2.3250597765996597, -2.305991328261478, -2.2864223419424285, -2.2663590329531496, -2.2458078272297355, -2.224775365799382, -2.203268509718927, -2.1812943455365392, -2.1588601913325287, -2.1359736034016477, -2.1126423836465253, -2.088874587760006, -2.0646785342834044, -2.040062814638087, -2.015036304239604, -1.9896081748169303, -1.9637879080745275, -1.9375853108521268, -1.9110105319566564, -1.884074080862923, -1.8567868485049217, -1.829160130408378, -1.8012056524478608, -1.772935599549101, -1.7443626476996297, -1.7154999996792557, -1.686361424977036, -1.6569613044241187, -1.6273146801431861, -1.5974373114961793, -1.5673457378037008, -1.5370573487130712, -1.5065904632085216, -1.4759644183874163, -1.4451996692713667, -1.414317901080781, -1.3833421555752237, -1.352296973248059, -1.3212085533584876, -1.290104933980862, -1.2590161944396059, -1.2279746826621518, -1.1970152700980765, -1.1661756368851814, -1.1354965898428782, -1.1050224155702295, -1.0748012703245151, -1.0448856073269717, -1.0153326405146312, -0.9862048413112727, -0.9575704614530354, -0.929504069950139, -0.9020870855342477, -0.8754082770735037, -0.8495641931575928, -0.8246594683025682, -0.8008069373635798, -0.7781274728549046, -0.7567494441200319, -0.7368076862626092, -0.71844186566252, -0.7017941443773256, -0.6870060847757167, -0.6742148036838882, -0.6635484826277284, -0.6551214595327159, -0.6490292488971532, -0.6453439337118627, -0.6441104114504065, -0.6453439337118652, -0.6490292488971582, -0.6551214595327234, -0.6635484826277382, -0.6742148036839004, -0.6870060847757309, -0.7017941443773417, -0.7184418656625381, -0.7368076862626287, -0.7567494441200531, -0.7781274728549272, -0.8008069373636038, -0.8246594683025931, -0.8495641931576189, -0.8754082770735305, -0.9020870855342754, -0.9295040699501675, -0.9575704614530645, -0.9862048413113024, -1.0153326405146612, -1.044885607327002, -1.0748012703245458, -1.1050224155702606, -1.1354965898429097, -1.166175636885213, -1.1970152700981083, -1.2279746826621836, -1.2590161944396379, -1.2901049339808943, -1.3212085533585196, -1.352296973248091, -1.3833421555752554, -1.414317901080813, -1.4451996692713984, -1.4759644183874479, -1.5065904632085527, -1.5370573487131025, -1.5673457378037314, -1.5974373114962097, -1.6273146801432163, -1.656961304424149, -1.6863614249770662, -1.7154999996792855, -1.7443626476996588, -1.7729355995491303, -1.8012056524478897, -1.829160130408407, -1.85678684850495, -1.884074080862951, -1.9110105319566837, -1.937585310852154, -1.9637879080745542, -1.9896081748169567, -2.01503630423963, -2.040062814638113, -2.0646785342834293, -2.088874587760031, -2.1126423836465493, -2.1359736034016716, -2.1588601913325522, -2.181294345536562, -2.203268509718949, -2.2247753657994043, -2.245807827229757, -2.2663590329531704, -2.2864223419424485, -2.3059913282614977, -2.325059776599679, -2.34362167823388, -2.3616712273776446, -2.379202817880742, -2.396211040246148, -2.4126906789346414, -2.428636709930095, -2.444044298541112, -2.4589087974170023, -2.473225744758145, -2.48699086270268, -2.500200055873148, -2.5128494100682253, -2.524935191086074, -2.5364538436670765, -2.547401990544857, -2.557776431595499, -2.567574143075834, -2.5767922769424922, -2.5854281602442097, -2.5934792945805825, -2.6009433556211166, -2.607818192679027, -2.6141018283347894, -2.6197924581049556, -2.6248884501522385, -2.6293883450333, -2.6332908554811034, -2.6365948662190704, -2.6392994338046782, -2.6414037865004616, -2.642907324170723, -2.643809618202595], [-2.667588140216162, -2.6672857368485547, -2.6663786136378094, -2.664867031272626, -2.6627514242758767, -2.66003240106771, -2.65671074405499, -2.6527874097481696, -2.6482635289070213, -2.643140406717019, -2.63741952299846, -2.631102532450843, -2.624191264935373, -2.6166877257988816, -2.608594096242887, -2.5999127337419834, -2.590646172516252, -2.5807971240629097, -2.570368477753002, -2.5593633014995727, -2.547784842504403, -2.5356365280911977, -2.522921966633839, -2.509644948589291, -2.495809447645631, -2.48141962199681, -2.466479815756877, -2.450994560527712, -2.4349685771357414, -2.418406777554666, -2.401314267032999, -2.3836963464471452, -2.365558514902885, -2.3469064726105415, -2.3277461240617443, -2.3080835815387015, -2.287925168990165, -2.2672774263120083, -2.246147114074446, -2.224541218742574, -2.202466958442109, -2.179931789328013, -2.156943412620291, -2.133509782378559, -2.10963911409535, -2.085339894197437, -2.0606208905550343, -2.035491164110673, -2.009960081753017, -1.9840373305761645, -1.9577329336822402, -1.9310572677046822, -1.9040210822518095, -1.8766355214954635, -1.848912148158079, -1.8208629701840067, -1.7925004704177252, -1.763837639653415, -1.7348880134677684, -1.705665713301724, -1.6761854923176942, -1.6464627866277184, -1.6165137725656553, -1.5863554307639207, -1.5560056178931816, -1.5254831470325958, -1.494807877759088, -1.4640008171769152, -1.4330842332528457, -1.4020817819762184, -1.3710186500240198, -1.3399217147740112, -1.3088197236658732, -1.2777434950492594, -1.2467261427606005, -1.2158033267116366, -1.1850135317152997, -1.154398376567626, -1.1240029549780628, -1.0938762092008423, -1.0640713360432101, -1.0346462231526183, -1.0056639109147627, -0.977193071686902, -0.9493084931716274, -0.9220915462176549, -0.8956306089596645, -0.8700214088319494, -0.8453672317003136, -0.8217789336652918, -0.799374677175816, -0.7782793010775473, -0.7586232274053906, -0.740540810651319, -0.7241680533279444, -0.7096396502464939, -0.6970853864837099, -0.686625999577632, -0.678368717155658, -0.6724027807156268, -0.6687953414785864, -0.6675881402161622, -0.668795341478589, -0.6724027807156318, -0.6783687171556656, -0.6866259995776417, -0.6970853864837216, -0.7096396502465077, -0.7241680533279602, -0.7405408106513367, -0.75862322740541, -0.7782793010775682, -0.7993746771758383, -0.8217789336653154, -0.8453672317003383, -0.8700214088319751, -0.8956306089596913, -0.9220915462176824, -0.9493084931716559, -0.9771930716869309, -1.0056639109147922, -1.0346462231526483, -1.0640713360432406, -1.0938762092008731, -1.1240029549780939, -1.1543983765676573, -1.185013531715331, -1.2158033267116684, -1.2467261427606322, -1.2777434950492914, -1.308819723665905, -1.3399217147740428, -1.371018650024052, -1.40208178197625, -1.4330842332528775, -1.4640008171769472, -1.49480787775912, -1.5254831470326276, -1.5560056178932131, -1.5863554307639518, -1.6165137725656864, -1.6464627866277497, -1.6761854923177248, -1.7056657133017539, -1.7348880134677982, -1.7638376396534448, -1.7925004704177547, -1.8208629701840353, -1.8489121481581077, -1.8766355214954917, -1.9040210822518377, -1.93105726770471, -1.9577329336822673, -1.9840373305761911, -2.009960081753043, -2.0354911641106983, -2.0606208905550596, -2.085339894197462, -2.109639114095375, -2.1335097823785834, -2.156943412620315, -2.1799317893280366, -2.2024669584421317, -2.224541218742597, -2.2461471140744678, -2.26727742631203, -2.2879251689901863, -2.308083581538722, -2.3277461240617647, -2.346906472610561, -2.365558514902904, -2.383696346447163, -2.4013142670330163, -2.418406777554683, -2.4349685771357588, -2.450994560527728, -2.4664798157568923, -2.4814196219968254, -2.495809447645646, -2.5096449485893046, -2.5229219666338523, -2.53563652809121, -2.547784842504416, -2.5593633014995842, -2.570368477753013, -2.5807971240629195, -2.5906461725162617, -2.599912733741993, -2.6085940962428955, -2.6166877257988896, -2.6241912649353805, -2.6311025324508495, -2.6374195229984663, -2.643140406717025, -2.648263528907027, -2.6527874097481736, -2.656710744054994, -2.660032401067713, -2.662751424275879, -2.6648670312726273, -2.6663786136378107, -2.6672857368485547], [-2.6904200205717554, -2.6901160783314664, -2.689204339656411, -2.6876850686979488, -2.6855587057549006, -2.682825867343961, -2.6794873462994064, -2.675544111903253, -2.6709973100473654, -2.665848263429347, -2.660098471784443, -2.6537496121560316, -2.6468035392077356, -2.639262285580561, -2.631128062298944, -2.6224032592301, -2.6130904456015203, -2.603192370582098, -2.5927119639328935, -2.581652336734252, -2.5700167821966664, -2.557808776563556, -2.545031980114961, -2.5316902382820787, -2.5177875828835683, -2.503328233495653, -2.488316598969249, -2.4727572791087082, -2.456655066528211, -2.440014948703482, -2.4228421102383084, -2.4051419353673107, -2.3869200107186574, -2.368182128362851, -2.348934289176448, -2.3291827065526256, -2.308933810493901, -2.288194252126071, -2.266970908676715, -2.2452708889662842, -2.2231015394651408, -2.2004704509758293, -2.177385466006527, -2.153854686909117, -2.1298864848637415, -2.105489509801158, -2.0806727013649007, -2.0554453010272726, -2.0298168654867705, -2.003797281489855, -1.9773967822373035, -1.9506259655549372, -1.9234958140306515, -1.8960177173447075, -1.8682034970485624, -1.8400654340795766, -1.811616299335169, -1.7828693876709947, -1.7538385557340228, -1.7245382640936426, -1.6949836241928133, -1.6651904507074546, -1.6351753199764631, -1.604955635247606, -1.5745496995766084, -1.5439767973184355, -1.5132572852610897, -1.4824126945728424, -1.4514658448624882, -1.4204409717867281, -1.389363869775362, -1.358262051577516, -1.3271649264515422, -1.296103998913998, -1.265113090009934, -1.2342285830403121, -1.2034896955450518, -1.1729387790404526, -1.1426216474786495, -1.1125879345434728, -1.0828914786044057, -1.053590732270879, -1.024749190843386, -0.9964358303367237, -0.968725540926198, -0.9416995354175602, -0.9154457044953312, -0.8900588810200176, -0.8656409647259535, -0.842300846928821, -0.8201540635035117, -0.7993220954719585, -0.7799312330393903, -0.7621109247474102, -0.7459915530081082, -0.7317016146770365, -0.7193643426037595, -0.7090938794290086, -0.700991200656415, -0.6951400660821866, -0.6916033379055933, -0.6904200205717552, -0.6916033379055957, -0.6951400660821914, -0.7009912006564223, -0.709093879429018, -0.7193643426037712, -0.7317016146770501, -0.7459915530081238, -0.7621109247474276, -0.7799312330394094, -0.7993220954719791, -0.820154063503534, -0.8423008469288444, -0.8656409647259781, -0.8900588810200432, -0.9154457044953577, -0.9416995354175876, -0.9687255409262262, -0.9964358303367525, -1.0247491908434154, -1.0535907322709088, -1.082891478604436, -1.1125879345435037, -1.1426216474786806, -1.172938779040484, -1.2034896955450833, -1.2342285830403439, -1.2651130900099659, -1.29610399891403, -1.327164926451574, -1.3582620515775479, -1.389363869775394, -1.4204409717867599, -1.45146584486252, -1.4824126945728742, -1.5132572852611212, -1.5439767973184668, -1.5745496995766397, -1.6049556352476368, -1.6351753199764945, -1.6651904507074855, -1.694983624192844, -1.7245382640936726, -1.753838555734053, -1.7828693876710247, -1.811616299335198, -1.8400654340796057, -1.868203497048591, -1.8960177173447357, -1.92349581403068, -1.9506259655549647, -1.9773967822373306, -2.003797281489882, -2.0298168654867967, -2.055445301027299, -2.0806727013649264, -2.1054895098011834, -2.1298864848637664, -2.153854686909141, -2.177385466006551, -2.200470450975853, -2.223101539465164, -2.2452708889663064, -2.266970908676737, -2.2881942521260923, -2.308933810493922, -2.3291827065526465, -2.3489342891764675, -2.368182128362871, -2.386920010718677, -2.405141935367329, -2.4228421102383266, -2.4400149487035, -2.456655066528228, -2.472757279108725, -2.488316598969265, -2.503328233495669, -2.517787582883583, -2.5316902382820925, -2.5450319801149752, -2.557808776563569, -2.570016782196679, -2.581652336734263, -2.5927119639329046, -2.6031923705821085, -2.6130904456015305, -2.622403259230109, -2.631128062298953, -2.639262285580569, -2.646803539207743, -2.653749612156038, -2.6600984717844494, -2.665848263429353, -2.6709973100473703, -2.6755441119032572, -2.6794873462994104, -2.6828258673439644, -2.6855587057549037, -2.687685068697951, -2.689204339656413, -2.690116078331467], [-2.712583964147515, -2.7122785528353126, -2.7113624080693883, -2.7098357973771328, -2.7076991666888173, -2.704953140415128, -2.701598521556883, -2.6976362918481525, -2.6930676119343073, -2.687893821586945, -2.6821164399579693, -2.675737165875537, -2.6687578781849943, -2.661180636138355, -2.653007679836369, -2.6442414307277065, -2.6348844921703383, -2.6249396500607554, -2.614409873537307, -2.6032983157646, -2.5916083148066336, -2.5793433945971462, -2.5665072660165014, -2.553103828085402, -2.5391371692867533, -2.524611569028112, -2.5095314992584474, -2.493901626254272, -2.4777268125917398, -2.4610121193229757, -2.443762808376742, -2.4259843452056, -2.407682401704003, -2.3888628594242403, -2.369531813119992, -2.349695574650329, -2.329360677280479, -2.3085338804195294, -2.2872221748395627, -2.265432788425507, -2.243173192510413, -2.220451108856857, -2.197274517351954, -2.173651664491022, -2.149591072733464, -2.125101550823975, -2.100192205182928, -2.0748724524819013, -2.049152033533887, -2.0230410286431004, -1.9965498745765538, -1.969689383339091, -1.9424707629555322, -1.914905640488407, -1.8870060875477117, -1.8587846485806938, -1.8302543722652107, -1.8014288463702852, -1.7723222364925042, -1.7429493291275338, -1.7133255795927218, -1.6834671653801343, -1.6533910455899459, -1.6231150271723085, -1.5926578387919776, -1.562039213224116, -1.5312799792915224, -1.5004021644621384, -1.4694291093393483, -1.438385595393403, -1.4072979873956142, -1.3761943921208992, -1.3451048349685704, -1.3140614562014854, -1.2830987284993671, -1.2522536974351668, -1.2215662462755805, -1.1910793861270756, -1.1608395718298299, -1.1308970430569287, -1.1013061886952562, -1.0721259306329283, -1.043420120396191, -1.0152579384870861, -0.9877142815861916, -0.9608701168371648, -0.9348127751231802, -0.9096361466210859, -0.8854407322642617, -0.862333494731557, -0.8404274434255248, -0.8198408815237308, -0.8006962422699059, -0.7831184495725202, -0.7672327583036139, -0.7531620654494517, -0.7410237355636886, -0.730926050447727, -0.7229644664600547, -0.7172179310492722, -0.7137455571420509, -0.7125839641475152, -0.7137455571420531, -0.717217931049277, -0.7229644664600617, -0.7309260504477363, -0.7410237355637002, -0.7531620654494652, -0.7672327583036292, -0.7831184495725375, -0.8006962422699248, -0.8198408815237513, -0.8404274434255468, -0.8623334947315803, -0.8854407322642861, -0.9096361466211113, -0.9348127751232065, -0.9608701168371921, -0.9877142815862195, -1.0152579384871148, -1.0434201203962203, -1.072125930632958, -1.1013061886952864, -1.1308970430569594, -1.1608395718298608, -1.191079386127107, -1.2215662462756118, -1.2522536974351983, -1.2830987284993989, -1.3140614562015174, -1.3451048349686021, -1.3761943921209312, -1.4072979873956464, -1.4383855953934348, -1.46942910933938, -1.5004021644621701, -1.5312799792915543, -1.5620392132241476, -1.592657838792009, -1.6231150271723398, -1.6533910455899772, -1.6834671653801656, -1.7133255795927522, -1.742949329127564, -1.7723222364925342, -1.8014288463703152, -1.8302543722652402, -1.8587846485807227, -1.8870060875477408, -1.9149056404884355, -1.9424707629555602, -1.9696893833391187, -1.9965498745765813, -2.0230410286431275, -2.0491520335339137, -2.074872452481927, -2.1001922051829536, -2.1251015508239997, -2.149591072733489, -2.173651664491046, -2.197274517351978, -2.2204511088568806, -2.243173192510436, -2.2654327884255303, -2.287222174839585, -2.3085338804195517, -2.3293606772805004, -2.34969557465035, -2.3695318131200125, -2.38886285942426, -2.407682401704022, -2.4259843452056185, -2.4437628083767597, -2.461012119322994, -2.477726812591757, -2.493901626254288, -2.509531499258463, -2.5246115690281266, -2.539137169286768, -2.5531038280854164, -2.5665072660165142, -2.579343394597159, -2.591608314806646, -2.603298315764611, -2.6144098735373182, -2.6249396500607656, -2.634884492170348, -2.6442414307277162, -2.6530076798363775, -2.661180636138363, -2.668757878185002, -2.675737165875544, -2.6821164399579756, -2.687893821586951, -2.693067611934312, -2.6976362918481573, -2.7015985215568876, -2.7049531404151312, -2.7076991666888195, -2.709835797377134, -2.7113624080693897, -2.712278552835313], [-2.7340585287594683, -2.733751716789256, -2.7328313711433596, -2.7312977626327033, -2.729151342664725, -2.7263927433278123, -2.7230227775107645, -2.7190424390584873, -2.714452902965549, -2.709255525609578, -2.703451845026894, -2.697043581233163, -2.6900326365923175, -2.6824210962374297, -2.6742112285477218, -2.665405485686401, -2.6560065042045804, -2.646017105717128, -2.6354402976569475, -2.6242792741148535, -2.6125374167730024, -2.6002182959406275, -2.587325671701719, -2.5738634951852895, -2.5598359099698915, -2.5452472536352677, -2.530102059475248, -2.514405058387456, -2.498161180956926, -2.4813755597524425, -2.464053531856312, -2.446200641650373, -2.4278226438833554, -2.4089255070473015, -2.389515417093568, -2.3695987815221433, -2.3491822338815247, -2.328272638720321, -2.3068770970361383, -2.2850029522721913, -2.262657796917544, -2.239849479772967, -2.216586113951273, -2.192876085688575, -2.1687280640515523, -2.1441510116353637, -2.1191541963576843, -2.0937472044664247, -2.0679399548923376, -2.0417427150930085, -2.0151661185519467, -1.9882211841158741, -1.9609193373750684, -1.933272434316158, -1.9052927875042935, -1.876993195082621, -1.848386972911759, -1.8194879902109977, -1.7903107091066628, -1.7608702285419118, -1.7311823330566942, -1.7012635470070765, -1.6711311948600025, -1.6408034682730814, -1.6102995007492136, -1.5796394507425617, -1.5488445941848488, -1.5179374274979212, -1.4869417822577164, -1.4558829527726767, -1.424787837931024, -1.3936850987483829, -1.3626053330991004, -1.33158126912583, -1.3006479787715182, -1.269843112737149, -1.2392071578993527, -1.2087837177739797, -1.1786198159200594, -1.148766221160822, -1.119277792052754, -1.090213836037645, -1.0616384760256627, -1.0336210136276904, -1.006236273734568, -0.9795649095133225, -0.9536936401170545, -0.9287153855924658, -0.9047292549637526, -0.8818403349785432, -0.8601592197121867, -0.8398012169243184, -0.8208851681452504, -0.8035318288087878, -0.7878617752662991, -0.7739928394271197, -0.7620371194740723, -0.7520976739481566, -0.7442650698269309, -0.7386140123377072, -0.7352003218706407, -0.7340585287594683, -0.7352003218706431, -0.738614012337712, -0.7442650698269379, -0.7520976739481658, -0.7620371194740835, -0.7739928394271329, -0.7878617752663142, -0.8035318288088047, -0.820885168145269, -0.8398012169243386, -0.8601592197122082, -0.881840334978566, -0.9047292549637769, -0.9287153855924908, -0.9536936401170804, -0.9795649095133495, -1.0062362737345956, -1.033621013627719, -1.0616384760256918, -1.0902138360376745, -1.119277792052784, -1.1487662211608527, -1.1786198159200902, -1.208783717774011, -1.239207157899384, -1.2698431127371805, -1.30064797877155, -1.3315812691258617, -1.3626053330991323, -1.3936850987484146, -1.4247878379310557, -1.455882952772709, -1.4869417822577484, -1.5179374274979531, -1.5488445941848805, -1.5796394507425935, -1.610299500749245, -1.6408034682731127, -1.6711311948600336, -1.7012635470071076, -1.7311823330567246, -1.7608702285419424, -1.7903107091066928, -1.8194879902110275, -1.8483869729117883, -1.8769931950826504, -1.9052927875043224, -1.9332724343161862, -1.9609193373750966, -1.988221184115902, -2.0151661185519743, -2.0417427150930356, -2.0679399548923643, -2.093747204466451, -2.11915419635771, -2.144151011635389, -2.168728064051577, -2.1928760856886, -2.216586113951297, -2.2398494797729906, -2.262657796917567, -2.2850029522722144, -2.30687709703616, -2.3282726387203425, -2.3491822338815456, -2.3695987815221633, -2.389515417093588, -2.4089255070473214, -2.4278226438833754, -2.4462006416503916, -2.464053531856331, -2.4813755597524607, -2.4981611809569437, -2.514405058387472, -2.5301020594752637, -2.5452472536352833, -2.5598359099699057, -2.573863495185303, -2.5873256717017328, -2.600218295940641, -2.612537416773015, -2.6242792741148646, -2.6354402976569586, -2.6460171057171387, -2.6560065042045897, -2.6654054856864104, -2.6742112285477306, -2.682421096237438, -2.6900326365923246, -2.6970435812331703, -2.7034518450269003, -2.709255525609584, -2.714452902965554, -2.7190424390584913, -2.723022777510768, -2.7263927433278154, -2.729151342664727, -2.731297762632705, -2.732831371143361, -2.7337517167892575], [-2.7548229391532653, -2.754514793611544, -2.7535904483125244, -2.752050177252688, -2.7498944371531833, -2.7471238675509713, -2.7437392909277083, -2.739741712877633, -2.7351323223161295, -2.72991249173102, -2.7240837774790516, -2.7176479201304713, -2.7106068448650293, -2.702962661923226, -2.6947176671171085, -2.685874342405494, -2.6764353565390016, -2.6664035657809695, -2.6557820147109354, -2.6445739371180843, -2.6327827569928743, -2.620412089625853, -2.607465742823609, -2.593947718252807, -2.579862212924343, -2.56521362083085, -2.5500065347521037, -2.534245748244325, -2.517936257830945, -2.501083265414188, -2.4836921809287142, -2.4657686252607434, -2.447318433458415, -2.4283476582617816, -2.4088625739837073, -2.3888696807762115, -2.368375709320337, -2.347387625981633, -2.3259126384777806, -2.3039582021098277, -2.281532026614027, -2.2586420836974317, -2.235296615327289, -2.2115041428519517, -2.1872734770397027, -2.1626137291314516, -2.137534323014149, -2.1120450086338374, -2.0861558767808632, -2.059877375395022, -2.0332203275555094, -2.006195951339753, -1.9788158817567307, -1.9510921949845474, -1.9230374351691246, -1.8946646440711865, -1.8659873938826885, -1.8370198235717548, -1.8077766791574688, -1.778273358362915, -1.7485259601469674, -1.7185513396728789, -1.6883671693348596, -1.6579920065326863, -1.627445368958745, -1.5967478182412984, -1.565921052871159, -1.5349880114246977, -1.5039729871814456, -1.4729017553155426, -1.4418017139110029, -1.4107020401029162, -1.3796338626686668, -1.3486304523690917, -1.317727431247649, -1.2869630019074103, -1.2563781974631876, -1.2260171523604717, -1.1959273935018069, -1.166160150047281, -1.1367706787649143, -1.107818599788781, -1.0793682349748546, -1.0514889375998693, -1.024255397812239, -0.9977479029418862, -0.972052525517443, -0.9472612047814005, -0.9234716800237547, -0.9007872268898107, -0.8793161421056205, -0.8591709194522656, -0.8404670624408342, -0.8233214894429569, -0.8078505073807455, -0.7941673620695527, -0.7823794168360968, -0.7725850633237592, -0.764870523317802, -0.7593067486326163, -0.7559466564064954, -0.754822939153265, -0.7559466564064977, -0.7593067486326209, -0.7648705233178089, -0.7725850633237682, -0.7823794168361079, -0.7941673620695658, -0.8078505073807605, -0.8233214894429736, -0.8404670624408528, -0.8591709194522855, -0.8793161421056419, -0.9007872268898334, -0.9234716800237786, -0.9472612047814254, -0.972052525517469, -0.9977479029419131, -1.0242553978122666, -1.0514889375998975, -1.0793682349748834, -1.1078185997888106, -1.1367706787649443, -1.1661601500473116, -1.1959273935018377, -1.2260171523605028, -1.2563781974632189, -1.2869630019074418, -1.3177274312476808, -1.3486304523691237, -1.3796338626686988, -1.410702040102948, -1.4418017139110348, -1.4729017553155745, -1.5039729871814775, -1.5349880114247298, -1.5659210528711907, -1.5967478182413302, -1.627445368958777, -1.6579920065327174, -1.6883671693348905, -1.71855133967291, -1.748525960146998, -1.7782733583629453, -1.8077766791574994, -1.8370198235717845, -1.8659873938827183, -1.8946646440712156, -1.9230374351691537, -1.951092194984576, -1.9788158817567592, -2.006195951339781, -2.033220327555537, -2.0598773753950494, -2.08615587678089, -2.1120450086338636, -2.137534323014175, -2.162613729131477, -2.187273477039728, -2.211504142851976, -2.2352966153273126, -2.258642083697456, -2.28153202661405, -2.3039582021098504, -2.3259126384778033, -2.3473876259816553, -2.3683757093203583, -2.3888696807762324, -2.408862573983727, -2.4283476582618015, -2.4473184334584355, -2.4657686252607616, -2.4836921809287325, -2.5010832654142052, -2.517936257830962, -2.5342457482443415, -2.55000653475212, -2.5652136208308653, -2.579862212924358, -2.593947718252821, -2.607465742823623, -2.620412089625866, -2.6327827569928868, -2.644573937118096, -2.6557820147109465, -2.6664035657809806, -2.676435356539011, -2.685874342405503, -2.6947176671171174, -2.7029626619232334, -2.710606844865037, -2.7176479201304784, -2.724083777479058, -2.7299124917310253, -2.7351323223161352, -2.739741712877638, -2.7437392909277127, -2.747123867550975, -2.749894437153186, -2.75205017725269, -2.753590448312526, -2.7545147936115444], [-2.7748571071028976, -2.774547693808068, -2.773619546276774, -2.772072941587942, -2.769908341604422, -2.767126393070619, -2.763727927750464, -2.7597139626070786, -2.755085700025818, -2.749844528082842, -2.743992020861727, -2.737529938821121, -2.7304602292168716, -2.722785026582562, -2.7145066532729034, -2.7056276200749716, -2.6961506268928774, -2.6860785635120856, -2.6754145104502727, -2.664161739902354, -2.6523237167880978, -2.639904099911612, -2.6269067432429285, -2.6133356973329263, -2.599195210873955, -2.584489732419762, -2.5692239122796288, -2.5534026046031495, -2.5370308696736577, -2.5201139764301277, -2.502657405239328, -2.484666850942183, -2.466148226200722, -2.4471076651746193, -2.4275515275593147, -2.407486403020966, -2.38691911606709, -2.36585673139583, -2.344306559771231, -2.32227616447694, -2.2997733684062807, -2.2768062618528986, -2.253383211073059, -2.2295128676984506, -2.2052041790869716, -2.180466399708644, -2.1553091036746035, -2.1297421985292186, -2.103775940438909, -2.0774209509264034, -2.050688235316125, -2.023589203075395, -1.9961356902573815, -1.9683399842754956, -1.9402148512654998, -1.9117735663212454, -1.8830299469230172, -1.85399838991425, -1.8246939124232067, -1.7951321971713803, -1.7653296426601768, -1.7353034187820027, -1.7050715284613578, -1.6746528759957546, -1.6440673428349335, -1.613335871609127, -1.582480559291789, -1.5515247604571836, -1.520493201665469, -1.489412108072952, -1.4583093434166636, -1.4272145645515408, -1.3961593917131447, -1.3651775956227141, -1.3343053024226292, -1.303581217200466, -1.2730468664916144, -1.2427468595965907, -1.2127291677504606, -1.1830454190656114, -1.1537512056492778, -1.124906397275201, -1.0965754533582093, -1.0688277216368545, -1.0417377078267613, -1.0153852955269982, -0.9898558898924389, -0.965240452221336, -0.9416353860625185, -0.9191422294358271, -0.8978671033762968, -0.8779198657704981, -0.8594129232447981, -0.8424596647796068, -0.8271725006664928, -0.8136605205117472, -0.8020268237654599, -0.7923656229150573, -0.784759267408359, -0.7792753773723049, -0.7759643007585225, -0.7748571071028976, -0.7759643007585247, -0.7792753773723096, -0.7847592674083657, -0.7923656229150663, -0.8020268237654709, -0.8136605205117602, -0.8271725006665076, -0.8424596647796234, -0.8594129232448162, -0.877919865770518, -0.8978671033763183, -0.9191422294358497, -0.9416353860625419, -0.9652404522213608, -0.9898558898924645, -1.0153852955270248, -1.0417377078267887, -1.0688277216368827, -1.0965754533582381, -1.1249063972752302, -1.1537512056493078, -1.1830454190656416, -1.2127291677504914, -1.2427468595966218, -1.2730468664916457, -1.3035812172004977, -1.3343053024226608, -1.3651775956227459, -1.3961593917131767, -1.4272145645515726, -1.458309343416696, -1.4894121080729843, -1.5204932016655008, -1.5515247604572153, -1.582480559291821, -1.6133358716091586, -1.644067342834965, -1.674652875995786, -1.7050715284613889, -1.7353034187820338, -1.7653296426602076, -1.795132197171411, -1.8246939124232369, -1.8539983899142802, -1.883029946923047, -1.9117735663212747, -1.9402148512655288, -1.968339984275524, -1.99613569025741, -2.023589203075423, -2.0506882353161524, -2.077420950926431, -2.1037759404389362, -2.1297421985292453, -2.1553091036746297, -2.1804663997086693, -2.205204179086997, -2.2295128676984755, -2.2533832110730834, -2.2768062618529226, -2.299773368406304, -2.3222761644769627, -2.3443065597712542, -2.3658567313958527, -2.386919116067112, -2.407486403020987, -2.427551527559335, -2.447107665174639, -2.4661482262007417, -2.484666850942202, -2.5026574052393458, -2.5201139764301455, -2.537030869673674, -2.553402604603166, -2.569223912279645, -2.5844897324197778, -2.59919521087397, -2.6133356973329405, -2.6269067432429423, -2.639904099911625, -2.6523237167881097, -2.664161739902366, -2.6754145104502842, -2.6860785635120963, -2.6961506268928876, -2.705627620074981, -2.7145066532729123, -2.72278502658257, -2.730460229216879, -2.7375299388211283, -2.7439920208617337, -2.7498445280828476, -2.755085700025823, -2.7597139626070826, -2.7637279277504683, -2.767126393070622, -2.7699083416044243, -2.7720729415879433, -2.773619546276776, -2.774547693808069], [-2.794141650844761, -2.7938310344061787, -2.792899278434728, -2.7913466629838823, -2.789173654878216, -2.7863809078172546, -2.7829692625222164, -2.7789397469269934, -2.7742935764151424, -2.769032154105068, -2.7631570711860025, -2.756670107307857, -2.749573231028471, -2.7418686003223125, -2.7335585631551873, -2.7246456581300977, -2.7151326152099746, -2.705022356523686, -2.6943179972623748, -2.683022846673976, -2.6711404091645403, -2.658674385515898, -2.645628674230136, -2.63200737301243, -2.61781478040489, -2.603055397585341, -2.5877339303463347, -2.571855291271175, -2.555424602125404, -2.538447196484009, -2.5209286226166077, -2.502874646655089, -2.484291256070631, -2.4651846634896932, -2.4455613108815966, -2.425427874153606, -2.404791268193098, -2.3836586524004706, -2.3620374367610077, -2.3399352885089058, -2.3173601394423167, -2.294320193954477, -2.2708239378529638, -2.246880148046861, -2.222497903190297, -2.1976865953804405, -2.1724559430188615, -2.146816004957181, -2.1207771960614057, -2.0943503043443776, -2.067546509832547, -2.0403774053520407, -2.012855019439921, -1.9849918416098828, -1.9568008502276266, -1.9282955432801012, -1.8994899723549474, -1.870398780182078, -1.8410372421286834, -1.8114213120822644, -1.781567673203733, -1.751493794084284, -1.7212179908955805, -1.6907594961825183, -1.6601385350109332, -1.6293764092480623, -1.5984955908198795, -1.5675198248542077, -1.5364742436783922, -1.5053854926904555, -1.4742818691563175, -1.4431934749936397, -1.4121523845726975, -1.3811928284798263, -1.3503513940276235, -1.319667243029923, -1.2891823469524046, -1.2589417389560116, -1.2289937815140064, -1.1993904471368726, -1.1701876082037261, -1.141445329886712, -1.1132281575747933, -1.0856053869707731, -1.058651301089714, -1.0324453537185128, -1.0070722735855213, -0.9826220577581447, -0.959189817063583, -0.9368754313160116, -0.9157829688671861, -0.8960198248625433, -0.8776955372588838, -0.8609202509254809, -0.8458028195396691, -0.8324485632448813, -0.8209567364626542, -0.8114178020756133, -0.8039106502843892, -0.7984999355733866, -0.7952337252536711, -0.7941416508447611, -0.7952337252536734, -0.7984999355733913, -0.8039106502843958, -0.8114178020756221, -0.8209567364626651, -0.832448563244894, -0.8458028195396836, -0.8609202509254974, -0.877695537258902, -0.8960198248625628, -0.915782968867207, -0.936875431316034, -0.9591898170636064, -0.9826220577581692, -1.0070722735855469, -1.0324453537185392, -1.0586513010897414, -1.0856053869708011, -1.113228157574822, -1.1414453298867413, -1.170187608203756, -1.1993904471369028, -1.228993781514037, -1.2589417389560424, -1.2891823469524357, -1.3196672430299545, -1.350351394027655, -1.381192828479858, -1.4121523845727293, -1.4431934749936717, -1.4742818691563497, -1.5053854926904875, -1.536474243678424, -1.56751982485424, -1.5984955908199112, -1.629376409248094, -1.660138535010965, -1.69075949618255, -1.721217990895612, -1.7514937940843156, -1.781567673203764, -1.811421312082295, -1.8410372421287138, -1.8703987801821085, -1.8994899723549776, -1.9282955432801305, -1.9568008502276557, -1.984991841609912, -2.0128550194399493, -2.0403774053520687, -2.0675465098325745, -2.094350304344405, -2.1207771960614323, -2.1468160049572074, -2.1724559430188877, -2.197686595380466, -2.222497903190322, -2.2468801480468863, -2.2708239378529878, -2.294320193954501, -2.31736013944234, -2.339935288508929, -2.36203743676103, -2.383658652400493, -2.4047912681931196, -2.4254278741536277, -2.445561310881617, -2.4651846634897128, -2.4842912560706507, -2.5028746466551075, -2.5209286226166254, -2.5384471964840274, -2.555424602125422, -2.5718552912711914, -2.587733930346351, -2.603055397585357, -2.6178147804049057, -2.6320073730124447, -2.645628674230149, -2.6586743855159107, -2.671140409164553, -2.683022846673988, -2.6943179972623863, -2.705022356523697, -2.715132615209985, -2.724645658130107, -2.733558563155196, -2.741868600322321, -2.7495732310284784, -2.7566701073078637, -2.763157071186009, -2.7690321541050738, -2.7742935764151473, -2.778939746926998, -2.782969262522221, -2.7863809078172577, -2.789173654878218, -2.791346662983884, -2.7928992784347293, -2.7938310344061787], [-2.8126579138282577, -2.8123461577049422, -2.8114109836329657, -2.809852674528005, -2.8076717019889466, -2.804868726407715, -2.8014445971244144, -2.7974003526291744, -2.7927372208125156, -2.7874566192664663, -2.7815601556391116, -2.7750496280457235, -2.7679270255400947, -2.7601945286502225, -2.7518545099830316, -2.742909534903382, -2.733362362293263, -2.7232159453976936, -2.7124734327645954, -2.701138169286642, -2.689213697353947, -2.6767037581273283, -2.663612292942884, -2.649943444859667, -2.6357015603634126, -2.6208911912405637, -2.605517096638187, -2.5895842453269595, -2.5730978181860236, -2.556063210930414, -2.5384860371037337, -2.5203721313610434, -2.5017275530693786, -2.482558590256045, -2.4628717639378714, -2.442673832867934, -2.421971798739987, -2.400772911894942, -2.3790846775782826, -2.3569148628024124, -2.3342715038735165, -2.3111629146488317, -2.287597695597155, -2.2635847437432086, -2.2391332635851304, -2.214252779083978, -2.188953146834909, -2.163244570541659, -2.137137616929305, -2.1106432332452036, -2.0837727665145658, -2.0565379847356566, -2.02895110022016, -2.0010247953071683, -1.9727722507046772, -1.9442071767406661, -1.9153438478370517, -1.8861971405542335, -1.8567825755918106, -1.827116364172505, -1.7972154592814642, -1.7670976122819135, -1.7367814354804274, -1.7062864712704624, -1.6756332685405386, -1.6448434670924035, -1.613939890872844, -1.582946650878016, -1.5518892586374482, -1.5207947512211741, -1.4896918287306826, -1.458611005223036, -1.427584773964922, -1.3966477878028882, -1.365837055245896, -1.335192152558758, -1.3047554517249584, -1.2745723635110935, -1.244691593999762, -1.2151654117904838, -1.1860499215275147, -1.1574053374217277, -1.1292962479133624, -1.1017918595064333, -1.0749662040548715, -1.0488982894098882, -1.0236721684526293, -0.9993768963781611, -0.9761063411010975, -0.9539588075033251, -0.9330364339143966, -0.9134443199721182, -0.8952893503420941, -0.8786786902029626, -0.8637179471555405, -0.8505090207463055, -0.8391476942400402, -0.8297210609469349, -0.8223049146005594, -0.8169612636082183, -0.8137361454247116, -0.8126579138282576, -0.8137361454247138, -0.8169612636082227, -0.8223049146005661, -0.8297210609469438, -0.8391476942400509, -0.8505090207463182, -0.8637179471555548, -0.8786786902029788, -0.8952893503421119, -0.9134443199721375, -0.9330364339144174, -0.9539588075033473, -0.9761063411011209, -0.9993768963781854, -1.0236721684526549, -1.0488982894099146, -1.0749662040548988, -1.1017918595064613, -1.129296247913391, -1.157405337421757, -1.1860499215275446, -1.215165411790514, -1.2446915939997925, -1.2745723635111246, -1.3047554517249897, -1.3351921525587893, -1.3658370552459276, -1.39664778780292, -1.4275847739649539, -1.4586110052230683, -1.4896918287307146, -1.5207947512212063, -1.5518892586374804, -1.5829466508780479, -1.6139398908728755, -1.644843467092435, -1.67563326854057, -1.7062864712704933, -1.7367814354804585, -1.7670976122819444, -1.797215459281495, -1.8271163641725356, -1.8567825755918412, -1.8861971405542635, -1.9153438478370817, -1.9442071767406957, -1.9727722507047065, -2.001024795307197, -2.0289511002201883, -2.0565379847356846, -2.0837727665145938, -2.1106432332452307, -2.137137616929332, -2.1632445705416856, -2.188953146834936, -2.214252779084004, -2.2391332635851557, -2.2635847437432335, -2.287597695597179, -2.3111629146488557, -2.3342715038735395, -2.356914862802435, -2.3790846775783057, -2.4007729118949643, -2.421971798740009, -2.4426738328679547, -2.462871763937892, -2.4825585902560654, -2.501727553069398, -2.520372131361062, -2.5384860371037523, -2.5560632109304318, -2.573097818186041, -2.5895842453269764, -2.605517096638204, -2.6208911912405797, -2.6357015603634273, -2.649943444859681, -2.663612292942898, -2.676703758127341, -2.689213697353959, -2.701138169286654, -2.712473432764606, -2.7232159453977043, -2.733362362293273, -2.742909534903391, -2.7518545099830405, -2.7601945286502314, -2.767927025540102, -2.7750496280457306, -2.781560155639118, -2.787456619266472, -2.792737220812521, -2.797400352629179, -2.801444597124418, -2.8048687264077183, -2.8076717019889488, -2.8098526745280066, -2.8114109836329675, -2.8123461577049436], [-2.8303879827648046, -2.830075149323747, -2.829136744213406, -2.827573053095184, -2.8253845521479772, -2.822571908183717, -2.8191359788105457, -2.815077812645051, -2.8103986495754114, -2.80509992107775, -2.799183250588425, -2.7926504539354964, -2.7855035398330643, -2.7777447104427333, -2.7693763620069856, -2.7604010855598506, -2.7508216677208837, -2.740641091579142, -2.729862537674571, -2.7184893850849945, -2.7065252126277515, -2.6939738001859412, -2.6808391301702277, -2.66712538912824, -2.6528369695147984, -2.6379784716374783, -2.6225547057934384, -2.606570694614996, -2.590031675643138, -2.5729431041500104, -2.555310656233512, -2.537140232209363, -2.518437960328533, -2.4992102008506816, -2.479463550507293, -2.459204847391581, -2.438441176315984, -2.417179874682179, -2.3954285389131593, -2.373195031502016, -2.350487488737692, -2.327314329174281, -2.3036842629174257, -2.2796063018091077, -2.255089770600797, -2.2301443192144856, -2.204779936201891, -2.1790069635239364, -2.1528361127859337, -2.126278483078583, -2.099345580591304, -2.0720493401826423, -2.0444021491126945, -2.01641687316495, -1.9881068854097756, -1.959486097889227, -1.930568996533126, -1.9013706796496077, -1.8719069003697182, -1.842194113465289, -1.8122495270021814, -1.7820911593370143, -1.751737902014371, -1.7212095891726649, -1.6905270741194933, -1.65971231379004, -1.6287884618529571, -1.5977799712743117, -1.5667127071877167, -1.5356140709422497, -1.5045131362019386, -1.4734407979416855, -1.4424299351117484, -1.4115155876095646, -1.380735147982361, -1.3501285679594628, -1.3197385794454801, -1.2896109289530402, -1.2597946235665236, -1.2303421853483367, -1.2013099095617676, -1.1727581201210642, -1.1447514132246346, -1.1173588771296987, -1.0906542724656065, -1.064716153393425, -1.0396279054255873, -1.0154776710772864, -0.9923581301662288, -0.9703660981696908, -0.9496019045018124, -0.9301685140472246, -0.9121703610999459, -0.8957118763108529, -0.8808957053211036, -0.8678206426880591, -0.8565793355152468, -0.847255845293019, -0.8399231895296114, -0.834641011118665, -0.8314535369338389, -0.8303879827648046, -0.8314535369338413, -0.8346410111186693, -0.839923189529618, -0.8472558452930276, -0.8565793355152574, -0.8678206426880716, -0.8808957053211179, -0.895711876310869, -0.9121703610999635, -0.9301685140472437, -0.9496019045018331, -0.9703660981697128, -0.992358130166252, -1.0154776710773106, -1.0396279054256126, -1.064716153393451, -1.0906542724656334, -1.1173588771297265, -1.1447514132246632, -1.1727581201210935, -1.2013099095617972, -1.2303421853483665, -1.2597946235665543, -1.289610928953071, -1.319738579445511, -1.3501285679594943, -1.3807351479823928, -1.4115155876095964, -1.4424299351117804, -1.473440797941717, -1.5045131362019706, -1.5356140709422819, -1.5667127071877485, -1.5977799712743435, -1.6287884618529889, -1.6597123137900716, -1.6905270741195246, -1.7212095891726964, -1.7517379020144022, -1.7820911593370456, -1.8122495270022125, -1.84219411346532, -1.8719069003697482, -1.9013706796496377, -1.930568996533156, -1.9594860978892565, -1.9881068854098045, -2.0164168731649785, -2.044402149112723, -2.0720493401826707, -2.0993455805913315, -2.12627848307861, -2.1528361127859608, -2.179006963523963, -2.2047799362019176, -2.230144319214512, -2.2550897706008217, -2.2796063018091326, -2.3036842629174497, -2.327314329174305, -2.350487488737716, -2.37319503150204, -2.395428538913182, -2.4171798746822013, -2.4384411763160054, -2.4592048473916015, -2.479463550507313, -2.499210200850702, -2.518437960328553, -2.5371402322093815, -2.5553106562335306, -2.5729431041500277, -2.5900316756431554, -2.606570694615013, -2.622554705793455, -2.637978471637494, -2.652836969514813, -2.667125389128254, -2.680839130170242, -2.693973800185955, -2.7065252126277644, -2.718489385085006, -2.729862537674583, -2.7406410915791524, -2.7508216677208934, -2.7604010855598604, -2.7693763620069944, -2.7777447104427417, -2.7855035398330714, -2.792650453935503, -2.799183250588432, -2.8050999210777556, -2.810398649575417, -2.815077812645055, -2.81913597881055, -2.82257190818372, -2.82538455214798, -2.8275730530951857, -2.829136744213407, -2.8300751493237475], [-2.8473147049577845, -2.8470008555317854, -2.8460594033413966, -2.8444906366734384, -2.8422950360861194, -2.8394732745300293, -2.8360262175189646, -2.8319549233520633, -2.8272606433891245, -2.821944822381474, -2.816009098861153, -2.8094553055917504, -2.802285470084646, -2.7945018151850047, -2.786106759732427, -2.777102919301732, -2.76749310703003, -2.7572803345368997, -2.7464678129452382, -2.735058954011146, -2.723057371372066, -2.710466881923331, -2.697291507334291, -2.6835354757162784, -2.66920322345589, -2.6542993972283644, -2.638828856207265, -2.622796674488263, -2.6062081437465254, -2.589068776149115, -2.57138430754589, -2.5531607009646846, -2.5344041504390606, -2.5151210851997456, -2.4953181742639057, -2.4750023314598244, -2.45418072092833, -2.4328607631464454, -2.4110501415233694, -2.3887568096240073, -2.3659889990809138, -2.3427552282618316, -2.319064311766963, -2.294925370837867, -2.270347844768514, -2.2453415034185364, -2.2199164609394186, -2.194083190836116, -2.1678525424997406, -2.1412357593615265, -2.1142444988344278, -2.086890854226649, -2.0591873788312562, -2.031147112417976, -2.002783610377536, -1.9741109757956055, -1.9451438947627142, -1.9158976752586336, -1.886388289984634, -1.8566324235548888, -1.826647524499001, -1.7964518625709323, -1.766064591905237, -1.7355058206086826, -1.7047966874231584, -1.673959446142642, -1.6430175585108378, -1.611995796363852, -1.5809203538098093, -1.5498189702490244, -1.5187210650267564, -1.4876578844657888, -1.456662661935223, -1.4257707914583524, -1.3950200151251573, -1.3644506242273284, -1.3341056735430048, -1.3040312075250273, -1.274276496243536, -1.2448942777476335, -1.2159410019829542, -1.1874770694723975, -1.1595670555815025, -1.1322799083099118, -1.1056891041710535, -1.079872742895095, -1.054913557554506, -1.0308988125319494, -1.007920057958081, -0.9860727064770556, -0.9654553973068226, -0.9461691146078026, -0.9283160333318126, -0.911998077108406, -0.897315190113558, -0.8843633483199058, -0.8732323639995466, -0.8640035683645814, -0.8567474868265822, -0.8515216444451315, -0.8483686503565612, -0.8473147049577844, -0.8483686503565633, -0.8515216444451358, -0.8567474868265885, -0.8640035683645898, -0.8732323639995572, -0.8843633483199181, -0.8973151901135722, -0.911998077108422, -0.92831603333183, -0.9461691146078216, -0.9654553973068432, -0.9860727064770775, -1.0079200579581038, -1.0308988125319734, -1.0549135575545312, -1.079872742895121, -1.1056891041710806, -1.1322799083099395, -1.159567055581531, -1.1874770694724264, -1.2159410019829837, -1.2448942777476637, -1.2742764962435664, -1.304031207525058, -1.3341056735430359, -1.36445062422736, -1.395020015125189, -1.425770791458384, -1.456662661935255, -1.4876578844658208, -1.5187210650267884, -1.5498189702490563, -1.5809203538098413, -1.6119957963638838, -1.6430175585108693, -1.6739594461426734, -1.70479668742319, -1.7355058206087137, -1.766064591905268, -1.7964518625709633, -1.826647524499032, -1.8566324235549196, -1.8863882899846645, -1.9158976752586638, -1.945143894762744, -1.974110975795635, -2.002783610377566, -2.0311471124180054, -2.059187378831285, -2.0868908542266773, -2.1142444988344553, -2.1412357593615536, -2.1678525424997677, -2.1940831908361433, -2.2199164609394457, -2.245341503418562, -2.2703478447685397, -2.294925370837892, -2.3190643117669874, -2.342755228261856, -2.365988999080937, -2.3887568096240304, -2.411050141523392, -2.4328607631464676, -2.4541807209283517, -2.4750023314598453, -2.4953181742639257, -2.515121085199766, -2.53440415043908, -2.5531607009647033, -2.571384307545909, -2.5890687761491322, -2.606208143746543, -2.6227966744882805, -2.6388288562072817, -2.65429939722838, -2.669203223455904, -2.683535475716292, -2.697291507334305, -2.710466881923345, -2.7230573713720787, -2.7350589540111576, -2.7464678129452493, -2.75728033453691, -2.76749310703004, -2.777102919301741, -2.7861067597324363, -2.7945018151850136, -2.802285470084654, -2.8094553055917575, -2.8160090988611595, -2.8219448223814796, -2.82726064338913, -2.8319549233520673, -2.836026217518969, -2.839473274530033, -2.8422950360861217, -2.84449063667344, -2.846059403341398, -2.847000855531786], [-2.86342170489667, -2.8631068998416827, -2.8621625815978384, -2.8605890409535215, -2.858386762639648, -2.8555564254558323, -2.8520989024484753, -2.8480152611422973, -2.8433067638272145, -2.8379748679029713, -2.832021226284373, -2.8254476878704837, -2.8182562980816477, -2.810449299468759, -2.8020291323997633, -2.792998435828997, -2.7833600481556227, -2.7731170081781022, -2.762272556152432, -2.75083013496264, -2.738793391412946, -2.7261661776519017, -2.7129525527399005, -2.699156784372512, -2.6847833507733525, -2.669836942771515, -2.6543224660800346, -2.638245043793462, -2.621610019124353, -2.6044229584004093, -2.5866896543460816, -2.5684161296747945, -2.5496086410204737, -2.530273683239873, -2.5104179941202935, -2.4900485595307207, -2.4691726190581593, -2.4477976721751635, -2.4259314849891345, -2.403582097629134, -2.3807578323316014, -2.3574673022926507, -2.3337194213616086, -2.30952341465819, -2.2848888302042645, -2.259825551670702, -2.234343812350335, -2.20845421047979, -2.1821677260459174, -2.155495739226946, -2.1284500506344255, -2.101042903539639, -2.073287008287672, -2.0451955691237833, -2.0167823136803964, -1.9880615253989846, -1.9590480791895264, -1.9297574806611721, -1.900205909291291, -1.8704102659362218, -1.8403882251256063, -1.8101582926229685, -1.779739868777654, -1.749153318236679, -1.718420046628245, -1.6875625848700957, -1.6566046817931421, -1.6255714058007462, -1.5944892563023754, -1.563386285661259, -1.532292232371595, -1.5012386661217223, -1.470259145292706, -1.4393893872704453, -1.4086674516929878, -1.3781339363874558, -1.3478321852413346, -1.3178085065631475, -1.288112399573821, -1.2587967854828859, -1.229918238090163, -1.2015372069614685, -1.1737182239112651, -1.1465300807598138, -1.1200459631253206, -1.0943435214278585, -1.0695048564718037, -1.0456163932069125, -1.022768612969505, -1.0010556122829193, -0.9805744559529087, -0.9614242946975926, -0.9437052239503197, -0.9275168717249421, -0.9129567201464613, -0.900118187357758, -0.8890885229255453, -0.8799465982242614, -0.8727606999267522, -0.8675864550932191, -0.8644650256887061, -0.8634217048966701, -0.8644650256887082, -0.8675864550932234, -0.8727606999267585, -0.8799465982242699, -0.8890885229255558, -0.9001181873577702, -0.9129567201464753, -0.9275168717249579, -0.9437052239503372, -0.9614242946976116, -0.9805744559529289, -1.001055612282941, -1.0227686129695277, -1.0456163932069364, -1.0695048564718288, -1.0943435214278847, -1.1200459631253474, -1.1465300807598413, -1.1737182239112933, -1.2015372069614971, -1.2299182380901923, -1.2587967854829154, -1.2881123995738515, -1.3178085065631782, -1.3478321852413655, -1.3781339363874867, -1.4086674516930193, -1.4393893872704768, -1.4702591452927378, -1.501238666121754, -1.5322922323716273, -1.563386285661291, -1.5944892563024071, -1.6255714058007784, -1.656604681793174, -1.6875625848701277, -1.7184200466282764, -1.7491533182367103, -1.7797398687776853, -1.8101582926229998, -1.8403882251256374, -1.8704102659362527, -1.9002059092913215, -1.9297574806612026, -1.9590480791895566, -1.988061525399014, -2.016782313680426, -2.0451955691238126, -2.073287008287701, -2.1010429035396676, -2.1284500506344535, -2.1554957392269745, -2.1821677260459444, -2.208454210479817, -2.2343438123503616, -2.2598255516707275, -2.2848888302042902, -2.309523414658215, -2.3337194213616326, -2.3574673022926746, -2.380757832331626, -2.403582097629157, -2.425931484989157, -2.447797672175186, -2.4691726190581815, -2.4900485595307416, -2.510417994120315, -2.5302736832398933, -2.5496086410204932, -2.568416129674813, -2.5866896543460998, -2.6044229584004275, -2.62161001912437, -2.6382450437934786, -2.654322466080051, -2.669836942771531, -2.684783350773368, -2.6991567843725264, -2.712952552739914, -2.726166177651914, -2.7387933914129583, -2.7508301349626523, -2.762272556152443, -2.773117008178113, -2.7833600481556333, -2.792998435829007, -2.8020291323997717, -2.810449299468767, -2.8182562980816552, -2.825447687870491, -2.8320212262843794, -2.837974867902977, -2.8433067638272194, -2.848015261142302, -2.8520989024484793, -2.8555564254558354, -2.8583867626396504, -2.860589040953523, -2.86216258159784, -2.8631068998416827], [-2.878693400099275, -2.8783776988512155, -2.877430692819312, -2.875852675166386, -2.8736441345840045, -2.8708057554235262, -2.867338417881073, -2.863243198237932, -2.85852136915837, -2.853174400047279, -2.8472039574705668, -2.8406119056417185, -2.8334003069784504, -2.825571422733966, -2.81712771370788, -2.808071841042522, -2.7984066671109735, -2.788135256503928, -2.7772608771231866, -2.765787001390476, -2.753717307581104, -2.741055681292981, -2.7278062170625317, -2.7139732201401854, -2.6995612084393508, -2.684574914674121, -2.6690192887024358, -2.652899500093028, -2.636220940936238, -2.6189892289207215, -2.601210210700184, -2.582889965576621, -2.564034809529094, -2.5446512996199098, -2.5247462388131874, -2.5043266812442146, -2.483399937981826, -2.4619735833301877, -2.440055461721051, -2.4176536952526253, -2.394776691936923, -2.3714331547237104, -2.347632091376128, -2.3233828252807984, -2.298695007283727, -2.273578628652802, -2.2480440352781503, -2.222101943233231, -2.195763455832367, -2.169040082334657, -2.141943758459881, -2.1144868688993665, -2.0866822720238827, -2.0585433270116495, -2.0300839236426134, -2.001318515030383, -1.9722621535907277, -1.9429305305753874, -1.9133400195321548, -1.8835077240866416, -1.8534515304777315, -1.8231901653170302, -1.792743259082131, -1.7621314158933667, -1.7313762901626584, -1.7005006707393442, -1.6695285732090461, -1.6384853410243745, -1.6073977561561423, -1.5762941599448383, -1.5452045847966869, -1.514160897296653, -1.4831969531894096, -1.452348764492317, -1.4216546787315363, -1.3911555699085023, -1.3608950402788393, -1.3309196313236125, -1.3012790413723812, -1.2720263461532992, -1.2432182170498403, -1.21491512999114, -1.1871815556571774, -1.160086119024819, -1.1337017132354075, -1.1081055494049177, -1.0833791204823855, -1.0596080538633785, -1.0368818245982887, -1.015293299282306, -0.9949380808269711, -0.9759136271807439, -0.9583181236249185, -0.9422490993458632, -0.9278017950496512, -0.9150673092709656, -0.904130575625168, -0.8950682493106837, -0.8879466053155933, -0.8828195688670023, -0.8797270064679892, -0.8786934000992751, -0.8797270064679912, -0.8828195688670066, -0.8879466053155997, -0.8950682493106921, -0.9041305756251783, -0.9150673092709777, -0.9278017950496651, -0.9422490993458791, -0.9583181236249358, -0.9759136271807629, -0.9949380808269914, -1.0152932992823278, -1.0368818245983116, -1.0596080538634023, -1.0833791204824104, -1.1081055494049437, -1.1337017132354343, -1.1600861190248466, -1.1871815556572058, -1.2149151299911687, -1.2432182170498696, -1.272026346153329, -1.3012790413724113, -1.330919631323643, -1.3608950402788704, -1.3911555699085334, -1.4216546787315676, -1.4523487644923487, -1.4831969531894418, -1.5141608972966851, -1.5452045847967188, -1.5762941599448705, -1.6073977561561748, -1.6384853410244065, -1.6695285732090779, -1.7005006707393757, -1.7313762901626901, -1.7621314158933983, -1.7927432590821621, -1.8231901653170612, -1.8534515304777621, -1.883507724086672, -1.9133400195321852, -1.9429305305754174, -1.9722621535907576, -2.0013185150304134, -2.030083923642643, -2.0585433270116784, -2.0866822720239115, -2.114486868899395, -2.1419437584599095, -2.1690400823346847, -2.1957634558323944, -2.2221019432332576, -2.248044035278177, -2.2735786286528277, -2.298695007283753, -2.3233828252808233, -2.347632091376153, -2.371433154723734, -2.394776691936947, -2.4176536952526484, -2.440055461721074, -2.46197358333021, -2.483399937981847, -2.5043266812442364, -2.524746238813208, -2.54465129961993, -2.5640348095291134, -2.58288996557664, -2.601210210700202, -2.6189892289207393, -2.636220940936255, -2.652899500093045, -2.669019288702452, -2.684574914674137, -2.699561208439366, -2.7139732201402, -2.7278062170625454, -2.7410556812929943, -2.7537173075811174, -2.7657870013904877, -2.7772608771231986, -2.7881352565039386, -2.7984066671109837, -2.8080718410425307, -2.8171277137078894, -2.825571422733975, -2.8334003069784583, -2.8406119056417256, -2.8472039574705725, -2.8531744000472847, -2.8585213691583755, -2.8632431982379365, -2.8673384178810766, -2.87080575542353, -2.8736441345840067, -2.8758526751663878, -2.877430692819313, -2.878377698851216], [-2.8931150161867976, -2.8927984773178146, -2.8918489591709386, -2.890266757153295, -2.888052363700023, -2.8852064684099203, -2.8817299582368845, -2.8776239177386813, -2.8728896293850457, -2.867528573927576, -2.8615424308344046, -2.8549330787930827, -2.847702596285721, -2.8398532622409225, -2.8313875567676803, -2.8223081619770363, -2.8126179628979573, -2.8023200484946202, -2.7914177127930606, -2.779914456125968, -2.7678139865053297, -2.755120221133568, -2.741837288064887, -2.7279695280296843, -2.71352149643613, -2.698497965564371, -2.6829039269703028, -2.6667445941174717, -2.650025405257454, -2.632752026580983, -2.6149303556642676, -2.596566525237258, -2.577666907303215, -2.5582381176417806, -2.538287020730868, -2.5178207351261492, -2.4968466393407245, -2.4753723782717567, -2.453405870225498, -2.430955314597265, -2.4080292002686012, -2.384636314790113, -2.360785754425436, -2.3364869351394377, -2.3117496046222796, -2.286583855450337, -2.26100013949539, -2.235009283704991, -2.2086225073895878, -2.1818514411660517, -2.154708147722695, -2.127205144587905, -2.099355429103285, -2.071172505822716, -2.0426704165812746, -2.0138637735024787, -1.9847677952389524, -1.9553983467704352, -1.9257719831139237, -1.8959059973336612, -1.8658184732733374, -1.8355283434688716, -1.8050554527368774, -1.774420627970406, -1.7436457547085216, -1.7127538610777537, -1.6817692097290409, -1.6507173984098664, -1.6196254698134576, -1.588522031329029, -1.55743738527144, -1.5264036700851369, -1.4954550128832216, -1.4646276934818268, -1.4339603198028423, -1.4034940141201753, -1.373272609087062, -1.3433428517704866, -1.3137546129948847, -1.2845610981190518, -1.255819053894612, -1.227588964242232, -1.1999352256041607, -1.172926289981175, -1.1466347608671885, -1.1211374241401433, -1.0965151927181198, -1.0728529407169454, -1.050239200355539, -1.0287656935043163, -1.0085266702655453, -0.9896180301299019, -0.9721362079115968, -0.956176817537278, -0.941833062215457, -0.9291939392957269, -0.9183422911253867, -0.9093527772820512, -0.9022898655744989, -0.8972059553780473, -0.8941397534231477, -0.8931150161867976, -0.8941397534231499, -0.8972059553780514, -0.9022898655745051, -0.9093527772820597, -0.9183422911253969, -0.929193939295739, -0.9418330622154709, -0.9561768175372936, -0.9721362079116138, -0.9896180301299206, -1.0085266702655655, -1.0287656935043379, -1.0502392003555616, -1.0728529407169693, -1.0965151927181447, -1.121137424140169, -1.146634760867215, -1.172926289981202, -1.1999352256041889, -1.2275889642422608, -1.2558190538946412, -1.2845610981190816, -1.3137546129949151, -1.3433428517705173, -1.373272609087093, -1.4034940141202068, -1.4339603198028739, -1.4646276934818585, -1.4954550128832533, -1.5264036700851684, -1.557437385271472, -1.5885220313290611, -1.6196254698134893, -1.6507173984098988, -1.6817692097290726, -1.7127538610777855, -1.7436457547085529, -1.7744206279704373, -1.8050554527369087, -1.8355283434689031, -1.8658184732733685, -1.8959059973336922, -1.9257719831139544, -1.9553983467704654, -1.9847677952389826, -2.013863773502509, -2.0426704165813043, -2.071172505822745, -2.099355429103314, -2.127205144587933, -2.1547081477227232, -2.1818514411660797, -2.2086225073896153, -2.2350092837050184, -2.2610001394954167, -2.286583855450363, -2.3117496046223054, -2.336486935139463, -2.3607857544254602, -2.384636314790137, -2.408029200268625, -2.4309553145972886, -2.4534058702255206, -2.475372378271779, -2.4968466393407462, -2.51782073512617, -2.538287020730889, -2.558238117641801, -2.577666907303235, -2.596566525237277, -2.614930355664286, -2.632752026581001, -2.650025405257472, -2.6667445941174894, -2.6829039269703188, -2.698497965564387, -2.7135214964361443, -2.727969528029699, -2.741837288064901, -2.7551202211335815, -2.767813986505342, -2.77991445612598, -2.791417712793072, -2.802320048494632, -2.812617962897967, -2.8223081619770456, -2.831387556767689, -2.839853262240931, -2.8477025962857287, -2.8549330787930893, -2.8615424308344104, -2.867528573927583, -2.8728896293850505, -2.877623917738686, -2.881729958236888, -2.885206468409923, -2.8880523637000257, -2.890266757153297, -2.8918489591709395, -2.8927984773178155], [-2.9066726011770783, -2.9063552824512664, -2.9054034254374206, -2.9038173276540773, -2.901597485058263, -2.898744592185454, -2.895259542347079, -2.891143427887131, -2.8863975404998983, -2.8810233716113514, -2.8750226128271703, -2.868397156450947, -2.8611490960766157, -2.8532807272597602, -2.8447945482730232, -2.8356932609514938, -2.8259797716346395, -2.8156571922120595, -2.8047288412811366, -2.7931982454254913, -2.7810691406240613, -2.7683454738016002, -2.755031404532475, -2.74113130691076, -2.726649771600928, -2.7115916080847717, -2.6959618471217066, -2.679765743441235, -2.663008778688138, -2.64569666464292, -2.627835346742196, -2.6094310079260548, -2.5904900728420306, -2.571019212438187, -2.5510253489809256, -2.530515661536632, -2.509497591960059, -2.4879788514365697, -2.4659674276300065, -2.443471592493072, -2.4204999108027985, -2.3970612494898997, -2.3731647878377653, -2.34882002863445, -2.324036810369508, -2.2988253205768077, -2.273196110434813, -2.2471601107471724, -2.2207286494390264, -2.193913470718278, -2.1667267560663293, -2.139181147239511, -2.111289771480824, -2.0830662691617348, -2.0545248240956897, -2.0256801967888984, -1.9965477609197362, -1.9671435433659121, -1.9374842681282172, -1.9075874045310761, -1.877471220112999, -1.8471548386538468, -1.8166583038199682, -1.7860026489416316, -1.7552099734684288, -1.724303526675435, -1.6933077992132732, -1.6622486231052873, -1.6311532807901292, -1.6000506237821255, -1.5689712014669666, -1.5379474004565323, -1.5070135947814183, -1.4762063069871352, -1.4455643799006426, -1.4151291584243482, -1.3849446801670209, -1.3550578730029563, -1.325518756725984, -1.2963806447947726, -1.2677003407118286, -1.2395383218066482, -1.2119589010814897, -1.185030355326171, -1.1588250049525175, -1.133419228031064, -1.108893388001293, -1.0853316517428164, -1.0628216725334123, -1.0414541114128242, -1.0213219712817465, -1.0025197214474844, -0.9851421970395323, -0.9692832683766159, -0.9550342902449983, -0.9424823598385809, -0.9317084337035432, -0.9227853763808174, -0.9157760336319458, -0.9107314377000684, -0.9076892575801194, -0.9066726011770783, -0.9076892575801216, -0.9107314377000726, -0.9157760336319521, -0.9227853763808255, -0.9317084337035534, -0.9424823598385929, -0.9550342902450122, -0.9692832683766316, -0.9851421970395494, -1.002519721447503, -1.0213219712817667, -1.0414541114128455, -1.062821672533435, -1.0853316517428402, -1.1088933880013176, -1.1334192280310897, -1.158825004952544, -1.185030355326198, -1.2119589010815175, -1.239538321806677, -1.2677003407118574, -1.296380644794802, -1.3255187567260143, -1.355057873002987, -1.3849446801670517, -1.4151291584243795, -1.4455643799006739, -1.4762063069871667, -1.50701359478145, -1.5379474004565639, -1.5689712014669985, -1.6000506237821577, -1.631153280790161, -1.6622486231053195, -1.6933077992133052, -1.7243035266754667, -1.7552099734684605, -1.7860026489416632, -1.8166583038199997, -1.8471548386538785, -1.87747122011303, -1.9075874045311074, -1.9374842681282476, -1.9671435433659425, -1.9965477609197662, -2.0256801967889286, -2.054524824095719, -2.083066269161764, -2.1112897714808527, -2.1391811472395394, -2.1667267560663577, -2.193913470718306, -2.2207286494390535, -2.2471601107471995, -2.273196110434839, -2.2988253205768334, -2.3240368103695337, -2.348820028634475, -2.3731647878377897, -2.3970612494899237, -2.4204999108028225, -2.4434715924930956, -2.4659674276300287, -2.4879788514365924, -2.5094975919600806, -2.530515661536653, -2.5510253489809465, -2.5710192124382076, -2.590490072842051, -2.6094310079260734, -2.6278353467422146, -2.645696664642937, -2.663008778688156, -2.679765743441252, -2.6959618471217226, -2.7115916080847873, -2.7266497716009432, -2.741131306910775, -2.755031404532489, -2.7683454738016136, -2.781069140624074, -2.793198245425504, -2.804728841281148, -2.81565719221207, -2.8259797716346498, -2.8356932609515035, -2.844794548273032, -2.853280727259769, -2.861149096076623, -2.8683971564509543, -2.875022612827177, -2.881023371611357, -2.8863975404999036, -2.891143427887135, -2.8952595423470835, -2.898744592185457, -2.9015974850582658, -2.903817327654079, -2.9054034254374215, -2.906355282451267], [-2.9193530389822415, -2.9190349974108027, -2.9180809725184713, -2.916491263799775, -2.914266370507734, -2.911406991797838, -2.9079140269312136, -2.9037885755385338, -2.899031937946737, -2.8936456155711245, -2.8876313113758325, -2.8809909304063086, -2.873726580397862, -2.865840572465013, -2.857335421876938, -2.848213848924962, -2.8384787798887454, -2.828133348108544, -2.817180895171708, -2.8056249722224558, -2.793469341404842, -2.7807179774498643, -2.7673750694187076, -2.7534450226153018, -2.738932460682622, -2.7238422278985652, -2.7081793916887196, -2.691949245375014, -2.6751573111810076, -2.657809343516581, -2.6399113325669337, -2.621469508213173, -2.6024903443143854, -2.582980563383933, -2.5629471416959078, -2.5423973148610948, -2.521338583915649, -2.4997787219699146, -2.4777257814694233, -2.455188102125265, -2.4321743195766685, -2.4086933748548764, -2.3847545247242783, -2.360367352984393, -2.3355417828246714, -2.3102880903333674, -2.284616919271949, -2.2585392972377876, -2.232066653350278, -2.205210837609219, -2.177984142089273, -2.1503993241508246, -2.1224696318655587, -2.0942088318747873, -2.0656312399199703, -2.0367517543080753, -2.007585892599486, -1.9781498318329753, -1.9484604526307745, -1.9185353875568094, -1.8883930741323167, -1.8580528129448972, -1.8275348313187405, -1.7968603530442793, -1.7660516746933366, -1.735132249068903, -1.7041267763543226, -1.6730613035311805, -1.6419633326239358, -1.610861938296102, -1.5797878952597606, -1.5487738158573576, -1.5178542980196241, -1.4870660835805136, -1.4564482266203556, -1.426042271089187, -1.3958924364066432, -1.3660458090121754, -1.3365525369156697, -1.3074660231380761, -1.2788431124996662, -1.2507442644809115, -1.2232337028313287, -1.1963795302412343, -1.1702537937631572, -1.1449324838705561, -1.1204954472432085, -1.0970261908396024, -1.0746115529409295, -1.05334121613821, -1.0333070383082201, -1.0146021811836423, -0.9973200228546129, -0.9815528509792532, -0.9673903478289495, -0.9549178961970571, -0.9442147555569073, -0.9353521787158074, -0.9283915578463188, -0.9233827019856842, -0.9203623527674555, -0.9193530389822417, -0.9203623527674575, -0.9233827019856884, -0.9283915578463249, -0.9353521787158156, -0.9442147555569173, -0.954917896197069, -0.9673903478289633, -0.9815528509792686, -0.99732002285463, -1.0146021811836607, -1.0333070383082401, -1.0533412161382312, -1.074611552940952, -1.0970261908396262, -1.1204954472432334, -1.1449324838705819, -1.1702537937631836, -1.1963795302412616, -1.2232337028313567, -1.2507442644809401, -1.278843112499695, -1.307466023138106, -1.3365525369156996, -1.3660458090122058, -1.3958924364066738, -1.4260422710892182, -1.456448226620387, -1.4870660835805452, -1.5178542980196557, -1.5487738158573896, -1.5797878952597924, -1.6108619382961338, -1.6419633326239678, -1.6730613035312125, -1.7041267763543544, -1.7351322490689347, -1.766051674693368, -1.796860353044311, -1.8275348313187716, -1.8580528129449283, -1.8883930741323478, -1.91853538755684, -1.9484604526308051, -1.9781498318330062, -2.0075858925995167, -2.0367517543081046, -2.0656312399199996, -2.0942088318748167, -2.122469631865587, -2.1503993241508534, -2.1779841420893016, -2.2052108376092465, -2.2320666533503055, -2.2585392972378147, -2.284616919271976, -2.310288090333393, -2.3355417828246967, -2.3603673529844182, -2.384754524724303, -2.4086933748549004, -2.432174319576692, -2.4551881021252884, -2.4777257814694456, -2.4997787219699372, -2.5213385839156706, -2.542397314861116, -2.562947141695929, -2.582980563383953, -2.6024903443144045, -2.621469508213193, -2.639911332566952, -2.657809343516599, -2.6751573111810254, -2.691949245375031, -2.708179391688736, -2.7238422278985803, -2.7389324606826375, -2.753445022615317, -2.767375069418722, -2.780717977449877, -2.7934693414048546, -2.8056249722224678, -2.81718089517172, -2.8281333481085547, -2.838478779888756, -2.848213848924972, -2.857335421876947, -2.8658405724650216, -2.8737265803978698, -2.8809909304063153, -2.887631311375839, -2.8936456155711303, -2.899031937946743, -2.9037885755385378, -2.907914026931218, -2.9114069917978407, -2.914266370507736, -2.9164912637997777, -2.918080972518472, -2.9190349974108036], [-2.9311440620976645, -2.9308253539935265, -2.9298693301156065, -2.928276291796699, -2.926046741356086, -2.923181382247236, -2.9196811192662198, -2.915547058822383, -2.910780509273404, -2.905382981327298, -2.8993561885144468, -2.892702047733278, -2.885422679873757, -2.8775204105234495, -2.868997770761518, -2.859857498046682, -2.850102537205861, -2.8397360415309607, -2.8287613739920796, -2.8171821085762376, -2.8050020317617, -2.792225144138922, -2.7788556621902654, -2.7648980202417768, -2.7503568726016296, -2.735237095901195, -2.719543791656242, -2.7032822890674124, -2.686458148080944, -2.6690771627325667, -2.6511453647997176, -2.632669027789553, -2.6136546712928777, -2.5941090657369936, -2.574039237573606, -2.553452474941415, -2.5323563338468507, -2.510758644910608, -2.488667520732311, -2.4660913639307105, -2.443038875922519, -2.419519066509152, -2.3955412643475706, -2.3711151283889285, -2.3462506603771285, -2.320958218508564, -2.2952485323644676, -2.269132719238444, -2.2426223019940674, -2.2157292286008676, -2.1884658935118746, -2.160845161062066, -2.1328803910847602, -2.104585466962295, -2.075974826348243, -2.0470634948210167, -2.017867122753039, -1.9884020257055577, -1.9586852286866392, -1.9287345146385797, -1.8985684775505878, -1.8682065806225268, -1.8376692199349818, -1.8069777941087635, -1.776154780461637, -1.7452238181894666, -1.714209799110261, -1.683138966509174, -1.6520390226054662, -1.6209392451227171, -1.5898706133732063, -1.5588659441565387, -1.527960037608825, -1.497189832906835, -1.466594573413027, -1.4362159804201047, -1.4060984340920408, -1.376289159473066, -1.34683841451497, -1.317799675923165, -1.289229817211995, -1.261189271664978, -1.233742170904459, -1.2069564474994732, -1.1809038875286062, -1.1556601163676208, -1.1313044983629654, -1.1079199287473582, -1.0855924945259479, -1.0644109805992514, -1.0444661986822825, -1.0258501202773718, -1.0086548016858008, -0.9929710992693522, -0.9788871870355021, -0.9664869057315154, -0.955847991907325, -0.9470402549784054, -0.9401237876213427, -0.9351473068977227, -0.9321467274731243, -0.9311440620976645, -0.9321467274731263, -0.9351473068977268, -0.940123787621349, -0.9470402549784136, -0.9558479919073348, -0.9664869057315273, -0.9788871870355156, -0.9929710992693673, -1.0086548016858177, -1.0258501202773902, -1.0444661986823025, -1.0644109805992725, -1.0855924945259703, -1.1079199287473815, -1.1313044983629899, -1.155660116367646, -1.1809038875286326, -1.2069564474995, -1.233742170904487, -1.2611892716650064, -1.2892298172120238, -1.3177996759231942, -1.3468384145150003, -1.3762891594730966, -1.4060984340920717, -1.436215980420136, -1.4665945734130583, -1.4971898329068665, -1.5279600376088565, -1.5588659441565704, -1.589870613373238, -1.6209392451227491, -1.6520390226054982, -1.683138966509206, -1.714209799110293, -1.7452238181894981, -1.7761547804616689, -1.806977794108795, -1.8376692199350133, -1.868206580622558, -1.8985684775506189, -1.9287345146386108, -1.9586852286866696, -1.9884020257055883, -2.0178671227530693, -2.0470634948210464, -2.075974826348273, -2.104585466962325, -2.132880391084789, -2.1608451610620945, -2.188465893511903, -2.2157292286008956, -2.242622301994095, -2.2691327192384714, -2.2952485323644938, -2.32095821850859, -2.3462506603771542, -2.3711151283889533, -2.395541264347596, -2.419519066509177, -2.4430388759225425, -2.4660913639307345, -2.4886675207323337, -2.5107586449106307, -2.532356333846872, -2.5534524749414365, -2.5740392375736265, -2.594109065737014, -2.6136546712928976, -2.6326690277895723, -2.6511453647997363, -2.669077162732584, -2.6864581480809617, -2.70328228906743, -2.7195437916562586, -2.735237095901211, -2.7503568726016447, -2.764898020241791, -2.7788556621902796, -2.792225144138936, -2.8050020317617124, -2.8171821085762496, -2.8287613739920903, -2.8397360415309714, -2.850102537205871, -2.8598574980466918, -2.8689977707615273, -2.8775204105234584, -2.8854226798737646, -2.892702047733285, -2.8993561885144534, -2.9053829813273038, -2.910780509273409, -2.915547058822387, -2.919681119266224, -2.9231813822472392, -2.9260467413560884, -2.928276291796702, -2.929869330115608, -2.930825353993527], [-2.942034263469994, -2.9417149445018995, -2.940757088598037, -2.939160998789659, -2.936927180229092, -2.934056340340877, -2.9305493890349976, -2.926407438983799, -2.921631805964707, -2.916224009271363, -2.9101857721962783, -2.9035190225886787, -2.8962258934917373, -2.8883087238640144, -2.879770059390526, -2.8706126533895255, -2.8608394678217954, -2.850453674409993, -2.8394586558763946, -2.827858007308247, -2.8156555376608927, -2.8028552714098, -2.789461450363768, -2.7754785356527143, -2.7609112099047888, -2.745764379628903, -2.7300431778203453, -2.713752966808768, -2.696899341369693, -2.67948813212265, -2.6615254092412517, -2.6430174865029, -2.6239709257084396, -2.6043925415049642, -2.5842894066481272, -2.5636688577438123, -2.5425385015128383, -2.5209062216265714, -2.4987801861659933, -2.4761688557618506, -2.453080992479168, -2.429525669515589, -2.405512281789872, -2.381050557504378, -2.3561505707737056, -2.3308227554207415, -2.305077920051483, -2.2789272645310037, -2.252382397995121, -2.2254553585456107, -2.1981586347914326, -2.170505189414364, -2.1425084849548313, -2.1141825120326216, -2.085541820237623, -2.0566015519477645, -2.0273774793549633, -1.9978860450049614, -1.9681444061833753, -1.9381704835078117, -1.907983014114028, -1.8776016098523785, -1.8470468209381896, -1.81634020552513, -1.7855044056924843, -1.7545632303532632, -1.7235417455975248, -1.6924663729803024, -1.6613649962413861, -1.630267076898636, -1.5992037790796783, -1.5682081038389066, -1.5373150330354235, -1.5065616826079677, -1.4759874647568814, -1.4456342581093697, -1.415546584377902, -1.3857717892946584, -1.3563602246873456, -1.3273654274227988, -1.2988442895563501, -1.2708572123658886, -1.2434682350126516, -1.216745126372598, -1.1907594261753374, -1.165586419076664, -1.1413050228500718, -1.117997569774076, -1.09574945887912, -1.0746486564691033, -1.0547850238074798, -1.0362494546629273, -1.0191328121163223, -1.0035246640507993, -0.9895118301683672, -0.9771767697860372, -0.966595857992562, -0.9578376162035364, -0.9509609793133736, -0.9460136927356172, -0.94303093601274, -0.9420342634699939, -0.9430309360127421, -0.9460136927356213, -0.9509609793133798, -0.9578376162035444, -0.966595857992572, -0.9771767697860488, -0.9895118301683807, -1.0035246640508146, -1.0191328121163392, -1.0362494546629457, -1.0547850238074998, -1.0746486564691242, -1.0957494588791423, -1.1179975697740991, -1.1413050228500963, -1.1655864190766891, -1.1907594261753636, -1.2167451263726248, -1.2434682350126793, -1.2708572123659172, -1.2988442895563792, -1.3273654274228284, -1.3563602246873758, -1.3857717892946888, -1.4155465843779327, -1.4456342581094004, -1.4759874647569127, -1.5065616826079995, -1.5373150330354552, -1.5682081038389384, -1.5992037790797102, -1.6302670768986678, -1.6613649962414183, -1.6924663729803344, -1.7235417455975568, -1.754563230353295, -1.785504405692516, -1.8163402055251616, -1.8470468209382207, -1.8776016098524098, -1.9079830141140588, -1.938170483507843, -1.9681444061834061, -1.9978860450049916, -2.027377479354994, -2.0566015519477943, -2.0855418202376526, -2.114182512032651, -2.14250848495486, -2.170505189414393, -2.198158634791461, -2.225455358545639, -2.252382397995149, -2.2789272645310312, -2.3050779200515095, -2.3308227554207672, -2.356150570773731, -2.3810505575044036, -2.405512281789897, -2.4295256695156136, -2.453080992479192, -2.4761688557618746, -2.4987801861660155, -2.5209062216265936, -2.54253850151286, -2.5636688577438336, -2.5842894066481477, -2.6043925415049847, -2.62397092570846, -2.6430174865029192, -2.661525409241271, -2.6794881321226685, -2.696899341369711, -2.713752966808785, -2.7300431778203618, -2.7457643796289193, -2.7609112099048034, -2.7754785356527285, -2.7894614503637816, -2.802855271409814, -2.8156555376609056, -2.8278580073082593, -2.839458655876406, -2.8504536744100046, -2.8608394678218056, -2.870612653389535, -2.8797700593905358, -2.8883087238640237, -2.896225893491745, -2.9035190225886853, -2.910185772196285, -2.916224009271369, -2.921631805964713, -2.9264074389838033, -2.9305493890350016, -2.9340563403408795, -2.9369271802290946, -2.939160998789661, -2.940757088598038, -2.941714944501901], [-2.9520131075327343, -2.951693232778823, -2.950733710036222, -2.949134843892949, -2.9468971420980243, -2.944021315715746, -2.9405082793433315, -2.9363591513935257, -2.9315752544443257, -2.9261581156584557, -2.920109467275725, -2.9134312471819763, -2.9061255995588713, -2.8981948756193665, -2.8896416344343616, -2.8804686438566645, -2.870678881549128, -2.860275536124569, -2.8492620084059, -2.837641912815762, -2.825419078905906, -2.8125975530375618, -2.7991816002251557, -2.785175706156916, -2.770584579407189, -2.7554131538567366, -2.7396665913387577, -2.723350284530114, -2.7064698601090216, -2.6890311822024917, -2.6710403561489935, -2.65250373260419, -2.6334279120202617, -2.6138197495321798, -2.5936863602874984, -2.5730351252596897, -2.5518736975888903, -2.5302100094981426, -2.5080522798378317, -2.4854090223161576, -2.46228905447905, -2.438701507509174, -2.414655836920432, -2.390161834231907, -2.365229639713417, -2.3398697563039224, -2.3140930648140303, -2.2879108405347646, -2.261334771386801, -2.234376977757544, -2.207050034187804, -2.1793669930855497, -2.151341410661312, -2.1229873752983424, -2.0943195385906725, -2.0653531493037085, -2.036104090535001, -2.006588920377136, -1.9768249164102283, -1.9468301243778903, -1.9166234114274059, -1.8862245243214846, -1.8556541530545472, -1.8249340003297105, -1.794086857371893, -1.763136686565494, -1.7321087114090157, -1.7010295142700311, -1.6699271423971416, -1.6388312225948576, -1.607773084884801, -1.5767858953525082, -1.5459047982013068, -1.515167066788547, -1.4846122630872014, -1.454282404576714, -1.424222136997045, -1.394478910672459, -1.365103157198198, -1.3361484621553466, -1.30767172815133, -1.2797333208577752, -1.252397188830473, -1.2257309457682581, -1.1998059015551141, -1.1746970260399152, -1.1504828272154797, -1.1272451235213614, -1.1050686887668222, -1.084040748103027, -1.0642503050987842, -1.0457872838612383, -1.0287414768178365, -1.0132012986020473, -0.9992523595101913, -0.9869758877867836, -0.976447047499516, -0.9677332162603991, -0.9608923022356392, -0.9559711901595545, -0.9530044089755835, -0.9520131075327342, -0.9530044089755856, -0.9559711901595583, -0.9608923022356451, -0.9677332162604071, -0.976447047499526, -0.9869758877867952, -0.9992523595102046, -1.0132012986020624, -1.0287414768178533, -1.0457872838612567, -1.064250305098804, -1.0840407481030478, -1.1050686887668444, -1.1272451235213847, -1.150482827215504, -1.1746970260399403, -1.1998059015551406, -1.2257309457682852, -1.2523971888305008, -1.2797333208578032, -1.307671728151359, -1.336148462155376, -1.3651031571982275, -1.3944789106724895, -1.424222136997076, -1.454282404576745, -1.4846122630872332, -1.5151670667885784, -1.5459047982013383, -1.57678589535254, -1.6077730848848328, -1.6388312225948896, -1.6699271423971738, -1.7010295142700629, -1.7321087114090479, -1.7631366865655258, -1.7940868573719249, -1.824934000329742, -1.8556541530545783, -1.8862245243215159, -1.9166234114274372, -1.9468301243779214, -1.9768249164102587, -2.0065889203771663, -2.0361040905350314, -2.0653531493037387, -2.0943195385907023, -2.122987375298372, -2.151341410661341, -2.1793669930855786, -2.2070500341878323, -2.234376977757572, -2.2613347713868284, -2.2879108405347917, -2.3140930648140574, -2.3398697563039486, -2.365229639713443, -2.390161834231933, -2.4146558369204563, -2.4387015075091982, -2.462289054479074, -2.4854090223161807, -2.508052279837855, -2.530210009498165, -2.5518736975889125, -2.573035125259711, -2.5936863602875193, -2.6138197495322, -2.6334279120202813, -2.6525037326042096, -2.6710403561490126, -2.68903118220251, -2.706469860109039, -2.7233502845301314, -2.739666591338774, -2.755413153856753, -2.770584579407205, -2.7851757061569304, -2.7991816002251704, -2.812597553037575, -2.825419078905919, -2.837641912815774, -2.8492620084059115, -2.8602755361245804, -2.8706788815491384, -2.8804686438566742, -2.8896416344343705, -2.898194875619375, -2.9061255995588793, -2.913431247181984, -2.9201094672757315, -2.9261581156584615, -2.9315752544443314, -2.93635915139353, -2.940508279343336, -2.9440213157157498, -2.9468971420980266, -2.949134843892951, -2.950733710036223, -2.9516932327788243], [-2.9610709403987285, -2.9607505643996306, -2.9597895383924087, -2.958188168378462, -2.9559469644643337, -2.953066641018828, -2.9495481168946363, -2.945392515716104, -2.9406011662352896, -2.9351756027589877, -2.929117565649867, -2.9224290019054666, -2.9151120658193315, -2.9071691197291902, -2.8986027348576964, -2.889415692251924, -2.8796109838285466, -2.869191813532357, -2.858161598616633, -2.8465239710547103, -2.8342827790930847, -2.82144208895738, -2.808006186723624, -2.7939795803684686, -2.7793670020132977, -2.764173410378581, -2.748403993466359, -2.7320641714904506, -2.715159600075772, -2.69769617375021, -2.679680029754638, -2.661117552199107, -2.6420153765958485, -2.6223803948026516, -2.6022197604133015, -2.581540894635306, -2.560351492698928, -2.538659530845764, -2.5164732739497437, -2.4938012838285224, -2.4706524283088194, -2.447035891115456, -2.4229611826605946, -2.3984381518171722, -2.373476998768702, -2.348088289036641, -2.322282968796425, -2.2960723816041284, -2.2694682866676077, -2.2424828788090125, -2.215128810279758, -2.1874192146045597, -2.1593677326479357, -2.130988541114812, -2.1022963837164794, -2.0733066052542024, -2.0440351888951485, -2.01449879693897, -1.984714815398039, -1.9547014027397178, -1.9244775431647503, -1.8940631048210563, -1.8634789033761185, -1.8327467713924108, -1.8018896339672457, -1.7709315911087642, -1.7398980073205996, -1.708815608855207, -1.6777125890650466, -1.6466187222255637, -1.6155654861163908, -1.5845861935176755, -1.5537161325950544, -1.5229927158949355, -1.4924556373342752, -1.462147036125584, -1.4321116660053816, -1.4023970674071868, -1.3730537393112845, -1.344135306386421, -1.3156986756900244, -1.2878041755985468, -1.2605156677977452, -1.2339006210979417, -1.208030133610739, -1.182978887540547, -1.1588250186809979, -1.1356498809176023, -1.113537684968805, -1.0925749906835844, -1.0728500339630438, -1.0544518733228574, -1.037469347750141, -1.0219898471552187, -1.0080979093898845, -0.9958736730509532, -0.9853912320771245, -0.9767169548168967, -0.9699078446009081, -0.9650100284326358, -0.9620574629199502, -0.9610709403987284, -0.9620574629199521, -0.9650100284326398, -0.9699078446009142, -0.9767169548169046, -0.9853912320771345, -0.9958736730509649, -1.0080979093898979, -1.0219898471552338, -1.0374693477501575, -1.0544518733228756, -1.0728500339630636, -1.0925749906836055, -1.1135376849688268, -1.1356498809176256, -1.1588250186810223, -1.182978887540572, -1.2080301336107653, -1.2339006210979686, -1.260515667797773, -1.2878041755985752, -1.3156986756900533, -1.34413530638645, -1.3730537393113145, -1.402397067407217, -1.4321116660054123, -1.462147036125615, -1.4924556373343065, -1.5229927158949672, -1.5537161325950866, -1.5845861935177072, -1.6155654861164226, -1.646618722225596, -1.6777125890650786, -1.708815608855239, -1.7398980073206314, -1.7709315911087957, -1.8018896339672774, -1.8327467713924424, -1.8634789033761496, -1.8940631048210874, -1.9244775431647811, -1.9547014027397487, -1.9847148153980696, -2.0144987969390007, -2.044035188895178, -2.0733066052542326, -2.1022963837165096, -2.1309885411148413, -2.1593677326479646, -2.187419214604588, -2.215128810279786, -2.24248287880904, -2.2694682866676357, -2.296072381604156, -2.3222829687964515, -2.348088289036667, -2.3734769987687283, -2.3984381518171976, -2.422961182660619, -2.44703589111548, -2.4706524283088434, -2.493801283828546, -2.516473273949767, -2.538659530845787, -2.5603514926989503, -2.5815408946353275, -2.6022197604133224, -2.622380394802672, -2.642015376595869, -2.661117552199126, -2.6796800297546572, -2.697696173750228, -2.71515960007579, -2.732064171490467, -2.748403993466376, -2.7641734103785964, -2.7793670020133123, -2.7939795803684833, -2.8080061867236386, -2.8214420889573932, -2.8342827790930976, -2.846523971054722, -2.858161598616645, -2.8691918135323675, -2.879610983828556, -2.8894156922519336, -2.8986027348577053, -2.907169119729199, -2.915112065819339, -2.9224290019054737, -2.929117565649874, -2.9351756027589935, -2.940601166235294, -2.945392515716108, -2.9495481168946402, -2.9530666410188315, -2.955946964464336, -2.9581881683784643, -2.95978953839241, -2.960750564399632], [-2.9691989991996697, -2.968878176011151, -2.9679158088583253, -2.966312205011093, -2.964067876691841, -2.9611835412351186, -2.9576601213128226, -2.9534987452265793, -2.9487007472694797, -2.9432676681598444, -2.9372012555502254, -2.9305034646153856, -2.9231764587235975, -2.9152226101961696, -2.9066445011607946, -2.8974449245049385, -2.8876268849362527, -2.877193600157719, -2.8661485021661055, -2.85449523868314, -2.8422376747298137, -2.8293798943552098, -2.8159262025323915, -2.8018811272350694, -2.787249421710083, -2.772036066962148, -2.7562462744688774, -2.7398854891457427, -2.7229593925825237, -2.705473906574773, -2.687435196976026, -2.668849677898922, -2.6497240162960085, -2.630065136953908, -2.6098802279377145, -2.5891767465259576, -2.567962425680294, -2.54624528109833, -2.524033618902551, -2.501336044023473, -2.478161469340674, -2.454519125651541, -2.430418572544317, -2.4058697102594464, -2.380882792631411, -2.355468441212158, -2.3296376606871085, -2.303401855705463, -2.2767728492583386, -2.2497629027511588, -2.222384737930753, -2.1946515608429404, -2.166577088012928, -2.138175575058785, -2.1094618479675167, -2.0804513372838582, -2.0511601154837877, -2.021604937827753, -1.9918032870125573, -1.961773421965327, -1.9315344311476033, -1.9011062907615588, -1.8705099282727433, -1.83976729168327, -1.8089014250042454, -1.777936550384204, -1.7468981573483793, -1.7158130995879732, -1.684709699704234, -1.6536178622529625, -1.6225691953432146, -1.5915971409098282, -1.5607371135911865, -1.5300266478870637, -1.4995055529295347, -1.469216073753057, -1.4392030573754835, -1.4095141212753872, -1.3801998209468997, -1.3513138121063613, -1.322913001794308, -1.2950576810491445, -1.2678116300275877, -1.2412421844382002, -1.2154202499997233, -1.1904202494460876, -1.166319984549053, -1.1432003939684647, -1.121145186806316, -1.1002403319557543, -1.0805733851873092, -1.0622326399109212, -1.0453060941479568, -1.0298802357314942, -1.0160386601123834, -1.003860549924026, -0.9934190616332043, -0.9847796805689468, -0.9779986192731485, -0.9731213431154347, -0.9701813092936102, -0.9691989991996697, -0.9701813092936123, -0.9731213431154386, -0.9779986192731545, -0.9847796805689547, -0.9934190616332139, -1.0038605499240378, -1.0160386601123967, -1.0298802357315093, -1.0453060941479735, -1.0622326399109394, -1.0805733851873287, -1.1002403319557748, -1.1211451868063382, -1.1432003939684878, -1.1663199845490773, -1.1904202494461127, -1.2154202499997493, -1.2412421844382273, -1.2678116300276152, -1.2950576810491727, -1.3229130017943367, -1.3513138121063906, -1.38019982094693, -1.4095141212754176, -1.4392030573755141, -1.469216073753088, -1.4995055529295658, -1.530026647887095, -1.5607371135912183, -1.59159714090986, -1.6225691953432468, -1.653617862252995, -1.684709699704266, -1.7158130995880054, -1.7468981573484113, -1.7779365503842357, -1.8089014250042774, -1.8397672916833017, -1.870509928272775, -1.9011062907615903, -1.9315344311476343, -1.9617734219653582, -1.991803287012588, -2.0216049378277834, -2.051160115483818, -2.0804513372838884, -2.1094618479675464, -2.1381755750588143, -2.166577088012957, -2.1946515608429693, -2.2223847379307813, -2.2497629027511867, -2.276772849258366, -2.3034018557054896, -2.329637660687135, -2.3554684412121842, -2.3808827926314367, -2.4058697102594717, -2.4304185725443412, -2.4545191256515655, -2.4781614693406975, -2.5013360440234966, -2.5240336189025743, -2.546245281098353, -2.5679624256803164, -2.589176746525979, -2.609880227937736, -2.630065136953928, -2.649724016296029, -2.668849677898942, -2.6874351969760446, -2.7054739065747913, -2.7229593925825415, -2.739885489145759, -2.7562462744688943, -2.7720360669621646, -2.7872494217100985, -2.8018811272350845, -2.815926202532406, -2.829379894355223, -2.842237674729826, -2.8544952386831524, -2.866148502166118, -2.8771936001577307, -2.887626884936263, -2.8974449245049487, -2.9066445011608026, -2.915222610196178, -2.923176458723605, -2.930503464615393, -2.9372012555502316, -2.94326766815985, -2.948700747269485, -2.9534987452265846, -2.9576601213128266, -2.9611835412351217, -2.964067876691843, -2.966312205011094, -2.967915808858327, -2.968878176011151], [-2.97638942056361, -2.976068203808789, -2.975104656331007, -2.973499086522444, -2.9712520084774585, -2.9683641421544857, -2.964836413604386, -2.960669955266891, -2.9558661063373415, -2.950426413206417, -2.9443526299760543, -2.937646719055373, -2.930310851840917, -2.9223474094862083, -2.913758983766206, -2.9045483780429446, -2.8947186083393808, -2.8842729045291957, -2.873214711651187, -2.8615476913577313, -2.8492757235077564, -2.8364029079157174, -2.8229335662691577, -2.8088722442286707, -2.7942237137253567, -2.7789929754723337, -2.7631852617083728, -2.7468060391934546, -2.729861012477856, -2.7123561274684342, -2.694297575317921, -2.675691796665519, -2.656545486259684, -2.636865597996893, -2.616659350413385, -2.595934232670323, -2.5746980110766837, -2.552958736198356, -2.5307247506065695, -2.5080046973238455, -2.484807529031228, -2.461142518106697, -2.437019267571392, -2.4124477230276717, -2.3874381856811526, -2.362001326547785, -2.336148201956795, -2.3098902704709974, -2.283239411357704, -2.2562079447562073, -2.228808653701722, -2.201054808180791, -2.172960191409505, -2.1445391285435638, -2.1158065180481143, -2.0867778659755563, -2.0574693234208783, -2.0278977274465673, -1.9980806457923723, -1.9680364257089498, -1.9377842472780327, -1.9073441816046701, -1.8767372542881415, -1.8459855145961421, -1.8151121107799266, -1.7841413719739914, -1.753098897119558, -1.722011651332729, -1.690908070100784, -1.659818171627474, -1.6287736775526298, -1.5978081421332928, -1.5669570897813099, -1.5362581605917824, -1.5057512631513361, -1.4754787334655517, -1.4454854982693206, -1.4158192402585714, -1.3865305618821668, -1.3576731432352853, -1.3293038882809116, -1.301483052083598, -1.2742743399742174, -1.24774496760463, -1.2219656687608755, -1.1970106356942753, -1.1729573747752273, -1.1498864587224376, -1.1278811558407866, -1.107026917023639, -1.087410703209558, -1.0691201400144876, -1.052242492814954, -1.0368634648967192, -1.023065833371175, -1.010927951931785, -1.0005221651732557, -0.9919131945640142, -0.9851565692222263, -0.9802971831588023, -0.9773680625587519, -0.9763894205636101, -0.977368062558754, -0.9802971831588063, -0.9851565692222322, -0.9919131945640222, -1.0005221651732656, -1.0109279519317966, -1.0230658333711884, -1.0368634648967343, -1.0522424928149705, -1.0691201400145056, -1.0874107032095774, -1.10702691702366, -1.1278811558408086, -1.1498864587224606, -1.1729573747752517, -1.1970106356943002, -1.2219656687609015, -1.2477449676046568, -1.2742743399742449, -1.3014830520836262, -1.3293038882809405, -1.357673143235315, -1.3865305618821966, -1.4158192402586016, -1.4454854982693512, -1.4754787334655828, -1.5057512631513672, -1.536258160591814, -1.5669570897813416, -1.5978081421333248, -1.6287736775526618, -1.6598181716275058, -1.690908070100816, -1.7220116513327612, -1.7530988971195895, -1.7841413719740231, -1.8151121107799584, -1.8459855145961737, -1.876737254288173, -1.9073441816047016, -1.9377842472780642, -1.9680364257089809, -1.9980806457924034, -2.027897727446598, -2.057469323420909, -2.0867778659755865, -2.115806518048144, -2.144539128543593, -2.1729601914095342, -2.2010548081808197, -2.2288086537017504, -2.2562079447562358, -2.283239411357731, -2.309890270471024, -2.3361482019568216, -2.362001326547811, -2.387438185681178, -2.4124477230276975, -2.4370192675714173, -2.4611425181067212, -2.4848075290312517, -2.508004697323869, -2.530724750606592, -2.5529587361983785, -2.574698011076706, -2.5959342326703445, -2.6166593504134057, -2.6368655979969136, -2.656545486259704, -2.675691796665539, -2.69429757531794, -2.7123561274684524, -2.729861012477875, -2.7468060391934714, -2.7631852617083896, -2.7789929754723497, -2.794223713725372, -2.808872244228685, -2.8229335662691715, -2.8364029079157307, -2.8492757235077693, -2.8615476913577433, -2.8732147116511983, -2.884272904529206, -2.894718608339391, -2.904548378042955, -2.913758983766215, -2.9223474094862167, -2.9303108518409244, -2.93764671905538, -2.944352629976061, -2.950426413206422, -2.9558661063373473, -2.9606699552668956, -2.9648364136043903, -2.9683641421544884, -2.971252008477461, -2.973499086522447, -2.975104656331008, -2.9760682038087904], [-2.9826352482222664, -2.9823136911434576, -2.9813491230185547, -2.9797418532146627, -2.977492397452301, -2.974601477969253, -2.9710700237516376, -2.966899170833888, -2.962090262669821, -2.9566448505775313, -2.950564694261317, -2.9438517624144684, -2.936508233407278, -2.9285364960652696, -2.9199391505432835, -2.9107190093017272, -2.9008790981920507, -2.8904226576592467, -2.8793531440700426, -2.867674231176321, -2.855389811724257, -2.842503999220725, -2.829021129869625, -2.8149457646919798, -2.8002826918450077, -2.7850369291567674, -2.769213726894537, -2.7528185707868116, -2.7358571853206017, -2.7183355373377824, -2.7002598399564284, -2.6816365568454863, -2.6624724068837846, -2.642774369237288, -2.622549688891664, -2.601805882680726, -2.580550745855159, -2.5587923592400923, -2.5365390970347472, -2.5137996353124192, -2.4905829612846317, -2.466898383399416, -2.4427555423503686, -2.4181644230805293, -2.3931353678731813, -2.3676790906305643, -2.34180669245118, -2.315529678627016, -2.288859977193611, -2.2618099591785374, -2.2343924607076886, -2.206620807143654, -2.1785088394467103, -2.150070942966286, -2.121322078889516, -2.0922778185932995, -2.0629543811673337, -2.033368674397529, -2.003538339521928, -1.9734818000942476, -1.9432183153130336, -1.912768038196307, -1.8821520790015411, -1.8513925743074657, -1.8205127621857529, -1.7895370638947548, -1.758491172521104, -1.7274021489742675, -1.696298525699157, -1.6652104184063787, -1.634169646021051, -1.6032098589096704, -1.5723666752488727, -1.5416778251360825, -1.5111833016937235, -1.4809255179669094, -1.4509494678381243, -1.4213028884583214, -1.392036420798457, -1.3632037638364582, -1.3348618165940924, -1.307070800717396, -1.2798943545597803, -1.253399587809355, -1.2276570836665925, -1.202740833537791, -1.1787280873366333, -1.155699101025556, -1.1337367623044001, -1.1129260757651345, -1.0933534908326517, -1.0751060598682067, -1.0582704203274735, -1.0429316040773475, -1.0291716888313198, -1.017068320689994, -1.006693151983196, -0.9981102534792825, -0.9913745725948272, -0.9865305173501867, -0.9836107475038185, -0.9826352482222663, -0.9836107475038204, -0.9865305173501907, -0.9913745725948331, -0.9981102534792903, -1.0066931519832059, -1.0170683206900053, -1.0291716888313331, -1.0429316040773622, -1.05827042032749, -1.0751060598682247, -1.0933534908326712, -1.1129260757651553, -1.1337367623044219, -1.155699101025579, -1.1787280873366575, -1.2027408335378162, -1.227657083666619, -1.2533995878093818, -1.2798943545598076, -1.3070708007174239, -1.3348618165941213, -1.3632037638364876, -1.3920364207984868, -1.4213028884583514, -1.4509494678381551, -1.4809255179669405, -1.511183301693755, -1.5416778251361143, -1.5723666752489047, -1.6032098589097024, -1.6341696460210826, -1.665210418406411, -1.696298525699189, -1.7274021489742997, -1.7584911725211356, -1.7895370638947865, -1.8205127621857844, -1.851392574307497, -1.8821520790015727, -1.9127680381963386, -1.9432183153130649, -1.9734818000942786, -2.003538339521959, -2.0333686743975594, -2.062954381167364, -2.0922778185933297, -2.1213220788895457, -2.1500709429663156, -2.1785088394467396, -2.206620807143683, -2.2343924607077166, -2.2618099591785654, -2.2888599771936384, -2.3155296786270436, -2.341806692451207, -2.367679090630591, -2.3931353678732075, -2.4181644230805546, -2.4427555423503935, -2.4668983833994402, -2.4905829612846557, -2.5137996353124428, -2.5365390970347708, -2.5587923592401154, -2.5805507458551813, -2.6018058826807478, -2.622549688891685, -2.642774369237309, -2.6624724068838055, -2.6816365568455054, -2.700259839956448, -2.718335537337801, -2.7358571853206195, -2.752818570786829, -2.7692137268945536, -2.7850369291567834, -2.8002826918450237, -2.8149457646919944, -2.829021129869639, -2.8425039992207384, -2.8553898117242698, -2.8676742311763332, -2.879353144070054, -2.890422657659257, -2.900879098192061, -2.910719009301737, -2.9199391505432923, -2.9285364960652784, -2.9365082334072854, -2.943851762414475, -2.9505646942613235, -2.956644850577537, -2.9620902626698267, -2.966899170833892, -2.971070023751642, -2.9746014779692564, -2.9774923974523033, -2.979741853214665, -2.981349123018556, -2.9823136911434585], [-2.987930439740759, -2.987608595250959, -2.9866431651684984, -2.9850344596870553, -2.9827829959058634, -2.979889497995208, -2.9763548974298066, -2.9721803332917665, -2.9673671526453345, -2.9619169109861416, -2.955831372768227, -2.9491125120126225, -2.941762513001938, -2.933783771065926, -2.925178893463706, -2.9159507003689975, -2.90610222596542, -2.8956367196597297, -2.8845576474216865, -2.872868693260103, -2.86057376084566, -2.847676975292037, -2.834182685108086, -2.8200954643349525, -2.805420114883397, -2.790161669087978, -2.774325392496329, -2.757916786913467, -2.7409415937229045, -2.723405797508371, -2.7053156300021706, -2.68667757438859, -2.6674983699934605, -2.647785017393841, -2.6275447839849813, -2.606785210045231, -2.5855141153433387, -2.5637396063368314, -2.541470084014746, -2.518714252443037, -2.4954811280765736, -2.47178004990769, -2.4476206905279967, -2.4230130681874558, -2.397967559942817, -2.372494915996318, -2.346606275335214, -2.320313182793274, -2.29362760766691, -2.2665619640311925, -2.239129132914632, -2.211342486506484, -2.1832159145862726, -2.154763853382518, -2.1260013170860126, -2.0969439322626404, -2.067607975431352, -2.038010414094493, -2.008168951529857, -1.9781020756763201, -1.947829112467018, -1.917370283985174, -1.8867467718366517, -1.8559807861488746, -1.8250956406160155, -1.7941158340129746, -1.7630671385926175, -1.731976695758069, -1.7008731193597073, -1.6697866068986034, -1.6387490588168665, -1.6077942059112174, -1.5769577447076752, -1.5462774803687311, -1.515793476353763, -1.4855482096000185, -1.4555867294146096, -1.425956817545103, -1.3967091460046943, -1.3678974281462977, -1.339578557191526, -1.3118127249181015, -1.2846635115008627, -1.2581979356193553, -1.23248645195555, -1.2076028812215454, -1.1836242560514276, -1.160630564706183, -1.1387043738942715, -1.1179303124937052, -1.0983944000159294, -1.0801832077267528, -1.0633828468195585, -1.048077787140478, -1.0343495216267093, -1.0222751053612562, -1.0119256129941716, -1.0033645727404419, -0.9966464473305362, -0.9918152400765299, -0.9889033057272915, -0.987930439740759, -0.9889033057272933, -0.9918152400765339, -0.9966464473305423, -1.0033645727404499, -1.0119256129941814, -1.0222751053612675, -1.0343495216267224, -1.0480777871404932, -1.063382846819575, -1.0801832077267708, -1.0983944000159487, -1.1179303124937259, -1.1387043738942935, -1.1606305647062058, -1.1836242560514516, -1.2076028812215704, -1.232486451955576, -1.2581979356193822, -1.2846635115008902, -1.31181272491813, -1.3395785571915548, -1.3678974281463272, -1.396709146004724, -1.4259568175451334, -1.45558672941464, -1.4855482096000494, -1.5157934763537941, -1.5462774803687624, -1.5769577447077066, -1.6077942059112493, -1.6387490588168983, -1.6697866068986353, -1.7008731193597388, -1.731976695758101, -1.7630671385926493, -1.7941158340130066, -1.8250956406160472, -1.8559807861489066, -1.8867467718366835, -1.917370283985206, -1.9478291124670493, -1.978102075676351, -2.008168951529888, -2.0380104140945234, -2.0676079754313825, -2.0969439322626706, -2.1260013170860423, -2.1547638533825477, -2.183215914586302, -2.2113424865065126, -2.2391291329146608, -2.2665619640312205, -2.2936276076669375, -2.3203131827933006, -2.346606275335241, -2.372494915996344, -2.3979675599428427, -2.423013068187481, -2.4476206905280216, -2.4717800499077143, -2.495481128076597, -2.5187142524430612, -2.5414700840147693, -2.5637396063368545, -2.5855141153433605, -2.6067852100452527, -2.627544783985002, -2.6477850173938604, -2.667498369993481, -2.6866775743886095, -2.705315630002189, -2.72340579750839, -2.740941593722922, -2.757916786913484, -2.7743253924963454, -2.7901616690879942, -2.805420114883413, -2.820095464334967, -2.8341826851081, -2.84767697529205, -2.8605737608456727, -2.872868693260115, -2.884557647421698, -2.8956367196597412, -2.90610222596543, -2.915950700369008, -2.9251788934637153, -2.9337837710659342, -2.941762513001946, -2.949112512012629, -2.955831372768233, -2.9619169109861474, -2.96736715264534, -2.972180333291772, -2.976354897429811, -2.9798894979952117, -2.982782995905866, -2.9850344596870566, -2.9866431651684993, -2.987608595250959], [-2.9922698723632783, -2.9919477930973577, -2.9909816589122444, -2.989371780679016, -2.9871186766267956, -2.984223072509598, -2.980685901841596, -2.976508306202524, -2.971691635615422, -2.9662374489994625, -2.9601475147011156, -2.9534238111075037, -2.946068527346343, -2.9380840640775165, -2.9294730343819597, -2.920238264754224, -2.9103827962058255, -2.8999098854872556, -2.888823006437381, -2.8771258514698372, -2.864822333207003, -2.85191658627318, -2.838412969259705, -2.8243160668759884, -2.8096306923017393, -2.79436188975711, -2.778514937309035, -2.7620953499337655, -2.7451088828574113, -2.7275615351983835, -2.709459553937793, -2.690809438246311, -2.671617944198646, -2.651892089909673, -2.6316391611294407, -2.6108667173377893, -2.589582598383089, -2.5677949317138484, -2.545512140256517, -2.5227429509978716, -2.49949640433592, -2.4757818642693383, -2.4516090295021336, -2.4269879455475616, -2.4019290179233392, -2.3764430265389977, -2.3505411413858344, -2.3242349396504505, -2.2975364243843184, -2.270458044874336, -2.2430127188728806, -2.2152138568605992, -2.1870753885310243, -2.158611791703188, -2.1298381238866, -2.1007700567423604, -2.0714239137045056, -2.0418167110469407, -2.011966202703105, -1.9818909291674789, -1.9516102708296463, -1.9211445061120545, -1.8905148748008507, -1.859743646973801, -1.8288541979385347, -1.7978710895957524, -1.7668201586326002, -1.7357286119271829, -1.7046251295012753, -1.6735399752884694, -1.6425051158816242, -1.611554347277173, -1.5807234294331733, -1.5500502281894197, -1.519574863745452, -1.4893398644377, -1.4593903239797825, -1.4297740596082968, -1.4005417676880947, -1.3717471722555348, -1.3434471606999223, -1.3157018992960114, -1.2885749196134146, -1.2621331649754097, -1.2364469841873718, -1.211590057817378, -1.1876392405600265, -1.1646743018894659, -1.1427775466233605, -1.1220332975594423, -1.1025272244420972, -1.0843455076042767, -1.0675738310795801, -1.052296208995408, -1.0385936605622792, -1.026542762487529, -1.0162141221977552, -1.007670829388329, -1.0009669552651335, -0.996146176373397, -0.9932406012807955, -0.9922698723632783, -0.9932406012807976, -0.996146176373401, -1.0009669552651392, -1.007670829388337, -1.0162141221977652, -1.02654276248754, -1.0385936605622927, -1.0522962089954226, -1.0675738310795966, -1.0843455076042945, -1.1025272244421163, -1.122033297559463, -1.1427775466233827, -1.1646743018894887, -1.1876392405600504, -1.2115900578174028, -1.2364469841873977, -1.2621331649754366, -1.2885749196134422, -1.3157018992960394, -1.3434471606999507, -1.3717471722555636, -1.4005417676881247, -1.429774059608327, -1.459390323979813, -1.4893398644377311, -1.5195748637454831, -1.5500502281894515, -1.5807234294332049, -1.6115543472772043, -1.6425051158816564, -1.6735399752885014, -1.7046251295013073, -1.7357286119272148, -1.7668201586326322, -1.7978710895957843, -1.828854197938566, -1.8597436469738324, -1.8905148748008824, -1.9211445061120862, -1.9516102708296772, -1.9818909291675102, -2.0119662027031358, -2.0418167110469714, -2.0714239137045363, -2.1007700567423906, -2.1298381238866297, -2.158611791703217, -2.1870753885310537, -2.215213856860628, -2.243012718872909, -2.270458044874364, -2.2975364243843455, -2.3242349396504776, -2.3505411413858615, -2.3764430265390244, -2.401929017923365, -2.4269879455475873, -2.4516090295021584, -2.475781864269363, -2.4994964043359444, -2.522742950997895, -2.5455121402565397, -2.5677949317138715, -2.589582598383111, -2.610866717337811, -2.631639161129462, -2.651892089909693, -2.6716179441986667, -2.69080943824633, -2.709459553937811, -2.727561535198402, -2.745108882857429, -2.7620953499337824, -2.778514937309052, -2.794361889757126, -2.8096306923017558, -2.824316066876003, -2.8384129692597186, -2.8519165862731928, -2.864822333207016, -2.877125851469849, -2.8888230064373928, -2.8999098854872667, -2.9103827962058357, -2.920238264754234, -2.9294730343819686, -2.9380840640775245, -2.9460685273463505, -2.9534238111075113, -2.9601475147011223, -2.966237448999468, -2.9716916356154277, -2.9765083062025286, -2.9806859018416, -2.9842230725096006, -2.987118676626798, -2.9893717806790177, -2.990981658912246, -2.9919477930973586], [-2.99564934796902, -2.9953270863346497, -2.9943604052199713, -2.9927496160236116, -2.990495237854647, -2.9875979977004854, -2.9840588306636056, -2.97987888026886, -2.975059498843553, -2.9696022479730426, -2.9635088990351424, -2.9567814338171656, -2.949422045220048, -2.941433138054585, -2.932817329935496, -2.9235774522796887, -2.913716551415862, -2.903237889813341, -2.892144947438885, -2.880441423251118, -2.86813123684318, -2.8552185302452617, -2.8417076698997823, -2.827603248823229, -2.8129100889699608, -2.7976332438147544, -2.781778001172396, -2.7653498862743566, -2.7483546651244355, -2.730798348157272, -2.7126871942258606, -2.6940277149466088, -2.6748266794331395, -2.655091119452936, -2.634828335044102, -2.614045900633005, -2.5927516716973904, -2.570953792023735, -2.548660701612219, -2.525881145287752, -2.50262418208099, -2.478899195449414, -2.4547159044151443, -2.4300843757035224, -2.4050150369744703, -2.3795186912474153, -2.3536065326301627, -2.327290163472566, -2.3005816130772683, -2.273493358112243, -2.2460383448833445, -2.218230013639697, -2.1900823251005432, -2.16160978940906, -2.132827497736777, -2.103751156781359, -2.0743971264207044, -2.0447824608072556, -2.0149249532079123, -1.9848431849165384, -1.954556578587209, -1.9240854563562768, -1.8934511031389545, -1.862675835500047, -1.8317830765068959, -1.8007974369730422, -1.769744803490626, -1.7386524336241043, -1.7075490585925923, -1.67646499369685, -1.6454322566419592, -1.6144846937587625, -1.5836581139247867, -1.5529904297152166, -1.5225218049606726, -1.4922948074330395, -1.4623545648032277, -1.4327489212940667, -1.4035285915657822, -1.3747473073008933, -1.3464619506849782, -1.318732667504192, -1.291622950909974, -1.2651996850703229, -1.2395331360034292, -1.2146968749871612, -1.1907676182278923, -1.1678249651931367, -1.1459510174753014, -1.125229860636624, -1.1057468936119312, -1.0875879943424585, -1.0708385167390009, -1.055582123019843, -1.0418994668517394, -1.029866756059681, -1.0195542380052116, -1.0110246646185324, -1.0043318056742327, -0.9995190862355928, -0.99661842546098, -0.9956493479690199, -0.9966184254609819, -0.9995190862355966, -1.0043318056742387, -1.0110246646185401, -1.0195542380052218, -1.0298667560596924, -1.0418994668517525, -1.0555821230198579, -1.0708385167390173, -1.0875879943424764, -1.1057468936119508, -1.1252298606366447, -1.1459510174753231, -1.1678249651931598, -1.1907676182279163, -1.2146968749871863, -1.2395331360034552, -1.2651996850703497, -1.2916229509100017, -1.3187326675042201, -1.346461950685007, -1.3747473073009226, -1.403528591565812, -1.4327489212940974, -1.4623545648032583, -1.4922948074330704, -1.5225218049607039, -1.552990429715248, -1.5836581139248185, -1.6144846937587944, -1.6454322566419912, -1.676464993696882, -1.7075490585926245, -1.738652433624136, -1.769744803490658, -1.8007974369730737, -1.8317830765069276, -1.8626758355000785, -1.8934511031389858, -1.9240854563563086, -1.9545565785872399, -1.984843184916569, -2.0149249532079434, -2.0447824608072858, -2.0743971264207346, -2.1037511567813887, -2.132827497736807, -2.161609789409089, -2.190082325100572, -2.218230013639726, -2.246038344883373, -2.273493358112271, -2.300581613077296, -2.3272901634725933, -2.3536065326301903, -2.379518691247441, -2.4050150369744965, -2.4300843757035477, -2.454715904415169, -2.4788991954494386, -2.5026241820810142, -2.5258811452877756, -2.5486607016122425, -2.5709537920237575, -2.5927516716974126, -2.614045900633026, -2.634828335044123, -2.655091119452957, -2.67482667943316, -2.6940277149466283, -2.7126871942258792, -2.7307983481572906, -2.748354665124453, -2.765349886274374, -2.7817780011724125, -2.797633243814771, -2.8129100889699763, -2.827603248823244, -2.841707669899797, -2.8552185302452755, -2.8681312368431926, -2.8804414232511295, -2.8921449474388967, -2.9032378898133517, -2.913716551415872, -2.923577452279698, -2.932817329935505, -2.941433138054594, -2.949422045220056, -2.9567814338171727, -2.963508899035149, -2.969602247973049, -2.9750594988435584, -2.9798788802688647, -2.9840588306636096, -2.9875979977004894, -2.9904952378546494, -2.9927496160236142, -2.994360405219973, -2.995327086334651], [-2.9980655971335954, -2.997743205361963, -2.996776133961177, -2.9951646947070567, -2.992909407337824, -2.9900109997227386, -2.986470408099886, -2.9822887773848334, -2.977467461552377, -2.9720080240941265, -2.965912238555217, -2.9591820891539893, -2.951819771489098, -2.943827693339079, -2.935208475560109, -2.92596495308835, -2.916100176054008, -2.9056174110150397, -2.894520142319258, -2.8828120736044935, -2.8704971294474397, -2.8575794571728688, -2.8440634288359874, -2.82995364339199, -2.815254929068126, -2.7999723459550885, -2.7841111888360657, -2.767676990273505, -2.7506755239755245, -2.7331128084658904, -2.7149951110837334, -2.6963289523415876, -2.677121110672966, -2.6573786276036344, -2.637108813383865, -2.6163192531225006, -2.5950178134674244, -2.573212649881254, -2.550912214565665, -2.528125265092798, -2.5048608738077216, -2.4811284380720133, -2.456937691425164, -2.4322987157477995, -2.4072219545187403, -2.3817182272666186, -2.3557987453263856, -2.3294751290214637, -2.3027594264036977, -2.2756641336956465, -2.248202217593224, -2.2203871396012245, -2.192232882589995, -2.163753979778318, -2.1349655463655686, -2.1058833140552267, -2.076523668731843, -2.0469036915743186, -2.017041203909629, -1.986954816132462, -1.9566639810370938, -1.926189051927359, -1.8955513458878055, -1.864773212612541, -1.833878109196109, -1.8028906812905625, -1.7718368510215954, -1.7407439120303565, -1.7096406319612993, -1.67855736264411, -1.6475261581116478, -1.6165809004466916, -1.5857574332467457, -1.555093702224913, -1.524629902110084, -1.4944086285535976, -1.4644750331720822, -1.4348769791362739, -1.4056651938317397, -1.3768934140503784, -1.3486185179068382, -1.3209006362068387, -1.2938032343358041, -1.2673931539209635, -1.241740601616894, -1.2169190704871937, -1.1930051777743136, -1.1700784016029575, -1.1482206986583867, -1.1275159854936365, -1.1080494682674913, -1.0899068098172549, -1.0731731293774398, -1.0579318391533965, -1.0442633332556117, -1.0322435577136568, -1.0219425044662152, -1.0134226859343587, -1.0067376582198766, -1.0019306681693896, -0.9990335007415136, -0.9980655971335952, -0.9990335007415155, -1.0019306681693936, -1.0067376582198824, -1.0134226859343665, -1.0219425044662247, -1.0322435577136684, -1.0442633332556248, -1.0579318391534116, -1.0731731293774562, -1.0899068098172728, -1.1080494682675108, -1.1275159854936576, -1.1482206986584085, -1.1700784016029806, -1.1930051777743373, -1.216919070487219, -1.24174060161692, -1.2673931539209902, -1.2938032343358317, -1.3209006362068667, -1.348618517906867, -1.3768934140504083, -1.4056651938317695, -1.4348769791363043, -1.4644750331721126, -1.4944086285536282, -1.5246299021101155, -1.5550937022249443, -1.585757433246777, -1.6165809004467233, -1.64752615811168, -1.6785573626441417, -1.7096406319613315, -1.7407439120303887, -1.7718368510216274, -1.8028906812905945, -1.8338781091961411, -1.8647732126125722, -1.8955513458878372, -1.9261890519273905, -1.9566639810371251, -1.9869548161324928, -2.0170412039096592, -2.0469036915743493, -2.0765236687318733, -2.105883314055257, -2.1349655463655983, -2.1637539797783476, -2.1922328825900244, -2.220387139601253, -2.2482022175932523, -2.275664133695675, -2.302759426403725, -2.3294751290214912, -2.355798745326412, -2.3817182272666453, -2.4072219545187665, -2.432298715747825, -2.456937691425188, -2.4811284380720386, -2.504860873807746, -2.5281252650928216, -2.5509122145656886, -2.5732126498812766, -2.595017813467447, -2.6163192531225223, -2.637108813383886, -2.6573786276036553, -2.677121110672987, -2.6963289523416063, -2.7149951110837525, -2.733112808465908, -2.7506755239755423, -2.767676990273522, -2.784111188836083, -2.7999723459551054, -2.815254929068141, -2.8299536433920043, -2.8440634288360016, -2.8575794571728825, -2.870497129447453, -2.8828120736045055, -2.8945201423192697, -2.9056174110150503, -2.916100176054018, -2.92596495308836, -2.9352084755601178, -2.9438276933390872, -2.951819771489106, -2.959182089153997, -2.9659122385552235, -2.9720080240941322, -2.9774674615523824, -2.9822887773848388, -2.9864704080998905, -2.990010999722742, -2.9929094073378266, -2.995164694707058, -2.9967761339611787, -2.9977432053619633], [-2.9995162822919883, -2.99919381248834, -2.9982265070669647, -2.9966146780301406, -2.9943588454938235, -2.9914597378567254, -2.9879182920387337, -2.9837356537903816, -2.978913178075594, -2.973452429530464, -2.967355183001345, -2.960623424166123, -2.953259350243103, -2.9452653707925838, -2.936644108616832, -2.927398400764866, -2.917531299649202, -2.9070460742824737, -2.895946211642714, -2.8842354181769543, -2.8719176214537945, -2.858996971976608, -2.84547784517022, -2.831364843555071, -2.816662799124249, -2.8013767759401778, -2.7855120729693343, -2.769074227175071, -2.7520690168904713, -2.7345024654952086, -2.716380845422573, -2.697710682525281, -2.67849876083132, -2.658752127723974, -2.6384780995833665, -2.6176842679303594, -2.5963785061174174, -2.5745689766152857, -2.552264138948904, -2.52947275834101, -2.5062039151274442, -2.4824670150141936, -2.4582718002529123, -2.4336283618188848, -2.4085471526834494, -2.3830390022815795, -2.3571151322849007, -2.330787173800865, -2.3040671861301374, -2.2769676772266525, -2.249501626018197, -2.2216825067599046, -2.1935243156086845, -2.1650415996233967, -2.1362494884134815, -2.107163728677727, -2.0778007218947394, -2.048177565447374, -2.018312097484485, -1.9882229458445537, -1.9579295813864206, -1.9274523760916529, -1.8968126663200582, -1.8660328216129798, -1.8351363194464896, -1.8041478263360182, -1.7730932856822252, -1.7420000127211368, -1.7108967968947564, -1.6798140118854155, -1.6487837334503515, -1.6178398650431534, -1.587018271004504, -1.5563569168327083, -1.525896015689237, -1.4956781798380243, -1.4657485751398567, -1.4361550760036526, -1.4069484173138251, -1.3781823387879242, -1.3499137159574668, -1.3222026705027836, -1.2951126510211852, -1.268710473502024, -1.2430663088911926, -1.218253603265246, -1.1943489144721593, -1.1714316478683584, -1.1495836732972278, -1.1288888060846423, -1.1094321369873812, -1.0912992001355921, -1.074574974406585, -1.0593427225355803, -1.0456826835142758, -1.0336706469673362, -1.0233764522812274, -1.0148624688668106, -1.008182125270955, -1.0033785619707922, -1.0004834838382897, -0.9995162822919884, -1.0004834838382919, -1.003378561970796, -1.008182125270961, -1.0148624688668184, -1.0233764522812367, -1.0336706469673478, -1.045682683514289, -1.0593427225355954, -1.0745749744066013, -1.0912992001356099, -1.1094321369874003, -1.1288888060846627, -1.1495836732972495, -1.1714316478683813, -1.194348914472183, -1.218253603265271, -1.2430663088912186, -1.268710473502051, -1.2951126510212128, -1.3222026705028118, -1.3499137159574954, -1.3781823387879535, -1.4069484173138551, -1.4361550760036828, -1.465748575139887, -1.4956781798380554, -1.525896015689268, -1.55635691683274, -1.5870182710045353, -1.6178398650431849, -1.648783733450383, -1.6798140118854474, -1.7108967968947881, -1.7420000127211688, -1.7730932856822574, -1.8041478263360502, -1.8351363194465218, -1.8660328216130115, -1.89681266632009, -1.9274523760916846, -1.9579295813864523, -1.9882229458445848, -2.0183120974845155, -2.048177565447405, -2.0778007218947696, -2.1071637286777567, -2.1362494884135113, -2.165041599623426, -2.193524315608714, -2.2216825067599335, -2.249501626018225, -2.2769676772266805, -2.304067186130165, -2.330787173800892, -2.3571151322849273, -2.3830390022816057, -2.408547152683475, -2.43362836181891, -2.4582718002529367, -2.482467015014218, -2.506203915127468, -2.5294727583410346, -2.552264138948927, -2.5745689766153084, -2.5963785061174396, -2.6176842679303816, -2.6384780995833874, -2.658752127723994, -2.678498760831341, -2.6977106825253006, -2.7163808454225915, -2.734502465495227, -2.7520690168904887, -2.7690742271750874, -2.7855120729693503, -2.8013767759401937, -2.8166627991242645, -2.8313648435550856, -2.8454778451702336, -2.8589969719766217, -2.8719176214538074, -2.8842354181769667, -2.8959462116427255, -2.907046074282485, -2.9175312996492124, -2.9273984007648757, -2.9366441086168407, -2.9452653707925927, -2.9532593502431106, -2.9606234241661307, -2.9673551830013514, -2.97345242953047, -2.9789131780755995, -2.983735653790386, -2.9879182920387377, -2.991459737856729, -2.994358845493826, -2.996614678030142, -2.9982265070669656, -2.999193812488341], [-3.0, -2.999677504194068, -2.9987101207910003, -2.997098161868588, -2.9948421476687392, -2.991942806766705, -2.988401076309713, -2.9842181023267096, -2.9793952401114328, -2.9739340546815924, -2.96783632131742, -2.96110402618347, -2.9537393670380996, -2.9457447540357156, -2.9371228106274834, -2.927876374566925, -2.918008499027559, -2.907522453840494, -2.8964217268607664, -2.8847100254720894, -2.872391278240657, -2.8594696367296866, -2.845949477487531, -2.831835404223384, -2.817132250185963, -2.8018450807619644, -2.7859791963126668, -2.769540135268778, -2.7525336775054314, -2.73496584802134, -2.716842920948255, -2.6981714239193764, -2.678958142827934, -2.659210127010139, -2.6389346948898282, -2.6181394401256193, -2.596832238305251, -2.5750212542359208, -2.5527149498840433, -2.5299220930229334, -2.5066517666523693, -2.4829133792601352, -2.4587166760022225, -2.4340717508857153, -2.4089890600463186, -2.3834794362212492, -2.3575541045277544, -2.3312246996679384, -2.3045032846919513, -2.2774023714639533, -2.2499349429886575, -2.2221144777707926, -2.193954976395436, -2.1654709905339162, -2.1366776545979196, -2.1075907202832984, -2.078226594265017, -2.0486023793252537, -2.0187359192177876, -1.9886458475929094, -1.958351641327715, -1.9278736786258825, -1.8972333022679102, -1.8664528884058247, -1.8355559213037362, -1.8045670744249098, -1.7735122982541318, -1.742418915217197, -1.711315722012353, -1.6802330995953667, -1.649203130952895, -1.6182597266487537, -1.5874387579232352, -1.5567781968534804, -1.5263182627274532, -1.4961015733274858, -1.4661732992419205, -1.4365813186040413, -1.4073763687752252, -1.378612190424997, -1.350345658200505, -1.3226368907175428, -1.295549330956093, -1.2691497863407857, -1.2435084158996748, -1.2186986500373664, -1.1947970268011252, -1.1718829272976403, -1.1500381924401608, -1.1293466038419477, -1.109893213836369, -1.091763513710301, -1.0750424356299084, -1.0598131925963747, -1.0461559719972728, -1.034146511433914, -1.023854599558435, -1.015342558226969, -1.0086637735756747, -1.003861350718125, -1.0009669679025603, -0.9999999999999999, -1.0009669679025626, -1.0038613507181289, -1.0086637735756805, -1.015342558226977, -1.023854599558445, -1.0341465114339252, -1.0461559719972862, -1.0598131925963896, -1.0750424356299246, -1.0917635137103192, -1.1098932138363884, -1.1293466038419684, -1.1500381924401826, -1.1718829272976632, -1.1947970268011494, -1.2186986500373913, -1.2435084158997007, -1.2691497863408125, -1.2955493309561206, -1.3226368907175707, -1.350345658200534, -1.3786121904250266, -1.4073763687752552, -1.4365813186040717, -1.4661732992419512, -1.4961015733275167, -1.5263182627274845, -1.5567781968535117, -1.5874387579232667, -1.6182597266487855, -1.649203130952927, -1.6802330995953987, -1.7113157220123851, -1.742418915217229, -1.773512298254164, -1.8045670744249418, -1.835555921303768, -1.8664528884058562, -1.8972333022679417, -1.9278736786259139, -1.9583516413277464, -1.9886458475929405, -2.0187359192178183, -2.0486023793252843, -2.078226594265047, -2.1075907202833286, -2.1366776545979493, -2.165470990533946, -2.1939549763954647, -2.2221144777708215, -2.2499349429886855, -2.2774023714639813, -2.3045032846919793, -2.331224699667965, -2.3575541045277815, -2.3834794362212763, -2.408989060046345, -2.4340717508857406, -2.4587166760022474, -2.4829133792601596, -2.5066517666523938, -2.529922093022957, -2.5527149498840664, -2.5750212542359434, -2.5968322383052733, -2.61813944012564, -2.638934694889849, -2.6592101270101605, -2.678958142827954, -2.698171423919396, -2.7168429209482743, -2.734965848021358, -2.752533677505449, -2.7695401352687954, -2.7859791963126836, -2.80184508076198, -2.8171322501859786, -2.8318354042233986, -2.8459494774875456, -2.8594696367297003, -2.87239127824067, -2.884710025472102, -2.8964217268607775, -2.9075224538405053, -2.9180084990275703, -2.927876374566935, -2.9371228106274923, -2.945744754035725, -2.9537393670381076, -2.9611040261834765, -2.9678363213174266, -2.9739340546815987, -2.979395240111438, -2.9842181023267145, -2.9884010763097173, -2.9919428067667075, -2.9948421476687415, -2.997098161868591, -2.998710120791002, -2.9996775041940684], [-2.9995162822919874, -2.9991938124883393, -2.9982265070669634, -2.9966146780301397, -2.9943588454938226, -2.9914597378567245, -2.987918292038733, -2.9837356537903807, -2.9789131780755933, -2.973452429530463, -2.9673551830013443, -2.9606234241661222, -2.953259350243102, -2.945265370792583, -2.936644108616831, -2.927398400764865, -2.9175312996492013, -2.907046074282473, -2.895946211642713, -2.8842354181769534, -2.8719176214537936, -2.858996971976607, -2.845477845170219, -2.83136484355507, -2.8166627991242477, -2.801376775940177, -2.785512072969333, -2.76907422717507, -2.7520690168904705, -2.7345024654952077, -2.716380845422572, -2.69771068252528, -2.678498760831319, -2.658752127723973, -2.6384780995833657, -2.6176842679303585, -2.5963785061174165, -2.5745689766152853, -2.5522641389489027, -2.5294727583410097, -2.506203915127443, -2.482467015014193, -2.458271800252911, -2.4336283618188834, -2.4085471526834485, -2.383039002281578, -2.3571151322848993, -2.3307871738008643, -2.3040671861301365, -2.2769676772266516, -2.249501626018196, -2.2216825067599033, -2.1935243156086837, -2.165041599623396, -2.1362494884134806, -2.1071637286777256, -2.0778007218947385, -2.0481775654473737, -2.018312097484484, -1.9882229458445528, -1.95792958138642, -1.9274523760916522, -1.8968126663200575, -1.8660328216129791, -1.835136319446489, -1.8041478263360171, -1.7730932856822246, -1.742000012721136, -1.7108967968947555, -1.6798140118854143, -1.6487837334503503, -1.6178398650431522, -1.5870182710045027, -1.5563569168327078, -1.5258960156892358, -1.4956781798380234, -1.4657485751398558, -1.4361550760036517, -1.4069484173138243, -1.3781823387879233, -1.349913715957466, -1.322202670502783, -1.2951126510211846, -1.2687104735020232, -1.2430663088911917, -1.2182536032652451, -1.1943489144721584, -1.1714316478683575, -1.1495836732972267, -1.1288888060846414, -1.1094321369873803, -1.091299200135591, -1.074574974406584, -1.0593427225355796, -1.0456826835142747, -1.0336706469673353, -1.0233764522812263, -1.0148624688668098, -1.0081821252709542, -1.0033785619707911, -1.0004834838382888, -0.9995162822919874, -1.0004834838382908, -1.0033785619707951, -1.0081821252709602, -1.0148624688668175, -1.0233764522812359, -1.0336706469673467, -1.0456826835142883, -1.0593427225355945, -1.0745749744066007, -1.091299200135609, -1.1094321369873994, -1.128888806084662, -1.1495836732972486, -1.1714316478683806, -1.1943489144721824, -1.2182536032652702, -1.2430663088912177, -1.2687104735020498, -1.295112651021212, -1.3222026705028112, -1.3499137159574945, -1.3781823387879526, -1.4069484173138542, -1.436155076003682, -1.4657485751398864, -1.4956781798380545, -1.5258960156892671, -1.556356916832739, -1.5870182710045346, -1.617839865043184, -1.648783733450382, -1.6798140118854465, -1.7108967968947875, -1.742000012721168, -1.7730932856822563, -1.804147826336049, -1.835136319446521, -1.8660328216130109, -1.896812666320089, -1.9274523760916837, -1.9579295813864512, -1.988222945844584, -2.0183120974845146, -2.048177565447404, -2.0778007218947687, -2.107163728677756, -2.1362494884135104, -2.1650415996234247, -2.193524315608713, -2.221682506759932, -2.2495016260182243, -2.2769676772266796, -2.304067186130164, -2.3307871738008914, -2.357115132284927, -2.3830390022816044, -2.4085471526834747, -2.433628361818909, -2.458271800252936, -2.4824670150142176, -2.5062039151274673, -2.529472758341033, -2.5522641389489262, -2.5745689766153075, -2.596378506117439, -2.6176842679303807, -2.638478099583387, -2.6587521277239934, -2.67849876083134, -2.6977106825252997, -2.7163808454225906, -2.7345024654952264, -2.752069016890488, -2.7690742271750866, -2.7855120729693494, -2.801376775940193, -2.8166627991242636, -2.8313648435550847, -2.8454778451702327, -2.8589969719766204, -2.8719176214538065, -2.884235418176966, -2.8959462116427246, -2.907046074282484, -2.9175312996492115, -2.927398400764875, -2.9366441086168398, -2.9452653707925918, -2.9532593502431097, -2.96062342416613, -2.9673551830013505, -2.973452429530469, -2.9789131780755986, -2.983735653790385, -2.987918292038737, -2.991459737856728, -2.994358845493825, -2.996614678030141, -2.9982265070669647, -2.99919381248834], [-2.998065597133593, -2.997743205361961, -2.9967761339611747, -2.995164694707055, -2.992909407337822, -2.990010999722737, -2.986470408099884, -2.9822887773848317, -2.977467461552375, -2.9720080240941247, -2.9659122385552146, -2.959182089153987, -2.951819771489096, -2.943827693339077, -2.935208475560107, -2.925964953088348, -2.9161001760540057, -2.905617411015038, -2.8945201423192564, -2.8828120736044913, -2.8704971294474384, -2.8575794571728665, -2.8440634288359856, -2.829953643391988, -2.8152549290681237, -2.7999723459550867, -2.7841111888360635, -2.7676769902735034, -2.7506755239755223, -2.7331128084658878, -2.714995111083731, -2.6963289523415854, -2.6771211106729647, -2.6573786276036326, -2.6371088133838625, -2.616319253122499, -2.5950178134674227, -2.5732126498812526, -2.5509122145656633, -2.5281252650927963, -2.5048608738077194, -2.4811284380720116, -2.456937691425162, -2.4322987157477978, -2.4072219545187385, -2.381718227266617, -2.3557987453263833, -2.3294751290214624, -2.302759426403696, -2.275664133695645, -2.2482022175932217, -2.2203871396012227, -2.1922328825899933, -2.1637539797783165, -2.134965546365567, -2.105883314055225, -2.0765236687318414, -2.0469036915743173, -2.017041203909627, -1.9869548161324602, -1.9566639810370923, -1.926189051927357, -1.8955513458878037, -1.864773212612539, -1.8338781091961076, -1.8028906812905607, -1.7718368510215938, -1.7407439120303547, -1.7096406319612978, -1.678557362644108, -1.647526158111646, -1.6165809004466898, -1.585757433246744, -1.555093702224911, -1.5246299021100826, -1.4944086285535954, -1.4644750331720802, -1.434876979136272, -1.4056651938317377, -1.376893414050377, -1.3486185179068364, -1.320900636206837, -1.2938032343358024, -1.2673931539209615, -1.2417406016168921, -1.2169190704871917, -1.1930051777743116, -1.170078401602956, -1.1482206986583847, -1.127515985493635, -1.1080494682674895, -1.0899068098172529, -1.073173129377438, -1.057931839153395, -1.0442633332556095, -1.0322435577136548, -1.0219425044662132, -1.013422685934357, -1.0067376582198746, -1.0019306681693876, -0.9990335007415116, -0.9980655971335932, -0.9990335007415135, -1.0019306681693916, -1.0067376582198806, -1.0134226859343647, -1.021942504466223, -1.0322435577136662, -1.044263333255623, -1.0579318391534096, -1.0731731293774545, -1.0899068098172708, -1.1080494682675088, -1.1275159854936554, -1.1482206986584067, -1.1700784016029786, -1.1930051777743358, -1.2169190704872168, -1.2417406016169181, -1.2673931539209884, -1.2938032343358299, -1.3209006362068652, -1.3486185179068648, -1.376893414050406, -1.4056651938317677, -1.4348769791363025, -1.4644750331721108, -1.4944086285536264, -1.5246299021101137, -1.5550937022249425, -1.5857574332467756, -1.6165809004467215, -1.647526158111678, -1.6785573626441401, -1.7096406319613295, -1.7407439120303867, -1.7718368510216258, -1.8028906812905925, -1.8338781091961394, -1.8647732126125705, -1.8955513458878352, -1.9261890519273885, -1.9566639810371236, -1.9869548161324915, -2.0170412039096575, -2.0469036915743475, -2.076523668731872, -2.105883314055255, -2.1349655463655965, -2.163753979778346, -2.192232882590022, -2.220387139601251, -2.24820221759325, -2.2756641336956736, -2.3027594264037234, -2.3294751290214895, -2.3557987453264104, -2.381718227266643, -2.4072219545187648, -2.432298715747823, -2.456937691425187, -2.481128438072036, -2.5048608738077434, -2.5281252650928194, -2.550912214565686, -2.573212649881275, -2.5950178134674453, -2.616319253122521, -2.637108813383884, -2.6573786276036526, -2.6771211106729846, -2.696328952341605, -2.7149951110837502, -2.7331128084659064, -2.75067552397554, -2.7676769902735208, -2.7841111888360803, -2.7999723459551036, -2.8152549290681397, -2.8299536433920025, -2.8440634288359994, -2.8575794571728803, -2.870497129447451, -2.8828120736045033, -2.894520142319268, -2.905617411015049, -2.916100176054016, -2.925964953088358, -2.935208475560116, -2.9438276933390854, -2.951819771489104, -2.9591820891539946, -2.9659122385552212, -2.9720080240941305, -2.977467461552381, -2.982288777384837, -2.9864704080998883, -2.99001099972274, -2.9929094073378244, -2.9951646947070563, -2.9967761339611765, -2.9977432053619615], [-2.995649347969017, -2.995327086334647, -2.994360405219968, -2.992749616023609, -2.990495237854644, -2.9875979977004823, -2.9840588306636024, -2.9798788802688576, -2.97505949884355, -2.9696022479730395, -2.9635088990351393, -2.9567814338171625, -2.949422045220045, -2.9414331380545824, -2.9328173299354927, -2.9235774522796856, -2.9137165514158587, -2.903237889813338, -2.892144947438882, -2.880441423251115, -2.8681312368431775, -2.8552185302452586, -2.8417076698997796, -2.827603248823226, -2.8129100889699576, -2.797633243814752, -2.7817780011723925, -2.765349886274354, -2.7483546651244324, -2.7307983481572693, -2.7126871942258584, -2.694027714946606, -2.674826679433137, -2.655091119452934, -2.634828335044099, -2.6140459006330024, -2.5927516716973877, -2.570953792023732, -2.5486607016122163, -2.5258811452877494, -2.5026241820809876, -2.478899195449411, -2.4547159044151416, -2.4300843757035198, -2.405015036974467, -2.379518691247412, -2.35360653263016, -2.3272901634725636, -2.3005816130772656, -2.2734933581122405, -2.246038344883342, -2.218230013639695, -2.1900823251005406, -2.161609789409057, -2.1328274977367743, -2.1037511567813567, -2.0743971264207017, -2.044782460807253, -2.0149249532079097, -1.984843184916535, -1.954556578587206, -1.9240854563562744, -1.893451103138952, -1.8626758355000446, -1.8317830765068936, -1.8007974369730397, -1.7697448034906236, -1.7386524336241016, -1.7075490585925897, -1.6764649936968472, -1.6454322566419566, -1.6144846937587598, -1.583658113924784, -1.552990429715214, -1.52252180496067, -1.4922948074330369, -1.462354564803225, -1.4327489212940643, -1.4035285915657796, -1.3747473073008907, -1.3464619506849758, -1.3187326675041893, -1.2916229509099717, -1.2651996850703202, -1.2395331360034265, -1.2146968749871583, -1.1907676182278895, -1.167824965193134, -1.1459510174752985, -1.1252298606366211, -1.1057468936119286, -1.0875879943424553, -1.070838516738998, -1.0555821230198403, -1.0418994668517363, -1.029866756059678, -1.019554238005209, -1.0110246646185297, -1.0043318056742299, -0.9995190862355898, -0.996618425460977, -0.9956493479690169, -0.9966184254609789, -0.9995190862355938, -1.0043318056742356, -1.0110246646185372, -1.019554238005219, -1.0298667560596892, -1.0418994668517496, -1.0555821230198552, -1.0708385167390144, -1.0875879943424736, -1.105746893611948, -1.125229860636642, -1.1459510174753205, -1.1678249651931571, -1.1907676182279134, -1.2146968749871834, -1.2395331360034523, -1.2651996850703469, -1.291622950909999, -1.3187326675042175, -1.3464619506850044, -1.37474730730092, -1.4035285915658096, -1.4327489212940945, -1.4623545648032557, -1.4922948074330677, -1.5225218049607012, -1.552990429715245, -1.5836581139248158, -1.6144846937587916, -1.6454322566419888, -1.6764649936968794, -1.7075490585926216, -1.7386524336241336, -1.7697448034906553, -1.8007974369730715, -1.831783076506925, -1.8626758355000763, -1.8934511031389836, -1.9240854563563061, -1.9545565785872374, -1.9848431849165666, -2.0149249532079407, -2.044782460807283, -2.074397126420732, -2.103751156781387, -2.132827497736804, -2.1616097894090864, -2.1900823251005694, -2.2182300136397237, -2.24603834488337, -2.2734933581122685, -2.3005816130772927, -2.3272901634725907, -2.353606532630187, -2.379518691247439, -2.4050150369744934, -2.4300843757035455, -2.4547159044151665, -2.478899195449436, -2.5026241820810116, -2.5258811452877725, -2.54866070161224, -2.570953792023755, -2.5927516716974104, -2.6140459006330237, -2.63482833504412, -2.6550911194529534, -2.6748266794331568, -2.6940277149466247, -2.7126871942258766, -2.7307983481572875, -2.74835466512445, -2.765349886274371, -2.78177800117241, -2.7976332438147677, -2.812910088969974, -2.8276032488232405, -2.841707669899794, -2.8552185302452724, -2.8681312368431904, -2.8804414232511264, -2.8921449474388936, -2.903237889813349, -2.91371655141587, -2.9235774522796953, -2.932817329935502, -2.941433138054591, -2.949422045220053, -2.9567814338171696, -2.963508899035146, -2.9696022479730457, -2.9750594988435553, -2.979878880268862, -2.9840588306636064, -2.9875979977004863, -2.9904952378546463, -2.992749616023611, -2.99436040521997, -2.995327086334648], [-2.9922698723632744, -2.9919477930973533, -2.990981658912241, -2.9893717806790114, -2.9871186766267916, -2.984223072509594, -2.980685901841592, -2.97650830620252, -2.971691635615418, -2.9662374489994585, -2.9601475147011116, -2.9534238111074997, -2.946068527346339, -2.938084064077512, -2.9294730343819557, -2.92023826475422, -2.9103827962058215, -2.8999098854872516, -2.888823006437377, -2.8771258514698332, -2.8648223332069995, -2.8519165862731755, -2.8384129692597004, -2.8243160668759844, -2.8096306923017362, -2.794361889757106, -2.7785149373090317, -2.762095349933761, -2.7451088828574077, -2.72756153519838, -2.709459553937789, -2.6908094382463066, -2.6716179441986423, -2.6518920899096687, -2.631639161129437, -2.6108667173377857, -2.5895825983830854, -2.567794931713845, -2.5455121402565135, -2.522742950997868, -2.499496404335917, -2.4757818642693348, -2.45160902950213, -2.426987945547557, -2.401929017923336, -2.376443026538994, -2.3505411413858313, -2.3242349396504465, -2.297536424384314, -2.270458044874332, -2.243012718872877, -2.2152138568605957, -2.187075388531021, -2.158611791703184, -2.1298381238865964, -2.1007700567423573, -2.071423913704502, -2.041816711046937, -2.0119662027031016, -1.9818909291674753, -1.9516102708296423, -1.9211445061120511, -1.8905148748008473, -1.8597436469737973, -1.828854197938531, -1.7978710895957488, -1.7668201586325967, -1.7357286119271793, -1.704625129501272, -1.673539975288466, -1.6425051158816208, -1.6115543472771692, -1.58072342943317, -1.5500502281894164, -1.5195748637454487, -1.4893398644376967, -1.4593903239797792, -1.4297740596082933, -1.4005417676880911, -1.371747172255531, -1.3434471606999185, -1.3157018992960077, -1.288574919613411, -1.2621331649754062, -1.236446984187368, -1.2115900578173744, -1.1876392405600227, -1.1646743018894623, -1.1427775466233567, -1.1220332975594385, -1.1025272244420932, -1.0843455076042727, -1.0675738310795764, -1.0522962089954042, -1.0385936605622754, -1.026542762487525, -1.0162141221977512, -1.007670829388325, -1.0009669552651295, -0.9961461763733932, -0.9932406012807915, -0.9922698723632744, -0.9932406012807936, -0.9961461763733972, -1.0009669552651355, -1.0076708293883327, -1.0162141221977612, -1.0265427624875363, -1.0385936605622887, -1.0522962089954186, -1.0675738310795928, -1.084345507604291, -1.1025272244421125, -1.1220332975594591, -1.142777546623379, -1.1646743018894852, -1.1876392405600467, -1.2115900578173993, -1.2364469841873942, -1.2621331649754328, -1.2885749196134386, -1.3157018992960359, -1.3434471606999472, -1.3717471722555603, -1.400541767688121, -1.4297740596083237, -1.4593903239798096, -1.4893398644377276, -1.5195748637454798, -1.5500502281894477, -1.5807234294332015, -1.6115543472772007, -1.6425051158816528, -1.673539975288498, -1.704625129501304, -1.7357286119272113, -1.7668201586326289, -1.7978710895957808, -1.8288541979385624, -1.8597436469738293, -1.8905148748008793, -1.9211445061120827, -1.9516102708296739, -1.9818909291675064, -2.0119662027031326, -2.041816711046968, -2.0714239137045323, -2.1007700567423875, -2.1298381238866257, -2.1586117917032137, -2.1870753885310505, -2.215213856860624, -2.2430127188729054, -2.27045804487436, -2.297536424384342, -2.3242349396504736, -2.350541141385858, -2.376443026539021, -2.401929017923362, -2.426987945547583, -2.451609029502155, -2.475781864269359, -2.4994964043359413, -2.522742950997892, -2.545512140256536, -2.5677949317138675, -2.5895825983831076, -2.6108667173378066, -2.6316391611294576, -2.6518920899096896, -2.671617944198663, -2.690809438246326, -2.7094595539378075, -2.727561535198398, -2.745108882857426, -2.7620953499337784, -2.7785149373090485, -2.7943618897571225, -2.809630692301751, -2.824316066875999, -2.8384129692597146, -2.851916586273189, -2.8648223332070124, -2.877125851469845, -2.8888230064373888, -2.8999098854872627, -2.9103827962058317, -2.92023826475423, -2.9294730343819646, -2.9380840640775205, -2.9460685273463465, -2.9534238111075073, -2.9601475147011183, -2.966237448999464, -2.9716916356154237, -2.976508306202524, -2.980685901841596, -2.9842230725095966, -2.9871186766267943, -2.9893717806790137, -2.990981658912242, -2.9919477930973546], [-2.987930439740754, -2.987608595250954, -2.986643165168493, -2.9850344596870504, -2.9827829959058585, -2.9798894979952033, -2.9763548974298017, -2.9721803332917616, -2.9673671526453296, -2.9619169109861367, -2.9558313727682215, -2.9491125120126176, -2.941762513001933, -2.9337837710659214, -2.925178893463702, -2.9159507003689926, -2.9061022259654146, -2.895636719659725, -2.884557647421681, -2.872868693260098, -2.860573760845655, -2.847676975292033, -2.8341826851080807, -2.8200954643349476, -2.805420114883392, -2.790161669087973, -2.7743253924963236, -2.757916786913462, -2.7409415937228996, -2.7234057975083665, -2.705315630002166, -2.686677574388585, -2.667498369993456, -2.647785017393836, -2.6275447839849764, -2.6067852100452265, -2.5855141153433334, -2.5637396063368274, -2.541470084014741, -2.518714252443033, -2.4954811280765683, -2.4717800499076854, -2.4476206905279922, -2.4230130681874513, -2.397967559942812, -2.3724949159963136, -2.3466062753352093, -2.320313182793269, -2.293627607666906, -2.266561964031188, -2.239129132914628, -2.2113424865064792, -2.183215914586268, -2.1547638533825135, -2.126001317086008, -2.096943932262636, -2.067607975431348, -2.0380104140944884, -2.0081689515298526, -1.9781020756763155, -1.947829112467014, -1.9173702839851698, -1.8867467718366475, -1.8559807861488704, -1.825095640616011, -1.7941158340129704, -1.7630671385926133, -1.7319766957580647, -1.7008731193597029, -1.669786606898599, -1.6387490588168618, -1.6077942059112134, -1.5769577447076704, -1.5462774803687267, -1.5157934763537586, -1.485548209600014, -1.4555867294146057, -1.4259568175450985, -1.3967091460046899, -1.3678974281462934, -1.3395785571915217, -1.311812724918097, -1.2846635115008584, -1.258197935619351, -1.2324864519555456, -1.2076028812215407, -1.1836242560514232, -1.160630564706178, -1.1387043738942668, -1.1179303124937006, -1.0983944000159247, -1.0801832077267481, -1.0633828468195539, -1.0480777871404732, -1.0343495216267045, -1.022275105361251, -1.0119256129941667, -1.003364572740437, -0.9966464473305312, -0.9918152400765249, -0.9889033057272865, -0.987930439740754, -0.9889033057272884, -0.9918152400765288, -0.9966464473305373, -1.0033645727404448, -1.0119256129941765, -1.0222751053612626, -1.034349521626718, -1.0480777871404883, -1.0633828468195705, -1.0801832077267661, -1.098394400015944, -1.1179303124937212, -1.1387043738942888, -1.1606305647062014, -1.1836242560514474, -1.2076028812215658, -1.2324864519555714, -1.2581979356193775, -1.2846635115008858, -1.3118127249181255, -1.3395785571915504, -1.3678974281463225, -1.3967091460047198, -1.4259568175451292, -1.455586729414636, -1.4855482096000452, -1.5157934763537897, -1.546277480368758, -1.5769577447077021, -1.6077942059112447, -1.6387490588168938, -1.6697866068986313, -1.7008731193597348, -1.7319766957580964, -1.763067138592645, -1.794115834013002, -1.8250956406160426, -1.855980786148902, -1.886746771836679, -1.9173702839852016, -1.9478291124670453, -1.9781020756763468, -2.0081689515298833, -2.038010414094519, -2.0676079754313785, -2.096943932262666, -2.126001317086038, -2.154763853382543, -2.183215914586297, -2.211342486506508, -2.239129132914656, -2.266561964031216, -2.293627607666933, -2.320313182793296, -2.3466062753352364, -2.3724949159963393, -2.397967559942838, -2.423013068187476, -2.447620690528017, -2.4717800499077103, -2.4954811280765923, -2.518714252443056, -2.5414700840147644, -2.5637396063368496, -2.585514115343356, -2.6067852100452478, -2.6275447839849972, -2.647785017393856, -2.667498369993476, -2.686677574388604, -2.7053156300021843, -2.7234057975083847, -2.740941593722917, -2.7579167869134795, -2.774325392496341, -2.790161669087989, -2.8054201148834084, -2.8200954643349623, -2.8341826851080953, -2.847676975292046, -2.8605737608456674, -2.87286869326011, -2.8845576474216927, -2.895636719659736, -2.906102225965425, -2.915950700369003, -2.9251788934637104, -2.9337837710659294, -2.941762513001941, -2.9491125120126243, -2.955831372768228, -2.9619169109861425, -2.967367152645335, -2.972180333291767, -2.976354897429806, -2.979889497995207, -2.9827829959058607, -2.9850344596870517, -2.9866431651684944, -2.987608595250954], [-2.9826352482222607, -2.982313691143452, -2.981349123018549, -2.979741853214657, -2.977492397452295, -2.9746014779692467, -2.971070023751632, -2.966899170833882, -2.962090262669815, -2.956644850577525, -2.950564694261311, -2.9438517624144627, -2.936508233407271, -2.9285364960652633, -2.9199391505432772, -2.910719009301722, -2.900879098192045, -2.89042265765924, -2.8793531440700373, -2.8676742311763155, -2.8553898117242507, -2.8425039992207193, -2.829021129869619, -2.8149457646919744, -2.8002826918450023, -2.7850369291567607, -2.769213726894531, -2.7528185707868063, -2.7358571853205964, -2.718335537337777, -2.700259839956423, -2.681636556845481, -2.6624724068837784, -2.6427743692372827, -2.622549688891658, -2.6018058826807207, -2.5805507458551538, -2.558792359240087, -2.5365390970347423, -2.5137996353124143, -2.4905829612846264, -2.46689838339941, -2.4427555423503633, -2.4181644230805235, -2.3931353678731764, -2.3676790906305594, -2.3418066924511747, -2.315529678627011, -2.2888599771936056, -2.2618099591785326, -2.2343924607076824, -2.2066208071436493, -2.178508839446705, -2.1500709429662805, -2.1213220788895106, -2.092277818593294, -2.0629543811673283, -2.033368674397524, -2.0035383395219233, -1.9734818000942425, -1.943218315313028, -1.9127680381963017, -1.882152079001536, -1.8513925743074606, -1.8205127621857473, -1.7895370638947494, -1.7584911725210988, -1.7274021489742626, -1.6962985256991518, -1.665210418406374, -1.634169646021046, -1.6032098589096653, -1.5723666752488679, -1.5416778251360774, -1.5111833016937184, -1.480925517966904, -1.4509494678381194, -1.4213028884583159, -1.392036420798452, -1.3632037638364527, -1.3348618165940873, -1.3070708007173903, -1.2798943545597747, -1.2533995878093496, -1.227657083666587, -1.2027408335377856, -1.1787280873366277, -1.1556991010255504, -1.1337367623043946, -1.112926075765129, -1.0933534908326457, -1.075106059868201, -1.0582704203274678, -1.0429316040773415, -1.0291716888313143, -1.0170683206899882, -1.0066931519831903, -0.9981102534792766, -0.9913745725948213, -0.9865305173501808, -0.9836107475038126, -0.9826352482222604, -0.9836107475038147, -0.9865305173501848, -0.9913745725948274, -0.9981102534792846, -1.0066931519832, -1.0170683206899995, -1.0291716888313276, -1.0429316040773564, -1.0582704203274842, -1.075106059868219, -1.0933534908326654, -1.1129260757651498, -1.1337367623044166, -1.1556991010255737, -1.1787280873366517, -1.2027408335378107, -1.2276570836666132, -1.2533995878093764, -1.2798943545598023, -1.3070708007174185, -1.3348618165941162, -1.3632037638364825, -1.3920364207984814, -1.4213028884583463, -1.4509494678381496, -1.4809255179669352, -1.5111833016937495, -1.5416778251361087, -1.5723666752488996, -1.6032098589096972, -1.634169646021078, -1.6652104184064058, -1.6962985256991838, -1.727402148974295, -1.7584911725211307, -1.7895370638947814, -1.8205127621857793, -1.8513925743074922, -1.8821520790015678, -1.9127680381963335, -1.9432183153130596, -1.9734818000942733, -2.003538339521954, -2.0333686743975545, -2.0629543811673585, -2.0922778185933244, -2.1213220788895404, -2.1500709429663103, -2.1785088394467342, -2.2066208071436777, -2.2343924607077112, -2.2618099591785605, -2.2888599771936335, -2.3155296786270387, -2.3418066924512013, -2.3676790906305856, -2.393135367873202, -2.4181644230805492, -2.4427555423503877, -2.466898383399435, -2.4905829612846504, -2.5137996353124374, -2.536539097034765, -2.558792359240109, -2.5805507458551755, -2.601805882680742, -2.622549688891679, -2.642774369237303, -2.6624724068837997, -2.6816365568455, -2.7002598399564426, -2.7183355373377953, -2.7358571853206137, -2.752818570786823, -2.7692137268945483, -2.7850369291567776, -2.8002826918450174, -2.814945764691988, -2.8290211298696337, -2.842503999220733, -2.8553898117242635, -2.8676742311763275, -2.879353144070049, -2.8904226576592515, -2.900879098192055, -2.910719009301731, -2.919939150543286, -2.928536496065272, -2.936508233407279, -2.9438517624144693, -2.9505646942613177, -2.9566448505775305, -2.962090262669821, -2.9668991708338863, -2.9710700237516363, -2.9746014779692507, -2.9774923974522975, -2.9797418532146587, -2.9813491230185503, -2.9823136911434522], [-2.9763894205636032, -2.9760682038087825, -2.9751046563309997, -2.9734990865224376, -2.9712520084774514, -2.9683641421544786, -2.964836413604379, -2.960669955266884, -2.955866106337335, -2.9504264132064097, -2.9443526299760476, -2.9376467190553663, -2.93031085184091, -2.9223474094862016, -2.913758983766199, -2.9045483780429384, -2.894718608339374, -2.884272904529188, -2.87321471165118, -2.8615476913577247, -2.84927572350775, -2.8364029079157107, -2.8229335662691515, -2.8088722442286636, -2.7942237137253496, -2.778992975472327, -2.763185261708366, -2.7468060391934483, -2.72986101247785, -2.712356127468428, -2.6942975753179144, -2.675691796665513, -2.656545486259678, -2.636865597996887, -2.616659350413378, -2.5959342326703165, -2.574698011076677, -2.5529587361983492, -2.530724750606563, -2.508004697323839, -2.4848075290312215, -2.46114251810669, -2.437019267571386, -2.412447723027666, -2.3874381856811455, -2.3620013265477784, -2.3361482019567883, -2.309890270470991, -2.283239411357698, -2.2562079447562016, -2.228808653701716, -2.2010548081807846, -2.1729601914094987, -2.1445391285435575, -2.115806518048108, -2.0867778659755505, -2.057469323420872, -2.0278977274465606, -1.998080645792366, -1.9680364257089435, -1.9377842472780267, -1.9073441816046641, -1.8767372542881353, -1.8459855145961364, -1.815112110779921, -1.7841413719739856, -1.753098897119552, -1.722011651332723, -1.6909080701007777, -1.659818171627468, -1.6287736775526238, -1.597808142133287, -1.566957089781304, -1.5362581605917767, -1.5057512631513301, -1.4754787334655453, -1.4454854982693146, -1.4158192402585656, -1.3865305618821604, -1.3576731432352795, -1.3293038882809054, -1.3014830520835918, -1.2742743399742111, -1.2477449676046235, -1.2219656687608693, -1.1970106356942687, -1.1729573747752213, -1.1498864587224313, -1.12788115584078, -1.1070269170236327, -1.0874107032095515, -1.069120140014481, -1.0522424928149472, -1.0368634648967128, -1.0230658333711684, -1.0109279519317784, -1.000522165173249, -0.9919131945640075, -0.9851565692222194, -0.9802971831587954, -0.977368062558745, -0.9763894205636032, -0.9773680625587471, -0.9802971831587997, -0.9851565692222255, -0.9919131945640154, -1.0005221651732588, -1.0109279519317897, -1.0230658333711817, -1.0368634648967276, -1.0522424928149638, -1.069120140014499, -1.0874107032095712, -1.1070269170236535, -1.127881155840802, -1.1498864587224542, -1.1729573747752455, -1.1970106356942938, -1.2219656687608953, -1.2477449676046504, -1.274274339974239, -1.30148305208362, -1.3293038882809343, -1.3576731432353086, -1.3865305618821904, -1.415819240258596, -1.445485498269345, -1.4754787334655763, -1.5057512631513614, -1.536258160591808, -1.5669570897813356, -1.5978081421333188, -1.6287736775526556, -1.6598181716275, -1.6909080701008101, -1.7220116513327552, -1.753098897119584, -1.7841413719740171, -1.8151121107799526, -1.8459855145961679, -1.876737254288167, -1.9073441816046954, -1.9377842472780578, -1.968036425708975, -1.9980806457923972, -2.0278977274465912, -2.057469323420903, -2.0867778659755802, -2.115806518048138, -2.1445391285435864, -2.172960191409528, -2.2010548081808134, -2.2288086537017446, -2.2562079447562295, -2.2832394113577257, -2.3098902704710182, -2.336148201956815, -2.3620013265478046, -2.3874381856811717, -2.4124477230276913, -2.4370192675714106, -2.461142518106715, -2.4848075290312455, -2.5080046973238623, -2.530724750606586, -2.5529587361983723, -2.5746980110766993, -2.5959342326703383, -2.6166593504133995, -2.636865597996907, -2.6565454862596978, -2.675691796665532, -2.6942975753179335, -2.7123561274684462, -2.7298610124778677, -2.746806039193465, -2.7631852617083834, -2.7789929754723426, -2.794223713725365, -2.808872244228678, -2.8229335662691653, -2.836402907915724, -2.849275723507763, -2.861547691357737, -2.8732147116511917, -2.8842729045291997, -2.8947186083393843, -2.904548378042948, -2.9137589837662077, -2.9223474094862096, -2.9303108518409173, -2.9376467190553734, -2.9443526299760543, -2.950426413206416, -2.9558661063373406, -2.960669955266889, -2.9648364136043837, -2.9683641421544817, -2.9712520084774536, -2.9734990865224393, -2.9751046563310015, -2.9760682038087833], [-2.9691989991996617, -2.968878176011143, -2.9679158088583177, -2.966312205011085, -2.964067876691833, -2.9611835412351106, -2.9576601213128146, -2.953498745226572, -2.9487007472694717, -2.9432676681598364, -2.937201255550217, -2.9305034646153776, -2.923176458723589, -2.915222610196162, -2.906644501160786, -2.897444924504931, -2.887626884936245, -2.877193600157712, -2.8661485021660984, -2.8544952386831324, -2.8422376747298057, -2.829379894355202, -2.815926202532384, -2.801881127235062, -2.7872494217100754, -2.7720360669621407, -2.7562462744688703, -2.7398854891457347, -2.722959392582516, -2.705473906574765, -2.6874351969760184, -2.668849677898915, -2.649724016296001, -2.6300651369539, -2.6098802279377074, -2.58917674652595, -2.567962425680287, -2.5462452810983223, -2.524033618902544, -2.501336044023466, -2.4781614693406664, -2.4545191256515335, -2.430418572544309, -2.4058697102594393, -2.380882792631404, -2.355468441212151, -2.3296376606871014, -2.303401855705456, -2.2767728492583315, -2.2497629027511516, -2.2223847379307458, -2.194651560842934, -2.166577088012921, -2.138175575058778, -2.1094618479675096, -2.0804513372838516, -2.05116011548378, -2.021604937827746, -1.9918032870125504, -1.96177342196532, -1.9315344311475962, -1.901106290761552, -1.8705099282727362, -1.8397672916832628, -1.8089014250042386, -1.777936550384197, -1.7468981573483724, -1.7158130995879668, -1.6847096997042275, -1.6536178622529556, -1.622569195343208, -1.5915971409098215, -1.5607371135911796, -1.5300266478870563, -1.4995055529295278, -1.4692160737530502, -1.4392030573754768, -1.4095141212753801, -1.380199820946893, -1.3513138121063542, -1.322913001794301, -1.2950576810491374, -1.2678116300275806, -1.2412421844381931, -1.2154202499997158, -1.1904202494460803, -1.1663199845490455, -1.1432003939684574, -1.1211451868063087, -1.1002403319557468, -1.0805733851873016, -1.0622326399109137, -1.045306094147949, -1.0298802357314867, -1.0160386601123756, -1.0038605499240185, -0.9934190616331963, -0.9847796805689388, -0.9779986192731406, -0.9731213431154269, -0.9701813092936024, -0.9691989991996618, -0.9701813092936045, -0.9731213431154307, -0.9779986192731466, -0.984779680568947, -0.9934190616332061, -1.00386054992403, -1.0160386601123892, -1.0298802357315018, -1.045306094147966, -1.0622326399109316, -1.0805733851873212, -1.1002403319557674, -1.121145186806331, -1.1432003939684805, -1.1663199845490697, -1.1904202494461054, -1.215420249999742, -1.2412421844382202, -1.267811630027608, -1.2950576810491656, -1.3229130017943298, -1.3513138121063837, -1.380199820946923, -1.4095141212754103, -1.4392030573755072, -1.4692160737530813, -1.499505552929559, -1.5300266478870879, -1.5607371135912114, -1.5915971409098533, -1.62256919534324, -1.6536178622529878, -1.6847096997042594, -1.7158130995879985, -1.7468981573484044, -1.7779365503842288, -1.8089014250042703, -1.8397672916832948, -1.8705099282727682, -1.9011062907615834, -1.9315344311476275, -1.9617734219653513, -1.9918032870125815, -2.0216049378277767, -2.051160115483811, -2.0804513372838813, -2.109461847967539, -2.138175575058807, -2.16657708801295, -2.194651560842962, -2.2223847379307746, -2.2497629027511796, -2.276772849258359, -2.3034018557054825, -2.329637660687128, -2.355468441212177, -2.3808827926314295, -2.4058697102594646, -2.4304185725443337, -2.4545191256515584, -2.478161469340691, -2.50133604402349, -2.524033618902567, -2.5462452810983454, -2.567962425680309, -2.589176746525972, -2.6098802279377282, -2.6300651369539203, -2.649724016296021, -2.668849677898934, -2.6874351969760366, -2.7054739065747837, -2.7229593925825344, -2.7398854891457516, -2.7562462744688863, -2.7720360669621567, -2.787249421710091, -2.8018811272350765, -2.8159262025323977, -2.829379894355215, -2.8422376747298186, -2.8544952386831444, -2.86614850216611, -2.877193600157723, -2.887626884936255, -2.8974449245049407, -2.9066445011607955, -2.91522261019617, -2.923176458723597, -2.930503464615385, -2.9372012555502236, -2.943267668159842, -2.948700747269477, -2.9534987452265766, -2.9576601213128186, -2.9611835412351137, -2.9640678766918356, -2.966312205011086, -2.967915808858319, -2.968878176011143], [-2.9610709403987197, -2.960750564399622, -2.9597895383923998, -2.9581881683784537, -2.955946964464325, -2.953066641018819, -2.949548116894628, -2.945392515716095, -2.9406011662352802, -2.935175602758979, -2.9291175656498583, -2.9224290019054573, -2.915112065819322, -2.9071691197291822, -2.8986027348576875, -2.8894156922519145, -2.8796109838285373, -2.869191813532348, -2.858161598616624, -2.846523971054702, -2.8342827790930754, -2.821442088957372, -2.808006186723616, -2.79397958036846, -2.779367002013289, -2.764173410378572, -2.7484039934663507, -2.732064171490442, -2.715159600075763, -2.697696173750202, -2.6796800297546306, -2.661117552199098, -2.6420153765958405, -2.622380394802644, -2.602219760413293, -2.5815408946352982, -2.5603514926989197, -2.538659530845756, -2.5164732739497353, -2.4938012838285144, -2.4706524283088114, -2.4470358911154477, -2.422961182660586, -2.3984381518171647, -2.373476998768694, -2.3480882890366326, -2.322282968796417, -2.296072381604121, -2.2694682866676, -2.242482878809005, -2.21512881027975, -2.1874192146045517, -2.1593677326479277, -2.130988541114804, -2.1022963837164723, -2.0733066052541953, -2.0440351888951405, -2.0144987969389625, -1.9847148153980312, -1.9547014027397098, -1.9244775431647427, -1.8940631048210486, -1.8634789033761108, -1.832746771392403, -1.8018896339672383, -1.7709315911087564, -1.7398980073205919, -1.7088156088551993, -1.6777125890650386, -1.6466187222255564, -1.615565486116383, -1.5845861935176684, -1.553716132595047, -1.5229927158949277, -1.492455637334268, -1.4621470361255762, -1.4321116660053739, -1.402397067407179, -1.373053739311277, -1.3441353063864132, -1.3156986756900166, -1.287804175598539, -1.2605156677977374, -1.2339006210979337, -1.2080301336107313, -1.1829788875405385, -1.1588250186809899, -1.1356498809175943, -1.1135376849687966, -1.0925749906835762, -1.0728500339630356, -1.0544518733228487, -1.0374693477501329, -1.0219898471552102, -1.0080979093898759, -0.9958736730509448, -0.9853912320771159, -0.976716954816888, -0.9699078446008993, -0.9650100284326271, -0.9620574629199414, -0.9610709403987197, -0.9620574629199433, -0.9650100284326311, -0.9699078446009053, -0.976716954816896, -0.9853912320771259, -0.9958736730509564, -1.0080979093898892, -1.0219898471552253, -1.0374693477501493, -1.0544518733228672, -1.072850033963055, -1.092574990683597, -1.1135376849688188, -1.1356498809176174, -1.158825018681014, -1.182978887540564, -1.2080301336107573, -1.2339006210979606, -1.2605156677977651, -1.2878041755985674, -1.3156986756900455, -1.3441353063864425, -1.3730537393113071, -1.4023970674072097, -1.4321116660054047, -1.4621470361256073, -1.492455637334299, -1.5229927158949594, -1.5537161325950786, -1.5845861935176997, -1.6155654861164148, -1.6466187222255888, -1.6777125890650708, -1.7088156088552315, -1.739898007320624, -1.7709315911087884, -1.80188963396727, -1.8327467713924348, -1.863478903376142, -1.89406310482108, -1.9244775431647736, -1.954701402739741, -1.9847148153980623, -2.014498796938993, -2.0440351888951707, -2.073306605254225, -2.1022963837165016, -2.1309885411148333, -2.159367732647957, -2.18741921460458, -2.215128810279778, -2.2424828788090325, -2.2694682866676277, -2.2960723816041475, -2.3222829687964435, -2.3480882890366592, -2.3734769987687203, -2.3984381518171896, -2.422961182660611, -2.447035891115472, -2.4706524283088354, -2.493801283828538, -2.5164732739497584, -2.5386595308457784, -2.5603514926989424, -2.581540894635319, -2.6022197604133144, -2.6223803948026636, -2.64201537659586, -2.6611175521991175, -2.6796800297546484, -2.6976961737502196, -2.715159600075781, -2.732064171490459, -2.748403993466367, -2.764173410378588, -2.7793670020133043, -2.793979580368475, -2.8080061867236297, -2.8214420889573844, -2.8342827790930882, -2.8465239710547134, -2.8581615986166358, -2.869191813532359, -2.8796109838285475, -2.889415692251925, -2.8986027348576964, -2.9071691197291902, -2.91511206581933, -2.922429001905465, -2.929117565649865, -2.9351756027589846, -2.940601166235286, -2.9453925157160996, -2.9495481168946314, -2.9530666410188227, -2.955946964464327, -2.9581881683784554, -2.959789538392401, -2.960750564399623], [-2.9520131075327245, -2.9516932327788132, -2.950733710036212, -2.9491348438929395, -2.9468971420980146, -2.9440213157157364, -2.9405082793433217, -2.9363591513935154, -2.931575254444316, -2.926158115658446, -2.9201094672757155, -2.9134312471819666, -2.9061255995588615, -2.8981948756193563, -2.8896416344343523, -2.880468643856655, -2.870678881549119, -2.8602755361245595, -2.84926200840589, -2.8376419128157524, -2.825419078905896, -2.8125975530375524, -2.7991816002251464, -2.785175706156906, -2.77058457940718, -2.7554131538567277, -2.7396665913387483, -2.7233502845301047, -2.706469860109012, -2.689031182202483, -2.671040356148984, -2.6525037326041807, -2.6334279120202524, -2.61381974953217, -2.593686360287489, -2.5730351252596804, -2.5518736975888814, -2.5302100094981332, -2.508052279837823, -2.4854090223161482, -2.4622890544790406, -2.4387015075091645, -2.414655836920423, -2.390161834231898, -2.365229639713408, -2.339869756303914, -2.3140930648140214, -2.2879108405347557, -2.261334771386792, -2.234376977757535, -2.207050034187796, -2.1793669930855417, -2.151341410661303, -2.122987375298334, -2.094319538590664, -2.0653531493037005, -2.0361040905349927, -2.0065889203771277, -1.9768249164102198, -1.946830124377882, -1.9166234114273977, -1.8862245243214761, -1.8556541530545385, -1.824934000329702, -1.794086857371885, -1.7631366865654858, -1.7321087114090072, -1.7010295142700225, -1.6699271423971331, -1.6388312225948494, -1.6077730848847929, -1.5767858953525, -1.5459047982012983, -1.5151670667885386, -1.484612263087193, -1.4542824045767055, -1.4242221369970363, -1.3944789106724507, -1.365103157198189, -1.336148462155338, -1.3076717281513213, -1.2797333208577666, -1.2523971888304641, -1.2257309457682493, -1.1998059015551052, -1.1746970260399063, -1.1504828272154708, -1.1272451235213523, -1.105068688766813, -1.0840407481030179, -1.0642503050987748, -1.0457872838612288, -1.028741476817827, -1.0132012986020378, -0.9992523595101818, -0.9869758877867739, -0.9764470474995063, -0.9677332162603894, -0.9608923022356295, -0.9559711901595447, -0.9530044089755739, -0.9520131075327244, -0.9530044089755758, -0.9559711901595486, -0.9608923022356355, -0.9677332162603975, -0.9764470474995163, -0.9869758877867857, -0.9992523595101953, -1.013201298602053, -1.0287414768178438, -1.0457872838612472, -1.0642503050987948, -1.084040748103039, -1.1050686887668353, -1.1272451235213756, -1.1504828272154952, -1.1746970260399314, -1.1998059015551317, -1.2257309457682763, -1.252397188830492, -1.2797333208577946, -1.3076717281513506, -1.3361484621553676, -1.365103157198219, -1.3944789106724809, -1.4242221369970673, -1.4542824045767366, -1.4846122630872245, -1.5151670667885702, -1.54590479820133, -1.5767858953525318, -1.6077730848848246, -1.6388312225948813, -1.6699271423971656, -1.7010295142700549, -1.7321087114090394, -1.7631366865655174, -1.7940868573719166, -1.8249340003297336, -1.8556541530545698, -1.8862245243215074, -1.916623411427429, -1.9468301243779131, -1.9768249164102505, -2.006588920377158, -2.036104090535023, -2.06535314930373, -2.094319538590694, -2.1229873752983632, -2.1513414106613324, -2.17936699308557, -2.207050034187824, -2.2343769777575635, -2.2613347713868195, -2.287910840534783, -2.3140930648140485, -2.3398697563039397, -2.365229639713434, -2.3901618342319235, -2.4146558369204474, -2.438701507509189, -2.4622890544790645, -2.4854090223161713, -2.5080522798378455, -2.5302100094981554, -2.551873697588903, -2.573035125259702, -2.59368636028751, -2.613819749532191, -2.633427912020272, -2.6525037326042007, -2.671040356149003, -2.6890311822025006, -2.7064698601090296, -2.723350284530122, -2.7396665913387652, -2.7554131538567437, -2.770584579407195, -2.785175706156921, -2.7991816002251606, -2.8125975530375658, -2.8254190789059095, -2.837641912815765, -2.8492620084059017, -2.86027553612457, -2.8706788815491286, -2.8804686438566645, -2.8896416344343607, -2.898194875619365, -2.9061255995588695, -2.913431247181974, -2.9201094672757217, -2.9261581156584517, -2.9315752544443217, -2.9363591513935203, -2.940508279343326, -2.94402131571574, -2.946897142098017, -2.9491348438929412, -2.9507337100362134, -2.9516932327788146], [-2.942034263469983, -2.941714944501889, -2.940757088598026, -2.9391609987896485, -2.9369271802290813, -2.934056340340866, -2.9305493890349865, -2.9264074389837886, -2.9216318059646964, -2.9162240092713527, -2.9101857721962676, -2.9035190225886676, -2.8962258934917267, -2.888308723864004, -2.8797700593905162, -2.870612653389515, -2.860839467821785, -2.850453674409983, -2.8394586558763844, -2.8278580073082367, -2.8156555376608816, -2.8028552714097894, -2.789461450363757, -2.775478535652704, -2.7609112099047777, -2.7457643796288926, -2.730043177820335, -2.7137529668087574, -2.6968993413696825, -2.6794881321226396, -2.6615254092412415, -2.64301748650289, -2.62397092570843, -2.604392541504954, -2.584289406648117, -2.5636688577438025, -2.542538501512828, -2.520906221626561, -2.4987801861659826, -2.4761688557618404, -2.4530809924791583, -2.42952566951558, -2.4055122817898624, -2.381050557504368, -2.356150570773695, -2.3308227554207317, -2.3050779200514726, -2.2789272645309944, -2.252382397995112, -2.2254553585456014, -2.1981586347914233, -2.1705051894143543, -2.142508484954822, -2.114182512032612, -2.0855418202376135, -2.0566015519477547, -2.0273774793549544, -1.9978860450049518, -1.9681444061833662, -1.9381704835078029, -1.9079830141140184, -1.8776016098523693, -1.8470468209381803, -1.816340205525121, -1.785504405692475, -1.754563230353254, -1.7235417455975155, -1.6924663729802933, -1.6613649962413772, -1.6302670768986267, -1.5992037790796692, -1.5682081038388975, -1.537315033035414, -1.5065616826079589, -1.4759874647568718, -1.4456342581093604, -1.4155465843778925, -1.3857717892946488, -1.3563602246873363, -1.3273654274227893, -1.2988442895563406, -1.270857212365879, -1.2434682350126418, -1.2167451263725884, -1.1907594261753276, -1.1655864190766543, -1.1413050228500619, -1.117997569774066, -1.09574945887911, -1.0746486564690931, -1.0547850238074696, -1.0362494546629168, -1.019132812116312, -1.003524664050789, -0.9895118301683569, -0.9771767697860266, -0.9665958579925513, -0.9578376162035257, -0.950960979313363, -0.9460136927356064, -0.9430309360127292, -0.9420342634699831, -0.9430309360127312, -0.9460136927356105, -0.950960979313369, -0.9578376162035337, -0.9665958579925614, -0.9771767697860383, -0.9895118301683703, -1.0035246640508042, -1.0191328121163288, -1.0362494546629353, -1.0547850238074894, -1.0746486564691142, -1.095749458879132, -1.1179975697740896, -1.1413050228500865, -1.1655864190766796, -1.190759426175354, -1.2167451263726154, -1.2434682350126696, -1.2708572123659074, -1.2988442895563697, -1.3273654274228188, -1.3563602246873663, -1.3857717892946793, -1.4155465843779234, -1.4456342581093915, -1.4759874647569033, -1.5065616826079904, -1.5373150330354461, -1.5682081038389293, -1.599203779079701, -1.6302670768986587, -1.6613649962414094, -1.6924663729803253, -1.7235417455975475, -1.7545632303532857, -1.7855044056925065, -1.8163402055251525, -1.8470468209382116, -1.8776016098524002, -1.90798301411405, -1.9381704835078335, -1.968144406183397, -1.997886045004982, -2.027377479354984, -2.0566015519477845, -2.085541820237643, -2.1141825120326416, -2.142508484954851, -2.170505189414383, -2.1981586347914512, -2.225455358545629, -2.252382397995139, -2.2789272645310215, -2.3050779200514997, -2.330822755420758, -2.356150570773721, -2.381050557504394, -2.4055122817898873, -2.429525669515604, -2.453080992479182, -2.476168855761864, -2.4987801861660057, -2.520906221626584, -2.5425385015128503, -2.563668857743824, -2.584289406648138, -2.6043925415049745, -2.62397092570845, -2.643017486502909, -2.6615254092412606, -2.679488132122658, -2.6968993413697, -2.7137529668087748, -2.730043177820352, -2.745764379628909, -2.760911209904793, -2.7754785356527183, -2.789461450363771, -2.8028552714098036, -2.815655537660895, -2.827858007308249, -2.839458655876396, -2.8504536744099935, -2.8608394678217954, -2.8706126533895246, -2.879770059390525, -2.888308723864013, -2.896225893491734, -2.903519022588675, -2.9101857721962743, -2.9162240092713585, -2.921631805964702, -2.9264074389837926, -2.930549389034991, -2.934056340340869, -2.9369271802290835, -2.9391609987896503, -2.940757088598027, -2.94171494450189], [-2.931144062097653, -2.930825353993515, -2.9298693301155945, -2.9282762917966876, -2.9260467413560742, -2.9231813822472246, -2.919681119266208, -2.9155470588223715, -2.910780509273392, -2.9053829813272865, -2.899356188514435, -2.8927020477332666, -2.8854226798737455, -2.877520410523438, -2.8689977707615064, -2.859857498046671, -2.850102537205849, -2.8397360415309496, -2.8287613739920676, -2.8171821085762256, -2.805002031761689, -2.7922251441389108, -2.7788556621902543, -2.7648980202417657, -2.7503568726016185, -2.7352370959011836, -2.71954379165623, -2.7032822890674018, -2.6864581480809324, -2.6690771627325556, -2.6511453647997065, -2.6326690277895426, -2.6136546712928665, -2.5941090657369825, -2.5740392375735954, -2.5534524749414045, -2.5323563338468396, -2.5107586449105974, -2.4886675207323, -2.4660913639307003, -2.443038875922508, -2.419519066509142, -2.3955412643475604, -2.371115128388918, -2.3462506603771174, -2.320958218508553, -2.2952485323644565, -2.2691327192384336, -2.242622301994057, -2.215729228600857, -2.1884658935118644, -2.160845161062056, -2.13288039108475, -2.104585466962285, -2.075974826348233, -2.0470634948210065, -2.017867122753029, -1.988402025705548, -1.9586852286866292, -1.9287345146385697, -1.8985684775505778, -1.868206580622517, -1.8376692199349722, -1.8069777941087535, -1.7761547804616271, -1.7452238181894566, -1.714209799110251, -1.683138966509164, -1.6520390226054564, -1.6209392451227074, -1.5898706133731961, -1.558865944156529, -1.527960037608815, -1.4971898329068247, -1.466594573413017, -1.4362159804200947, -1.4060984340920306, -1.3762891594730557, -1.3468384145149601, -1.3177996759231547, -1.2892298172119847, -1.2611892716649675, -1.2337421709044485, -1.2069564474994627, -1.1809038875285955, -1.1556601163676103, -1.1313044983629545, -1.1079199287473473, -1.0855924945259372, -1.0644109805992406, -1.0444661986822714, -1.0258501202773607, -1.0086548016857897, -0.9929710992693408, -0.9788871870354906, -0.9664869057315042, -0.9558479919073133, -0.9470402549783938, -0.9401237876213311, -0.9351473068977111, -0.9321467274731127, -0.9311440620976529, -0.9321467274731147, -0.9351473068977152, -0.9401237876213374, -0.947040254978402, -0.9558479919073234, -0.9664869057315159, -0.9788871870355043, -0.9929710992693562, -1.0086548016858066, -1.0258501202773789, -1.0444661986822912, -1.0644109805992616, -1.0855924945259592, -1.1079199287473707, -1.1313044983629792, -1.1556601163676357, -1.180903887528622, -1.2069564474994896, -1.2337421709044767, -1.2611892716649962, -1.2892298172120136, -1.3177996759231843, -1.3468384145149903, -1.3762891594730862, -1.4060984340920617, -1.4362159804201258, -1.466594573413048, -1.4971898329068565, -1.527960037608847, -1.5588659441565607, -1.5898706133732279, -1.620939245122739, -1.6520390226054884, -1.683138966509196, -1.714209799110283, -1.745223818189488, -1.7761547804616586, -1.806977794108785, -1.8376692199350033, -1.868206580622548, -1.8985684775506093, -1.9287345146386004, -1.9586852286866598, -1.9884020257055783, -2.017867122753059, -2.0470634948210362, -2.0759748263482622, -2.1045854669623147, -2.1328803910847784, -2.1608451610620842, -2.1884658935118924, -2.215729228600885, -2.2426223019940847, -2.2691327192384607, -2.295248532364483, -2.3209582185085798, -2.346250660377143, -2.3711151283889427, -2.3955412643475853, -2.4195190665091664, -2.443038875922532, -2.4660913639307234, -2.488667520732323, -2.51075864491062, -2.5323563338468613, -2.553452474941426, -2.574039237573616, -2.5941090657370034, -2.613654671292887, -2.6326690277895617, -2.651145364799726, -2.669077162732573, -2.6864581480809497, -2.7032822890674186, -2.719543791656247, -2.7352370959012, -2.750356872601633, -2.76489802024178, -2.7788556621902685, -2.7922251441389245, -2.8050020317617013, -2.8171821085762385, -2.828761373992079, -2.8397360415309603, -2.85010253720586, -2.85985749804668, -2.8689977707615153, -2.8775204105234464, -2.8854226798737534, -2.892702047733273, -2.899356188514442, -2.9053829813272922, -2.9107805092733976, -2.9155470588223755, -2.9196811192662127, -2.9231813822472277, -2.9260467413560765, -2.9282762917966902, -2.9298693301155962, -2.9308253539935154], [-2.919353038982229, -2.9190349974107903, -2.918080972518459, -2.9164912637997635, -2.914266370507721, -2.911406991797825, -2.907914026931201, -2.903788575538521, -2.8990319379467246, -2.8936456155711117, -2.8876313113758196, -2.880990930406296, -2.8737265803978493, -2.8658405724650007, -2.857335421876926, -2.8482138489249493, -2.8384787798887334, -2.8281333481085316, -2.8171808951716955, -2.805624972222443, -2.7934693414048293, -2.7807179774498523, -2.7673750694186956, -2.75344502261529, -2.73893246068261, -2.7238422278985523, -2.7081793916887076, -2.6919492453750022, -2.6751573111809956, -2.657809343516569, -2.639911332566922, -2.621469508213162, -2.6024903443143725, -2.5829805633839213, -2.562947141695896, -2.542397314861083, -2.521338583915637, -2.4997787219699026, -2.477725781469412, -2.455188102125253, -2.432174319576657, -2.4086933748548645, -2.384754524724267, -2.360367352984382, -2.33554178282466, -2.3102880903333562, -2.284616919271938, -2.2585392972377765, -2.232066653350267, -2.205210837609208, -2.177984142089262, -2.1503993241508135, -2.1224696318655476, -2.0942088318747762, -2.0656312399199592, -2.036751754308064, -2.0075858925994754, -1.9781498318329642, -1.9484604526307638, -1.9185353875567985, -1.8883930741323058, -1.8580528129448861, -1.8275348313187292, -1.7968603530442686, -1.7660516746933257, -1.7351322490688923, -1.7041267763543118, -1.67306130353117, -1.6419633326239254, -1.6108619382960914, -1.57978789525975, -1.5487738158573472, -1.5178542980196137, -1.4870660835805027, -1.456448226620345, -1.4260422710891758, -1.3958924364066323, -1.3660458090121645, -1.3365525369156588, -1.3074660231380653, -1.278843112499655, -1.2507442644809004, -1.2232337028313178, -1.196379530241223, -1.170253793763146, -1.1449324838705446, -1.1204954472431972, -1.097026190839591, -1.074611552940918, -1.053341216138198, -1.0333070383082084, -1.01460218118363, -0.9973200228546009, -0.9815528509792409, -0.9673903478289373, -0.9549178961970448, -0.9442147555568947, -0.935352178715795, -0.9283915578463061, -0.9233827019856715, -0.9203623527674429, -0.9193530389822292, -0.9203623527674449, -0.9233827019856758, -0.9283915578463124, -0.9353521787158031, -0.9442147555569049, -0.9549178961970566, -0.9673903478289511, -0.9815528509792563, -0.9973200228546177, -1.0146021811836488, -1.0333070383082281, -1.0533412161382194, -1.0746115529409401, -1.0970261908396144, -1.1204954472432216, -1.1449324838705701, -1.170253793763172, -1.1963795302412503, -1.2232337028313456, -1.250744264480929, -1.278843112499684, -1.307466023138095, -1.336552536915689, -1.366045809012195, -1.395892436406663, -1.426042271089207, -1.456448226620376, -1.4870660835805343, -1.517854298019645, -1.5487738158573787, -1.5797878952597817, -1.6108619382961236, -1.641963332623957, -1.673061303531202, -1.7041267763543437, -1.735132249068924, -1.7660516746933574, -1.7968603530443004, -1.8275348313187614, -1.8580528129449179, -1.8883930741323367, -1.918535387556829, -1.9484604526307943, -1.9781498318329953, -2.0075858925995056, -2.036751754308094, -2.0656312399199885, -2.0942088318748056, -2.1224696318655765, -2.1503993241508423, -2.17798414208929, -2.2052108376092354, -2.232066653350294, -2.258539297237803, -2.284616919271964, -2.3102880903333816, -2.3355417828246856, -2.3603673529844067, -2.3847545247242916, -2.408693374854889, -2.4321743195766805, -2.4551881021252764, -2.4777257814694345, -2.499778721969925, -2.521338583915659, -2.542397314861104, -2.5629471416959175, -2.5829805633839413, -2.602490344314393, -2.6214695082131807, -2.6399113325669403, -2.657809343516587, -2.675157311181014, -2.691949245375019, -2.708179391688724, -2.723842227898568, -2.738932460682625, -2.753445022615304, -2.7673750694187094, -2.780717977449865, -2.793469341404842, -2.8056249722224553, -2.8171808951717066, -2.8281333481085422, -2.838478779888744, -2.8482138489249595, -2.8573354218769342, -2.8658405724650087, -2.873726580397857, -2.880990930406303, -2.8876313113758263, -2.8936456155711174, -2.8990319379467304, -2.9037885755385258, -2.907914026931205, -2.9114069917978287, -2.9142663705077236, -2.916491263799765, -2.9180809725184598, -2.9190349974107908], [-2.906672601177065, -2.906355282451253, -2.905403425437407, -2.903817327654064, -2.9015974850582498, -2.8987445921854404, -2.8952595423470657, -2.8911434278871178, -2.886397540499885, -2.881023371611338, -2.875022612827157, -2.868397156450934, -2.8611490960766024, -2.853280727259747, -2.8447945482730104, -2.835693260951481, -2.8259797716346267, -2.815657192212046, -2.8047288412811238, -2.7931982454254785, -2.781069140624048, -2.768345473801587, -2.7550314045324624, -2.7411313069107472, -2.7266497716009153, -2.711591608084759, -2.6959618471216937, -2.679765743441222, -2.663008778688125, -2.645696664642907, -2.627835346742183, -2.609431007926042, -2.590490072842018, -2.5710192124381748, -2.551025348980913, -2.5305156615366196, -2.5094975919600464, -2.4879788514365573, -2.4659674276299937, -2.4434715924930597, -2.4204999108027856, -2.3970612494898877, -2.3731647878377533, -2.3488200286344374, -2.324036810369496, -2.2988253205767952, -2.2731961104348, -2.247160110747161, -2.220728649439014, -2.193913470718266, -2.1667267560663177, -2.1391811472394995, -2.1112897714808123, -2.0830662691617228, -2.0545248240956777, -2.0256801967888864, -1.9965477609197242, -1.9671435433659006, -1.9374842681282054, -1.9075874045310646, -1.8774712201129875, -1.8471548386538352, -1.8166583038199566, -1.78600264894162, -1.7552099734684172, -1.7243035266754236, -1.6933077992132621, -1.6622486231052758, -1.6311532807901177, -1.6000506237821142, -1.568971201466955, -1.5379474004565208, -1.5070135947814067, -1.4762063069871239, -1.4455643799006308, -1.4151291584243368, -1.3849446801670091, -1.3550578730029448, -1.3255187567259725, -1.2963806447947608, -1.2677003407118166, -1.2395383218066365, -1.2119589010814775, -1.1850303553261587, -1.1588250049525053, -1.133419228031052, -1.1088933880012808, -1.0853316517428042, -1.0628216725333999, -1.0414541114128117, -1.021321971281734, -1.0025197214474715, -0.9851421970395193, -0.9692832683766032, -0.9550342902449852, -0.9424823598385675, -0.93170843370353, -0.922785376380804, -0.9157760336319325, -0.910731437700055, -0.907689257580106, -0.9066726011770648, -0.9076892575801082, -0.910731437700059, -0.9157760336319388, -0.9227853763808122, -0.9317084337035402, -0.9424823598385798, -0.9550342902449991, -0.9692832683766186, -0.9851421970395364, -1.0025197214474901, -1.021321971281754, -1.0414541114128328, -1.0628216725334225, -1.0853316517428278, -1.1088933880013054, -1.1334192280310775, -1.158825004952532, -1.185030355326186, -1.2119589010815055, -1.239538321806665, -1.2677003407118457, -1.2963806447947905, -1.3255187567260027, -1.3550578730029752, -1.3849446801670402, -1.415129158424368, -1.4455643799006623, -1.4762063069871554, -1.5070135947814387, -1.5379474004565523, -1.568971201466987, -1.600050623782146, -1.6311532807901497, -1.662248623105308, -1.6933077992132939, -1.7243035266754554, -1.7552099734684485, -1.7860026489416516, -1.816658303819988, -1.8471548386538665, -1.8774712201130184, -1.9075874045310952, -1.9374842681282363, -1.9671435433659308, -1.9965477609197548, -2.0256801967889166, -2.0545248240957075, -2.083066269161752, -2.111289771480841, -2.1391811472395275, -2.1667267560663457, -2.1939134707182935, -2.2207286494390415, -2.247160110747188, -2.2731961104348275, -2.2988253205768214, -2.3240368103695217, -2.348820028634463, -2.3731647878377773, -2.3970612494899117, -2.4204999108028096, -2.443471592493083, -2.4659674276300168, -2.48797885143658, -2.5094975919600677, -2.530515661536641, -2.551025348980934, -2.571019212438195, -2.590490072842038, -2.6094310079260605, -2.6278353467422018, -2.645696664642925, -2.663008778688143, -2.679765743441239, -2.6959618471217097, -2.711591608084775, -2.7266497716009304, -2.7411313069107615, -2.755031404532476, -2.768345473801601, -2.7810691406240613, -2.793198245425491, -2.8047288412811353, -2.8156571922120572, -2.8259797716346364, -2.8356932609514907, -2.844794548273019, -2.8532807272597553, -2.86114909607661, -2.868397156450941, -2.8750226128271636, -2.881023371611344, -2.8863975404998903, -2.8911434278871218, -2.89525954234707, -2.8987445921854436, -2.901597485058252, -2.9038173276540657, -2.905403425437408, -2.9063552824512535], [-2.8931150161867834, -2.8927984773178004, -2.891848959170924, -2.890266757153281, -2.888052363700009, -2.885206468409906, -2.8817299582368703, -2.877623917738668, -2.8728896293850315, -2.867528573927563, -2.86154243083439, -2.854933078793069, -2.8477025962857074, -2.8398532622409087, -2.8313875567676665, -2.8223081619770216, -2.8126179628979435, -2.8023200484946065, -2.791417712793047, -2.779914456125954, -2.767813986505316, -2.7551202211335544, -2.741837288064873, -2.7279695280296705, -2.713521496436116, -2.6984979655643566, -2.682903926970289, -2.6667445941174583, -2.650025405257441, -2.6327520265809694, -2.614930355664254, -2.5965665252372445, -2.5776669073032017, -2.5582381176417677, -2.5382870207308543, -2.517820735126136, -2.4968466393407107, -2.4753723782717434, -2.453405870225484, -2.4309553145972522, -2.408029200268588, -2.3846363147900997, -2.360785754425423, -2.336486935139425, -2.3117496046222668, -2.2865838554503233, -2.2610001394953776, -2.2350092837049784, -2.2086225073895753, -2.1818514411660392, -2.1547081477226824, -2.1272051445878923, -2.0993554291032726, -2.071172505822703, -2.042670416581262, -2.0138637735024663, -1.9847677952389402, -1.955398346770423, -1.9257719831139113, -1.895905997333649, -1.8658184732733252, -1.8355283434688594, -1.8050554527368647, -1.7744206279703938, -1.7436457547085091, -1.7127538610777417, -1.6817692097290289, -1.6507173984098544, -1.6196254698134454, -1.5885220313290167, -1.557437385271428, -1.5264036700851247, -1.4954550128832091, -1.4646276934818148, -1.4339603198028301, -1.4034940141201633, -1.37327260908705, -1.343342851770474, -1.3137546129948723, -1.2845610981190392, -1.2558190538945995, -1.2275889642422197, -1.199935225604148, -1.172926289981162, -1.1466347608671756, -1.1211374241401304, -1.096515192718107, -1.0728529407169323, -1.0502392003555259, -1.028765693504303, -1.0085266702655318, -0.9896180301298881, -0.9721362079115831, -0.9561768175372642, -0.9418330622154432, -0.9291939392957129, -0.9183422911253725, -0.9093527772820371, -0.9022898655744847, -0.897205955378033, -0.8941397534231333, -0.8931150161867832, -0.8941397534231356, -0.8972059553780373, -0.9022898655744909, -0.9093527772820453, -0.9183422911253828, -0.929193939295725, -0.9418330622154569, -0.9561768175372798, -0.9721362079116003, -0.989618030129907, -1.0085266702655518, -1.0287656935043243, -1.0502392003555483, -1.072852940716956, -1.0965151927181316, -1.1211374241401562, -1.1466347608672023, -1.1729262899811894, -1.1999352256041758, -1.227588964242248, -1.2558190538946288, -1.2845610981190692, -1.3137546129949025, -1.3433428517705048, -1.3732726090870808, -1.4034940141201944, -1.4339603198028616, -1.4646276934818463, -1.4954550128832411, -1.5264036700851566, -1.5574373852714598, -1.588522031329049, -1.6196254698134775, -1.6507173984098864, -1.6817692097290604, -1.7127538610777735, -1.7436457547085407, -1.774420627970425, -1.8050554527368963, -1.835528343468891, -1.8658184732733567, -1.8959059973336798, -1.925771983113942, -1.955398346770453, -1.9847677952389704, -2.013863773502496, -2.042670416581292, -2.0711725058227324, -2.099355429103301, -2.1272051445879208, -2.1547081477227104, -2.1818514411660668, -2.2086225073896024, -2.235009283705005, -2.261000139495404, -2.2865838554503495, -2.3117496046222925, -2.33648693513945, -2.3607857544254474, -2.384636314790124, -2.408029200268612, -2.430955314597275, -2.453405870225507, -2.475372378271766, -2.496846639340733, -2.5178207351261563, -2.538287020730875, -2.5582381176417877, -2.5776669073032217, -2.5965665252372636, -2.614930355664273, -2.632752026580987, -2.650025405257458, -2.666744594117475, -2.6829039269703054, -2.6984979655643735, -2.713521496436131, -2.7279695280296847, -2.7418372880648874, -2.7551202211335677, -2.7678139865053284, -2.779914456125966, -2.7914177127930584, -2.802320048494617, -2.8126179628979533, -2.822308161977031, -2.831387556767675, -2.8398532622409176, -2.8477025962857145, -2.8549330787930756, -2.8615424308343966, -2.8675285739275687, -2.872889629385037, -2.877623917738672, -2.8817299582368743, -2.885206468409909, -2.888052363700011, -2.8902667571532827, -2.8918489591709253, -2.8927984773178013], [-2.8786934000992597, -2.8783776988512004, -2.877430692819297, -2.875852675166371, -2.8736441345839894, -2.870805755423511, -2.8673384178810575, -2.8632431982379174, -2.8585213691583546, -2.853174400047264, -2.847203957470551, -2.840611905641703, -2.8334003069784357, -2.825571422733951, -2.8171277137078654, -2.8080718410425063, -2.7984066671109584, -2.7881352565039124, -2.777260877123172, -2.7657870013904606, -2.7537173075810895, -2.7410556812929667, -2.7278062170625166, -2.7139732201401707, -2.6995612084393366, -2.6845749146741067, -2.669019288702421, -2.6528995000930133, -2.636220940936223, -2.618989228920707, -2.6012102107001693, -2.5828899655766064, -2.5640348095290793, -2.5446512996198956, -2.5247462388131727, -2.5043266812442013, -2.4833999379818117, -2.461973583330174, -2.440055461721037, -2.4176536952526106, -2.394776691936909, -2.371433154723696, -2.3476320913761137, -2.323382825280784, -2.2986950072837136, -2.273578628652788, -2.2480440352781366, -2.2221019432332176, -2.1957634558323536, -2.1690400823346434, -2.1419437584598677, -2.1144868688993532, -2.08668227202387, -2.0585433270116362, -2.0300839236426005, -2.0013185150303703, -1.9722621535907146, -1.9429305305753741, -1.9133400195321415, -1.8835077240866285, -1.8534515304777182, -1.823190165317017, -1.792743259082118, -1.7621314158933539, -1.7313762901626453, -1.7005006707393313, -1.669528573209033, -1.6384853410243616, -1.6073977561561297, -1.5762941599448255, -1.5452045847966742, -1.5141608972966403, -1.483196953189397, -1.4523487644923043, -1.4216546787315234, -1.3911555699084892, -1.3608950402788262, -1.3309196313235994, -1.301279041372368, -1.272026346153286, -1.243218217049827, -1.2149151299911265, -1.187181555657164, -1.1600861190248055, -1.133701713235394, -1.1081055494049044, -1.0833791204823715, -1.0596080538633645, -1.0368818245982747, -1.0152932992822918, -0.9949380808269568, -0.9759136271807296, -0.9583181236249039, -0.9422490993458487, -0.9278017950496363, -0.9150673092709508, -0.9041305756251529, -0.8950682493106685, -0.887946605315578, -0.8828195688669873, -0.879727006467974, -0.8786934000992599, -0.8797270064679761, -0.8828195688669914, -0.8879466053155843, -0.8950682493106772, -0.9041305756251633, -0.915067309270963, -0.9278017950496504, -0.9422490993458643, -0.9583181236249212, -0.9759136271807484, -0.994938080826977, -1.0152932992823136, -1.0368818245982974, -1.0596080538633883, -1.0833791204823962, -1.10810554940493, -1.1337017132354206, -1.160086119024833, -1.1871815556571923, -1.2149151299911551, -1.2432182170498565, -1.272026346153316, -1.3012790413723982, -1.3309196313236298, -1.360895040278857, -1.3911555699085207, -1.4216546787315547, -1.4523487644923356, -1.4831969531894287, -1.514160897296672, -1.545204584796706, -1.5762941599448574, -1.6073977561561617, -1.6384853410243936, -1.6695285732090648, -1.700500670739363, -1.7313762901626772, -1.7621314158933856, -1.7927432590821493, -1.8231901653170481, -1.8534515304777492, -1.883507724086659, -1.9133400195321721, -1.9429305305754043, -1.9722621535907443, -2.0013185150304, -2.03008392364263, -2.058543327011665, -2.086682272023898, -2.1144868688993816, -2.1419437584598957, -2.169040082334671, -2.1957634558323806, -2.2221019432332443, -2.2480440352781637, -2.273578628652814, -2.298695007283739, -2.3233828252808095, -2.347632091376139, -2.37143315472372, -2.3947766919369333, -2.4176536952526346, -2.4400554617210597, -2.461973583330196, -2.4833999379818334, -2.5043266812442218, -2.5247462388131936, -2.544651299619915, -2.564034809529099, -2.5828899655766255, -2.6012102107001875, -2.6189892289207246, -2.636220940936241, -2.6528995000930298, -2.669019288702437, -2.6845749146741222, -2.699561208439351, -2.7139732201401854, -2.7278062170625303, -2.7410556812929796, -2.753717307581102, -2.765787001390472, -2.7772608771231835, -2.788135256503924, -2.7984066671109686, -2.808071841042516, -2.8171277137078743, -2.8255714227339594, -2.8334003069784433, -2.84061190564171, -2.847203957470558, -2.8531744000472696, -2.85852136915836, -2.8632431982379214, -2.867338417881061, -2.8708057554235142, -2.8736441345839916, -2.8758526751663727, -2.8774306928192974, -2.878377698851201], [-2.863421704896654, -2.863106899841666, -2.8621625815978224, -2.860589040953505, -2.858386762639632, -2.8555564254558163, -2.8520989024484593, -2.8480152611422813, -2.8433067638271985, -2.8379748679029553, -2.832021226284357, -2.8254476878704677, -2.8182562980816317, -2.810449299468743, -2.802029132399747, -2.7929984358289817, -2.783360048155607, -2.7731170081780867, -2.762272556152416, -2.7508301349626243, -2.73879339141293, -2.7261661776518857, -2.7129525527398846, -2.699156784372496, -2.6847833507733374, -2.6698369427715, -2.6543224660800195, -2.638245043793446, -2.621610019124338, -2.604422958400394, -2.5866896543460656, -2.568416129674779, -2.5496086410204586, -2.5302736832398582, -2.510417994120279, -2.4900485595307056, -2.4691726190581447, -2.447797672175149, -2.4259314849891194, -2.4035820976291196, -2.380757832331587, -2.357467302292636, -2.3337194213615935, -2.3095234146581753, -2.2848888302042503, -2.2598255516706875, -2.2343438123503203, -2.208454210479776, -2.182167726045903, -2.155495739226932, -2.1284500506344113, -2.101042903539625, -2.073287008287658, -2.045195569123769, -2.016782313680382, -1.9880615253989706, -1.9590480791895128, -1.9297574806611584, -1.9002059092912773, -1.870410265936208, -1.840388225125593, -1.810158292622955, -1.7797398687776402, -1.7491533182366654, -1.7184200466282311, -1.6875625848700821, -1.6566046817931284, -1.6255714058007324, -1.5944892563023614, -1.5633862856612453, -1.5322922323715817, -1.5012386661217088, -1.4702591452926923, -1.4393893872704318, -1.408667451692974, -1.378133936387442, -1.3478321852413209, -1.3178085065631335, -1.2881123995738073, -1.2587967854828717, -1.2299182380901488, -1.2015372069614543, -1.173718223911251, -1.1465300807597996, -1.1200459631253061, -1.094343521427844, -1.069504856471789, -1.0456163932068978, -1.02276861296949, -1.0010556122829044, -0.9805744559528936, -0.9614242946975774, -0.9437052239503043, -0.9275168717249267, -0.9129567201464455, -0.9001181873577423, -0.8890885229255295, -0.8799465982242454, -0.872760699926736, -0.867586455093203, -0.86446502568869, -0.863421704896654, -0.8644650256886921, -0.8675864550932072, -0.8727606999267425, -0.8799465982242538, -0.8890885229255401, -0.9001181873577545, -0.9129567201464597, -0.9275168717249423, -0.9437052239503217, -0.9614242946975963, -0.9805744559529138, -1.001055612282926, -1.0227686129695128, -1.0456163932069218, -1.0695048564718141, -1.09434352142787, -1.120045963125333, -1.146530080759827, -1.1737182239112791, -1.2015372069614831, -1.2299182380901783, -1.2587967854829016, -1.2881123995738375, -1.3178085065631644, -1.347832185241352, -1.3781339363874732, -1.4086674516930056, -1.4393893872704635, -1.4702591452927245, -1.5012386661217405, -1.5322922323716135, -1.5633862856612775, -1.5944892563023934, -1.6255714058007646, -1.6566046817931601, -1.687562584870114, -1.7184200466282629, -1.7491533182366965, -1.7797398687776715, -1.8101582926229862, -1.8403882251256238, -1.8704102659362387, -1.9002059092913077, -1.9297574806611881, -1.9590480791895428, -1.9880615253990004, -2.016782313680412, -2.0451955691237984, -2.073287008287687, -2.1010429035396534, -2.1284500506344393, -2.1554957392269594, -2.18216772604593, -2.2084542104798026, -2.2343438123503474, -2.2598255516707138, -2.284888830204276, -2.3095234146582, -2.3337194213616184, -2.35746730229266, -2.3807578323316108, -2.403582097629142, -2.425931484989142, -2.4477976721751715, -2.469172619058167, -2.4900485595307265, -2.5104179941202993, -2.5302736832398782, -2.5496086410204786, -2.568416129674798, -2.5866896543460847, -2.604422958400412, -2.621610019124355, -2.638245043793463, -2.654322466080036, -2.669836942771516, -2.684783350773352, -2.699156784372511, -2.7129525527398988, -2.726166177651899, -2.738793391412943, -2.7508301349626363, -2.7622725561524275, -2.773117008178097, -2.783360048155617, -2.792998435828991, -2.802029132399756, -2.8104492994687518, -2.8182562980816392, -2.825447687870475, -2.8320212262843634, -2.837974867902961, -2.8433067638272043, -2.8480152611422858, -2.8520989024484633, -2.8555564254558194, -2.8583867626396344, -2.860589040953507, -2.862162581597824, -2.8631068998416667], [-2.8473147049577676, -2.8470008555317685, -2.8460594033413797, -2.8444906366734215, -2.842295036086103, -2.839473274530012, -2.8360262175189477, -2.8319549233520456, -2.8272606433891077, -2.8219448223814565, -2.8160090988611355, -2.809455305591734, -2.802285470084629, -2.7945018151849883, -2.7861067597324096, -2.7771029193017154, -2.7674931070300133, -2.757280334536883, -2.746467812945221, -2.7350589540111296, -2.7230573713720494, -2.7104668819233146, -2.697291507334274, -2.6835354757162615, -2.669203223455873, -2.654299397228347, -2.6388288562072484, -2.622796674488247, -2.6062081437465094, -2.589068776149099, -2.571384307545874, -2.5531607009646686, -2.534404150439044, -2.5151210851997297, -2.4953181742638897, -2.4750023314598084, -2.4541807209283144, -2.432860763146429, -2.411050141523354, -2.388756809623992, -2.365988999080898, -2.342755228261816, -2.319064311766947, -2.2949253708378516, -2.270347844768499, -2.2453415034185213, -2.219916460939404, -2.194083190836101, -2.1678525424997255, -2.1412357593615114, -2.1142444988344127, -2.0868908542266342, -2.059187378831241, -2.0311471124179614, -2.0027836103775214, -1.9741109757955908, -1.945143894762699, -1.9158976752586192, -1.8863882899846192, -1.8566324235548743, -1.8266475244989862, -1.7964518625709178, -1.7660645919052225, -1.735505820608668, -1.7047966874231437, -1.6739594461426275, -1.6430175585108233, -1.6119957963638376, -1.5809203538097951, -1.5498189702490102, -1.5187210650267422, -1.4876578844657746, -1.456662661935209, -1.4257707914583377, -1.395020015125143, -1.3644506242273142, -1.3341056735429901, -1.3040312075250124, -1.2742764962435218, -1.2448942777476188, -1.2159410019829395, -1.1874770694723824, -1.1595670555814879, -1.1322799083098969, -1.1056891041710384, -1.0798727428950796, -1.0549135575544906, -1.0308988125319338, -1.0079200579580652, -0.9860727064770397, -0.9654553973068067, -0.9461691146077864, -0.9283160333317962, -0.9119980771083898, -0.8973151901135414, -0.8843633483198894, -0.87323236399953, -0.8640035683645646, -0.8567474868265652, -0.8515216444451146, -0.8483686503565442, -0.8473147049577674, -0.8483686503565465, -0.8515216444451189, -0.8567474868265719, -0.864003568364573, -0.8732323639995405, -0.8843633483199016, -0.8973151901135556, -0.9119980771084057, -0.9283160333318138, -0.9461691146078055, -0.9654553973068274, -0.9860727064770617, -1.0079200579580883, -1.0308988125319578, -1.0549135575545159, -1.0798727428951058, -1.1056891041710653, -1.1322799083099244, -1.1595670555815163, -1.1874770694724115, -1.2159410019829688, -1.244894277747649, -1.2742764962435518, -1.3040312075250435, -1.3341056735430215, -1.3644506242273455, -1.3950200151251746, -1.4257707914583695, -1.4566626619352407, -1.4876578844658066, -1.518721065026774, -1.5498189702490421, -1.5809203538098273, -1.6119957963638698, -1.6430175585108548, -1.6739594461426592, -1.7047966874231757, -1.7355058206086995, -1.7660645919052538, -1.796451862570949, -1.8266475244990172, -1.8566324235549048, -1.8863882899846498, -1.9158976752586494, -1.9451438947627293, -1.9741109757956201, -2.002783610377551, -2.0311471124179907, -2.05918737883127, -2.0868908542266618, -2.1142444988344407, -2.141235759361539, -2.1678525424997526, -2.194083190836128, -2.21991646093943, -2.245341503418547, -2.2703478447685246, -2.294925370837877, -2.3190643117669714, -2.3427552282618405, -2.3659889990809213, -2.388756809624015, -2.411050141523377, -2.4328607631464516, -2.4541807209283357, -2.4750023314598293, -2.4953181742639106, -2.51512108519975, -2.534404150439064, -2.5531607009646873, -2.571384307545893, -2.5890687761491167, -2.6062081437465268, -2.6227966744882636, -2.6388288562072653, -2.6542993972283635, -2.6692032234558876, -2.6835354757162757, -2.6972915073342887, -2.710466881923328, -2.723057371372062, -2.735058954011141, -2.7464678129452325, -2.757280334536893, -2.7674931070300235, -2.7771029193017247, -2.786106759732419, -2.7945018151849967, -2.8022854700846365, -2.809455305591741, -2.816009098861142, -2.8219448223814623, -2.827260643389113, -2.8319549233520505, -2.836026217518952, -2.839473274530016, -2.842295036086105, -2.844490636673423, -2.846059403341381, -2.8470008555317685], [-2.830387982764787, -2.8300751493237293, -2.8291367442133883, -2.827573053095166, -2.8253845521479595, -2.8225719081836993, -2.819135978810528, -2.815077812645033, -2.8103986495753936, -2.805099921077732, -2.799183250588408, -2.7926504539354786, -2.785503539833046, -2.7777447104427155, -2.7693763620069682, -2.760401085559833, -2.7508216677208663, -2.7406410915791244, -2.729862537674554, -2.7184893850849767, -2.7065252126277337, -2.6939738001859244, -2.680839130170211, -2.667125389128223, -2.652836969514781, -2.637978471637461, -2.6225547057934215, -2.606570694614979, -2.590031675643121, -2.572943104149994, -2.5553106562334955, -2.5371402322093464, -2.5184379603285167, -2.4992102008506656, -2.4794635505072766, -2.459204847391564, -2.4384411763159677, -2.417179874682162, -2.395428538913143, -2.373195031502, -2.350487488737676, -2.3273143291742646, -2.3036842629174092, -2.2796063018090917, -2.255089770600781, -2.23014431921447, -2.204779936201875, -2.1790069635239204, -2.152836112785918, -2.126278483078567, -2.0993455805912884, -2.0720493401826268, -2.044402149112679, -2.0164168731649346, -1.98810688540976, -1.9594860978892112, -1.930568996533111, -1.9013706796495924, -1.8719069003697029, -1.8421941134652742, -1.8122495270021668, -1.7820911593369995, -1.751737902014356, -1.72120958917265, -1.6905270741194782, -1.659712313790025, -1.628788461852942, -1.5977799712742966, -1.5667127071877016, -1.535614070942235, -1.5045131362019237, -1.4734407979416706, -1.4424299351117333, -1.4115155876095498, -1.3807351479823462, -1.350128567959448, -1.319738579445465, -1.2896109289530253, -1.2597946235665083, -1.2303421853483214, -1.2013099095617523, -1.1727581201210489, -1.144751413224619, -1.1173588771296832, -1.0906542724655908, -1.064716153393409, -1.0396279054255713, -1.0154776710772702, -0.9923581301662124, -0.9703660981696743, -0.9496019045017957, -0.9301685140472077, -0.912170361099929, -0.8957118763108358, -0.8808957053210865, -0.8678206426880417, -0.8565793355152292, -0.8472558452930014, -0.8399231895295937, -0.8346410111186471, -0.8314535369338212, -0.8303879827647869, -0.8314535369338235, -0.8346410111186515, -0.8399231895296002, -0.8472558452930099, -0.85657933551524, -0.8678206426880541, -0.8808957053211008, -0.895711876310852, -0.9121703610999466, -0.930168514047227, -0.9496019045018166, -0.9703660981696963, -0.9923581301662356, -1.0154776710772946, -1.0396279054255966, -1.0647161533934353, -1.0906542724656176, -1.117358877129711, -1.1447514132246475, -1.172758120121078, -1.2013099095617819, -1.2303421853483512, -1.259794623566539, -1.2896109289530562, -1.319738579445496, -1.3501285679594792, -1.380735147982378, -1.4115155876095815, -1.4424299351117655, -1.4734407979417021, -1.504513136201956, -1.535614070942267, -1.5667127071877338, -1.5977799712743288, -1.628788461852974, -1.6597123137900567, -1.6905270741195095, -1.721209589172681, -1.751737902014387, -1.7820911593370308, -1.8122495270021977, -1.842194113465305, -1.871906900369733, -1.9013706796496224, -1.9305689965331405, -1.959486097889241, -1.9881068854097894, -2.0164168731649634, -2.044402149112708, -2.072049340182655, -2.099345580591316, -2.1262784830785946, -2.152836112785945, -2.1790069635239466, -2.2047799362019016, -2.230144319214496, -2.255089770600806, -2.279606301809117, -2.3036842629174337, -2.3273143291742886, -2.3504874887376994, -2.3731950315020236, -2.3954285389131655, -2.4171798746821844, -2.438441176315989, -2.459204847391585, -2.4794635505072966, -2.499210200850685, -2.5184379603285363, -2.537140232209365, -2.555310656233514, -2.5729431041500113, -2.590031675643139, -2.606570694614996, -2.622554705793438, -2.637978471637477, -2.6528369695147958, -2.6671253891282367, -2.6808391301702246, -2.6939738001859372, -2.7065252126277466, -2.718489385084989, -2.729862537674565, -2.740641091579135, -2.750821667720876, -2.760401085559842, -2.7693763620069767, -2.7777447104427244, -2.785503539833054, -2.7926504539354857, -2.7991832505884138, -2.805099921077738, -2.810398649575399, -2.815077812645037, -2.8191359788105324, -2.8225719081837033, -2.825384552147962, -2.827573053095168, -2.8291367442133892, -2.8300751493237297], [-2.812657913828239, -2.812346157704924, -2.811410983632947, -2.8098526745279866, -2.807671701988928, -2.804868726407697, -2.8014445971243958, -2.7974003526291558, -2.7927372208124974, -2.7874566192664476, -2.781560155639093, -2.7750496280457053, -2.7679270255400756, -2.7601945286502048, -2.7518545099830134, -2.7429095349033634, -2.7333623622932444, -2.723215945397675, -2.712473432764577, -2.701138169286623, -2.6892136973539285, -2.6767037581273105, -2.663612292942866, -2.649943444859648, -2.6357015603633944, -2.6208911912405455, -2.6055170966381693, -2.5895842453269418, -2.573097818186006, -2.5560632109303967, -2.5384860371037163, -2.5203721313610257, -2.5017275530693612, -2.482558590256028, -2.462871763937854, -2.442673832867917, -2.4219717987399703, -2.400772911894925, -2.3790846775782653, -2.3569148628023955, -2.334271503873499, -2.3111629146488144, -2.287597695597138, -2.2635847437431917, -2.2391332635851136, -2.214252779083962, -2.188953146834893, -2.1632445705416425, -2.137137616929289, -2.110643233245187, -2.0837727665145493, -2.0565379847356406, -2.0289511002201435, -2.0010247953071523, -1.972772250704661, -1.9442071767406504, -1.915343847837036, -1.886197140554218, -1.8567825755917946, -1.8271163641724892, -1.7972154592814482, -1.7670976122818978, -1.7367814354804116, -1.7062864712704464, -1.675633268540523, -1.644843467092388, -1.6139398908728284, -1.5829466508780006, -1.5518892586374327, -1.5207947512211588, -1.489691828730667, -1.4586110052230208, -1.4275847739649064, -1.3966477878028727, -1.3658370552458803, -1.3351921525587422, -1.304755451724943, -1.274572363511078, -1.244691593999746, -1.2151654117904682, -1.1860499215274989, -1.157405337421712, -1.1292962479133464, -1.1017918595064171, -1.074966204054855, -1.0488982894098717, -1.0236721684526127, -0.9993768963781441, -0.9761063411010806, -0.9539588075033081, -0.9330364339143793, -0.9134443199721006, -0.8952893503420766, -0.8786786902029448, -0.8637179471555226, -0.8505090207462875, -0.8391476942400219, -0.8297210609469168, -0.822304914600541, -0.8169612636081998, -0.8137361454246931, -0.812657913828239, -0.8137361454246953, -0.8169612636082043, -0.8223049146005476, -0.8297210609469255, -0.8391476942400327, -0.8505090207463002, -0.863717947155537, -0.8786786902029611, -0.8952893503420942, -0.91344431997212, -0.9330364339144003, -0.9539588075033302, -0.9761063411011038, -0.9993768963781685, -1.0236721684526382, -1.0488982894098982, -1.0749662040548822, -1.101791859506445, -1.129296247913375, -1.1574053374217408, -1.1860499215275286, -1.215165411790498, -1.2446915939997767, -1.2745723635111086, -1.304755451724974, -1.3351921525587738, -1.365837055245912, -1.3966477878029044, -1.4275847739649383, -1.4586110052230528, -1.489691828730699, -1.5207947512211906, -1.5518892586374646, -1.5829466508780325, -1.6139398908728604, -1.6448434670924197, -1.6756332685405546, -1.7062864712704777, -1.736781435480443, -1.7670976122819289, -1.797215459281479, -1.82711636417252, -1.8567825755918252, -1.8861971405542481, -1.9153438478370657, -1.9442071767406797, -1.9727722507046903, -2.001024795307181, -2.0289511002201723, -2.056537984735668, -2.0837727665145773, -2.1106432332452147, -2.1371376169293157, -2.163244570541669, -2.1889531468349186, -2.214252779083987, -2.239133263585139, -2.263584743743217, -2.287597695597162, -2.311162914648839, -2.3342715038735227, -2.356914862802418, -2.3790846775782883, -2.400772911894947, -2.421971798739992, -2.442673832867938, -2.462871763937875, -2.4825585902560476, -2.5017275530693803, -2.5203721313610448, -2.538486037103734, -2.5560632109304144, -2.573097818186023, -2.5895842453269586, -2.605517096638186, -2.6208911912405615, -2.63570156036341, -2.649943444859663, -2.66361229294288, -2.6767037581273234, -2.6892136973539413, -2.7011381692866356, -2.7124734327645883, -2.723215945397686, -2.7333623622932546, -2.742909534903373, -2.7518545099830223, -2.760194528650213, -2.767927025540083, -2.7750496280457115, -2.7815601556390996, -2.7874566192664534, -2.7927372208125023, -2.7974003526291606, -2.8014445971244, -2.8048687264076997, -2.80767170198893, -2.809852674527988, -2.811410983632949, -2.812346157704925], [-2.7941416508447414, -2.793831034406159, -2.7928992784347084, -2.791346662983863, -2.789173654878197, -2.7863809078172355, -2.782969262522197, -2.7789397469269748, -2.774293576415123, -2.769032154105049, -2.763157071185983, -2.7566701073078375, -2.7495732310284517, -2.7418686003222934, -2.7335585631551687, -2.7246456581300778, -2.7151326152099555, -2.7050223565236675, -2.6943179972623565, -2.6830228466739574, -2.6711404091645217, -2.6586743855158788, -2.645628674230117, -2.6320073730124114, -2.6178147804048715, -2.603055397585323, -2.587733930346316, -2.5718552912711563, -2.555424602125386, -2.5384471964839905, -2.520928622616589, -2.50287464665507, -2.484291256070613, -2.465184663489675, -2.4455613108815784, -2.4254278741535886, -2.4047912681930796, -2.3836586524004533, -2.36203743676099, -2.3399352885088875, -2.317360139442299, -2.2943201939544595, -2.270823937852946, -2.2468801480468437, -2.222497903190279, -2.197686595380423, -2.1724559430188446, -2.1468160049571634, -2.1207771960613884, -2.0943503043443608, -2.06754650983253, -2.0403774053520234, -2.012855019439904, -1.9849918416098662, -1.9568008502276097, -1.9282955432800846, -1.899489972354931, -1.8703987801820618, -1.841037242128667, -1.811421312082248, -1.7815676732037167, -1.751493794084268, -1.721217990895564, -1.6907594961825023, -1.660138535010917, -1.629376409248046, -1.5984955908198633, -1.5675198248541917, -1.536474243678376, -1.5053854926904395, -1.4742818691563013, -1.4431934749936237, -1.4121523845726813, -1.38119282847981, -1.350351394027607, -1.319667243029907, -1.2891823469523882, -1.2589417389559951, -1.22899378151399, -1.199390447136856, -1.1701876082037095, -1.1414453298866953, -1.1132281575747764, -1.0856053869707563, -1.058651301089697, -1.0324453537184954, -1.007072273585504, -0.982622057758127, -0.9591898170635653, -0.9368754313159937, -0.9157829688671679, -0.8960198248625251, -0.8776955372588654, -0.8609202509254623, -0.8458028195396502, -0.8324485632448624, -0.8209567364626352, -0.8114178020755941, -0.8039106502843698, -0.7984999355733673, -0.7952337252536517, -0.7941416508447416, -0.7952337252536541, -0.7984999355733717, -0.8039106502843766, -0.8114178020756029, -0.820956736462646, -0.8324485632448752, -0.8458028195396647, -0.8609202509254787, -0.8776955372588836, -0.8960198248625446, -0.915782968867189, -0.9368754313160161, -0.9591898170635887, -0.9826220577581516, -1.0070722735855293, -1.032445353718522, -1.0586513010897243, -1.0856053869707845, -1.113228157574805, -1.1414453298867246, -1.1701876082037392, -1.1993904471368864, -1.2289937815140204, -1.2589417389560258, -1.2891823469524195, -1.3196672430299385, -1.3503513940276388, -1.3811928284798418, -1.412152384572713, -1.4431934749936555, -1.4742818691563335, -1.5053854926904713, -1.5364742436784082, -1.5675198248542235, -1.5984955908198952, -1.6293764092480778, -1.6601385350109488, -1.6907594961825336, -1.7212179908955958, -1.751493794084299, -1.7815676732037475, -1.8114213120822784, -1.8410372421286973, -1.8703987801820918, -1.8994899723549608, -1.928295543280114, -1.9568008502276388, -1.9849918416098948, -2.012855019439933, -2.0403774053520514, -2.0675465098325576, -2.0943503043443883, -2.120777196061415, -2.14681600495719, -2.172455943018871, -2.1976865953804485, -2.222497903190305, -2.2468801480468685, -2.2708239378529704, -2.2943201939544835, -2.3173601394423224, -2.3399352885089106, -2.362037436761012, -2.383658652400475, -2.4047912681931014, -2.425427874153609, -2.445561310881599, -2.4651846634896946, -2.4842912560706325, -2.5028746466550897, -2.5209286226166068, -2.5384471964840087, -2.555424602125403, -2.5718552912711727, -2.5877339303463325, -2.6030553975853374, -2.6178147804048866, -2.632007373012426, -2.64562867423013, -2.6586743855158916, -2.6711404091645345, -2.683022846673969, -2.694317997262368, -2.7050223565236777, -2.7151326152099653, -2.724645658130088, -2.7335585631551775, -2.7418686003223014, -2.7495732310284597, -2.7566701073078446, -2.7631570711859896, -2.7690321541050547, -2.774293576415128, -2.7789397469269788, -2.7829692625222013, -2.786380907817238, -2.789173654878199, -2.791346662983865, -2.7928992784347098, -2.7938310344061597], [-2.7748571071028776, -2.7745476938080476, -2.773619546276754, -2.7720729415879215, -2.7699083416044017, -2.7671263930705985, -2.763727927750444, -2.759713962607058, -2.755085700025798, -2.749844528082822, -2.7439920208617075, -2.7375299388211016, -2.730460229216851, -2.722785026582542, -2.7145066532728834, -2.705627620074952, -2.6961506268928583, -2.6860785635120656, -2.675414510450253, -2.6641617399023345, -2.652323716788078, -2.639904099911592, -2.626906743242909, -2.6133356973329067, -2.599195210873936, -2.5844897324197427, -2.5692239122796097, -2.55340260460313, -2.537030869673638, -2.520113976430108, -2.502657405239308, -2.4846668509421646, -2.466148226200703, -2.4471076651746, -2.427551527559296, -2.407486403020947, -2.3869191160670713, -2.3658567313958114, -2.344306559771213, -2.322276164476922, -2.2997733684062625, -2.2768062618528804, -2.2533832110730407, -2.2295128676984324, -2.2052041790869534, -2.180466399708626, -2.1553091036745857, -2.129742198529201, -2.1037759404388914, -2.0774209509263857, -2.050688235316107, -2.0235892030753777, -1.9961356902573646, -1.9683399842754783, -1.9402148512654824, -1.9117735663212279, -1.8830299469229999, -1.853998389914233, -1.8246939124231898, -1.7951321971713634, -1.7653296426601597, -1.7353034187819856, -1.705071528461341, -1.6746528759957378, -1.6440673428349164, -1.6133358716091102, -1.5824805592917723, -1.5515247604571667, -1.5204932016654522, -1.4894121080729354, -1.4583093434166472, -1.4272145645515242, -1.396159391713128, -1.3651775956226977, -1.3343053024226124, -1.3035812172004495, -1.2730468664915977, -1.2427468595965734, -1.212729167750444, -1.1830454190655944, -1.1537512056492607, -1.1249063972751834, -1.096575453358192, -1.068827721636837, -1.0417377078267436, -1.0153852955269802, -0.9898558898924207, -0.9652404522213179, -0.9416353860625001, -0.9191422294358086, -0.8978671033762783, -0.8779198657704792, -0.8594129232447789, -0.8424596647795874, -0.8271725006664733, -0.8136605205117275, -0.8020268237654401, -0.7923656229150374, -0.7847592674083388, -0.7792753773722848, -0.7759643007585023, -0.7748571071028774, -0.7759643007585045, -0.7792753773722895, -0.7847592674083456, -0.7923656229150463, -0.8020268237654512, -0.8136605205117404, -0.8271725006664882, -0.8424596647796041, -0.859412923244797, -0.877919865770499, -0.8978671033762995, -0.919142229435831, -0.9416353860625237, -0.9652404522213427, -0.9898558898924465, -1.0153852955270068, -1.041737707826771, -1.0688277216368651, -1.0965754533582206, -1.1249063972752127, -1.1537512056492905, -1.1830454190656245, -1.2127291677504743, -1.2427468595966045, -1.2730468664916288, -1.303581217200481, -1.334305302422644, -1.3651775956227294, -1.39615939171316, -1.4272145645515564, -1.4583093434166792, -1.4894121080729672, -1.5204932016654842, -1.5515247604571987, -1.5824805592918039, -1.613335871609142, -1.6440673428349482, -1.6746528759957693, -1.705071528461372, -1.7353034187820167, -1.7653296426601905, -1.7951321971713936, -1.82469391242322, -1.8539983899142631, -1.8830299469230296, -1.9117735663212574, -1.9402148512655113, -1.968339984275507, -1.9961356902573926, -2.0235892030754057, -2.050688235316135, -2.077420950926413, -2.1037759404389185, -2.1297421985292275, -2.155309103674612, -2.1804663997086515, -2.2052041790869787, -2.2295128676984572, -2.2533832110730647, -2.2768062618529044, -2.299773368406286, -2.3222761644769445, -2.3443065597712356, -2.3658567313958336, -2.386919116067093, -2.407486403020968, -2.4275515275593165, -2.4471076651746198, -2.466148226200723, -2.4846668509421823, -2.5026574052393267, -2.520113976430126, -2.537030869673655, -2.5534026046031464, -2.569223912279626, -2.5844897324197587, -2.5991952108739507, -2.6133356973329205, -2.6269067432429227, -2.6399040999116052, -2.6523237167880906, -2.664161739902346, -2.6754145104502642, -2.686078563512076, -2.6961506268928677, -2.705627620074961, -2.714506653272892, -2.72278502658255, -2.7304602292168583, -2.7375299388211087, -2.7439920208617137, -2.749844528082827, -2.755085700025803, -2.7597139626070626, -2.7637279277504483, -2.7671263930706016, -2.7699083416044044, -2.772072941587923, -2.7736195462767554, -2.7745476938080484], [-2.754822939153244, -2.754514793611523, -2.7535904483125035, -2.7520501772526673, -2.7498944371531624, -2.747123867550951, -2.743739290927688, -2.7397417128776125, -2.7351323223161086, -2.7299124917309987, -2.7240837774790303, -2.7176479201304504, -2.710606844865009, -2.702962661923205, -2.694717667117088, -2.6858743424054725, -2.6764353565389802, -2.6664035657809495, -2.655782014710915, -2.644573937118063, -2.632782756992853, -2.620412089625833, -2.607465742823589, -2.593947718252787, -2.579862212924323, -2.5652136208308294, -2.550006534752084, -2.5342457482443046, -2.517936257830925, -2.501083265414168, -2.4836921809286943, -2.4657686252607234, -2.4473184334583955, -2.4283476582617625, -2.4088625739836873, -2.388869680776192, -2.368375709320318, -2.347387625981614, -2.325912638477762, -2.3039582021098086, -2.2815320266140073, -2.258642083697413, -2.2352966153272695, -2.211504142851933, -2.187273477039684, -2.1626137291314333, -2.13753432301413, -2.1120450086338187, -2.0861558767808446, -2.0598773753950037, -2.0332203275554908, -2.0061959513397354, -1.9788158817567125, -1.9510921949845295, -1.9230374351691066, -1.8946646440711685, -1.8659873938826708, -1.8370198235717368, -1.8077766791574512, -1.7782733583628973, -1.7485259601469496, -1.7185513396728611, -1.6883671693348419, -1.6579920065326685, -1.6274453689587278, -1.596747818241281, -1.5659210528711414, -1.5349880114246806, -1.5039729871814285, -1.4729017553155253, -1.4418017139109855, -1.410702040102899, -1.3796338626686497, -1.3486304523690744, -1.3177274312476317, -1.286963001907393, -1.2563781974631703, -1.2260171523604542, -1.1959273935017896, -1.1661601500472636, -1.1367706787648968, -1.1078185997887633, -1.0793682349748366, -1.051488937599851, -1.0242553978122206, -0.9977479029418678, -0.9720525255174246, -0.9472612047813816, -0.9234716800237357, -0.9007872268897914, -0.879316142105601, -0.8591709194522459, -0.8404670624408146, -0.8233214894429368, -0.8078505073807252, -0.7941673620695323, -0.782379416836076, -0.7725850633237384, -0.7648705233177812, -0.7593067486325954, -0.7559466564064744, -0.754822939153244, -0.7559466564064767, -0.7593067486326001, -0.7648705233177882, -0.7725850633237474, -0.7823794168360872, -0.7941673620695454, -0.8078505073807403, -0.8233214894429536, -0.8404670624408328, -0.859170919452266, -0.8793161421056224, -0.9007872268898143, -0.9234716800237596, -0.9472612047814066, -0.9720525255174505, -0.9977479029418946, -1.0242553978122482, -1.0514889375998795, -1.0793682349748657, -1.1078185997887928, -1.1367706787649265, -1.166160150047294, -1.1959273935018202, -1.2260171523604853, -1.2563781974632013, -1.2869630019074243, -1.3177274312476632, -1.3486304523691062, -1.3796338626686813, -1.4107020401029309, -1.4418017139110177, -1.4729017553155574, -1.50397298718146, -1.5349880114247125, -1.5659210528711733, -1.5967478182413126, -1.6274453689587594, -1.6579920065327, -1.6883671693348732, -1.7185513396728924, -1.7485259601469805, -1.7782733583629278, -1.8077766791574814, -1.8370198235717672, -1.8659873938827005, -1.8946646440711978, -1.9230374351691355, -1.9510921949845583, -1.9788158817567407, -2.006195951339763, -2.0332203275555187, -2.059877375395031, -2.086155876780871, -2.112045008633845, -2.1375343230141564, -2.162613729131458, -2.187273477039709, -2.211504142851958, -2.235296615327294, -2.258642083697437, -2.281532026614031, -2.3039582021098313, -2.3259126384777837, -2.347387625981636, -2.3683757093203393, -2.388869680776213, -2.4088625739837077, -2.4283476582617816, -2.447318433458415, -2.465768625260742, -2.483692180928712, -2.501083265414186, -2.5179362578309425, -2.534245748244321, -2.5500065347520997, -2.5652136208308454, -2.5798622129243376, -2.5939477182528012, -2.607465742823602, -2.6204120896258454, -2.632782756992866, -2.644573937118075, -2.655782014710926, -2.6664035657809597, -2.6764353565389905, -2.6858743424054827, -2.6947176671170965, -2.702962661923213, -2.7106068448650165, -2.717647920130457, -2.7240837774790365, -2.729912491731005, -2.7351323223161135, -2.7397417128776165, -2.7437392909276914, -2.747123867550954, -2.749894437153165, -2.752050177252669, -2.753590448312505, -2.7545147936115235], [-2.7340585287594465, -2.733751716789235, -2.7328313711433374, -2.731297762632682, -2.729151342664703, -2.7263927433277906, -2.7230227775107423, -2.7190424390584655, -2.7144529029655273, -2.709255525609557, -2.7034518450268727, -2.6970435812331415, -2.6900326365922953, -2.6824210962374084, -2.6742112285477004, -2.66540548568638, -2.6560065042045586, -2.6460171057171067, -2.6354402976569267, -2.6242792741148318, -2.612537416772981, -2.6002182959406066, -2.5873256717016986, -2.5738634951852677, -2.55983590996987, -2.545247253635247, -2.530102059475227, -2.5144050583874353, -2.4981611809569055, -2.4813755597524225, -2.4640535318562926, -2.446200641650352, -2.4278226438833355, -2.408925507047282, -2.3895154170935475, -2.369598781522123, -2.3491822338815043, -2.3282726387203008, -2.306877097036118, -2.2850029522721718, -2.2626577969175234, -2.239849479772947, -2.2165861139512533, -2.1928760856885554, -2.1687280640515327, -2.144151011635344, -2.1191541963576648, -2.0937472044664056, -2.0679399548923185, -2.0417427150929894, -2.015166118551928, -1.9882211841158552, -1.9609193373750495, -1.9332724343161394, -1.9052927875042749, -1.8769931950826027, -1.8483869729117401, -1.8194879902109795, -1.7903107091066444, -1.7608702285418936, -1.7311823330566758, -1.7012635470070585, -1.6711311948599845, -1.6408034682730634, -1.6102995007491958, -1.579639450742544, -1.548844594184831, -1.5179374274979034, -1.4869417822576987, -1.4558829527726591, -1.424787837931006, -1.393685098748365, -1.3626053330990824, -1.3315812691258122, -1.3006479787715004, -1.269843112737131, -1.2392071578993347, -1.2087837177739618, -1.1786198159200414, -1.1487662211608038, -1.1192777920527357, -1.0902138360376266, -1.061638476025644, -1.0336210136276718, -1.006236273734549, -0.9795649095133035, -0.9536936401170352, -0.9287153855924464, -0.9047292549637331, -0.8818403349785232, -0.8601592197121666, -0.8398012169242983, -0.8208851681452298, -0.803531828808767, -0.7878617752662782, -0.7739928394270986, -0.7620371194740508, -0.7520976739481352, -0.7442650698269092, -0.7386140123376855, -0.735200321870619, -0.7340585287594465, -0.7352003218706213, -0.7386140123376903, -0.7442650698269162, -0.7520976739481444, -0.762037119474062, -0.7739928394271118, -0.7878617752662932, -0.8035318288087839, -0.8208851681452485, -0.8398012169243185, -0.8601592197121882, -0.8818403349785462, -0.9047292549637572, -0.9287153855924716, -0.9536936401170614, -0.9795649095133304, -1.006236273734577, -1.0336210136277002, -1.0616384760256732, -1.090213836037656, -1.119277792052766, -1.1487662211608343, -1.178619815920072, -1.2087837177739928, -1.2392071578993662, -1.2698431127371628, -1.3006479787715322, -1.331581269125844, -1.3626053330991144, -1.3936850987483969, -1.424787837931038, -1.4558829527726913, -1.4869417822577304, -1.5179374274979351, -1.5488445941848628, -1.5796394507425755, -1.610299500749227, -1.6408034682730948, -1.6711311948600158, -1.7012635470070894, -1.7311823330567067, -1.7608702285419242, -1.7903107091066748, -1.819487990211009, -1.84838697291177, -1.8769931950826317, -1.9052927875043038, -1.933272434316168, -1.960919337375078, -1.988221184115883, -2.0151661185519556, -2.0417427150930165, -2.0679399548923456, -2.093747204466432, -2.1191541963576905, -2.1441510116353695, -2.168728064051558, -2.1928760856885803, -2.2165861139512772, -2.239849479772971, -2.2626577969175465, -2.2850029522721944, -2.30687709703614, -2.3282726387203225, -2.3491822338815265, -2.3695987815221438, -2.389515417093568, -2.4089255070473015, -2.4278226438833546, -2.4462006416503708, -2.4640535318563104, -2.4813755597524403, -2.4981611809569224, -2.5144050583874513, -2.5301020594752432, -2.5452472536352624, -2.5598359099698853, -2.5738634951852823, -2.587325671701712, -2.6002182959406195, -2.6125374167729936, -2.6242792741148437, -2.6354402976569373, -2.646017105717117, -2.6560065042045684, -2.665405485686389, -2.6742112285477093, -2.682421096237417, -2.690032636592303, -2.697043581233149, -2.703451845026879, -2.7092555256095623, -2.714452902965532, -2.7190424390584704, -2.7230227775107467, -2.7263927433277937, -2.7291513426647054, -2.7312977626326833, -2.732831371143339, -2.733751716789236], [-2.712583964147493, -2.71227855283529, -2.7113624080693657, -2.70983579737711, -2.707699166688795, -2.704953140415106, -2.701598521556862, -2.6976362918481303, -2.6930676119342847, -2.6878938215869232, -2.682116439957947, -2.6757371658755154, -2.6687578781849726, -2.661180636138333, -2.6530076798363473, -2.6442414307276847, -2.634884492170317, -2.6249396500607336, -2.6144098735372854, -2.603298315764578, -2.591608314806612, -2.5793433945971245, -2.566507266016479, -2.553103828085381, -2.5391371692867315, -2.52461156902809, -2.5095314992584257, -2.49390162625425, -2.477726812591719, -2.4610121193229553, -2.4437628083767207, -2.425984345205579, -2.4076824017039815, -2.3888628594242194, -2.3695318131199716, -2.3496955746503088, -2.329360677280458, -2.308533880419509, -2.2872221748395423, -2.265432788425487, -2.2431731925103926, -2.2204511088568366, -2.197274517351934, -2.173651664491002, -2.1495910727334437, -2.1251015508239544, -2.100192205182908, -2.074872452481881, -2.0491520335338675, -2.023041028643081, -1.9965498745765342, -1.9696893833390714, -1.9424707629555131, -1.9149056404883875, -1.8870060875476926, -1.8587846485806743, -1.8302543722651918, -1.8014288463702666, -1.7723222364924853, -1.742949329127515, -1.7133255795927032, -1.683467165380116, -1.6533910455899277, -1.6231150271722903, -1.592657838791959, -1.5620392132240977, -1.5312799792915044, -1.50040216446212, -1.4694291093393301, -1.4383855953933846, -1.407297987395596, -1.3761943921208808, -1.345104834968552, -1.3140614562014674, -1.283098728499349, -1.2522536974351486, -1.221566246275562, -1.1910793861270572, -1.1608395718298115, -1.1308970430569103, -1.1013061886952378, -1.0721259306329096, -1.0434201203961722, -1.015257938487067, -0.9877142815861722, -0.9608701168371454, -0.9348127751231604, -0.9096361466210662, -0.8854407322642416, -0.8623334947315368, -0.8404274434255042, -0.81984088152371, -0.8006962422698848, -0.7831184495724989, -0.7672327583035924, -0.7531620654494301, -0.7410237355636666, -0.7309260504477049, -0.7229644664600324, -0.7172179310492498, -0.7137455571420285, -0.7125839641474928, -0.7137455571420308, -0.7172179310492547, -0.7229644664600395, -0.7309260504477142, -0.7410237355636782, -0.7531620654494435, -0.7672327583036077, -0.7831184495725162, -0.8006962422699039, -0.8198408815237305, -0.8404274434255262, -0.8623334947315601, -0.885440732264266, -0.9096361466210915, -0.9348127751231867, -0.9608701168371726, -0.9877142815862002, -1.0152579384870957, -1.0434201203962015, -1.0721259306329394, -1.1013061886952678, -1.130897043056941, -1.1608395718298423, -1.1910793861270885, -1.2215662462755936, -1.25225369743518, -1.283098728499381, -1.3140614562014994, -1.345104834968584, -1.376194392120913, -1.407297987395628, -1.4383855953934164, -1.469429109339362, -1.5004021644621517, -1.531279979291536, -1.562039213224129, -1.5926578387919903, -1.6231150271723211, -1.6533910455899583, -1.6834671653801467, -1.7133255795927338, -1.7429493291275453, -1.7723222364925155, -1.801428846370296, -1.8302543722652214, -1.8587846485807038, -1.8870060875477217, -1.9149056404884162, -1.942470762955541, -1.9696893833390992, -1.9965498745765617, -2.0230410286431075, -2.049152033533894, -2.0748724524819075, -2.1001922051829336, -2.12510155082398, -2.149591072733469, -2.173651664491026, -2.197274517351958, -2.2204511088568606, -2.2431731925104157, -2.2654327884255094, -2.2872221748395645, -2.3085338804195312, -2.329360677280479, -2.3496955746503287, -2.369531813119991, -2.388862859424239, -2.4076824017040015, -2.4259843452055976, -2.4437628083767384, -2.4610121193229726, -2.4777268125917353, -2.493901626254267, -2.509531499258442, -2.5246115690281057, -2.5391371692867466, -2.553103828085395, -2.566507266016493, -2.5793433945971374, -2.5916083148066242, -2.6032983157645897, -2.614409873537296, -2.6249396500607443, -2.6348844921703267, -2.6442414307276936, -2.6530076798363558, -2.6611806361383414, -2.66875787818498, -2.675737165875522, -2.6821164399579533, -2.6878938215869286, -2.69306761193429, -2.6976362918481347, -2.7015985215568654, -2.704953140415109, -2.707699166688797, -2.709835797377112, -2.7113624080693675, -2.712278552835291], [-2.6904200205717324, -2.6901160783314433, -2.689204339656389, -2.687685068697926, -2.6855587057548775, -2.682825867343938, -2.6794873462993833, -2.6755441119032293, -2.6709973100473423, -2.6658482634293246, -2.6600984717844205, -2.6537496121560085, -2.646803539207713, -2.6392622855805383, -2.631128062298921, -2.622403259230077, -2.613090445601498, -2.6031923705820756, -2.592711963932871, -2.5816523367342294, -2.570016782196644, -2.557808776563534, -2.545031980114939, -2.5316902382820565, -2.5177875828835465, -2.5033282334956306, -2.488316598969227, -2.472757279108686, -2.456655066528189, -2.440014948703461, -2.422842110238287, -2.405141935367289, -2.3869200107186357, -2.3681821283628297, -2.3489342891764267, -2.3291827065526043, -2.3089338104938797, -2.2881942521260497, -2.2669709086766936, -2.2452708889662634, -2.22310153946512, -2.2004704509758084, -2.1773854660065064, -2.153854686909096, -2.129886484863721, -2.1054895098011377, -2.08067270136488, -2.055445301027252, -2.02981686548675, -2.003797281489835, -1.9773967822372835, -1.9506259655549174, -1.9234958140306317, -1.896017717344688, -1.8682034970485428, -1.840065434079557, -1.8116162993351494, -1.7828693876709754, -1.753838555734004, -1.7245382640936233, -1.694983624192794, -1.6651904507074355, -1.6351753199764445, -1.604955635247587, -1.5745496995765893, -1.5439767973184164, -1.5132572852610708, -1.4824126945728235, -1.4514658448624695, -1.4204409717867095, -1.3893638697753434, -1.3582620515774972, -1.3271649264515235, -1.2961039989139795, -1.2651130900099155, -1.2342285830402935, -1.203489695545033, -1.1729387790404338, -1.1426216474786304, -1.112587934543454, -1.0828914786043864, -1.05359073227086, -1.0247491908433666, -0.996435830336704, -0.9687255409261782, -0.9416995354175403, -0.9154457044953112, -0.8900588810199973, -0.8656409647259329, -0.8423008469288003, -0.8201540635034907, -0.7993220954719371, -0.7799312330393686, -0.7621109247473883, -0.7459915530080861, -0.7317016146770142, -0.7193643426037368, -0.7090938794289857, -0.7009912006563921, -0.6951400660821635, -0.6916033379055702, -0.6904200205717321, -0.6916033379055727, -0.6951400660821683, -0.7009912006563993, -0.7090938794289952, -0.7193643426037486, -0.7317016146770278, -0.7459915530081017, -0.7621109247474058, -0.7799312330393877, -0.7993220954719579, -0.8201540635035128, -0.8423008469288237, -0.8656409647259574, -0.8900588810200228, -0.9154457044953375, -0.9416995354175677, -0.9687255409262063, -0.9964358303367329, -1.0247491908433959, -1.0535907322708895, -1.0828914786044168, -1.1125879345434846, -1.1426216474786615, -1.1729387790404648, -1.2034896955450647, -1.234228583040325, -1.2651130900099472, -1.2961039989140113, -1.3271649264515553, -1.3582620515775292, -1.3893638697753754, -1.4204409717867412, -1.451465844862501, -1.4824126945728555, -1.5132572852611024, -1.5439767973184482, -1.5745496995766208, -1.6049556352476182, -1.6351753199764756, -1.6651904507074666, -1.6949836241928247, -1.7245382640936533, -1.7538385557340337, -1.7828693876710053, -1.811616299335179, -1.8400654340795861, -1.8682034970485715, -1.8960177173447161, -1.9234958140306602, -1.950625965554945, -1.9773967822373106, -2.0037972814898617, -2.0298168654867768, -2.0554453010272784, -2.080672701364906, -2.105489509801163, -2.129886484863746, -2.1538546869091206, -2.1773854660065304, -2.200470450975832, -2.2231015394651426, -2.2452708889662856, -2.2669709086767162, -2.2881942521260714, -2.3089338104939006, -2.329182706552625, -2.3489342891764466, -2.3681821283628497, -2.3869200107186552, -2.405141935367307, -2.422842110238305, -2.4400149487034777, -2.4566550665282056, -2.4727572791087025, -2.4883165989692433, -2.503328233495646, -2.517787582883561, -2.5316902382820703, -2.545031980114953, -2.5578087765635473, -2.5700167821966566, -2.581652336734241, -2.5927119639328815, -2.6031923705820854, -2.613090445601508, -2.622403259230086, -2.63112806229893, -2.6392622855805463, -2.6468035392077205, -2.653749612156015, -2.6600984717844263, -2.66584826342933, -2.6709973100473476, -2.675544111903234, -2.6794873462993873, -2.6828258673439414, -2.6855587057548806, -2.687685068697928, -2.68920433965639, -2.6901160783314437], [-2.6675881402161385, -2.6672857368485308, -2.666378613637786, -2.664867031272602, -2.662751424275853, -2.6600324010676863, -2.6567107440549664, -2.6527874097481456, -2.648263528906998, -2.643140406716996, -2.637419522998437, -2.6311025324508193, -2.6241912649353494, -2.616687725798858, -2.608594096242864, -2.59991273374196, -2.590646172516229, -2.580797124062886, -2.570368477752979, -2.559363301499549, -2.547784842504381, -2.5356365280911746, -2.522921966633816, -2.509644948589268, -2.495809447645608, -2.4814196219967872, -2.4664798157568537, -2.4509945605276893, -2.4349685771357192, -2.4184067775546434, -2.4013142670329763, -2.383696346447123, -2.365558514902863, -2.3469064726105193, -2.327746124061723, -2.3080835815386798, -2.287925168990143, -2.267277426311987, -2.2461471140744242, -2.224541218742553, -2.2024669584420873, -2.179931789327992, -2.1569434126202705, -2.1335097823785376, -2.109639114095329, -2.085339894197416, -2.0606208905550134, -2.0354911641106517, -2.009960081752996, -1.9840373305761436, -1.95773293368222, -1.9310572677046618, -1.9040210822517896, -1.8766355214954433, -1.8489121481580588, -1.8208629701839865, -1.7925004704177057, -1.7638376396533955, -1.7348880134677487, -1.7056657133017041, -1.676185492317675, -1.6464627866276993, -1.6165137725656364, -1.5863554307639014, -1.5560056178931625, -1.525483147032577, -1.4948078777590694, -1.4640008171768961, -1.4330842332528266, -1.4020817819761993, -1.371018650024001, -1.339921714773992, -1.3088197236658539, -1.2777434950492408, -1.2467261427605816, -1.2158033267116177, -1.1850135317152806, -1.1543983765676067, -1.1240029549780435, -1.0938762092008232, -1.0640713360431908, -1.0346462231525986, -1.005663910914743, -0.977193071686882, -0.9493084931716074, -0.9220915462176346, -0.895630608959644, -0.8700214088319286, -0.8453672317002925, -0.8217789336652706, -0.7993746771757945, -0.7782793010775254, -0.7586232274053685, -0.7405408106512965, -0.7241680533279217, -0.7096396502464709, -0.6970853864836866, -0.6866259995776086, -0.6783687171556345, -0.6724027807156032, -0.6687953414785627, -0.6675881402161384, -0.6687953414785652, -0.6724027807156082, -0.6783687171556421, -0.6866259995776184, -0.6970853864836986, -0.7096396502464848, -0.7241680533279377, -0.7405408106513144, -0.7586232274053878, -0.7782793010775463, -0.7993746771758168, -0.8217789336652942, -0.8453672317003174, -0.8700214088319543, -0.8956306089596706, -0.9220915462176622, -0.9493084931716357, -0.9771930716869109, -1.0056639109147725, -1.0346462231526286, -1.064071336043221, -1.0938762092008538, -1.1240029549780746, -1.1543983765676382, -1.185013531715312, -1.2158033267116493, -1.246726142760613, -1.2777434950492725, -1.308819723665886, -1.3399217147740239, -1.371018650024033, -1.4020817819762312, -1.4330842332528586, -1.4640008171769276, -1.4948078777591007, -1.5254831470326082, -1.5560056178931936, -1.5863554307639323, -1.616513772565667, -1.64646278662773, -1.6761854923177057, -1.7056657133017343, -1.7348880134677784, -1.763837639653425, -1.7925004704177347, -1.8208629701840156, -1.8489121481580877, -1.8766355214954715, -1.9040210822518173, -1.9310572677046893, -1.957732933682247, -1.9840373305761703, -2.0099600817530225, -2.035491164110678, -2.060620890555039, -2.085339894197441, -2.1096391140953537, -2.133509782378562, -2.156943412620294, -2.1799317893280157, -2.20246695844211, -2.2245412187425755, -2.2461471140744464, -2.267277426312009, -2.2879251689901645, -2.3080835815386997, -2.3277461240617425, -2.3469064726105393, -2.365558514902882, -2.383696346447141, -2.401314267032994, -2.4184067775546607, -2.434968577135736, -2.4509945605277057, -2.4664798157568697, -2.4814196219968023, -2.4958094476456227, -2.509644948589282, -2.522921966633829, -2.5356365280911874, -2.547784842504393, -2.559363301499561, -2.5703684777529903, -2.580797124062897, -2.5906461725162386, -2.599912733741969, -2.608594096242872, -2.6166877257988665, -2.6241912649353565, -2.631102532450826, -2.6374195229984427, -2.6431404067170017, -2.648263528907003, -2.6527874097481496, -2.656710744054971, -2.6600324010676895, -2.6627514242758554, -2.6648670312726037, -2.666378613637787, -2.667285736848531], [-2.644110411450382, -2.6438096182025697, -2.6429073241706975, -2.6414037865004354, -2.6392994338046516, -2.6365948662190424, -2.633290855481075, -2.629388345033272, -2.624888450152209, -2.6197924581049254, -2.6141018283347592, -2.6078181926789963, -2.6009433556210846, -2.5934792945805505, -2.5854281602441773, -2.576792276942459, -2.5675741430758, -2.5577764315954648, -2.547401990544822, -2.5364538436670414, -2.5249351910860374, -2.5128494100681884, -2.500200055873111, -2.4869908627026422, -2.4732257447581065, -2.4589087974169637, -2.4440442985410726, -2.428636709930055, -2.412690678934602, -2.3962110402461074, -2.3792028178807016, -2.361671227377604, -2.343621678233838, -2.3250597765996366, -2.3059913282614555, -2.2864223419424063, -2.266359032953127, -2.2458078272297133, -2.22477536579936, -2.2032685097189044, -2.1812943455365175, -2.1588601913325065, -2.135973603401626, -2.1126423836465036, -2.088874587759985, -2.064678534283383, -2.0400628146380653, -2.015036304239583, -1.9896081748169092, -1.9637879080745062, -1.9375853108521062, -1.9110105319566357, -1.8840740808629024, -1.8567868485049013, -1.8291601304083576, -1.8012056524478404, -1.7729355995490808, -1.7443626476996095, -1.7154999996792357, -1.686361424977016, -1.6569613044240987, -1.6273146801431664, -1.597437311496159, -1.5673457378036812, -1.5370573487130517, -1.5065904632085019, -1.4759644183873968, -1.4451996692713474, -1.4143179010807614, -1.3833421555752041, -1.3522969732480397, -1.3212085533584685, -1.2901049339808428, -1.2590161944395866, -1.2279746826621323, -1.1970152700980572, -1.166175636885162, -1.1354965898428586, -1.1050224155702097, -1.0748012703244954, -1.0448856073269517, -1.0153326405146113, -0.9862048413112525, -0.957570461453015, -0.9295040699501186, -0.9020870855342268, -0.8754082770734827, -0.8495641931575716, -0.8246594683025467, -0.800806937363558, -0.7781274728548825, -0.7567494441200094, -0.7368076862625865, -0.7184418656624971, -0.7017941443773023, -0.6870060847756931, -0.6742148036838644, -0.6635484826277044, -0.6551214595326919, -0.6490292488971289, -0.6453439337118383, -0.6441104114503821, -0.6453439337118408, -0.6490292488971339, -0.6551214595326992, -0.6635484826277143, -0.6742148036838768, -0.6870060847757072, -0.7017941443773186, -0.7184418656625151, -0.7368076862626062, -0.7567494441200309, -0.7781274728549051, -0.8008069373635819, -0.8246594683025718, -0.8495641931575977, -0.8754082770735095, -0.9020870855342547, -0.9295040699501469, -0.9575704614530444, -0.9862048413112822, -1.0153326405146414, -1.0448856073269823, -1.0748012703245262, -1.105022415570241, -1.1354965898428901, -1.1661756368851937, -1.197015270098089, -1.227974682662164, -1.2590161944396183, -1.290104933980875, -1.3212085533585003, -1.3522969732480714, -1.383342155575236, -1.4143179010807936, -1.445199669271379, -1.4759644183874283, -1.5065904632085332, -1.5370573487130827, -1.567345737803712, -1.5974373114961897, -1.6273146801431966, -1.656961304424129, -1.686361424977046, -1.7154999996792653, -1.7443626476996386, -1.77293559954911, -1.8012056524478692, -1.8291601304083864, -1.8567868485049297, -1.8840740808629302, -1.911010531956663, -1.9375853108521333, -1.9637879080745333, -1.9896081748169359, -2.015036304239609, -2.040062814638091, -2.064678534283408, -2.0888745877600097, -2.1126423836465276, -2.13597360340165, -2.15886019133253, -2.18129434553654, -2.2032685097189266, -2.2247753657993816, -2.2458078272297346, -2.266359032953148, -2.2864223419424263, -2.305991328261475, -2.325059776599656, -2.3436216782338573, -2.3616712273776215, -2.379202817880719, -2.3962110402461247, -2.4126906789346183, -2.428636709930072, -2.444044298541089, -2.458908797416979, -2.473225744758121, -2.486990862702656, -2.5002000558731243, -2.5128494100682017, -2.5249351910860502, -2.5364538436670525, -2.547401990544833, -2.557776431595475, -2.5675741430758094, -2.576792276942468, -2.5854281602441858, -2.5934792945805585, -2.600943355621092, -2.607818192679003, -2.6141018283347655, -2.6197924581049308, -2.624888450152214, -2.6293883450332762, -2.6332908554810786, -2.6365948662190455, -2.639299433804654, -2.641403786500438, -2.6429073241706984, -2.6438096182025705], [-2.620009547460759, -2.6197104370855606, -2.618813190466457, -2.6173180611323854, -2.6152254716632686, -2.6125360137380453, -2.609250448202911, -2.6053697051607583, -2.6008948840831216, -2.5958272539462364, -2.590168253393132, -2.5839194909240315, -2.5770827451176674, -2.569659964886518, -2.5616532697693275, -2.5530649502647504, -2.5438974682103748, -2.5341534572118736, -2.523835723127597, -2.512947244614441, -2.501491173741499, -2.489470836678651, -2.476889734468011, -2.463751543886952, -2.4500601184123316, -2.4358194892965277, -2.4210338667669578, -2.405707641361993, -2.3898453854174426, -2.373451854719316, -2.3565319903401356, -2.339090920677922, -2.3211339637189594, -2.3026666295476894, -2.2836946231295907, -2.2642238473956615, -2.2442604066602785, -2.223810610407662, -2.2028809774861062, -2.1814782407535422, -2.1596093522229154, -2.1372814887614506, -2.1145020584041236, -2.091278707348741, -2.0676193277080324, -2.0435320661031713, -2.0190253331934067, -1.994107814248067, -1.9687884808803955, -1.9430766040776195, -1.9169817686787092, -1.890513889470644, -1.863683229096125, -1.8365004179908693, -1.8089764765974068, -1.7811228401351844, -1.7529513862443755, -1.7244744658637774, -1.6957049377523654, -1.6666562071203226, -1.6373422688996984, -1.6077777562584004, -1.5779779950451809, -1.5479590649490167, -1.5177378682652283, -1.4873322072842432, -1.4567608714585822, -1.4260437356606481, -1.3952018710191951, -1.3642576700162967, -1.333234987738506, -1.3021593014034587, -1.2710578905216803, -1.2399600402944202, -1.2088972710782762, -1.1779035969447662, -1.1470158164956545, -1.1162738391153575, -1.0857210496820306, -1.055404714322888, -1.0253764289540157, -0.9956926109103011, -0.9664150317087814, -0.937611385592666, -0.9093558835951464, -0.8817298559994712, -0.8548223367797825, -0.8287305914518402, -0.803560534488487, -0.7794269642146028, -0.7564535227962815, -0.7347722686944448, -0.7145227325970478, -0.6958503213179239, -0.6789039454580885, -0.6638327848795388, -0.6507821791119833, -0.6398887404007461, -0.6312749279024387, -0.625043471421722, -0.6212721573940071, -0.6200095474607589, -0.6212721573940095, -0.6250434714217272, -0.6312749279024464, -0.639888740400756, -0.6507821791119957, -0.6638327848795532, -0.678903945458105, -0.6958503213179423, -0.7145227325970678, -0.7347722686944663, -0.7564535227963045, -0.779426964214627, -0.8035605344885122, -0.8287305914518667, -0.8548223367798097, -0.8817298559994992, -0.9093558835951752, -0.9376113855926953, -0.9664150317088114, -0.9956926109103313, -1.0253764289540463, -1.0554047143229188, -1.085721049682062, -1.1162738391153888, -1.147015816495686, -1.1779035969447982, -1.2088972710783081, -1.239960040294452, -1.271057890521712, -1.3021593014034905, -1.3332349877385377, -1.3642576700163287, -1.3952018710192269, -1.4260437356606799, -1.4567608714586138, -1.487332207284274, -1.5177378682652596, -1.5479590649490476, -1.5779779950452113, -1.6077777562584308, -1.6373422688997288, -1.6666562071203526, -1.6957049377523954, -1.7244744658638065, -1.7529513862444046, -1.7811228401352135, -1.8089764765974354, -1.8365004179908977, -1.8636832290961527, -1.8905138894706712, -1.916981768678736, -1.943076604077646, -1.9687884808804215, -1.9941078142480932, -2.0190253331934325, -2.0435320661031966, -2.067619327708057, -2.091278707348765, -2.114502058404147, -2.1372814887614746, -2.159609352222938, -2.181478240753564, -2.202880977486128, -2.223810610407684, -2.2442604066602994, -2.264223847395681, -2.2836946231296107, -2.302666629547709, -2.3211339637189785, -2.33909092067794, -2.3565319903401534, -2.373451854719333, -2.389845385417459, -2.4057076413620093, -2.4210338667669737, -2.4358194892965424, -2.4500601184123467, -2.463751543886966, -2.476889734468025, -2.4894708366786644, -2.5014911737415115, -2.5129472446144527, -2.523835723127608, -2.534153457211884, -2.543897468210384, -2.5530649502647593, -2.561653269769336, -2.5696599648865264, -2.5770827451176754, -2.5839194909240377, -2.590168253393138, -2.595827253946242, -2.6008948840831265, -2.605369705160762, -2.6092504482029146, -2.6125360137380484, -2.6152254716632712, -2.6173180611323876, -2.6188131904664584, -2.619710437085562], [-2.5953088642766495, -2.595011511091647, -2.594119534815856, -2.592633185294853, -2.5905528789644965, -2.5878791988912404, -2.5846128948295095, -2.5807548832970904, -2.5763062476697565, -2.5712682382966605, -2.5656422726383155, -2.559429935429303, -2.552632978868207, -2.5452533228375764, -2.537293055157159, -2.5287544318739994, -2.5196398775934536, -2.509951985855637, -2.499693519562316, -2.488867411459803, -2.4774767646840203, -2.4655248533745304, -2.4530151233650495, -2.4399511929587314, -2.426336853797372, -2.4121760718346135, -2.3974729884242683, -2.3822319215360257, -2.3664573671120803, -2.3501540005796, -2.333326678535541, -2.315980440622029, -2.298120511612452, -2.2797523037305853, -2.2608814192274336, -2.2415136532431967, -2.221654996984748, -2.201311641252388, -2.1804899803534346, -2.159196616444436, -2.1374383643486206, -2.1152222569005485, -2.0925555508760643, -2.069445733572495, -2.0459005301118576, -2.0219279115486453, -1.9975361038737778, -1.9727335980176792, -1.9475291609683687, -1.921931848135196, -1.8959510171056175, -1.869596342961611, -1.8428778353441893, -1.8158058574795644, -1.7883911474091667, -1.7606448416986378, -1.7325785019385957, -1.704204144393293, -1.6755342732029848, -1.6465819176029557, -1.6173606736877852, -1.5878847513248406, -1.5581690269075934, -1.5282291027387016, -1.4980813739466805, -1.4677431039701596, -1.4372325097922043, -1.4065688582758427, -1.3757725751425454, -1.3448653683493317, -1.3138703678580534, -1.2828122840515535, -1.2517175873330884, -1.2206147117416806, -1.1895342857160696, -1.1585093934255677, -1.1275758703288228, -1.0967726367775326, -1.066142073486708, -1.035730442451908, -1.0055883562729702, -0.9757712976564104, -0.9463401888605681, -0.917362007681503, -0.8889104418211219, -0.8610665666022159, -0.8339195213909372, -0.807567147134238, -0.7821165306164805, -0.7576843802492633, -0.7343971340546209, -0.7123906749323666, -0.691809505287459, -0.6728052192849518, -0.6555341159829252, -0.640153832106251, -0.6268189505952501, -0.6156756663764271, -0.6068557583043644, -0.6004703023181654, -0.5966037229025231, -0.5953088642766493, -0.5966037229025258, -0.6004703023181708, -0.6068557583043722, -0.6156756663764376, -0.6268189505952626, -0.6401538321062656, -0.655534115982942, -0.6728052192849705, -0.6918095052874793, -0.7123906749323884, -0.7343971340546444, -0.7576843802492879, -0.7821165306165061, -0.8075671471342647, -0.8339195213909646, -0.8610665666022441, -0.8889104418211509, -0.9173620076815325, -0.9463401888605981, -0.9757712976564406, -1.005588356273001, -1.0357304424519391, -1.0661420734867393, -1.0967726367775643, -1.1275758703288543, -1.1585093934255997, -1.1895342857161015, -1.2206147117417125, -1.25171758733312, -1.2828122840515854, -1.3138703678580852, -1.3448653683493634, -1.375772575142577, -1.4065688582758742, -1.4372325097922354, -1.467743103970191, -1.4980813739467116, -1.5282291027387325, -1.558169026907624, -1.5878847513248713, -1.6173606736878154, -1.6465819176029854, -1.6755342732030145, -1.7042041443933222, -1.7325785019386246, -1.7606448416986666, -1.7883911474091951, -1.8158058574795921, -1.842877835344217, -1.8695963429616378, -1.8959510171056444, -1.9219318481352223, -1.947529160968395, -1.9727335980177045, -1.9975361038738033, -2.02192791154867, -2.045900530111882, -2.0694457335725187, -2.092555550876088, -2.115222256900571, -2.1374383643486428, -2.159196616444458, -2.1804899803534563, -2.2013116412524094, -2.221654996984768, -2.2415136532432167, -2.2608814192274527, -2.279752303730605, -2.298120511612471, -2.3159804406220466, -2.3333266785355584, -2.350154000579617, -2.3664573671120968, -2.382231921536042, -2.397472988424284, -2.412176071834629, -2.426336853797386, -2.4399511929587447, -2.4530151233650628, -2.465524853374543, -2.4774767646840328, -2.488867411459815, -2.499693519562327, -2.5099519858556474, -2.519639877593463, -2.5287544318740083, -2.5372930551571677, -2.545253322837585, -2.552632978868214, -2.55942993542931, -2.5656422726383212, -2.571268238296666, -2.576306247669762, -2.580754883297095, -2.5846128948295135, -2.587879198891243, -2.590552878964499, -2.5926331852948548, -2.5941195348158574, -2.595011511091647], [-2.5700322582137654, -2.569736738159855, -2.568850260030364, -2.5673730699283928, -2.5653055780471488, -2.56264835870246, -2.559402150379167, -2.555567855792296, -2.5511465419641737, -2.546139440318909, -2.5405479467959755, -2.534373621984902, -2.52761819128342, -2.5202835450817336, -2.5123717389759395, -2.503884994014013, -2.4948256969781646, -2.485196400707837, -2.474999824468073, -2.4642388543685017, -2.4529165438387666, -2.4410361141668107, -2.4286009551071333, -2.4156146255668527, -2.4020808543782173, -2.3880035411671106, -2.373386757328083, -2.3582347471175122, -2.342551928877722, -2.326342896406219, -2.309612420485683, -2.292365450592021, -2.2746071167996127, -2.2563427319049607, -2.237577793792224, -2.2183179880667216, -2.1985691909853466, -2.178337472716085, -2.1576291009624717, -2.136450544992898, -2.114808480119318, -2.0927097926750964, -2.0701615855476354, -2.04717118432808, -2.0237461441479545, -1.999894257281157, -1.9756235615994677, -1.9509423499808367, -1.925859180782327, -1.9003828895040202, -1.8745226017866625, -1.8482877479046769, -1.8216880789377563, -1.794733684829035, -1.7674350145662587, -1.7398028987550909, -1.7118485748913164, -1.6835837156820765, -1.6550204608162251, -1.6261714526415976, -1.5970498762735428, -1.5676695047359326, -1.5380447498246381, -1.5081907194859214, -1.4781232826203925, -1.4478591423593747, -1.4174159190171383, -1.3868122441021034, -1.356067866975414, -1.3252037759786766, -1.2942423361162438, -1.2632074456722677, -1.2321247144684326, -1.2010216668215676, -1.16992797263387, -1.1388757104281753, -1.1078996665027636, -1.077037674686086, -1.0463310013619547, -1.0158247804204816, -0.9855685024375523, -0.9556165615065918, -0.9260288614747472, -0.8968714805068865, -0.8682173884301205, -0.8401472045784729, -0.8127499741095368, -0.7861239271632824, -0.7603771669729843, -0.7356282095982628, -0.7120062695305037, -0.6896511536236052, -0.6687125945547384, -0.649348831590431, -0.6317242421379647, -0.6160058573569881, -0.6023586749630251, -0.5909398234201264, -0.5818918314172218, -0.5753354892630542, -0.5713630021406526, -0.5700322582137655, -0.5713630021406554, -0.5753354892630597, -0.58189183141723, -0.590939823420137, -0.602358674963038, -0.6160058573570032, -0.631724242137982, -0.6493488315904502, -0.6687125945547591, -0.6896511536236275, -0.7120062695305274, -0.7356282095982877, -0.7603771669730103, -0.7861239271633093, -0.8127499741095644, -0.8401472045785013, -0.8682173884301495, -0.8968714805069162, -0.9260288614747773, -0.9556165615066224, -0.9855685024375834, -1.015824780420513, -1.046331001361986, -1.0770376746861174, -1.1078996665027956, -1.138875710428207, -1.169927972633902, -1.2010216668215998, -1.2321247144684646, -1.2632074456722997, -1.2942423361162756, -1.3252037759787085, -1.3560678669754453, -1.386812244102135, -1.4174159190171698, -1.4478591423594065, -1.4781232826204236, -1.5081907194859525, -1.5380447498246692, -1.567669504735963, -1.5970498762735728, -1.6261714526416275, -1.6550204608162546, -1.6835837156821063, -1.7118485748913455, -1.739802898755119, -1.7674350145662872, -1.794733684829063, -1.8216880789377836, -1.848287747904704, -1.8745226017866894, -1.9003828895040467, -1.925859180782353, -1.9509423499808622, -1.9756235615994928, -1.9998942572811815, -2.023746144147979, -2.0471711843281035, -2.0701615855476585, -2.092709792675119, -2.1148084801193403, -2.13645054499292, -2.157629100962493, -2.1783374727161062, -2.198569190985367, -2.2183179880667416, -2.237577793792244, -2.2563427319049794, -2.2746071167996313, -2.2923654505920386, -2.3096124204857, -2.326342896406236, -2.3425519288777386, -2.358234747117528, -2.373386757328099, -2.3880035411671257, -2.4020808543782315, -2.415614625566867, -2.428600955107146, -2.4410361141668226, -2.4529165438387786, -2.4642388543685136, -2.474999824468083, -2.485196400707847, -2.4948256969781744, -2.503884994014023, -2.5123717389759483, -2.5202835450817416, -2.5276181912834272, -2.5343736219849085, -2.5405479467959813, -2.546139440318915, -2.551146541964178, -2.5555678557923005, -2.5594021503791704, -2.562648358702463, -2.565305578047151, -2.5673730699283945, -2.5688502600303655, -2.5697367381598557], [-2.5442041827560096, -2.5439105734552077, -2.543029826321016, -2.541562183662887, -2.5395080493460624, -2.536867988816225, -2.5336427291348267, -2.529833159025953, -2.525440328935784, -2.520465451106021, -2.5149098996628743, -2.508775210723516, -2.502063082522183, -2.494775375558447, -2.4869141127704766, -2.4784814797365025, -2.4694798249080585, -2.4599116598790003, -2.4497796596947445, -2.4390866632066603, -2.427835673477071, -2.416029858240914, -2.403672550430727, -2.390767248772334, -2.377317618459365, -2.3633274919155878, -2.3488008696549625, -2.333741921250361, -2.318154986423026, -2.3020445762661335, -2.285415374617196, -2.268272239595657, -2.250620205323743, -2.2324644838506145, -2.2138104673020305, -2.1946637302802166, -2.175030032541348, -2.154915321981175, -2.13432573796278, -2.113267615024384, -2.091747487009546, -2.069772091667089, -2.047348375773753, -2.024483500838994, -2.0011848494586193, -1.9774600323922356, -1.9533168964489067, -1.928763533276171, -1.9038082891598243, -1.8784597759559234, -1.852726883292519, -1.8266187921970607, -1.80014499032658, -1.7733152890021007, -1.7461398422767525, -1.7186291682993955, -1.6907941732728915, -1.662646178349304, -1.6341969498542561, -1.6054587332905317, -1.5764442916380859, -1.5471669485454735, -1.5176406370980637, -1.4878799549533224, -1.4579002267552583, -1.427717574881478, -1.397348999740148, -1.366812471023817, -1.336127031545982, -1.3053129155381786, -1.2743916835737643, -1.2433863766125206, -1.21232169202978, -1.1812241849049363, -1.1501224982935292, -1.1190476266854623, -1.088033217341388, -1.0571159146682865, -1.0263357531918302, -0.9957366049252803, -0.9653666868970929, -0.9352791340954949, -0.9055326418465997, -0.8761921792781453, -0.8473297715019986, -0.8190253417656588, -0.7913675951701882, -0.7644549115450329, -0.738396195541054, -0.7133116059352216, -0.6893330531328616, -0.6666043149125014, -0.6452805791771662, -0.6255271865131192, -0.6075173277982023, -0.5914284717398446, -0.5774373761732325, -0.5657136938318382, -0.5564124213719951, -0.5496657334453466, -0.5455750272374141, -0.5442041827560096, -0.5455750272374169, -0.5496657334453523, -0.5564124213720033, -0.5657136938318491, -0.5774373761732459, -0.5914284717398601, -0.60751732779822, -0.6255271865131387, -0.6452805791771872, -0.6666043149125241, -0.6893330531328857, -0.7133116059352468, -0.7383961955410802, -0.7644549115450601, -0.7913675951702163, -0.8190253417656875, -0.847329771502028, -0.8761921792781753, -0.90553264184663, -0.9352791340955255, -0.9653666868971241, -0.9957366049253115, -1.0263357531918618, -1.0571159146683182, -1.0880332173414198, -1.1190476266854943, -1.1501224982935612, -1.1812241849049683, -1.2123216920298119, -1.2433863766125524, -1.2743916835737958, -1.3053129155382104, -1.3361270315460136, -1.3668124710238487, -1.3973489997401796, -1.4277175748815092, -1.4579002267552894, -1.487879954953353, -1.5176406370980942, -1.5471669485455037, -1.576444291638116, -1.6054587332905614, -1.6341969498542854, -1.662646178349333, -1.6907941732729204, -1.7186291682994241, -1.7461398422767804, -1.7733152890021284, -1.8001449903266074, -1.8266187921970878, -1.8527268832925456, -1.8784597759559498, -1.90380828915985, -1.9287635332761965, -1.953316896448932, -1.97746003239226, -2.0011848494586433, -2.024483500839018, -2.047348375773776, -2.069772091667112, -2.0917474870095685, -2.1132676150244056, -2.134325737962801, -2.1549153219811963, -2.1750300325413687, -2.1946637302802365, -2.21381046730205, -2.2324644838506336, -2.250620205323762, -2.268272239595675, -2.2854153746172132, -2.3020445762661508, -2.318154986423042, -2.3337419212503767, -2.348800869654978, -2.3633274919156024, -2.37731761845938, -2.390767248772348, -2.40367255043074, -2.416029858240926, -2.4278356734770834, -2.439086663206672, -2.449779659694755, -2.4599116598790096, -2.4694798249080674, -2.4784814797365113, -2.4869141127704846, -2.4947753755584547, -2.50206308252219, -2.508775210723522, -2.5149098996628805, -2.5204654511060265, -2.5254403289357885, -2.5298331590259573, -2.5336427291348307, -2.5368679888162275, -2.5395080493460647, -2.541562183662888, -2.543029826321017, -2.5439105734552085], [-2.5178496248983073, -2.517558005710538, -2.5166832276371602, -2.515225529151207, -2.513185307718656, -2.5105631198151914, -2.507359680950455, -2.503575865700543, -2.49921270774978, -2.4942713999430106, -2.488753294349921, -2.482659902343147, -2.4759928946922214, -2.4687541016756893, -2.4609455132140394, -2.4525692790264384, -2.443627708814605, -2.4341232724775552, -2.4240586003613633, -2.4134364835485407, -2.402259874192138, -2.3905318859002045, -2.3782557941768467, -2.3654350369267685, -2.3520732150309063, -2.3381740930015473, -2.3237415997262123, -2.3087798293105424, -2.293293042031498, -2.277285665413396, -2.260762295440604, -2.2437276979222256, -2.226186810025738, -2.2081447419984097, -2.1896067790973817, -2.170578383751627, -2.151065197981603, -2.1310730461053584, -2.110607937763134, -2.08967607129626, -2.0682838375203354, -2.046437823937468, -2.0241448194377307, -2.0014118195461585, -1.978246032278561, -1.9546548846773701, -1.9306460301078228, -1.906227356405099, -1.881406994974894, -1.8561933309634568, -1.8305950146287124, -1.804620974061955, -1.7782804294302412, -1.7515829089333326, -1.7245382666965212, -1.697156702852367, -1.6694487861011824, -1.641425479082723, -1.6130981669411042, -1.584478689522587, -1.5555793777129787, -1.5264130944996412, -1.4969932814343714, -1.4673340112800046, -1.4374500477481111, -1.4073569133806059, -1.3770709667980068, -1.3466094907353843, -1.315990792518169, -1.285234318898796, -1.2543607874867795, -1.2233923373644102, -1.1923527018925615, -1.1612674071796487, -1.1301640002126287, -1.099072311228743, -1.068024755529675, -1.0370566805830852, -1.0062067648784168, -0.9755174755339293, -0.945035591976432, -0.9148128029570904, -0.8849063834579849, -0.8553799562895695, -0.8263043398113048, -0.797758477436201, -0.7698304353450692, -0.7426184407887607, -0.716231912907616, -0.6907924095135087, -0.6664343755429825, -0.6433055319754889, -0.6215666907373535, -0.6013907290853966, -0.5829604208603095, -0.5664648249908265, -0.5520940037997788, -0.540032014490757, -0.5304484000483831, -0.5234887767064987, -0.5192654961487824, -0.5178496248983072, -0.5192654961487854, -0.5234887767065046, -0.5304484000483916, -0.5400320144907682, -0.5520940037997925, -0.5664648249908422, -0.5829604208603275, -0.6013907290854165, -0.621566690737375, -0.643305531975512, -0.666434375543007, -0.6907924095135344, -0.7162319129076425, -0.7426184407887881, -0.7698304353450977, -0.7977584774362301, -0.8263043398113344, -0.8553799562895995, -0.8849063834580154, -0.9148128029571212, -0.9450355919764633, -0.9755174755339608, -1.0062067648784483, -1.037056680583117, -1.0680247555297067, -1.099072311228775, -1.1301640002126607, -1.1612674071796807, -1.1923527018925935, -1.2233923373644422, -1.2543607874868115, -1.2852343188988278, -1.3159907925182008, -1.3466094907354158, -1.3770709667980379, -1.4073569133806367, -1.437450047748142, -1.4673340112800348, -1.4969932814344016, -1.5264130944996717, -1.5555793777130087, -1.5844786895226164, -1.6130981669411333, -1.6414254790827516, -1.6694487861012115, -1.6971567028523955, -1.7245382666965494, -1.75158290893336, -1.778280429430268, -1.804620974061982, -1.8305950146287386, -1.8561933309634826, -1.8814069949749195, -1.9062273564051246, -1.9306460301078479, -1.9546548846773948, -1.978246032278585, -2.001411819546182, -2.0241448194377534, -2.0464378239374907, -2.0682838375203576, -2.0896760712962816, -2.1106079377631555, -2.1310730461053797, -2.151065197981623, -2.1705783837516464, -2.189606779097401, -2.208144741998429, -2.2261868100257565, -2.243727697922243, -2.2607622954406215, -2.2772856654134124, -2.293293042031514, -2.308779829310558, -2.323741599726228, -2.338174093001562, -2.35207321503092, -2.365435036926782, -2.3782557941768596, -2.390531885900217, -2.4022598741921497, -2.4134364835485522, -2.424058600361374, -2.434123272477566, -2.4436277088146143, -2.4525692790264473, -2.4609455132140483, -2.4687541016756978, -2.4759928946922285, -2.4826599023431535, -2.4887532943499266, -2.494271399943016, -2.4992127077497845, -2.503575865700547, -2.507359680950459, -2.510563119815194, -2.5131853077186577, -2.515225529151209, -2.5166832276371616, -2.517558005710539], [-2.4909940809733033, -2.4907045330518467, -2.4898359674878137, -2.488388618883895, -2.4863628782502745, -2.48375929301353, -2.480578567029813, -2.4768215606030264, -2.472489290508925, -2.4675829300263272, -2.462103808976792, -2.4560534137744283, -2.449433387487711, -2.4422455299154695, -2.434491797679506, -2.4261743043366004, -2.4172953205130017, -2.407857274064854, -2.397862750268413, -2.387314492044307, -2.3762154002205875, -2.3645685338397806, -2.3523771105157505, -2.3396445068467506, -2.3263742588917355, -2.3125700627177266, -2.298235775026857, -2.2833754138726157, -2.2679931594758083, -2.252093355151895, -2.2356805083625684, -2.2187592919058625, -2.201334545260605, -2.1834112761027664, -2.1649946620132146, -2.1460900523985496, -2.1267029706491565, -2.106839116561377, -2.086504369053814, -2.065704789211308, -2.044446623694109, -2.022736308554271, -2.0005804735064467, -1.9779859467060428, -1.9549597600943882, -1.9315091553780674, -1.9076415907182749, -1.8833647482158984, -1.8586865422893897, -1.833615129055509, -1.8081589168379832, -1.7823265779463917, -1.7561270618874802, -1.729569610194142, -1.7026637730839491, -1.6754194281900439, -1.647846801643135, -1.6199564918251654, -1.591759496163979, -1.5632672413952544, -1.5344916177845498, -1.5054450178802827, -1.476140380459891, -1.4465912404387606, -1.4168117856376277, -1.3868169214524535, -1.356622344645259, -1.3262446276796367, -1.2957013152660226, -1.2650110350653456, -1.2341936248321035, -1.2032702786666434, -1.1722637154989892, -1.1411983734503635, -1.1101006343196451, -1.0789990831235765, -1.0479248083791841, -1.0169117496423905, -0.9859970996796316, -0.9552217694945979, -0.9246309251639879, -0.8942746058953791, -0.8642084326538679, -0.834494415721298, -0.8052018670667613, -0.7764084185663972, -0.7482011387131424, -0.7206777268835503, -0.6939477434236265, -0.6681338034071571, -0.6433726196239726, -0.6198157248866877, -0.5976296365120494, -0.5769951536308704, -0.5581054165001744, -0.5411623340432717, -0.5263710415322794, -0.5139322296313581, -0.504032519192909, -0.49683352745046633, -0.49246078831703244, -0.49099408097330355, -0.49246078831703544, -0.49683352745047227, -0.5040325191929179, -0.5139322296313696, -0.5263710415322934, -0.5411623340432881, -0.5581054165001929, -0.5769951536308908, -0.5976296365120715, -0.6198157248867111, -0.6433726196239977, -0.6681338034071831, -0.6939477434236535, -0.7206777268835781, -0.748201138713171, -0.7764084185664264, -0.8052018670667912, -0.8344944157213283, -0.8642084326538987, -0.8942746058954101, -0.9246309251640193, -0.9552217694946296, -0.9859970996796632, -1.0169117496424225, -1.0479248083792159, -1.0789990831236083, -1.1101006343196769, -1.1411983734503954, -1.172263715499021, -1.2032702786666751, -1.2341936248321355, -1.2650110350653774, -1.2957013152660541, -1.3262446276796678, -1.35662234464529, -1.3868169214524844, -1.4168117856376585, -1.4465912404387913, -1.476140380459921, -1.505445017880313, -1.5344916177845798, -1.5632672413952835, -1.5917594961640082, -1.619956491825194, -1.6478468016431636, -1.675419428190072, -1.7026637730839769, -1.7295696101941695, -1.7561270618875076, -1.7823265779464186, -1.8081589168380097, -1.8336151290555347, -1.8586865422894154, -1.8833647482159237, -1.9076415907182998, -1.9315091553780916, -1.954959760094412, -1.9779859467060663, -2.0005804735064694, -2.022736308554294, -2.0444466236941308, -2.06570478921133, -2.086504369053835, -2.106839116561398, -2.126702970649177, -2.146090052398569, -2.1649946620132337, -2.1834112761027846, -2.201334545260623, -2.2187592919058807, -2.235680508362585, -2.252093355151912, -2.2679931594758247, -2.2833754138726308, -2.298235775026872, -2.3125700627177403, -2.3263742588917493, -2.3396445068467644, -2.3523771105157634, -2.3645685338397926, -2.376215400220599, -2.387314492044318, -2.3978627502684233, -2.407857274064864, -2.4172953205130105, -2.4261743043366093, -2.4344917976795144, -2.442245529915477, -2.4494333874877174, -2.456053413774435, -2.4621038089767975, -2.467582930026333, -2.47248929050893, -2.4768215606030304, -2.480578567029817, -2.4837592930135326, -2.4863628782502762, -2.488388618883897, -2.489835967487814, -2.4907045330518476], [-2.463663531985308, -2.4633761383305512, -2.462514034268815, -2.461077450507829, -2.459066771560991, -2.4564825357484668, -2.453325435199379, -2.449596315855766, -2.4452961774791464, -2.4404261736607777, -2.4349876118368723, -2.428981953310281, -2.422410813280382, -2.4152759608831538, -2.407579319243706, -2.3993229655437913, -2.390509131107149, -2.3811402015058576, -2.3712187166912466, -2.3607473711532667, -2.3497290141127, -2.3381666497510083, -2.3260634374831586, -2.3134226922793153, -2.3002478850418973, -2.2865426430452076, -2.2723107504455733, -2.2575561488707776, -2.2422829380985116, -2.226495376834589, -2.2101978836028215, -2.193395037759771, -2.176091580648991, -2.1582924169110154, -2.140002615967158, -2.1212274136972082, -2.10197221433342, -2.0822425925957506, -2.0620442960962446, -2.0413832480437333, -2.020265550283779, -1.998697486713019, -1.9766855271118742, -1.9542363314451061, -1.9313567546859258, -1.9080538522265176, -1.8843348859460372, -1.86020733101649, -1.8356788835376827, -1.8107574691048294, -1.7854512524266541, -1.759768648128344, -1.733718332892757, -1.7073092591154113, -1.6805506702744417, -1.65345211824658, -1.6260234828350155, -1.5982749938156504, -1.5702172558558074, -1.5418612767151987, -1.5132184992044047, -1.4843008374530908, -1.455120718130901, -1.425691127370973, -1.3960256642725086, -1.3661386020084612, -1.336044957741627, -1.305760572762516, -1.2753022045114564, -1.2446876324427547, -1.2139357800387085, -1.1830668556953938, -1.1521025156910212, -1.121066053022605, -1.089982616569239, -1.0588794658207603, -1.0277862673062033, -0.9967354398674017, -0.9657625570369296, -0.9349068159615782, -0.9042115834911286, -0.873725031096367, -0.8435008709659574, -0.8135992055923523, -0.7840875018134352, -0.7550416967431254, -0.7265474359885522, -0.698701432142091, -0.6716129112125211, -0.6454050832071881, -0.6202165268842551, -0.5962023145949414, -0.5735346202617746, -0.5524024566683953, -0.5330100928437123, -0.515573640454186, -0.5003153218623142, -0.4874551084274461, -0.47719980336259293, -0.469730242539843, -0.4651879951493533, -0.46366353198530824, -0.46518799514935644, -0.4697302425398492, -0.4771998033626021, -0.48745510842745804, -0.5003153218623287, -0.5155736404542027, -0.5330100928437312, -0.5524024566684161, -0.5735346202617971, -0.5962023145949655, -0.6202165268842804, -0.6454050832072145, -0.6716129112125484, -0.6987014321421191, -0.7265474359885811, -0.755041696743155, -0.7840875018134652, -0.8135992055923831, -0.8435008709659882, -0.8737250310963981, -0.90421158349116, -0.93490681596161, -0.9657625570369611, -0.9967354398674334, -1.027786267306235, -1.058879465820792, -1.089982616569271, -1.121066053022637, -1.152102515691053, -1.1830668556954256, -1.2139357800387403, -1.2446876324427862, -1.275302204511488, -1.3057605727625472, -1.336044957741658, -1.3661386020084918, -1.396025664272539, -1.4256911273710031, -1.4551207181309311, -1.4843008374531212, -1.5132184992044342, -1.541861276715228, -1.5702172558558363, -1.598274993815679, -1.626023482835044, -1.6534521182466082, -1.6805506702744692, -1.7073092591154384, -1.7337183328927839, -1.7597686481283707, -1.7854512524266803, -1.810757469104855, -1.835678883537708, -1.860207331016515, -1.884334885946062, -1.9080538522265418, -1.9313567546859496, -1.9542363314451296, -1.9766855271118966, -1.9986974867130414, -2.0202655502838014, -2.0413832480437546, -2.062044296096265, -2.082242592595771, -2.10197221433344, -2.121227413697228, -2.1400026159671772, -2.1582924169110345, -2.1760915806490093, -2.1933950377597884, -2.210197883602838, -2.226495376834605, -2.242282938098528, -2.2575561488707927, -2.272310750445588, -2.2865426430452223, -2.300247885041911, -2.3134226922793286, -2.3260634374831715, -2.33816664975102, -2.3497290141127114, -2.360747371153278, -2.3712187166912573, -2.3811402015058674, -2.390509131107158, -2.3993229655438006, -2.4075793192437134, -2.415275960883161, -2.4224108132803885, -2.428981953310288, -2.4349876118368785, -2.440426173660783, -2.4452961774791513, -2.44959631585577, -2.453325435199383, -2.4564825357484694, -2.4590667715609937, -2.46107745050783, -2.4625140342688154, -2.4633761383305517], [-2.4358844184753514, -2.435599263986433, -2.4347438761194473, -2.4333184816723055, -2.431323458636922, -2.428759336192618, -2.425626794697468, -2.4219266656782192, -2.417659931819549, -2.4128277269536382, -2.407431336051226, -2.4014721952155136, -2.3949518916805084, -2.387872163815602, -2.3802349011384667, -2.372042144338554, -2.363296085313821, -2.3539990672235573, -2.344153584560559, -2.3337622832462173, -2.322827960752503, -2.311353566255246, -2.2993422008235624, -2.2867971176508317, -2.2737217223331423, -2.260119573201802, -2.245994381717171, -2.2313500129318387, -2.216190486032064, -2.2005199749672912, -2.1843428091786627, -2.1676634744386094, -2.1504866138149454, -2.1328170287743644, -2.1146596804419198, -2.096019691034949, -2.0769023454920155, -2.057313093319837, -2.037257550683876, -2.01674150277132, -1.995770906458648, -1.9743518933199498, -1.95249077301661, -1.9301940371141257, -1.9074683633776528, -1.8843206206045573, -1.8607578740599355, -1.8367873915898472, -1.8124166504971428, -1.7876533452764485, -1.7625053963183368, -1.7369809597083363, -1.7110884382645082, -1.6848364939783531, -1.6582340620482736, -1.6312903667233802, -1.6040149392087995, -1.5764176379227466, -1.548508671441534, -1.5202986245226806, -1.4917984876599395, -1.4630196906992674, -1.4339741411337348, -1.404674267800933, -1.3751330708318084, -1.3453641788491033, -1.315381914591467, -1.2852013703516796, -1.2548384948712126, -1.224310193636926, -1.1936344448889258, -1.1628304340831588, -1.1319187100717574, -1.1009213668839049, -1.0698622557271786, -1.0387672327020465, -1.0076644487480277, -0.9765846895333633, -0.9455617743671828, -0.9146330247440355, -0.8838398147853079, -0.853228217528545, -0.8228497625557016, -0.792762321526732, -0.7630311382579315, -0.733730018181718, -0.7049426869769839, -0.6767643177967729, -0.6493032078429702, -0.622682553936221, -0.597042228026931, -0.5725403816668249, -0.5493546090498588, -0.5276822723143895, -0.5077394533787666, -0.48975787822788, -0.47397912749168836, -0.4606455968772346, -0.4499881033900563, -0.4422107915230523, -0.43747497266625884, -0.4358844184753516, -0.4374749726662622, -0.4422107915230588, -0.4499881033900658, -0.46064559687724704, -0.4739791274917034, -0.4897578782278973, -0.5077394533787861, -0.5276822723144109, -0.549354609049882, -0.5725403816668494, -0.5970422280269568, -0.6226825539362479, -0.6493032078429981, -0.6767643177968016, -0.7049426869770133, -0.7337300181817478, -0.763031138257962, -0.7927623215267627, -0.8228497625557327, -0.8532282175285762, -0.8838398147853395, -0.9146330247440673, -0.9455617743672147, -0.9765846895333953, -1.00766444874806, -1.0387672327020787, -1.0698622557272106, -1.1009213668839368, -1.1319187100717891, -1.1628304340831905, -1.1936344448889578, -1.2243101936369576, -1.254838494871244, -1.2852013703517107, -1.3153819145914978, -1.345364178849134, -1.375133070831839, -1.4046742678009634, -1.4339741411337648, -1.4630196906992972, -1.491798487659969, -1.5202986245227097, -1.548508671441563, -1.576417637922775, -1.6040149392088277, -1.6312903667234082, -1.658234062048301, -1.68483649397838, -1.7110884382645353, -1.736980959708363, -1.7625053963183628, -1.7876533452764742, -1.8124166504971682, -1.8367873915898718, -1.8607578740599597, -1.8843206206045808, -1.9074683633776761, -1.9301940371141488, -1.9524907730166323, -1.9743518933199717, -1.9957709064586697, -2.0167415027713416, -2.0372575506838975, -2.0573130933198573, -2.076902345492035, -2.0960196910349684, -2.114659680441939, -2.132817028774383, -2.1504866138149636, -2.167663474438627, -2.1843428091786796, -2.200519974967308, -2.21619048603208, -2.2313500129318533, -2.245994381717185, -2.2601195732018167, -2.273721722333156, -2.2867971176508446, -2.299342200823575, -2.3113535662552573, -2.3228279607525146, -2.333762283246228, -2.3441535845605697, -2.353999067223567, -2.3632960853138303, -2.372042144338563, -2.3802349011384747, -2.3878721638156097, -2.394951891680515, -2.4014721952155202, -2.407431336051231, -2.412827726953643, -2.417659931819554, -2.4219266656782237, -2.4256267946974717, -2.428759336192621, -2.431323458636925, -2.4333184816723064, -2.4347438761194478, -2.435599263986433], [-2.4076836149416687, -2.407400786465547, -2.4065523753326272, -2.4051386044263503, -2.403159845209497, -2.400616617710043, -2.3975095905018775, -2.3938395806809614, -2.389607553837598, -2.384814624025728, -2.379462053730274, -2.3735512538337855, -2.3670837835838103, -2.360061350562627, -2.352485810661194, -2.3443591680594213, -2.335683575215078, -2.3264613328639934, -2.3166948900344293, -2.3063868440788897, -2.295539940726942, -2.28415707416303, -2.2722412871336792, -2.2597957710889585, -2.2468238663635822, -2.233329062403588, -2.2193149980451876, -2.204785461853048, -2.189744392526068, -2.174195879379569, -2.1581441629137816, -2.1415936354795964, -2.1245488420537653, -2.1070144811370795, -2.088995405790594, -2.070496624826683, -2.0515233041736436, -2.032080768434768, -2.0121745026652667, -1.9918101543932554, -1.9709935359141866, -1.9497306268917607, -1.928027577302463, -1.9058907107656167, -1.8833265283062337, -1.8603417126041346, -1.8369431327899108, -1.8131378498564954, -1.788933122764502, -1.7643364153303995, -1.7393554039991617, -1.7139979866176496, -1.688272292341943, -1.6621866928316118, -1.6357498149069771, -1.6089705548724107, -1.5818580947403473, -1.554421920627869, -1.5266718436415139, -1.4986180236176398, -1.4702709961468692, -1.441641703383659, -1.412741529228317, -1.383582339571532, -1.354176528414228, -1.3245370708224453, -1.2946775838531241, -1.2646123967984186, -1.2343566323510782, -1.2039263006008534, -1.1733384081430804, -1.142611085029209, -1.111763732831466, -1.080817197749507, -1.0497939734785577, -1.0187184395121867, -0.9876171416971087, -0.9565191232220408, -0.9254563158350141, -0.8944640029624126, -0.8635813685469649, -0.8328521477896366, -0.8023253984576852, -0.7720564137670443, -0.7421077996080876, -0.7125507392607048, -0.6834664663948098, -0.6549479599084291, -0.6271018586569348, -0.600050565406803, -0.5739344605218766, -0.5489140683278052, -0.5251719038405442, -0.5029135693066624, -0.4823674755989215, -0.46378236598861367, -0.4474216963054832, -0.43355400808105604, -0.42243888676180524, -0.41430904447208855, -0.40935042796552285, -0.4076836149416689, -0.4093504279655262, -0.4143090444720953, -0.4224388867618152, -0.433554008081069, -0.44742169630549883, -0.4637823659886316, -0.48236747559894166, -0.5029135693066845, -0.5251719038405679, -0.5489140683278303, -0.5739344605219029, -0.6000505654068302, -0.627101858656963, -0.654947959908458, -0.6834664663948394, -0.7125507392607348, -0.7421077996081182, -0.7720564137670751, -0.8023253984577166, -0.8328521477896679, -0.8635813685469964, -0.8944640029624443, -0.9254563158350461, -0.9565191232220728, -0.9876171416971407, -1.0187184395122186, -1.0497939734785895, -1.0808171977495387, -1.1117637328314978, -1.1426110850292406, -1.173338408143112, -1.2039263006008847, -1.2343566323511095, -1.26461239679845, -1.2946775838531548, -1.324537070822476, -1.3541765284142584, -1.3835823395715618, -1.412741529228347, -1.4416417033836888, -1.4702709961468987, -1.498618023617669, -1.5266718436415427, -1.5544219206278977, -1.5818580947403753, -1.6089705548724382, -1.6357498149070044, -1.6621866928316387, -1.6882722923419697, -1.713997986617676, -1.7393554039991876, -1.764336415330425, -1.788933122764527, -1.81313784985652, -1.836943132789935, -1.8603417126041581, -1.883326528306257, -1.9058907107656393, -1.9280275773024853, -1.9497306268917831, -1.9709935359142083, -1.9918101543932765, -2.0121745026652875, -2.0320807684347884, -2.0515233041736636, -2.0704966248267023, -2.088995405790613, -2.1070144811370977, -2.124548842053783, -2.1415936354796137, -2.158144162913798, -2.1741958793795857, -2.1897443925260838, -2.2047854618530627, -2.2193149980452023, -2.233329062403602, -2.246823866363596, -2.259795771088972, -2.2722412871336912, -2.2841570741630415, -2.2955399407269534, -2.3063868440789004, -2.316694890034439, -2.326461332864003, -2.3356835752150875, -2.3443591680594302, -2.3524858106612023, -2.360061350562634, -2.3670837835838174, -2.373551253833792, -2.3794620537302795, -2.3848146240257333, -2.3896075538376027, -2.393839580680966, -2.397509590501882, -2.400616617710046, -2.4031598452094998, -2.4051386044263516, -2.4065523753326286, -2.407400786465547], [-2.379088403840359, -2.378807990217782, -2.3779668223431627, -2.3765651191914614, -2.3746032457064574, -2.372081712779245, -2.3690011772186144, -2.365362441713807, -2.361166454790265, -2.3564143107591686, -2.3511072496616934, -2.3452466572091, -2.3388340647199244, -2.3318711490557402, -2.3243597325571397, -2.3163017829818164, -2.307699413446834, -2.2985548823774185, -2.28887059346489, -2.2786490956366197, -2.267893083041222, -2.256605395052538, -2.244789016296344, -2.2324470767041373, -2.2195828515988123, -2.206199761817543, -2.192301373877774, -2.177891400192819, -2.162973699344287, -2.1475522764193347, -2.131631283421593, -2.115215019765617, -2.098307932865777, -2.0809146188317427, -2.0630398232840927, -2.0446884423051332, -2.0258655235417526, -2.0065762674791445, -1.9868260289064492, -1.966620318597931, -1.945964805236208, -1.924865317607326, -1.9033278471012725, -1.881358550555786, -1.8589637534862873, -1.8361499537503876, -1.8129238257019435, -1.789292224897132, -1.76526219342365, -1.7408409659341881, -1.7160359764769069, -1.6908548662291516, -1.6653054922563537, -1.6393959374364016, -1.613134521711232, -1.586529814852555, -1.5595906509582265, -1.5323261449306507, -1.5047457112298037, -1.4768590852422887, -1.4486763476657936, -1.4202079523773496, -1.3914647583362032, -1.3624580661707308, -1.3331996602172238, -1.303701856920806, -1.27397756068059, -1.2440403284290256, -1.2139044444873752, -1.18358500754547, -1.1530980319867874, -1.122460566234857, -1.091690831352905, -1.0608083838086655, -1.029834307148498, -0.9987914383431054, -0.9677046358109918, -0.9366010976410148, -0.9055107403719844, -0.8744666508959403, -0.8435056266757504, -0.8126688225271431, -0.7820025256789703, -0.7515590845605936, -0.7213980204525156, -0.6915873541289014, -0.6622051807175285, -0.6333415230985431, -0.6051004837341832, -0.5776026912329583, -0.5509879926671949, -0.5254182636739153, -0.5010800806889836, -0.4781868086711063, -0.4569793983798226, -0.4377248834036149, -0.42071130138394697, -0.40623770959162353, -0.3945983850149023, -0.38606144983546276, -0.3808440584936737, -0.37908840384035897, -0.3808440584936773, -0.38606144983546997, -0.3945983850149127, -0.406237709591637, -0.4207113013839632, -0.43772488340363347, -0.45697939837984336, -0.47818680867112895, -0.5010800806890079, -0.5254182636739408, -0.5509879926672218, -0.5776026912329861, -0.605100483734212, -0.6333415230985723, -0.6622051807175584, -0.6915873541289317, -0.7213980204525465, -0.7515590845606248, -0.7820025256790017, -0.8126688225271745, -0.843505626675782, -0.8744666508959722, -0.9055107403720164, -0.9366010976410469, -0.9677046358110236, -0.9987914383431373, -1.0298343071485299, -1.0608083838086972, -1.0916908313529368, -1.1224605662348883, -1.153098031986819, -1.1835850075455012, -1.2139044444874063, -1.2440403284290564, -1.273977560680621, -1.3037018569208367, -1.333199660217254, -1.3624580661707606, -1.3914647583362327, -1.4202079523773792, -1.4486763476658229, -1.4768590852423176, -1.5047457112298321, -1.532326144930679, -1.5595906509582547, -1.5865298148525824, -1.613134521711259, -1.6393959374364284, -1.6653054922563801, -1.6908548662291776, -1.7160359764769326, -1.7408409659342137, -1.765262193423675, -1.7892922248971566, -1.812923825701968, -1.836149953750411, -1.8589637534863102, -1.8813585505558086, -1.9033278471012944, -1.924865317607348, -1.9459648052362293, -1.966620318597952, -1.9868260289064696, -2.006576267479165, -2.0258655235417726, -2.0446884423051523, -2.0630398232841114, -2.080914618831761, -2.098307932865795, -2.115215019765634, -2.1316312834216093, -2.147552276419351, -2.1629736993443034, -2.177891400192834, -2.192301373877789, -2.206199761817557, -2.2195828515988256, -2.23244707670415, -2.244789016296356, -2.2566053950525498, -2.2678930830412334, -2.2786490956366303, -2.2888705934648996, -2.2985548823774278, -2.307699413446843, -2.3163017829818253, -2.324359732557147, -2.3318711490557478, -2.3388340647199315, -2.345246657209106, -2.3511072496616987, -2.356414310759173, -2.3611664547902698, -2.3653624417138115, -2.369001177218618, -2.3720817127792477, -2.37460324570646, -2.3765651191914627, -2.377966822343163, -2.378807990217783], [-2.35012644919137, -2.3498485412991577, -2.349014889318964, -2.347625708334343, -2.3456813567986816, -2.343182336506617, -2.340129292554432, -2.3365230132898795, -2.3323644302519804, -2.3276546181014863, -2.3223947945428463, -2.316586320238635, -2.3102306987175925, -2.303329576277537, -2.2958847418846404, -2.2878981270707017, -2.279371805830266, -2.270307994519659, -2.260709051760232, -2.2505774783483754, -2.2399159171751277, -2.228727153158522, -2.217014113192141, -2.204779866113724, -2.192027622698079, -2.1787607356789906, -2.1649826998053396, -2.1506971519371807, -2.1359078711881563, -2.1206187791213242, -2.104833940006216, -2.0885575611458522, -2.071793993283371, -2.054547731099037, -2.036823413809618, -2.0186258258835, -1.9999598978864748, -1.9808307074749045, -1.9612434805549648, -1.9412035926289626, -1.9207165703523, -1.8997880933276248, -1.8784239961660834, -1.8566302708494462, -1.8344130694313334, -1.8117787071208415, -1.7887336657977497, -1.7652845980152594, -1.7414383315540456, -1.71720187460048, -1.6925824216324312, -1.6675873601083224, -1.6422242780694565, -1.61650097278239, -1.590425460567786, -1.5640059879853068, -1.5372510445713423, -1.5101693773586011, -1.4827700074447365, -1.4550622489225653, -1.4270557305384883, -1.3987604205103359, -1.3701866550133093, -1.341345170935804, -1.312247143619152, -1.2829042304311244, -1.2533286211877208, -1.2235330966382105, -1.1935310964729633, -1.1633367986129806, -1.132965211907518, -1.102432284818468, -1.0717550332282764, -1.0409516911983174, -1.0100418893597738, -0.9790468666799069, -0.9479897226635456, -0.9168957186838492, -0.8857926391609461, -0.8547112258061387, -0.8236857012150184, -0.7927544018153876, -0.7619605446236938, -0.7313531574427795, -0.7009882079124414, -0.6709299727976419, -0.6412526941530529, -0.6120425717166029, -0.5834001376905206, -0.5554430450685289, -0.5283092640635748, -0.5021606076669815, -0.47718637495532557, -0.45360668216808464, -0.4316747224229887, -0.41167675637674606, -0.39392816032314487, -0.3787635541855669, -0.366519291688535, -0.35750791231804374, -0.35198677612435086, -0.3501264491913699, -0.35198677612435475, -0.3575079123180513, -0.3665192916885459, -0.37876355418558105, -0.39392816032316197, -0.41167675637676543, -0.43167472242301025, -0.4536066821681082, -0.4771863749553505, -0.5021606076670078, -0.5283092640636023, -0.5554430450685572, -0.5834001376905495, -0.6120425717166326, -0.641252694153083, -0.6709299727976725, -0.7009882079124725, -0.7313531574428109, -0.7619605446237254, -0.7927544018154192, -0.8236857012150502, -0.8547112258061706, -0.8857926391609781, -0.9168957186838813, -0.9479897226635775, -0.979046866679939, -1.0100418893598058, -1.040951691198349, -1.071755033228308, -1.1024322848184995, -1.1329652119075493, -1.1633367986130119, -1.1935310964729942, -1.2235330966382414, -1.2533286211877515, -1.2829042304311546, -1.3122471436191823, -1.3413451709358335, -1.370186655013339, -1.3987604205103654, -1.4270557305385174, -1.455062248922594, -1.4827700074447647, -1.510169377358629, -1.5372510445713696, -1.564005987985334, -1.590425460567813, -1.6165009727824164, -1.6422242780694827, -1.6675873601083484, -1.692582421632457, -1.717201874600505, -1.74143833155407, -1.7652845980152834, -1.7887336657977733, -1.8117787071208649, -1.8344130694313565, -1.8566302708494686, -1.8784239961661056, -1.8997880933276468, -1.9207165703523212, -1.9412035926289835, -1.961243480554985, -1.9808307074749243, -1.9999598978864943, -2.018625825883519, -2.036823413809637, -2.054547731099055, -2.071793993283389, -2.088557561145869, -2.104833940006232, -2.1206187791213402, -2.1359078711881723, -2.1506971519371954, -2.1649826998053543, -2.1787607356790044, -2.1920276226980926, -2.2047798661137366, -2.2170141131921532, -2.228727153158534, -2.2399159171751397, -2.250577478348386, -2.260709051760242, -2.2703079945196687, -2.279371805830275, -2.28789812707071, -2.295884741884648, -2.3033295762775445, -2.3102306987175996, -2.316586320238642, -2.322394794542852, -2.3276546181014917, -2.332364430251985, -2.336523013289884, -2.3401292925544355, -2.34318233650662, -2.3456813567986843, -2.347625708334344, -2.349014889318965, -2.349848541299158], [-2.3208257698153467, -2.3205504606043106, -2.319724603380472, -2.3183484093645106, -2.3164222305671953, -2.313946559754027, -2.3109220303961, -2.3073494166075657, -2.303229633070187, -2.298563734945566, -2.293352917775792, -2.2875985173733313, -2.281302009701162, -2.274465010744259, -2.2670892763737114, -2.259176702204905, -2.2507293234513703, -2.241749314776103, -2.2322389901423496, -2.222200802666076, -2.2116373444725888, -2.200551346560039, -2.188945678672824, -2.17682334918823, -2.164187505020017, -2.151041431543032, -2.1373885525433844, -2.123232430199173, -2.108576765097348, -2.093425396292827, -2.0777823014167165, -2.0616515968412052, -2.0450375379095647, -2.0279445192406347, -2.0103770751182535, -1.9923398799772931, -1.9738377489993402, -1.9548756388326103, -1.9354586484524454, -1.9155920201807461, -1.8952811408849757, -1.8745315433799763, -1.8533489080588128, -1.8317390647822782, -1.8097079950606194, -1.787261834565535, -1.764406876015732, -1.7411495724853054, -1.7174965411911962, -1.693454567824062, -1.6690306114963032, -1.644231810391965, -1.6190654882160829, -1.5935391615560761, -1.5676605482855022, -1.5414375771613225, -1.5148783987904777, -1.4879913981707817, -1.4607852090458433, -1.433268730355118, -1.4054511451096579, -1.3773419420834863, -1.348950940781915, -1.3202883202343336, -1.291364652263395, -1.262190940009389, -1.232778662643312, -1.2031398273914566, -1.173287030226807, -1.1432335268690101, -1.1129933160889505, -1.0825812377535575, -1.0520130885938603, -1.0213057593630699, -0.9904773979082444, -0.9595476037555775, -0.928537661165058, -0.8974708193205012, -0.8663726304803927, -0.8352713596407747, -0.8041984826952728, -0.7731892943845113, -0.7422836526873205, -0.7115268928894009, -0.6809709524770171, -0.6506757571730515, -0.6207109283967516, -0.5911578819299531, -0.5621123938472687, -0.5336877073252008, -0.5060182326042485, -0.479263834381288, -0.45361457737784777, -0.42929556923402823, -0.4065711476449374, -0.3857470645987657, -0.3671685539627527, -0.3512114436499713, -0.33826333116914303, -0.32869315917419645, -0.3228110719999002, -0.3208257698153465, -0.3228110719999043, -0.32869315917420444, -0.33826333116915464, -0.35121144364998635, -0.36716855396277065, -0.38574706459878594, -0.4065711476449598, -0.42929556923405243, -0.45361457737787336, -0.4792638343813149, -0.5060182326042765, -0.5336877073252296, -0.5621123938472983, -0.5911578819299832, -0.6207109283967821, -0.6506757571730823, -0.6809709524770484, -0.7115268928894323, -0.7422836526873523, -0.7731892943845431, -0.8041984826953047, -0.8352713596408066, -0.8663726304804246, -0.8974708193205331, -0.9285376611650901, -0.9595476037556091, -0.990477397908276, -1.0213057593631016, -1.0520130885938916, -1.0825812377535888, -1.1129933160889818, -1.1432335268690412, -1.1732870302268377, -1.2031398273914875, -1.2327786626433426, -1.262190940009419, -1.291364652263425, -1.3202883202343632, -1.3489509407819442, -1.3773419420835156, -1.4054511451096867, -1.4332687303551461, -1.4607852090458715, -1.4879913981708095, -1.514878398790505, -1.5414375771613493, -1.5676605482855288, -1.5935391615561023, -1.619065488216109, -1.6442318103919908, -1.6690306114963285, -1.6934545678240867, -1.7174965411912206, -1.7411495724853296, -1.7644068760157559, -1.7872618345655582, -1.809707995060642, -1.8317390647823009, -1.8533489080588346, -1.8745315433799976, -1.8952811408849968, -1.9155920201807668, -1.9354586484524658, -1.9548756388326303, -1.9738377489993593, -1.9923398799773115, -2.010377075118272, -2.0279445192406524, -2.045037537909582, -2.061651596841222, -2.077782301416733, -2.0934253962928424, -2.1085767650973635, -2.123232430199188, -2.137388552543399, -2.151041431543047, -2.16418750502003, -2.176823349188242, -2.188945678672836, -2.2005513465600504, -2.2116373444725994, -2.2222008026660864, -2.23223899014236, -2.2417493147761127, -2.2507293234513788, -2.259176702204913, -2.267089276373719, -2.274465010744266, -2.2813020097011685, -2.287598517373338, -2.2933529177757976, -2.2985637349455708, -2.3032296330701914, -2.3073494166075696, -2.3109220303961036, -2.3139465597540307, -2.316422230567198, -2.318348409364512, -2.3197246033804735, -2.320550460604311], [-2.2912147122272306, -2.2909420967550034, -2.2901243194738483, -2.288761587781947, -2.286854247314998, -2.2844027819044554, -2.281407813519393, -2.277870102192298, -2.273790545929216, -2.269170180604759, -2.264010179842595, -2.258311854882145, -2.2520766544323254, -2.245306164513295, -2.2380021082872963, -2.2301663458798178, -2.2218008741924504, -2.212907826708972, -2.2034894732963806, -2.1935482200027523, -2.1830866088540546, -2.1721073176522325, -2.1606131597771516, -2.14860708399526, -2.136092174278119, -2.1230716496343143, -2.1095488639585893, -2.0955273059025186, -2.081010598771428, -2.066002500452853, -2.050506903382349, -2.0345278345531512, -2.018069455576888, -2.0011360628033716, -1.9837320875084221, -1.965862096159705, -1.9475307907717547, -1.9287430093626823, -1.9095037265265826, -1.8898180541373928, -1.8696912422019023, -1.8491286798818865, -1.8281358967078882, -1.8067185640101484, -1.7848824965955632, -1.7626336547034689, -1.7399781462775776, -1.7169222295966124, -1.693472316312253, -1.6696349749500758, -1.6454169349373806, -1.6208250912314177, -1.595866509632782, -1.570548432881989, -1.5448782876528027, -1.5188636925743215, -1.4925124674356167, -1.465832643752638, -1.4388324769079848, -1.4115204601110483, -1.3839053404703416, -1.3559961375231002, -1.3278021646316212, -1.299333053733782, -1.2705987840300517, -1.2416097153050978, -1.2123766267239873, -1.182910762117558, -1.1532238829871175, -1.123328330726003, -1.09323709988846, -1.0629639247525746, -1.0325233819466881, -1.0019310125677567, -0.9712034680544555, -0.9403586851383329, -0.9094160965493756, -0.878396885884648, -0.8473242972731624, -0.8162240133332669, -0.7851246186088534, -0.7540581704259819, -0.723060905226409, -0.6921741162569697, -0.6614452484025054, -0.6309292682874562, -0.6006903826840755, -0.5708041953644859, -0.5413604102099444, -0.5124662025002124, -0.48425038176841045, -0.4568684402682984, -0.43050848725461094, -0.4053978532096673, -0.3818097218282178, -0.3600684026081096, -0.3405507248139088, -0.3236796528690784, -0.3099052442892084, -0.29966892981846016, -0.2933516242666591, -0.29121471222723055, -0.2933516242666635, -0.2996689298184687, -0.30990524428922084, -0.3236796528690943, -0.3405507248139276, -0.3600684026081308, -0.3818097218282411, -0.40539785320969235, -0.4305084872546374, -0.4568684402683261, -0.484250381768439, -0.5124662025002417, -0.5413604102099744, -0.5708041953645163, -0.6006903826841065, -0.6309292682874875, -0.6614452484025369, -0.6921741162570013, -0.7230609052264408, -0.7540581704260138, -0.7851246186088854, -0.8162240133332989, -0.8473242972731944, -0.8783968858846798, -0.9094160965494075, -0.9403586851383646, -0.9712034680544871, -1.0019310125677883, -1.0325233819467194, -1.0629639247526057, -1.0932370998884908, -1.1233283307260336, -1.1532238829871482, -1.1829107621175887, -1.2123766267240175, -1.2416097153051278, -1.2705987840300814, -1.2993330537338112, -1.3278021646316502, -1.3559961375231293, -1.3839053404703703, -1.4115204601110767, -1.4388324769080125, -1.465832643752666, -1.492512467435644, -1.5188636925743486, -1.5448782876528293, -1.570548432882015, -1.595866509632808, -1.620825091231443, -1.645416934937406, -1.6696349749501003, -1.693472316312277, -1.7169222295966362, -1.7399781462776012, -1.7626336547034915, -1.7848824965955858, -1.8067185640101708, -1.8281358967079098, -1.8491286798819078, -1.8696912422019234, -1.8898180541374137, -1.9095037265266026, -1.928743009362702, -1.9475307907717738, -1.9658620961597233, -1.9837320875084403, -2.0011360628033894, -2.018069455576905, -2.034527834553168, -2.0505069033823653, -2.066002500452869, -2.081010598771443, -2.0955273059025328, -2.1095488639586035, -2.1230716496343276, -2.1360921742781325, -2.1486070839952722, -2.160613159777164, -2.172107317652244, -2.1830866088540657, -2.1935482200027625, -2.2034894732963903, -2.2129078267089817, -2.2218008741924584, -2.230166345879826, -2.2380021082873043, -2.245306164513303, -2.2520766544323316, -2.2583118548821512, -2.2640101798426007, -2.2691701806047644, -2.2737905459292205, -2.277870102192302, -2.281407813519396, -2.284402781904458, -2.2868542473150004, -2.2887615877819494, -2.290124319473849, -2.2909420967550043], [-2.2613219232128388, -2.261052098670769, -2.2602426929238297, -2.2588939096002534, -2.257006088048534, -2.2545797032897212, -2.2516153659508977, -2.248113822180107, -2.2440759535430828, -2.2395027769022113, -2.234395444278242, -2.228755242695358, -2.2225835940103136, -2.2158820547264284, -2.208652315793375, -2.200896202393768, -2.1926156737177194, -2.1838128227266336, -2.174489875907694, -2.16464919302061, -2.1542932668384065, -2.1434247228841925, -2.1320463191660814, -2.1201609459126534, -2.107771625311591, -2.0948815112544312, -2.0814938890906536, -2.0676121753946917, -2.053239917749843, -2.0383807945534658, -2.023038614848346, -2.0072173181856656, -1.9909209745255914, -1.9741537841822072, -1.9569200778202733, -1.9392243165121728, -1.921071091864393, -1.9024651262240122, -1.8834112729769314, -1.863914516951047, -1.8439799749392176, -1.8236128963587694, -1.802818664066457, -1.7816027953502895, -1.759970943122513, -1.7379288973413303, -1.715482586692793, -1.692638080568719, -1.669401591381654, -1.6457794772638967, -1.6217782452046139, -1.5974045546872813, -1.5726652218993094, -1.5475672245970542, -1.5221177077227868, -1.4963239898860248, -1.4701935708404443, -1.4437341401099724, -1.4169535869444219, -1.389860011817113, -1.3624617397155083, -1.3347673355224845, -1.3067856218423037, -1.2785256996940053, -1.2499969725787676, -1.2212091745305476, -1.1921724028858114, -1.1628971566645645, -1.1333943816490821, -1.1036755234889934, -1.073752590464945, -1.0436382279253291, -1.0133458068942793, -0.9828895299642044, -0.9522845583722703, -0.9215471651700232, -0.890694920698995, -0.8597469182765212, -0.8287240502009137, -0.7976493470723883, -0.7665483972219032, -0.7354498680463213, -0.7043861576648622, -0.6733942140600785, -0.6425165704084074, -0.611802660440474, -0.5813104972760597, -0.55110882400413, -0.5212798744398598, -0.4919229163099149, -0.4631587806709582, -0.43513559558291176, -0.40803590553031316, -0.38208520343551944, -0.35756150586634755, -0.33480476664537745, -0.3142234069395449, -0.29629294029139064, -0.2815391502536509, -0.27049761004323264, -0.26364634465734405, -0.2613219232128388, -0.2636463446573488, -0.27049761004324197, -0.28153915025366427, -0.29629294029140757, -0.3142234069395648, -0.33480476664539977, -0.35756150586637186, -0.3820852034355455, -0.4080359055303404, -0.4351355955829401, -0.4631587806709874, -0.4919229163099449, -0.5212798744398902, -0.5511088240041608, -0.5813104972760909, -0.6118026604405054, -0.642516570408439, -0.6733942140601102, -0.704386157664894, -0.7354498680463533, -0.766548397221935, -0.7976493470724203, -0.8287240502009455, -0.8597469182765531, -0.8906949206990269, -0.9215471651700549, -0.952284558372302, -0.9828895299642358, -1.0133458068943106, -1.04363822792536, -1.0737525904649756, -1.1036755234890243, -1.1333943816491125, -1.1628971566645947, -1.1921724028858414, -1.221209174530577, -1.249996972578797, -1.2785256996940344, -1.3067856218423328, -1.3347673355225131, -1.3624617397155367, -1.389860011817141, -1.4169535869444496, -1.4437341401099997, -1.4701935708404714, -1.4963239898860514, -1.5221177077228132, -1.5475672245970802, -1.5726652218993347, -1.5974045546873064, -1.6217782452046385, -1.6457794772639212, -1.669401591381678, -1.6926380805687427, -1.7154825866928163, -1.737928897341353, -1.7599709431225354, -1.7816027953503117, -1.8028186640664783, -1.8236128963587905, -1.843979974939238, -1.863914516951067, -1.8834112729769512, -1.902465126224032, -1.921071091864412, -1.9392243165121907, -1.956920077820291, -1.9741537841822245, -1.9909209745256082, -2.007217318185682, -2.023038614848362, -2.0383807945534813, -2.053239917749858, -2.067612175394706, -2.0814938890906673, -2.0948815112544454, -2.107771625311604, -2.1201609459126654, -2.1320463191660934, -2.1434247228842036, -2.1542932668384176, -2.1646491930206206, -2.174489875907703, -2.183812822726643, -2.1926156737177283, -2.2008962023937766, -2.208652315793382, -2.215882054726435, -2.2225835940103202, -2.2287552426953647, -2.234395444278247, -2.239502776902216, -2.244075953543087, -2.248113822180111, -2.2516153659509013, -2.254579703289724, -2.257006088048536, -2.2588939096002547, -2.2602426929238306, -2.2610520986707696], [-2.2311763221149477, -2.2309093878481483, -2.230108651692398, -2.228774313570975, -2.2269067066538426, -2.224506297304493, -2.2215736850057617, -2.2181096022648163, -2.2141149144976087, -2.209590619893151, -2.204537849258031, -2.1989578658416757, -2.192852065142933, -2.186221974698632, -2.179069253854877, -2.171395693521901, -2.1632032159134473, -2.1544938742716977, -2.1452698525789575, -2.135533465257361, -2.1252871568580627, -2.114533501741497, -2.103275203750477, -2.091515095878078, -2.079256139932463, -2.066501426201036, -2.0532541731165628, -2.039517726928169, -2.025295561380455, -2.0105912774043113, -1.9954086028233975, -1.979751392080714, -1.9636236259901618, -1.947029411518565, -1.929972981604241, -1.912458695018933, -1.8944910362806988, -1.8760746156262935, -1.8572141690525956, -1.837914558437829, -1.818180771754678, -1.7980179233889453, -1.7774312545791757, -1.756426133994712, -1.7350080584720105, -1.7131826539317456, -1.690955676502394, -1.6683330138796337, -1.6453206869551316, -1.6219248517532623, -1.5981518017200715, -1.574007970415597, -1.5494999346686325, -1.5246344182624345, -1.499418296230987, -1.4738585998586393, -1.4479625224916284, -1.4217374262887374, -1.3951908500607826, -1.3683305183755996, -1.34116435213774, -1.3137004808914792, -1.2859472571436283, -1.2579132730610714, -1.229607379969556, -1.2010387111683893, -1.1722167086846282, -1.1431511547256463, -1.1138522087577936, -1.0843304513505987, -1.054596936192885, -1.0246632520254264, -0.9945415966658442, -0.9642448658538839, -0.9337867603573654, -0.9031819157026831, -0.8724460600988658, -0.8415962077065852, -0.8106508964943328, -0.7796304827040447, -0.7485575076677792, -0.7174571577224165, -0.6863578447419709, -0.6552919440133649, -0.6242967387378288, -0.5934156375885974, -0.5626997551336788, -0.532209976585664, -0.5020196705486509, -0.47221826804067923, -0.44291599262838516, -0.4142500977208591, -0.3863930185098688, -0.3595628146405218, -0.33403602292804924, -0.3101622710177559, -0.28837823344633323, -0.2692151409804246, -0.2532890274749414, -0.24125852092660144, -0.23373826277265083, -0.23117632211494746, -0.23373826277265605, -0.24125852092661162, -0.25328902747495596, -0.2692151409804428, -0.28837823344635444, -0.31016227101777943, -0.3340360229280747, -0.3595628146405488, -0.38639301850989693, -0.4142500977208881, -0.4429159926284151, -0.4722182680407096, -0.5020196705486818, -0.5322099765856951, -0.5626997551337102, -0.5934156375886289, -0.6242967387378606, -0.6552919440133967, -0.6863578447420029, -0.7174571577224483, -0.748557507667811, -0.7796304827040765, -0.8106508964943645, -0.8415962077066169, -0.8724460600988974, -0.9031819157027146, -0.9337867603573968, -0.9642448658539151, -0.9945415966658752, -1.024663252025457, -1.0545969361929157, -1.0843304513506293, -1.1138522087578238, -1.1431511547256765, -1.172216708684658, -1.2010387111684186, -1.2296073799695855, -1.2579132730611002, -1.2859472571436572, -1.3137004808915078, -1.3411643521377683, -1.3683305183756276, -1.3951908500608101, -1.4217374262887645, -1.447962522491655, -1.4738585998586657, -1.4994182962310132, -1.5246344182624605, -1.549499934668658, -1.5740079704156218, -1.5981518017200962, -1.6219248517532865, -1.645320686955155, -1.6683330138796575, -1.6909556765024174, -1.713182653931768, -1.7350080584720329, -1.7564261339947338, -1.7774312545791968, -1.7980179233889664, -1.8181807717546983, -1.837914558437849, -1.8572141690526154, -1.8760746156263128, -1.8944910362807177, -1.9124586950189513, -1.9299729816042588, -1.947029411518582, -1.9636236259901787, -1.9797513920807304, -1.995408602823413, -2.010591277404327, -2.02529556138047, -2.039517726928183, -2.0532541731165765, -2.0665014262010493, -2.0792561399324754, -2.09151509587809, -2.103275203750489, -2.114533501741508, -2.1252871568580733, -2.1355334652573714, -2.1452698525789673, -2.1544938742717066, -2.1632032159134553, -2.171395693521909, -2.179069253854884, -2.1862219746986393, -2.1928520651429393, -2.1989578658416815, -2.2045378492580365, -2.209590619893156, -2.2141149144976136, -2.21810960226482, -2.221573685005765, -2.2245062973044956, -2.226906706653845, -2.228774313570977, -2.230108651692399, -2.230909387848149], [-2.200807072855696, -2.2005431303752183, -2.1997513683696606, -2.1984319831350216, -2.1965853017925676, -2.1942117822308176, -2.1913120130244974, -2.187886713330645, -2.183936732762079, -2.1794630512385362, -2.1744667788157925, -2.168949155493185, -2.1629115509999868, -2.1563554645611562, -2.149282524643064, -2.1416944886798674, -2.1335932427812723, -2.1249808014225295, -2.1158593071175913, -2.1062310300764597, -2.0960983678478677, -2.0854638449485567, -2.074330112480549, -2.062699947737957, -2.0505762538050303, -2.037962059147326, -2.0248605171980896, -2.0112749059421318, -1.9972086274997702, -1.9826652077136402, -1.9676482957415127, -1.9521616636585928, -1.936209206073155, -1.9197949397598202, -1.9029230033152544, -1.8855976568416501, -1.86782328166395, -1.8496043800875275, -1.830945575203823, -1.8118516107523803, -1.7923273510487934, -1.7723777809892816, -1.7520080061440249, -1.7312232529529785, -1.7100288690397718, -1.6884303236614076, -1.6664332083140003, -1.644043237517639, -1.6212662498068624, -1.5981082089571315, -1.5745752054822924, -1.5506734584434236, -1.5264093176157965, -1.501789266068207, -1.476819923217794, -1.4515080484340415, -1.4258605452782278, -1.3998844664796635, -1.3735870197680957, -1.3469755747034653, -1.320057670670491, -1.2928410262375296, -1.265333550118109, -1.2375433540211975, -1.2094787677348977, -1.1811483568606473, -1.1525609437048325, -1.123725631946761, -1.094651835842377, -1.0653493149000752, -1.035828215189282, -1.006099118728378, -0.9761731027652457, -0.9460618112369736, -0.9157775413100986, -0.8853333487070206, -0.8547431765837574, -0.8240220141303465, -0.7931860929456176, -0.76225313177247, -0.7312426436230927, -0.7001763240398889, -0.6690785457504688, -0.6379769940400476, -0.606903489878065, -0.575895065787688, -0.5449953849334804, -0.5142566301997963, -0.4837420416893244, -0.45352935405698547, -0.42371548629465383, -0.39442297127194503, -0.3658087761748317, -0.33807632234898355, -0.3114915441416491, -0.2864034113187981, -0.26326774804366343, -0.24266904291519736, -0.2253265806990873, -0.2120593544183678, -0.20367911969311972, -0.200807072855696, -0.20367911969312558, -0.21205935441837906, -0.22532658069910316, -0.24266904291521701, -0.263267748043686, -0.286403411318823, -0.31149154414167574, -0.33807632234901147, -0.3658087761748607, -0.3944229712719748, -0.42371548629468425, -0.45352935405701633, -0.48374204168935553, -0.5142566301998278, -0.5449953849335122, -0.5758950657877199, -0.6069034898780968, -0.6379769940400796, -0.6690785457505007, -0.7001763240399208, -0.7312426436231244, -0.7622531317725019, -0.7931860929456493, -0.8240220141303781, -0.854743176583789, -0.8853333487070518, -0.9157775413101298, -0.9460618112370048, -0.9761731027652766, -1.0060991187284085, -1.0358282151893123, -1.0653493149001056, -1.0946518358424069, -1.1237256319467908, -1.152560943704862, -1.1811483568606767, -1.2094787677349266, -1.2375433540212262, -1.2653335501181378, -1.2928410262375578, -1.3200576706705187, -1.3469755747034928, -1.3735870197681228, -1.3998844664796901, -1.4258605452782545, -1.4515080484340674, -1.4768199232178199, -1.5017892660682322, -1.5264093176158215, -1.5506734584434483, -1.5745752054823166, -1.5981082089571552, -1.621266249806886, -1.644043237517662, -1.666433208314023, -1.68843032366143, -1.7100288690397936, -1.7312232529530003, -1.7520080061440457, -1.7723777809893024, -1.7923273510488136, -1.8118516107524005, -1.8309455752038424, -1.8496043800875466, -1.8678232816639688, -1.8855976568416684, -1.9029230033152724, -1.9197949397598366, -1.9362092060731715, -1.9521616636586085, -1.967648295741528, -1.9826652077136553, -1.9972086274997853, -2.011274905942146, -2.0248605171981033, -2.0379620591473393, -2.050576253805043, -2.0626999477379693, -2.0743301124805607, -2.0854638449485674, -2.0960983678478784, -2.10623103007647, -2.115859307117601, -2.1249808014225384, -2.1335932427812807, -2.1416944886798754, -2.149282524643071, -2.1563554645611633, -2.162911550999993, -2.1689491554931912, -2.1744667788157974, -2.179463051238541, -2.183936732762084, -2.1878867133306494, -2.1913120130245014, -2.1942117822308203, -2.19658530179257, -2.198431983135023, -2.1997513683696615, -2.2005431303752188], [-2.170243555722376, -2.169982708708371, -2.1692002319235852, -2.1678963181272315, -2.166071288543137, -2.16372559279751, -2.1608598088319546, -2.157474642791864, -2.153570928890367, -2.1491496292480545, -2.1442118337087335, -2.1387587596315316, -2.1327917516596955, -2.1263122814664914, -2.1193219474786678, -2.1118224745779894, -2.103815713781426, -2.0953036419006295, -2.0862883611814156, -2.0767720989240397, -2.066757207085134, -2.056246161862277, -2.045241563262253, -2.0337461346541725, -2.021762722308767, -2.0092942949252586, -1.9963439431474064, -1.9829148790704607, -1.9690104357409517, -1.9546340666514481, -1.9397893452326442, -1.9244799643453931, -1.908709735775596, -1.892482589735179, -1.8758025743727562, -1.8586738552980044, -1.8411007151242254, -1.823087553034128, -1.8046388843744632, -1.7857593402858352, -1.766453667374818, -1.7467267274364098, -1.7265834972359113, -1.7060290683605073, -1.685068647152243, -1.6637075547356672, -1.6419512271553103, -1.6198052156403082, -1.59727518701603, -1.5743669242855154, -1.5510863274069966, -1.5274394142978427, -1.503432322100076, -1.479071308748286, -1.4543627548874851, -1.4293131661964886, -1.40392917618195, -1.3782175495196585, -1.3521851860334966, -1.3258391254190958, -1.299186552839411, -1.2722348055439763, -1.2449913806936024, -1.217463944609103, -1.1896603437080266, -1.1615886174496248, -1.133257013678326, -1.104674006843651, -1.075848319684842, -1.0467889491081388, -1.0175051971624631, -0.9880067082471549, -0.9583035139793088, -0.9284060875299647, -0.8983254097377241, -0.8680730499664965, -0.8376612655484796, -0.8071031248248994, -0.7764126603802171, -0.7456050612248093, -0.7146969156545505, -0.683706520651319, -0.652654279500347, -0.6215632175558994, -0.5904596579423854, -0.5593741161922218, -0.5283424980888615, -0.49740772245182296, -0.46662194665944295, -0.4360496571170005, -0.40577201421349784, -0.37589303212871383, -0.3465484533545605, -0.3179185645063372, -0.29024666256412046, -0.2638652042127198, -0.23923109850635393, -0.2169680445793053, -0.19790278742323775, -0.18305822363980156, -0.17353674920942846, -0.17024355572237582, -0.17353674920943515, -0.1830582236398143, -0.19790278742325537, -0.21696804457932672, -0.23923109850637822, -0.2638652042127461, -0.2902466625641483, -0.31791856450636624, -0.34654845335459034, -0.37589303212874425, -0.4057720142135289, -0.4360496571170317, -0.4666219466594744, -0.49740772245185483, -0.5283424980888932, -0.5593741161922536, -0.5904596579424174, -0.6215632175559314, -0.652654279500379, -0.6837065206513507, -0.7146969156545823, -0.745605061224841, -0.7764126603802486, -0.8071031248249309, -0.8376612655485111, -0.8680730499665278, -0.8983254097377549, -0.9284060875299958, -0.9583035139793393, -0.9880067082471852, -1.0175051971624933, -1.0467889491081688, -1.0758483196848716, -1.1046740068436804, -1.1332570136783553, -1.161588617449654, -1.1896603437080553, -1.217463944609131, -1.2449913806936304, -1.2722348055440043, -1.2991865528394388, -1.3258391254191229, -1.3521851860335234, -1.3782175495196851, -1.403929176181976, -1.4293131661965146, -1.4543627548875107, -1.4790713087483114, -1.503432322100101, -1.527439414297867, -1.5510863274070208, -1.5743669242855391, -1.597275187016053, -1.619805215640331, -1.641951227155333, -1.6637075547356894, -1.6850686471522645, -1.7060290683605286, -1.7265834972359317, -1.7467267274364306, -1.7664536673748379, -1.7857593402858547, -1.8046388843744823, -1.8230875530341466, -1.8411007151242436, -1.858673855298022, -1.8758025743727735, -1.8924825897351956, -1.9087097357756124, -1.924479964345409, -1.9397893452326593, -1.9546340666514632, -1.9690104357409663, -1.982914879070475, -1.9963439431474204, -2.0092942949252715, -2.0217627223087797, -2.0337461346541845, -2.0452415632622643, -2.0562461618622883, -2.0667572070851445, -2.0767720989240495, -2.086288361181425, -2.0953036419006383, -2.103815713781435, -2.1118224745779974, -2.119321947478675, -2.1263122814664985, -2.1327917516597017, -2.138758759631537, -2.144211833708739, -2.1491496292480594, -2.1535709288903715, -2.1574746427918674, -2.1608598088319577, -2.1637255927975128, -2.1660712885431392, -2.1678963181272337, -2.1692002319235866, -2.169982708708372], [-2.1395153389439, -2.13925769323853, -2.138484819235409, -2.1371969062603497, -2.135394269812521, -2.1330773514987214, -2.1302467189414616, -2.1269030656609584, -2.1230472109311704, -2.1186800996100383, -2.1138028019441215, -2.108416513347866, -2.102522554157757, -2.096122369361656, -2.089217528303673, -2.08180972436493, -2.073900774620667, -2.065492619474132, -2.056587322267803, -2.047187068872497, -2.037294167255016, -2.0269110470250244, -2.0160402589619344, -2.0046844745226453, -1.9928464853310748, -1.980529202650517, -1.9677356568399529, -1.9544689967955746, -1.9407324893788973, -1.9265295188329872, -1.9118635861884834, -1.8967383086612906, -1.8811574190439952, -1.8651247650933154, -1.8486443089161169, -1.83172012635686, -1.8143564063896247, -1.796557450518275, -1.7783276721887231, -1.7596715962177492, -1.7405938582433897, -1.7210992042025328, -1.7011924898421007, -1.6808786802710372, -1.6601628495612857, -1.6390501804070743, -1.617545963853123, -1.5956555991039172, -1.5733845934279418, -1.5507385621728766, -1.5277232289101432, -1.504344425730089, -1.480608093712453, -1.4565202836007523, -1.432087156713985, -1.4073149861346947, -1.3822101582192066, -1.3567791744839608, -1.3310286539316587, -1.3049653358927438, -1.2785960834721166, -1.2519278877084805, -1.2249678725751572, -1.1977233009775947, -1.1702015819353964, -1.1424102791772122, -1.1143571214274344, -1.0860500147271683, -1.0574970572121878, -1.0287065568725442, -0.9996870529488414, -0.9704473417879738, -0.9409965081986077, -0.9113439636306487, -0.8814994928766182, -0.851473311488666, -0.8212761367684706, -0.7909192760834819, -0.7604147374852119, -0.7297753692894374, -0.6990150376241978, -0.6681488542574414, -0.6371934717321541, -0.6061674696519027, -0.5750918659438099, -0.5439908017647396, -0.5128924711052603, -0.4818304004580236, -0.45084523734705645, -0.4199872910396109, -0.38932020448324617, -0.358926357168198, -0.32891495997180104, -0.2994343927043629, -0.27069127185572567, -0.24298010580290869, -0.21672892723412993, -0.19256616480760083, -0.17140536528373174, -0.15450920126827933, -0.1434117753067263, -0.13951533894389997, -0.1434117753067342, -0.15450920126829398, -0.17140536528375155, -0.19256616480762437, -0.216728927234156, -0.2429801058029365, -0.27069127185575476, -0.29943439270439287, -0.3289149599718316, -0.358926357168229, -0.38932020448327764, -0.4199872910396425, -0.4508452373470882, -0.4818304004580555, -0.5128924711052921, -0.5439908017647715, -0.5750918659438419, -0.6061674696519346, -0.6371934717321861, -0.6681488542574733, -0.6990150376242293, -0.729775369289469, -0.7604147374852434, -0.7909192760835131, -0.8212761367685016, -0.851473311488697, -0.881499492876649, -0.9113439636306794, -0.940996508198638, -0.9704473417880038, -0.9996870529488714, -1.0287065568725742, -1.057497057212217, -1.0860500147271974, -1.1143571214274632, -1.1424102791772408, -1.1702015819354248, -1.197723300977623, -1.2249678725751851, -1.2519278877085083, -1.2785960834721437, -1.3049653358927706, -1.3310286539316853, -1.356779174483987, -1.3822101582192325, -1.4073149861347205, -1.4320871567140103, -1.4565202836007771, -1.4806080937124777, -1.5043444257301133, -1.527723228910167, -1.5507385621729004, -1.5733845934279649, -1.5956555991039396, -1.6175459638531453, -1.639050180407096, -1.660162849561307, -1.6808786802710582, -1.7011924898421213, -1.721099204202553, -1.7405938582434095, -1.7596715962177687, -1.7783276721887418, -1.7965574505182937, -1.814356406389643, -1.8317201263568776, -1.8486443089161344, -1.865124765093332, -1.8811574190440117, -1.8967383086613063, -1.9118635861884985, -1.9265295188330018, -1.940732489378912, -1.9544689967955882, -1.9677356568399662, -1.9805292026505301, -1.9928464853310872, -2.004684474522657, -2.016040258961946, -2.026911047025035, -2.0372941672550264, -2.047187068872507, -2.0565873222678124, -2.0654926194741408, -2.073900774620675, -2.081809724364938, -2.0892175283036796, -2.0961223693616633, -2.1025225541577632, -2.1084165133478723, -2.113802801944127, -2.1186800996100428, -2.123047210931175, -2.1269030656609624, -2.130246718941465, -2.133077351498724, -2.1353942698125232, -2.1371969062603506, -2.13848481923541, -2.1392576932385303], [-2.1086521500854514, -2.108397813674154, -2.1076348664477087, -2.1063634944147585, -2.104584007544061, -2.1022968396960513, -2.099502548527108, -2.0962018153665825, -2.092395445066694, -2.0880843658254036, -2.0832696289824026, -2.0779524087883794, -2.072134002147746, -2.065815828335041, -2.058999428685242, -2.0516864662582512, -2.0438787254778576, -2.035578111745495, -2.026786651029163, -2.0175064894279067, -2.007739892712297, -1.997489245841384, -1.9867570524566691, -1.9755459343536523, -1.9638586309316068, -1.9516979986222724, -1.9390670102982268, -1.9259687546617827, -1.9124064356153225, -1.8983833716140894, -1.883902995002554, -1.8689688513355796, -1.8535845986857509, -1.8377540069383684, -1.821480957075778, -1.8047694404528736, -1.7876235580658515, -1.7700475198164898, -1.7520456437745213, -1.7336223554409769, -1.7147821870156965, -1.6955297766726476, -1.6758698678471091, -1.6558073085393403, -1.6353470506399537, -1.614494149282907, -1.593253762232884, -1.571631149314754, -1.5496316718939407, -1.5272607924178327, -1.5045240740298973, -1.4814271802699694, -1.4579758748763316, -1.4341760217077058, -1.4100335848063117, -1.3855546286267149, -1.3607453184594887, -1.3356119210838744, -1.3101608056898426, -1.2843984451175061, -1.258331417470992, -1.2319664081750843, -1.205310212556682, -1.1783697390500474, -1.1511520131458088, -1.1236641822297886, -1.0959135214904405, -1.0679074411148495, -1.0396534950454057, -1.0111593916357313, -0.982433006629726, -0.9534823989977822, -0.9243158303076293, -0.8949417884953512, -0.8653690171508925, -0.8356065517642006, -0.8056637648249919, -0.7755504222767199, -0.7452767546602534, -0.7148535474430082, -0.6842922566609866, -0.6536051583255622, -0.6228055434037586, -0.5919079751009939, -0.5609286325022239, -0.5298857757264104, -0.4988003848744527, -0.4676970520027044, -0.4366052486841881, -0.40556116298449996, -0.3746104197546398, -0.3438122056264122, -0.3132456878772634, -0.2830202841535057, -0.2532925759512606, -0.2242949587181136, -0.19638527842528866, -0.17013328589069254, -0.14646504420861173, -0.1268639015328373, -0.1134805669365201, -0.10865215008545126, -0.11348056693652982, -0.12686390153285465, -0.1464650442086343, -0.1701332858907184, -0.19638527842531667, -0.2242949587181429, -0.2532925759512908, -0.2830202841535365, -0.3132456878772947, -0.3438122056264437, -0.37461041975467163, -0.4055611629845318, -0.43660524868422007, -0.46769705200273637, -0.4988003848744847, -0.5298857757264422, -0.5609286325022559, -0.5919079751010258, -0.6228055434037904, -0.6536051583255938, -0.6842922566610181, -0.7148535474430396, -0.7452767546602846, -0.7755504222767509, -0.8056637648250227, -0.8356065517642313, -0.8653690171509231, -0.8949417884953815, -0.9243158303076594, -0.9534823989978121, -0.9824330066297555, -1.0111593916357609, -1.039653495045435, -1.0679074411148783, -1.0959135214904692, -1.123664182229817, -1.1511520131458368, -1.1783697390500751, -1.2053102125567094, -1.2319664081751118, -1.258331417471019, -1.284398445117533, -1.310160805689869, -1.3356119210839006, -1.3607453184595144, -1.38555462862674, -1.4100335848063366, -1.4341760217077306, -1.457975874876356, -1.4814271802699934, -1.5045240740299208, -1.527260792417856, -1.5496316718939636, -1.5716311493147763, -1.5932537622329062, -1.6144941492829286, -1.635347050639975, -1.6558073085393612, -1.675869867847129, -1.6955297766726674, -1.7147821870157158, -1.7336223554409957, -1.7520456437745402, -1.7700475198165082, -1.7876235580658695, -1.8047694404528907, -1.8214809570757944, -1.837754006938385, -1.8535845986857669, -1.8689688513355953, -1.883902995002569, -1.8983833716141036, -1.9124064356153367, -1.925968754661797, -1.9390670102982406, -1.9516979986222855, -1.9638586309316188, -1.975545934353664, -1.9867570524566807, -1.9974892458413949, -2.0077398927123067, -2.017506489427917, -2.0267866510291723, -2.035578111745504, -2.0438787254778656, -2.051686466258259, -2.0589994286852495, -2.065815828335048, -2.072134002147752, -2.077952408788385, -2.083269628982408, -2.0880843658254085, -2.092395445066698, -2.096201815366586, -2.0995025485271115, -2.102296839696054, -2.1045840075440627, -2.1063634944147602, -2.10763486644771, -2.108397813674155], [-2.077683847288983, -2.077432930268605, -2.0766802401522964, -2.0754259597604587, -2.0736703937468923, -2.0714139685285065, -2.0686572321869687, -2.065400854342343, -2.0616456259987648, -2.057392459362253, -2.0526423876307356, -2.047396564756409, -2.041656265180546, -2.0354228835409045, -2.0286979343518876, -2.021483051657636, -2.013779988658248, -2.0055906173093447, -1.9969169278952075, -1.9877610285757663, -1.9781251449077013, -1.9680116193399813, -1.9574229106841696, -1.9463615935598653, -1.934830357815679, -1.922832007926178, -1.9103694623652707, -1.8974457529565523, -1.8840640242011641, -1.8702275325837854, -1.855939645857429, -1.841203842307768, -1.8260237099977967, -1.8104029459937203, -1.7943453555730204, -1.777854851415791, -1.760935452780507, -1.7435912846655464, -1.725826576957908, -1.7076456635707502, -1.6890529815715434, -1.6700530703028593, -1.6506505704980547, -1.6308502233943878, -1.6106568698464452, -1.5900754494431104, -1.569110999631764, -1.547768654853895, -1.5260536456969063, -1.50397129806759, -1.4815270323935512, -1.458726362859837, -1.435574896689135, -1.4120783334752762, -1.3882424645813483, -1.3640731726156547, -1.3395764310010172, -1.314758303655689, -1.2896249448074462, -1.2641825989664548, -1.2384376010874047, -1.2123963769573933, -1.186065443853393, -1.1594514115222267, -1.1325609835472368, -1.1054009591799012, -1.0779782357322767, -1.050299811648401, -1.0223727904010336, -0.9942043853961917, -0.9658019261143826, -0.937172865777568, -0.9083247909094553, -0.8792654332600911, -0.8500026847029849, -0.8205446158968858, -0.7908994997531138, -0.7610758410894376, -0.7310824143215636, -0.7009283117008893, -0.6706230055388579, -0.6401764291966963, -0.6095990835709638, -0.5789021786975019, -0.5480978244582538, -0.5171992910810442, -0.48622137064929893, -0.4551808877485268, -0.4240974352353271, -0.3929944583122999, -0.361900892564264, -0.3308537107495535, -0.2999020132885049, -0.269113846197701, -0.23858805564629446, -0.2084759102047767, -0.17902268124499734, -0.15065207437261527, -0.12414521725601123, -0.10101549176322236, -0.08412710413868502, -0.07768384728898271, -0.08412710413869776, -0.10101549176324356, -0.12414521725603711, -0.15065207437264366, -0.1790226812450272, -0.20847591020480738, -0.23858805564632565, -0.26911384619773254, -0.29990201328853666, -0.3308537107495853, -0.361900892564296, -0.3929944583123319, -0.424097435235359, -0.45518088774855864, -0.48622137064933074, -0.5171992910810761, -0.5480978244582856, -0.5789021786975336, -0.6095990835709953, -0.6401764291967276, -0.6706230055388891, -0.7009283117009204, -0.7310824143215946, -0.7610758410894684, -0.7908994997531442, -0.8205446158969161, -0.8500026847030151, -0.879265433260121, -0.9083247909094849, -0.9371728657775974, -0.9658019261144121, -0.9942043853962208, -1.0223727904010622, -1.05029981164843, -1.077978235732305, -1.1054009591799292, -1.1325609835472645, -1.1594514115222543, -1.1860654438534204, -1.2123963769574204, -1.2384376010874314, -1.2641825989664812, -1.2896249448074724, -1.3147583036557147, -1.3395764310010425, -1.36407317261568, -1.3882424645813731, -1.4120783334753004, -1.4355748966891593, -1.4587263628598606, -1.4815270323935747, -1.5039712980676125, -1.526053645696929, -1.5477686548539171, -1.5691109996317858, -1.5900754494431317, -1.610656869846466, -1.6308502233944082, -1.6506505704980747, -1.6700530703028793, -1.6890529815715627, -1.707645663570769, -1.7258265769579266, -1.7435912846655646, -1.7609354527805248, -1.7778548514158081, -1.794345355573037, -1.8104029459937365, -1.8260237099978132, -1.841203842307783, -1.8559396458574442, -1.8702275325837998, -1.8840640242011781, -1.897445752956566, -1.9103694623652843, -1.9228320079261907, -1.934830357815691, -1.9463615935598768, -1.9574229106841807, -1.968011619339992, -1.9781251449077115, -1.9877610285757759, -1.996916927895217, -2.005590617309353, -2.0137799886582566, -2.021483051657644, -2.0286979343518947, -2.035422883540911, -2.041656265180552, -2.047396564756415, -2.052642387630741, -2.0573924593622577, -2.0616456259987688, -2.0654008543423465, -2.068657232186972, -2.0714139685285087, -2.073670393746894, -2.0754259597604605, -2.0766802401522977, -2.077432930268606], [-2.046640390387394, -2.0463930049195245, -2.0456509084451677, -2.0444142807378283, -2.042683421372528, -2.0404587496545936, -2.0377408045199967, -2.0345302444072697, -2.0308278471010524, -2.026634509547313, -2.0219512476403136, -2.0167791959813886, -2.01111960760962, -2.0049738537045023, -1.9983434232607078, -1.9912299227350538, -1.9836350756658152, -1.9755607222645064, -1.9670088189802934, -1.9579814380371863, -1.9484807669442064, -1.938509107978695, -1.9280688776429904, -1.9171626060946738, -1.9057929365506276, -1.8939626246651637, -1.8816745378824788, -1.8689316547637391, -1.8557370642891, -1.842093965134999, -1.8280056649270755, -1.8134755794691115, -1.7985072319484035, -1.7831042521180203, -1.7672703754564274, -1.7510094423050115, -1.7343253969840706, -1.7172222868878948, -1.6997042615596165, -1.6817755717465759, -1.6634405684370117, -1.6447037018789827, -1.6255695205825091, -1.606042670306032, -1.5861278930284215, -1.5658300259078952, -1.54515400022938, -1.524104840342042, -1.5026876625889296, -1.4809076742309342, -1.458770172367585, -1.436280542857545, -1.4134442592420986, -1.3902668816754349, -1.3667540558661153, -1.3429115120348263, -1.3187450638943825, -1.2942606076589596, -1.2694641210907813, -1.2443616625939868, -1.2189593703672366, -1.1932634616288522, -1.1672802319310467, -1.1410160545831944, -1.1144773802083334, -1.0876707364623577, -1.0606027279519956, -1.0332800363960497, -1.0057094210850166, -0.977897719707851, -0.949851849632191, -0.9215788097471891, -0.8930856830079315, -0.8643796398598242, -0.8354679427737486, -0.8063579521932471, -0.7770571342906336, -0.7475730710601234, -0.7179134734581942, -0.6880861985572949, -0.6580992720434933, -0.6279609179153195, -0.5976795980141573, -0.5672640651709626, -0.5367234355105766, -0.5060672881829178, -0.475305805124542, -0.44444997051548324, -0.41351186142824875, -0.38250508162463576, -0.3514454271109602, -0.3203519404441344, -0.2892486444090381, -0.25816752123272335, -0.22715390855681877, -0.19627691452318813, -0.1656511531458827, -0.1354867286134469, -0.10621893567428393, -0.0788959717476695, -0.0564613407296469, -0.04664039038739381, -0.056461340729665334, -0.07889597174769589, -0.1062189356743133, -0.13548672861347758, -0.16565115314591403, -0.19627691452321977, -0.2271539085568506, -0.25816752123275527, -0.2892486444090701, -0.3203519404441663, -0.35144542711099214, -0.3825050816246676, -0.4135118614282805, -0.4444499705155149, -0.47530580512457365, -0.5060672881829494, -0.536723435510608, -0.567264065170994, -0.5976795980141886, -0.6279609179153505, -0.6580992720435241, -0.6880861985573257, -0.7179134734582248, -0.7475730710601537, -0.7770571342906638, -0.8063579521932772, -0.8354679427737782, -0.8643796398598538, -0.8930856830079607, -0.9215788097472182, -0.9498518496322201, -0.9778977197078798, -1.005709421085045, -1.033280036396078, -1.0606027279520236, -1.0876707364623854, -1.114477380208361, -1.1410160545832215, -1.1672802319310736, -1.1932634616288789, -1.2189593703672628, -1.2443616625940128, -1.2694641210908069, -1.2942606076589849, -1.3187450638944076, -1.3429115120348512, -1.36675405586614, -1.390266881675459, -1.413444259242122, -1.4362805428575682, -1.4587701723676079, -1.4809076742309566, -1.5026876625889516, -1.524104840342064, -1.5451540002294015, -1.5658300259079163, -1.5861278930284424, -1.6060426703060522, -1.6255695205825287, -1.6447037018790023, -1.6634405684370306, -1.6817755717465945, -1.6997042615596345, -1.7172222868879126, -1.734325396984088, -1.7510094423050284, -1.7672703754564436, -1.783104252118036, -1.7985072319484192, -1.8134755794691266, -1.8280056649270902, -1.842093965135013, -1.8557370642891138, -1.868931654763752, -1.881674537882492, -1.8939626246651764, -1.9057929365506396, -1.9171626060946851, -1.9280688776430017, -1.9385091079787056, -1.9484807669442163, -1.957981438037196, -1.967008818980302, -1.9755607222645148, -1.983635075665823, -1.9912299227350612, -1.9983434232607147, -2.0049738537045094, -2.0111196076096256, -2.016779195981394, -2.021951247640318, -2.0266345095473173, -2.030827847101057, -2.0345302444072733, -2.03774080452, -2.0404587496545963, -2.042683421372529, -2.0444142807378296, -2.045650908445169, -2.0463930049195254], [-2.015551811920327, -2.015308072168038, -2.014576911875888, -2.0133585079237917, -2.011653155064166, -2.0094612658507756, -2.006783370539147, -2.003620116958571, -1.9999722703557254, -1.9958407132099627, -1.9912264450203017, -1.9861305820641844, -1.9805543571280546, -1.9744991192098302, -1.9679663331933404, -1.9609575794948124, -1.9534745536815032, -1.9455190660625628, -1.9370930412522451, -1.9281985177055725, -1.9188376472265702, -1.90901269444921, -1.898726036291181, -1.8879801613806457, -1.8767776694561167, -1.8651212707396247, -1.8530137852833333, -1.840458142289774, -1.8274573794058917, -1.8140146419910828, -1.80013318235942, -1.7858163589962819, -1.7710676357495947, -1.7558905809959124, -1.7402888667815686, -1.7242662679391503, -1.7078266611795387, -1.6909740241597948, -1.6737124345271537, -1.656046068939431, -1.6379792020621349, -1.6195162055426096, -1.600661546961536, -1.5814197887621475, -1.5617955871575286, -1.5417936910163845, -1.5214189407277023, -1.500676267044738, -1.4795706899088086, -1.4581073172533872, -1.4362913437890503, -1.4141280497698678, -1.3916227997418753, -1.3687810412743369, -1.3456083036745705, -1.322110196687206, -1.2982924091788255, -1.2741607078090882, -1.2497209356895531, -1.2249790110316137, -1.1999409257851636, -1.1746127442698635, -1.1490006018012116, -1.123110703314004, -1.0969493219862612, -1.0705227978673026, -1.0438375365144161, -1.0169000076435313, -0.9897167438005322, -0.9622943390614079, -0.9346394477714682, -0.9067587833364728, -0.8786591170819642, -0.8503472772016405, -0.8218301478216588, -0.7931146682159068, -0.7642078322183711, -0.7351166878939451, -0.7058483375502198, -0.6764099382026242, -0.6468087026479046, -0.6170519013626804, -0.5871468655347942, -0.5571009916715537, -0.5269217484374283, -0.4966166866992647, -0.46619345427745984, -0.4356598177556238, -0.4050236951449999, -0.37429320572298064, -0.34347674794473804, -0.3125831250101649, -0.2816217549885953, -0.2506030390826793, -0.21953904506541447, -0.18844487023225975, -0.15734162333824003, -0.12626380760020356, -0.09528107871029981, -0.06458197524021321, -0.03499056506635985, -0.015551811920326975, -0.0349905650663887, -0.06458197524024448, -0.09528107871033158, -0.1262638076002355, -0.15734162333827206, -0.18844487023229173, -0.21953904506544644, -0.2506030390827112, -0.2816217549886272, -0.31258312501019664, -0.3434767479447698, -0.3742932057230123, -0.4050236951450314, -0.4356598177556552, -0.46619345427749115, -0.496616686699296, -0.5269217484374595, -0.5571009916715846, -0.5871468655348251, -0.617051901362711, -0.646808702647935, -0.6764099382026545, -0.7058483375502499, -0.7351166878939752, -0.7642078322184009, -0.7931146682159365, -0.8218301478216881, -0.8503472772016698, -0.8786591170819931, -0.9067587833365015, -0.9346394477714969, -0.9622943390614362, -0.9897167438005603, -1.0169000076435593, -1.0438375365144437, -1.07052279786733, -1.0969493219862883, -1.1231107033140306, -1.149000601801238, -1.1746127442698895, -1.1999409257851896, -1.2249790110316394, -1.2497209356895784, -1.2741607078091133, -1.2982924091788504, -1.3221101966872302, -1.3456083036745947, -1.3687810412743604, -1.3916227997418986, -1.4141280497698907, -1.436291343789073, -1.4581073172534094, -1.4795706899088306, -1.5006762670447595, -1.5214189407277234, -1.5417936910164052, -1.561795587157549, -1.5814197887621673, -1.600661546961555, -1.6195162055426287, -1.6379792020621535, -1.6560460689394492, -1.6737124345271717, -1.6909740241598124, -1.7078266611795558, -1.7242662679391667, -1.7402888667815848, -1.755890580995928, -1.7710676357496105, -1.7858163589962968, -1.8001331823594342, -1.8140146419910967, -1.8274573794059055, -1.8404581422897868, -1.8530137852833461, -1.8651212707396374, -1.8767776694561285, -1.8879801613806566, -1.8987260362911917, -1.9090126944492203, -1.9188376472265805, -1.928198517705582, -1.937093041252254, -1.945519066062571, -1.9534745536815108, -1.9609575794948202, -1.9679663331933472, -1.9744991192098367, -1.9805543571280604, -1.9861305820641895, -1.9912264450203068, -1.9958407132099674, -1.9999722703557297, -2.0036201169585746, -2.00678337053915, -2.009461265850778, -2.011653155064168, -2.013358507923793, -2.014576911875889, -2.0153080721680383], [-1.984448188079625, -1.984208210125671, -1.9834883343188103, -1.9822887348100366, -1.980609701804299, -1.9784516414904478, -1.9758150759431954, -1.9727006429971, -1.9691090960926088, -1.9650413040942085, -1.960498251080718, -1.9554810361077821, -1.949990872942625, -1.9440290897711314, -1.9375971288773306, -1.9306965462953618, -1.9233290114340176, -1.915496306673948, -1.9072003269376467, -1.8984430792323095, -1.889226682165703, -1.8795533654351537, -1.8694254692897954, -1.8588454439662199, -1.8478158490976702, -1.8363393530969352, -1.824418732513114, -1.8120568713624106, -1.7992567604331464, -1.7860214965651744, -1.7723542819038907, -1.7582584231290463, -1.7437373306585762, -1.7287945178276645, -1.7134336000432764, -1.6976582939144014, -1.6814724163582602, -1.6648798836827359, -1.6478847106453056, -1.6304910094887612, -1.612702988954018, -1.5945249532703274, -1.575961301123226, -1.5570165246005678, -1.5376952081170097, -1.518002027317335, -1.4979417479590322, -1.4775192247745692, -1.4567394003138223, -1.4356073037671828, -1.414128049769868, -1.392306837188036, -1.370148947887346, -1.3476597454846706, -1.324844674083735, -1.3017092569955553, -1.2782590954446378, -1.254499867262037, -1.2304373255665044, -1.2060772974351486, -1.18142568256524, -1.1564884519290537, -1.1312716464239716, -1.1057813755204604, -1.08002381591104, -1.0540052101639719, -1.0277318653861662, -1.0012101519008, -0.9744465019463607, -0.9474474084054428, -0.920219423573665, -0.8927691579817442, -0.8651032792872667, -0.8372285112572957, -0.809151632869119, -0.7808794775647089, -0.752418932705724, -0.7237769392913461, -0.6949604920227617, -0.6659766398283963, -0.6368324870072837, -0.6075351952106676, -0.5780919865743191, -0.548510148452543, -0.5187970404165403, -0.48896010451032074, -0.4590068802857543, -0.42894502700558984, -0.3987823568691663, -0.36852688567723396, -0.33818691200183604, -0.3077711447422415, -0.2772889165297407, -0.24675055767283513, -0.2161680900256433, -0.1855566105049646, -0.154937317358543, -0.12434500048331784, -0.09385010320576674, -0.06364352007630433, -0.03455790642377664, -0.01555181192037493, -0.03455790642380496, -0.06364352007633506, -0.09385010320579798, -0.12434500048334926, -0.15493731735857447, -0.18555661050499606, -0.21616809002567472, -0.2467505576728665, -0.277288916529772, -0.3077711447422728, -0.33818691200186723, -0.36852688567726516, -0.39878235686919733, -0.4289450270056207, -0.4590068802857852, -0.48896010451035143, -0.5187970404165709, -0.5485101484525734, -0.5780919865743497, -0.6075351952106978, -0.6368324870073137, -0.6659766398284263, -0.6949604920227914, -0.7237769392913757, -0.7524189327057532, -0.7808794775647382, -0.8091516328691479, -0.8372285112573244, -0.8651032792872951, -0.8927691579817724, -0.920219423573693, -0.9474474084054709, -0.9744465019463883, -1.0012101519008274, -1.0277318653861933, -1.0540052101639987, -1.0800238159110667, -1.1057813755204866, -1.1312716464239976, -1.15648845192908, -1.1814256825652656, -1.2060772974351737, -1.230437325566529, -1.2544998672620618, -1.278259095444662, -1.301709256995579, -1.324844674083759, -1.347659745484694, -1.370148947887369, -1.3923068371880583, -1.41412804976989, -1.4356073037672048, -1.4567394003138436, -1.4775192247745905, -1.4979417479590533, -1.5180020273173553, -1.5376952081170299, -1.5570165246005876, -1.575961301123245, -1.5945249532703465, -1.6127029889540365, -1.6304910094887797, -1.6478847106453232, -1.6648798836827534, -1.6814724163582773, -1.6976582939144178, -1.7134336000432926, -1.7287945178276802, -1.7437373306585915, -1.7582584231290608, -1.7723542819039049, -1.7860214965651884, -1.79925676043316, -1.8120568713624234, -1.8244187325131265, -1.8363393530969472, -1.8478158490976817, -1.858845443966231, -1.8694254692898058, -1.8795533654351637, -1.8892266821657127, -1.8984430792323184, -1.9072003269376554, -1.9154963066739565, -1.9233290114340251, -1.9306965462953691, -1.937597128877337, -1.944029089771138, -1.9499908729426307, -1.9554810361077875, -1.960498251080723, -1.9650413040942127, -1.9691090960926123, -1.9727006429971035, -1.975815075943199, -1.97845164149045, -1.9806097018043007, -1.9822887348100382, -1.9834883343188114, -1.9842082101256717], [-1.9533596096125583, -1.9531235113569188, -1.9524152737936227, -1.95123506851996, -1.9495831814861666, -1.9474600129275648, -1.9448660772696003, -1.9418020030057939, -1.938268532548666, -1.934266522053673, -1.9297969412162235, -1.9248608730418448, -1.9194595135895838, -1.9135941716887246, -1.90726626862894, -1.9004773378239779, -1.8932290244490095, -1.8855230850517828, -1.8773613871377188, -1.868745908729119, -1.859678737898651, -1.850162072277307, -1.8401982185370303, -1.8297895918482296, -1.8189387153124155, -1.8076482193702061, -1.7959208411849763, -1.783759424002434, -1.771166916486437, -1.7581463720313872, -1.7447009480515558, -1.7308339052477322, -1.7165486068516136, -1.701848517848388, -1.6867372041779973, -1.6712183319156189, -1.6552956664319376, -1.638973071533846, -1.6222545085862523, -1.6051440356157665, -1.5876458063970857, -1.569764069523, -1.5515031674590385, -1.5328675355838763, -1.51386170121677, -1.4944902826334185, -1.474757988071833, -1.4546696147299916, -1.434230047757295, -1.413444259242099, -1.3923173071979322, -1.3708543345513726, -1.3490605681350047, -1.3269413176894056, -1.3045019748787223, -1.2817480123251639, -1.2586849826686077, -1.2353185176586061, -1.2116543272873677, -1.1876981989738642, -1.1634559968111293, -1.1389336608911587, -1.1141372067247017, -1.0890727247768022, -1.06374638014336, -1.0381644123995188, -1.0123331356576097, -0.9862589388811568, -0.9599482865125795, -0.9334077194864937, -0.9066438567188763, -0.8796633971862173, -0.8524731227399873, -0.8250799018429193, -0.7974906944684063, -0.7697125584779316, -0.7417526578913759, -0.7136182736020836, -0.6853168172787591, -0.656855849463442, -0.628243103255214, -0.5994865155188078, -0.5705942683635906, -0.5415748448419135, -0.512437104646035, -0.4831903884237107, -0.453844663842918, -0.4244107338786864, -0.39490054008591996, -0.36532761484953047, -0.3357077745805047, -0.3060602165485044, -0.27640931992897283, -0.2467877351345704, -0.21724196556811634, -0.18784310465697424, -0.15870913183992696, -0.13005579167224057, -0.10232691659149741, -0.07657472911209624, -0.055656444964064175, -0.04664039038744172, -0.0556564449640812, -0.07657472911212099, -0.10232691659152518, -0.13005579167226966, -0.15870913183995675, -0.18784310465700435, -0.21724196556814662, -0.24678773513460078, -0.27640931992900325, -0.30606021654853494, -0.33570777458053525, -0.3653276148495609, -0.3949005400859503, -0.4244107338787167, -0.4538446638429482, -0.4831903884237409, -0.5124371046460651, -0.5415748448419434, -0.5705942683636206, -0.5994865155188375, -0.6282431032552434, -0.6568558494634712, -0.6853168172787882, -0.7136182736021125, -0.7417526578914048, -0.7697125584779603, -0.7974906944684347, -0.8250799018429478, -0.8524731227400153, -0.8796633971862452, -0.9066438567189039, -0.9334077194865211, -0.9599482865126067, -0.9862589388811835, -1.0123331356576364, -1.0381644123995453, -1.0637463801433864, -1.089072724776828, -1.1141372067247275, -1.1389336608911844, -1.1634559968111546, -1.1876981989738888, -1.211654327287392, -1.2353185176586303, -1.2586849826686315, -1.2817480123251874, -1.3045019748787456, -1.3269413176894285, -1.3490605681350276, -1.3708543345513948, -1.3923173071979542, -1.4134442592421206, -1.434230047757316, -1.4546696147300122, -1.4747579880718533, -1.4944902826334385, -1.5138617012167899, -1.5328675355838954, -1.5515031674590571, -1.5697640695230188, -1.5876458063971037, -1.6051440356157842, -1.6222545085862696, -1.638973071533863, -1.6552956664319545, -1.6712183319156348, -1.686737204178013, -1.7018485178484033, -1.7165486068516291, -1.7308339052477468, -1.7447009480515698, -1.758146372031401, -1.7711669164864505, -1.7837594240024468, -1.795920841184989, -1.8076482193702181, -1.8189387153124268, -1.8297895918482405, -1.8401982185370407, -1.8501620722773169, -1.8596787378986603, -1.868745908729128, -1.8773613871377277, -1.885523085051791, -1.893229024449017, -1.900477337823985, -1.9072662686289468, -1.9135941716887308, -1.919459513589589, -1.9248608730418506, -1.9297969412162284, -1.9342665220536779, -1.9382685325486702, -1.9418020030057976, -1.944866077269603, -1.947460012927567, -1.9495831814861682, -1.951235068519961, -1.9524152737936238, -1.9531235113569194], [-1.9223161527109696, -1.9220840537454653, -1.921387813262703, -1.9202276004910215, -1.9186036974346135, -1.9165164988089893, -1.9139665119506812, -1.9109543567012277, -1.9074807652655057, -1.9035465820444988, -1.8991527634425747, -1.8943003776494018, -1.8889906043966227, -1.8832247346894186, -1.8770041705131433, -1.870330424515186, -1.8632051196622768, -1.855629988873438, -1.8476068746288365, -1.8391377285547874, -1.8302246109852065, -1.820869690499818, -1.8110752434394708, -1.8008436533989276, -1.790177410697543, -1.7790791118282738, -1.7675514588855066, -1.7555972589722355, -1.7432194235871683, -1.7304209679923959, -1.7172050105623207, -1.7035747721146026, -1.6895335752239637, -1.6750848435197665, -1.6602321009683862, -1.6449789711414942, -1.629329176471495, -1.6132865374954914, -1.5968549720893115, -1.580038494693299, -1.5628412155317772, -1.5452673398283208, -1.5273211670192315, -1.509007089967921, -1.4903295941832557, -1.4712932570453072, -1.4519027470424468, -1.4321628230242434, -1.412078333475277, -1.3916542158157217, -1.3708954957354242, -1.3498072865692436, -1.328394788722625, -1.3066632891578394, -1.2846181609530238, -1.2622648629482232, -1.2396089394950778, -1.2166560203297696, -1.1934118205923914, -1.1698821410202456, -1.1460728683478223, -1.121989975952663, -1.097639524794199, -1.0730276647024277, -1.0481606360853806, -1.023044772139432, -0.9976865016654148, -0.9720923526173847, -0.9462689565411426, -0.9202230540983172, -0.8939615019215221, -0.8674912811105163, -0.840819507763328, -0.8139534460468405, -0.7869005244580032, -0.7596683561231339, -0.7322647642481706, -0.7046978141950985, -0.6769758541601857, -0.6491075671287246, -0.6211020377701301, -0.5929688393559663, -0.5647181478485078, -0.5363608933613414, -0.5079089637884712, -0.4793754824429344, -0.4507751925693774, -0.4221249992352788, -0.39344474803596746, -0.36475836879282164, -0.3360955970262795, -0.30749463769560664, -0.2790064176498935, -0.25070161795497375, -0.2226827737112165, -0.19510602818587053, -0.16822211773740697, -0.14245709281519472, -0.11857543344057674, -0.0979951128816957, -0.08322896995955179, -0.07768384728903052, -0.08322896995956279, -0.09799511288171439, -0.11857543344059991, -0.1424570928152204, -0.16822211773743417, -0.1951060281858986, -0.22268277371124515, -0.2507016179550027, -0.2790064176499227, -0.307494637695636, -0.3360955970263089, -0.36475836879285106, -0.39344474803599694, -0.42212499923530816, -0.4507751925694069, -0.4793754824429638, -0.5079089637885005, -0.5363608933613706, -0.564718147848537, -0.5929688393559953, -0.6211020377701589, -0.6491075671287535, -0.6769758541602141, -0.7046978141951269, -0.7322647642481986, -0.7596683561231621, -0.7869005244580309, -0.8139534460468685, -0.8408195077633556, -0.8674912811105436, -0.8939615019215492, -0.920223054098344, -0.9462689565411693, -0.9720923526174111, -0.997686501665441, -1.0230447721394578, -1.0481606360854063, -1.073027664702453, -1.097639524794224, -1.1219899759526881, -1.1460728683478472, -1.1698821410202698, -1.1934118205924156, -1.2166560203297931, -1.2396089394951013, -1.2622648629482462, -1.2846181609530465, -1.3066632891578618, -1.3283947887226473, -1.3498072865692656, -1.3708954957354458, -1.3916542158157428, -1.4120783334752978, -1.4321628230242638, -1.4519027470424668, -1.4712932570453268, -1.490329594183275, -1.50900708996794, -1.5273211670192497, -1.5452673398283392, -1.562841215531795, -1.5800384946933164, -1.5968549720893286, -1.6132865374955083, -1.6293291764715112, -1.64497897114151, -1.6602321009684016, -1.6750848435197816, -1.6895335752239786, -1.703574772114617, -1.7172050105623342, -1.7304209679924092, -1.743219423587181, -1.755597258972248, -1.7675514588855186, -1.7790791118282854, -1.790177410697554, -1.800843653398938, -1.8110752434394812, -1.8208696904998276, -1.8302246109852158, -1.8391377285547963, -1.8476068746288448, -1.855629988873446, -1.8632051196622843, -1.870330424515193, -1.8770041705131495, -1.883224734689425, -1.8889906043966285, -1.8943003776494074, -1.899152763442579, -1.9035465820445032, -1.9074807652655097, -1.9109543567012308, -1.9139665119506846, -1.9165164988089918, -1.918603697434615, -1.9202276004910228, -1.921387813262704, -1.922084053745466], [-1.8913478499145011, -1.8911198713720405, -1.8904359914328037, -1.8892963771492082, -1.8877013069018866, -1.8856511703396326, -1.8831464682953998, -1.8801878126784242, -1.8767759263425723, -1.872911642931034, -1.8685959066974984, -1.8638297723039874, -1.8586144045955333, -1.8529510783519247, -1.8468411780167633, -1.8402861974041171, -1.8332877393830715, -1.8258475155405254, -1.8179673458226115, -1.8096491581551615, -1.8008949880436758, -1.7917069781533048, -1.782087377869408, -1.7720385428392917, -1.761562934495811, -1.7506631195635738, -1.739341769548556, -1.727601660212034, -1.7154456710298085, -1.7028767846378219, -1.6898980862653512, -1.6765127631571202, -1.6627241039857823, -1.6485354982564078, -1.6339504357047767, -1.6189725056914852, -1.6036053965940948, -1.587852895199831, -1.5717188861016076, -1.5552073511005162, -1.5383223686182876, -1.5210681131236876, -1.503448854577303, -1.4854689578997713, -1.4671328824691818, -1.4484451816541457, -1.4294105023899566, -1.4100335848063128, -1.3903192619162963, -1.3702724593777638, -1.3498981953399851, -1.32920158039036, -1.3081878176184008, -1.2868622028169545, -1.2652301248439504, -1.243297066171907, -1.2210686036571694, -1.1985504095665103, -1.17574825290559, -1.1526680011020418, -1.1293156221060279, -1.1056971869833991, -1.0818188730916547, -1.0576869679474656, -1.0333078739174961, -1.0086881138928316, -0.9838343381430724, -0.9587533325911066, -0.9334520288064518, -0.907937516087457, -0.8822170560954158, -0.85629810062331, -0.8301883132373874, -0.8038955957333481, -0.777428120617598, -0.7507943711816735, -0.7240031912183291, -0.6970638470792297, -0.6699861056666695, -0.6427803331877288, -0.6154576212308556, -0.5880299491807888, -0.560510395517074, -0.5329134156850264, -0.5052552118374279, -0.4775542311843767, -0.4498318471810216, -0.4221133050213538, -0.39442905614170526, -0.3668166764534946, -0.3393236787606555, -0.3120117250485197, -0.2849630798327658, -0.25829073037060424, -0.23215462121165034, -0.20678819608712037, -0.18254216743311008, -0.15995547822852046, -0.13986128265278458, -0.12350603786810706, -0.11255048287859502, -0.10865215008549892, -0.11255048287860289, -0.12350603786812141, -0.13986128265280354, -0.15995547822854256, -0.18254216743313428, -0.206788196087146, -0.2321546212116769, -0.25829073037063144, -0.2849630798327935, -0.31201172504854763, -0.33932367876068376, -0.3668166764535229, -0.3944290561417336, -0.4221133050213822, -0.4498318471810501, -0.47755423118440515, -0.5052552118374565, -0.5329134156850549, -0.5605103955171026, -0.588029949180817, -0.6154576212308837, -0.6427803331877567, -0.6699861056666975, -0.6970638470792575, -0.7240031912183567, -0.7507943711817009, -0.7774281206176252, -0.8038955957333753, -0.8301883132374144, -0.8562981006233367, -0.8822170560954423, -0.9079375160874833, -0.9334520288064779, -0.9587533325911325, -0.9838343381430981, -1.0086881138928572, -1.0333078739175212, -1.0576869679474905, -1.0818188730916793, -1.1056971869834238, -1.1293156221060523, -1.1526680011020654, -1.1757482529056136, -1.1985504095665336, -1.2210686036571923, -1.2432970661719296, -1.2652301248439726, -1.2868622028169765, -1.3081878176184225, -1.3292015803903816, -1.349898195340006, -1.3702724593777844, -1.3903192619163165, -1.410033584806333, -1.4294105023899764, -1.4484451816541648, -1.467132882469201, -1.48546895789979, -1.503448854577321, -1.5210681131237054, -1.5383223686183052, -1.555207351100533, -1.5717188861016245, -1.5878528951998476, -1.6036053965941108, -1.6189725056915005, -1.6339504357047918, -1.6485354982564224, -1.662724103985797, -1.6765127631571344, -1.6898980862653648, -1.702876784637835, -1.7154456710298214, -1.727601660212046, -1.7393417695485682, -1.7506631195635853, -1.761562934495822, -1.772038542839302, -1.782087377869418, -1.7917069781533144, -1.8008949880436849, -1.8096491581551704, -1.81796734582262, -1.8258475155405332, -1.833287739383079, -1.840286197404124, -1.8468411780167697, -1.8529510783519307, -1.858614404595539, -1.8638297723039925, -1.8685959066975033, -1.8729116429310382, -1.8767759263425763, -1.8801878126784275, -1.8831464682954027, -1.885651170339635, -1.8877013069018882, -1.8892963771492093, -1.8904359914328048, -1.8911198713720407], [-1.8604846610560526, -1.8602609254319147, -1.8595897735885636, -1.858471370602289, -1.8569059915639357, -1.8548940215244951, -1.8524359554190473, -1.8495323979691545, -1.84618406356385, -1.8423917761193969, -1.8381564689180272, -1.8334791844259024, -1.8283610740905827, -1.822803398118325, -1.8168075252315734, -1.8103749324070615, -1.8035072045949714, -1.7962060344196702, -1.7884732218625898, -1.7803106739278733, -1.7717204042914865, -1.7627045329345554, -1.753265285761785, -1.743404994205877, -1.73312609481899, -1.7224311288523664, -1.711322741825378, -1.6998036830853789, -1.6878768053598827, -1.675545064302762, -1.6628115180363299, -1.6496793266913872, -1.6361517519475248, -1.622232156576247, -1.607924003989758, -1.5932308577985914, -1.5781563813816202, -1.5627043374724316, -1.5468785877664986, -1.5306830925541595, -1.5141219103850214, -1.4971991977701378, -1.479919208929125, -1.462286295590336, -1.444304906853314, -1.4259795891240057, -1.4073149861346965, -1.3883158390623362, -1.3689869867609255, -1.34933336612596, -1.3293600126116767, -1.3090720609250488, -1.2884747459242876, -1.267573403754084, -1.2463734732551526, -1.2248804976919876, -1.2031001268502983, -1.1810381195646957, -1.1587003467480992, -1.1360927950075494, -1.1132215709470994, -1.0900929062779403, -1.0667131638797318, -1.0430888449863682, -1.0192265977054968, -0.9951332271258683, -0.9708157073223734, -0.9462811956384949, -0.9215370497139302, -0.8965908478366936, -0.8714504133411883, -0.8461238439561864, -0.8206195472422839, -0.7949462835648672, -0.7691132184502225, -0.7431299867026967, -0.7170067713668007, -0.6907544015661125, -0.6643844745352561, -0.637909508918098, -0.6113431388324015, -0.5847003615893318, -0.5579978567377881, -0.5312544009285315, -0.5044914129495655, -0.4777336776903207, -0.4510103191032491, -0.4243561241309168, -0.39781336784197835, -0.37143436375195515, -0.3452850765706766, -0.3194503084993052, -0.294041233695389, -0.2692064398716408, -0.24514814436981208, -0.2221457514701003, -0.20058881508743606, -0.18101890044813926, -0.16417024236184158, -0.15097542114639959, -0.14246751607540087, -0.13951533894394746, -0.1424675160754069, -0.1509754211464109, -0.16417024236185718, -0.1810189004481581, -0.2005888150874573, -0.2221457514701233, -0.24514814436983634, -0.2692064398716659, -0.29404123369541485, -0.31945030849933154, -0.3452850765707034, -0.37143436375198213, -0.3978133678420056, -0.42435612413094415, -0.45101031910327655, -0.47773367769034825, -0.504491412949593, -0.5312544009285589, -0.5579978567378158, -0.5847003615893592, -0.6113431388324289, -0.6379095089181251, -0.664384474535283, -0.6907544015661394, -0.7170067713668276, -0.7431299867027236, -0.7691132184502492, -0.7949462835648937, -0.8206195472423101, -0.8461238439562125, -0.8714504133412142, -0.8965908478367196, -0.9215370497139558, -0.9462811956385202, -0.9708157073223986, -0.9951332271258932, -1.0192265977055217, -1.0430888449863929, -1.066713163879756, -1.090092906277964, -1.1132215709471234, -1.1360927950075728, -1.1587003467481223, -1.1810381195647186, -1.203100126850321, -1.2248804976920098, -1.2463734732551748, -1.2675734037541055, -1.2884747459243087, -1.3090720609250697, -1.3293600126116973, -1.3493333661259805, -1.3689869867609454, -1.388315839062356, -1.4073149861347158, -1.4259795891240246, -1.4443049068533325, -1.4622862955903542, -1.4799192089291429, -1.4971991977701555, -1.5141219103850387, -1.5306830925541766, -1.5468785877665154, -1.5627043374724476, -1.5781563813816357, -1.5932308577986065, -1.607924003989773, -1.6222321565762614, -1.6361517519475393, -1.649679326691401, -1.6628115180363432, -1.675545064302775, -1.6878768053598951, -1.6998036830853906, -1.7113227418253896, -1.7224311288523775, -1.7331260948190008, -1.743404994205887, -1.7532652857617947, -1.762704532934565, -1.7717204042914954, -1.780310673927882, -1.7884732218625976, -1.7962060344196775, -1.8035072045949785, -1.8103749324070686, -1.8168075252315796, -1.8228033981183307, -1.8283610740905882, -1.8334791844259075, -1.8381564689180314, -1.842391776119401, -1.8461840635638536, -1.8495323979691578, -1.8524359554190502, -1.8548940215244976, -1.8569059915639374, -1.8584713706022904, -1.8595897735885645, -1.8602609254319156], [-1.8297564442775769, -1.829537075219973, -1.828879022485321, -1.82778244937856, -1.8262476280428137, -1.8242749394117967, -1.821864873143342, -1.819018027534189, -1.81573510941623, -1.8120169340344674, -1.8078644249069606, -1.8032786136671102, -1.798260639888677, -1.7928117508939796, -1.7869333015457922, -1.7806267540235072, -1.7738936775842156, -1.766735748309419, -1.7591547488381758, -1.7511525680875613, -1.742731200961436, -1.7338927480485922, -1.7246394153114937, -1.7149735137669262, -1.7048974591600285, -1.6944137716333263, -1.68352507539255, -1.672234098371228, -1.6605436718962436, -1.6484567303567803, -1.6359763108793535, -1.6231055530119205, -1.6098476984203856, -1.5962060906012052, -1.5821841746142202, -1.567785496840309, -1.553013704769023, -1.5378725468219554, -1.5223658722183273, -1.5064976308900462, -1.4902718734544342, -1.473692751253857, -1.4567645164726932, -1.4394915223434719, -1.4218782234556007, -1.403929176181952, -1.3856490392407221, -1.3670425744124537, -1.348114647435006, -1.3288702291026457, -1.309314396599366, -1.2894523351012035, -1.2692893396877605, -1.2488308176096141, -1.2280822909659104, -1.2070493998555205, -1.1857379060759485, -1.1641536974571074, -1.1423027929325844, -1.1201913484697112, -1.0978256640023258, -1.075212191537522, -1.0523575446410731, -1.0292685095470675, -1.0059520581874979, -0.982415363499526, -0.9586658174450035, -0.934711052272643, -0.9105589656732448, -0.8862177506295507, -0.8616959309537098, -0.8370024037491737, -0.8121464903462602, -0.7871379976634685, -0.7619872924694223, -0.7367053917033763, -0.7113040729109051, -0.6857960100423418, -0.6601949414515695, -0.6345158790718697, -0.6087753706457084, -0.5829918308482807, -0.5571859626019477, -0.5313812974507258, -0.5056048944441487, -0.4798882518535642, -0.4542685070484547, -0.42879002957972256, -0.40350655446570943, -0.3784840613123524, -0.353804685004525, -0.3295720479593975, -0.30591852577550027, -0.28301506333331355, -0.26108414188908113, -0.2404160927365794, -0.22138757660360522, -0.20447766310364965, -0.19027041647098925, -0.17942417549892867, -0.17258506318879716, -0.17024355572242306, -0.1725850631888019, -0.17942417549893785, -0.1902704164710022, -0.20447766310366572, -0.22138757660362376, -0.24041609273659992, -0.26108414188910306, -0.28301506333333654, -0.30591852577552425, -0.32957204795942213, -0.35380468500455015, -0.37848406131237794, -0.4035065544657353, -0.42879002957974865, -0.4542685070484809, -0.4798882518535907, -0.5056048944441752, -0.5313812974507522, -0.5571859626019743, -0.5829918308483072, -0.6087753706457348, -0.6345158790718961, -0.660194941451596, -0.6857960100423681, -0.7113040729109311, -0.7367053917034023, -0.7619872924694483, -0.7871379976634945, -0.8121464903462858, -0.837002403749199, -0.8616959309537352, -0.8862177506295759, -0.9105589656732698, -0.9347110522726676, -0.958665817445028, -0.98241536349955, -1.005952058187522, -1.0292685095470913, -1.0523575446410967, -1.0752121915375454, -1.097825664002349, -1.1201913484697341, -1.142302792932607, -1.1641536974571296, -1.1857379060759707, -1.2070493998555423, -1.2280822909659321, -1.2488308176096354, -1.2692893396877811, -1.289452335101224, -1.3093143965993863, -1.3288702291026657, -1.3481146474350258, -1.367042574412473, -1.3856490392407412, -1.4039291761819703, -1.4218782234556189, -1.4394915223434899, -1.4567645164727105, -1.473692751253874, -1.4902718734544511, -1.5064976308900628, -1.5223658722183437, -1.5378725468219714, -1.553013704769038, -1.5677854968403242, -1.5821841746142347, -1.5962060906012197, -1.6098476984203995, -1.6231055530119338, -1.6359763108793663, -1.6484567303567927, -1.6605436718962558, -1.6722340983712398, -1.6835250753925615, -1.6944137716333374, -1.704897459160039, -1.7149735137669357, -1.7246394153115032, -1.7338927480486013, -1.7427312009614448, -1.7511525680875697, -1.7591547488381833, -1.7667357483094266, -1.7738936775842225, -1.7806267540235137, -1.7869333015457982, -1.7928117508939854, -1.798260639888682, -1.803278613667115, -1.807864424906965, -1.8120169340344716, -1.8157351094162337, -1.8190180275341923, -1.821864873143345, -1.824274939411799, -1.8262476280428153, -1.8277824493785613, -1.828879022485322, -1.8295370752199736], [-1.799192927144257, -1.798978049211264, -1.7983334693286899, -1.7972593492377964, -1.7957559584808667, -1.7938236743615752, -1.791462981889705, -1.7886744737104159, -1.7854588500183186, -1.7818169184566877, -1.7777495940021952, -1.7732578988356247, -1.7683429621990892, -1.7630060202403643, -1.7572484158450132, -1.751071598457079, -1.744477123889205, -1.7374666541231523, -1.730041957101781, -1.7222049065136904, -1.7139574815718424, -1.7053017667876218, -1.6962399517419644, -1.6867743308553307, -1.6769073031585142, -1.6666413720664714, -1.6559791451575911, -1.6449233339610931, -1.6334767537555195, -1.621642323381616, -1.6094230650732528, -1.596822104310448, -1.5838426696990056, -1.5704880928817941, -1.556761808487267, -1.542667354121489, -1.5282083704106602, -1.5133886011019766, -1.4982118932316184, -1.482682197369747, -1.466803567953631, -1.4505801637214455, -1.434016248260912, -1.4171161906888254, -1.3998844664796657, -1.3823256584639725, -1.36444445802005, -1.346245666485894, -1.3277341968221088, -1.3089150755611059, -1.289793445083141, -1.2703745662659296, -1.2506638215618338, -1.2306667185651587, -1.210388894142183, -1.1898361192085058, -1.1690143042524892, -1.1479295057205074, -1.126587933399954, -1.1049959589602514, -1.0831601258413508, -1.061087160714559, -1.0387839867833955, -1.0162577392443892, -0.9935157832915338, -0.9705657351264687, -0.9474154865330172, -0.9240732336943017, -0.9005475110793958, -0.8768472314123571, -0.8529817329699055, -0.828960835748594, -0.8047949084159676, -0.7804949484366451, -0.7560726783749793, -0.7315406621630317, -0.7069124461425075, -0.6822027310180113, -0.6574275825992906, -0.6326046915011094, -0.6077536949997189, -0.5828965782698543, -0.5580581775899062, -0.5332668152644012, -0.5085551055735221, -0.48396098378076574, -0.4595290270176313, -0.4353121576581478, -0.41137384723756265, -0.38779097157586423, -0.36465750206442804, -0.3420892436482521, -0.3202298216848617, -0.29925802326097917, -0.2793963075839985, -0.2609196315221456, -0.24416243547021146, -0.22951951371347962, -0.21743390069660629, -0.20836363091251806, -0.20272308218564059, -0.20080707285574295, -0.20272308218564453, -0.20836363091252566, -0.21743390069661725, -0.22951951371349338, -0.24416243547022765, -0.2609196315221638, -0.2793963075840183, -0.2992580232610002, -0.3202298216848838, -0.3420892436482749, -0.36465750206445163, -0.38779097157588827, -0.4113738472375871, -0.4353121576581725, -0.45952902701765636, -0.48396098378079094, -0.5085551055735476, -0.5332668152644267, -0.5580581775899318, -0.5828965782698797, -0.6077536949997444, -0.632604691501135, -0.657427582599316, -0.6822027310180367, -0.7069124461425328, -0.7315406621630571, -0.7560726783750044, -0.7804949484366701, -0.8047949084159923, -0.8289608357486188, -0.8529817329699301, -0.8768472314123816, -0.9005475110794201, -0.9240732336943257, -0.9474154865330412, -0.9705657351264925, -0.9935157832915574, -1.0162577392444125, -1.0387839867834188, -1.061087160714582, -1.0831601258413734, -1.1049959589602738, -1.126587933399976, -1.147929505720529, -1.1690143042525107, -1.1898361192085272, -1.210388894142204, -1.2306667185651794, -1.2506638215618542, -1.2703745662659496, -1.2897934450831605, -1.3089150755611254, -1.327734196822128, -1.346245666485913, -1.3644444580200685, -1.3823256584639905, -1.3998844664796837, -1.417116190688843, -1.434016248260929, -1.4505801637214624, -1.4668035679536475, -1.4826821973697633, -1.4982118932316342, -1.5133886011019921, -1.5282083704106753, -1.5426673541215035, -1.5567618084872812, -1.570488092881808, -1.5838426696990198, -1.596822104310461, -1.6094230650732655, -1.6216423233816286, -1.6334767537555317, -1.6449233339611045, -1.6559791451576025, -1.6666413720664823, -1.6769073031585244, -1.6867743308553405, -1.696239951741974, -1.7053017667876307, -1.713957481571851, -1.7222049065136988, -1.7300419571017889, -1.7374666541231598, -1.744477123889212, -1.7510715984570853, -1.7572484158450195, -1.7630060202403701, -1.768342962199094, -1.7732578988356293, -1.7777495940021997, -1.7818169184566914, -1.785458850018322, -1.788674473710419, -1.791462981889708, -1.7938236743615772, -1.7957559584808684, -1.7972593492377977, -1.7983334693286905, -1.7989780492112648], [-1.768823677885006, -1.7686134162648366, -1.7679826848682982, -1.7669316440811527, -1.765460561192537, -1.7635698103643949, -1.7612598725889375, -1.7585313356343901, -1.755384893979362, -1.7518213487362584, -1.7478416075642327, -1.74344668457226, -1.7386377002130258, -1.7334158811683902, -1.7277825602273194, -1.7217391761572765, -1.7152872735701818, -1.7084285027841861, -1.7011646196826453, -1.6934974855718299, -1.6854290670390755, -1.6769614358132663, -1.6680967686297408, -1.6588373471019326, -1.649185557602307, -1.6391438911554255, -1.6287149433462709, -1.6179014142472992, -1.6067061083680676, -1.5951319346316921, -1.5831819063828663, -1.5708591414326913, -1.5581668621461584, -1.5451083955787774, -1.531687173669603, -1.5179067334987493, -1.5037707176184216, -1.4892828744675963, -1.4744470588816854, -1.4592672327099323, -1.4437474655548652, -1.4278919356499555, -1.4117049308937075, -1.3951908500607852, -1.3783542042135355, -1.361199618340399, -1.3437318332513732, -1.3259557077648831, -1.3078762212253106, -1.289498476396118, -1.2708277027801114, -1.2518692604261257, -1.2326286442904533, -1.2131114892319799, -1.1933235757324825, -1.173270836448317, -1.1529593637172053, -1.132395418164566, -1.111585438578562, -1.0905360532525388, -1.0692540930288994, -1.0477466063209817, -1.0260208764407903, -1.0040844416225059, -0.9819451182071051, -0.9596110275453328, -0.9370906272887325, -0.914392747876566, -0.891526635196734, -0.8685020006095711, -0.8453290797852525, -0.8220187021322258, -0.7985823730031807, -0.7750323713793994, -0.751381866383416, -0.727645056791971, -0.7038373387659164, -0.6799755083451209, -0.6560780069572982, -0.6321652203658912, -0.6082598442675206, -0.5843873333098799, -0.5605764548347808, -0.5368599743818142, -0.5132755071380543, -0.48986657824495, -0.46668394512614897, -0.4437872462425822, -0.42124705134452706, -0.39914739476940786, -0.37758886822474064, -0.3566923187013234, -0.336603115649757, -0.317495778463767, -0.2995784320427257, -0.2830960200378134, -0.2683304293674949, -0.25559480086063013, -0.24521880127332674, -0.23752246495676277, -0.2327794646468593, -0.23117632211499411, -0.2327794646468626, -0.2375224649567692, -0.2452188012733361, -0.25559480086064207, -0.268330429367509, -0.2830960200378296, -0.2995784320427435, -0.317495778463786, -0.33660311564977724, -0.35669231870134455, -0.3775888682247625, -0.3991473947694303, -0.42124705134455004, -0.44378724624260557, -0.4666839451261728, -0.48986657824497404, -0.5132755071380786, -0.5368599743818385, -0.5605764548348053, -0.5843873333099044, -0.608259844267545, -0.6321652203659157, -0.6560780069573228, -0.6799755083451454, -0.7038373387659409, -0.7276450567919953, -0.7513818663834403, -0.7750323713794237, -0.7985823730032047, -0.8220187021322499, -0.8453290797852763, -0.8685020006095948, -0.8915266351967576, -0.9143927478765894, -0.9370906272887557, -0.9596110275453558, -0.9819451182071278, -1.0040844416225285, -1.0260208764408127, -1.0477466063210041, -1.0692540930289214, -1.0905360532525605, -1.1115854385785833, -1.1323954181645872, -1.1529593637172262, -1.173270836448338, -1.193323575732503, -1.213111489232, -1.2326286442904733, -1.2518692604261452, -1.2708277027801307, -1.2894984763961368, -1.3078762212253292, -1.3259557077649016, -1.3437318332513912, -1.3611996183404165, -1.3783542042135528, -1.3951908500608026, -1.4117049308937237, -1.4278919356499722, -1.4437474655548812, -1.4592672327099483, -1.474447058881701, -1.4892828744676114, -1.5037707176184365, -1.5179067334987635, -1.5316871736696167, -1.5451083955787908, -1.558166862146172, -1.5708591414327042, -1.5831819063828783, -1.5951319346317039, -1.6067061083680794, -1.6179014142473105, -1.628714943346282, -1.6391438911554361, -1.649185557602317, -1.6588373471019422, -1.6680967686297503, -1.6769614358132752, -1.6854290670390837, -1.6934974855718379, -1.7011646196826529, -1.708428502784193, -1.7152872735701885, -1.721739176157283, -1.7277825602273253, -1.7334158811683957, -1.738637700213031, -1.7434466845722647, -1.747841607564237, -1.7518213487362628, -1.7553848939793653, -1.7585313356343932, -1.7612598725889401, -1.7635698103643966, -1.7654605611925382, -1.7669316440811538, -1.7679826848682991, -1.7686134162648368], [-1.7386780767871148, -1.7384725569785728, -1.737856050633068, -1.7368287169868275, -1.735390821419807, -1.7335427354352166, -1.7312849366311749, -1.728618008664821, -1.725542641209287, -1.7220596299040685, -1.7181698762994049, -1.7138743877954024, -1.709174277576746, -1.7040707645439745, -1.6985651732424076, -1.6926589337899745, -1.6863535818053181, -1.6796507583377405, -1.6725522098007028, -1.6650597879108044, -1.657175449634368, -1.6489012571439814, -1.6402393777876105, -1.6311920840731657, -1.62176175367171, -1.611950869442845, -1.6017620194861726, -1.5911978972231633, -1.5802613015142084, -1.5689551368161725, -1.557282413386321, -1.5452462475391588, -1.532849861963446, -1.5200965861074591, -1.5069898566414988, -1.4935332180076843, -1.4797303230682328, -1.465584933864767, -1.4511009225026767, -1.436282272176294, -1.4211330783525604, -1.4056575501330972, -1.3898600118171158, -1.3737449046904995, -1.3573167890697162, -1.340580346633033, -1.3235403830758994, -1.3062018311324426, -1.2885697540108698, -1.2706493492973798, -1.252445953391067, -1.233965046541489, -1.215212258571293, -1.1961933753788156, -1.176914346330289, -1.1573812926685392, -1.1376005170854375, -1.1175785146294077, -1.097321985147791, -1.0768378474977212, -1.0561332557994838, -1.0352156180545067, -1.0140926175078395, -0.9927722372043247, -0.9712627882712311, -0.9495729425611193, -0.9277117704111617, -0.9056887844240074, -0.8835139903568305, -0.8611979464272111, -0.8387518326167467, -0.816187531888033, -0.7935177256431943, -0.7707560062616595, -0.7479170101852128, -0.7250165757990514, -0.7020719313248897, -0.6791019191398774, -0.6561272644151043, -0.6331708977888345, -0.6102583440157172, -0.5874181912240529, -0.5646826586094486, -0.542088284085346, -0.5196767574822472, -0.4974959290126743, -0.47560102618980676, -0.4540561138227307, -0.43293582859163676, -0.41232740767722575, -0.392333002831457, -0.3730722161044706, -0.35468469561918975, -0.3373324704505834, -0.321201466951016, -0.30650133840785204, -0.2934624110028499, -0.28232835348881613, -0.2733433922773871, -0.2667338552374925, -0.26268568838862255, -0.2613219232128851, -0.2626856883886254, -0.266733855237498, -0.2733433922773951, -0.28232835348882646, -0.29346241100286236, -0.3065013384078664, -0.32120146695103186, -0.33733247045060066, -0.3546846956192082, -0.37307221610449004, -0.3923330028314772, -0.4123274076772466, -0.43293582859165824, -0.45405611382275274, -0.47560102618982913, -0.49749592901269696, -0.5196767574822702, -0.5420882840853692, -0.5646826586094719, -0.5874181912240765, -0.6102583440157406, -0.6331708977888582, -0.6561272644151278, -0.6791019191399009, -0.7020719313249132, -0.725016575799075, -0.7479170101852363, -0.7707560062616831, -0.7935177256432177, -0.8161875318880564, -0.8387518326167699, -0.861197946427234, -0.8835139903568533, -0.90568878442403, -0.9277117704111844, -0.9495729425611418, -0.9712627882712533, -0.9927722372043468, -1.014092617507861, -1.0352156180545284, -1.0561332557995053, -1.0768378474977423, -1.097321985147812, -1.1175785146294284, -1.137600517085458, -1.1573812926685596, -1.176914346330309, -1.1961933753788354, -1.2152122585713123, -1.2339650465415082, -1.2524459533910854, -1.2706493492973985, -1.288569754010888, -1.3062018311324606, -1.3235403830759171, -1.3405803466330504, -1.3573167890697335, -1.3737449046905161, -1.389860011817132, -1.4056575501331132, -1.4211330783525762, -1.4362822721763095, -1.4511009225026916, -1.4655849338647817, -1.4797303230682473, -1.493533218007698, -1.5069898566415123, -1.5200965861074722, -1.5328498619634594, -1.545246247539171, -1.557282413386333, -1.5689551368161843, -1.58026130151422, -1.5911978972231742, -1.6017620194861835, -1.6119508694428555, -1.6217617536717202, -1.6311920840731753, -1.6402393777876196, -1.6489012571439896, -1.6571754496343762, -1.6650597879108122, -1.6725522098007104, -1.6796507583377476, -1.686353581805325, -1.692658933789981, -1.6985651732424134, -1.7040707645439799, -1.709174277576751, -1.713874387795407, -1.7181698762994093, -1.7220596299040722, -1.7255426412092905, -1.7286180086648242, -1.7312849366311778, -1.7335427354352184, -1.7353908214198086, -1.7368287169868288, -1.737856050633069, -1.7384725569785733], [-1.7087852877727236, -1.7085846352226046, -1.7079827303353632, -1.7069797313983996, -1.7055759022176296, -1.7037716121080413, -1.7015673358808754, -1.698963653827798, -1.6959612517025864, -1.6925609207009615, -1.6887635574393012, -1.6845701639331458, -1.6799818475765047, -1.6749998211231445, -1.6696254026711894, -1.6638600156525345, -1.657705188828752, -1.6511625562953685, -1.6442338574966089, -1.6369209372529197, -1.6292257458038573, -1.6211503388691835, -1.6126968777313309, -1.6038676293427234, -1.5946649664618113, -1.5850913678220875, -1.5751494183387962, -1.5648418093585643, -1.5541713389577136, -1.543140912295666, -1.5317535420305177, -1.5200123488046535, -1.5079205618091285, -1.495481519436522, -1.482698670033064, -1.4695755727620583, -1.4561158985920313, -1.442323431424586, -1.4282020693787227, -1.4137558262504095, -1.398988833168455, -1.3839053404703447, -1.3685097198246534, -1.3528064666300388, -1.3368002027246744, -1.320495679444411, -1.3038977810730439, -1.2870115287338992, -1.269842084778699, -1.2523947577374346, -1.2346750079019813, -1.2166884536266238, -1.1984408784407743, -1.179938239083296, -1.1611866745842951, -1.142192516539526, -1.122962300745108, -1.1035027803867885, -1.083820941009193, -1.063924017527357, -1.0438195135864063, -1.0235152236269216, -1.0030192580749016, -0.9823400721483564, -0.9614864988598182, -0.940467786898427, -0.9192936442003578, -0.8979742881665874, -0.8765205036677329, -0.8549437101934537, -0.8332560397665694, -0.8114704275591748, -0.78960071753096, -0.7676617858721997, -0.7456696855910951, -0.7236418162551552, -0.7015971236985031, -0.6795563354612029, -0.6575422388506024, -0.6355800098191632, -0.6136976023339532, -0.5919262095362706, -0.5703008096690161, -0.5488608113064143, -0.5276508135256294, -0.5067214967379489, -0.48613065799110267, -0.4659443991306087, -0.4462384649081141, -0.4270997074917641, -0.40862761912574136, -0.3909358200409304, -0.37415330820672, -0.35842516799119367, -0.343912301754706, -0.33078961560088455, -0.31924201180434897, -0.30945760630600544, -0.30161791213581746, -0.2958853852461819, -0.29238965885845336, -0.29121471222727646, -0.29238965885845575, -0.2958853852461867, -0.30161791213582445, -0.3094576063060145, -0.3192420118043599, -0.33078961560089726, -0.34391230175472026, -0.35842516799120927, -0.3741533082067367, -0.3909358200409482, -0.40862761912575996, -0.4270997074917834, -0.446238464908134, -0.4659443991306292, -0.4861306579911236, -0.5067214967379703, -0.5276508135256511, -0.5488608113064362, -0.5703008096690384, -0.5919262095362928, -0.6136976023339755, -0.6355800098191857, -0.6575422388506249, -0.6795563354612254, -0.7015971236985259, -0.7236418162551779, -0.7456696855911177, -0.7676617858722222, -0.7896007175309823, -0.8114704275591972, -0.8332560397665917, -0.854943710193476, -0.876520503667755, -0.8979742881666093, -0.9192936442003797, -0.9404677868984486, -0.9614864988598397, -0.9823400721483777, -1.0030192580749226, -1.023515223626943, -1.0438195135864272, -1.0639240175273774, -1.0838209410092132, -1.1035027803868085, -1.122962300745128, -1.1421925165395457, -1.1611866745843147, -1.179938239083315, -1.1984408784407932, -1.2166884536266422, -1.2346750079019995, -1.2523947577374526, -1.2698420847787169, -1.2870115287339168, -1.303897781073061, -1.3204956794444278, -1.3368002027246908, -1.352806466630055, -1.3685097198246694, -1.3839053404703605, -1.3989888331684706, -1.4137558262504244, -1.4282020693787374, -1.4423234314246007, -1.4561158985920455, -1.4695755727620714, -1.4826986700330769, -1.4954815194365352, -1.5079205618091414, -1.520012348804666, -1.5317535420305297, -1.5431409122956776, -1.554171338957725, -1.564841809358575, -1.5751494183388068, -1.5850913678220977, -1.594664966461821, -1.6038676293427327, -1.61269687773134, -1.621150338869192, -1.6292257458038655, -1.6369209372529272, -1.644233857496616, -1.6511625562953753, -1.6577051888287582, -1.6638600156525407, -1.6696254026711952, -1.67499982112315, -1.6799818475765096, -1.6845701639331503, -1.6887635574393052, -1.692560920700965, -1.69596125170259, -1.6989636538278006, -1.7015673358808778, -1.7037716121080433, -1.7055759022176304, -1.706979731398401, -1.7079827303353643, -1.7085846352226057], [-1.679174230184608, -1.6789785698787643, -1.6783916414713091, -1.6774136024928932, -1.6760447154960607, -1.6742853480576705, -1.6721359727827423, -1.6695971673101933, -1.6666696143210584, -1.6633541015499547, -1.6596515218006613, -1.6555628729668836, -1.6510892580594023, -1.6462318852409994, -1.6409920678707384, -1.6353712245593688, -1.6293708792378385, -1.6229926612411405, -1.616238305409956, -1.6091096522128363, -1.6016086478919607, -1.5937373446358378, -1.5854979007826555, -1.576892581058407, -1.5679237568543174, -1.5585939065485948, -1.5489056158780514, -1.5388615783657125, -1.528464595811195, -1.5177175788513515, -1.5066235475994678, -1.4951856323722243, -1.4834070745146075, -1.4712912273340941, -1.4588415571566908, -1.4460616445188186, -1.4329551855106286, -1.4195259932881283, -1.4057779997735242, -1.3917152575654665, -1.37734194208349, -1.3626623539738663, -1.3476809218074426, -1.3324022051038242, -1.3168308977206071, -1.300971831651303, -1.2848299812812636, -1.268410468157392, -1.2517185663348704, -1.234759708372691, -1.2175394920596228, -1.2000636879636364, -1.182338247910925, -1.1643693145159164, -1.1461632319013004, -1.1277265577676514, -1.1090660769961103, -1.0901888169954912, -1.071102065037761, -1.0518133878639933, -1.0323306538876438, -1.0126620583745445, -0.9928161520408378, -0.97280187358292, -0.9526285867393666, -0.9323061225862945, -0.9118448278875196, -0.8912556204626885, -0.8705500527042809, -0.8497403845726678, -0.8288396676326268, -0.8078618419708204, -0.7868218481583263, -0.7657357568021835, -0.7446209186716973, -0.7234961388944164, -0.7023818792959315, -0.6813004936043561, -0.6602765009423331, -0.6393369037584871, -0.6185115570519325, -0.5978335963220719, -0.5773399319717831, -0.5570718176494407, -0.537075498837081, -0.5174029452809608, -0.4981126657463056, -0.4792705948407624, -0.4609510276694986, -0.44323755686375943, -0.4262239359155469, -0.41001475104982776, -0.39472573104707437, -0.3804834642827445, -0.3674242354601611, -0.3556916620046311, -0.3454328345324344, -0.33679278726159967, -0.3299073749789821, -0.32489501032326334, -0.3218481501913122, -0.3208257698153919, -0.32184815019131435, -0.32489501032326756, -0.3299073749789882, -0.33679278726160766, -0.34543283453244417, -0.35569166200464253, -0.36742423546017394, -0.3804834642827585, -0.39472573104708963, -0.4100147510498441, -0.426223935915564, -0.4432375568637772, -0.4609510276695172, -0.47927059484078155, -0.4981126657463252, -0.5174029452809809, -0.5370754988371013, -0.5570718176494613, -0.5773399319718042, -0.597833596322093, -0.6185115570519538, -0.6393369037585085, -0.6602765009423547, -0.6813004936043776, -0.7023818792959533, -0.723496138894438, -0.744620918671719, -0.7657357568022052, -0.7868218481583481, -0.8078618419708419, -0.8288396676326484, -0.8497403845726892, -0.8705500527043021, -0.8912556204627097, -0.9118448278875406, -0.9323061225863155, -0.9526285867393876, -0.9728018735829406, -0.9928161520408585, -1.0126620583745647, -1.0323306538876642, -1.051813387864013, -1.0711020650377805, -1.0901888169955107, -1.1090660769961296, -1.1277265577676705, -1.1461632319013193, -1.1643693145159348, -1.1823382479109432, -1.2000636879636544, -1.2175394920596405, -1.2347597083727082, -1.2517185663348878, -1.268410468157409, -1.2848299812812805, -1.3009718316513195, -1.3168308977206233, -1.3324022051038398, -1.347680921807458, -1.3626623539738816, -1.377341942083505, -1.3917152575654814, -1.4057779997735382, -1.419525993288142, -1.4329551855106422, -1.446061644518832, -1.4588415571567042, -1.4712912273341068, -1.48340707451462, -1.4951856323722363, -1.5066235475994794, -1.5177175788513628, -1.5284645958112062, -1.5388615783657227, -1.5489056158780616, -1.5585939065486047, -1.5679237568543267, -1.5768925810584158, -1.5854979007826642, -1.5937373446358458, -1.6016086478919684, -1.6091096522128434, -1.6162383054099632, -1.6229926612411472, -1.6293708792378445, -1.635371224559375, -1.6409920678707437, -1.6462318852410045, -1.651089258059407, -1.655562872966888, -1.659651521800665, -1.6633541015499582, -1.6666696143210618, -1.669597167310196, -1.672135972782745, -1.6742853480576725, -1.676044715496062, -1.677413602492894, -1.6783916414713098, -1.6789785698787647], [-1.649873550808585, -1.6496830068133512, -1.6491114271445573, -1.6481589687558407, -1.646825893246389, -1.6451125668758912, -1.643019460586001, -1.6405471500288478, -1.6376963156032884, -1.6344677424997682, -1.6308623207548145, -1.6268810453163878, -1.6225250161214861, -1.617795438187615, -1.6126936217199344, -1.6072209822361427, -1.601379040711386, -1.595169423745751, -1.588593863757202, -1.58165419920311, -1.5743523748338808, -1.566690441982557, -1.5586705588946634, -1.5502949911030335, -1.541566111852822, -1.532486402582467, -1.523058453466954, -1.5132849640304027, -1.5031687438357184, -1.492712713259879, -1.4819199043643214, -1.4707934618709073, -1.459336644255067, -1.4475528249689853, -1.4354454938090873, -1.4230182584436721, -1.4102748461183023, -1.3972191055585454, -1.3838550090919077, -1.3701866550133135, -1.3562182702213432, -1.3419542131556499, -1.3273989770696266, -1.3125571936765266, -1.2974336372119375, -1.2820332289608325, -1.266361042303517, -1.2504223083417132, -1.234222422173939, -1.2177669498984145, -1.2010616364320856, -1.1841124142462898, -1.1669254131332512, -1.1495069711333599, -1.131863646771323, -1.114002232770225, -1.0959297714367278, -1.077653571938635, -1.0591812297284622, -1.0405206484042526, -1.0216800643425012, -1.0026680744887237, -0.9834936677500904, -0.9641662605029976, -0.944695736808035, -0.9250924940172726, -0.9053674945661773, -0.885532324866961, -0.8655992623641783, -0.8455813519794882, -0.8254924933631391, -0.8053475405872554, -0.785162416162052, -0.764954241531119, -0.7447414865042801, -0.724544140411026, -0.7043839080934146, -0.6842844341851387, -0.6642715594107192, -0.6443736128335037, -0.6246217440032052, -0.6050502986827, -0.5856972410932758, -0.5666046241552133, -0.5478191066654721, -0.5293925122736334, -0.5113824188814045, -0.4938527579602553, -0.47687439044307317, -0.4605256085616527, -0.4448924909136683, -0.4300690116985085, -0.41615677671860996, -0.4032642334010368, -0.39150518848840044, -0.3809964779585228, -0.3718546845047546, -0.36419190190660217, -0.358110706054426, -0.35369869231078294, -0.3510231347253015, -0.3501264491914149, -0.35102313472530333, -0.35369869231078654, -0.35811070605443146, -0.3641919019066092, -0.37185468450476333, -0.3809964779585329, -0.39150518848841187, -0.4032642334010495, -0.41615677671862383, -0.43006901169852324, -0.4448924909136839, -0.4605256085616692, -0.4768743904430903, -0.4938527579602731, -0.5113824188814228, -0.5293925122736524, -0.5478191066654912, -0.5666046241552327, -0.5856972410932958, -0.6050502986827202, -0.6246217440032253, -0.644373612833524, -0.6642715594107397, -0.6842844341851593, -0.7043839080934352, -0.7245441404110468, -0.7447414865043007, -0.7649542415311399, -0.7851624161620726, -0.8053475405872761, -0.8254924933631598, -0.8455813519795089, -0.8655992623641988, -0.8855323248669814, -0.9053674945661978, -0.9250924940172927, -0.9446957368080551, -0.9641662605030175, -0.9834936677501103, -1.0026680744887435, -1.0216800643425208, -1.040520648404272, -1.0591812297284815, -1.077653571938654, -1.0959297714367466, -1.1140022327702435, -1.1318636467713412, -1.1495069711333779, -1.1669254131332687, -1.184112414246307, -1.201061636432103, -1.2177669498984316, -1.234222422173956, -1.2504223083417296, -1.2663610423035334, -1.2820332289608483, -1.2974336372119535, -1.3125571936765421, -1.3273989770696415, -1.3419542131556648, -1.3562182702213577, -1.3701866550133277, -1.3838550090919215, -1.3972191055585592, -1.4102748461183157, -1.4230182584436848, -1.4354454938091, -1.4475528249689975, -1.4593366442550793, -1.4707934618709189, -1.4819199043643325, -1.4927127132598899, -1.5031687438357288, -1.5132849640304127, -1.5230584534669638, -1.5324864025824767, -1.5415661118528314, -1.5502949911030421, -1.5586705588946719, -1.5666904419825647, -1.5743523748338886, -1.581654199203117, -1.588593863757209, -1.5951694237457574, -1.601379040711392, -1.6072209822361485, -1.6126936217199395, -1.6177954381876198, -1.6225250161214906, -1.6268810453163915, -1.6308623207548183, -1.6344677424997718, -1.6376963156032918, -1.6405471500288504, -1.6430194605860036, -1.6451125668758932, -1.6468258932463902, -1.6481589687558418, -1.6491114271445582, -1.649683006813352], [-1.6209115961595966, -1.6207262911103486, -1.620170428140774, -1.6192441637908928, -1.617947758979189, -1.6162815790305933, -1.6142460937162562, -1.611841877305725, -1.609069608632316, -1.6059300711726556, -1.6024241531415666, -1.5985528476036752, -1.594317252603331, -1.5897185713146618, -1.5847581122138215, -1.579437289275755, -1.5737576221980742, -1.567720736654941, -1.561328364584183, -1.5545823445111975, -1.5474846219136102, -1.5400372496310346, -1.5322423883247653, -1.5241023069927127, -1.5156193835454395, -1.5067961054497643, -1.497635070447051, -1.4881389873540412, -1.4783106769548868, -1.4681530729939474, -1.4576692232798962, -1.4468622909127915, -1.435735555647, -1.42429241540422, -1.4125363879523853, -1.4004711127679368, -1.38810035310086, -1.3754279982640196, -1.3624580661707346, -1.3491947061472214, -1.3356422020495733, -1.3218049757183588, -1.3076875908077723, -1.2932947570306126, -1.278631334865297, -1.2637023407766597, -1.2485129530086123, -1.2330685180138763, -1.2173745575941362, -1.2014367768332068, -1.1852610729163116, -1.1688535449405841, -1.152220504835568, -1.1353684895281253, -1.1183042745040184, -1.1010348889388613, -1.0835676325945178, -1.0659100947038105, -1.0480701750970807, -1.0300561078593053, -1.0118764878467557, -0.9935403004383183, -0.9750569549494069, -0.9564363221967258, -0.9376887767710189, -0.9188252446532834, -0.899857256898801, -0.8807970102136626, -0.8616574353610089, -0.8424522744594491, -0.823196168373911, -0.8039047555484942, -0.7845947837892684, -0.7652842366677135, -0.7459924763747889, -0.7267404049988947, -0.7075506463090292, -0.6884477501686274, -0.6694584216442379, -0.6506117766469667, -0.6319396254704895, -0.6134767847537469, -0.5952614170471432, -0.5773353951004447, -0.5597446849707415, -0.5425397377744509, -0.5257758740529664, -0.5095136369749016, -0.49381908074534625, -0.4787639486660153, -0.4644256817932125, -0.4508871853573158, -0.4382362684606327, -0.4265646669225628, -0.41596656482759303, -0.40653655359969804, -0.3983670139171719, -0.3915449778826607, -0.3861486223205339, -0.38224364516503717, -0.3798798623178239, -0.3790884038404034, -0.37987986231782545, -0.38224364516504034, -0.3861486223205386, -0.39154497788266696, -0.3983670139171796, -0.40653655359970714, -0.41596656482760336, -0.4265646669225742, -0.43823626846064523, -0.4508871853573293, -0.46442568179322674, -0.4787639486660304, -0.493819080745362, -0.509513636974918, -0.5257758740529835, -0.5425397377744684, -0.5597446849707594, -0.5773353951004631, -0.5952614170471618, -0.6134767847537658, -0.6319396254705085, -0.6506117766469859, -0.6694584216442573, -0.6884477501686469, -0.7075506463090487, -0.7267404049989146, -0.7459924763748088, -0.7652842366677334, -0.7845947837892882, -0.8039047555485139, -0.8231961683739308, -0.8424522744594689, -0.8616574353610286, -0.8807970102136823, -0.8998572568988207, -0.9188252446533026, -0.9376887767710382, -0.9564363221967451, -0.9750569549494261, -0.9935403004383374, -1.0118764878467743, -1.030056107859324, -1.0480701750970989, -1.0659100947038285, -1.0835676325945358, -1.101034888938879, -1.1183042745040361, -1.135368489528143, -1.1522205048355854, -1.1688535449406012, -1.1852610729163282, -1.201436776833223, -1.2173745575941524, -1.2330685180138923, -1.248512953008628, -1.263702340776675, -1.278631334865312, -1.2932947570306275, -1.3076875908077867, -1.3218049757183734, -1.3356422020495873, -1.3491947061472354, -1.3624580661707484, -1.375427998264033, -1.3881003531008727, -1.4004711127679494, -1.4125363879523973, -1.424292415404232, -1.4357355556470117, -1.4468622909128028, -1.457669223279907, -1.4681530729939583, -1.478310676954897, -1.488138987354051, -1.4976350704470607, -1.5067961054497736, -1.5156193835454481, -1.524102306992721, -1.5322423883247736, -1.5400372496310422, -1.5474846219136176, -1.5545823445112046, -1.5613283645841893, -1.5677207366549475, -1.5737576221980802, -1.5794372892757609, -1.5847581122138268, -1.5897185713146667, -1.5943172526033353, -1.5985528476036794, -1.6024241531415706, -1.605930071172659, -1.6090696086323186, -1.6118418773057277, -1.6142460937162584, -1.6162815790305955, -1.6179477589791904, -1.6192441637908939, -1.620170428140775, -1.620726291110349], [-1.5923163850582873, -1.5921364395920017, -1.5915966552801437, -1.5906971883918752, -1.5894382994031087, -1.5878203530378037, -1.5858438183264594, -1.5835092686824728, -1.5808173819972469, -1.577768940755141, -1.574364832169565, -1.5706060483417528, -1.5664936864439853, -1.5620289489292876, -1.5572131437698926, -1.5520476847270461, -1.5465340916550352, -1.5406739908426523, -1.5344691153956656, -1.5279213056642322, -1.5210325097196415, -1.5138047838851891, -1.5062402933265087, -1.4983413127072123, -1.4901102269162942, -1.48154953187439, -1.4726618354267091, -1.4634498583312474, -1.4539164353517449, -1.444064516465831, -1.4338971681998438, -1.423417575103003, -1.412629041374915, -1.4015349926618472, -1.3901389780388074, -1.3784446721962855, -1.3664558778524984, -1.3541765284142324, -1.3416106909118644, -1.328762569236953, -1.3156365077139172, -1.302236995040834, -1.2885686686383275, -1.2746363194499548, -1.2604448972424698, -1.2459995164599502, -1.2313054626920976, -1.2163681998241265, -1.2011933779437, -1.1857868420894513, -1.1701546419358617, -1.1543030425208842, -1.1382385361357885, -1.1219678555115644, -1.105497988453, -1.0888361940905598, -1.0719900209417, -1.054967326997588, -1.0377763020786746, -1.0204254927336267, -1.0029238299911094, -0.9852806603132656, -0.9675057801438857, -0.949609474493598, -0.9316025600592747, -0.9134964334354979, -0.8953031250424031, -0.8770353594663318, -0.8587066229867882, -0.8403312391439504, -0.8219244532832118, -0.8035025270934049, -0.7850828442281266, -0.7666840281570338, -0.7483260734247288, -0.7300304914828258, -0.7118204721836794, -0.6937210618515853, -0.6757593585381191, -0.6579647245686475, -0.640369015727134, -0.6230068253181434, -0.6059157397809799, -0.5891366003855718, -0.5727137626755613, -0.5566953416059462, -0.5411334256451377, -0.5260842374442658, -0.5116082121349236, -0.4977699572575277, -0.4846380514665881, -0.47228463371649704, -0.4607847323918513, -0.4502152871598218, -0.4406538278668761, -0.432176797031939, -0.4248575367060542, -0.41876400562558724, -0.4139563441465969, -0.4104844539298572, -0.40838579522351004, -0.4076836149417127, -0.4083857952235115, -0.41048445392986005, -0.41395634414660115, -0.41876400562559285, -0.424857536706061, -0.43217679703194717, -0.44065382786688545, -0.4502152871598321, -0.4607847323918627, -0.4722846337165093, -0.4846380514666012, -0.4977699572575416, -0.5116082121349381, -0.526084237444281, -0.5411334256451533, -0.5566953416059626, -0.572713762675578, -0.5891366003855888, -0.6059157397809973, -0.6230068253181612, -0.6403690157271519, -0.6579647245686657, -0.6757593585381374, -0.6937210618516038, -0.7118204721836979, -0.7300304914828446, -0.7483260734247477, -0.7666840281570527, -0.7850828442281454, -0.8035025270934237, -0.8219244532832306, -0.8403312391439692, -0.8587066229868071, -0.8770353594663507, -0.8953031250424218, -0.9134964334355167, -0.9316025600592933, -0.9496094744936163, -0.9675057801439041, -0.9852806603132841, -1.0029238299911276, -1.0204254927336445, -1.0377763020786925, -1.0549673269976059, -1.0719900209417175, -1.0888361940905766, -1.1054979884530172, -1.1219678555115813, -1.138238536135805, -1.1543030425209007, -1.170154641935878, -1.1857868420894673, -1.2011933779437158, -1.2163681998241418, -1.231305462692113, -1.2459995164599649, -1.2604448972424842, -1.2746363194499692, -1.2885686686383415, -1.3022369950408477, -1.3156365077139305, -1.328762569236966, -1.3416106909118772, -1.3541765284142453, -1.3664558778525109, -1.3784446721962975, -1.3901389780388191, -1.4015349926618588, -1.4126290413749263, -1.4234175751030136, -1.4338971681998545, -1.4440645164658417, -1.4539164353517549, -1.4634498583312567, -1.472661835426719, -1.4815495318743994, -1.4901102269163031, -1.4983413127072205, -1.5062402933265162, -1.5138047838851967, -1.521032509719649, -1.5279213056642391, -1.534469115395672, -1.5406739908426585, -1.546534091655041, -1.5520476847270517, -1.5572131437698975, -1.5620289489292922, -1.5664936864439893, -1.570606048341757, -1.5743648321695687, -1.5777689407551443, -1.5808173819972497, -1.5835092686824752, -1.585843818326462, -1.5878203530378059, -1.58943829940311, -1.5906971883918763, -1.5915966552801444, -1.592136439592002], [-1.5641155815246053, -1.5639411136535022, -1.5634177620752183, -1.5625456829056605, -1.561325136374213, -1.5597564868784088, -1.5578402030612115, -1.5555768579116451, -1.5529671288897304, -1.5500117980769357, -1.5467117523535496, -1.5430679836046741, -1.5390815889567555, -1.534753771046873, -1.5300858383272828, -1.5250792054080275, -1.5197353934407483, -1.5140560305471975, -1.5080428522963312, -1.5016977022342604, -1.495022532471813, -1.4880194043349158, -1.4806904890835497, -1.4730380687056066, -1.4650645367926012, -1.4567723995048776, -1.4481642766347198, -1.439242902776585, -1.4300111286146087, -1.4204719223385318, -1.4106283712002983, -1.4004836832248146, -1.3900411890897033, -1.379304344190387, -1.3682767309084987, -1.3569620611034594, -1.345364178849108, -1.3334870634395393, -1.3213348326908427, -1.3089117465682436, -1.2962222111712896, -1.2832707831132253, -1.2700621743346026, -1.2566012573955379, -1.242893071295898, -1.2289428278781525, -1.2147559188737227, -1.2003379236604863, -1.18569461780673, -1.1708319824854034, -1.1557562148521006, -1.140473739490925, -1.1249912210443993, -1.10931557815701, -1.0934539988769998, -1.0774139576777937, -1.0612032342791455, -1.0448299344689158, -1.0283025131495216, -1.011629799858689, -0.994821027042372, -0.9778858613886809, -0.9608344385654274, -0.943677401740411, -0.9264259443026545, -0.909091857243995, -0.8916875817030998, -0.8742262672169165, -0.8567218362661233, -0.8391890557387861, -0.8216436159666363, -0.8041022180061848, -0.7865826698355034, -0.7691039921077291, -0.7516865340319084, -0.7343520998245407, -0.7171240859701167, -0.7000276292192732, -0.6830897648052793, -0.6663395937322009, -0.6498084571321295, -0.6335301145480324, -0.617540921512105, -0.6018799998966767, -0.5865893921657134, -0.5717141878256765, -0.5573026070903475, -0.543406023142894, -0.5300789006318612, -0.5173786245797453, -0.5053651913338372, -0.494100732411007, -0.48364884416277426, -0.47407370231396445, -0.46543895170840266, -0.45780637868414, -0.45123439616058636, -0.4457763981681066, -0.4414790679868843, -0.4383807475989366, -0.4365099903346202, -0.4358844184753947, -0.4365099903346215, -0.43838074759893914, -0.441479067986888, -0.4457763981681116, -0.4512343961605925, -0.45780637868414725, -0.46543895170841104, -0.4740737023139737, -0.48364884416278464, -0.49410073241101815, -0.5053651913338493, -0.5173786245797579, -0.5300789006318747, -0.5434060231429081, -0.5573026070903622, -0.5717141878256916, -0.5865893921657289, -0.6018799998966927, -0.6175409215121215, -0.6335301145480492, -0.6498084571321463, -0.666339593732218, -0.6830897648052965, -0.7000276292192906, -0.7171240859701343, -0.7343520998245585, -0.7516865340319263, -0.769103992107747, -0.7865826698355213, -0.8041022180062026, -0.8216436159666544, -0.8391890557388041, -0.8567218362661412, -0.8742262672169344, -0.8916875817031178, -0.909091857244013, -0.9264259443026722, -0.9436774017404288, -0.9608344385654449, -0.9778858613886986, -0.9948210270423893, -1.0116297998587063, -1.0283025131495387, -1.0448299344689327, -1.061203234279162, -1.0774139576778103, -1.0934539988770162, -1.109315578157026, -1.1249912210444155, -1.1404737394909408, -1.155756214852116, -1.170831982485419, -1.1856946178067453, -1.2003379236605014, -1.2147559188737376, -1.2289428278781669, -1.2428930712959123, -1.256601257395552, -1.270062174334616, -1.2832707831132386, -1.2962222111713029, -1.3089117465682565, -1.3213348326908552, -1.3334870634395515, -1.34536417884912, -1.356962061103471, -1.36827673090851, -1.3793043441903983, -1.3900411890897144, -1.400483683224825, -1.4106283712003085, -1.420471922338542, -1.4300111286146187, -1.439242902776594, -1.4481642766347291, -1.4567723995048867, -1.4650645367926096, -1.4730380687056148, -1.4806904890835573, -1.488019404334923, -1.49502253247182, -1.5016977022342668, -1.5080428522963376, -1.5140560305472037, -1.5197353934407536, -1.5250792054080327, -1.5300858383272877, -1.5347537710468777, -1.53908158895676, -1.5430679836046781, -1.5467117523535532, -1.5500117980769388, -1.5529671288897338, -1.5555768579116476, -1.5578402030612142, -1.5597564868784104, -1.5613251363742144, -1.5625456829056614, -1.563417762075219, -1.5639411136535026], [-1.5363364680146492, -1.5361675924382945, -1.5356610177215406, -1.5348168999147793, -1.5336354991469654, -1.5321171796934667, -1.5302624100718418, -1.5280717631663567, -1.5255459163822604, -1.5226856518311216, -1.5194918565487403, -1.5159655227474598, -1.512107748104933, -1.5079197360917331, -1.5034027963404748, -1.4985583450594668, -1.4933879054942416, -1.4878931084407085, -1.482075692814063, -1.4759375062780227, -1.469480505939436, -1.4627067591138092, -1.455618444167857, -1.4482178514457744, -1.4405073842865865, -1.4324895601406413, -1.4241670117940979, -1.415542488711104, -1.406618858504308, -1.3973991085453616, -1.3878863477282077, -1.3780838083991895, -1.367994848469378, -1.357622953726027, -1.3469717403617214, -1.336044957741632, -1.3248464914312992, -1.313380366509627, -1.3016507511942452, -1.2896619608091358, -1.2774184621274787, -1.2649248781260316, -1.2521859931911012, -1.2392067588203113, -1.2259922998689732, -1.2125479213949584, -1.1988791161616426, -1.1849915728647622, -1.170891185155978, -1.1565840615436669, -1.1420765362599823, -1.1273751811926862, -1.1124868189906774, -1.097418537463656, -1.082177705409023, -1.0667719900130108, -1.0512093759882501, -1.0354981866265274, -1.0196471069634336, -1.0036652092709286, -0.987561981114444, -0.9713473562329332, -0.9550317485229363, -0.938626089430876, -0.9221418690808262, -0.9055911814869994, -0.8889867742199562, -0.8723421029113281, -0.8556713909913438, -0.8389896950535723, -0.822312976227926, -0.8056581779107692, -0.789043310143032, -0.7724875408347255, -0.7560112938960761, -0.7396363541378393, -0.7233859785293859, -0.7072850130326973, -0.6913600137400423, -0.6756393704064283, -0.6601534296567919, -0.6449346141345081, -0.6300175326184654, -0.6154390746569179, -0.6012384815524494, -0.5874573836189075, -0.574139791599121, -0.5613320281263943, -0.5490825833605446, -0.5374418777559852, -0.5264619147534537, -0.5161958075448835, -0.5066971674999631, -0.4980193478714069, -0.490214545335525, -0.4833327737345893, -0.47742073848230865, -0.47252065521106457, -0.468669070433332, -0.46589575281955525, -0.46422272864131964, -0.4636635319853507, -0.4642227286413208, -0.46589575281955753, -0.4686690704333354, -0.472520655211069, -0.47742073848231414, -0.48333277373459593, -0.49021454533553255, -0.4980193478714154, -0.5066971674999725, -0.5161958075448937, -0.5264619147534646, -0.5374418777559968, -0.5490825833605568, -0.5613320281264071, -0.5741397915991344, -0.5874573836189214, -0.6012384815524638, -0.6154390746569327, -0.6300175326184808, -0.6449346141345237, -0.6601534296568077, -0.6756393704064444, -0.6913600137400585, -0.7072850130327137, -0.7233859785294025, -0.7396363541378562, -0.7560112938960928, -0.7724875408347425, -0.7890433101430488, -0.8056581779107863, -0.8223129762279431, -0.8389896950535896, -0.855671390991361, -0.8723421029113453, -0.8889867742199733, -0.9055911814870163, -0.9221418690808433, -0.9386260894308929, -0.955031748522953, -0.9713473562329499, -0.9875619811144605, -1.0036652092709453, -1.0196471069634498, -1.0354981866265438, -1.0512093759882664, -1.0667719900130268, -1.0821777054090387, -1.0974185374636714, -1.112486818990693, -1.1273751811927013, -1.1420765362599972, -1.1565840615436815, -1.1708911851559924, -1.1849915728647764, -1.198879116161657, -1.2125479213949724, -1.2259922998689867, -1.2392067588203246, -1.2521859931911141, -1.2649248781260445, -1.2774184621274913, -1.2896619608091484, -1.3016507511942574, -1.313380366509639, -1.3248464914313107, -1.3360449577416431, -1.3469717403617325, -1.3576229537260376, -1.367994848469389, -1.3780838083991998, -1.3878863477282173, -1.3973991085453712, -1.4066188585043178, -1.4155424887111128, -1.4241670117941065, -1.4324895601406498, -1.4405073842865947, -1.448217851445782, -1.4556184441678641, -1.4627067591138159, -1.469480505939443, -1.475937506278029, -1.482075692814069, -1.487893108440714, -1.4933879054942467, -1.498558345059472, -1.5034027963404795, -1.5079197360917376, -1.512107748104937, -1.5159655227474638, -1.5194918565487436, -1.5226856518311245, -1.5255459163822636, -1.5280717631663596, -1.5302624100718443, -1.5321171796934685, -1.5336354991469672, -1.53481689991478, -1.5356610177215408, -1.5361675924382947], [-1.5090059190266547, -1.5088427463803, -1.5083532804485538, -1.5075376772693572, -1.5063961969593629, -1.5049292037944746, -1.503137166323448, -1.5010206575153895, -1.498580354942253, -1.495817040997694, -1.492731603153898, -1.489325034258287, -1.4855984328722993, -1.4815530036547362, -1.477190057792502, -1.472511013481901, -1.4675173964640205, -1.4622108406181178, -1.4565930886173504, -1.4506659926516299, -1.4444315152228688, -1.437891730018406, -1.431048822868965, -1.4239050927981034, -1.416462953170782, -1.4087249329493972, -1.4006936780664123, -1.3923719529235725, -1.3837626420286313, -1.3748687517815328, -1.3656934124231115, -1.3562398801606066, -1.3465115394856173, -1.3365119057016013, -1.3262446276796418, -1.3157134908629753, -1.304922420542721, -1.293875485429402, -1.282576901547195, -1.2710310364804511, -1.2592424140048546, -1.2472157191387514, -1.2349558036536017, -1.2224676920863091, -1.209756588300356, -1.1968278826472303, -1.1836871597846685, -1.1703402072137483, -1.156793024602887, -1.143051833973412, -1.1291230908285674, -1.1150134963156568, -1.100730010519538, -1.0862798669948859, -1.071670588654556, -1.0569100051419833, -1.04200627182684, -1.0269678905750683, -1.0118037324567921, -0.9965230625683533, -0.9811355671575307, -0.9656513832535784, -0.9500811310155326, -0.9344359490226818, -0.9187275327392521, -0.9029681763900926, -0.8871708184839531, -0.8713490912138561, -0.8555173739476007, -0.8396908509924337, -0.823885573772395, -0.8081185274898994, -0.7924077022486695, -0.7767721684858871, -0.7612321563886563, -0.7458091387433604, -0.7305259163746648, -0.7154067049609159, -0.7004772215511027, -0.6857647685421571, -0.6712983121928764, -0.6571085519450319, -0.6432279758937656, -0.6296908967108367, -0.616533461206436, -0.6037936255739987, -0.591511087286482, -0.5797271637307646, -0.5684846071530535, -0.5578273455610624, -0.5478001401422652, -0.5384481517787275, -0.5298164126084026, -0.5219492034570852, -0.5148893443453678, -0.5086774129302872, -0.5033509141492295, -0.498943432660162, -0.4954838068208166, -0.49299536769469166, -0.4914952877738419, -0.49099408097334535, -0.4914952877738429, -0.49299536769469365, -0.4954838068208196, -0.49894343266016605, -0.5033509141492345, -0.5086774129302932, -0.5148893443453747, -0.5219492034570928, -0.5298164126084112, -0.5384481517787368, -0.5478001401422752, -0.557827345561073, -0.5684846071530648, -0.5797271637307764, -0.5915110872864945, -0.6037936255740117, -0.6165334612064495, -0.6296908967108504, -0.6432279758937798, -0.6571085519450464, -0.6712983121928912, -0.6857647685421722, -0.7004772215511179, -0.7154067049609313, -0.7305259163746803, -0.7458091387433762, -0.761232156388672, -0.7767721684859034, -0.7924077022486855, -0.8081185274899155, -0.8238855737724111, -0.83969085099245, -0.8555173739476168, -0.8713490912138722, -0.8871708184839694, -0.9029681763901088, -0.9187275327392683, -0.9344359490226979, -0.9500811310155488, -0.9656513832535946, -0.9811355671575466, -0.996523062568369, -1.0118037324568079, -1.0269678905750839, -1.0420062718268552, -1.0569100051419984, -1.0716705886545712, -1.0862798669949008, -1.1007300105195525, -1.1150134963156715, -1.1291230908285816, -1.1430518339734261, -1.1567930246029008, -1.1703402072137623, -1.183687159784682, -1.1968278826472434, -1.2097565883003694, -1.222467692086322, -1.2349558036536141, -1.247215719138764, -1.2592424140048668, -1.2710310364804631, -1.2825769015472068, -1.2938754854294132, -1.3049224205427323, -1.3157134908629862, -1.3262446276796525, -1.3365119057016117, -1.3465115394856277, -1.3562398801606166, -1.3656934124231208, -1.3748687517815419, -1.3837626420286404, -1.392371952923581, -1.4006936780664208, -1.4087249329494054, -1.4164629531707897, -1.423905092798111, -1.4310488228689722, -1.4378917300184124, -1.4444315152228755, -1.450665992651636, -1.4565930886173561, -1.4622108406181233, -1.4675173964640256, -1.472511013481906, -1.4771900577925063, -1.4815530036547406, -1.4855984328723033, -1.4893250342582907, -1.492731603153901, -1.4958170409976972, -1.4985803549422558, -1.501020657515392, -1.5031371663234503, -1.5049292037944766, -1.506396196959364, -1.507537677269358, -1.5083532804485544, -1.5088427463803005], [-1.4821503751016516, -1.481993011139136, -1.4815209712584887, -1.4807344114987728, -1.4796335919864443, -1.4782188770278082, -1.476490735239338, -1.474449739716725, -1.4720965682438063, -1.4694320035427793, -1.4664569335673832, -1.4631723518410227, -1.4595793578421103, -1.4556791574392072, -1.451473063378888, -1.4469624958295986, -1.4421489829851417, -1.4370341617318392, -1.4316197783838198, -1.4259076894913512, -1.4198998627276134, -1.4135983778598316, -1.4070054278112574, -1.4001233198210825, -1.39295447671004, -1.3855014382601505, -1.3777668627178459, -1.3697535284305438, -1.3614643356276495, -1.3529023083579597, -1.34407059659652, -1.3349724785351544, -1.3256113630721758, -1.3159907925181746, -1.306114445536307, -1.2959861403371655, -1.2856098381501244, -1.2749896469950346, -1.2641298257802909, -1.2530347887556574, -1.2417091103507973, -1.230157530433251, -1.218384960022648, -1.2063964875012538, -1.1941973853645618, -1.1817931175595175, -1.1691893474622275, -1.1563919465515493, -1.143407003839894, -1.130240836127866, -1.1168999991550141, -1.103391299725007, -1.0897218088899083, -1.0758988762849357, -1.0619301457120565, -1.0478235720779343, -1.0335874397990081, -1.0192303827936824, -1.0047614061885282, -0.9901899098717999, -0.975525714033042, -0.9607790868316937, -0.9459607743397068, -0.9310820329025815, -0.9161546640588526, -0.9011910521487236, -0.8862042047267039, -0.8712077958688722, -0.8562162124304236, -0.8412446032606936, -0.826308931317471, -0.8114260285361748, -0.7966136531977208, -0.7818905493963192, -0.7672765080291395, -0.7527924285073141, -0.7384603801155283, -0.7243036616190581, -0.7103468573271142, -0.6966158873661853, -0.6831380493965847, -0.6699420484246552, -0.6570580107347863, -0.6445174773127422, -0.6323533714917547, -0.6205999349792433, -0.6092926259884482, -0.5984679730000816, -0.5881633778283045, -0.5784168622909727, -0.5692667540172464, -0.5607513088825292, -0.5529082703175774, -0.5457743693012078, -0.5393847731171185, -0.5337724957074154, -0.5289677873178764, -0.5249975256004719, -0.5218846338269671, -0.5196475537733528, -0.5182998006521728, -0.5178496248983484, -0.5182998006521738, -0.5196475537733547, -0.5218846338269699, -0.5249975256004754, -0.528967787317881, -0.5337724957074207, -0.5393847731171246, -0.5457743693012148, -0.5529082703175852, -0.5607513088825377, -0.5692667540172555, -0.5784168622909824, -0.588163377828315, -0.5984679730000925, -0.6092926259884596, -0.6205999349792553, -0.6323533714917671, -0.6445174773127549, -0.6570580107347994, -0.6699420484246686, -0.6831380493965983, -0.6966158873661994, -0.7103468573271284, -0.7243036616190726, -0.7384603801155429, -0.7527924285073289, -0.7672765080291543, -0.7818905493963343, -0.796613653197736, -0.8114260285361901, -0.8263089313174862, -0.841244603260709, -0.856216212430439, -0.8712077958688875, -0.8862042047267195, -0.901191052148739, -0.9161546640588683, -0.9310820329025968, -0.9459607743397221, -0.960779086831709, -0.9755257140330572, -0.9901899098718149, -1.0047614061885433, -1.019230382793697, -1.0335874397990228, -1.0478235720779487, -1.0619301457120711, -1.07589887628495, -1.0897218088899223, -1.103391299725021, -1.116899999155028, -1.1302408361278795, -1.1434070038399073, -1.1563919465515624, -1.1691893474622406, -1.1817931175595302, -1.1941973853645742, -1.2063964875012663, -1.2183849600226597, -1.2301575304332633, -1.241709110350809, -1.2530347887556688, -1.264129825780302, -1.274989646995046, -1.285609838150135, -1.2959861403371757, -1.3061144455363172, -1.3159907925181848, -1.3256113630721857, -1.3349724785351638, -1.3440705965965292, -1.3529023083579685, -1.3614643356276581, -1.3697535284305522, -1.3777668627178543, -1.385501438260158, -1.3929544767100472, -1.4001233198210896, -1.4070054278112643, -1.4135983778598382, -1.4198998627276194, -1.4259076894913572, -1.4316197783838254, -1.4370341617318445, -1.4421489829851468, -1.4469624958296032, -1.4514730633788924, -1.4556791574392112, -1.4595793578421141, -1.463172351841026, -1.4664569335673863, -1.4694320035427826, -1.4720965682438087, -1.474449739716727, -1.4764907352393402, -1.47821887702781, -1.4796335919864454, -1.480734411498774, -1.4815209712584896, -1.4819930111391364], [-1.45579581724395, -1.4556443619541495, -1.4551900480810867, -1.45443303163431, -1.4533735726982997, -1.452012035535762, -1.4503488887331337, -1.4483847053891974, -1.4461201633479634, -1.443556045477271, -1.4406932399948111, -1.437532740843593, -1.4340756481191597, -1.4303231685511897, -1.4262766160424432, -1.4219374122683752, -1.4173070873410964, -1.4123872805417634, -1.407179741125906, -1.4016863292066277, -1.3959090167211112, -1.389849888486367, -1.3835111433507021, -1.3768950954479997, -1.3700041755625043, -1.3628409326125228, -1.3554080352621662, -1.3477082736710708, -1.339744561392887, -1.3315199374342646, -1.3230375684870699, -1.314300751347654, -1.3053129155381842, -1.2960776261463225, -1.2865985869009149, -1.2768796435028686, -1.2669247872319993, -1.256738158852394, -1.2463240528407271, -1.235686921964014, -1.2248313822354915, -1.2137622182796919, -1.2024843891403363, -1.191003034567402, -1.1793234818226717, -1.1674512530461763, -1.1553920732292988, -1.1431518788438026, -1.1307368271797673, -1.118153306449296, -1.1054079467168643, -1.0925076317213311, -1.079459511658799, -1.0662710169997023, -1.0529498734175478, -1.0395041179105777, -1.0259421162010356, -1.0122725814995668, -0.9985045947242235, -0.9846476262643091, -0.9707115593784323, -0.9567067153131319, -0.9426438802226678, -0.9285343339612226, -0.9143898808049234, -0.9002228821415842, -0.8860462911395399, -0.8718736893717557, -0.8577193253256344, -0.843598154670429, -0.8295258820803249, -0.8155190043193172, -0.8015948541808392, -0.7877716447374393, -0.7740685131903322, -0.7605055634121977, -0.7471039060465281, -0.7338856947614208, -0.7208741569548701, -0.7080936168746219, -0.6955695087542187, -0.683328377188341, -0.6713978615913233, -0.6598066612265905, -0.6485844769943199, -0.6377619259620723, -0.6273704245704208, -0.617442036603171, -0.6080092824454578, -0.5991049069284672, -0.590761604233775, -0.5830116999404128, -0.5758867923474024, -0.5694173576495684, -0.5636323262808878, -0.5585586405962413, -0.5542208068030755, -0.5506404563926804, -0.5478359339484672, -0.5458219288375323, -0.5446091677021763, -0.54420418275605, -0.544609167702177, -0.5458219288375339, -0.5478359339484697, -0.5506404563926838, -0.5542208068030795, -0.5585586405962462, -0.5636323262808934, -0.5694173576495747, -0.5758867923474095, -0.5830116999404206, -0.5907616042337833, -0.5991049069284761, -0.6080092824454671, -0.6174420366031809, -0.6273704245704312, -0.6377619259620833, -0.6485844769943312, -0.6598066612266021, -0.6713978615913354, -0.6833283771883536, -0.6955695087542314, -0.7080936168746349, -0.7208741569548833, -0.7338856947614343, -0.7471039060465418, -0.7605055634122115, -0.7740685131903462, -0.7877716447374534, -0.8015948541808533, -0.8155190043193317, -0.8295258820803394, -0.8435981546704435, -0.857719325325649, -0.8718736893717701, -0.8860462911395547, -0.9002228821415987, -0.914389880804938, -0.9285343339612371, -0.9426438802226823, -0.9567067153131465, -0.9707115593784468, -0.9846476262643235, -0.9985045947242376, -1.0122725814995808, -1.0259421162010496, -1.0395041179105915, -1.0529498734175617, -1.0662710169997156, -1.0794595116588126, -1.0925076317213445, -1.1054079467168774, -1.1181533064493088, -1.1307368271797802, -1.1431518788438153, -1.1553920732293115, -1.1674512530461887, -1.1793234818226837, -1.191003034567414, -1.2024843891403478, -1.2137622182797034, -1.2248313822355026, -1.2356869219640252, -1.246324052840738, -1.2567381588524045, -1.2669247872320097, -1.2768796435028786, -1.2865985869009247, -1.296077626146332, -1.3053129155381937, -1.3143007513476628, -1.3230375684870785, -1.3315199374342732, -1.3397445613928953, -1.347708273671079, -1.355408035262174, -1.3628409326125304, -1.3700041755625116, -1.3768950954480066, -1.383511143350709, -1.3898498884863733, -1.3959090167211174, -1.4016863292066333, -1.4071797411259115, -1.4123872805417685, -1.4173070873411011, -1.42193741226838, -1.4262766160424472, -1.4303231685511937, -1.434075648119163, -1.4375327408435963, -1.4406932399948138, -1.4435560454772736, -1.446120163347966, -1.4483847053891996, -1.4503488887331362, -1.4520120355357633, -1.4533735726983008, -1.4544330316343108, -1.4551900480810873, -1.45564436195415], [-1.4299677417861951, -1.4298222884428535, -1.4293859803722586, -1.428658973475123, -1.4276415276608299, -1.4263340069601764, -1.4247368796841076, -1.422850718629348, -1.4206762013320846, -1.4182141103711627, -1.4154653337224943, -1.4124308651666975, -1.409111804752281, -1.4055093593169898, -1.4016248430702711, -1.3974596782401525, -1.3930153957881988, -1.3882936361965823, -1.3832961503317296, -1.3780248003894076, -1.3724815609266103, -1.366668519986056, -1.3605878803196596, -1.3542419607178797, -1.3476331974524525, -1.34076414584066, -1.3336374819399544, -1.3262560043825202, -1.3186226363601248, -1.3107404277704633, -1.302612557537122, -1.2942423361162498, -1.2856332082040887, -1.2767887556606372, -1.2677127006659243, -1.2584089091266801, -1.2488813943525638, -1.2391343210225987, -1.2291720094640446, -1.218998940267627, -1.2086197592648307, -1.1980392828948685, -1.1872625039909386, -1.1762945980174937, -1.1651409297924662, -1.1538070607306656, -1.1422987566469738, -1.130621996160364, -1.1187829797422506, -1.1067881394551184, -1.0946441494297894, -1.0823579371319634, -1.0699366954707665, -1.0573878958038425, -1.0447193018949061, -1.0319389848805036, -1.0190553393027724, -1.0060771002640772, -0.9930133617571765, -0.9798735962207543, -0.9666676753642774, -0.9534058922977399, -0.94009898499032, -0.9267581610666021, -0.9133951239290096, -0.900022100169448, -0.8866518682008329, -0.8732977879988802, -0.8599738317948925, -0.8466946154997624, -0.8334754305663614, -0.8203322759102115, -0.8072818894051397, -0.7943417783499137, -0.781530248162374, -0.7688664283985145, -0.7563702950153421, -0.7440626875993108, -0.7319653200694856, -0.7201007831412811, -0.7084925366103402, -0.6971648892979965, -0.686142964304937, -0.6754526470677649, -0.6651205136285488, -0.6551737365390056, -0.6456399659611873, -0.6365471838298183, -0.6279235294411093, -0.6197970955572519, -0.612195695082782, -0.6051465995800558, -0.5986762523247166, -0.5928099602082236, -0.5875715704911072, -0.5829831400833387, -0.5790646065357186, -0.5758334711109545, -0.5733045050079809, -0.5714894899021989, -0.5703970033454606, -0.570032258213805, -0.5703970033454613, -0.5714894899022005, -0.5733045050079831, -0.5758334711109575, -0.5790646065357221, -0.5829831400833432, -0.5875715704911123, -0.5928099602082293, -0.598676252324723, -0.6051465995800628, -0.6121956950827896, -0.6197970955572599, -0.6279235294411178, -0.6365471838298274, -0.645639965961197, -0.6551737365390157, -0.6651205136285593, -0.6754526470677757, -0.6861429643049483, -0.697164889298008, -0.7084925366103519, -0.7201007831412932, -0.7319653200694977, -0.7440626875993233, -0.7563702950153549, -0.7688664283985275, -0.7815302481623871, -0.7943417783499271, -0.8072818894051528, -0.8203322759102248, -0.833475430566375, -0.8466946154997761, -0.859973831794906, -0.8732977879988938, -0.8866518682008467, -0.9000221001694618, -0.9133951239290234, -0.9267581610666159, -0.9400989849903335, -0.9534058922977536, -0.9666676753642909, -0.979873596220768, -0.9930133617571901, -1.0060771002640907, -1.0190553393027855, -1.031938984880517, -1.0447193018949192, -1.0573878958038554, -1.0699366954707794, -1.0823579371319763, -1.0946441494298018, -1.1067881394551307, -1.1187829797422626, -1.130621996160376, -1.1422987566469858, -1.1538070607306772, -1.1651409297924775, -1.1762945980175052, -1.1872625039909495, -1.1980392828948796, -1.2086197592648413, -1.2189989402676378, -1.2291720094640548, -1.239134321022609, -1.2488813943525738, -1.2584089091266897, -1.2677127006659337, -1.2767887556606465, -1.285633208204098, -1.2942423361162583, -1.3026125575371303, -1.3107404277704713, -1.3186226363601328, -1.326256004382528, -1.3336374819399621, -1.3407641458406676, -1.3476331974524596, -1.3542419607178862, -1.3605878803196663, -1.3666685199860624, -1.372481560926616, -1.3780248003894129, -1.3832961503317345, -1.3882936361965874, -1.3930153957882032, -1.397459678240157, -1.4016248430702751, -1.4055093593169936, -1.4091118047522846, -1.4124308651667006, -1.4154653337224974, -1.4182141103711656, -1.4206762013320868, -1.4228507186293498, -1.4247368796841098, -1.4263340069601775, -1.427641527660831, -1.4286589734751243, -1.4293859803722595, -1.429822288442854], [-1.404691135723312, -1.4045517698690921, -1.404133724185038, -1.403437154330944, -1.4024623198198465, -1.401209584138526, -1.3996794149171004, -1.397872384148585, -1.3957891684595651, -1.3934305494334072, -1.390797413987682, -1.3878907548077806, -1.384711670838974, -1.3812613678394914, -1.3775411589974875, -1.3735524656151208, -1.369296817863288, -1.3647758556109504, -1.3599913293333439, -1.3549451011037956, -1.3496391456742824, -1.3440755516503233, -1.3382565227662893, -1.3321843792677133, -1.325861559407739, -1.319290621065416, -1.312474243494175, -1.3054152292094647, -1.298116506025235, -1.2905811292496947, -1.2828122840515594, -1.2748132880088525, -1.2665875938532034, -1.2581387924235583, -1.2494706158441884, -1.240586940942983, -1.2314917929271014, -1.222189349334257, -1.2126839442791435, -1.2029800730157956, -1.1930823968380362, -1.1829957483415516, -1.1727251370725555, -1.1622757555894856, -1.1516529859656197, -1.1408624067619915, -1.1299098005013923, -1.118801161675639, -1.1075427053195315, -1.0961408761860598, -1.0846023585582976, -1.0729340867340424, -1.0611432562194854, -1.0492373356679265, -1.0372240795986547, -1.0251115419294328, -1.012908090353351, -1.000622421586938, -0.9882635775110435, -0.97584096221884, -0.963364359975938, -0.9508439540856547, -0.9382903466374083, -0.925714579097475, -0.9131281536783002, -0.9005430553944825, -0.8879717746796729, -0.8754273303981215, -0.8629232930365409, -0.8504738078055017, -0.83809361731378, -0.8257980834032365, -0.8136032076452386, -0.8015256499020318, -0.7895827442478967, -0.7777925114260434, -0.7661736668894777, -0.7547456233400222, -0.7435284865431435, -0.7325430430626726, -0.7218107384362742, -0.7113536442091472, -0.701194412171736, -0.6913562141213213, -0.6818626655034284, -0.6727377314046801, -0.6640056135821936, -0.6556906175429852, -0.6478169991442185, -0.6404087907800609, -0.6334896079535425, -0.6270824378909208, -0.6212094128164496, -0.6158915715261906, -0.6111486139236479, -0.6069986541363735, -0.6034579786400925, -0.6005408163910112, -0.598259128229155, -0.5966224227032567, -0.5956376049441885, -0.5953088642766879, -0.5956376049441893, -0.596622422703258, -0.5982591282291571, -0.6005408163910138, -0.603457978640096, -0.6069986541363775, -0.6111486139236526, -0.6158915715261957, -0.6212094128164554, -0.6270824378909271, -0.6334896079535494, -0.6404087907800684, -0.6478169991442264, -0.6556906175429936, -0.6640056135822023, -0.6727377314046894, -0.6818626655034381, -0.6913562141213313, -0.7011944121717463, -0.7113536442091579, -0.7218107384362851, -0.7325430430626838, -0.743528486543155, -0.7547456233400338, -0.7661736668894895, -0.7777925114260554, -0.7895827442479089, -0.8015256499020441, -0.8136032076452512, -0.8257980834032492, -0.8380936173137927, -0.8504738078055146, -0.8629232930365538, -0.8754273303981343, -0.8879717746796859, -0.9005430553944954, -0.9131281536783133, -0.9257145790974879, -0.9382903466374212, -0.9508439540856678, -0.9633643599759509, -0.9758409622188527, -0.9882635775110562, -1.0006224215869506, -1.0129080903533636, -1.0251115419294452, -1.0372240795986671, -1.0492373356679385, -1.0611432562194973, -1.0729340867340544, -1.0846023585583093, -1.0961408761860718, -1.1075427053195432, -1.1188011616756504, -1.1299098005014037, -1.1408624067620023, -1.1516529859656308, -1.1622757555894963, -1.1727251370725662, -1.1829957483415618, -1.1930823968380464, -1.2029800730158053, -1.2126839442791535, -1.2221893493342668, -1.2314917929271108, -1.2405869409429922, -1.2494706158441975, -1.258138792423567, -1.2665875938532123, -1.2748132880088605, -1.2828122840515677, -1.2905811292497025, -1.2981165060252426, -1.305415229209472, -1.312474243494182, -1.319290621065423, -1.3258615594077456, -1.3321843792677195, -1.3382565227662953, -1.3440755516503293, -1.3496391456742882, -1.3549451011038007, -1.3599913293333488, -1.364775855610955, -1.3692968178632925, -1.3735524656151248, -1.3775411589974913, -1.3812613678394952, -1.3847116708389775, -1.3878907548077837, -1.3907974139876849, -1.3934305494334098, -1.3957891684595674, -1.3978723841485872, -1.3996794149171026, -1.401209584138527, -1.4024623198198474, -1.403437154330945, -1.4041337241850385, -1.4045517698690924], [-1.3799904525392033, -1.3798572509059837, -1.379457697741456, -1.37879194827616, -1.377860261311584, -1.3766629993464767, -1.3752006287545278, -1.373473720014278, -1.3714829479923534, -1.3692290922813926, -1.3667130375942782, -1.363935774216565, -1.360898398519269, -1.357602113534467, -1.3540482295964544, -1.3502381650515218, -1.346173447039724, -1.3418557123523582, -1.3372867083692273, -1.3324682940801142, -1.3274024411953107, -1.3220912353504215, -1.316536877411126, -1.3107416848840132, -1.304708093440094, -1.298438658558088, -1.2919360572951413, -1.2852030901931526, -1.2782426833295168, -1.2710578905216863, -1.2636518956956162, -1.2560280154288535, -1.2481897016797268, -1.2401405447148672, -1.2318842762480535, -1.2234247728041987, -1.214766059323124, -1.2059123130186398, -1.1968678675093105, -1.1876372172382046, -1.1782250221997934, -1.1686361129930731, -1.1588754962208336, -1.1489483602558366, -1.138860081395418, -1.1286162304267193, -1.1182225796253027, -1.1076851102103056, -1.0970100202794935, -1.086203733247489, -1.075272906810071, -1.0642244424566205, -1.0530654955514887, -1.0418034860031284, -1.0304461095371598, -1.019001349585965, -1.0074774898027585, -0.9958831272021367, -0.9842271859216803, -0.9725189315899214, -0.9607679862746921, -0.948984343972113, -0.9371783865799401, -0.9253609002792378, -0.913543092224948, -0.9017366074184048, -0.8899535456027362, -0.87820647798493, -0.8665084635456244, -0.8548730646491098, -0.8433143616112221, -0.8318469658216965, -0.8204860309502219, -0.8092472616922738, -0.7981469194326689, -0.7872018241229968, -0.7764293515856808, -0.765847425375188, -0.7554745022496172, -0.7453295502383173, -0.7354320182392706, -0.725801796050836, -0.7164591637442568, -0.7074247293252395, -0.698719353724538, -0.6903640623084886, -0.6823799423196656, -0.674788025952298, -0.6676091591407661, -0.6608638565919467, -0.6545721441171725, -0.6487533899038328, -0.6434261269890796, -0.6386078698294421, -0.6343149284637993, -0.6305622243006994, -0.6273631119792253, -0.6247292120113075, -0.6226702589739831, -0.6211939698546166, -0.6203059367474075, -0.6200095474607966, -0.6203059367474082, -0.6211939698546178, -0.6226702589739849, -0.6247292120113098, -0.6273631119792283, -0.6305622243007031, -0.6343149284638036, -0.6386078698294467, -0.643426126989085, -0.6487533899038386, -0.6545721441171787, -0.6608638565919535, -0.6676091591407732, -0.6747880259523057, -0.6823799423196736, -0.6903640623084971, -0.698719353724547, -0.7074247293252486, -0.7164591637442663, -0.7258017960508458, -0.7354320182392806, -0.7453295502383277, -0.7554745022496278, -0.7658474253751988, -0.7764293515856918, -0.787201824123008, -0.7981469194326802, -0.8092472616922854, -0.8204860309502334, -0.8318469658217083, -0.8433143616112339, -0.8548730646491218, -0.8665084635456364, -0.8782064779849421, -0.8899535456027484, -0.9017366074184167, -0.9135430922249603, -0.9253609002792499, -0.9371783865799521, -0.9489843439721253, -0.9607679862747043, -0.9725189315899334, -0.9842271859216923, -0.9958831272021487, -1.0074774898027703, -1.019001349585977, -1.0304461095371713, -1.0418034860031398, -1.0530654955515002, -1.064224442456632, -1.0752729068100824, -1.0862037332475003, -1.0970100202795046, -1.1076851102103165, -1.1182225796253136, -1.12861623042673, -1.1388600813954282, -1.1489483602558466, -1.1588754962208436, -1.168636112993083, -1.1782250221998032, -1.187637217238214, -1.1968678675093196, -1.2059123130186489, -1.214766059323133, -1.2234247728042071, -1.2318842762480622, -1.2401405447148757, -1.2481897016797352, -1.2560280154288612, -1.263651895695624, -1.2710578905216936, -1.2782426833295246, -1.2852030901931595, -1.2919360572951482, -1.298438658558095, -1.3047080934401, -1.3107416848840192, -1.3165368774111312, -1.3220912353504266, -1.3274024411953163, -1.3324682940801194, -1.337286708369232, -1.3418557123523627, -1.346173447039728, -1.3502381650515265, -1.3540482295964582, -1.3576021135344705, -1.360898398519272, -1.363935774216568, -1.3667130375942806, -1.369229092281395, -1.3714829479923556, -1.3734737200142801, -1.3752006287545298, -1.3766629993464778, -1.3778602613115853, -1.3787919482761606, -1.3794576977414563, -1.3798572509059837], [-1.355889588549581, -1.3557626179184155, -1.3553817575342837, -1.35474716195115, -1.3538590888452955, -1.3527178991452278, -1.3513240572143543, -1.3496781310872166, -1.3477807927603285, -1.3456328185388877, -1.3432350894408813, -1.3405885916603473, -1.3376944170918232, -1.3345537639182543, -1.3311679372649277, -1.3275383499222644, -1.3236665231405953, -1.319554087500354, -1.3152027838614302, -1.3106144643957467, -1.3057910937074821, -1.3007347500456954, -1.2954476266144923, -1.2899320329862596, -1.284190396623888, -1.2782252645183316, -1.2720393049482914, -1.2656353093692518, -1.2590161944395928, -1.252185004191969, -1.245144912358666, -1.2378992248601544, -1.2304513824666108, -1.2228049636427007, -1.21496368758648, -1.2069314174738324, -1.198712163920402, -1.1903100886735325, -1.1817295085472506, -1.1729748996138347, -1.1640509016659768, -1.1549623229639434, -1.1457141452824986, -1.1363115292725798, -1.1267598201528664, -1.1170645537463397, -1.107231462876756, -1.0972664841395088, -1.0871757650606688, -1.076965671656959, -1.066642796407988, -1.056213966650184, -1.0456862533993858, -1.0350669806059503, -1.0243637348423118, -1.0135843754181335, -1.0027370449123036, -0.9918301801039576, -0.9808725232761798, -0.9698731338559509, -0.9588414003419444, -0.9477870524577743, -0.9367201734519675, -0.9256512124470229, -0.9145909967181922, -0.9035507437577799, -0.8925420729526289, -0.8815770166708256, -0.8706680305183736, -0.8598280024876931, -0.8490702606772895, -0.8384085792161848, -0.827857181978105, -0.8174307436197986, -0.8071443874262957, -0.7970136793949271, -0.7870546179414823, -0.7772836185685081, -0.7677174928005145, -0.7583734206674521, -0.7492689160104907, -0.7404217838976584, -0.7318500694764086, -0.7235719976609922, -0.7156059031597508, -0.707970150495671, -0.7006830438662307, -0.6937627269274507, -0.6872270728715482, -0.6810935654940099, -0.6753791723070105, -0.6701002111406354, -0.6652722120659069, -0.6609097768548425, -0.6570264385402583, -0.6536345239273353, -0.6507450221154975, -0.6483674621902037, -0.6465098032213307, -0.6451783395459396, -0.6443776240148199, -0.6441104114504189, -0.6443776240148205, -0.6451783395459407, -0.6465098032213322, -0.6483674621902058, -0.6507450221155001, -0.6536345239273386, -0.657026438540262, -0.6609097768548469, -0.6652722120659118, -0.6701002111406408, -0.675379172307016, -0.6810935654940159, -0.6872270728715546, -0.6937627269274576, -0.700683043866238, -0.7079701504956788, -0.7156059031597588, -0.7235719976610006, -0.7318500694764174, -0.7404217838976676, -0.7492689160104999, -0.7583734206674615, -0.7677174928005243, -0.777283618568518, -0.7870546179414925, -0.7970136793949374, -0.8071443874263062, -0.8174307436198093, -0.8278571819781158, -0.8384085792161955, -0.8490702606773005, -0.8598280024877043, -0.8706680305183848, -0.8815770166708365, -0.8925420729526403, -0.9035507437577912, -0.9145909967182038, -0.9256512124470342, -0.9367201734519788, -0.9477870524577859, -0.9588414003419556, -0.9698731338559622, -0.980872523276191, -0.991830180103969, -1.002737044912315, -1.0135843754181446, -1.024363734842323, -1.0350669806059611, -1.0456862533993967, -1.0562139666501946, -1.0666427964079988, -1.0769656716569693, -1.0871757650606795, -1.0972664841395188, -1.107231462876766, -1.1170645537463497, -1.1267598201528763, -1.1363115292725898, -1.1457141452825077, -1.1549623229639527, -1.1640509016659861, -1.1729748996138438, -1.1817295085472592, -1.1903100886735414, -1.1987121639204106, -1.2069314174738406, -1.214963687586488, -1.2228049636427087, -1.2304513824666188, -1.2378992248601617, -1.245144912358673, -1.2521850041919764, -1.2590161944395997, -1.2656353093692583, -1.2720393049482979, -1.2782252645183383, -1.284190396623894, -1.2899320329862651, -1.2954476266144976, -1.3007347500457005, -1.3057910937074872, -1.3106144643957511, -1.3152027838614344, -1.3195540875003582, -1.323666523140599, -1.3275383499222684, -1.3311679372649314, -1.3345537639182576, -1.3376944170918261, -1.3405885916603504, -1.3432350894408838, -1.3456328185388902, -1.3477807927603307, -1.3496781310872186, -1.3513240572143561, -1.3527178991452293, -1.3538590888452966, -1.3547471619511506, -1.3553817575342844, -1.3557626179184157], [-1.3324118597838257, -1.3322911757895615, -1.3319291749878472, -1.3313260109480365, -1.3304819397062155, -1.329397319896312, -1.328072612934379, -1.3265083832567899, -1.3247052986132835, -1.3226641304160336, -1.3203857541461166, -1.3178711498189923, -1.3151214025108249, -1.3121377029477264, -1.3089213481602173, -1.305473742205475, -1.3017963969601711, -1.2978909329869686, -1.2937590804780223, -1.289402680279094, -1.284823684998189, -1.280024160202902, -1.2750062857109818, -1.2697723569789177, -1.264324786593683, -1.2586661058730972, -1.2527989665806014, -1.2467261427605878, -1.2404505327007778, -1.233975161028482, -1.227303180947946, -1.2204378766263255, -1.213382665736195, -1.2061411021628259, -1.198716878884803, -1.1911138310368572, -1.1833359391640723, -1.1753873326768745, -1.1672722935164113, -1.15899526004008, -1.1505608311370352, -1.1419737705834938, -1.1332390116475357, -1.1243616619528527, -1.11534700861049, -1.1062005236270342, -1.0969278695968925, -1.087534905685231, -1.0780276939067657, -1.0684125057038536, -1.0586958288251826, -1.0488843745037069, -1.0389850849292717, -1.0290051410075334, -1.018951970392171, -1.0088332557719812, -0.9986569433880427, -0.9884312517487014, -0.9781646805014441, -0.9678660194107394, -0.9575443573794329, -0.9472090914381721, -0.9368699356124631, -0.9265369295601826, -0.9162204468536029, -0.9059312027591039, -0.8956802613447366, -0.8854790417206672, -0.8753393231903372, -0.8652732490611273, -0.8552933288326882, -0.8454124384493811, -0.8356438182710425, -0.8260010683844373, -0.8164981408473518, -0.807149328429661, -0.7979692493925619, -0.7889728278304103, -0.7801752690915554, -0.7715920297977186, -0.7632387819986172, -0.755131371032585, -0.74728576671777, -0.7397180075748733, -0.7324441378836303, -0.725480137503016, -0.7188418445401684, -0.7125448711346667, -0.7066045128308649, -0.7010356522373452, -0.6958526579130437, -0.6910692796658457, -0.6866985416910963, -0.682752635202364, -0.679242812401676, -0.676179283787615, -0.6735711208939892, -0.671426166577881, -0.6697509549250908, -0.6685506427085953, -0.6678289541216008, -0.6675881402161743, -0.6678289541216013, -0.6685506427085963, -0.6697509549250923, -0.6714261665778829, -0.6735711208939915, -0.676179283787618, -0.6792428124016794, -0.6827526352023677, -0.6866985416911007, -0.6910692796658504, -0.695852657913049, -0.7010356522373508, -0.7066045128308708, -0.712544871134673, -0.7188418445401752, -0.7254801375030232, -0.7324441378836377, -0.7397180075748809, -0.747285766717778, -0.7551313710325931, -0.7632387819986255, -0.7715920297977271, -0.7801752690915644, -0.7889728278304194, -0.7979692493925711, -0.8071493284296706, -0.8164981408473615, -0.8260010683844474, -0.8356438182710524, -0.8454124384493911, -0.8552933288326984, -0.8652732490611377, -0.8753393231903478, -0.8854790417206775, -0.895680261344747, -0.9059312027591144, -0.9162204468536136, -0.9265369295601932, -0.9368699356124739, -0.9472090914381829, -0.9575443573794435, -0.9678660194107499, -0.9781646805014546, -0.988431251748712, -0.998656943388053, -1.0088332557719915, -1.0189519703921817, -1.0290051410075436, -1.0389850849292819, -1.0488843745037169, -1.0586958288251929, -1.0684125057038634, -1.0780276939067757, -1.087534905685241, -1.0969278695969022, -1.1062005236270438, -1.1153470086104995, -1.1243616619528618, -1.1332390116475448, -1.1419737705835027, -1.150560831137044, -1.1589952600400886, -1.1672722935164197, -1.175387332676883, -1.1833359391640805, -1.191113831036865, -1.1987168788848106, -1.2061411021628334, -1.2133826657362023, -1.2204378766263326, -1.2273031809479529, -1.2339751610284886, -1.2404505327007842, -1.2467261427605942, -1.2527989665806076, -1.2586661058731035, -1.2643247865936886, -1.2697723569789228, -1.275006285710987, -1.280024160202907, -1.2848236849981938, -1.2894026802790988, -1.2937590804780266, -1.2978909329869728, -1.301796396960175, -1.3054737422054787, -1.3089213481602204, -1.3121377029477295, -1.3151214025108278, -1.3178711498189948, -1.3203857541461193, -1.3226641304160358, -1.3247052986132855, -1.3265083832567917, -1.328072612934381, -1.3293973198963132, -1.3304819397062164, -1.3313260109480372, -1.3319291749878477, -1.3322911757895617], [-1.309579979428233, -1.309465625315556, -1.3091226137073928, -1.3085510968192071, -1.307751328429737, -1.3067236640107667, -1.3054685609094516, -1.303986578583858, -1.3022783788925385, -1.3003447264391872, -1.2981864889735861, -1.2958046378502603, -1.2932002485464555, -1.2903745012412453, -1.2873286814577953, -1.2840641807709967, -1.280582497582915, -1.2768852379686997, -1.2729741165958248, -1.268850957719755, -1.2645176962593543, -1.259976378955585, -1.2552291656172787, -1.250278330457995, -1.2451262635282128, -1.2397754722473464, -1.2342285830402997, -1.2284883430835154, -1.2225576221656926, -1.2164394146685698, -1.2101368416733758, -1.2036531531987473, -1.1969917305760809, -1.1901560889684453, -1.1831498800392928, -1.1759768947773002, -1.1686410664837033, -1.161146473928476, -1.1534973446816226, -1.145698058625694, -1.1377531516553836, -1.1296673195697058, -1.1214454221617514, -1.1130924875103931, -1.104613716477491, -1.096014487413118, -1.0873003610700889, -1.078477085727541, -1.0695506025214767, -1.0605270509780047, -1.0514127747424074, -1.0422143274941253, -1.0329384790341858, -1.0235922215274533, -1.0141827758773025, -1.0047175982047962, -0.9952043863981512, -0.9856510866910997, -0.9760659002206182, -0.9664572895053419, -0.9568339847757064, -0.9472049900754336, -0.9375795890413131, -0.927967350254311, -0.918378132039863, -0.9088220865787727, -0.899309663172536, -0.8898516104882706, -0.8804589775889028, -0.8711431135341889, -0.8619156653178288, -0.8527885738859015, -0.8437740679627159, -0.8348846553926655, -0.8261331116917427, -0.8175324654910634, -0.8090959805483104, -0.8008371340028101, -0.7927695905575168, -0.7849071722881086, -0.7772638238072945, -0.7698535725529236, -0.7626904840229913, -0.7557886118503273, -0.7491619426954249, -0.7428243360377133, -0.7367894590630863, -0.7310707169772979, -0.7256811792185143, -0.7206335021943904, -0.7159398493248735, -0.7116118093258438, -0.7076603138140242, -0.7040955554430021, -0.700926907886073, -0.698162849056417, -0.6958108889920065, -0.6938775038260189, -0.6923680772095285, -0.691286850450299, -0.690636882480591, -0.690420020571767, -0.6906368824805914, -0.6912868504502999, -0.6923680772095298, -0.6938775038260208, -0.6958108889920086, -0.6981628490564197, -0.7009269078860761, -0.7040955554430056, -0.7076603138140282, -0.711611809325848, -0.7159398493248781, -0.7206335021943954, -0.7256811792185196, -0.7310707169773035, -0.7367894590630925, -0.7428243360377198, -0.7491619426954317, -0.7557886118503342, -0.7626904840229988, -0.7698535725529312, -0.7772638238073022, -0.7849071722881166, -0.7927695905575249, -0.8008371340028184, -0.8090959805483191, -0.8175324654910722, -0.8261331116917516, -0.8348846553926746, -0.8437740679627251, -0.8527885738859108, -0.8619156653178383, -0.8711431135341985, -0.8804589775889123, -0.8898516104882804, -0.8993096631725458, -0.9088220865787825, -0.9183781320398728, -0.9279673502543206, -0.937579589041323, -0.9472049900754437, -0.9568339847757162, -0.9664572895053518, -0.9760659002206281, -0.9856510866911095, -0.995204386398161, -1.004717598204806, -1.0141827758773123, -1.0235922215274629, -1.0329384790341953, -1.042214327494135, -1.0514127747424167, -1.0605270509780138, -1.0695506025214858, -1.07847708572755, -1.087300361070098, -1.0960144874131268, -1.1046137164774998, -1.1130924875104018, -1.1214454221617596, -1.1296673195697144, -1.1377531516553918, -1.1456980586257017, -1.1534973446816306, -1.1611464739284838, -1.1686410664837108, -1.1759768947773073, -1.1831498800393, -1.1901560889684524, -1.1969917305760878, -1.203653153198754, -1.2101368416733824, -1.2164394146685762, -1.2225576221656989, -1.2284883430835214, -1.2342285830403057, -1.2397754722473522, -1.2451262635282183, -1.250278330458, -1.2552291656172834, -1.2599763789555896, -1.2645176962593592, -1.2688509577197595, -1.2729741165958288, -1.2768852379687032, -1.2805824975829183, -1.284064180771, -1.2873286814577987, -1.2903745012412486, -1.2932002485464582, -1.2958046378502628, -1.2981864889735883, -1.3003447264391892, -1.3022783788925403, -1.30398657858386, -1.3054685609094532, -1.3067236640107676, -1.3077513284297382, -1.3085510968192076, -1.309122613707393, -1.3094656253155563], [-1.2874160358524733, -1.2873080411921152, -1.2869841073466637, -1.2864443847480778, -1.2856891241999893, -1.284718677003533, -1.283533495134061, -1.282134131469294, -1.2805212400696269, -1.278695576511458, -1.2766579982745783, -1.2744094651848155, -1.2719510399132927, -1.269283888533825, -1.266409281140137, -1.2633285925247635, -1.2600433029216402, -1.2565549988145825, -1.252865373814, -1.2489762296043627, -1.2448894769651089, -1.2406071368678424, -1.2361313416528217, -1.231464336287914, -1.226608479713325, -1.2215662462755685, -1.2163402272542732, -1.2109331324855441, -1.205347792085714, -1.1995871582794106, -1.1936543073359316, -1.1875524416179801, -1.1812848917468182, -1.1748551188878915, -1.1682667171609011, -1.1615234161782129, -1.1546290837153075, -1.1475877285167526, -1.1404035032408633, -1.1330807075458178, -1.125623791319484, -1.1180373580545946, -1.11032616837014, -1.10249514367893, -1.0945493700001865, -1.0864941019147178, -1.078334766658712, -1.0700769683503968, -1.0617264923417407, -1.0532893096849851, -1.044771581701037, -1.0361796646336023, -1.0275201143693582, -1.0187996912003825, -1.0100253646004713, -1.0012043179817953, -0.9923439533925836, -0.9834518961100671, -0.9745359990757997, -0.9656043471126128, -0.9566652608538652, -0.9477273003062868, -0.9387992679576187, -0.9298902113294117, -0.9210094248638566, -0.9121664510214358, -0.9033710804536452, -0.8946333511022175, -0.8859635460633869, -0.8773721900430855, -0.868870044216894, -0.8604680992975104, -0.8521775666030064, -0.8440098669117485, -0.8359766168853296, -0.8280896128398884, -0.8203608116496731, -0.8128023085754985, -0.8054263118257697, -0.7982451136799333, -0.7912710580343942, -0.7845165042698801, -0.7779937873875125, -0.7717151744187756, -0.765692817182178, -0.7599387015362623, -0.7544645933638611, -0.7492819816146772, -0.7444020188303829, -0.7398354596758594, -0.735592598098737, -0.7316832038333559, -0.7281164590505612, -0.724900896027066, -0.7220443367631779, -0.719553835511451, -0.717435625187787, -0.715695068618028, -0.7143366155255092, -0.7133637660881095, -0.7127790417881408, -0.7125839641475267, -0.7127790417881411, -0.7133637660881101, -0.7143366155255104, -0.7156950686180296, -0.7174356251877889, -0.7195538355114535, -0.7220443367631808, -0.7249008960270692, -0.7281164590505648, -0.7316832038333599, -0.7355925980987412, -0.7398354596758637, -0.7444020188303876, -0.7492819816146824, -0.7544645933638666, -0.7599387015362681, -0.7656928171821841, -0.771715174418782, -0.777993787387519, -0.784516504269887, -0.7912710580344013, -0.7982451136799407, -0.8054263118257771, -0.8128023085755062, -0.8203608116496809, -0.8280896128398965, -0.8359766168853379, -0.8440098669117568, -0.8521775666030146, -0.8604680992975189, -0.8688700442169026, -0.8773721900430944, -0.8859635460633957, -0.8946333511022265, -0.9033710804536543, -0.9121664510214449, -0.9210094248638658, -0.929890211329421, -0.9387992679576281, -0.9477273003062961, -0.9566652608538743, -0.965604347112622, -0.9745359990758089, -0.9834518961100764, -0.9923439533925928, -1.0012043179818044, -1.0100253646004804, -1.0187996912003918, -1.027520114369367, -1.0361796646336112, -1.044771581701046, -1.0532893096849938, -1.061726492341749, -1.0700769683504052, -1.0783347666587206, -1.086494101914726, -1.0945493700001947, -1.1024951436789379, -1.1103261683701477, -1.1180373580546026, -1.1256237913194915, -1.1330807075458253, -1.1404035032408706, -1.14758772851676, -1.1546290837153146, -1.1615234161782197, -1.168266717160908, -1.174855118887898, -1.181284891746825, -1.1875524416179863, -1.1936543073359378, -1.1995871582794166, -1.20534779208572, -1.2109331324855497, -1.216340227254279, -1.221566246275574, -1.2266084797133299, -1.2314643362879187, -1.2361313416528263, -1.2406071368678468, -1.244889476965113, -1.2489762296043665, -1.2528653738140039, -1.256554998814586, -1.2600433029216436, -1.2633285925247666, -1.2664092811401402, -1.2692838885338278, -1.2719510399132954, -1.274409465184818, -1.2766579982745807, -1.2786955765114603, -1.2805212400696289, -1.2821341314692953, -1.2835334951340622, -1.2847186770035341, -1.28568912419999, -1.2864443847480784, -1.2869841073466641, -1.2873080411921154], [-1.2659414712405206, -1.2658398506164779, -1.265535038123436, -1.2650271819224537, -1.264316529028012, -1.2634034254273159, -1.2622883162477652, -1.2609717459730423, -1.2594543587083935, -1.257736898495813, -1.255820209679953, -1.2537052373257243, -1.2513930276886733, -1.248884728739339, -1.2461815907429272, -1.243284966895766, -1.2401963140200998, -1.236917193318941, -1.2334492711927678, -1.2297943201199981, -1.225954219603263, -1.2219309571836008, -1.21772662952479, -1.2133434435701187, -1.2087837177739684, -1.2040498834106301, -1.1991444859628437, -1.1940701865925574, -1.1888297636964187, -1.1834261145484946, -1.1778622570326678, -1.1721413314670848, -1.1662666025229123, -1.1602414612395107, -1.154069427137915, -1.1477541504342637, -1.141299414354484, -1.1347091375511447, -1.1279873766229087, -1.1211383287364345, -1.1141663343499086, -1.1070758800365808, -1.0998716014057417, -1.092558286117507, -1.0851408769865198, -1.077624475168244, -1.0700143434198919, -1.062315909426157, -1.0545347691778082, -1.0466766903888196, -1.0387476159350146, -1.0307536672942086, -1.0227011479644696, -1.0145965468333922, -1.0064465414671633, -0.9982580012836534, -0.990037990568798, -0.9817937712901134, -0.9735328056553169, -0.9652627583576955, -0.9569914984430987, -0.948727100726244, -0.9404778466764712, -0.9322522246852005, -0.9240589296192502, -0.9159068615559388, -0.907805123587689, -0.8997630185758373, -0.8917900447257432, -0.8838958898483472, -0.8760904241673392, -0.8683836915264173, -0.8607858988481352, -0.8533074036949734, -0.8459586997850157, -0.8387504003194551, -0.8316932189876188, -0.8247979485278092, -0.8180754367395137, -0.8115365598648874, -0.8051921932852487, -0.799053179511911, -0.7931302934901251, -0.7874342052801432, -0.7819754402301483, -0.776764336811429, -0.7718110023458694, -0.7671252669183622, -0.7627166358306408, -0.7585942410164456, -0.7547667918987904, -0.7512425262260796, -0.7480291614725159, -0.7451338474271396, -0.7425631206226448, -0.7403228612676532, -0.7384182533426896, -0.7368537484994595, -0.7356330343646077, -0.7347590077930711, -0.7342337535433784, -0.7340585287594793, -0.7342337535433787, -0.7347590077930719, -0.7356330343646088, -0.736853748499461, -0.7384182533426914, -0.7403228612676555, -0.7425631206226474, -0.7451338474271426, -0.7480291614725192, -0.751242526226083, -0.754766791898794, -0.7585942410164497, -0.7627166358306453, -0.7671252669183669, -0.7718110023458745, -0.7767643368114343, -0.7819754402301539, -0.787434205280149, -0.7931302934901312, -0.7990531795119173, -0.805192193285255, -0.811536559864894, -0.8180754367395204, -0.8247979485278162, -0.8316932189876259, -0.8387504003194626, -0.8459586997850232, -0.8533074036949809, -0.8607858988481429, -0.8683836915264251, -0.8760904241673472, -0.8838958898483553, -0.8917900447257513, -0.8997630185758454, -0.9078051235876973, -0.9159068615559471, -0.9240589296192587, -0.9322522246852087, -0.9404778466764797, -0.9487271007262527, -0.9569914984431073, -0.965262758357704, -0.9735328056553254, -0.981793771290122, -0.9900379905688065, -0.9982580012836618, -1.0064465414671715, -1.0145965468334004, -1.022701147964478, -1.030753667294217, -1.0387476159350226, -1.0466766903888276, -1.0545347691778162, -1.062315909426165, -1.0700143434198999, -1.0776244751682518, -1.0851408769865276, -1.0925582861175145, -1.099871601405749, -1.107075880036588, -1.1141663343499157, -1.1211383287364416, -1.1279873766229158, -1.134709137551152, -1.1412994143544906, -1.14775415043427, -1.1540694271379215, -1.160241461239517, -1.1662666025229185, -1.1721413314670908, -1.1778622570326738, -1.1834261145485, -1.1888297636964242, -1.1940701865925627, -1.1991444859628488, -1.204049883410635, -1.208783717773973, -1.2133434435701234, -1.2177266295247937, -1.221930957183605, -1.2259542196032671, -1.229794320120002, -1.2334492711927711, -1.2369171933189445, -1.2401963140201029, -1.243284966895769, -1.2461815907429303, -1.2488847287393414, -1.2513930276886756, -1.2537052373257263, -1.255820209679955, -1.257736898495815, -1.2594543587083953, -1.260971745973044, -1.2622883162477667, -1.263403425427317, -1.264316529028013, -1.2650271819224541, -1.2655350381234363, -1.2658398506164779], [-1.2451770608467245, -1.2450818125276055, -1.2447961160127106, -1.244320116651435, -1.2436540567661911, -1.2427982757627, -1.241753210284753, -1.2405193944137598, -1.2390974599135294, -1.237488136520812, -1.235692252282218, -1.2337107339382274, -1.2315446073550913, -1.229194998005514, -1.2266631314990828, -1.2239503341634996, -1.2210580336777388, -1.2179877597583244, -1.214741144899996, -1.211319925172068, -1.2077259410718642, -1.2039611384366198, -1.2000275694153035, -1.1959273935017962, -1.1916628786308934, -1.1872364023385669, -1.182650452987893, -1.1779076310619996, -1.1730106505253064, -1.1679623402542214, -1.16276564553832, -1.1574236296528548, -1.1519394755032355, -1.1463164873418408, -1.140558092557232, -1.1346678435354478, -1.1286494195926324, -1.1225066289777434, -1.1162434109434896, -1.1098638378829746, -1.1033721175287485, -1.0967725952100735, -1.0900697561632102, -1.0832682278883854, -1.076372782545821, -1.0693883393817523, -1.062319967173754, -1.0551728866828898, -1.0479524730981855, -1.0406642584567303, -1.0333139340202377, -1.025907352586231, -1.0184505307090634, -1.0109496508027813, -1.0034110630943662, -0.9958412873921342, -0.9882470146300507, -0.980635108144429, -0.9730126046349176, -0.965386714756915, -0.9577648232875485, -0.9501544888022131, -0.9425634427933982, -0.9349995881582586, -0.9274709969761274, -0.9199859074921113, -0.9125527202181178, -0.90517999305833, -0.8978764353624242, -0.8906509008069328, -0.8835123790033058, -0.8764699857306724, -0.8695329516923168, -0.8627106096977527, -0.8560123801772841, -0.8494477549434116, -0.8430262791236387, -0.8367575312024411, -0.8306511011266232, -0.8247165664481769, -0.8189634665021817, -0.8134012746442881, -0.8080393686027976, -0.8028869990340609, -0.7979532564065213, -0.793247036377652, -0.7887770038686034, -0.784551556082669, -0.7805787847546832, -0.7768664379579464, -0.7734218818319499, -0.7702520626266272, -0.7673634694856949, -0.7647620984114698, -0.7624534178651139, -0.7604423364584489, -0.7587331731854986, -0.7573296306231999, -0.7562347715011751, -0.755450999000297, -0.754980041089729, -0.7548229391532756, -0.7549800410897294, -0.7554509990002977, -0.7562347715011761, -0.7573296306232012, -0.7587331731855003, -0.7604423364584509, -0.7624534178651161, -0.7647620984114725, -0.7673634694856977, -0.7702520626266304, -0.7734218818319532, -0.7768664379579501, -0.7805787847546872, -0.7845515560826734, -0.7887770038686079, -0.7932470363776569, -0.7979532564065264, -0.8028869990340661, -0.8080393686028031, -0.8134012746442937, -0.8189634665021874, -0.824716566448183, -0.8306511011266294, -0.8367575312024473, -0.8430262791236454, -0.8494477549434184, -0.856012380177291, -0.8627106096977597, -0.8695329516923239, -0.8764699857306795, -0.8835123790033131, -0.8906509008069403, -0.8978764353624317, -0.9051799930583375, -0.9125527202181255, -0.919985907492119, -0.9274709969761352, -0.9349995881582662, -0.942563442793406, -0.9501544888022209, -0.9577648232875564, -0.9653867147569226, -0.9730126046349254, -0.9806351081444368, -0.9882470146300586, -0.995841287392142, -1.0034110630943742, -1.010949650802789, -1.0184505307090708, -1.0259073525862386, -1.033313934020245, -1.0406642584567378, -1.047952473098193, -1.055172886682897, -1.0623199671737615, -1.0693883393817591, -1.0763727825458282, -1.0832682278883925, -1.0900697561632169, -1.0967725952100804, -1.1033721175287552, -1.1098638378829813, -1.116243410943496, -1.12250662897775, -1.1286494195926386, -1.1346678435354538, -1.140558092557238, -1.1463164873418465, -1.1519394755032413, -1.1574236296528606, -1.1627656455383253, -1.1679623402542265, -1.1730106505253115, -1.1779076310620045, -1.182650452987898, -1.1872364023385718, -1.1916628786308978, -1.1959273935018004, -1.200027569415308, -1.203961138436624, -1.207725941071868, -1.2113199251720717, -1.2147411448999992, -1.2179877597583275, -1.2210580336777417, -1.2239503341635025, -1.2266631314990852, -1.2291949980055168, -1.2315446073550937, -1.2337107339382296, -1.2356922522822202, -1.237488136520814, -1.239097459913531, -1.2405193944137611, -1.2417532102847546, -1.2427982757627012, -1.2436540567661913, -1.2443201166514357, -1.2447961160127112, -1.245081812527606], [-1.2251428928970922, -1.225053997507049, -1.2247873586470075, -1.2243431182670026, -1.2237215130163663, -1.2229228743427496, -1.2219476286309885, -1.220796297382034, -1.2194694974322358, -1.217967941213342, -1.2162924370536101, -1.2144438895205083, -1.2124232998055195, -1.2102317661516155, -1.2078704843240216, -1.2053407481249134, -1.2026439499527424, -1.1997815814068906, -1.1967552339383987, -1.193566599547493, -1.1902174715286642, -1.186709745264018, -1.183045419065601, -1.1792265950673648, -1.1752554801673747, -1.1711343870207915, -1.1668657350840566, -1.162452051710598, -1.157895973298218, -1.153200246488155, -1.1483677294155963, -1.1434013930111755, -1.138304322352704, -1.1330797180660481, -1.1277308977736822, -1.1222612975890194, -1.1166744736541139, -1.1109741037177694, -1.1051639887504465, -1.0992480545916565, -1.0932303536247088, -1.0871150664727924, -1.0809065037093724, -1.0746091075747577, -1.0682274536894918, -1.0617662527538367, -1.055230352221151, -1.0486247379313218, -1.0419545356886326, -1.0352250127665066, -1.02844157931948, -1.0216097896804772, -1.014735343519049, -1.0078240868336212, -1.000882012748057, -0.9939152620799024, -0.9869301236446334, -0.9799330342570356, -0.9729305783875428, -0.9659294874279991, -0.9589366385178907, -0.9519590528787097, -0.9450038936007588, -0.9380784628235205, -0.931190198247724, -0.9243466689145604, -0.9175555701852325, -0.9108247178522889, -0.9041620413131162, -0.897575575735708, -0.8910734531475175, -0.8846638923800413, -0.8783551878049083, -0.8721556968018439, -0.8660738259051354, -0.8601180155832581, -0.8542967236163163, -0.8486184070480038, -0.8430915027029794, -0.8377244062769299, -0.8325254500251315, -0.8275028790959291, -0.8226648265780991, -0.8180192873552482, -0.8135740908859623, -0.8093368730548521, -0.8053150472664805, -0.801515774980751, -0.7979459359140076, -0.7946120981540841, -0.7915204884590417, -0.7886769630275319, -0.7860869790428248, -0.783755567301765, -0.7816873062436527, -0.7798862976916859, -0.7783561446108136, -0.7770999311704241, -0.7761202053782482, -0.775418964523456, -0.7749976436326381, -0.7748571071029079, -0.7749976436326386, -0.7754189645234567, -0.7761202053782491, -0.7770999311704252, -0.7783561446108151, -0.7798862976916876, -0.7816873062436547, -0.7837555673017671, -0.7860869790428273, -0.7886769630275348, -0.7915204884590445, -0.7946120981540874, -0.7979459359140111, -0.8015157749807548, -0.8053150472664845, -0.8093368730548564, -0.8135740908859669, -0.8180192873552529, -0.822664826578104, -0.8275028790959343, -0.8325254500251367, -0.8377244062769353, -0.8430915027029849, -0.8486184070480096, -0.8542967236163223, -0.8601180155832642, -0.8660738259051417, -0.8721556968018502, -0.8783551878049147, -0.884663892380048, -0.8910734531475242, -0.8975755757357148, -0.9041620413131229, -0.9108247178522958, -0.9175555701852397, -0.9243466689145673, -0.9311901982477311, -0.9380784628235276, -0.9450038936007662, -0.9519590528787172, -0.9589366385178979, -0.9659294874280062, -0.97293057838755, -0.9799330342570427, -0.9869301236446405, -0.9939152620799095, -1.0008820127480642, -1.0078240868336281, -1.0147353435190558, -1.0216097896804843, -1.028441579319487, -1.0352250127665137, -1.0419545356886393, -1.048624737931329, -1.055230352221158, -1.0617662527538434, -1.0682274536894985, -1.0746091075747641, -1.0809065037093786, -1.0871150664727989, -1.0932303536247148, -1.0992480545916627, -1.1051639887504525, -1.1109741037177754, -1.1166744736541196, -1.122261297589025, -1.1277308977736877, -1.1330797180660537, -1.1383043223527096, -1.1434013930111804, -1.148367729415601, -1.1532002464881599, -1.1578959732982228, -1.1624520517106025, -1.1668657350840612, -1.171134387020796, -1.175255480167379, -1.1792265950673686, -1.1830454190656048, -1.1867097452640218, -1.190217471528668, -1.1935665995474962, -1.1967552339384018, -1.1997815814068935, -1.202643949952745, -1.205340748124916, -1.207870484324024, -1.210231766151618, -1.2124232998055215, -1.2144438895205103, -1.216292437053612, -1.2179679412133437, -1.2194694974322373, -1.220796297382035, -1.22194762863099, -1.2229228743427505, -1.2237215130163668, -1.2243431182670033, -1.224787358647008, -1.2250539975070494], [-1.205858349155229, -1.2057757683623092, -1.2055280719527088, -1.2051153978510445, -1.2045379759888288, -1.20379612839026, -1.2028902692924501, -1.201820905300214, -1.2005886355755675, -1.1991941520621279, -1.197638239744611, -1.1959217769436696, -1.1940457356463163, -1.192011181872204, -1.1898192760760329, -1.1874712735863688, -1.1849685250811421, -1.1823124771000924, -1.1795046725944038, -1.1765467515137338, -1.1734404514308119, -1.1701876082037161, -1.1667901566758738, -1.163250131413743, -1.1595696674820328, -1.155751001256198, -1.1517964712717923, -1.147708519110113, -1.1434896903193588, -1.139142635370315, -1.1346701106453152, -1.1300749794589506, -1.1253602131086593, -1.1205288919529752, -1.1155842065147876, -1.1105294586065149, -1.1053680624735671, -1.1001035459519155, -1.094739551634934, -1.0892798380439976, -1.0837282807965325, -1.0780888737643792, -1.0723657302143945, -1.0665630839222047, -1.0606852902489303, -1.0547368271694944, -1.0487222962398433, -1.0426464234890163, -1.036514060220505, -1.0303301837057535, -1.0240998977509495, -1.0178284331164662, -1.0115211477664194, -1.0051835269238296, -0.9988211829048225, -0.9924398547031736, -0.9860454072943364, -0.9796438306258906, -0.973241238259139, -0.9668438656244216, -0.9604580678505846, -0.9540903171270622, -0.9477471995551706, -0.9414354114435944, -0.9351617550016939, -0.9289331333832693, -0.9227565450328423, -0.9166390772864741, -0.910587899179681, -0.9046102534162764, -0.8987134474540144, -0.8929048436658719, -0.8871918485397625, -0.8815819008845202, -0.8760824590162154, -0.8707009869063399, -0.8654449392821726, -0.8603217456797402, -0.855338793461245, -0.8505034098215704, -0.8458228428224758, -0.841304241508196, -0.8369546351722469, -0.8327809118620558, -0.8287897962253592, -0.8249878268197974, -0.8213813330244342, -0.8179764117086352, -0.8147789038294142, -0.8117943711425187, -0.8090280732247344, -0.8064849450146354, -0.8041695750858923, -0.8020861848708204, -0.8002386090518285, -0.7986302773344918, -0.7972641978080114, -0.7961429420867635, -0.7952686324105528, -0.7946429308612872, -0.7942670308303844, -0.794141650844771, -0.7942670308303846, -0.7946429308612877, -0.7952686324105535, -0.7961429420867644, -0.7972641978080127, -0.7986302773344933, -0.8002386090518302, -0.8020861848708224, -0.8041695750858946, -0.806484945014638, -0.809028073224737, -0.8117943711425217, -0.8147789038294173, -0.8179764117086387, -0.8213813330244377, -0.8249878268198014, -0.8287897962253633, -0.8327809118620599, -0.8369546351722515, -0.8413042415082006, -0.8458228428224804, -0.8505034098215752, -0.8553387934612499, -0.8603217456797453, -0.8654449392821778, -0.8707009869063455, -0.876082459016221, -0.881581900884526, -0.8871918485397683, -0.8929048436658777, -0.8987134474540203, -0.9046102534162825, -0.9105878991796871, -0.9166390772864803, -0.9227565450328487, -0.9289331333832754, -0.9351617550017004, -0.9414354114436008, -0.9477471995551772, -0.9540903171270688, -0.960458067850591, -0.966843865624428, -0.9732412382591455, -0.9796438306258972, -0.9860454072943432, -0.9924398547031801, -0.9988211829048291, -1.005183526923836, -1.0115211477664259, -1.0178284331164726, -1.0240998977509557, -1.0303301837057597, -1.0365140602205112, -1.0426464234890225, -1.0487222962398497, -1.0547368271695003, -1.0606852902489363, -1.0665630839222104, -1.0723657302144003, -1.0780888737643852, -1.0837282807965383, -1.0892798380440034, -1.0947395516349396, -1.1001035459519208, -1.1053680624735727, -1.11052945860652, -1.1155842065147927, -1.12052889195298, -1.1253602131086642, -1.1300749794589553, -1.13467011064532, -1.1391426353703196, -1.1434896903193634, -1.1477085191101173, -1.1517964712717967, -1.1557510012562022, -1.1595696674820368, -1.1632501314137464, -1.1667901566758774, -1.1701876082037195, -1.1734404514308152, -1.1765467515137369, -1.1795046725944067, -1.1823124771000952, -1.1849685250811446, -1.1874712735863715, -1.1898192760760349, -1.1920111818722061, -1.194045735646318, -1.1959217769436714, -1.1976382397446128, -1.1991941520621294, -1.2005886355755688, -1.2018209053002151, -1.2028902692924517, -1.203796128390261, -1.2045379759888295, -1.2051153978510447, -1.2055280719527093, -1.2057757683623096], [-1.187342086171733, -1.1872657614138327, -1.1870368315505901, -1.186655429827572, -1.1861217783680427, -1.1854361882439555, -1.1845990595753704, -1.1836108816583129, -1.1824722331211077, -1.181183782109215, -1.1797462864985881, -1.1781605941375803, -1.1764276431174043, -1.1745484620711424, -1.172524170501276, -1.1703559791356841, -1.1680451903120175, -1.1655931983903163, -1.1630014901936838, -1.1602716454767672, -1.1574053374217184, -1.1544043331612266, -1.1512704943281031, -1.1480057776307906, -1.144612235454032, -1.1410920164837761, -1.1374473663552347, -1.1336806283228, -1.1297942439503208, -1.1257907538199818, -1.121672798257766, -1.1174431180731677, -1.1131045553104926, -1.1086600540087022, -1.104112660966355, -1.0994655265077418, -1.0947219052458175, -1.0898851568369914, -1.0849587467222488, -1.0799462468484289, -1.0748513363628018, -1.0696778022733213, -1.0644295400661277, -1.0591105542710018, -1.0537249589645457, -1.04827697819986, -1.042770946350442, -1.0372113083549022, -1.0316026198479296, -1.0259495471616817, -1.0202568671805117, -1.0145294670305816, -1.0087723435845612, -1.0029906027601836, -0.9971894585900213, -0.9913742320384125, -0.9855503495400517, -0.9797233412333887, -0.9738988388606488, -0.9680825733050671, -0.9622803717348002, -0.9564981543220286, -0.9507419305049825, -0.9450177947600963, -0.9393319218512456, -0.933690561523097, -0.928100032606078, -0.9225667165013832, -0.9170970500158477, -0.9116975175184912, -0.9063746423931253, -0.9011349777646757, -0.8959850964808435, -0.8909315803354779, -0.8859810085255612, -0.8811399453400636, -0.876414927086103, -0.8718124482658374, -0.8673389470262901, -0.8630007899138189, -0.8588042559750937, -0.8547555202571485, -0.8508606367701975, -0.8471255209882546, -0.8435559319740358, -0.8401574542258815, -0.8369354793553119, -0.8338951877140472, -0.8310415300986262, -0.8283792096688454, -0.8259126642228801, -0.8236460489768306, -0.8215832199993638, -0.8197277184528613, -0.8180827557908702, -0.8166512000575896, -0.8154355634285241, -0.8144379911223356, -0.8136602518023683, -0.8131037295724874, -0.8127694176559459, -0.8126579138282671, -0.812769417655946, -0.813103729572488, -0.813660251802369, -0.8144379911223366, -0.8154355634285253, -0.8166512000575907, -0.8180827557908718, -0.8197277184528631, -0.821583219999366, -0.8236460489768328, -0.8259126642228826, -0.8283792096688479, -0.831041530098629, -0.8338951877140504, -0.8369354793553151, -0.840157454225885, -0.8435559319740394, -0.8471255209882582, -0.8508606367702015, -0.8547555202571527, -0.8588042559750978, -0.8630007899138235, -0.8673389470262945, -0.8718124482658421, -0.8764149270861078, -0.8811399453400685, -0.8859810085255663, -0.890931580335483, -0.8959850964808486, -0.9011349777646811, -0.9063746423931307, -0.9116975175184965, -0.9170970500158533, -0.9225667165013888, -0.9281000326060839, -0.9336905615231028, -0.9393319218512516, -0.9450177947601021, -0.9507419305049882, -0.9564981543220346, -0.9622803717348062, -0.9680825733050729, -0.9738988388606546, -0.9797233412333947, -0.9855503495400576, -0.9913742320384182, -0.9971894585900271, -1.0029906027601894, -1.0087723435845672, -1.0145294670305876, -1.0202568671805174, -1.0259495471616875, -1.031602619847935, -1.0372113083549082, -1.0427709463504475, -1.0482769781998655, -1.0537249589645512, -1.059110554271007, -1.064429540066133, -1.0696778022733269, -1.0748513363628072, -1.0799462468484342, -1.084958746722254, -1.0898851568369967, -1.0947219052458224, -1.0994655265077464, -1.1041126609663596, -1.1086600540087068, -1.1131045553104972, -1.117443118073172, -1.12167279825777, -1.1257907538199858, -1.1297942439503248, -1.1336806283228038, -1.1374473663552385, -1.14109201648378, -1.1446122354540358, -1.1480057776307941, -1.1512704943281062, -1.1544043331612297, -1.1574053374217212, -1.16027164547677, -1.1630014901936865, -1.165593198390319, -1.16804519031202, -1.1703559791356861, -1.172524170501278, -1.1745484620711446, -1.1764276431174063, -1.1781605941375821, -1.1797462864985897, -1.1811837821092164, -1.182472233121109, -1.1836108816583137, -1.1845990595753715, -1.1854361882439566, -1.186121778368043, -1.1866554298275727, -1.1870368315505908, -1.1872657614138333], [-1.1696120172351863, -1.1695418685059997, -1.1693314649475264, -1.1689809344580584, -1.1684904902381796, -1.167860430845886, -1.1670911402736894, -1.1661830880476551, -1.1651368293482731, -1.163953005153077, -1.1626323424008633, -1.1611756541773535, -1.1595838399221021, -1.1578578856564137, -1.1559988642319778, -1.1540079355999004, -1.1518863470997267, -1.1496354337679935, -1.1472566186657802, -1.1447514132246255, -1.142121417610091, -1.1393683211021393, -1.1364939024913738, -1.1335000304900484, -1.1303886641566068, -1.1271618533323406, -1.123821739088568, -1.1203705541825366, -1.1168106235200144, -1.113144364622299, -1.1093742880950928, -1.105502998096398, -1.1015331928002619, -1.0974676648528496, -1.0933093018169335, -1.0890610866004868, -1.084726097864606, -1.08030751040552, -1.0758085955049135, -1.07123272124225, -1.066583352762183, -1.0618640524895095, -1.05707848028347, -1.0522303935224686, -1.0473236471095693, -1.0423621933883251, -1.0373500819576995, -1.03229145937398, -1.0271905687267304, -1.0220517490749084, -1.0168794347283912, -1.0116781543592015, -1.006452529925825, -1.0012072753930772, -0.9959471952290999, -0.9906771826601878, -0.9854022176633522, -0.9801273646757769, -0.9748577699996669, -0.9695986588804476, -0.9643553322358565, -0.9591331630132252, -0.9539375921521787, -0.9487741241301422, -0.9436483220684495, -0.9385658023775416, -0.9335322289207484, -0.9285533066775128, -0.9236347748886499, -0.9187823996684059, -0.9140019660706696, -0.9092992695997727, -0.904680107159869, -0.9001502674409481, -0.8957155207441087, -0.8913816082537942, -0.8871542307702633, -0.8830390369215941, -0.8790416108809833, -0.87516745962193, -0.8714219997510204, -0.8678105439653814, -0.8643382871893377, -0.8610102924522657, -0.8578314765769868, -0.8548065957551004, -0.8519402310923175, -0.8492367742129127, -0.8467004130177542, -0.844335117694798, -0.8421446270843101, -0.8401324355032713, -0.8383017801342769, -0.8366556290836928, -0.8351966702117604, -0.8339273008337333, -0.8328496183859603, -0.8319654121441085, -0.8312761560725427, -0.8307830028743062, -0.8304867793003529, -0.8303879827648137, -0.830486779300353, -0.8307830028743066, -0.8312761560725433, -0.8319654121441092, -0.8328496183859613, -0.8339273008337345, -0.8351966702117617, -0.8366556290836945, -0.8383017801342787, -0.8401324355032733, -0.8421446270843124, -0.8443351176948002, -0.8467004130177567, -0.8492367742129153, -0.8519402310923204, -0.8548065957551035, -0.85783147657699, -0.861010292452269, -0.8643382871893411, -0.867810543965385, -0.8714219997510241, -0.875167459621934, -0.8790416108809872, -0.8830390369215982, -0.8871542307702677, -0.8913816082537986, -0.8957155207441132, -0.9001502674409527, -0.9046801071598737, -0.9092992695997774, -0.9140019660706744, -0.9187823996684109, -0.9236347748886549, -0.9285533066775177, -0.9335322289207535, -0.9385658023775467, -0.943648322068455, -0.9487741241301476, -0.9539375921521841, -0.9591331630132306, -0.964355332235862, -0.9695986588804529, -0.9748577699996723, -0.9801273646757823, -0.9854022176633577, -0.9906771826601932, -0.9959471952291055, -1.0012072753930825, -1.0064525299258302, -1.0116781543592068, -1.0168794347283965, -1.0220517490749137, -1.0271905687267355, -1.0322914593739854, -1.0373500819577046, -1.0423621933883305, -1.0473236471095744, -1.0522303935224737, -1.0570784802834747, -1.0618640524895144, -1.066583352762188, -1.071232721242255, -1.0758085955049181, -1.0803075104055246, -1.0847260978646105, -1.089061086600491, -1.093309301816938, -1.0974676648528539, -1.1015331928002663, -1.105502998096402, -1.1093742880950965, -1.1131443646223027, -1.1168106235200181, -1.1203705541825402, -1.1238217390885716, -1.127161853332344, -1.13038866415661, -1.1335000304900515, -1.1364939024913767, -1.1393683211021421, -1.1421214176100938, -1.1447514132246281, -1.1472566186657827, -1.1496354337679957, -1.1518863470997287, -1.1540079355999027, -1.1559988642319794, -1.1578578856564157, -1.159583839922104, -1.1611756541773548, -1.1626323424008647, -1.1639530051530784, -1.1651368293482744, -1.166183088047656, -1.1670911402736905, -1.1678604308458864, -1.16849049023818, -1.1689809344580586, -1.1693314649475268, -1.169541868506], [-1.152685295042207, -1.1526212197615529, -1.1524290345447585, -1.152108861275091, -1.1516609031171832, -1.1510854445557532, -1.1503828514496828, -1.149553571101327, -1.1485981323408772, -1.1475171456255748, -1.1463113031535075, -1.1449813789916814, -1.1435282292180138, -1.1419527920768135, -1.1402560881472807, -1.1384392205244587, -1.1365033750120235, -1.1344498203261837, -1.1322799083099033, -1.1299950741565283, -1.1275968366418145, -1.125086798363219, -1.1224666459851875, -1.119738150489036, -1.116903167425851, -1.1139636371706843, -1.110921585176115, -1.1077791222230577, -1.10453844466648, -1.1012018346734591, -1.097771660450739, -1.0942503764587055, -1.0906405236083696, -1.0869447294376648, -1.0831657082630073, -1.079306261301725, -1.0753692767605694, -1.0713577298851278, -1.0672746829645212, -1.0631232852853236, -1.0589067730281685, -1.054628469100006, -1.0502917828944627, -1.0459002099722117, -1.0414573316527174, -1.0369668145081314, -1.032432409749547, -1.0278579524952198, -1.023247360909763, -1.018604635202735, -1.0139338564744362, -1.0092391853961695, -1.0045248607116453, -0.9997951975457033, -0.9950545855060322, -0.9903074865631332, -0.9855584326934174, -0.9808120232700293, -0.9760729221858017, -0.971345854692662, -0.9666356039418494, -0.961947007209502, -0.9572849517925096, -0.9526543705600828, -0.9480602371472143, -0.9435075607771765, -0.9390013807014023, -0.934546760246562, -0.9301487804603783, -0.9258125333497643, -0.9215431147071901, -0.9173456165238243, -0.9132251189909615, -0.9091866820944974, -0.9052353368107986, -0.9013760759161714, -0.8976138444262701, -0.8939535296861634, -0.8903999511363653, -0.8869578497848767, -0.8836318774201452, -0.8804265856047407, -0.8773464144944294, -0.8743956815320888, -0.8715785700705009, -0.868899117982364, -0.8663612063198076, -0.8639685480891713, -0.8617246772097336, -0.8596329377273557, -0.8576964733555557, -0.8559182174172705, -0.854300883260449, -0.8528469552195747, -0.8515586801932308, -0.8504380599048632, -0.8494868439099782, -0.8487065234081599, -0.8480983259125467, -0.8476632108228402, -0.8474018659406182, -0.847314704957793, -0.8474018659406183, -0.8476632108228405, -0.8480983259125471, -0.8487065234081606, -0.8494868439099791, -0.8504380599048643, -0.851558680193232, -0.8528469552195762, -0.8543008832604506, -0.8559182174172723, -0.8576964733555577, -0.8596329377273577, -0.8617246772097358, -0.8639685480891738, -0.8663612063198103, -0.8688991179823667, -0.8715785700705037, -0.8743956815320917, -0.8773464144944326, -0.8804265856047441, -0.8836318774201485, -0.8869578497848801, -0.8903999511363688, -0.8939535296861671, -0.8976138444262738, -0.9013760759161754, -0.9052353368108025, -0.9091866820945014, -0.9132251189909657, -0.9173456165238286, -0.9215431147071944, -0.9258125333497689, -0.9301487804603826, -0.9345467602465665, -0.939001380701407, -0.943507560777181, -0.9480602371472191, -0.9526543705600877, -0.9572849517925144, -0.9619470072095069, -0.9666356039418544, -0.9713458546926668, -0.9760729221858064, -0.9808120232700341, -0.9855584326934224, -0.990307486563138, -0.9950545855060371, -0.9997951975457082, -1.00452486071165, -1.0092391853961744, -1.0139338564744411, -1.0186046352027396, -1.0232473609097679, -1.0278579524952243, -1.0324324097495516, -1.036966814508136, -1.041457331652722, -1.0459002099722163, -1.0502917828944671, -1.0546284691000105, -1.0589067730281727, -1.063123285285328, -1.0672746829645254, -1.071357729885132, -1.0753692767605734, -1.0793062613017288, -1.0831657082630113, -1.0869447294376686, -1.0906405236083734, -1.094250376458709, -1.0977716604507424, -1.1012018346734622, -1.1045384446664837, -1.1077791222230609, -1.1109215851761183, -1.1139636371706876, -1.1169031674258536, -1.1197381504890387, -1.1224666459851904, -1.1250867983632213, -1.127596836641817, -1.1299950741565306, -1.1322799083099055, -1.1344498203261857, -1.1365033750120253, -1.1384392205244604, -1.1402560881472823, -1.1419527920768153, -1.1435282292180151, -1.144981378991683, -1.1463113031535084, -1.1475171456255762, -1.1485981323408783, -1.1495535711013276, -1.1503828514496837, -1.1510854445557537, -1.1516609031171832, -1.1521088612750914, -1.152429034544759, -1.152621219761553], [-1.1365782951033216, -1.1365201670978964, -1.1363458214860913, -1.1360553734858239, -1.1356490151419425, -1.1351270153486195, -1.1344897198805204, -1.1337375514325725, -1.1328710096680918, -1.1318906712749857, -1.1307971900296714, -1.1295912968683048, -1.1282737999648353, -1.1268455848153431, -1.125307614328032, -1.1236609289181787, -1.1219066466072514, -1.1200459631253126, -1.1180801520157417, -1.116010564741183, -1.1138386307895316, -1.111565857778637, -1.1091938315582803, -1.1067242163078344, -1.10415875462787, -1.1014992676238125, -1.0987476549795718, -1.0959058950188962, -1.0929760447519963, -1.0899602399047765, -1.0868606949277964, -1.0836797029818355, -1.0804196358967, -1.0770829440996383, -1.0736721565094467, -1.0701898803920777, -1.0666388011732306, -1.0630216822031044, -1.0593413644681517, -1.055600766244326, -1.0518028826859698, -1.0479507853441081, -1.0440476216075565, -1.0400966140598507, -1.0361010597446434, -1.0320643293318073, -1.0279898661761087, -1.0238811852599385, -1.0197418720112097, -1.0155755809871865, -1.011386034414667, -1.0071770205766362, -1.0029523920352323, -0.9987160636806284, -0.9944720105952499, -0.9902242657226097, -0.9859769173299863, -0.9817341062541745, -0.9775000229196364, -0.973278904118578, -0.9690750295427709, -0.9648927180573703, -0.9607363237075236, -0.9566102314492618, -0.9525188525970167, -0.9484666199811091, -0.9444579828097418, -0.9404974012313965, -0.9365893405950719, -0.932738265407557, -0.9289486329888524, -0.9252248868289936, -0.9215714496518315, -0.9179927161938372, -0.9144930457086531, -0.9110767542109439, -0.9077481064760541, -0.904511307815048, -0.9013704956478593, -0.8983297309004743, -0.8953929892552769, -0.8925641522868588, -0.8898469985186909, -0.8872451944390082, -0.8847622855170473, -0.8824016872633065, -0.8801666763797602, -0.8780603820478473, -0.8760857774035747, -0.8742456712501177, -0.8725427000588796, -0.8709793203099931, -0.8695578012227372, -0.8682802179252139, -0.8671484451109477, -0.8661641512277435, -0.8653287932412711, -0.8646436120123688, -0.864109628323076, -0.8637276395819227, -0.8634982172340773, -0.8634217048966784, -0.8634982172340775, -0.8637276395819231, -0.8641096283230767, -0.8646436120123693, -0.865328793241272, -0.8661641512277444, -0.8671484451109487, -0.8682802179252153, -0.8695578012227385, -0.8709793203099949, -0.8725427000588813, -0.8742456712501195, -0.8760857774035766, -0.8780603820478494, -0.8801666763797623, -0.8824016872633088, -0.8847622855170497, -0.8872451944390107, -0.8898469985186936, -0.8925641522868617, -0.8953929892552799, -0.8983297309004773, -0.9013704956478624, -0.9045113078150512, -0.9077481064760575, -0.9110767542109474, -0.9144930457086565, -0.9179927161938409, -0.9215714496518352, -0.9252248868289974, -0.9289486329888563, -0.9327382654075609, -0.9365893405950759, -0.9404974012314005, -0.944457982809746, -0.9484666199811131, -0.9525188525970211, -0.956610231449266, -0.9607363237075278, -0.9648927180573748, -0.9690750295427754, -0.9732789041185823, -0.9775000229196409, -0.9817341062541787, -0.9859769173299906, -0.9902242657226141, -0.9944720105952544, -0.9987160636806328, -1.0029523920352366, -1.0071770205766406, -1.0113860344146712, -1.015575580987191, -1.019741872011214, -1.023881185259943, -1.027989866176113, -1.0320643293318115, -1.0361010597446474, -1.0400966140598547, -1.0440476216075605, -1.0479507853441121, -1.0518028826859736, -1.0556007662443299, -1.0593413644681555, -1.0630216822031084, -1.0666388011732344, -1.0701898803920813, -1.0736721565094502, -1.077082944099642, -1.0804196358967038, -1.0836797029818384, -1.0868606949277995, -1.0899602399047799, -1.0929760447519994, -1.0959058950188991, -1.0987476549795747, -1.1014992676238153, -1.1041587546278728, -1.1067242163078366, -1.1091938315582828, -1.1115658577786391, -1.1138386307895338, -1.1160105647411853, -1.118080152015744, -1.1200459631253143, -1.121906646607253, -1.1236609289181807, -1.1253076143280334, -1.1268455848153447, -1.1282737999648367, -1.129591296868306, -1.1307971900296727, -1.1318906712749868, -1.1328710096680927, -1.1337375514325734, -1.1344897198805215, -1.13512701534862, -1.1356490151419427, -1.136055373485824, -1.1363458214860918, -1.1365201670978964], [-1.1213065999007172, -1.1212542685225173, -1.1210973103668491, -1.1208358333718849, -1.12047001743915, -1.1200001144402691, -1.1194264482262122, -1.118749414638809, -1.117969481524273, -1.11708718874839, -1.1161031482129666, -1.1150180438730641, -1.113832631754471, -1.112547739970796, -1.1111642687394747, -1.1096831903959166, -1.1081055494049104, -1.106432462368337, -1.104665118028123, -1.1028047772632732, -1.1008527730797166, -1.0988105105915722, -1.0966794669923325, -1.0944611915143303, -1.0921573053747056, -1.089769501705975, -1.08729954546912, -1.0847492733469801, -1.0821205936155502, -1.0794154859906215, -1.076636001447003, -1.0737842620073899, -1.0708624604977224, -1.0678728602656904, -1.0648177948588076, -1.0616996676582633, -1.0585209514645275, -1.055284188030452, -1.0519919875373596, -1.0486470280093816, -1.0452520546610449, -1.0418098791728645, -1.0383233788894517, -1.0347954959343952, -1.0312292362359383, -1.0276276684572365, -1.0239939228247585, -1.0203311898481853, -1.0166427189249636, -1.0129318168225099, -1.0092018460309005, -1.0054562229787851, -1.0016984161051625, -0.997931943779634, -0.9941603720637469, -0.9903873123061017, -0.9866164185640159, -0.9828513848447206, -0.9790959421593117, -0.9753538553830264, -0.9716289199158098, -0.9679249581376678, -0.9642458156538887, -0.9605953573259335, -0.9569774630846076, -0.9533960235230549, -0.9498549352681573, -0.9463580961300899, -0.9429094000310502, -0.9395127317155985, -0.9361719612465368, -0.932890938291905, -0.9296734862103859, -0.926523395944253, -0.9234444197309013, -0.9204402646459937, -0.9175145859932983, -0.9146709805583672, -0.911912979745313, -0.9092440426180178, -0.9066675488691718, -0.9041867917425253, -0.901804970935648, -0.8995251855122547, -0.8973504268547945, -0.8952835716894314, -0.8933273752167701, -0.8914844643826453, -0.8897573313240067, -0.8881483270253078, -0.8866596552208914, -0.8852933665785873, -0.8840513531991021, -0.8829353434647937, -0.8819468972700494, -0.8810874016637577, -0.8803580669322734, -0.8797599231488423, -0.8792938172127093, -0.8789604103980804, -0.8787601764298264, -0.8786934000992829, -0.8787601764298265, -0.8789604103980807, -0.8792938172127095, -0.8797599231488428, -0.880358066932274, -0.8810874016637585, -0.8819468972700503, -0.8829353434647947, -0.8840513531991033, -0.8852933665785887, -0.8866596552208929, -0.8881483270253091, -0.8897573313240085, -0.8914844643826473, -0.893327375216772, -0.8952835716894338, -0.8973504268547966, -0.899525185512257, -0.9018049709356505, -0.9041867917425278, -0.9066675488691742, -0.9092440426180205, -0.9119129797453158, -0.9146709805583702, -0.917514585993301, -0.9204402646459969, -0.9234444197309044, -0.9265233959442561, -0.9296734862103891, -0.9328909382919083, -0.9361719612465402, -0.9395127317156019, -0.9429094000310538, -0.9463580961300934, -0.9498549352681611, -0.9533960235230583, -0.9569774630846114, -0.9605953573259371, -0.9642458156538923, -0.9679249581376715, -0.9716289199158136, -0.9753538553830303, -0.9790959421593158, -0.9828513848447245, -0.9866164185640198, -0.9903873123061054, -0.9941603720637509, -0.9979319437796378, -1.0016984161051663, -1.005456222978789, -1.009201846030904, -1.0129318168225134, -1.0166427189249674, -1.020331189848189, -1.0239939228247625, -1.02762766845724, -1.0312292362359419, -1.0347954959343988, -1.0383233788894553, -1.041809879172868, -1.0452520546610484, -1.0486470280093851, -1.051991987537363, -1.0552841880304553, -1.0585209514645308, -1.0616996676582662, -1.0648177948588107, -1.0678728602656935, -1.0708624604977255, -1.0737842620073927, -1.076636001447006, -1.0794154859906244, -1.0821205936155531, -1.0847492733469828, -1.0872995454691228, -1.0897695017059774, -1.092157305374708, -1.0944611915143323, -1.0966794669923348, -1.0988105105915742, -1.1008527730797188, -1.1028047772632752, -1.1046651180281246, -1.1064324623683386, -1.1081055494049117, -1.1096831903959177, -1.1111642687394763, -1.1125477399707975, -1.1138326317544722, -1.1150180438730652, -1.1161031482129677, -1.1170871887483909, -1.1179694815242738, -1.1187494146388095, -1.119426448226213, -1.1200001144402696, -1.1204700174391498, -1.1208358333718853, -1.1210973103668493, -1.1212542685225177], [-1.106884983813195, -1.1068382732234892, -1.1066981748213962, -1.1064647887065002, -1.1061382817064451, -1.1057188873693231, -1.1052069059528036, -1.1046027044097704, -1.103906716370178, -1.1031194421187789, -1.1022414485682877, -1.101273369227494, -1.1002159041637547, -1.0990698199592248, -1.0978359496601047, -1.0965151927181127, -1.0951085149232884, -1.0936169483271687, -1.0920415911552703, -1.090383607707728, -1.0886442282468325, -1.086824748870119, -1.0849265313675438, -1.0829510030611702, -1.0808996566256888, -1.0787740498879472, -1.076575805603572, -1.0743066112086044, -1.0719682185439634, -1.0695624435503936, -1.0670911659314177, -1.0645563287816688, -1.0619599381778242, -1.0593040627292047, -1.0565908330849563, -1.0538224413945583, -1.0510011407182551, -1.0481292443838404, -1.0452091252860567, -1.0422432151247292, -1.0392340035775813, -1.0361840374035367, -1.0330959194721587, -1.0299723077147516, -1.0268159139925046, -1.023629502876956, -1.0204158903379408, -1.0171779423341105, -1.0139185733010365, -1.0106407445318766, -1.0073474624455507, -1.0040417767374026, -1.0007267784073457, -0.9974055976605911, -0.9940814016761582, -0.990757392238543, -0.9874368032281186, -0.9841228979661167, -0.9808189664103362, -0.9775283221981171, -0.9742542995335444, -0.9710002499163437, -0.9677695387105126, -0.9645655415513491, -0.9613916405902698, -0.9582512205775776, -0.9551476647841964, -0.9520843507643263, -0.9490646459619554, -0.946091903165249, -0.9431694558139522, -0.9403006131661402, -0.9374886553318938, -0.9347368281827634, -0.93204833814721, -0.9294263469035678, -0.9268739659834275, -0.9243942512997146, -0.9219901976150814, -0.9196647329675538, -0.91742071307165, -0.9152609157143936, -0.9131880351667838, -0.9112046766322905, -0.9093133507548777, -0.9075164682098074, -0.9058163344011038, -0.9042151442900015, -0.9027149773789563, -0.9013177928758668, -0.9000254250629903, -0.8988395788946855, -0.8977618258475053, -0.8967936000453527, -0.8959361946813591, -0.8951907587568826, -0.8945582941565293, -0.8940396530764207, -0.8936355358210488, -0.8933464889820101, -0.8931729040097101, -0.893115016186805, -0.8931729040097101, -0.8933464889820103, -0.8936355358210494, -0.8940396530764212, -0.89455829415653, -0.8951907587568834, -0.89593619468136, -0.8967936000453536, -0.8977618258475065, -0.8988395788946865, -0.9000254250629915, -0.9013177928758681, -0.9027149773789579, -0.9042151442900029, -0.9058163344011056, -0.9075164682098094, -0.9093133507548796, -0.9112046766322925, -0.9131880351667859, -0.915260915714396, -0.9174207130716521, -0.9196647329675562, -0.9219901976150839, -0.9243942512997172, -0.92687396598343, -0.9294263469035705, -0.9320483381472129, -0.9347368281827662, -0.9374886553318966, -0.940300613166143, -0.9431694558139552, -0.9460919031652522, -0.9490646459619584, -0.9520843507643293, -0.9551476647841998, -0.9582512205775806, -0.9613916405902732, -0.9645655415513523, -0.967769538710516, -0.9710002499163471, -0.9742542995335477, -0.9775283221981205, -0.9808189664103395, -0.9841228979661204, -0.9874368032281221, -0.9907573922385463, -0.9940814016761618, -0.9974055976605944, -1.000726778407349, -1.004041776737406, -1.007347462445554, -1.0106407445318797, -1.0139185733010398, -1.0171779423341138, -1.0204158903379443, -1.0236295028769593, -1.026815913992508, -1.0299723077147547, -1.0330959194721616, -1.0361840374035396, -1.0392340035775847, -1.042243215124732, -1.0452091252860596, -1.0481292443838435, -1.0510011407182582, -1.0538224413945612, -1.0565908330849592, -1.0593040627292076, -1.061959938177827, -1.0645563287816715, -1.0670911659314202, -1.069562443550396, -1.0719682185439658, -1.0743066112086066, -1.0765758056035746, -1.0787740498879497, -1.080899656625691, -1.0829510030611724, -1.0849265313675456, -1.086824748870121, -1.0886442282468343, -1.0903836077077298, -1.092041591155272, -1.09361694832717, -1.0951085149232898, -1.096515192718114, -1.097835949660106, -1.099069819959226, -1.1002159041637558, -1.1012733692274952, -1.1022414485682885, -1.1031194421187798, -1.103906716370179, -1.1046027044097715, -1.1052069059528045, -1.1057188873693233, -1.1061382817064456, -1.1064647887065002, -1.106698174821396, -1.1068382732234892], [-1.0933273988229149, -1.0932861074695746, -1.0931622640035132, -1.0929559602026107, -1.0926673490166492, -1.0922966445471753, -1.09184412201909, -1.0913101177437514, -1.0906950290732993, -1.089999314345868, -1.0892234928212625, -1.0883681446066311, -1.087433910571583, -1.0864214922521365, -1.08533165174281, -1.0841652115760996, -1.082923054588509, -1.0816061237722148, -1.0802154221113867, -1.0787520124020826, -1.0772170170545696, -1.075611617876826, -1.0739370558378987, -1.0721946308096926, -1.070385701285683, -1.0685116840749411, -1.0665740539697652, -1.064574343385117, -1.0625141419679536, -1.0603950961744513, -1.058218908813002, -1.0559873385507705, -1.0537021993814908, -1.051365360052069, -1.0489787434454647, -1.0465443259172171, -1.0440641365828736, -1.0415402565534908, -1.03897481811628, -1.0363700038573687, -1.0337280457235865, -1.0310512240200855, -1.0283418663405504, -1.0256023464266875, -1.022835082953643, -1.0200425382379505, -1.0172272168646084, -1.0143916642298667, -1.0115384649963288, -1.0086702414570066, -1.0057896518050229, -1.0028993883057418, -1.0000021753682158, -0.9971007675129784, -0.9941979472333772, -0.9912965227478518, -0.9883993256407952, -0.9855092083899135, -0.9826290417783168, -0.9797617121899255, -0.9769101187871807, -0.9740771705704813, -0.9712657833192611, -0.9684788764151457, -0.965719369548208, -0.9629901793079507, -0.9602942156613137, -0.9576343783207003, -0.9550135530057592, -0.9524346076034351, -0.9499003882316086, -0.9474137152124831, -0.9449773789627328, -0.9425941358083041, -0.9402667037326419, -0.9379977580680035, -0.9357899271403992, -0.9336457878795671, -0.9315678614062253, -0.92955860860966, -0.927620425729456, -0.9257556399558987, -0.923966505064203, -0.922255197098298, -0.9206238101203695, -0.9190743520427468, -0.9176087405589884, -0.9162287991911877, -0.9149362534705587, -0.9137327272682618, -0.9126197392932182, -0.911598699773289, -0.9106709073357069, -0.9098375461019931, -0.9090996830118365, -0.9084582653894809, -0.907914118765142, -0.9074679449628127, -0.907120320464541, -0.9068716950598998, -0.9067223907879016, -0.9066726011770851, -0.9067223907879016, -0.9068716950599001, -0.9071203204645413, -0.907467944962813, -0.9079141187651426, -0.9084582653894816, -0.9090996830118373, -0.9098375461019939, -0.9106709073357077, -0.91159869977329, -0.9126197392932193, -0.913732727268263, -0.9149362534705601, -0.9162287991911893, -0.9176087405589897, -0.9190743520427486, -0.9206238101203711, -0.9222551970982996, -0.923966505064205, -0.9257556399559008, -0.927620425729458, -0.9295586086096621, -0.9315678614062274, -0.9336457878795691, -0.9357899271404013, -0.9379977580680058, -0.9402667037326444, -0.9425941358083064, -0.9449773789627353, -0.9474137152124855, -0.9499003882316112, -0.9524346076034376, -0.9550135530057619, -0.957634378320703, -0.9602942156613165, -0.9629901793079536, -0.9657193695482108, -0.9684788764151485, -0.9712657833192639, -0.9740771705704844, -0.9769101187871836, -0.9797617121899284, -0.9826290417783198, -0.9855092083899167, -0.9883993256407982, -0.991296522747855, -0.9941979472333803, -0.9971007675129815, -1.0000021753682187, -1.0028993883057447, -1.0057896518050258, -1.0086702414570095, -1.0115384649963317, -1.0143916642298696, -1.0172272168646115, -1.0200425382379534, -1.022835082953646, -1.0256023464266901, -1.0283418663405528, -1.0310512240200882, -1.0337280457235893, -1.0363700038573713, -1.0389748181162826, -1.0415402565534935, -1.044064136582876, -1.0465443259172198, -1.0489787434454672, -1.0513653600520714, -1.0537021993814932, -1.0559873385507728, -1.058218908813004, -1.0603950961744537, -1.0625141419679558, -1.064574343385119, -1.0665740539697675, -1.0685116840749431, -1.070385701285685, -1.0721946308096941, -1.0739370558379004, -1.0756116178768278, -1.0772170170545714, -1.0787520124020842, -1.080215422111388, -1.0816061237722159, -1.08292305458851, -1.0841652115761007, -1.0853316517428109, -1.0864214922521378, -1.0874339105715838, -1.0883681446066318, -1.0892234928212632, -1.0899993143458686, -1.0906950290733004, -1.0913101177437519, -1.0918441220190909, -1.0922966445471756, -1.0926673490166496, -1.0929559602026109, -1.0931622640035135, -1.093286107469575], [-1.0806469610177518, -1.0806108613328942, -1.0805025899699563, -1.0803222299977973, -1.0800699198443315, -1.0797458532661495, -1.079350279305795, -1.0788835022364907, -1.0783458814940583, -1.0777378315957267, -1.0770598220454426, -1.0763123772252647, -1.075496076272341, -1.0746115529409233, -1.073659495448804, -1.0726406463074987, -1.0715558021354379, -1.0704058134533663, -1.0691915844610798, -1.0679140727945684, -1.0665742892625658, -1.0651732975614334, -1.0637122139672497, -1.0621922070038894, -1.0606144970858276, -1.0589803561343132, -1.0572911071654998, -1.05554812384905, -1.0537528300356467, -1.051906699251794, -1.0500112541602034, -1.0480680659840058, -1.046078753892958, -1.044044984349747, -1.0419684704144376, -1.0398509710050503, -1.0376942901121966, -1.0355002759656584, -1.0332708201507441, -1.0310078566722185, -1.0287133609635768, -1.026389348839402, -1.0240378753885333, -1.021661033805765, -1.0192609541598094, -1.0168398020952627, -1.0143997774663476, -1.0119431129002627, -1.0094720722880095, -1.006988949200661, -1.0044960652291224, -1.0019957682455578, -0.9994904305847775, -0.996982447144054, -0.9944742334000017, -0.9919682233413627, -0.9894668673167696, -0.9869726297968092, -0.9844879870499846, -0.9820154247324908, -0.9795574353920362, -0.9771165158863179, -0.9746951647171301, -0.9722958792815095, -0.9699211530417512, -0.9675734726165967, -0.9652553147963754, -0.9629691434853935, -0.9607174065753843, -0.9585025327543749, -0.9563269282558876, -0.9541929735539413, -0.9521030200099101, -0.9500593864778457, -0.9480643558754576, -0.9461201717284898, -0.9442290346967939, -0.9423930990909116, -0.9406144693884962, -0.9388951967603668, -0.9372372756164244, -0.9356426401820562, -0.934113161115993, -0.9326506421808768, -0.9312568169780201, -0.9299333457580036, -0.9286818123188523, -0.9275037210035417, -0.9264004938085331, -0.9253734676148846, -0.9244238915532725, -0.9235529245139319, -0.9227616328121462, -0.9220509880194258, -0.9214218649699611, -0.9208750399512947, -0.9204111890874382, -0.9200308869218777, -0.9197346052070584, -0.919522711906027, -0.9193954704109533, -0.9193530389822482, -0.9193954704109535, -0.9195227119060272, -0.9197346052070586, -0.9200308869218781, -0.9204111890874386, -0.9208750399512953, -0.9214218649699618, -0.9220509880194264, -0.922761632812147, -0.9235529245139328, -0.9244238915532734, -0.9253734676148856, -0.9264004938085342, -0.927503721003543, -0.9286818123188536, -0.9299333457580049, -0.9312568169780217, -0.9326506421808783, -0.9341131611159946, -0.9356426401820579, -0.9372372756164262, -0.9388951967603686, -0.9406144693884979, -0.9423930990909134, -0.9442290346967959, -0.9461201717284919, -0.9480643558754596, -0.9500593864778479, -0.9521030200099122, -0.9541929735539435, -0.9563269282558897, -0.9585025327543771, -0.9607174065753865, -0.9629691434853958, -0.9652553147963778, -0.9675734726165992, -0.9699211530417539, -0.972295879281512, -0.9746951647171327, -0.9771165158863203, -0.9795574353920388, -0.9820154247324935, -0.9844879870499874, -0.9869726297968119, -0.9894668673167722, -0.9919682233413651, -0.9944742334000044, -0.9969824471440565, -0.99949043058478, -1.0019957682455605, -1.004496065229125, -1.0069889492006634, -1.0094720722880122, -1.0119431129002652, -1.0143997774663502, -1.0168398020952651, -1.019260954159812, -1.0216610338057672, -1.0240378753885353, -1.0263893488394045, -1.0287133609635792, -1.0310078566722207, -1.0332708201507466, -1.0355002759656609, -1.0376942901121986, -1.0398509710050523, -1.0419684704144399, -1.044044984349749, -1.0460787538929601, -1.0480680659840078, -1.0500112541602051, -1.0519066992517958, -1.053752830035649, -1.0555481238490516, -1.0572911071655016, -1.0589803561343147, -1.0606144970858293, -1.062192207003891, -1.0637122139672512, -1.065173297561435, -1.0665742892625674, -1.0679140727945697, -1.0691915844610809, -1.0704058134533674, -1.071555802135439, -1.0726406463074998, -1.0736594954488048, -1.0746115529409244, -1.0754960762723416, -1.0763123772252652, -1.0770598220454433, -1.0777378315957271, -1.078345881494059, -1.078883502236491, -1.0793502793057959, -1.0797458532661497, -1.0800699198443315, -1.0803222299977973, -1.0805025899699563, -1.0806108613328942], [-1.0688559379023295, -1.068824776245451, -1.0687313159731842, -1.0685756311730623, -1.0683578452990394, -1.0680781311335004, -1.067736710733912, -1.0673338553639382, -1.0668698854088032, -1.0663451702746467, -1.0657601282715374, -1.065115226479803, -1.0644109805992459, -1.0636479547807942, -1.0628267614400728, -1.0619480610523289, -1.061012561928111, -1.0600210199690314, -1.0589742384029066, -1.0578730674975123, -1.0567184042521442, -1.0555111920661233, -1.0542524203833348, -1.0529431243118452, -1.0515843842175876, -1.0501773252910587, -1.048723117085933, -1.0472229730284375, -1.0456781498963024, -1.0440899472660532, -1.042459706927366, -1.040788812263177, -1.0390786875941989, -1.0373307974864605, -1.0355466460204628, -1.033727776020516, -1.031875768242803, -1.0299922405207005, -1.0280788468658721, -1.026137276523653, -1.0241692529812427, -1.0221765329272323, -1.0201609051610108, -1.0181241894506206, -1.0160682353376727, -1.0139949208879673, -1.01190615138653, -1.0098038579758388, -1.0076899962360946, -1.0055665447064759, -1.003435503346439, -1.001298891936217, -0.9991587484158337, -0.9970171271620747, -0.9948760972030276, -0.9927377403699922, -0.9906041493867375, -0.9884774258963146, -0.9863596784258436, -0.9842530202899478, -0.9821595674337645, -0.980081436216736, -0.978020741138672, -0.9759795925098821, -0.9739600940674951, -0.9719643405404037, -0.9699944151656211, -0.9680523871591803, -0.9661403091450645, -0.964260214546019, -0.9624141149404567, -0.9606039973900419, -0.9588318217428891, -0.9570995179176841, -0.9554089831743776, -0.9537620793774418, -0.9521606302580123, -0.9506064186815357, -0.9491011839278399, -0.9476466189908017, -0.946244367905019, -0.9448960231071031, -0.9436031228393753, -0.9423671486038772, -0.9411895226747015, -0.9400716056766977, -0.9390146942386031, -0.9380200187286113, -0.9370887410802946, -0.9362219527166463, -0.9354206725798273, -0.934685845273937, -0.9340183393278491, -0.933418945584792, -0.9328883757249687, -0.9324272609270625, -0.9320361506739898, -0.9317155117077385, -0.9314657271375638, -0.9312870957052101, -0.931179831210213, -0.9311440620976705, -0.9311798312102131, -0.9312870957052101, -0.9314657271375638, -0.9317155117077388, -0.93203615067399, -0.9324272609270631, -0.9328883757249693, -0.9334189455847925, -0.9340183393278498, -0.9346858452739376, -0.935420672579828, -0.936221952716647, -0.9370887410802955, -0.9380200187286125, -0.9390146942386042, -0.9400716056766989, -0.9411895226747027, -0.9423671486038784, -0.9436031228393768, -0.9448960231071046, -0.9462443679050203, -0.9476466189908033, -0.9491011839278414, -0.9506064186815372, -0.9521606302580139, -0.9537620793774436, -0.9554089831743793, -0.9570995179176858, -0.9588318217428907, -0.9606039973900437, -0.9624141149404585, -0.9642602145460207, -0.9661403091450665, -0.9680523871591822, -0.969994415165623, -0.9719643405404057, -0.9739600940674973, -0.975979592509884, -0.9780207411386741, -0.9800814362167383, -0.9821595674337666, -0.9842530202899498, -0.9863596784258457, -0.9884774258963169, -0.9906041493867397, -0.9927377403699942, -0.9948760972030298, -0.9970171271620769, -0.9991587484158359, -1.001298891936219, -1.003435503346441, -1.005566544706478, -1.0076899962360968, -1.009803857975841, -1.011906151386532, -1.0139949208879693, -1.016068235337675, -1.0181241894506226, -1.0201609051610125, -1.0221765329272343, -1.0241692529812447, -1.0261372765236547, -1.0280788468658741, -1.0299922405207027, -1.031875768242805, -1.0337277760205175, -1.0355466460204645, -1.0373307974864623, -1.0390786875942006, -1.0407888122631785, -1.0424597069273676, -1.044089947266055, -1.0456781498963041, -1.0472229730284388, -1.0487231170859346, -1.0501773252910602, -1.051584384217589, -1.0529431243118466, -1.054252420383336, -1.0555111920661244, -1.0567184042521456, -1.0578730674975134, -1.0589742384029077, -1.0600210199690323, -1.0610125619281119, -1.0619480610523298, -1.0628267614400735, -1.063647954780795, -1.0644109805992463, -1.0651152264798034, -1.065760128271538, -1.0663451702746471, -1.066869885408804, -1.0673338553639384, -1.0677367107339126, -1.0680781311335006, -1.0683578452990394, -1.0685756311730623, -1.0687313159731842, -1.0688247762454512], [-1.0579657365300008, -1.0579392333990796, -1.0578597456646475, -1.057727338293165, -1.057542119533591, -1.0573042408746058, -1.0570138969845915, -1.0566713256342322, -1.056276807601569, -1.0558306665592976, -1.0553332689440642, -1.0547850238074747, -1.0541863826484956, -1.0535378392268904, -1.0528399293572916, -1.0520932306834823, -1.051298362432414, -1.0504559851474566, -1.0495668004003467, -1.0486315504812502, -1.0476510180663416, -1.046626025862246, -1.045557436226683, -1.0444461507645963, -1.0432931098990381, -1.0420992924160446, -1.040865714982708, -1.0395934316376332, -1.0382835332529323, -1.0369371469669015, -1.035555435586495, -1.0341395969587026, -1.0326908633099188, -1.0312105005523833, -1.0296998075567674, -1.0281601153899753, -1.0265927865172328, -1.024999213967543, -1.0233808204615937, -1.0217390575012246, -1.02007540441958, -1.0183913673911, -1.0166884784005394, -1.0149682941702398, -1.013232395044935, -1.0114823838334184, -1.0097198846064679, -1.0079465414504927, -1.0061640171764479, -1.0043739919836492, -1.0025781620782208, -1.0007782382460093, -0.9989759443799223, -0.9971730159617648, -0.9953711984987906, -0.9935722459153286, -0.9917779188999895, -0.9899899832091403, -0.9882102079274846, -0.9864403636867891, -0.9846822208439708, -0.9829375476199695, -0.9812081082010273, -0.9794956608042144, -0.9778019557092571, -0.9761287332589451, -0.9744777218306236, -0.9728506357815087, -0.9712491733707846, -0.9696750146616875, -0.9681298194069954, -0.9666152249215787, -0.9651328439458849, -0.963684262504445, -0.9622710377636953, -0.9608946958936059, -0.9595567299377921, -0.958258597696949, -0.9570017196306115, -0.955787476782373, -0.9546172087338102, -0.9534922115924639, -0.9524137360192882, -0.9513829853010348, -0.9504011134730519, -0.9494692234979791, -0.9485883655057777, -0.9477595351004724, -0.9469836717388876, -0.9462616571865363, -0.9455943140556607, -0.9449824044302444, -0.9444266285825914, -0.9439276237858327, -0.9434859632264408, -0.9431021550205354, -0.9427766413374402, -0.9425097976336009, -0.9423019319996043, -0.9421532846226551, -0.9420640273664519, -0.9420342634699993, -0.9420640273664519, -0.9421532846226552, -0.9423019319996047, -0.942509797633601, -0.9427766413374404, -0.9431021550205357, -0.9434859632264413, -0.9439276237858333, -0.9444266285825921, -0.9449824044302451, -0.9455943140556614, -0.9462616571865369, -0.9469836717388885, -0.9477595351004732, -0.9485883655057787, -0.9494692234979801, -0.9504011134730529, -0.9513829853010358, -0.9524137360192894, -0.953492211592465, -0.9546172087338115, -0.9557874767823742, -0.9570017196306128, -0.9582585976969502, -0.9595567299377934, -0.9608946958936074, -0.9622710377636967, -0.9636842625044466, -0.9651328439458864, -0.9666152249215801, -0.968129819406997, -0.9696750146616891, -0.9712491733707863, -0.9728506357815102, -0.9744777218306252, -0.9761287332589466, -0.9778019557092588, -0.979495660804216, -0.9812081082010289, -0.9829375476199714, -0.9846822208439726, -0.986440363686791, -0.9882102079274866, -0.9899899832091421, -0.9917779188999915, -0.9935722459153303, -0.9953711984987927, -0.9971730159617666, -0.9989759443799242, -1.000778238246011, -1.0025781620782224, -1.004373991983651, -1.0061640171764497, -1.0079465414504947, -1.0097198846064697, -1.01148238383342, -1.013232395044937, -1.0149682941702416, -1.0166884784005412, -1.0183913673911018, -1.0200754044195814, -1.0217390575012262, -1.0233808204615953, -1.0249992139675448, -1.0265927865172344, -1.0281601153899766, -1.0296998075567692, -1.0312105005523848, -1.0326908633099203, -1.0341395969587042, -1.0355554355864964, -1.0369371469669029, -1.0382835332529339, -1.0395934316376345, -1.0408657149827096, -1.042099292416046, -1.0432931098990395, -1.0444461507645975, -1.0455574362266842, -1.046626025862247, -1.0476510180663425, -1.0486315504812513, -1.0495668004003473, -1.050455985147457, -1.0512983624324146, -1.0520932306834831, -1.052839929357292, -1.053537839226891, -1.054186382648496, -1.054785023807475, -1.0553332689440647, -1.0558306665592982, -1.0562768076015696, -1.0566713256342326, -1.0570138969845921, -1.057304240874606, -1.057542119533591, -1.0577273382931653, -1.0578597456646477, -1.0579392333990798], [-1.0479868924672608, -1.0479647429965895, -1.047898313205298, -1.0477876589466204, -1.047632873279501, -1.047434086423872, -1.0471914656979535, -1.0469052154374712, -1.0465755768966742, -1.0462028281310034, -1.0457872838612332, -1.0453292953188884, -1.0448292500727006, -1.0442875718358637, -1.0437047202537966, -1.0430811906721198, -1.042417513884516, -1.0417142558601253, -1.040972017450104, -1.040191434072952, -1.0393731753781958, -1.0385179448879949, -1.0376264796162167, -1.0366995496645122, -1.0357379577949124, -1.0347425389784386, -1.0337141599192228, -1.032653718553614, -1.0315621435237388, -1.0304403936249853, -1.0292894572268614, -1.028110351666694, -1.0269041226156208, -1.0256718434163425, -1.0244146143921027, -1.0231335621263746, -1.0218298387127518, -1.020504620974548, -1.0191591096536454, -1.017794528568142, -1.016412123738386, -1.0150131624810246, -1.0135989324707138, -1.0121707407692042, -1.0107299128215457, -1.0092777914192175, -1.007815735630048, -1.0063451196948492, -1.004867331890765, -1.0033837733614033, -1.0018958569139058, -1.0004050057831968, -0.9989126523637387, -0.9974202369092289, -0.9959292062007655, -0.9944410121841278, -0.992957110576924, -0.9914789594464817, -0.9900080177594763, -0.988545743904427, -0.9870935941883104, -0.9856530213086913, -0.9842254728028946, -0.9828123894758939, -0.9814152038087252, -0.9800353383493879, -0.9786742040883283, -0.9773331988207538, -0.9760137054981599, -0.9747170905716025, -0.9734447023293692, -0.9721978692318558, -0.9709778982465631, -0.9697860731862656, -0.9686236530535074, -0.9674918703946938, -0.9663919296671417, -0.9653250056225375, -0.9642922417103259, -0.9632947485046233, -0.9623336021582867, -0.9614098428878156, -0.9605244734927807, -0.9596784579134767, -0.9588727198304859, -0.9581081413098175, -0.9573855614972272, -0.9567057753652752, -0.9560695325165863, -0.9554775360466862, -0.9549304414696628, -0.954428855709776, -0.9539733361619801, -0.9535643898241598, -0.9532024725036913, -0.9528879881007528, -0.9526212879705753, -0.9524026703666187, -0.9522323799664077, -0.9521106074815152, -0.9520374893529249, -0.9520131075327393, -0.9520374893529249, -0.9521106074815153, -0.9522323799664079, -0.952402670366619, -0.9526212879705754, -0.9528879881007533, -0.9532024725036916, -0.95356438982416, -0.9539733361619807, -0.9544288557097765, -0.9549304414696632, -0.9554775360466866, -0.9560695325165871, -0.9567057753652759, -0.9573855614972281, -0.9581081413098184, -0.9588727198304868, -0.9596784579134775, -0.9605244734927819, -0.9614098428878165, -0.9623336021582876, -0.9632947485046242, -0.964292241710327, -0.9653250056225385, -0.9663919296671429, -0.967491870394695, -0.9686236530535085, -0.9697860731862669, -0.9709778982465644, -0.972197869231857, -0.9734447023293705, -0.9747170905716038, -0.9760137054981614, -0.9773331988207551, -0.9786742040883298, -0.9800353383493893, -0.9814152038087266, -0.9828123894758952, -0.984225472802896, -0.9856530213086927, -0.987093594188312, -0.9885457439044286, -0.9900080177594779, -0.9914789594464831, -0.9929571105769256, -0.9944410121841293, -0.9959292062007672, -0.9974202369092302, -0.9989126523637402, -1.0004050057831981, -1.0018958569139074, -1.0033837733614048, -1.0048673318907666, -1.0063451196948507, -1.0078157356300494, -1.009277791419219, -1.010729912821547, -1.0121707407692055, -1.0135989324707149, -1.015013162481026, -1.0164121237383876, -1.0177945285681433, -1.019159109653647, -1.0205046209745494, -1.021829838712753, -1.023133562126376, -1.024414614392104, -1.0256718434163439, -1.0269041226156221, -1.0281103516666952, -1.0292894572268627, -1.0304403936249864, -1.0315621435237399, -1.032653718553615, -1.033714159919224, -1.0347425389784397, -1.0357379577949135, -1.036699549664513, -1.0376264796162173, -1.0385179448879958, -1.0393731753781965, -1.0401914340729526, -1.0409720174501047, -1.0417142558601258, -1.0424175138845166, -1.0430811906721205, -1.0437047202537972, -1.0442875718358644, -1.044829250072701, -1.0453292953188889, -1.0457872838612337, -1.0462028281310038, -1.046575576896675, -1.0469052154374714, -1.0471914656979542, -1.0474340864238723, -1.0476328732795008, -1.0477876589466206, -1.0478983132052981, -1.04796474299659], [-1.038929059601267, -1.0389109343601124, -1.038856574275301, -1.0387660262540048, -1.0386393684455555, -1.038476710197483, -1.0382781919939086, -1.0380439853762333, -1.0377742928460423, -1.0374693477501367, -1.0371294141475773, -1.036754786658618, -1.036345790295387, -1.0359027802741576, -1.0354261418090405, -1.0349162898869082, -1.03437366902336, -1.0337987529995083, -1.0331920445793714, -1.0325540752076339, -1.0318854046875365, -1.0311866208386369, -1.0304583391341864, -1.029701202317857, -1.0289158799995408, -1.0281030682299561, -1.0272634890537722, -1.026397890040985, -1.0255070437962561, -1.0245917474459516, -1.0236528221025996, -1.022691112306515, -1.0217074854443295, -1.0207028311441877, -1.019678060647378, -1.01863410615619, -1.0175719201577946, -1.0164924747239834, -1.0153967607866106, -1.0142857873886146, -1.0131605809105328, -1.0120221842724395, -1.0108716561112894, -1.0097100699336763, -1.0085385132440658, -1.0073580866486038, -1.0061699029346465, -1.0049750861262208, -1.0037747705156654, -1.002570099671776, -1.0013622254248202, -1.0001523068288791, -0.9989415091020104, -0.997731002544824, -0.9965219614381169, -0.9953155629203033, -0.9941129858454422, -0.9929154096227564, -0.9917240130386111, -0.9905399730620142, -0.9893644636347705, -0.9881986544475299, -0.9870437097030379, -0.985900786867997, -0.984771035415029, -0.9836555955563185, -0.9825555969706024, -0.981472157525255, -0.9804063819953014, -0.9793593607812722, -0.9783321686278847, -0.9773258633456195, -0.976341484537315, -0.9753800523319821, -0.9744425661280869, -0.9735300033486114, -0.9726433182102407, -0.9717834405090713, -0.9709512744252604, -0.9701476973490639, -0.9693735587307252, -0.9686296789566774, -0.9679168482545313, -0.9672358256292909, -0.9665873378332343, -0.9659720783718492, -0.9653907065481799, -0.9648438465478871, -0.964332086567251, -0.9638559779862899, -0.9634160345890663, -0.9630127318331677, -0.9626465061702469, -0.9623177544193886, -0.9620268331949501, -0.9617740583903989, -0.9615597047195205, -0.9613840053162399, -0.9612471513941364, -0.9611492919665827, -0.9610905336282716, -0.9610709403987331, -0.9610905336282716, -0.9611492919665828, -0.9612471513941365, -0.9613840053162401, -0.9615597047195207, -0.9617740583903992, -0.9620268331949505, -0.9623177544193889, -0.9626465061702474, -0.9630127318331682, -0.9634160345890668, -0.9638559779862904, -0.9643320865672513, -0.9648438465478876, -0.9653907065481806, -0.96597207837185, -0.966587337833235, -0.9672358256292916, -0.9679168482545321, -0.9686296789566782, -0.9693735587307258, -0.9701476973490647, -0.9709512744252612, -0.9717834405090723, -0.9726433182102415, -0.9735300033486124, -0.974442566128088, -0.9753800523319831, -0.9763414845373161, -0.9773258633456205, -0.9783321686278859, -0.9793593607812733, -0.9804063819953025, -0.981472157525256, -0.9825555969706036, -0.9836555955563195, -0.9847710354150302, -0.9859007868679982, -0.9870437097030393, -0.9881986544475312, -0.9893644636347718, -0.9905399730620156, -0.9917240130386125, -0.9929154096227575, -0.9941129858454435, -0.9953155629203048, -0.9965219614381182, -0.9977310025448252, -0.9989415091020116, -1.0001523068288802, -1.0013622254248213, -1.002570099671777, -1.0037747705156668, -1.004975086126222, -1.0061699029346478, -1.007358086648605, -1.008538513244067, -1.0097100699336774, -1.0108716561112903, -1.0120221842724406, -1.013160580910534, -1.0142857873886155, -1.0153967607866117, -1.016492474723985, -1.0175719201577957, -1.018634106156191, -1.0196780606473792, -1.0207028311441886, -1.0217074854443307, -1.0226911123065159, -1.0236528221026007, -1.0245917474459525, -1.0255070437962575, -1.0263978900409858, -1.0272634890537733, -1.028103068229957, -1.0289158799995417, -1.0297012023178576, -1.0304583391341873, -1.0311866208386375, -1.0318854046875372, -1.0325540752076345, -1.0331920445793716, -1.0337987529995087, -1.0343736690233607, -1.0349162898869089, -1.0354261418090407, -1.035902780274158, -1.0363457902953872, -1.0367547866586184, -1.0371294141475778, -1.0374693477501369, -1.0377742928460425, -1.0380439853762333, -1.0382781919939088, -1.038476710197483, -1.0386393684455555, -1.0387660262540048, -1.0388565742753013, -1.0389109343601128], [-1.0308010008003263, -1.0307865469009239, -1.0307431979705137, -1.030670992304323, -1.0305699937005268, -1.030440291419423, -1.0302820001262505, -1.0300952598176158, -1.0298802357314902, -1.0296371182407347, -1.029366122730088, -1.0290674894565708, -1.0287414833932185, -1.0283883940560834, -1.0280085353144104, -1.027602245183907, -1.0271698856030096, -1.0267118421920456, -1.0262285239952003, -1.025720363205168, -1.0251878148703937, -1.024631356584789, -1.0240514881598146, -1.0234487312788216, -1.0228236291335444, -1.022176746042638, -1.021508667052162, -1.020819997517914, -1.0201113626695204, -1.0193834071562085, -1.0186367945741777, -1.0178722069755173, -1.0170903443586121, -1.016291924140001, -1.015477680607669, -1.0146483643557633, -1.013804741700748, -1.0129475940790318, -1.01207771742612, -1.0111959215373747, -1.0103030294104824, -1.0093998765697656, -1.0084873103724932, -1.0075661892973882, -1.0066373822155532, -1.0057017676440732, -1.0047602329825958, -1.0038136737332188, -1.00286299270406, -1.0019090991969293, -1.0009529081795565, -0.999995339442885, -0.9990373167439746, -0.9980797669351177, -0.9971236190798117, -0.9961698035562824, -0.9952192511493079, -0.9942728921311396, -0.9933316553323676, -0.9923964672036357, -0.9914682508691565, -0.9905479251730349, -0.989636403719458, -0.9887345939078582, -0.9878433959642102, -0.9869637019696731, -0.9860963948878309, -0.9852423475918357, -0.9844024218928036, -0.983577467570848, -0.9827683214101848, -0.9819758062397707, -0.9812007299809773, -0.9804438847038298, -0.9797060456933646, -0.9789879705276863, -0.9782903981693202, -0.977614048071471, -0.9769596193008047, -0.9763277896783805, -0.9757192149403526, -0.975134527920056, -0.9745743377530837, -0.9740392291069369, -0.9735297614368136, -0.9730464682690665, -0.9725898565138317, -0.9721604058082819, -0.971758567891919, -0.9713847660152609, -0.971039394383232, -0.9707228176344822, -0.9704353703578196, -0.9701773566468416, -0.9699490496937877, -0.9697506914235514, -0.9695824921686955, -0.9694446303862331, -0.9693372524168384, -0.9692604722870534, -0.9692143715549582, -0.9691989991996738, -0.9692143715549583, -0.9692604722870535, -0.9693372524168387, -0.9694446303862331, -0.9695824921686955, -0.9697506914235517, -0.969949049693788, -0.9701773566468419, -0.9704353703578199, -0.9707228176344823, -0.9710393943832322, -0.9713847660152612, -0.9717585678919192, -0.9721604058082826, -0.9725898565138321, -0.9730464682690672, -0.9735297614368141, -0.9740392291069374, -0.9745743377530843, -0.9751345279200566, -0.9757192149403532, -0.9763277896783811, -0.9769596193008052, -0.9776140480714717, -0.978290398169321, -0.978987970527687, -0.9797060456933654, -0.9804438847038306, -0.981200729980978, -0.9819758062397713, -0.9827683214101854, -0.9835774675708489, -0.9844024218928044, -0.9852423475918364, -0.9860963948878317, -0.986963701969674, -0.9878433959642111, -0.9887345939078592, -0.9896364037194592, -0.9905479251730359, -0.9914682508691574, -0.9923964672036368, -0.9933316553323687, -0.9942728921311407, -0.9952192511493088, -0.9961698035562833, -0.9971236190798126, -0.9980797669351188, -0.9990373167439753, -0.9999953394428859, -1.0009529081795574, -1.0019090991969302, -1.002862992704061, -1.0038136737332197, -1.0047602329825969, -1.005701767644074, -1.006637382215554, -1.0075661892973893, -1.008487310372494, -1.0093998765697665, -1.0103030294104833, -1.0111959215373754, -1.0120777174261208, -1.0129475940790327, -1.0138047417007492, -1.0146483643557642, -1.01547768060767, -1.0162919241400017, -1.0170903443586128, -1.0178722069755182, -1.0186367945741783, -1.019383407156209, -1.020111362669521, -1.0208199975179144, -1.0215086670521627, -1.0221767460426388, -1.022823629133545, -1.0234487312788223, -1.024051488159815, -1.0246313565847893, -1.0251878148703941, -1.0257203632051681, -1.0262285239952005, -1.026711842192046, -1.0271698856030098, -1.0276022451839077, -1.0280085353144106, -1.0283883940560838, -1.0287414833932187, -1.029067489456571, -1.0293661227300883, -1.029637118240735, -1.0298802357314907, -1.0300952598176156, -1.0302820001262507, -1.030440291419423, -1.0305699937005266, -1.030670992304323, -1.0307431979705137, -1.0307865469009243], [-1.0236105794363861, -1.02359942195341, -1.0235659595692972, -1.0235102224713435, -1.0234322609478625, -1.023332145352411, -1.0232099660536986, -1.0230658333711717, -1.0228998774962588, -1.0227122483992723, -1.0225031157219457, -1.0222726686555959, -1.0220211158048909, -1.0217486850372104, -1.0214556233175744, -1.0211421965291303, -1.0208086892791743, -1.0204554046906937, -1.0200826641794132, -1.0196908072163342, -1.019280191075752, -1.0188511905687443, -1.0184041977621283, -1.0179396216828829, -1.0174578880080423, -1.0169594387400713, -1.0164447318677405, -1.0159142410125215, -1.01536845506054, -1.0148078777801257, -1.0142330274250093, -1.0136444363232306, -1.0130426504518313, -1.0124282289974194, -1.0118017439027045, -1.0111637793991197, -1.0105149315256619, -1.0098558076340944, -1.0091870258806808, -1.0085092147046293, -1.0078230122934546, -1.0071290660354777, -1.0064280319597099, -1.0057205741633886, -1.0050073642274557, -1.0042890806202935, -1.0035664080900581, -1.002840037045977, -1.0021106629290017, -1.0013789855722428, -1.0006457085516192, -0.9999115385272196, -0.9991771845758636, -0.9984433575154071, -0.9977107692213544, -0.99698013193637, -0.9962521575733166, -0.9955275570124744, -0.9948070393936239, -0.9940913114037103, -0.9933810765608282, -0.9926770344953036, -0.9919798802286744, -0.9912903034513901, -0.9906089878000975, -0.9899366101353814, -0.9892738398208715, -0.9886213380046425, -0.9879797569038508, -0.9873497390935858, -0.9867319168009127, -0.9861269112051164, -0.985535331745159, -0.9849577754353814, -0.9843948261904854, -0.9838470541608387, -0.9833150150791566, -0.9827992496196045, -0.9823002827703718, -0.9818186232207653, -0.9813547627638517, -0.9809091757156837, -0.980482318352118, -0.9800746283642251, -0.9796865243332666, -0.9793184052261948, -0.9789706499126042, -0.9786436167040324, -0.9783376429164806, -0.9780530444569809, -0.9777901154350099, -0.9775491277994967, -0.9773303310021381, -0.9771339516876805, -0.9769601934117856, -0.9768092363870399, -0.97668123725762, -0.9765763289030664, -0.9764946202715633, -0.9764361962430662, -0.9764011175225523, -0.9763894205636138, -0.9764011175225524, -0.9764361962430663, -0.9764946202715633, -0.9765763289030663, -0.9766812372576203, -0.9768092363870401, -0.9769601934117857, -0.9771339516876808, -0.9773303310021383, -0.977549127799497, -0.9777901154350104, -0.9780530444569813, -0.9783376429164811, -0.9786436167040329, -0.9789706499126044, -0.9793184052261952, -0.9796865243332671, -0.9800746283642257, -0.9804823183521184, -0.9809091757156841, -0.9813547627638523, -0.9818186232207657, -0.9823002827703724, -0.9827992496196049, -0.9833150150791571, -0.9838470541608393, -0.9843948261904859, -0.9849577754353821, -0.9855353317451596, -0.9861269112051169, -0.9867319168009132, -0.9873497390935864, -0.9879797569038514, -0.988621338004643, -0.9892738398208724, -0.989936610135382, -0.9906089878000982, -0.9912903034513908, -0.991979880228675, -0.9926770344953044, -0.9933810765608287, -0.994091311403711, -0.9948070393936248, -0.9955275570124751, -0.9962521575733173, -0.9969801319363708, -0.9977107692213553, -0.9984433575154078, -0.9991771845758641, -0.9999115385272203, -1.0006457085516198, -1.0013789855722435, -1.0021106629290026, -1.0028400370459774, -1.003566408090059, -1.0042890806202942, -1.0050073642274564, -1.0057205741633892, -1.0064280319597105, -1.0071290660354781, -1.0078230122934553, -1.00850921470463, -1.0091870258806814, -1.0098558076340953, -1.0105149315256625, -1.0111637793991204, -1.0118017439027052, -1.01242822899742, -1.013042650451832, -1.0136444363232313, -1.01423302742501, -1.0148078777801264, -1.0153684550605406, -1.0159142410125217, -1.0164447318677412, -1.016959438740072, -1.0174578880080427, -1.0179396216828833, -1.0184041977621288, -1.0188511905687445, -1.0192801910757525, -1.0196908072163346, -1.0200826641794136, -1.020455404690694, -1.0208086892791748, -1.0211421965291307, -1.0214556233175747, -1.0217486850372106, -1.0220211158048909, -1.0222726686555959, -1.0225031157219457, -1.0227122483992725, -1.0228998774962592, -1.0230658333711717, -1.023209966053699, -1.023332145352411, -1.0234322609478628, -1.0235102224713433, -1.023565959569297, -1.02359942195341], [-1.0173647517777304, -1.0173564954743755, -1.0173317341499462, -1.0172904905554678, -1.0172328025897117, -1.017158723269789, -1.017068320689991, -1.0169616779688802, -1.0168388931846362, -1.0167000792986738, -1.016545364067539, -1.0163748899431002, -1.0161888139610515, -1.0159873076177475, -1.015770556735388, -1.015538761315587, -1.0152921353813442, -1.0150309068074592, -1.0147553171394212, -1.014465621400816, -1.014162087889295, -1.0138449979611552, -1.0135146458045914, -1.013171338201673, -1.0128153942791203, -1.0124471452479518, -1.012066934132081, -1.0116751154859562, -1.0112720551013352, -1.0108581297033035, -1.0104337266356442, -1.0099992435356895, -1.0095550879987798, -1.0091016772324792, -1.0086394377006955, -1.0081688047578758, -1.0076902222734487, -1.0072041422467057, -1.0067110244123236, -1.0062113358367393, -1.005705550505608, -1.0051941489025893, -1.0046776175797105, -1.0041564487195869, -1.00363113968978, -1.003102192589597, -1.0025701137896523, -1.0020354134645162, -1.0014986051188126, -1.000960205107121, -1.0004207321480716, -0.9998807068330302, -0.9993406511297908, -0.9988010878817045, -0.9982625403027001, -0.9977255314686537, -0.9971905838055966, -0.9966582185752534, -0.9961289553584273, -0.9956033115367591, -0.9950818017734036, -0.9945649374931813, -0.9940532263627782, -0.9935471717715738, -0.9930472723137007, -0.9925540212719365, -0.9920679061040529, -0.9915894079322494, -0.9911190010363042, -0.9906571523510945, -0.9902043209691316, -0.9897609576487688, -0.9893275043287452, -0.9889043936497228, -0.9884920484834875, -0.9880908814704717, -0.9877012945662653, -0.9873236785977707, -0.9869584128296569, -0.9866058645417621, -0.9862663886180799, -0.985940327147962, -0.9856280090401549, -0.9853297496502765, -0.9850458504223198, -0.9847765985447635, -0.9845222666218408, -0.9842831123605058, -0.9840593782736103, -0.9838512913997903, -0.9836590630405208, -0.9834828885147919, -0.9833229469318178, -0.9831794009821646, -0.9830523967476625, -0.9829420635304229, -0.9828485137012608, -0.9827718425677879, -0.9827121282624022, -0.9826694316503732, -0.9826437962581871, -0.9826352482222696, -0.982643796258187, -0.9826694316503732, -0.9827121282624022, -0.982771842567788, -0.9828485137012609, -0.9829420635304229, -0.9830523967476626, -0.9831794009821649, -0.983322946931818, -0.983482888514792, -0.983659063040521, -0.9838512913997906, -0.9840593782736107, -0.9842831123605059, -0.9845222666218413, -0.9847765985447638, -0.9850458504223201, -0.9853297496502768, -0.9856280090401552, -0.9859403271479623, -0.9862663886180802, -0.9866058645417625, -0.9869584128296572, -0.9873236785977709, -0.9877012945662658, -0.9880908814704722, -0.988492048483488, -0.9889043936497232, -0.9893275043287455, -0.9897609576487694, -0.990204320969132, -0.990657152351095, -0.9911190010363046, -0.9915894079322498, -0.9920679061040535, -0.9925540212719367, -0.9930472723137014, -0.9935471717715745, -0.9940532263627786, -0.9945649374931818, -0.9950818017734041, -0.9956033115367597, -0.996128955358428, -0.996658218575254, -0.997190583805597, -0.9977255314686542, -0.9982625403027007, -0.9988010878817052, -0.9993406511297913, -0.9998807068330309, -1.000420732148072, -1.0009602051071216, -1.0014986051188133, -1.0020354134645166, -1.0025701137896528, -1.0031021925895978, -1.0036311396897803, -1.0041564487195873, -1.004677617579711, -1.0051941489025897, -1.0057055505056087, -1.00621133583674, -1.0067110244123243, -1.0072041422467064, -1.0076902222734492, -1.0081688047578763, -1.008639437700696, -1.0091016772324797, -1.0095550879987802, -1.00999924353569, -1.0104337266356447, -1.010858129703304, -1.0112720551013357, -1.0116751154859565, -1.0120669341320816, -1.0124471452479522, -1.012815394279121, -1.0131713382016732, -1.0135146458045916, -1.0138449979611552, -1.0141620878892952, -1.0144656214008165, -1.0147553171394215, -1.0150309068074594, -1.0152921353813444, -1.0155387613155873, -1.0157705567353883, -1.015987307617748, -1.0161888139610518, -1.0163748899431004, -1.0165453640675393, -1.016700079298674, -1.0168388931846364, -1.0169616779688804, -1.0170683206899913, -1.017158723269789, -1.0172328025897117, -1.0172904905554678, -1.0173317341499462, -1.0173564954743757], [-1.0120695602592384, -1.0120637916076622, -1.0120464910365554, -1.012017674692304, -1.0119773694706233, -1.0119256129941692, -1.0118624535812126, -1.0117879502053786, -1.0117021724464759, -1.0116052004324323, -1.0114971247723612, -1.0113780464807847, -1.0112480768930492, -1.0111073375719668, -1.010955960205718, -1.0107940864970697, -1.0106218680439474, -1.0104394662114207, -1.0102470519951567, -1.0100448058764053, -1.009832917668584, -1.0096115863555324, -1.0093810199215192, -1.0091414351730794, -1.0088930575527773, -1.0086361209449828, -1.0083708674737693, -1.008097547293036, -1.0078164183689697, -1.007527746254967, -1.007231803859143, -1.0069288712045619, -1.0066192351823293, -1.0063031892976986, -1.0059810334093406, -1.0056530734619509, -1.0053196212123559, -1.0049809939493068, -1.0046375142071446, -1.0042895094735327, -1.0039373118914634, -1.0035812579557564, -1.0032216882042606, -1.0028589469040015, -1.002493381732507, -1.002125343454564, -1.0017551855946614, -1.0013832641053853, -1.0010099370320453, -1.0006355641738116, -1.0002605067416575, -0.999885127013411, -0.999509787986221, -0.9991348530267588, -0.9987606855194823, -0.9983876485132955, -0.9980161043669458, -0.9976464143935087, -0.997278938504318, -0.9969140348527028, -0.9965520594779, -0.9961933659495255, -0.9958383050129745, -0.9954872242361481, -0.9951404676578908, -0.9947983754385349, -0.9944612835129555, -0.9941295232465324, -0.9938034210944248, -0.9934832982645678, -0.9931694703847925, -0.9928622471744806, -0.9925619321211596, -0.9922688221624443, -0.9919832073737276, -0.9917053706620231, -0.9914355874663571, -0.9911741254651026, -0.9909212442906449, -0.9906771952517612, -0.99044222106409, -0.9902165555890576, -0.9900004235816249, -0.9897940404472023, -0.9895976120080737, -0.9894113342796639, -0.9892353932569623, -0.9890699647114136, -0.988915213998567, -0.9887712958767624, -0.9886383543371231, -0.9885165224450976, -0.9884059221937921, -0.9883066643693057, -0.9882188484282723, -0.9881425623877919, -0.9880778827279142, -0.9880248743068268, -0.9879835902888693, -0.9879540720854882, -0.9879363493092181, -0.9879304397407617, -0.987936349309218, -0.9879540720854882, -0.9879835902888694, -0.988024874306827, -0.9880778827279142, -0.9881425623877919, -0.9882188484282725, -0.9883066643693059, -0.9884059221937922, -0.9885165224450978, -0.9886383543371232, -0.9887712958767625, -0.988915213998567, -0.9890699647114138, -0.9892353932569624, -0.9894113342796642, -0.989597612008074, -0.9897940404472024, -0.9900004235816254, -0.9902165555890579, -0.9904422210640902, -0.9906771952517615, -0.9909212442906452, -0.991174125465103, -0.9914355874663573, -0.9917053706620234, -0.9919832073737279, -0.9922688221624446, -0.9925619321211598, -0.9928622471744808, -0.9931694703847928, -0.9934832982645682, -0.9938034210944251, -0.9941295232465324, -0.9944612835129558, -0.9947983754385352, -0.9951404676578912, -0.9954872242361487, -0.9958383050129748, -0.9961933659495258, -0.9965520594779004, -0.996914034852703, -0.9972789385043186, -0.9976464143935091, -0.998016104366946, -0.998387648513296, -0.9987606855194827, -0.9991348530267592, -0.9995097879862214, -0.9998851270134115, -1.0002605067416577, -1.0006355641738118, -1.0010099370320458, -1.0013832641053857, -1.0017551855946618, -1.0021253434545645, -1.0024933817325075, -1.0028589469040017, -1.0032216882042608, -1.0035812579557568, -1.0039373118914636, -1.004289509473533, -1.004637514207145, -1.0049809939493073, -1.0053196212123559, -1.005653073461951, -1.0059810334093409, -1.006303189297699, -1.00661923518233, -1.006928871204562, -1.0072318038591435, -1.0075277462549672, -1.00781641836897, -1.008097547293036, -1.0083708674737697, -1.008636120944983, -1.0088930575527775, -1.0091414351730796, -1.0093810199215194, -1.0096115863555326, -1.0098329176685843, -1.0100448058764055, -1.0102470519951567, -1.0104394662114207, -1.0106218680439474, -1.01079408649707, -1.010955960205718, -1.0111073375719672, -1.0112480768930494, -1.0113780464807847, -1.0114971247723612, -1.0116052004324325, -1.011702172446476, -1.0117879502053788, -1.0118624535812129, -1.0119256129941692, -1.011977369470623, -1.0120176746923042, -1.0120464910365556, -1.0120637916076625], [-1.0077301276367194, -1.0077264171130342, -1.007715289049741, -1.0076967539670425, -1.0076708293883272, -1.0076375398247492, -1.0075969167536565, -1.0075489985908768, -1.007493830656877, -1.0074314651368244, -1.0073619610345608, -1.0072853841205343, -1.0072018068737052, -1.0071113084174745, -1.0070139744496651, -1.0069098971666082, -1.0067991751813767, -1.0066819134362206, -1.0065582231092576, -1.0064282215154838, -1.0062920320021644, -1.006149783838674, -1.0060016121008601, -1.0058476575500073, -1.005688066506482, -1.0055229907181433, -1.0053525872236129, -1.005177018210495, -1.00499645086865, -1.00481105723862, -1.0046210140553193, -1.004426502587103, -1.0042277084703255, -1.0040248215395189, -1.0038180356533126, -1.0036075485162304, -1.0033935614964966, -1.0031762794399979, -1.0029559104805417, -1.0027326658465663, -1.002506759664454, -1.0022784087586114, -1.0020478324484798, -1.0018152523426422, -1.001580892130207, -1.0013449773696408, -1.0011077352752367, -1.000869394501405, -1.0006301849249755, -1.000390337425708, -1.0001500836652133, -0.999909655864482, -0.9996692865802358, -0.9994292084803051, -0.9991896541182512, -0.9989508557074499, -0.9987130448948555, -0.9984764525346697, -0.9982413084621411, -0.9980078412677242, -0.9977762780718258, -0.9975468443003751, -0.9973197634614478, -0.9970952569231822, -0.9968735436932222, -0.996654840199924, -0.9964393600755653, -0.9962273139417954, -0.99601890919756, -0.9958143498097415, -0.9956138361067508, -0.9954175645753001, -0.995225727660598, -0.9950385135701918, -0.9948561060816875, -0.9946786843545746, -0.9945064227463793, -0.9943394906333618, -0.9941780522359781, -0.9940222664493137, -0.9938722866787009, -0.9937282606807128, -0.9935903304097418, -0.993458631870343, -0.9933332949755331, -0.9932144434112198, -0.993102194506935, -0.9929966591130353, -0.9928979414845226, -0.9928061391716426, -0.9927213429173909, -0.9926436365620663, -0.9925730969549957, -0.9925097938735373, -0.9924537899494773, -0.9924051406029115, -0.9923638939836973, -0.992330090920557, -0.9923037648778954, -0.9922849419203928, -0.9922736406854145, -0.9922698723632805, -0.9922736406854146, -0.9922849419203928, -0.9923037648778955, -0.9923300909205569, -0.9923638939836974, -0.9924051406029116, -0.9924537899494775, -0.9925097938735373, -0.992573096954996, -0.9926436365620666, -0.9927213429173909, -0.9928061391716427, -0.9928979414845227, -0.9929966591130354, -0.9931021945069353, -0.9932144434112198, -0.9933332949755332, -0.9934586318703432, -0.9935903304097421, -0.993728260680713, -0.993872286678701, -0.9940222664493139, -0.9941780522359782, -0.9943394906333619, -0.9945064227463795, -0.9946786843545748, -0.9948561060816877, -0.995038513570192, -0.9952257276605981, -0.9954175645753002, -0.9956138361067508, -0.9958143498097417, -0.9960189091975602, -0.9962273139417955, -0.9964393600755658, -0.9966548401999242, -0.9968735436932226, -0.9970952569231825, -0.9973197634614479, -0.9975468443003752, -0.997776278071826, -0.9980078412677245, -0.9982413084621413, -0.9984764525346699, -0.9987130448948558, -0.9989508557074502, -0.9991896541182514, -0.9994292084803051, -0.9996692865802359, -0.9999096558644822, -1.0001500836652135, -1.0003903374257082, -1.0006301849249757, -1.0008693945014053, -1.0011077352752369, -1.0013449773696408, -1.0015808921302072, -1.0018152523426427, -1.00204783244848, -1.0022784087586116, -1.0025067596644541, -1.0027326658465667, -1.0029559104805421, -1.003176279439998, -1.0033935614964968, -1.0036075485162304, -1.0038180356533128, -1.004024821539519, -1.004227708470326, -1.0044265025871033, -1.0046210140553196, -1.00481105723862, -1.0049964508686502, -1.0051770182104953, -1.0053525872236133, -1.0055229907181436, -1.0056880665064822, -1.0058476575500075, -1.0060016121008601, -1.006149783838674, -1.0062920320021647, -1.0064282215154838, -1.0065582231092578, -1.0066819134362206, -1.006799175181377, -1.0069098971666082, -1.007013974449665, -1.0071113084174745, -1.0072018068737052, -1.0072853841205343, -1.0073619610345608, -1.0074314651368246, -1.0074938306568773, -1.0075489985908768, -1.007596916753657, -1.0076375398247492, -1.007670829388327, -1.0076967539670423, -1.0077152890497407, -1.0077264171130342], [-1.0043506520309784, -1.0043485566575947, -1.0043422725383675, -1.0043318056742314, -1.0043171660606258, -1.0042983676783217, -1.00427542848059, -1.0042483703767193, -1.004217219211897, -1.00418200474347, -1.004142760613602, -1.004099524318346, -1.0040523371731633, -1.0040012442749078, -1.0039462944603073, -1.0038875402609773, -1.0038250378550007, -1.0037588470151053, -1.0036890310534932, -1.0036156567633479, -1.003538794357084, -1.0034585174013717, -1.003374902749, -1.0032880304676257, -1.0031979837654696, -1.0031048489140189, -1.0030087151677953, -1.0029096746812605, -1.0028078224229189, -1.0027032560866984, -1.0025960760006714, -1.0024863850332018, -1.0023742884965892, -1.0022598940482979, -1.0021433115898466, -1.0020246531634538, -1.0019040328465187, -1.0017815666440364, -1.0016573723790345, -1.0015315695811302, -1.0014042793733056, -1.0012756243569993, -1.0011457284956198, -1.0010147169965795, -1.000882716191964, -1.0007498534179378, -1.000616256892997, -1.0004820555951883, -1.0003473791383966, -1.0002123576478268, -1.0000771216347906, -0.9999418018709196, -0.9998065292619196, -0.9996714347209937, -0.9995366490420525, -0.9994023027728306, -0.9992685260880405, -0.9991354486626853, -0.9990031995456508, -0.9988719070337119, -0.9987416985460705, -0.9986127004995579, -0.9984850381846224, -0.9983588356422342, -0.9982342155418283, -0.9981112990604161, -0.997990205762987, -0.997871053484329, -0.9977539582123861, -0.9976390339732832, -0.9975263927181339, -0.9974161442117555, -0.9973083959234086, -0.9972032529196806, -0.9971008177596274, -0.997001190392287, -0.9969044680566802, -0.9968107451844036, -0.9967201133049248, -0.9966326609536857, -0.9965484735831118, -0.9964676334766319, -0.996390219665801, -0.9963163078506192, -0.9962459703231406, -0.9961792758944527, -0.9961162898251157, -0.9960570737591334, -0.9960016856615385, -0.9959501797596589, -0.9959026064881349, -0.9958590124377467, -0.9958194403081185, -0.9957839288643465, -0.9957525128976039, -0.9957252231897694, -0.9957020864821203, -0.995683125448123, -0.9956683586703593, -0.9956578006216074, -0.9956514616501074, -0.9956493479690216, -0.9956514616501075, -0.9956578006216076, -0.9956683586703593, -0.9956831254481231, -0.9957020864821202, -0.9957252231897695, -0.9957525128976039, -0.9957839288643465, -0.9958194403081185, -0.9958590124377467, -0.9959026064881349, -0.9959501797596592, -0.9960016856615386, -0.9960570737591334, -0.9961162898251158, -0.9961792758944528, -0.9962459703231406, -0.9963163078506193, -0.9963902196658012, -0.9964676334766323, -0.9965484735831119, -0.9966326609536857, -0.9967201133049249, -0.9968107451844037, -0.9969044680566802, -0.9970011903922871, -0.9971008177596276, -0.9972032529196807, -0.9973083959234086, -0.9974161442117555, -0.9975263927181339, -0.9976390339732832, -0.9977539582123862, -0.997871053484329, -0.9979902057629872, -0.9981112990604161, -0.9982342155418285, -0.9983588356422343, -0.9984850381846228, -0.998612700499558, -0.9987416985460708, -0.9988719070337119, -0.9990031995456509, -0.9991354486626853, -0.9992685260880408, -0.9994023027728307, -0.9995366490420529, -0.999671434720994, -0.9998065292619195, -0.9999418018709196, -1.0000771216347908, -1.0002123576478268, -1.0003473791383968, -1.0004820555951888, -1.0006162568929975, -1.0007498534179378, -1.0008827161919642, -1.0010147169965795, -1.0011457284956198, -1.0012756243569996, -1.0014042793733056, -1.0015315695811304, -1.0016573723790345, -1.0017815666440366, -1.001904032846519, -1.0020246531634538, -1.0021433115898468, -1.0022598940482979, -1.0023742884965894, -1.0024863850332018, -1.0025960760006714, -1.0027032560866984, -1.002807822422919, -1.0029096746812605, -1.0030087151677956, -1.003104848914019, -1.0031979837654696, -1.0032880304676255, -1.003374902749, -1.0034585174013717, -1.0035387943570842, -1.003615656763348, -1.003689031053493, -1.0037588470151053, -1.0038250378550004, -1.0038875402609773, -1.003946294460307, -1.0040012442749078, -1.0040523371731633, -1.004099524318346, -1.004142760613602, -1.00418200474347, -1.004217219211897, -1.0042483703767193, -1.0042754284805904, -1.004298367678322, -1.0043171660606258, -1.0043318056742312, -1.0043422725383675, -1.004348556657595], [-1.0019344028664037, -1.001933468967583, -1.0019306681693885, -1.0019260031657715, -1.0019194784438221, -1.0019111002795276, -1.0019008767318403, -1.00188881763506, -1.0018749345895346, -1.0018592409506928, -1.001841751816413, -1.001822484012743, -1.0018014560779807, -1.001778688245132, -1.0017542024227613, -1.001728022174247, -1.0017001726954697, -1.0016706807909392, -1.0016395748483993, -1.0016068848119128, -1.0015726421534683, -1.0015368798431232, -1.0014996323177137, -1.0014609354481583, -1.0014208265053857, -1.0013793441249175, -1.0013365282701328, -1.0012924201942566, -1.0012470624010987, -1.0012004986045806, -1.0011527736870902, -1.001103933656697, -1.0010540256032705, -1.001003097653543, -1.0009511989251492, -1.0008983794796993, -1.000844690274914, -1.0007901831158754, -1.0007349106054348, -1.000678926093824, -1.0006222836275152, -1.0005650378973832, -1.0005072441862097, -1.000448958315584, -1.000390236592252, -1.000331135753957, -1.000271712914831, -1.0002120255103824, -1.0001521312421366, -1.0000920880219786, -1.0000319539162548, -0.9999717870896841, -0.9999116457491323, -0.9998515880873078, -0.9997916722264277, -0.9997319561619148, -0.9996724977061724, -0.9996133544325012, -0.9995545836192047, -0.9994962421939442, -0.9994383866783919, -0.9993810731332446, -0.9993243571036435, -0.999268293565062, -0.9992129368697101, -0.9991583406935113, -0.9991045579837032, -0.9990516409071182, -0.9989996407991901, -0.9989486081137434, -0.9988985923736138, -0.998849642122149, -0.9988018048756411, -0.9987551270767371, -0.9987096540488768, -0.9986654299518016, -0.9986224977381839, -0.9985808991114186, -0.9985406744846197, -0.9985018629408677, -0.9984645021947451, -0.9984286285552011, -0.998394276889784, -0.9983614805902806, -0.9983302715397923, -0.9983006800812897, -0.9982727349876735, -0.998246463433373, -0.9982218909675151, -0.9981990414886887, -0.9981779372213335, -0.9981585986937743, -0.9981410447179299, -0.9981252923707098, -0.9981113569771265, -0.9980992520951354, -0.9980889895022217, -0.9980805791837445, -0.9980740293230564, -0.9980693462934033, -0.9980665346516153, -0.9980655971335964, -0.9980665346516154, -0.9980693462934034, -0.9980740293230563, -0.9980805791837444, -0.9980889895022217, -0.9980992520951355, -0.9981113569771266, -0.9981252923707098, -0.9981410447179299, -0.9981585986937743, -0.9981779372213333, -0.9981990414886887, -0.9982218909675151, -0.9982464634333732, -0.9982727349876735, -0.9983006800812899, -0.9983302715397921, -0.9983614805902804, -0.9983942768897841, -0.9984286285552011, -0.9984645021947454, -0.9985018629408677, -0.9985406744846196, -0.9985808991114185, -0.9986224977381839, -0.9986654299518016, -0.9987096540488768, -0.9987551270767373, -0.998801804875641, -0.9988496421221491, -0.9988985923736139, -0.9989486081137435, -0.99899964079919, -0.9990516409071182, -0.9991045579837032, -0.9991583406935113, -0.9992129368697104, -0.9992682935650621, -0.9993243571036436, -0.9993810731332448, -0.9994383866783921, -0.9994962421939443, -0.9995545836192048, -0.9996133544325012, -0.9996724977061724, -0.9997319561619148, -0.9997916722264281, -0.9998515880873078, -0.9999116457491324, -0.9999717870896841, -1.000031953916255, -1.0000920880219786, -1.0001521312421364, -1.0002120255103826, -1.000271712914831, -1.000331135753957, -1.0003902365922521, -1.000448958315584, -1.0005072441862095, -1.0005650378973834, -1.0006222836275154, -1.0006789260938238, -1.0007349106054348, -1.0007901831158754, -1.000844690274914, -1.000898379479699, -1.0009511989251494, -1.001003097653543, -1.0010540256032707, -1.001103933656697, -1.0011527736870902, -1.0012004986045806, -1.0012470624010987, -1.0012924201942566, -1.0013365282701328, -1.0013793441249175, -1.0014208265053859, -1.001460935448158, -1.0014996323177134, -1.001536879843123, -1.0015726421534683, -1.0016068848119128, -1.0016395748483993, -1.0016706807909392, -1.0017001726954695, -1.0017280221742473, -1.0017542024227613, -1.001778688245132, -1.0018014560779804, -1.001822484012743, -1.0018417518164133, -1.0018592409506928, -1.0018749345895346, -1.00188881763506, -1.0019008767318405, -1.0019111002795273, -1.001919478443822, -1.0019260031657715, -1.0019306681693887, -1.0019334689675834], [-1.0004837177080108, -1.0004834838382894, -1.000482782455051, -1.0004816142358564, -1.0004799803092497, -1.000477882253672, -1.0004753220959437, -1.0004723023093158, -1.000468825811089, -1.0004648959598093, -1.0004605165520353, -1.000455691818687, -1.000450426420976, -1.0004447254459188, -1.0004385944014438, -1.0004320392110904, -1.00042506620831, -1.000417682130369, -1.000409894111865, -1.0004017096778606, -1.0003931367366377, -1.0003841835720846, -1.0003748588357209, -1.0003651715383655, -1.0003551310414596, -1.0003447470480498, -1.0003340295934415, -1.0003229890355325, -1.000311636044831, -1.0002999815941747, -1.0002880369481553, -1.0002758136522605, -1.0002633235217444, -1.0002505786302356, -1.0002375912980934, -1.0002243740805268, -1.0002109397554828, -1.00019730131132, -1.0001834719342744, -1.0001694649957351, -1.000155294039337, -1.0001409727678874, -1.0001265150301335, -1.0001119348073897, -1.000097246200033, -1.000082463413881, -1.0000676007464662, -1.0000526725732204, -1.0000376933335768, -1.0000226775170145, -1.000007639649046, -0.9999925942771707, -0.999977555956804, -0.999962539237196, -0.9999475586473529, -0.999932628681977, -0.9999177637874355, -0.9999029783477758, -0.9998882866707968, -0.9998737029741916, -0.9998592413717773, -0.9998449158598193, -0.9998307403034712, -0.9998167284233359, -0.9998028937821669, -0.9997892497717188, -0.9997758095997625, -0.9997625862772773, -0.999749592605829, -0.9997368411651515, -0.9997243443009429, -0.9997121141128821, -0.9997001624428877, -0.9996885008636218, -0.9996771406672557, -0.9996660928545038, -0.9996553681239428, -0.9996449768616189, -0.9996349291309596, -0.9996252346629979, -0.9996159028469165, -0.9996069427209242, -0.9995983629634732, -0.9995901718848226, -0.9995823774189612, -0.9995749871158943, -0.9995680081343047, -0.999561447234589, -0.9995553107722867, -0.999549604691898, -0.9995443345211028, -0.9995395053653842, -0.9995351219030625, -0.9995311883807442, -0.9995277086091906, -0.9995246859596113, -0.9995221233603837, -0.9995200232942038, -0.9995183877956709, -0.9995172184493079, -0.9995165163880192, -0.9995162822919892, -0.9995165163880191, -0.9995172184493077, -0.9995183877956707, -0.9995200232942036, -0.9995221233603837, -0.9995246859596115, -0.9995277086091905, -0.9995311883807443, -0.9995351219030625, -0.9995395053653842, -0.9995443345211029, -0.9995496046918979, -0.9995553107722868, -0.9995614472345891, -0.9995680081343047, -0.9995749871158945, -0.999582377418961, -0.9995901718848225, -0.9995983629634733, -0.9996069427209245, -0.9996159028469165, -0.9996252346629978, -0.9996349291309596, -0.9996449768616189, -0.9996553681239428, -0.9996660928545039, -0.9996771406672557, -0.9996885008636218, -0.9997001624428876, -0.9997121141128822, -0.999724344300943, -0.9997368411651518, -0.9997495926058289, -0.9997625862772771, -0.9997758095997625, -0.9997892497717186, -0.9998028937821668, -0.9998167284233359, -0.9998307403034713, -0.9998449158598195, -0.9998592413717773, -0.9998737029741916, -0.9998882866707969, -0.9999029783477761, -0.9999177637874355, -0.9999326286819769, -0.9999475586473532, -0.999962539237196, -0.9999775559568042, -0.9999925942771707, -1.0000076396490458, -1.0000226775170145, -1.0000376933335768, -1.0000526725732204, -1.0000676007464664, -1.0000824634138807, -1.0000972462000328, -1.0001119348073897, -1.0001265150301335, -1.0001409727678876, -1.0001552940393372, -1.000169464995735, -1.0001834719342744, -1.0001973013113201, -1.0002109397554828, -1.0002243740805266, -1.0002375912980934, -1.0002505786302356, -1.0002633235217446, -1.0002758136522605, -1.000288036948155, -1.0002999815941747, -1.000311636044831, -1.0003229890355325, -1.0003340295934418, -1.0003447470480498, -1.0003551310414596, -1.0003651715383655, -1.0003748588357209, -1.0003841835720844, -1.0003931367366377, -1.0004017096778606, -1.000409894111865, -1.0004176821303687, -1.00042506620831, -1.0004320392110906, -1.0004385944014436, -1.0004447254459188, -1.0004504264209757, -1.000455691818687, -1.000460516552035, -1.0004648959598093, -1.000468825811089, -1.0004723023093158, -1.000475322095944, -1.000477882253672, -1.0004799803092497, -1.0004816142358561, -1.000482782455051, -1.0004834838382894]]}, {\"colorbar\": {\"x\": 0.9}, \"opacity\": 0.6, \"type\": \"surface\", \"x\": [[-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151], [-3.141592653589793, -3.110487775831478, -3.0793828980731632, -3.0482780203148483, -3.0171731425565333, -2.9860682647982184, -2.9549633870399035, -2.9238585092815885, -2.8927536315232736, -2.8616487537649586, -2.8305438760066437, -2.7994389982483288, -2.768334120490014, -2.737229242731699, -2.706124364973384, -2.675019487215069, -2.643914609456754, -2.612809731698439, -2.581704853940124, -2.5505999761818092, -2.5194950984234943, -2.4883902206651793, -2.4572853429068644, -2.4261804651485495, -2.3950755873902345, -2.3639707096319196, -2.3328658318736046, -2.3017609541152897, -2.2706560763569748, -2.23955119859866, -2.208446320840345, -2.17734144308203, -2.146236565323715, -2.1151316875654, -2.084026809807085, -2.05292193204877, -2.021817054290455, -1.9907121765321403, -1.9596072987738253, -1.9285024210155104, -1.8973975432571955, -1.8662926654988805, -1.8351877877405656, -1.8040829099822506, -1.7729780322239357, -1.7418731544656207, -1.7107682767073058, -1.6796633989489909, -1.648558521190676, -1.617453643432361, -1.586348765674046, -1.555243887915731, -1.5241390101574162, -1.4930341323991012, -1.4619292546407863, -1.4308243768824713, -1.3997194991241564, -1.3686146213658414, -1.3375097436075265, -1.3064048658492116, -1.2752999880908966, -1.2441951103325817, -1.2130902325742667, -1.1819853548159518, -1.1508804770576369, -1.119775599299322, -1.088670721541007, -1.057565843782692, -1.026460966024377, -0.9953560882660621, -0.9642512105077472, -0.9331463327494323, -0.9020414549911173, -0.8709365772328024, -0.8398316994744874, -0.8087268217161725, -0.7776219439578576, -0.7465170661995426, -0.7154121884412277, -0.6843073106829127, -0.6532024329245978, -0.6220975551662828, -0.5909926774079679, -0.559887799649653, -0.528782921891338, -0.4976780441330231, -0.46657316637470814, -0.4354682886163932, -0.40436341085807825, -0.3732585330997633, -0.34215365534144837, -0.31104877758313343, -0.2799438998248185, -0.24883902206650355, -0.2177341443081886, -0.18662926654987366, -0.15552438879155872, -0.12441951103324378, -0.09331463327492884, -0.062209755516613896, -0.031104877758298954, 1.5987211554602254e-14, 0.03110487775833093, 0.06220975551664587, 0.09331463327496081, 0.12441951103327575, 0.1555243887915907, 0.18662926654990564, 0.21773414430822058, 0.24883902206653552, 0.27994389982485046, 0.3110487775831654, 0.34215365534148034, 0.3732585330997953, 0.40436341085811023, 0.43546828861642517, 0.4665731663747401, 0.49767804413305505, 0.52878292189137, 0.5598877996496849, 0.5909926774079999, 0.6220975551663148, 0.6532024329246298, 0.6843073106829447, 0.7154121884412596, 0.7465170661995746, 0.7776219439578895, 0.8087268217162045, 0.8398316994745194, 0.8709365772328344, 0.9020414549911493, 0.9331463327494642, 0.9642512105077792, 0.9953560882660941, 1.026460966024409, 1.057565843782724, 1.088670721541039, 1.1197755992993539, 1.1508804770576688, 1.1819853548159838, 1.2130902325742987, 1.2441951103326137, 1.2752999880909286, 1.3064048658492435, 1.3375097436075585, 1.3686146213658734, 1.3997194991241884, 1.4308243768825033, 1.4619292546408182, 1.4930341323991332, 1.5241390101574481, 1.555243887915763, 1.586348765674078, 1.617453643432393, 1.648558521190708, 1.6796633989490228, 1.7107682767073378, 1.7418731544656527, 1.7729780322239677, 1.8040829099822826, 1.8351877877405975, 1.8662926654989125, 1.8973975432572274, 1.9285024210155424, 1.9596072987738573, 1.9907121765321723, 2.021817054290487, 2.052921932048802, 2.084026809807117, 2.115131687565432, 2.146236565323747, 2.177341443082062, 2.208446320840377, 2.239551198598692, 2.2706560763570067, 2.3017609541153217, 2.3328658318736366, 2.3639707096319516, 2.3950755873902665, 2.4261804651485814, 2.4572853429068964, 2.4883902206652113, 2.5194950984235263, 2.550599976181841, 2.581704853940156, 2.612809731698471, 2.643914609456786, 2.675019487215101, 2.706124364973416, 2.737229242731731, 2.768334120490046, 2.7994389982483607, 2.8305438760066757, 2.8616487537649906, 2.8927536315233056, 2.9238585092816205, 2.9549633870399354, 2.9860682647982504, 3.0171731425565653, 3.0482780203148803, 3.079382898073195, 3.11048777583151]], \"y\": [[-3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793, -3.141592653589793], [-3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478, -3.110487775831478], [-3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632, -3.0793828980731632], [-3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483, -3.0482780203148483], [-3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333, -3.0171731425565333], [-2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184, -2.9860682647982184], [-2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035, -2.9549633870399035], [-2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885, -2.9238585092815885], [-2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736, -2.8927536315232736], [-2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586, -2.8616487537649586], [-2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437, -2.8305438760066437], [-2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288, -2.7994389982483288], [-2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014, -2.768334120490014], [-2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699, -2.737229242731699], [-2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384, -2.706124364973384], [-2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069, -2.675019487215069], [-2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754, -2.643914609456754], [-2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439, -2.612809731698439], [-2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124, -2.581704853940124], [-2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092, -2.5505999761818092], [-2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943, -2.5194950984234943], [-2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793, -2.4883902206651793], [-2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644, -2.4572853429068644], [-2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495, -2.4261804651485495], [-2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345, -2.3950755873902345], [-2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196, -2.3639707096319196], [-2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046, -2.3328658318736046], [-2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897, -2.3017609541152897], [-2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748, -2.2706560763569748], [-2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866, -2.23955119859866], [-2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345, -2.208446320840345], [-2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203, -2.17734144308203], [-2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715, -2.146236565323715], [-2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654, -2.1151316875654], [-2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085, -2.084026809807085], [-2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877, -2.05292193204877], [-2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455, -2.021817054290455], [-1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403, -1.9907121765321403], [-1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253, -1.9596072987738253], [-1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104, -1.9285024210155104], [-1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955, -1.8973975432571955], [-1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805, -1.8662926654988805], [-1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656, -1.8351877877405656], [-1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506, -1.8040829099822506], [-1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357, -1.7729780322239357], [-1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207, -1.7418731544656207], [-1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058, -1.7107682767073058], [-1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909, -1.6796633989489909], [-1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676, -1.648558521190676], [-1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361, -1.617453643432361], [-1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046, -1.586348765674046], [-1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731, -1.555243887915731], [-1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162, -1.5241390101574162], [-1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012, -1.4930341323991012], [-1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863, -1.4619292546407863], [-1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713, -1.4308243768824713], [-1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564, -1.3997194991241564], [-1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414, -1.3686146213658414], [-1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265, -1.3375097436075265], [-1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116, -1.3064048658492116], [-1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966, -1.2752999880908966], [-1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817, -1.2441951103325817], [-1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667, -1.2130902325742667], [-1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518, -1.1819853548159518], [-1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369, -1.1508804770576369], [-1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322, -1.119775599299322], [-1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007, -1.088670721541007], [-1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692, -1.057565843782692], [-1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377, -1.026460966024377], [-0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621, -0.9953560882660621], [-0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472, -0.9642512105077472], [-0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323, -0.9331463327494323], [-0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173, -0.9020414549911173], [-0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024, -0.8709365772328024], [-0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874, -0.8398316994744874], [-0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725, -0.8087268217161725], [-0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576, -0.7776219439578576], [-0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426, -0.7465170661995426], [-0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277, -0.7154121884412277], [-0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127, -0.6843073106829127], [-0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978, -0.6532024329245978], [-0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828, -0.6220975551662828], [-0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679, -0.5909926774079679], [-0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653, -0.559887799649653], [-0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338, -0.528782921891338], [-0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231, -0.4976780441330231], [-0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814, -0.46657316637470814], [-0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932, -0.4354682886163932], [-0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825, -0.40436341085807825], [-0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633, -0.3732585330997633], [-0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837, -0.34215365534144837], [-0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343, -0.31104877758313343], [-0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185, -0.2799438998248185], [-0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355, -0.24883902206650355], [-0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886, -0.2177341443081886], [-0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366, -0.18662926654987366], [-0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872, -0.15552438879155872], [-0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378, -0.12441951103324378], [-0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884, -0.09331463327492884], [-0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896, -0.062209755516613896], [-0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954, -0.031104877758298954], [1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14, 1.5987211554602254e-14], [0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093, 0.03110487775833093], [0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587, 0.06220975551664587], [0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081, 0.09331463327496081], [0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575, 0.12441951103327575], [0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907, 0.1555243887915907], [0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564, 0.18662926654990564], [0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058, 0.21773414430822058], [0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552, 0.24883902206653552], [0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046, 0.27994389982485046], [0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654, 0.3110487775831654], [0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034, 0.34215365534148034], [0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953, 0.3732585330997953], [0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023, 0.40436341085811023], [0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517, 0.43546828861642517], [0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401, 0.4665731663747401], [0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505, 0.49767804413305505], [0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137, 0.52878292189137], [0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849, 0.5598877996496849], [0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999, 0.5909926774079999], [0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148, 0.6220975551663148], [0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298, 0.6532024329246298], [0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447, 0.6843073106829447], [0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596, 0.7154121884412596], [0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746, 0.7465170661995746], [0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895, 0.7776219439578895], [0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045, 0.8087268217162045], [0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194, 0.8398316994745194], [0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344, 0.8709365772328344], [0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493, 0.9020414549911493], [0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642, 0.9331463327494642], [0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792, 0.9642512105077792], [0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941, 0.9953560882660941], [1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409, 1.026460966024409], [1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724, 1.057565843782724], [1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039, 1.088670721541039], [1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539, 1.1197755992993539], [1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688, 1.1508804770576688], [1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838, 1.1819853548159838], [1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987, 1.2130902325742987], [1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137, 1.2441951103326137], [1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286, 1.2752999880909286], [1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435, 1.3064048658492435], [1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585, 1.3375097436075585], [1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734, 1.3686146213658734], [1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884, 1.3997194991241884], [1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033, 1.4308243768825033], [1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182, 1.4619292546408182], [1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332, 1.4930341323991332], [1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481, 1.5241390101574481], [1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763, 1.555243887915763], [1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078, 1.586348765674078], [1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393, 1.617453643432393], [1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708, 1.648558521190708], [1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228, 1.6796633989490228], [1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378, 1.7107682767073378], [1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527, 1.7418731544656527], [1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677, 1.7729780322239677], [1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826, 1.8040829099822826], [1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975, 1.8351877877405975], [1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125, 1.8662926654989125], [1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274, 1.8973975432572274], [1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424, 1.9285024210155424], [1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573, 1.9596072987738573], [1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723, 1.9907121765321723], [2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487, 2.021817054290487], [2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802, 2.052921932048802], [2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117, 2.084026809807117], [2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432, 2.115131687565432], [2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747, 2.146236565323747], [2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062, 2.177341443082062], [2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377, 2.208446320840377], [2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692, 2.239551198598692], [2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067, 2.2706560763570067], [2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217, 2.3017609541153217], [2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366, 2.3328658318736366], [2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516, 2.3639707096319516], [2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665, 2.3950755873902665], [2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814, 2.4261804651485814], [2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964, 2.4572853429068964], [2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113, 2.4883902206652113], [2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263, 2.5194950984235263], [2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841, 2.550599976181841], [2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156, 2.581704853940156], [2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471, 2.612809731698471], [2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786, 2.643914609456786], [2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101, 2.675019487215101], [2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416, 2.706124364973416], [2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731, 2.737229242731731], [2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046, 2.768334120490046], [2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607, 2.7994389982483607], [2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757, 2.8305438760066757], [2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906, 2.8616487537649906], [2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056, 2.8927536315233056], [2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205, 2.9238585092816205], [2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354, 2.9549633870399354], [2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504, 2.9860682647982504], [3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653, 3.0171731425565653], [3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803, 3.0482780203148803], [3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195, 3.079382898073195], [3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151, 3.11048777583151]], \"z\": [[1.0, 1.0, 0.9999999999999999, 1.0, 1.0000000000000002, 1.0, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0000000000000002, 1.0, 1.0000000000000002, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0000000000000002, 1.0, 0.9999999999999999, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0000000000000002, 1.0, 1.0, 1.0, 1.0000000000000002, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 1.0000000000000002, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0000000000000002, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0000000000000002, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0000000000000002, 1.0, 1.0000000000000002, 1.0, 1.0, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0000000000000002, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0000000000000002, 1.0, 0.9999999999999998, 0.9999999999999999, 0.9999999999999999, 0.9999999999999999, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 0.9999999999999999, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0, 0.9999999999999999, 1.0, 1.0, 0.9999999999999999, 1.0, 0.9999999999999998, 1.0, 1.0, 1.0, 0.9999999999999999, 0.9999999999999999, 1.0, 1.0, 1.0, 1.0, 0.9999999999999999, 1.0000000000000002], [1.0004837177080117, 1.0004834838382903, 1.0004827824550522, 1.0004816142358575, 1.0004799803092508, 1.0004778822536728, 1.0004753220959446, 1.000472302309317, 1.00046882581109, 1.0004648959598101, 1.000460516552036, 1.000455691818688, 1.0004504264209768, 1.0004447254459197, 1.0004385944014447, 1.0004320392110913, 1.0004250662083112, 1.0004176821303699, 1.000409894111866, 1.0004017096778615, 1.0003931367366383, 1.0003841835720853, 1.0003748588357217, 1.0003651715383663, 1.0003551310414602, 1.0003447470480504, 1.0003340295934422, 1.0003229890355332, 1.0003116360448314, 1.0002999815941753, 1.0002880369481557, 1.0002758136522611, 1.000263323521745, 1.0002505786302363, 1.0002375912980939, 1.0002243740805272, 1.0002109397554833, 1.0001973013113203, 1.0001834719342748, 1.0001694649957356, 1.0001552940393375, 1.0001409727678876, 1.000126515030134, 1.00011193480739, 1.0000972462000333, 1.0000824634138812, 1.0000676007464664, 1.0000526725732204, 1.0000376933335768, 1.0000226775170145, 1.000007639649046, 0.9999925942771707, 0.999977555956804, 0.999962539237196, 0.9999475586473529, 0.9999326286819769, 0.9999177637874352, 0.9999029783477758, 0.9998882866707965, 0.9998737029741914, 0.999859241371777, 0.999844915859819, 0.999830740303471, 0.9998167284233356, 0.9998028937821662, 0.9997892497717181, 0.9997758095997621, 0.999762586277277, 0.9997495926058284, 0.9997368411651512, 0.9997243443009424, 0.9997121141128815, 0.9997001624428871, 0.9996885008636212, 0.999677140667255, 0.9996660928545031, 0.9996553681239421, 0.9996449768616181, 0.999634929130959, 0.9996252346629971, 0.9996159028469157, 0.9996069427209235, 0.9995983629634723, 0.9995901718848216, 0.9995823774189602, 0.9995749871158935, 0.9995680081343037, 0.9995614472345881, 0.9995553107722857, 0.9995496046918969, 0.9995443345211019, 0.9995395053653833, 0.9995351219030616, 0.9995311883807432, 0.9995277086091896, 0.9995246859596103, 0.9995221233603827, 0.9995200232942028, 0.9995183877956699, 0.9995172184493069, 0.9995165163880182, 0.9995162822919882, 0.9995165163880181, 0.9995172184493067, 0.9995183877956697, 0.9995200232942029, 0.9995221233603827, 0.9995246859596104, 0.9995277086091895, 0.9995311883807433, 0.9995351219030617, 0.9995395053653834, 0.9995443345211018, 0.999549604691897, 0.9995553107722859, 0.9995614472345881, 0.9995680081343037, 0.9995749871158937, 0.9995823774189603, 0.9995901718848217, 0.9995983629634725, 0.9996069427209237, 0.9996159028469156, 0.9996252346629972, 0.9996349291309587, 0.999644976861618, 0.9996553681239421, 0.9996660928545033, 0.999677140667255, 0.9996885008636212, 0.999700162442887, 0.9997121141128816, 0.9997243443009423, 0.999736841165151, 0.9997495926058283, 0.9997625862772768, 0.9997758095997622, 0.9997892497717181, 0.9998028937821665, 0.9998167284233355, 0.9998307403034709, 0.999844915859819, 0.9998592413717768, 0.9998737029741915, 0.9998882866707967, 0.9999029783477759, 0.9999177637874352, 0.9999326286819769, 0.999947558647353, 0.9999625392371958, 0.9999775559568042, 0.9999925942771707, 1.0000076396490458, 1.0000226775170145, 1.0000376933335768, 1.0000526725732204, 1.0000676007464666, 1.000082463413881, 1.000097246200033, 1.00011193480739, 1.000126515030134, 1.0001409727678878, 1.0001552940393375, 1.0001694649957353, 1.0001834719342746, 1.0001973013113206, 1.0002109397554833, 1.000224374080527, 1.0002375912980939, 1.0002505786302363, 1.0002633235217453, 1.0002758136522611, 1.0002880369481557, 1.0002999815941753, 1.0003116360448316, 1.0003229890355332, 1.0003340295934424, 1.0003447470480504, 1.0003551310414602, 1.0003651715383661, 1.0003748588357217, 1.0003841835720853, 1.0003931367366383, 1.0004017096778615, 1.0004098941118658, 1.0004176821303696, 1.000425066208311, 1.0004320392110915, 1.0004385944014444, 1.0004447254459197, 1.0004504264209766, 1.0004556918186878, 1.0004605165520362, 1.0004648959598104, 1.00046882581109, 1.0004723023093167, 1.0004753220959448, 1.0004778822536728, 1.0004799803092506, 1.0004816142358572, 1.0004827824550522, 1.0004834838382903], [1.0019344028664054, 1.0019334689675852, 1.0019306681693905, 1.0019260031657735, 1.0019194784438241, 1.0019111002795296, 1.0019008767318422, 1.0018888176350618, 1.0018749345895364, 1.0018592409506948, 1.001841751816415, 1.001822484012745, 1.0018014560779824, 1.001778688245134, 1.001754202422763, 1.0017280221742488, 1.0017001726954713, 1.0016706807909412, 1.0016395748484008, 1.0016068848119142, 1.0015726421534699, 1.0015368798431248, 1.001499632317715, 1.0014609354481598, 1.0014208265053872, 1.0013793441249188, 1.001336528270134, 1.0012924201942581, 1.0012470624010998, 1.001200498604582, 1.0011527736870913, 1.001103933656698, 1.0010540256032716, 1.0010030976535438, 1.00095119892515, 1.0008983794797002, 1.0008446902749146, 1.000790183115876, 1.0007349106054357, 1.0006789260938245, 1.0006222836275158, 1.0005650378973838, 1.0005072441862102, 1.0004489583155847, 1.0003902365922523, 1.0003311357539575, 1.0002717129148313, 1.0002120255103826, 1.0001521312421366, 1.0000920880219788, 1.0000319539162548, 0.9999717870896841, 0.9999116457491323, 0.9998515880873076, 0.9997916722264277, 0.9997319561619146, 0.999672497706172, 0.9996133544325008, 0.9995545836192044, 0.9994962421939436, 0.9994383866783915, 0.999381073133244, 0.9993243571036429, 0.9992682935650614, 0.9992129368697094, 0.9991583406935104, 0.9991045579837022, 0.9990516409071173, 0.998999640799189, 0.9989486081137423, 0.9988985923736127, 0.9988496421221478, 0.9988018048756399, 0.998755127076736, 0.9987096540488756, 0.9986654299518002, 0.9986224977381825, 0.9985808991114171, 0.998540674484618, 0.9985018629408662, 0.9984645021947437, 0.9984286285551993, 0.9983942768897826, 0.9983614805902787, 0.9983302715397906, 0.998300680081288, 0.9982727349876717, 0.9982464634333712, 0.9982218909675131, 0.9981990414886867, 0.9981779372213314, 0.9981585986937724, 0.998141044717928, 0.9981252923707079, 0.9981113569771244, 0.9980992520951336, 0.9980889895022197, 0.9980805791837425, 0.9980740293230544, 0.9980693462934015, 0.9980665346516133, 0.9980655971335944, 0.9980665346516134, 0.9980693462934014, 0.9980740293230546, 0.9980805791837424, 0.9980889895022197, 0.9980992520951337, 0.9981113569771245, 0.998125292370708, 0.998141044717928, 0.9981585986937724, 0.9981779372213314, 0.9981990414886868, 0.9982218909675133, 0.9982464634333712, 0.9982727349876719, 0.998300680081288, 0.9983302715397906, 0.9983614805902788, 0.9983942768897827, 0.9984286285551995, 0.9984645021947437, 0.9985018629408662, 0.9985406744846181, 0.998580899111417, 0.9986224977381826, 0.9986654299518003, 0.9987096540488756, 0.9987551270767359, 0.9988018048756397, 0.9988496421221479, 0.9988985923736128, 0.9989486081137424, 0.9989996407991891, 0.9990516409071172, 0.9991045579837022, 0.9991583406935105, 0.9992129368697095, 0.9992682935650613, 0.999324357103643, 0.9993810731332439, 0.9994383866783915, 0.9994962421939436, 0.9995545836192044, 0.9996133544325008, 0.999672497706172, 0.9997319561619146, 0.9997916722264278, 0.9998515880873076, 0.9999116457491322, 0.9999717870896841, 1.000031953916255, 1.0000920880219788, 1.0001521312421366, 1.0002120255103828, 1.0002717129148315, 1.0003311357539575, 1.0003902365922523, 1.0004489583155844, 1.0005072441862102, 1.000565037897384, 1.000622283627516, 1.0006789260938247, 1.0007349106054357, 1.0007901831158763, 1.0008446902749148, 1.0008983794797002, 1.00095119892515, 1.001003097653544, 1.0010540256032718, 1.001103933656698, 1.0011527736870915, 1.001200498604582, 1.0012470624011, 1.001292420194258, 1.0013365282701343, 1.001379344124919, 1.0014208265053874, 1.0014609354481596, 1.0014996323177152, 1.0015368798431248, 1.00157264215347, 1.0016068848119142, 1.001639574848401, 1.001670680790941, 1.0017001726954713, 1.001728022174249, 1.0017542024227628, 1.001778688245134, 1.0018014560779824, 1.001822484012745, 1.001841751816415, 1.0018592409506948, 1.0018749345895366, 1.0018888176350618, 1.0019008767318425, 1.0019111002795293, 1.001919478443824, 1.0019260031657735, 1.0019306681693905, 1.0019334689675852], [1.0043506520309813, 1.0043485566575978, 1.0043422725383706, 1.0043318056742343, 1.004317166060629, 1.0042983676783248, 1.004275428480593, 1.0042483703767222, 1.0042172192118999, 1.0041820047434729, 1.0041427606136046, 1.0040995243183488, 1.0040523371731662, 1.0040012442749104, 1.00394629446031, 1.00388754026098, 1.003825037855003, 1.003758847015108, 1.0036890310534956, 1.0036156567633503, 1.0035387943570864, 1.0034585174013742, 1.0033749027490022, 1.003288030467628, 1.0031979837654716, 1.0031048489140209, 1.0030087151677975, 1.0029096746812625, 1.0028078224229209, 1.0027032560867002, 1.0025960760006731, 1.0024863850332033, 1.0023742884965907, 1.0022598940482994, 1.0021433115898482, 1.0020246531634553, 1.00190403284652, 1.0017815666440375, 1.0016573723790354, 1.0015315695811313, 1.0014042793733064, 1.0012756243570002, 1.0011457284956204, 1.00101471699658, 1.0008827161919647, 1.0007498534179382, 1.0006162568929975, 1.0004820555951888, 1.0003473791383968, 1.0002123576478268, 1.0000771216347908, 0.9999418018709196, 0.9998065292619194, 0.9996714347209935, 0.9995366490420523, 0.9994023027728302, 0.9992685260880401, 0.9991354486626847, 0.99900319954565, 0.998871907033711, 0.9987416985460698, 0.998612700499557, 0.9984850381846213, 0.998358835642233, 0.9982342155418271, 0.9981112990604146, 0.9979902057629857, 0.9978710534843277, 0.9977539582123846, 0.9976390339732815, 0.997526392718132, 0.9974161442117535, 0.9973083959234067, 0.9972032529196787, 0.9971008177596252, 0.997001190392285, 0.9969044680566781, 0.9968107451844015, 0.9967201133049225, 0.9966326609536833, 0.9965484735831095, 0.9964676334766295, 0.9963902196657984, 0.9963163078506165, 0.9962459703231379, 0.99617927589445, 0.996116289825113, 0.9960570737591306, 0.9960016856615358, 0.9959501797596564, 0.9959026064881321, 0.9958590124377437, 0.9958194403081156, 0.9957839288643436, 0.995752512897601, 0.9957252231897666, 0.9957020864821172, 0.9956831254481202, 0.9956683586703563, 0.9956578006216044, 0.9956514616501044, 0.9956493479690186, 0.9956514616501045, 0.9956578006216046, 0.9956683586703563, 0.9956831254481201, 0.9957020864821174, 0.9957252231897665, 0.9957525128976011, 0.9957839288643436, 0.9958194403081159, 0.9958590124377438, 0.9959026064881321, 0.9959501797596564, 0.996001685661536, 0.9960570737591308, 0.996116289825113, 0.9961792758944502, 0.9962459703231381, 0.9963163078506168, 0.9963902196657987, 0.9964676334766296, 0.9965484735831095, 0.9966326609536834, 0.9967201133049226, 0.9968107451844014, 0.9969044680566782, 0.997001190392285, 0.9971008177596256, 0.9972032529196788, 0.9973083959234067, 0.9974161442117537, 0.9975263927181323, 0.9976390339732818, 0.9977539582123847, 0.9978710534843277, 0.9979902057629859, 0.9981112990604146, 0.9982342155418272, 0.9983588356422332, 0.9984850381846216, 0.9986127004995571, 0.9987416985460696, 0.9988719070337111, 0.9990031995456502, 0.9991354486626849, 0.9992685260880404, 0.9994023027728303, 0.9995366490420524, 0.9996714347209937, 0.9998065292619195, 0.9999418018709196, 1.000077121634791, 1.000212357647827, 1.000347379138397, 1.000482055595189, 1.000616256892998, 1.0007498534179384, 1.000882716191965, 1.0010147169965802, 1.0011457284956204, 1.0012756243570005, 1.0014042793733067, 1.0015315695811313, 1.0016573723790356, 1.001781566644038, 1.00190403284652, 1.0020246531634551, 1.0021433115898484, 1.0022598940482994, 1.002374288496591, 1.0024863850332033, 1.0025960760006731, 1.0027032560867002, 1.002807822422921, 1.0029096746812625, 1.0030087151677978, 1.0031048489140213, 1.0031979837654719, 1.0032880304676277, 1.0033749027490024, 1.0034585174013742, 1.0035387943570866, 1.0036156567633503, 1.0036890310534956, 1.003758847015108, 1.003825037855003, 1.0038875402609801, 1.0039462944603097, 1.0040012442749107, 1.0040523371731662, 1.0040995243183486, 1.0041427606136046, 1.004182004743473, 1.0042172192118999, 1.0042483703767222, 1.0042754284805933, 1.004298367678325, 1.0043171660606287, 1.004331805674234, 1.0043422725383704, 1.0043485566575978], [1.0077301276367234, 1.007726417113038, 1.0077152890497447, 1.0076967539670463, 1.0076708293883312, 1.0076375398247532, 1.0075969167536605, 1.0075489985908808, 1.0074938306568808, 1.007431465136828, 1.0073619610345645, 1.0072853841205378, 1.007201806873709, 1.007111308417478, 1.0070139744496684, 1.0069098971666117, 1.0067991751813805, 1.006681913436224, 1.006558223109261, 1.0064282215154872, 1.0062920320021675, 1.006149783838677, 1.0060016121008633, 1.0058476575500104, 1.005688066506485, 1.0055229907181462, 1.0053525872236155, 1.0051770182104978, 1.0049964508686524, 1.0048110572386224, 1.0046210140553218, 1.0044265025871055, 1.0042277084703277, 1.0040248215395209, 1.0038180356533146, 1.0036075485162321, 1.0033935614964984, 1.0031762794399997, 1.0029559104805434, 1.0027326658465676, 1.0025067596644552, 1.0022784087586125, 1.002047832448481, 1.0018152523426433, 1.0015808921302078, 1.0013449773696412, 1.001107735275237, 1.0008693945014056, 1.0006301849249757, 1.0003903374257082, 1.0001500836652133, 0.9999096558644818, 0.9996692865802356, 0.9994292084803047, 0.9991896541182508, 0.9989508557074495, 0.9987130448948549, 0.998476452534669, 0.9982413084621402, 0.9980078412677231, 0.9977762780718248, 0.9975468443003739, 0.9973197634614464, 0.9970952569231808, 0.9968735436932208, 0.9966548401999225, 0.9964393600755636, 0.9962273139417936, 0.9960189091975579, 0.9958143498097395, 0.9956138361067485, 0.9954175645752977, 0.9952257276605956, 0.9950385135701892, 0.9948561060816848, 0.994678684354572, 0.9945064227463765, 0.9943394906333591, 0.994178052235975, 0.9940222664493108, 0.9938722866786979, 0.9937282606807096, 0.9935903304097385, 0.9934586318703398, 0.9933332949755297, 0.9932144434112163, 0.9931021945069317, 0.9929966591130316, 0.9928979414845192, 0.9928061391716391, 0.9927213429173872, 0.9926436365620627, 0.992573096954992, 0.9925097938735336, 0.9924537899494735, 0.9924051406029076, 0.9923638939836935, 0.9923300909205531, 0.9923037648778917, 0.992284941920389, 0.9922736406854106, 0.9922698723632766, 0.9922736406854107, 0.992284941920389, 0.9923037648778915, 0.9923300909205532, 0.9923638939836935, 0.9924051406029076, 0.9924537899494738, 0.9925097938735336, 0.9925730969549921, 0.9926436365620629, 0.9927213429173871, 0.992806139171639, 0.9928979414845192, 0.9929966591130317, 0.9931021945069317, 0.9932144434112166, 0.9933332949755298, 0.9934586318703398, 0.9935903304097389, 0.9937282606807099, 0.9938722866786978, 0.9940222664493109, 0.9941780522359751, 0.9943394906333591, 0.9945064227463768, 0.9946786843545723, 0.9948561060816851, 0.9950385135701896, 0.9952257276605958, 0.9954175645752978, 0.9956138361067488, 0.9958143498097398, 0.9960189091975581, 0.9962273139417938, 0.9964393600755638, 0.9966548401999226, 0.9968735436932209, 0.997095256923181, 0.9973197634614467, 0.997546844300374, 0.9977762780718249, 0.9980078412677235, 0.9982413084621404, 0.9984764525346692, 0.9987130448948551, 0.9989508557074496, 0.999189654118251, 0.9994292084803049, 0.9996692865802357, 0.999909655864482, 1.0001500836652135, 1.0003903374257084, 1.0006301849249761, 1.0008693945014058, 1.0011077352752376, 1.0013449773696415, 1.001580892130208, 1.0018152523426436, 1.0020478324484812, 1.0022784087586127, 1.0025067596644552, 1.0027326658465678, 1.0029559104805434, 1.0031762794399999, 1.0033935614964984, 1.0036075485162321, 1.0038180356533148, 1.004024821539521, 1.004227708470328, 1.0044265025871055, 1.004621014055322, 1.0048110572386224, 1.0049964508686529, 1.005177018210498, 1.0053525872236158, 1.0055229907181464, 1.0056880665064851, 1.0058476575500104, 1.0060016121008633, 1.006149783838677, 1.0062920320021678, 1.0064282215154872, 1.006558223109261, 1.0066819134362242, 1.0067991751813803, 1.0069098971666117, 1.0070139744496684, 1.0071113084174783, 1.0072018068737087, 1.007285384120538, 1.0073619610345645, 1.0074314651368281, 1.007493830656881, 1.0075489985908805, 1.0075969167536607, 1.007637539824753, 1.007670829388331, 1.0076967539670463, 1.0077152890497447, 1.0077264171130382], [1.0120695602592433, 1.0120637916076674, 1.0120464910365605, 1.012017674692309, 1.0119773694706282, 1.0119256129941743, 1.0118624535812175, 1.0117879502053835, 1.0117021724464808, 1.0116052004324372, 1.0114971247723659, 1.0113780464807893, 1.011248076893054, 1.0111073375719715, 1.0109559602057228, 1.0107940864970741, 1.0106218680439518, 1.0104394662114249, 1.010247051995161, 1.0100448058764095, 1.009832917668588, 1.0096115863555366, 1.009381019921523, 1.0091414351730834, 1.008893057552781, 1.0086361209449861, 1.0083708674737726, 1.0080975472930394, 1.0078164183689728, 1.00752774625497, 1.0072318038591461, 1.0069288712045648, 1.0066192351823322, 1.0063031892977012, 1.005981033409343, 1.005653073461953, 1.005319621212358, 1.004980993949309, 1.0046375142071469, 1.0042895094735342, 1.0039373118914652, 1.0035812579557577, 1.003221688204262, 1.0028589469040026, 1.0024933817325081, 1.0021253434545652, 1.0017551855946623, 1.001383264105386, 1.0010099370320458, 1.0006355641738118, 1.0002605067416577, 0.999885127013411, 0.9995097879862208, 0.9991348530267585, 0.9987606855194818, 0.9983876485132949, 0.9980161043669449, 0.9976464143935078, 0.997278938504317, 0.9969140348527016, 0.9965520594778987, 0.9961933659495238, 0.9958383050129729, 0.9954872242361464, 0.9951404676578888, 0.9947983754385327, 0.9944612835129532, 0.9941295232465298, 0.9938034210944222, 0.9934832982645653, 0.9931694703847898, 0.9928622471744777, 0.9925619321211566, 0.992268822162441, 0.9919832073737243, 0.9917053706620197, 0.9914355874663535, 0.991174125465099, 0.9909212442906412, 0.9906771952517575, 0.9904422210640861, 0.9902165555890536, 0.9900004235816209, 0.9897940404471981, 0.9895976120080695, 0.9894113342796595, 0.9892353932569579, 0.9890699647114093, 0.9889152139985623, 0.9887712958767577, 0.9886383543371184, 0.9885165224450928, 0.9884059221937873, 0.988306664369301, 0.9882188484282675, 0.9881425623877867, 0.9880778827279092, 0.9880248743068218, 0.9879835902888645, 0.9879540720854832, 0.9879363493092131, 0.9879304397407567, 0.987936349309213, 0.9879540720854832, 0.9879835902888645, 0.988024874306822, 0.9880778827279091, 0.988142562387787, 0.9882188484282675, 0.9883066643693011, 0.9884059221937874, 0.9885165224450929, 0.9886383543371186, 0.9887712958767577, 0.9889152139985625, 0.9890699647114095, 0.9892353932569581, 0.9894113342796599, 0.9895976120080696, 0.9897940404471983, 0.9900004235816211, 0.9902165555890537, 0.9904422210640863, 0.9906771952517577, 0.9909212442906414, 0.9911741254650993, 0.9914355874663537, 0.9917053706620199, 0.9919832073737246, 0.9922688221624414, 0.9925619321211568, 0.9928622471744778, 0.9931694703847901, 0.9934832982645656, 0.9938034210944224, 0.99412952324653, 0.9944612835129537, 0.994798375438533, 0.9951404676578892, 0.9954872242361468, 0.9958383050129731, 0.9961933659495243, 0.9965520594778992, 0.996914034852702, 0.9972789385043175, 0.9976464143935083, 0.9980161043669451, 0.9983876485132953, 0.9987606855194824, 0.9991348530267588, 0.9995097879862211, 0.9998851270134115, 1.000260506741658, 1.0006355641738123, 1.0010099370320462, 1.0013832641053864, 1.0017551855946627, 1.0021253434545654, 1.0024933817325083, 1.0028589469040028, 1.0032216882042622, 1.0035812579557581, 1.0039373118914654, 1.0042895094735347, 1.004637514207147, 1.0049809939493095, 1.0053196212123583, 1.0056530734619533, 1.0059810334093435, 1.0063031892977017, 1.0066192351823327, 1.006928871204565, 1.0072318038591463, 1.0075277462549703, 1.0078164183689733, 1.0080975472930396, 1.008370867473773, 1.0086361209449868, 1.0088930575527812, 1.0091414351730834, 1.0093810199215232, 1.0096115863555368, 1.0098329176685883, 1.0100448058764095, 1.010247051995161, 1.0104394662114249, 1.0106218680439518, 1.0107940864970741, 1.0109559602057225, 1.0111073375719717, 1.011248076893054, 1.0113780464807893, 1.0114971247723659, 1.0116052004324374, 1.011702172446481, 1.0117879502053837, 1.011862453581218, 1.0119256129941743, 1.011977369470628, 1.012017674692309, 1.0120464910365605, 1.0120637916076674], [1.0173647517777364, 1.0173564954743815, 1.0173317341499521, 1.0172904905554738, 1.017232802589718, 1.017158723269795, 1.0170683206899969, 1.0169616779688861, 1.016838893184642, 1.0167000792986798, 1.0165453640675448, 1.016374889943106, 1.0161888139610575, 1.015987307617753, 1.0157705567353934, 1.0155387613155924, 1.0152921353813495, 1.0150309068074646, 1.0147553171394266, 1.0144656214008212, 1.0141620878892996, 1.01384499796116, 1.0135146458045958, 1.0131713382016774, 1.0128153942791247, 1.0124471452479562, 1.0120669341320851, 1.01167511548596, 1.0112720551013392, 1.0108581297033072, 1.0104337266356478, 1.009999243535693, 1.0095550879987831, 1.0091016772324823, 1.0086394377006986, 1.0081688047578787, 1.0076902222734514, 1.0072041422467084, 1.006711024412326, 1.0062113358367415, 1.0057055505056103, 1.005194148902591, 1.0046776175797123, 1.0041564487195884, 1.0036311396897812, 1.0031021925895982, 1.0025701137896532, 1.0020354134645169, 1.0014986051188133, 1.0009602051071214, 1.0004207321480718, 0.9998807068330302, 0.9993406511297905, 0.9988010878817043, 0.9982625403026995, 0.9977255314686531, 0.9971905838055957, 0.9966582185752523, 0.996128955358426, 0.9956033115367577, 0.9950818017734018, 0.9945649374931794, 0.994053226362776, 0.9935471717715716, 0.9930472723136985, 0.9925540212719338, 0.9920679061040502, 0.9915894079322465, 0.9911190010363011, 0.9906571523510913, 0.9902043209691282, 0.9897609576487653, 0.9893275043287415, 0.9889043936497189, 0.9884920484834837, 0.9880908814704678, 0.9877012945662611, 0.9873236785977663, 0.9869584128296525, 0.9866058645417575, 0.9862663886180753, 0.985940327147957, 0.98562800904015, 0.9853297496502714, 0.9850458504223146, 0.9847765985447582, 0.9845222666218356, 0.9842831123605003, 0.984059378273605, 0.9838512913997847, 0.9836590630405152, 0.9834828885147863, 0.9833229469318119, 0.9831794009821588, 0.9830523967476568, 0.982942063530417, 0.9828485137012549, 0.9827718425677819, 0.9827121282623962, 0.9826694316503672, 0.9826437962581811, 0.9826352482222636, 0.982643796258181, 0.9826694316503675, 0.9827121282623962, 0.982771842567782, 0.982848513701255, 0.982942063530417, 0.983052396747657, 0.983179400982159, 0.983322946931812, 0.9834828885147864, 0.9836590630405152, 0.9838512913997849, 0.9840593782736051, 0.9842831123605007, 0.9845222666218358, 0.9847765985447587, 0.985045850422315, 0.9853297496502716, 0.9856280090401504, 0.9859403271479575, 0.9862663886180756, 0.9866058645417579, 0.9869584128296527, 0.9873236785977667, 0.9877012945662615, 0.9880908814704682, 0.988492048483484, 0.9889043936497195, 0.9893275043287418, 0.9897609576487658, 0.9902043209691287, 0.9906571523510918, 0.9911190010363017, 0.9915894079322468, 0.9920679061040507, 0.9925540212719344, 0.9930472723136989, 0.9935471717715723, 0.9940532263627767, 0.9945649374931801, 0.9950818017734023, 0.9956033115367582, 0.9961289553584265, 0.9966582185752529, 0.9971905838055961, 0.9977255314686535, 0.9982625403027002, 0.9988010878817047, 0.9993406511297911, 0.9998807068330309, 1.0004207321480723, 1.0009602051071218, 1.0014986051188137, 1.0020354134645175, 1.0025701137896537, 1.0031021925895989, 1.0036311396897817, 1.0041564487195889, 1.0046776175797125, 1.0051941489025915, 1.0057055505056107, 1.006211335836742, 1.0067110244123265, 1.0072041422467088, 1.0076902222734518, 1.0081688047578792, 1.008639437700699, 1.0091016772324828, 1.0095550879987838, 1.0099992435356935, 1.0104337266356485, 1.0108581297033077, 1.0112720551013397, 1.0116751154859605, 1.0120669341320858, 1.0124471452479566, 1.0128153942791251, 1.0131713382016776, 1.0135146458045963, 1.0138449979611601, 1.0141620878893, 1.0144656214008216, 1.0147553171394266, 1.0150309068074646, 1.0152921353813498, 1.0155387613155926, 1.0157705567353938, 1.0159873076177532, 1.0161888139610573, 1.0163748899431062, 1.016545364067545, 1.0167000792986798, 1.0168388931846422, 1.0169616779688861, 1.017068320689997, 1.0171587232697947, 1.0172328025897175, 1.0172904905554738, 1.0173317341499521, 1.0173564954743817], [1.0236105794363932, 1.0235994219534166, 1.0235659595693036, 1.0235102224713504, 1.0234322609478697, 1.023332145352418, 1.0232099660537055, 1.0230658333711784, 1.0228998774962654, 1.022712248399279, 1.0225031157219524, 1.0222726686556023, 1.022021115804897, 1.0217486850372166, 1.0214556233175804, 1.0211421965291365, 1.0208086892791806, 1.0204554046906995, 1.020082664179419, 1.01969080721634, 1.0192801910757576, 1.0188511905687496, 1.0184041977621339, 1.0179396216828884, 1.0174578880080474, 1.0169594387400764, 1.0164447318677454, 1.0159142410125261, 1.0153684550605444, 1.0148078777801304, 1.0142330274250138, 1.0136444363232346, 1.013042650451835, 1.0124282289974231, 1.011801743902708, 1.011163779399123, 1.010514931525665, 1.0098558076340975, 1.0091870258806834, 1.008509214704632, 1.0078230122934568, 1.0071290660354797, 1.0064280319597116, 1.0057205741633901, 1.0050073642274573, 1.0042890806202949, 1.0035664080900593, 1.0028400370459776, 1.0021106629290026, 1.0013789855722433, 1.0006457085516194, 0.9999115385272196, 0.9991771845758634, 0.9984433575154067, 0.9977107692213539, 0.9969801319363691, 0.9962521575733155, 0.9955275570124731, 0.9948070393936226, 0.9940913114037087, 0.9933810765608262, 0.9926770344953015, 0.9919798802286721, 0.9912903034513877, 0.9906089878000949, 0.9899366101353786, 0.9892738398208685, 0.9886213380046391, 0.9879797569038474, 0.987349739093582, 0.9867319168009089, 0.9861269112051123, 0.9855353317451548, 0.984957775435377, 0.9843948261904809, 0.983847054160834, 0.9833150150791518, 0.9827992496195994, 0.9823002827703666, 0.98181862322076, 0.9813547627638464, 0.9809091757156781, 0.9804823183521123, 0.9800746283642193, 0.9796865243332606, 0.9793184052261886, 0.978970649912598, 0.9786436167040264, 0.9783376429164745, 0.9780530444569746, 0.9777901154350037, 0.9775491277994902, 0.9773303310021315, 0.9771339516876738, 0.9769601934117788, 0.9768092363870331, 0.9766812372576132, 0.9765763289030596, 0.9764946202715563, 0.9764361962430593, 0.9764011175225454, 0.9763894205636069, 0.9764011175225455, 0.9764361962430594, 0.9764946202715565, 0.9765763289030596, 0.9766812372576136, 0.9768092363870333, 0.9769601934117789, 0.977133951687674, 0.9773303310021317, 0.9775491277994904, 0.9777901154350038, 0.9780530444569749, 0.9783376429164747, 0.9786436167040266, 0.9789706499125984, 0.9793184052261893, 0.9796865243332611, 0.9800746283642198, 0.9804823183521127, 0.9809091757156785, 0.9813547627638467, 0.9818186232207606, 0.9823002827703672, 0.9827992496195999, 0.9833150150791522, 0.9838470541608346, 0.9843948261904814, 0.9849577754353778, 0.9855353317451554, 0.9861269112051129, 0.9867319168009094, 0.9873497390935828, 0.9879797569038479, 0.9886213380046397, 0.9892738398208691, 0.9899366101353793, 0.9906089878000955, 0.9912903034513882, 0.9919798802286728, 0.9926770344953025, 0.993381076560827, 0.9940913114037093, 0.9948070393936234, 0.9955275570124738, 0.9962521575733162, 0.9969801319363699, 0.9977107692213546, 0.9984433575154076, 0.9991771845758639, 0.9999115385272203, 1.00064570855162, 1.001378985572244, 1.0021106629290033, 1.0028400370459785, 1.0035664080900601, 1.0042890806202958, 1.0050073642274582, 1.0057205741633908, 1.0064280319597123, 1.0071290660354806, 1.0078230122934575, 1.0085092147046326, 1.0091870258806843, 1.0098558076340982, 1.0105149315256656, 1.0111637793991235, 1.0118017439027085, 1.0124282289974238, 1.013042650451836, 1.0136444363232353, 1.0142330274250142, 1.0148078777801306, 1.015368455060545, 1.0159142410125266, 1.016444731867746, 1.016959438740077, 1.017457888008048, 1.0179396216828887, 1.018404197762134, 1.0188511905687503, 1.019280191075758, 1.0196908072163404, 1.0200826641794194, 1.0204554046907, 1.0208086892791808, 1.0211421965291367, 1.0214556233175807, 1.0217486850372168, 1.0220211158048975, 1.0222726686556025, 1.0225031157219526, 1.0227122483992792, 1.0228998774962659, 1.0230658333711786, 1.0232099660537062, 1.023332145352418, 1.0234322609478694, 1.0235102224713504, 1.023565959569304, 1.023599421953417], [1.030801000800334, 1.0307865469009319, 1.0307431979705217, 1.0306709923043307, 1.0305699937005346, 1.0304402914194308, 1.0302820001262583, 1.0300952598176234, 1.029880235731498, 1.0296371182407422, 1.0293661227300959, 1.029067489456578, 1.0287414833932258, 1.0283883940560907, 1.0280085353144177, 1.0276022451839142, 1.0271698856030167, 1.0267118421920525, 1.026228523995207, 1.0257203632051743, 1.0251878148704001, 1.024631356584795, 1.0240514881598208, 1.0234487312788276, 1.0228236291335502, 1.0221767460426436, 1.0215086670521676, 1.0208199975179193, 1.0201113626695255, 1.0193834071562131, 1.0186367945741825, 1.0178722069755222, 1.0170903443586163, 1.0162919241400052, 1.015477680607673, 1.014648364355767, 1.0138047417007516, 1.0129475940790351, 1.012077717426123, 1.0111959215373776, 1.0103030294104853, 1.009399876569768, 1.0084873103724956, 1.0075661892973904, 1.006637382215555, 1.0057017676440747, 1.004760232982597, 1.00381367373322, 1.0028629927040609, 1.0019090991969297, 1.000952908179557, 0.9999953394428852, 0.9990373167439743, 0.9980797669351175, 0.9971236190798111, 0.9961698035562815, 0.9952192511493068, 0.9942728921311383, 0.9933316553323661, 0.9923964672036341, 0.9914682508691544, 0.9905479251730327, 0.9896364037194556, 0.9887345939078556, 0.9878433959642071, 0.9869637019696699, 0.9860963948878273, 0.985242347591832, 0.9844024218927996, 0.9835774675708439, 0.9827683214101804, 0.981975806239766, 0.9812007299809726, 0.9804438847038248, 0.9797060456933595, 0.9789879705276809, 0.9782903981693147, 0.9776140480714653, 0.9769596193007988, 0.9763277896783744, 0.9757192149403464, 0.9751345279200496, 0.9745743377530772, 0.9740392291069303, 0.9735297614368067, 0.9730464682690597, 0.9725898565138247, 0.9721604058082749, 0.9717585678919116, 0.9713847660152536, 0.9710393943832245, 0.9707228176344745, 0.9704353703578121, 0.970177356646834, 0.96994904969378, 0.9697506914235436, 0.9695824921686877, 0.9694446303862251, 0.9693372524168307, 0.9692604722870456, 0.9692143715549503, 0.9691989991996659, 0.9692143715549504, 0.9692604722870456, 0.9693372524168307, 0.9694446303862253, 0.9695824921686877, 0.969750691423544, 0.9699490496937804, 0.9701773566468342, 0.9704353703578125, 0.9707228176344751, 0.9710393943832248, 0.971384766015254, 0.971758567891912, 0.9721604058082753, 0.9725898565138252, 0.9730464682690602, 0.9735297614368074, 0.9740392291069307, 0.9745743377530778, 0.9751345279200503, 0.975719214940347, 0.976327789678375, 0.9769596193007994, 0.9776140480714659, 0.9782903981693154, 0.9789879705276818, 0.9797060456933603, 0.9804438847038257, 0.9812007299809733, 0.9819758062397668, 0.9827683214101812, 0.9835774675708447, 0.9844024218928006, 0.9852423475918329, 0.9860963948878284, 0.9869637019696708, 0.9878433959642081, 0.9887345939078563, 0.9896364037194564, 0.9905479251730336, 0.9914682508691552, 0.9923964672036348, 0.9933316553323672, 0.9942728921311395, 0.9952192511493076, 0.9961698035562824, 0.997123619079812, 0.9980797669351184, 0.9990373167439753, 0.9999953394428861, 1.0009529081795578, 1.0019090991969308, 1.002862992704062, 1.0038136737332208, 1.0047602329825984, 1.0057017676440754, 1.0066373822155559, 1.0075661892973913, 1.0084873103724965, 1.009399876569769, 1.0103030294104862, 1.0111959215373785, 1.0120777174261242, 1.0129475940790362, 1.0138047417007527, 1.0146483643557678, 1.015477680607674, 1.0162919241400061, 1.0170903443586174, 1.0178722069755228, 1.018636794574183, 1.019383407156214, 1.0201113626695264, 1.02081999751792, 1.0215086670521683, 1.0221767460426445, 1.0228236291335508, 1.0234487312788283, 1.0240514881598213, 1.0246313565847958, 1.0251878148704006, 1.0257203632051748, 1.0262285239952071, 1.026711842192053, 1.0271698856030167, 1.0276022451839146, 1.028008535314418, 1.0283883940560912, 1.0287414833932262, 1.0290674894565786, 1.029366122730096, 1.0296371182407424, 1.0298802357314982, 1.0300952598176234, 1.0302820001262585, 1.0304402914194308, 1.0305699937005346, 1.0306709923043307, 1.0307431979705215, 1.030786546900932], [1.038929059601276, 1.0389109343601213, 1.03885657427531, 1.0387660262540137, 1.0386393684455644, 1.0384767101974919, 1.0382781919939172, 1.0380439853762418, 1.037774292846051, 1.0374693477501453, 1.0371294141475857, 1.0367547866586264, 1.0363457902953952, 1.0359027802741658, 1.0354261418090485, 1.0349162898869162, 1.0343736690233678, 1.033798752999516, 1.033192044579379, 1.0325540752076412, 1.0318854046875439, 1.031186620838644, 1.0304583391341935, 1.0297012023178638, 1.0289158799995475, 1.0281030682299626, 1.0272634890537784, 1.0263978900409911, 1.0255070437962621, 1.0245917474459574, 1.023652822102605, 1.0226911123065203, 1.0217074854443347, 1.0207028311441924, 1.0196780606473828, 1.0186341061561945, 1.0175719201577988, 1.0164924747239876, 1.0153967607866141, 1.014285787388618, 1.013160580910536, 1.0120221842724422, 1.010871656111292, 1.0097100699336785, 1.008538513244068, 1.0073580866486058, 1.0061699029346483, 1.0049750861262219, 1.0037747705156665, 1.0025700996717766, 1.001362225424821, 1.0001523068288793, 0.9989415091020104, 0.9977310025448236, 0.9965219614381162, 0.9953155629203024, 0.994112985845441, 0.9929154096227549, 0.9917240130386096, 0.9905399730620124, 0.9893644636347684, 0.9881986544475273, 0.9870437097030352, 0.9859007868679939, 0.9847710354150255, 0.983655595556315, 0.9825555969705985, 0.9814721575252509, 0.9804063819952973, 0.9793593607812675, 0.97833216862788, 0.9773258633456146, 0.9763414845373097, 0.9753800523319766, 0.9744425661280812, 0.9735300033486055, 0.9726433182102346, 0.971783440509065, 0.9709512744252538, 0.9701476973490573, 0.9693735587307183, 0.9686296789566702, 0.9679168482545238, 0.9672358256292833, 0.9665873378332268, 0.9659720783718414, 0.9653907065481722, 0.9648438465478791, 0.9643320865672428, 0.9638559779862816, 0.9634160345890581, 0.9630127318331594, 0.9626465061702385, 0.9623177544193801, 0.9620268331949416, 0.9617740583903902, 0.9615597047195117, 0.9613840053162309, 0.9612471513941276, 0.9611492919665738, 0.9610905336282627, 0.9610709403987242, 0.9610905336282627, 0.961149291966574, 0.9612471513941279, 0.9613840053162311, 0.9615597047195119, 0.9617740583903905, 0.9620268331949419, 0.9623177544193804, 0.962646506170239, 0.9630127318331596, 0.9634160345890584, 0.9638559779862822, 0.9643320865672433, 0.9648438465478796, 0.9653907065481729, 0.9659720783718422, 0.9665873378332275, 0.967235825629284, 0.9679168482545246, 0.9686296789566711, 0.969373558730719, 0.970147697349058, 0.9709512744252545, 0.9717834405090657, 0.9726433182102355, 0.9735300033486065, 0.9744425661280822, 0.9753800523319776, 0.9763414845373108, 0.9773258633456156, 0.9783321686278811, 0.9793593607812686, 0.9804063819952982, 0.9814721575252519, 0.9825555969705996, 0.983655595556316, 0.9847710354150269, 0.9859007868679951, 0.9870437097030363, 0.9881986544475286, 0.9893644636347695, 0.9905399730620136, 0.9917240130386107, 0.9929154096227559, 0.9941129858454422, 0.9953155629203037, 0.9965219614381176, 0.9977310025448247, 0.9989415091020116, 1.0001523068288805, 1.0013622254248218, 1.0025700996717777, 1.0037747705156679, 1.0049750861262234, 1.0061699029346494, 1.007358086648607, 1.0085385132440692, 1.0097100699336796, 1.0108716561112931, 1.0120221842724435, 1.013160580910537, 1.014285787388619, 1.0153967607866152, 1.0164924747239887, 1.0175719201577997, 1.0186341061561954, 1.0196780606473836, 1.0207028311441935, 1.0217074854443358, 1.0226911123065212, 1.0236528221026062, 1.0245917474459583, 1.0255070437962632, 1.026397890040992, 1.0272634890537795, 1.0281030682299632, 1.0289158799995484, 1.0297012023178644, 1.0304583391341942, 1.0311866208386447, 1.0318854046875445, 1.0325540752076419, 1.0331920445793794, 1.0337987529995165, 1.0343736690233685, 1.0349162898869169, 1.0354261418090487, 1.0359027802741665, 1.0363457902953956, 1.0367547866586269, 1.0371294141475862, 1.0374693477501458, 1.0377742928460514, 1.038043985376242, 1.0382781919939175, 1.0384767101974917, 1.0386393684455641, 1.0387660262540137, 1.0388565742753102, 1.0389109343601217], [1.0479868924672706, 1.0479647429965993, 1.0478983132053077, 1.0477876589466302, 1.0476328732795106, 1.0474340864238818, 1.047191465697963, 1.046905215437481, 1.046575576896684, 1.046202828131013, 1.0457872838612428, 1.0453292953188975, 1.0448292500727097, 1.0442875718358728, 1.0437047202538057, 1.0430811906721287, 1.0424175138845246, 1.041714255860134, 1.0409720174501125, 1.0401914340729599, 1.0393731753782038, 1.0385179448880029, 1.0376264796162245, 1.0366995496645197, 1.03573795779492, 1.034742538978446, 1.0337141599192299, 1.0326537185536209, 1.0315621435237452, 1.0304403936249915, 1.0292894572268676, 1.0281103516666998, 1.0269041226156266, 1.025671843416348, 1.024414614392108, 1.0231335621263797, 1.0218298387127562, 1.0205046209745523, 1.0191591096536496, 1.0177945285681456, 1.0164121237383896, 1.0150131624810277, 1.0135989324707169, 1.0121707407692069, 1.0107299128215481, 1.0092777914192197, 1.0078157356300497, 1.0063451196948507, 1.0048673318907662, 1.0033837733614042, 1.0018958569139063, 1.000405005783197, 0.9989126523637387, 0.9974202369092284, 0.9959292062007649, 0.994441012184127, 0.992957110576923, 0.9914789594464803, 0.9900080177594746, 0.988545743904425, 0.9870935941883081, 0.9856530213086885, 0.9842254728028917, 0.9828123894758906, 0.9814152038087217, 0.9800353383493842, 0.9786742040883242, 0.9773331988207493, 0.9760137054981554, 0.9747170905715975, 0.9734447023293641, 0.9721978692318503, 0.9709778982465573, 0.9697860731862595, 0.9686236530535011, 0.9674918703946872, 0.966391929667135, 0.9653250056225305, 0.9642922417103188, 0.9632947485046158, 0.962333602158279, 0.9614098428878078, 0.9605244734927729, 0.9596784579134685, 0.9588727198304776, 0.9581081413098089, 0.9573855614972185, 0.9567057753652665, 0.9560695325165773, 0.9554775360466772, 0.9549304414696537, 0.9544288557097667, 0.9539733361619709, 0.9535643898241503, 0.9532024725036818, 0.9528879881007433, 0.9526212879705657, 0.952402670366609, 0.9522323799663981, 0.9521106074815056, 0.9520374893529151, 0.9520131075327295, 0.9520374893529151, 0.9521106074815057, 0.9522323799663983, 0.9524026703666093, 0.9526212879705658, 0.9528879881007437, 0.9532024725036822, 0.9535643898241507, 0.9539733361619714, 0.9544288557097672, 0.9549304414696541, 0.9554775360466776, 0.9560695325165781, 0.9567057753652671, 0.9573855614972192, 0.9581081413098098, 0.9588727198304785, 0.9596784579134693, 0.9605244734927739, 0.9614098428878088, 0.96233360215828, 0.9632947485046168, 0.9642922417103197, 0.9653250056225315, 0.9663919296671362, 0.9674918703946885, 0.9686236530535022, 0.9697860731862608, 0.9709778982465584, 0.9721978692318515, 0.9734447023293654, 0.9747170905715989, 0.9760137054981568, 0.9773331988207506, 0.9786742040883257, 0.9800353383493855, 0.9814152038087232, 0.9828123894758919, 0.9842254728028931, 0.9856530213086899, 0.9870935941883094, 0.9885457439044263, 0.9900080177594761, 0.9914789594464817, 0.9929571105769243, 0.9944410121841284, 0.9959292062007665, 0.99742023690923, 0.9989126523637402, 1.0004050057831986, 1.001895856913908, 1.0033837733614057, 1.0048673318907677, 1.0063451196948523, 1.0078157356300514, 1.009277791419221, 1.0107299128215494, 1.0121707407692084, 1.0135989324707182, 1.0150131624810292, 1.016412123738391, 1.0177945285681471, 1.019159109653651, 1.0205046209745539, 1.0218298387127578, 1.0231335621263808, 1.0244146143921091, 1.0256718434163494, 1.0269041226156277, 1.0281103516667012, 1.0292894572268687, 1.0304403936249926, 1.0315621435237465, 1.0326537185536215, 1.0337141599192312, 1.034742538978447, 1.0357379577949208, 1.0366995496645208, 1.0376264796162251, 1.0385179448880038, 1.0393731753782047, 1.0401914340729608, 1.0409720174501131, 1.0417142558601347, 1.0424175138845253, 1.0430811906721293, 1.0437047202538061, 1.0442875718358735, 1.04482925007271, 1.0453292953188977, 1.0457872838612434, 1.0462028281310134, 1.0465755768966842, 1.046905215437481, 1.0471914656979635, 1.0474340864238818, 1.0476328732795106, 1.0477876589466304, 1.0478983132053081, 1.0479647429965997], [1.0579657365300115, 1.0579392333990898, 1.0578597456646581, 1.0577273382931753, 1.0575421195336017, 1.0573042408746167, 1.057013896984602, 1.0566713256342428, 1.0562768076015792, 1.0558306665593078, 1.0553332689440744, 1.0547850238074845, 1.0541863826485056, 1.0535378392269001, 1.0528399293573012, 1.0520932306834918, 1.0512983624324235, 1.0504559851474657, 1.0495668004003558, 1.0486315504812593, 1.0476510180663503, 1.0466260258622546, 1.0455574362266917, 1.0444461507646048, 1.0432931098990463, 1.0420992924160524, 1.0408657149827156, 1.0395934316376407, 1.0382835332529396, 1.0369371469669086, 1.0355554355865018, 1.0341395969587093, 1.032690863309925, 1.0312105005523893, 1.0296998075567732, 1.0281601153899806, 1.026592786517238, 1.024999213967548, 1.0233808204615984, 1.0217390575012286, 1.0200754044195837, 1.0183913673911036, 1.016688478400543, 1.014968294170243, 1.0132323950449376, 1.0114823838334208, 1.00971988460647, 1.0079465414504944, 1.0061640171764492, 1.0043739919836503, 1.0025781620782215, 1.0007782382460098, 0.9989759443799225, 0.9971730159617646, 0.9953711984987903, 0.9935722459153277, 0.9917779188999885, 0.9899899832091388, 0.9882102079274827, 0.986440363686787, 0.9846822208439683, 0.9829375476199668, 0.981208108201024, 0.9794956608042109, 0.9778019557092532, 0.9761287332589409, 0.9744777218306191, 0.972850635781504, 0.9712491733707794, 0.9696750146616823, 0.9681298194069897, 0.9666152249215726, 0.9651328439458788, 0.9636842625044385, 0.9622710377636885, 0.9608946958935989, 0.9595567299377847, 0.9582585976969414, 0.9570017196306038, 0.955787476782365, 0.9546172087338021, 0.9534922115924553, 0.9524137360192796, 0.9513829853010258, 0.9504011134730427, 0.9494692234979699, 0.9485883655057684, 0.947759535100463, 0.946983671738878, 0.9462616571865263, 0.9455943140556509, 0.9449824044302344, 0.944426628582581, 0.9439276237858225, 0.9434859632264305, 0.943102155020525, 0.9427766413374296, 0.9425097976335903, 0.9423019319995939, 0.9421532846226445, 0.9420640273664412, 0.9420342634699886, 0.9420640273664412, 0.9421532846226447, 0.942301931999594, 0.9425097976335904, 0.9427766413374301, 0.9431021550205253, 0.943485963226431, 0.9439276237858231, 0.9444266285825816, 0.944982404430235, 0.9455943140556515, 0.946261657186527, 0.9469836717388788, 0.9477595351004637, 0.9485883655057692, 0.9494692234979709, 0.9504011134730439, 0.9513829853010269, 0.9524137360192808, 0.9534922115924565, 0.9546172087338031, 0.9557874767823662, 0.9570017196306051, 0.9582585976969427, 0.9595567299377861, 0.9608946958936003, 0.9622710377636899, 0.9636842625044401, 0.9651328439458802, 0.9666152249215744, 0.9681298194069914, 0.9696750146616838, 0.9712491733707812, 0.9728506357815054, 0.9744777218306209, 0.9761287332589426, 0.9778019557092551, 0.9794956608042126, 0.9812081082010258, 0.9829375476199684, 0.9846822208439703, 0.9864403636867889, 0.9882102079274846, 0.9899899832091406, 0.9917779188999901, 0.9935722459153294, 0.9953711984987921, 0.9971730159617663, 0.9989759443799242, 1.0007782382460115, 1.0025781620782233, 1.004373991983652, 1.006164017176451, 1.0079465414504964, 1.0097198846064719, 1.0114823838334226, 1.0132323950449393, 1.0149682941702445, 1.0166884784005445, 1.0183913673911054, 1.0200754044195854, 1.0217390575012304, 1.0233808204616, 1.0249992139675497, 1.0265927865172397, 1.028160115389982, 1.0296998075567747, 1.0312105005523908, 1.0326908633099265, 1.0341395969587104, 1.035555435586503, 1.0369371469669098, 1.038283533252941, 1.039593431637642, 1.040865714982717, 1.0420992924160537, 1.0432931098990474, 1.044446150764606, 1.0455574362266926, 1.0466260258622557, 1.0476510180663516, 1.0486315504812604, 1.0495668004003567, 1.0504559851474666, 1.051298362432424, 1.0520932306834927, 1.0528399293573019, 1.053537839226901, 1.0541863826485063, 1.0547850238074854, 1.0553332689440749, 1.0558306665593082, 1.0562768076015798, 1.056671325634243, 1.0570138969846026, 1.0573042408746167, 1.0575421195336014, 1.0577273382931758, 1.0578597456646583, 1.0579392333990902], [1.0688559379023412, 1.0688247762454626, 1.0687313159731957, 1.0685756311730739, 1.068357845299051, 1.068078131133512, 1.0677367107339235, 1.0673338553639495, 1.066869885408815, 1.0663451702746582, 1.0657601282715488, 1.0651152264798143, 1.0644109805992565, 1.0636479547808053, 1.0628267614400837, 1.0619480610523393, 1.0610125619281214, 1.0600210199690414, 1.0589742384029168, 1.057873067497522, 1.056718404252154, 1.0555111920661329, 1.054252420383344, 1.0529431243118546, 1.0515843842175963, 1.0501773252910673, 1.0487231170859412, 1.0472229730284457, 1.0456781498963104, 1.044089947266061, 1.0424597069273733, 1.040788812263184, 1.0390786875942057, 1.0373307974864672, 1.035546646020469, 1.0337277760205217, 1.0318757682428088, 1.029992240520706, 1.0280788468658772, 1.0261372765236578, 1.024169252981247, 1.0221765329272365, 1.0201609051610148, 1.0181241894506239, 1.0160682353376758, 1.01399492088797, 1.0119061513865324, 1.009803857975841, 1.0076899962360961, 1.0055665447064774, 1.00343550334644, 1.0012988919362174, 0.999158748415834, 0.9970171271620745, 0.9948760972030272, 0.9927377403699913, 0.9906041493867361, 0.9884774258963133, 0.9863596784258416, 0.9842530202899454, 0.982159567433762, 0.980081436216733, 0.9780207411386687, 0.9759795925098784, 0.973960094067491, 0.9719643405403993, 0.9699944151656162, 0.9680523871591753, 0.9661403091450591, 0.964260214546013, 0.9624141149404507, 0.9606039973900354, 0.9588318217428823, 0.957099517917677, 0.9554089831743703, 0.9537620793774343, 0.9521606302580043, 0.9506064186815274, 0.9491011839278314, 0.9476466189907932, 0.94624436790501, 0.9448960231070939, 0.9436031228393659, 0.9423671486038675, 0.9411895226746916, 0.9400716056766876, 0.9390146942385927, 0.9380200187286011, 0.937088741080284, 0.9362219527166356, 0.9354206725798163, 0.9346858452739261, 0.9340183393278378, 0.9334189455847807, 0.9328883757249576, 0.9324272609270511, 0.9320361506739782, 0.9317155117077269, 0.931465727137552, 0.9312870957051983, 0.9311798312102013, 0.9311440620976589, 0.9311798312102013, 0.9312870957051986, 0.9314657271375522, 0.9317155117077273, 0.9320361506739786, 0.9324272609270515, 0.932888375724958, 0.9334189455847813, 0.9340183393278386, 0.9346858452739267, 0.9354206725798172, 0.9362219527166363, 0.9370887410802848, 0.9380200187286021, 0.9390146942385938, 0.9400716056766888, 0.9411895226746929, 0.9423671486038687, 0.9436031228393674, 0.9448960231070954, 0.9462443679050114, 0.9476466189907945, 0.949101183927833, 0.9506064186815288, 0.9521606302580059, 0.9537620793774361, 0.9554089831743721, 0.9570995179176789, 0.9588318217428841, 0.9606039973900372, 0.9624141149404525, 0.964260214546015, 0.966140309145061, 0.9680523871591772, 0.9699944151656184, 0.9719643405404013, 0.9739600940674932, 0.9759795925098803, 0.9780207411386708, 0.9800814362167352, 0.982159567433764, 0.9842530202899474, 0.9863596784258438, 0.9884774258963155, 0.9906041493867384, 0.9927377403699935, 0.9948760972030294, 0.9970171271620767, 0.9991587484158361, 1.0012988919362196, 1.003435503346442, 1.0055665447064794, 1.0076899962360983, 1.009803857975843, 1.0119061513865344, 1.013994920887972, 1.016068235337678, 1.018124189450626, 1.0201609051610165, 1.0221765329272383, 1.0241692529812492, 1.0261372765236596, 1.0280788468658792, 1.029992240520708, 1.0318757682428106, 1.0337277760205237, 1.035546646020471, 1.037330797486469, 1.0390786875942075, 1.0407888122631856, 1.0424597069273749, 1.0440899472660625, 1.045678149896312, 1.0472229730284468, 1.048723117085943, 1.0501773252910689, 1.0515843842175978, 1.0529431243118557, 1.0542524203833454, 1.055511192066134, 1.0567184042521554, 1.0578730674975234, 1.0589742384029177, 1.0600210199690425, 1.061012561928122, 1.0619480610523404, 1.0628267614400844, 1.0636479547808062, 1.0644109805992572, 1.0651152264798147, 1.0657601282715494, 1.0663451702746587, 1.0668698854088157, 1.0673338553639498, 1.0677367107339244, 1.0680781311335121, 1.068357845299051, 1.068575631173074, 1.068731315973196, 1.068824776245463], [1.0806469610177643, 1.0806108613329068, 1.0805025899699687, 1.08032222999781, 1.0800699198443438, 1.079745853266162, 1.0793502793058074, 1.0788835022365029, 1.0783458814940705, 1.0777378315957384, 1.0770598220454544, 1.0763123772252765, 1.0754960762723524, 1.074611552940935, 1.0736594954488157, 1.07264064630751, 1.0715558021354492, 1.0704058134533774, 1.0691915844610906, 1.067914072794579, 1.0665742892625762, 1.0651732975614436, 1.06371221396726, 1.0621922070038992, 1.0606144970858375, 1.0589803561343225, 1.057291107165509, 1.055548123849059, 1.0537528300356553, 1.0519066992518025, 1.0500112541602113, 1.0480680659840136, 1.0460787538929655, 1.0440449843497541, 1.0419684704144445, 1.0398509710050567, 1.0376942901122026, 1.0355002759656644, 1.0332708201507497, 1.0310078566722238, 1.0287133609635817, 1.0263893488394065, 1.0240378753885373, 1.0216610338057686, 1.0192609541598132, 1.0168398020952658, 1.0143997774663502, 1.0119431129002652, 1.0094720722880115, 1.0069889492006625, 1.0044960652291237, 1.0019957682455587, 0.9994904305847779, 0.996982447144054, 0.9944742334000013, 0.9919682233413618, 0.9894668673167685, 0.9869726297968078, 0.9844879870499829, 0.9820154247324884, 0.9795574353920337, 0.9771165158863148, 0.9746951647171266, 0.9722958792815056, 0.969921153041747, 0.967573472616592, 0.9652553147963704, 0.9629691434853882, 0.9607174065753784, 0.9585025327543689, 0.9563269282558811, 0.9541929735539347, 0.952103020009903, 0.9500593864778384, 0.9480643558754498, 0.9461201717284818, 0.9442290346967855, 0.942393099090903, 0.9406144693884873, 0.9388951967603576, 0.937237275616415, 0.9356426401820463, 0.934113161115983, 0.9326506421808665, 0.9312568169780095, 0.9299333457579929, 0.9286818123188412, 0.9275037210035305, 0.9264004938085216, 0.925373467614873, 0.9244238915532608, 0.9235529245139199, 0.9227616328121342, 0.9220509880194137, 0.921421864969949, 0.9208750399512825, 0.9204111890874259, 0.9200308869218654, 0.919734605207046, 0.9195227119060144, 0.9193954704109407, 0.9193530389822356, 0.9193954704109409, 0.9195227119060146, 0.9197346052070462, 0.9200308869218656, 0.9204111890874263, 0.9208750399512831, 0.9214218649699495, 0.9220509880194144, 0.922761632812135, 0.9235529245139208, 0.9244238915532617, 0.9253734676148739, 0.9264004938085227, 0.9275037210035317, 0.9286818123188425, 0.9299333457579941, 0.931256816978011, 0.9326506421808681, 0.9341131611159846, 0.935642640182048, 0.9372372756164166, 0.9388951967603594, 0.9406144693884891, 0.9423930990909046, 0.9442290346967874, 0.9461201717284838, 0.9480643558754518, 0.9500593864778404, 0.952103020009905, 0.9541929735539367, 0.9563269282558833, 0.9585025327543711, 0.9607174065753806, 0.9629691434853905, 0.9652553147963726, 0.9675734726165943, 0.9699211530417495, 0.9722958792815081, 0.9746951647171291, 0.9771165158863174, 0.9795574353920362, 0.9820154247324911, 0.9844879870499854, 0.9869726297968103, 0.9894668673167709, 0.9919682233413645, 0.994474233400004, 0.9969824471440565, 0.9994904305847805, 1.0019957682455611, 1.0044960652291262, 1.006988949200665, 1.0094720722880142, 1.0119431129002676, 1.014399777466353, 1.0168398020952683, 1.0192609541598157, 1.021661033805771, 1.0240378753885395, 1.026389348839409, 1.028713360963584, 1.031007856672226, 1.0332708201507521, 1.0355002759656666, 1.037694290112205, 1.0398509710050587, 1.0419684704144467, 1.0440449843497561, 1.0460787538929677, 1.0480680659840154, 1.0500112541602131, 1.0519066992518045, 1.0537528300356573, 1.0555481238490605, 1.057291107165511, 1.058980356134324, 1.060614497085839, 1.062192207003901, 1.0637122139672612, 1.0651732975614452, 1.0665742892625776, 1.0679140727945806, 1.069191584461092, 1.0704058134533783, 1.0715558021354503, 1.072640646307511, 1.0736594954488166, 1.074611552940936, 1.0754960762723533, 1.0763123772252772, 1.0770598220454553, 1.0777378315957393, 1.078345881494071, 1.0788835022365035, 1.079350279305808, 1.0797458532661621, 1.0800699198443442, 1.0803222299978097, 1.0805025899699687, 1.0806108613329066], [1.0933273988229284, 1.0932861074695879, 1.0931622640035266, 1.092955960202624, 1.092667349016663, 1.0922966445471884, 1.0918441220191033, 1.0913101177437647, 1.0906950290733126, 1.089999314345881, 1.0892234928212754, 1.0883681446066438, 1.0874339105715958, 1.086421492252149, 1.085331651742822, 1.0841652115761118, 1.082923054588521, 1.0816061237722265, 1.0802154221113982, 1.078752012402094, 1.077217017054581, 1.0756116178768373, 1.0739370558379095, 1.072194630809703, 1.0703857012856934, 1.0685116840749513, 1.0665740539697752, 1.0645743433851265, 1.062514141967963, 1.0603950961744604, 1.0582189088130107, 1.055987338550779, 1.053702199381499, 1.0513653600520767, 1.0489787434454723, 1.0465443259172245, 1.0440641365828802, 1.0415402565534975, 1.0389748181162861, 1.0363700038573744, 1.0337280457235918, 1.0310512240200904, 1.0283418663405548, 1.0256023464266917, 1.0228350829536468, 1.020042538237954, 1.0172272168646115, 1.0143916642298691, 1.011538464996331, 1.0086702414570086, 1.0057896518050244, 1.0028993883057429, 1.0000021753682165, 0.9971007675129786, 0.994197947233377, 0.9912965227478514, 0.9883993256407944, 0.9855092083899122, 0.9826290417783149, 0.979761712189923, 0.9769101187871779, 0.9740771705704784, 0.9712657833192575, 0.9684788764151419, 0.9657193695482036, 0.962990179307946, 0.9602942156613083, 0.9576343783206948, 0.9550135530057531, 0.9524346076034288, 0.9499003882316018, 0.947413715212476, 0.9449773789627254, 0.9425941358082963, 0.9402667037326338, 0.937997758067995, 0.9357899271403903, 0.9336457878795579, 0.9315678614062158, 0.9295586086096501, 0.927620425729446, 0.9257556399558884, 0.9239665050641924, 0.9222551970982868, 0.9206238101203582, 0.9190743520427355, 0.9176087405589766, 0.9162287991911757, 0.9149362534705465, 0.9137327272682496, 0.9126197392932058, 0.9115986997732765, 0.9106709073356939, 0.9098375461019801, 0.9090996830118235, 0.9084582653894677, 0.9079141187651288, 0.9074679449627994, 0.9071203204645277, 0.9068716950598864, 0.9067223907878882, 0.9066726011770717, 0.9067223907878882, 0.9068716950598866, 0.907120320464528, 0.9074679449627999, 0.9079141187651294, 0.9084582653894685, 0.9090996830118243, 0.9098375461019811, 0.9106709073356949, 0.9115986997732775, 0.9126197392932068, 0.9137327272682508, 0.9149362534705479, 0.9162287991911772, 0.917608740558978, 0.919074352042737, 0.92062381012036, 0.9222551970982885, 0.9239665050641942, 0.9257556399558904, 0.9276204257294478, 0.929558608609652, 0.9315678614062178, 0.9336457878795599, 0.9357899271403924, 0.9379977580679972, 0.9402667037326361, 0.9425941358082986, 0.9449773789627277, 0.9474137152124785, 0.9499003882316045, 0.9524346076034313, 0.9550135530057559, 0.9576343783206972, 0.9602942156613113, 0.9629901793079488, 0.9657193695482065, 0.9684788764151446, 0.9712657833192604, 0.9740771705704812, 0.9769101187871808, 0.9797617121899259, 0.9826290417783178, 0.9855092083899152, 0.9883993256407971, 0.9912965227478543, 0.9941979472333801, 0.9971007675129817, 1.0000021753682193, 1.0028993883057458, 1.005789651805027, 1.0086702414570115, 1.011538464996334, 1.0143916642298723, 1.0172272168646144, 1.0200425382379568, 1.0228350829536497, 1.0256023464266946, 1.0283418663405575, 1.0310512240200933, 1.0337280457235947, 1.036370003857377, 1.0389748181162888, 1.0415402565535, 1.0440641365828829, 1.0465443259172267, 1.0489787434454747, 1.0513653600520791, 1.0537021993815014, 1.0559873385507812, 1.0582189088130127, 1.0603950961744626, 1.0625141419679651, 1.0645743433851285, 1.0665740539697772, 1.0685116840749533, 1.0703857012856952, 1.0721946308097048, 1.073937055837911, 1.075611617876839, 1.0772170170545827, 1.0787520124020957, 1.0802154221113998, 1.0816061237722279, 1.0829230545885222, 1.084165211576113, 1.0853316517428233, 1.0864214922521505, 1.0874339105715967, 1.0883681446066447, 1.089223492821276, 1.089999314345882, 1.0906950290733133, 1.0913101177437647, 1.0918441220191042, 1.0922966445471889, 1.092667349016663, 1.0929559602026244, 1.093162264003527, 1.0932861074695885], [1.1068849838132095, 1.1068382732235034, 1.1066981748214104, 1.1064647887065144, 1.1061382817064596, 1.1057188873693375, 1.1052069059528182, 1.1046027044097848, 1.1039067163701926, 1.103119442118793, 1.1022414485683019, 1.1012733692275078, 1.1002159041637687, 1.0990698199592381, 1.0978359496601182, 1.0965151927181258, 1.0951085149233013, 1.0936169483271816, 1.0920415911552832, 1.0903836077077405, 1.0886442282468445, 1.086824748870131, 1.0849265313675553, 1.0829510030611817, 1.0808996566256996, 1.0787740498879583, 1.0765758056035826, 1.0743066112086146, 1.0719682185439736, 1.0695624435504032, 1.067091165931427, 1.064556328781678, 1.0619599381778329, 1.0593040627292136, 1.0565908330849647, 1.053822441394566, 1.0510011407182627, 1.0481292443838475, 1.0452091252860634, 1.0422432151247354, 1.0392340035775873, 1.036184037403542, 1.0330959194721638, 1.0299723077147562, 1.026815913992509, 1.0236295028769598, 1.0204158903379443, 1.0171779423341134, 1.0139185733010392, 1.0106407445318788, 1.0073474624455525, 1.0040417767374037, 1.0007267784073466, 0.9974055976605916, 0.9940814016761582, 0.9907573922385423, 0.9874368032281178, 0.9841228979661155, 0.9808189664103342, 0.9775283221981148, 0.9742542995335416, 0.9710002499163405, 0.967769538710509, 0.9645655415513448, 0.9613916405902652, 0.9582512205775726, 0.9551476647841912, 0.9520843507643205, 0.9490646459619492, 0.9460919031652423, 0.9431694558139451, 0.9403006131661327, 0.9374886553318859, 0.934736828182755, 0.9320483381472013, 0.9294263469035589, 0.926873965983418, 0.9243942512997049, 0.9219901976150713, 0.9196647329675435, 0.9174207130716391, 0.9152609157143826, 0.9131880351667724, 0.9112046766322788, 0.9093133507548656, 0.9075164682097951, 0.9058163344010913, 0.9042151442899887, 0.9027149773789436, 0.9013177928758536, 0.9000254250629768, 0.8988395788946718, 0.8977618258474916, 0.8967936000453389, 0.8959361946813452, 0.8951907587568686, 0.8945582941565152, 0.8940396530764065, 0.8936355358210345, 0.8933464889819956, 0.8931729040096956, 0.8931150161867906, 0.8931729040096958, 0.8933464889819961, 0.8936355358210348, 0.894039653076407, 0.8945582941565157, 0.8951907587568694, 0.895936194681346, 0.8967936000453398, 0.8977618258474926, 0.898839578894673, 0.9000254250629782, 0.9013177928758549, 0.902714977378945, 0.9042151442899904, 0.905816334401093, 0.907516468209797, 0.9093133507548676, 0.9112046766322809, 0.9131880351667747, 0.9152609157143848, 0.9174207130716414, 0.9196647329675457, 0.9219901976150737, 0.9243942512997073, 0.9268739659834206, 0.9294263469035615, 0.9320483381472041, 0.9347368281827578, 0.9374886553318887, 0.9403006131661354, 0.9431694558139481, 0.9460919031652454, 0.9490646459619523, 0.9520843507643235, 0.9551476647841942, 0.9582512205775757, 0.9613916405902686, 0.9645655415513482, 0.9677695387105124, 0.9710002499163439, 0.9742542995335449, 0.9775283221981181, 0.9808189664103378, 0.9841228979661188, 0.9874368032281212, 0.9907573922385459, 0.9940814016761618, 0.9974055976605949, 1.00072677840735, 1.0040417767374072, 1.0073474624455558, 1.010640744531882, 1.0139185733010427, 1.017177942334117, 1.0204158903379477, 1.023629502876963, 1.0268159139925122, 1.0299723077147593, 1.033095919472167, 1.0361840374035451, 1.0392340035775904, 1.0422432151247385, 1.0452091252860665, 1.0481292443838506, 1.0510011407182656, 1.0538224413945687, 1.0565908330849674, 1.059304062729216, 1.0619599381778357, 1.0645563287816806, 1.0670911659314295, 1.0695624435504059, 1.071968218543976, 1.074306611208617, 1.076575805603585, 1.0787740498879606, 1.080899656625702, 1.0829510030611837, 1.0849265313675573, 1.0868247488701328, 1.0886442282468465, 1.0903836077077422, 1.0920415911552848, 1.093616948327183, 1.0951085149233029, 1.0965151927181271, 1.0978359496601195, 1.0990698199592397, 1.1002159041637696, 1.1012733692275092, 1.1022414485683028, 1.103119442118794, 1.1039067163701932, 1.1046027044097853, 1.105206905952819, 1.105718887369338, 1.1061382817064596, 1.1064647887065149, 1.1066981748214106, 1.1068382732235038], [1.1213065999007323, 1.1212542685225326, 1.1210973103668642, 1.1208358333719002, 1.1204700174391649, 1.120000114440284, 1.119426448226227, 1.1187494146388237, 1.1179694815242875, 1.1170871887484046, 1.116103148212981, 1.1150180438730786, 1.1138326317544853, 1.1125477399708101, 1.111164268739489, 1.1096831903959303, 1.1081055494049241, 1.1064324623683508, 1.1046651180281364, 1.1028047772632865, 1.1008527730797297, 1.0988105105915846, 1.096679466992345, 1.0944611915143423, 1.0921573053747173, 1.0897695017059867, 1.0872995454691314, 1.0847492733469912, 1.0821205936155611, 1.079415485990632, 1.0766360014470133, 1.0737842620073996, 1.0708624604977317, 1.0678728602656995, 1.0648177948588164, 1.0616996676582717, 1.0585209514645355, 1.0552841880304595, 1.051991987537367, 1.0486470280093885, 1.0452520546610513, 1.0418098791728707, 1.0383233788894575, 1.0347954959344003, 1.031229236235943, 1.0276276684572407, 1.0239939228247625, 1.0203311898481886, 1.0166427189249665, 1.0129318168225123, 1.0092018460309025, 1.0054562229787867, 1.0016984161051636, 0.9979319437796347, 0.9941603720637471, 0.9903873123061014, 0.9866164185640153, 0.9828513848447192, 0.9790959421593101, 0.9753538553830243, 0.971628919915807, 0.9679249581376643, 0.9642458156538849, 0.9605953573259294, 0.956977463084603, 0.9533960235230499, 0.9498549352681518, 0.9463580961300838, 0.942909400031044, 0.9395127317155916, 0.9361719612465296, 0.9328909382918971, 0.9296734862103777, 0.9265233959442444, 0.9234444197308924, 0.9204402646459844, 0.9175145859932884, 0.914670980558357, 0.9119129797453026, 0.909244042618007, 0.9066675488691603, 0.9041867917425136, 0.9018049709356359, 0.8995251855122425, 0.897350426854782, 0.8952835716894186, 0.8933273752167569, 0.8914844643826318, 0.8897573313239932, 0.8881483270252938, 0.8866596552208773, 0.8852933665785732, 0.8840513531990876, 0.882935343464779, 0.8819468972700346, 0.8810874016637429, 0.8803580669322585, 0.8797599231488273, 0.879293817212694, 0.8789604103980652, 0.8787601764298112, 0.8786934000992677, 0.8787601764298113, 0.8789604103980655, 0.8792938172126944, 0.8797599231488278, 0.8803580669322589, 0.8810874016637437, 0.8819468972700355, 0.8829353434647802, 0.884051353199089, 0.8852933665785745, 0.8866596552208789, 0.8881483270252953, 0.8897573313239949, 0.8914844643826338, 0.893327375216759, 0.8952835716894209, 0.8973504268547841, 0.8995251855122448, 0.9018049709356386, 0.9041867917425163, 0.9066675488691629, 0.9092440426180096, 0.9119129797453052, 0.9146709805583598, 0.9175145859932914, 0.9204402646459874, 0.9234444197308955, 0.9265233959442477, 0.9296734862103809, 0.9328909382919006, 0.936171961246533, 0.939512731715595, 0.9429094000310473, 0.9463580961300874, 0.9498549352681556, 0.9533960235230533, 0.9569774630846067, 0.960595357325933, 0.9642458156538888, 0.9679249581376684, 0.971628919915811, 0.975353855383028, 0.9790959421593141, 0.9828513848447231, 0.9866164185640192, 0.9903873123061052, 0.9941603720637511, 0.9979319437796385, 1.0016984161051674, 1.0054562229787904, 1.0092018460309062, 1.012931816822516, 1.0166427189249705, 1.0203311898481924, 1.0239939228247663, 1.0276276684572445, 1.0312292362359468, 1.034795495934404, 1.0383233788894608, 1.041809879172874, 1.0452520546610546, 1.048647028009392, 1.0519919875373702, 1.0552841880304629, 1.0585209514645388, 1.0616996676582746, 1.0648177948588198, 1.0678728602657026, 1.0708624604977348, 1.0737842620074025, 1.0766360014470162, 1.0794154859906346, 1.082120593615564, 1.084749273346994, 1.0872995454691343, 1.0897695017059892, 1.0921573053747198, 1.0944611915143445, 1.0966794669923474, 1.0988105105915866, 1.1008527730797317, 1.1028047772632885, 1.1046651180281382, 1.1064324623683524, 1.1081055494049254, 1.109683190395932, 1.1111642687394903, 1.1125477399708115, 1.1138326317544864, 1.1150180438730797, 1.1161031482129822, 1.1170871887484055, 1.1179694815242887, 1.1187494146388246, 1.119426448226228, 1.1200001144402847, 1.1204700174391649, 1.1208358333719002, 1.1210973103668644, 1.1212542685225328], [1.1365782951033379, 1.1365201670979124, 1.1363458214861075, 1.1360553734858398, 1.1356490151419587, 1.1351270153486357, 1.1344897198805366, 1.1337375514325885, 1.1328710096681076, 1.1318906712750014, 1.130797190029687, 1.1295912968683204, 1.1282737999648507, 1.126845584815358, 1.125307614328047, 1.1236609289181938, 1.1219066466072658, 1.1200459631253268, 1.1180801520157562, 1.116010564741197, 1.1138386307895454, 1.1115658577786505, 1.1091938315582934, 1.106724216307847, 1.1041587546278826, 1.1014992676238249, 1.0987476549795838, 1.0959058950189082, 1.0929760447520078, 1.0899602399047879, 1.0868606949278072, 1.0836797029818457, 1.0804196358967104, 1.077082944099648, 1.0736721565094562, 1.0701898803920866, 1.066638801173239, 1.0630216822031129, 1.0593413644681595, 1.0556007662443334, 1.0518028826859767, 1.0479507853441148, 1.0440476216075627, 1.0400966140598564, 1.0361010597446485, 1.032064329331812, 1.027989866176113, 1.0238811852599425, 1.0197418720112132, 1.0155755809871894, 1.0113860344146695, 1.0071770205766382, 1.0029523920352337, 0.9987160636806293, 0.9944720105952504, 0.9902242657226097, 0.9859769173299856, 0.9817341062541733, 0.9775000229196349, 0.9732789041185761, 0.9690750295427684, 0.9648927180573674, 0.96073632370752, 0.9566102314492579, 0.9525188525970123, 0.9484666199811042, 0.9444579828097363, 0.9404974012313904, 0.9365893405950655, 0.9327382654075499, 0.928948632988845, 0.9252248868289857, 0.921571449651823, 0.9179927161938282, 0.9144930457086438, 0.9110767542109341, 0.907748106476044, 0.9045113078150373, 0.9013704956478482, 0.8983297309004629, 0.895392989255265, 0.8925641522868466, 0.8898469985186783, 0.8872451944389953, 0.884762285517034, 0.8824016872632929, 0.8801666763797461, 0.8780603820478332, 0.8760857774035602, 0.8742456712501031, 0.8725427000588647, 0.8709793203099782, 0.8695578012227219, 0.8682802179251986, 0.8671484451109319, 0.8661641512277275, 0.8653287932412553, 0.864643612012353, 0.86410962832306, 0.8637276395819067, 0.8634982172340612, 0.8634217048966623, 0.8634982172340613, 0.863727639581907, 0.8641096283230607, 0.8646436120123534, 0.8653287932412561, 0.8661641512277286, 0.867148445110933, 0.8682802179251998, 0.8695578012227232, 0.8709793203099797, 0.8725427000588665, 0.874245671250105, 0.8760857774035623, 0.8780603820478353, 0.8801666763797484, 0.8824016872632955, 0.8847622855170366, 0.887245194438998, 0.8898469985186811, 0.8925641522868496, 0.895392989255268, 0.8983297309004659, 0.9013704956478513, 0.9045113078150405, 0.9077481064760473, 0.9110767542109377, 0.9144930457086473, 0.9179927161938319, 0.9215714496518268, 0.9252248868289894, 0.928948632988849, 0.9327382654075539, 0.9365893405950694, 0.9404974012313942, 0.9444579828097404, 0.9484666199811081, 0.9525188525970164, 0.9566102314492619, 0.9607363237075243, 0.9648927180573716, 0.9690750295427728, 0.9732789041185804, 0.9775000229196392, 0.9817341062541779, 0.9859769173299899, 0.9902242657226139, 0.9944720105952548, 0.9987160636806337, 1.002952392035238, 1.0071770205766424, 1.0113860344146737, 1.0155755809871936, 1.0197418720112172, 1.0238811852599468, 1.0279898661761175, 1.0320643293318161, 1.036101059744653, 1.0400966140598602, 1.0440476216075665, 1.0479507853441188, 1.0518028826859804, 1.0556007662443374, 1.0593413644681633, 1.0630216822031167, 1.066638801173243, 1.0701898803920904, 1.0736721565094598, 1.0770829440996517, 1.0804196358967137, 1.083679702981849, 1.0868606949278103, 1.089960239904791, 1.092976044752011, 1.0959058950189111, 1.0987476549795867, 1.1014992676238278, 1.1041587546278855, 1.1067242163078497, 1.109193831558296, 1.1115658577786527, 1.1138386307895474, 1.1160105647411993, 1.118080152015758, 1.1200459631253288, 1.1219066466072676, 1.1236609289181954, 1.1253076143280485, 1.1268455848153598, 1.128273799964852, 1.1295912968683215, 1.1307971900296883, 1.1318906712750025, 1.1328710096681087, 1.1337375514325891, 1.1344897198805373, 1.135127015348636, 1.1356490151419587, 1.13605537348584, 1.136345821486108, 1.1365201670979126], [1.152685295042224, 1.15262121976157, 1.1524290345447756, 1.1521088612751078, 1.1516609031172, 1.1510854445557697, 1.1503828514496992, 1.1495535711013436, 1.1485981323408938, 1.1475171456255913, 1.1463113031535237, 1.1449813789916976, 1.1435282292180295, 1.1419527920768298, 1.1402560881472963, 1.1384392205244744, 1.1365033750120386, 1.1344498203261988, 1.1322799083099182, 1.129995074156543, 1.127596836641829, 1.125086798363233, 1.1224666459852017, 1.1197381504890496, 1.1169031674258643, 1.1139636371706976, 1.110921585176128, 1.1077791222230702, 1.1045384446664923, 1.1012018346734709, 1.0977716604507506, 1.0942503764587166, 1.0906405236083805, 1.0869447294376753, 1.0831657082630175, 1.0793062613017346, 1.0753692767605785, 1.071357729885137, 1.0672746829645297, 1.0631232852853316, 1.058906773028176, 1.0546284691000134, 1.0502917828944693, 1.0459002099722179, 1.0414573316527234, 1.0369668145081368, 1.0324324097495516, 1.0278579524952238, 1.0232473609097668, 1.0186046352027383, 1.0139338564744391, 1.0092391853961717, 1.004524860711647, 0.9997951975457047, 0.9950545855060329, 0.9903074865631336, 0.9855584326934171, 0.9808120232700284, 0.9760729221858003, 0.9713458546926601, 0.9666356039418471, 0.9619470072094991, 0.9572849517925061, 0.9526543705600787, 0.9480602371472099, 0.9435075607771712, 0.9390013807013967, 0.9345467602465558, 0.9301487804603715, 0.9258125333497573, 0.9215431147071824, 0.9173456165238161, 0.9132251189909528, 0.909186682094488, 0.9052353368107888, 0.9013760759161613, 0.8976138444262594, 0.8939535296861524, 0.8903999511363537, 0.8869578497848648, 0.8836318774201329, 0.880426585604728, 0.8773464144944163, 0.8743956815320754, 0.871578570070487, 0.8688991179823498, 0.8663612063197932, 0.8639685480891566, 0.8617246772097185, 0.8596329377273403, 0.85769647335554, 0.8559182174172548, 0.854300883260433, 0.8528469552195586, 0.8515586801932143, 0.8504380599048467, 0.8494868439099614, 0.8487065234081431, 0.8480983259125298, 0.8476632108228233, 0.8474018659406012, 0.847314704957776, 0.8474018659406015, 0.8476632108228237, 0.8480983259125302, 0.8487065234081437, 0.8494868439099623, 0.8504380599048477, 0.8515586801932156, 0.8528469552195599, 0.8543008832604346, 0.8559182174172564, 0.857696473355542, 0.8596329377273424, 0.8617246772097206, 0.863968548089159, 0.8663612063197959, 0.8688991179823525, 0.8715785700704898, 0.8743956815320784, 0.8773464144944195, 0.8804265856047313, 0.8836318774201362, 0.8869578497848682, 0.8903999511363573, 0.8939535296861559, 0.8976138444262632, 0.9013760759161653, 0.9052353368107929, 0.9091866820944924, 0.9132251189909569, 0.9173456165238204, 0.9215431147071866, 0.9258125333497617, 0.930148780460376, 0.9345467602465602, 0.9390013807014013, 0.943507560777176, 0.9480602371472145, 0.9526543705600836, 0.9572849517925108, 0.9619470072095039, 0.9666356039418521, 0.9713458546926648, 0.9760729221858052, 0.9808120232700333, 0.9855584326934219, 0.9903074865631383, 0.9950545855060378, 0.9997951975457093, 1.0045248607116517, 1.0092391853961766, 1.013933856474444, 1.018604635202743, 1.0232473609097716, 1.0278579524952287, 1.0324324097495563, 1.0369668145081412, 1.0414573316527278, 1.0459002099722225, 1.0502917828944738, 1.0546284691000176, 1.0589067730281805, 1.0631232852853358, 1.067274682964534, 1.0713577298851409, 1.0753692767605827, 1.0793062613017386, 1.0831657082630213, 1.086944729437679, 1.0906405236083843, 1.0942503764587201, 1.0977716604507541, 1.1012018346734744, 1.1045384446664959, 1.1077791222230735, 1.1109215851761314, 1.1139636371707007, 1.1169031674258671, 1.1197381504890525, 1.1224666459852044, 1.1250867983632358, 1.1275968366418314, 1.1299950741565452, 1.1322799083099204, 1.1344498203262008, 1.1365033750120406, 1.1384392205244762, 1.1402560881472978, 1.1419527920768313, 1.143528229218031, 1.1449813789916992, 1.146311303153525, 1.1475171456255926, 1.1485981323408947, 1.1495535711013443, 1.1503828514497005, 1.1510854445557703, 1.1516609031172005, 1.1521088612751083, 1.1524290345447759, 1.15262121976157], [1.1696120172352042, 1.1695418685060175, 1.1693314649475441, 1.1689809344580762, 1.1684904902381976, 1.1678604308459035, 1.1670911402737074, 1.1661830880476727, 1.1651368293482907, 1.1639530051530946, 1.1626323424008806, 1.1611756541773706, 1.1595838399221194, 1.1578578856564306, 1.1559988642319943, 1.1540079355999169, 1.1518863470997431, 1.1496354337680095, 1.1472566186657962, 1.144751413224641, 1.1421214176101062, 1.1393683211021544, 1.1364939024913887, 1.133500030490063, 1.1303886641566212, 1.1271618533323546, 1.1238217390885816, 1.1203705541825502, 1.1168106235200275, 1.1131443646223118, 1.1093742880951052, 1.10550299809641, 1.1015331928002734, 1.0974676648528607, 1.0933093018169444, 1.089061086600497, 1.084726097864616, 1.0803075104055295, 1.0758085955049228, 1.071232721242259, 1.0665833527621913, 1.0618640524895173, 1.0570784802834774, 1.0522303935224755, 1.0473236471095757, 1.0423621933883311, 1.0373500819577046, 1.032291459373985, 1.0271905687267344, 1.0220517490749121, 1.0168794347283945, 1.0116781543592044, 1.0064525299258271, 1.001207275393079, 0.995947195229101, 0.9906771826601883, 0.9854022176633522, 0.9801273646757763, 0.9748577699996658, 0.969598658880446, 0.9643553322358541, 0.9591331630132222, 0.9539375921521753, 0.9487741241301383, 0.9436483220684451, 0.9385658023775364, 0.9335322289207427, 0.9285533066775064, 0.9236347748886431, 0.9187823996683987, 0.9140019660706618, 0.9092992695997643, 0.9046801071598601, 0.9001502674409387, 0.8957155207440988, 0.8913816082537838, 0.8871542307702523, 0.8830390369215827, 0.8790416108809713, 0.8751674596219177, 0.8714219997510075, 0.8678105439653682, 0.8643382871893239, 0.8610102924522516, 0.8578314765769722, 0.8548065957550857, 0.8519402310923024, 0.8492367742128971, 0.8467004130177384, 0.8443351176947816, 0.8421446270842938, 0.8401324355032547, 0.8383017801342599, 0.8366556290836757, 0.8351966702117429, 0.8339273008337159, 0.8328496183859426, 0.8319654121440908, 0.8312761560725249, 0.8307830028742883, 0.830486779300335, 0.8303879827647959, 0.8304867793003351, 0.8307830028742889, 0.8312761560725256, 0.8319654121440915, 0.8328496183859437, 0.833927300833717, 0.8351966702117445, 0.8366556290836774, 0.8383017801342618, 0.8401324355032567, 0.8421446270842962, 0.8443351176947841, 0.8467004130177408, 0.8492367742128998, 0.8519402310923052, 0.8548065957550888, 0.8578314765769754, 0.861010292452255, 0.8643382871893275, 0.8678105439653718, 0.8714219997510112, 0.8751674596219216, 0.8790416108809754, 0.8830390369215867, 0.8871542307702566, 0.8913816082537882, 0.8957155207441033, 0.9001502674409434, 0.9046801071598648, 0.909299269599769, 0.9140019660706667, 0.9187823996684036, 0.9236347748886482, 0.9285533066775115, 0.9335322289207479, 0.9385658023775417, 0.9436483220684505, 0.9487741241301437, 0.9539375921521808, 0.9591331630132276, 0.9643553322358597, 0.9695986588804513, 0.9748577699996713, 0.9801273646757817, 0.9854022176633577, 0.9906771826601937, 0.9959471952291066, 1.0012072753930843, 1.0064525299258325, 1.0116781543592095, 1.0168794347283996, 1.0220517490749175, 1.0271905687267398, 1.0322914593739903, 1.03735008195771, 1.042362193388336, 1.0473236471095808, 1.0522303935224804, 1.057078480283482, 1.0618640524895222, 1.0665833527621962, 1.0712327212422637, 1.0758085955049272, 1.0803075104055342, 1.0847260978646205, 1.0890610866005015, 1.0933093018169486, 1.097467664852865, 1.1015331928002778, 1.1055029980964137, 1.109374288095109, 1.1131443646223156, 1.1168106235200312, 1.1203705541825535, 1.1238217390885854, 1.127161853332358, 1.1303886641566245, 1.1335000304900662, 1.1364939024913916, 1.139368321102157, 1.1421214176101093, 1.144751413224644, 1.1472566186657984, 1.1496354337680117, 1.1518863470997454, 1.1540079355999189, 1.1559988642319963, 1.1578578856564326, 1.1595838399221212, 1.1611756541773721, 1.162632342400882, 1.163953005153096, 1.165136829348292, 1.1661830880476738, 1.1670911402737085, 1.1678604308459044, 1.1684904902381978, 1.1689809344580766, 1.1693314649475448, 1.169541868506018], [1.1873420861717516, 1.1872657614138513, 1.1870368315506088, 1.1866554298275906, 1.1861217783680613, 1.1854361882439741, 1.1845990595753888, 1.183610881658331, 1.1824722331211257, 1.1811837821092332, 1.1797462864986061, 1.1781605941375983, 1.176427643117422, 1.1745484620711597, 1.1725241705012934, 1.1703559791357014, 1.1680451903120346, 1.1655931983903334, 1.1630014901937005, 1.1602716454767834, 1.1574053374217343, 1.1544043331612424, 1.1512704943281187, 1.1480057776308061, 1.1446122354540471, 1.1410920164837908, 1.1374473663552491, 1.1336806283228142, 1.1297942439503346, 1.1257907538199952, 1.121672798257779, 1.1174431180731805, 1.113104555310505, 1.1086600540087141, 1.1041126609663663, 1.0994655265077529, 1.094721905245828, 1.0898851568370018, 1.0849587467222588, 1.0799462468484382, 1.0748513363628107, 1.06967780227333, 1.0644295400661357, 1.059110554271009, 1.0537249589645525, 1.0482769781998664, 1.0427709463504475, 1.0372113083549077, 1.0316026198479342, 1.025949547161686, 1.0202568671805152, 1.0145294670305849, 1.008772343584564, 1.0029906027601856, 0.9971894585900226, 0.9913742320384133, 0.9855503495400519, 0.9797233412333884, 0.9738988388606479, 0.9680825733050655, 0.9622803717347981, 0.956498154322026, 0.9507419305049791, 0.9450177947600925, 0.9393319218512413, 0.933690561523092, 0.9281000326060724, 0.9225667165013771, 0.9170970500158411, 0.9116975175184837, 0.9063746423931174, 0.9011349777646671, 0.8959850964808346, 0.8909315803354683, 0.8859810085255512, 0.8811399453400529, 0.8764149270860918, 0.8718124482658258, 0.8673389470262779, 0.8630007899138064, 0.8588042559750804, 0.854755520257135, 0.8508606367701834, 0.84712552098824, 0.8435559319740208, 0.8401574542258662, 0.8369354793552961, 0.8338951877140313, 0.8310415300986098, 0.8283792096688285, 0.825912664222863, 0.8236460489768133, 0.8215832199993462, 0.8197277184528435, 0.8180827557908521, 0.8166512000575713, 0.8154355634285059, 0.8144379911223173, 0.8136602518023498, 0.813103729572469, 0.8127694176559273, 0.8126579138282485, 0.8127694176559274, 0.8131037295724693, 0.8136602518023504, 0.8144379911223181, 0.8154355634285068, 0.8166512000575726, 0.8180827557908538, 0.8197277184528453, 0.8215832199993482, 0.8236460489768155, 0.8259126642228656, 0.8283792096688313, 0.8310415300986126, 0.8338951877140344, 0.8369354793552993, 0.8401574542258697, 0.8435559319740243, 0.8471255209882437, 0.8508606367701874, 0.854755520257139, 0.8588042559750846, 0.8630007899138107, 0.8673389470262823, 0.8718124482658304, 0.8764149270860967, 0.8811399453400579, 0.8859810085255562, 0.8909315803354735, 0.8959850964808397, 0.9011349777646726, 0.9063746423931227, 0.9116975175184893, 0.9170970500158466, 0.9225667165013828, 0.9281000326060782, 0.9336905615230978, 0.939331921851247, 0.9450177947600983, 0.9507419305049851, 0.9564981543220319, 0.9622803717348041, 0.9680825733050715, 0.973898838860654, 0.9797233412333944, 0.985550349540058, 0.9913742320384193, 0.9971894585900286, 1.0029906027601914, 1.00877234358457, 1.0145294670305907, 1.020256867180521, 1.025949547161692, 1.03160261984794, 1.0372113083549135, 1.0427709463504535, 1.048276978199872, 1.053724958964558, 1.0591105542710146, 1.064429540066141, 1.0696778022733353, 1.0748513363628158, 1.0799462468484433, 1.0849587467222637, 1.0898851568370067, 1.094721905245833, 1.0994655265077575, 1.1041126609663712, 1.1086600540087188, 1.1131045553105094, 1.1174431180731847, 1.121672798257783, 1.1257907538199994, 1.1297942439503388, 1.133680628322818, 1.137447366355253, 1.1410920164837945, 1.1446122354540504, 1.1480057776308092, 1.1512704943281218, 1.1544043331612455, 1.1574053374217375, 1.1602716454767863, 1.1630014901937031, 1.1655931983903356, 1.1680451903120368, 1.1703559791357032, 1.1725241705012954, 1.1745484620711621, 1.1764276431174239, 1.1781605941375999, 1.1797462864986075, 1.1811837821092348, 1.1824722331211273, 1.183610881658332, 1.18459905957539, 1.1854361882439748, 1.1861217783680613, 1.186655429827591, 1.1870368315506092, 1.187265761413852], [1.2058583491552484, 1.2057757683623287, 1.2055280719527284, 1.2051153978510638, 1.204537975988848, 1.2037961283902792, 1.2028902692924694, 1.2018209053002327, 1.2005886355755864, 1.1991941520621465, 1.1976382397446297, 1.195921776943688, 1.1940457356463345, 1.1920111818722223, 1.189819276076051, 1.1874712735863868, 1.18496852508116, 1.18231247710011, 1.179504672594421, 1.1765467515137509, 1.1734404514308285, 1.1701876082037326, 1.1667901566758903, 1.163250131413759, 1.1595696674820488, 1.1557510012562136, 1.1517964712718076, 1.147708519110128, 1.1434896903193732, 1.1391426353703291, 1.134670110645329, 1.130074979458964, 1.1253602131086722, 1.1205288919529877, 1.1155842065147996, 1.1105294586065264, 1.1053680624735784, 1.1001035459519262, 1.0947395516349443, 1.0892798380440076, 1.083728280796542, 1.0780888737643883, 1.072365730214403, 1.0665630839222127, 1.0606852902489379, 1.0547368271695012, 1.0487222962398497, 1.0426464234890223, 1.0365140602205103, 1.0303301837057581, 1.0240998977509537, 1.01782843311647, 1.0115211477664223, 1.005183526923832, 0.9988211829048241, 0.992439854703175, 0.9860454072943373, 0.9796438306258906, 0.9732412382591386, 0.9668438656244203, 0.9604580678505829, 0.9540903171270598, 0.9477471995551677, 0.9414354114435907, 0.9351617550016896, 0.9289331333832643, 0.9227565450328369, 0.9166390772864681, 0.9105878991796742, 0.9046102534162691, 0.8987134474540065, 0.8929048436658633, 0.8871918485397534, 0.8815819008845105, 0.8760824590162052, 0.8707009869063291, 0.865444939282161, 0.8603217456797283, 0.8553387934612324, 0.8505034098215574, 0.8458228428224623, 0.8413042415081821, 0.8369546351722326, 0.8327809118620408, 0.8287897962253438, 0.8249878268197817, 0.821381333024418, 0.8179764117086187, 0.8147789038293971, 0.8117943711425014, 0.8090280732247167, 0.8064849450146175, 0.804169575085874, 0.8020861848708019, 0.8002386090518099, 0.7986302773344729, 0.7972641978079923, 0.7961429420867443, 0.7952686324105336, 0.7946429308612679, 0.794267030830365, 0.7941416508447515, 0.7942670308303652, 0.7946429308612684, 0.7952686324105342, 0.7961429420867452, 0.7972641978079935, 0.7986302773344744, 0.8002386090518117, 0.8020861848708039, 0.8041695750858765, 0.80648494501462, 0.8090280732247193, 0.8117943711425044, 0.8147789038294003, 0.8179764117086221, 0.8213813330244216, 0.8249878268197854, 0.8287897962253479, 0.8327809118620452, 0.836954635172237, 0.8413042415081866, 0.8458228428224669, 0.8505034098215624, 0.8553387934612374, 0.8603217456797334, 0.8654449392821664, 0.8707009869063347, 0.8760824590162107, 0.8815819008845163, 0.8871918485397592, 0.8929048436658692, 0.8987134474540124, 0.9046102534162752, 0.9105878991796804, 0.9166390772864741, 0.9227565450328433, 0.9289331333832707, 0.9351617550016962, 0.9414354114435973, 0.9477471995551743, 0.9540903171270665, 0.9604580678505893, 0.9668438656244269, 0.9732412382591451, 0.9796438306258972, 0.9860454072943439, 0.9924398547031814, 0.9988211829048308, 1.0051835269238385, 1.011521147766429, 1.0178284331164762, 1.0240998977509599, 1.0303301837057646, 1.0365140602205165, 1.0426464234890285, 1.0487222962398557, 1.0547368271695075, 1.0606852902489436, 1.0665630839222184, 1.072365730214409, 1.0780888737643943, 1.0837282807965476, 1.0892798380440132, 1.09473955163495, 1.100103545951932, 1.1053680624735838, 1.1105294586065315, 1.1155842065148047, 1.1205288919529925, 1.1253602131086773, 1.1300749794589686, 1.1346701106453339, 1.1391426353703333, 1.1434896903193776, 1.147708519110132, 1.1517964712718118, 1.1557510012562175, 1.1595696674820526, 1.1632501314137624, 1.1667901566758936, 1.1701876082037361, 1.1734404514308319, 1.1765467515137538, 1.179504672594424, 1.1823124771001128, 1.1849685250811623, 1.1874712735863895, 1.189819276076053, 1.1920111818722243, 1.1940457356463365, 1.1959217769436898, 1.1976382397446315, 1.1991941520621483, 1.200588635575588, 1.2018209053002342, 1.2028902692924708, 1.20379612839028, 1.2045379759888488, 1.205115397851064, 1.2055280719527284, 1.205775768362329], [1.2251428928971122, 1.2250539975070693, 1.224787358647028, 1.224343118267023, 1.2237215130163863, 1.2229228743427696, 1.2219476286310085, 1.2207962973820536, 1.2194694974322555, 1.2179679412133613, 1.2162924370536294, 1.2144438895205278, 1.2124232998055386, 1.2102317661516349, 1.2078704843240404, 1.205340748124932, 1.2026439499527606, 1.1997815814069088, 1.1967552339384167, 1.1935665995475107, 1.190217471528682, 1.1867097452640358, 1.183045419065618, 1.1792265950673817, 1.1752554801673911, 1.1711343870208077, 1.1668657350840723, 1.1624520517106136, 1.1578959732982332, 1.1532002464881699, 1.1483677294156105, 1.1434013930111895, 1.1383043223527178, 1.1330797180660614, 1.127730897773695, 1.1222612975890318, 1.1166744736541259, 1.110974103717781, 1.1051639887504576, 1.0992480545916672, 1.0932303536247188, 1.087115066472802, 1.0809065037093812, 1.0746091075747664, 1.0682274536895, 1.0617662527538445, 1.055230352221158, 1.0486247379313285, 1.0419545356886382, 1.035225012766512, 1.028441579319485, 1.0216097896804817, 1.0147353435190525, 1.0078240868336241, 1.0008820127480593, 0.9939152620799042, 0.9869301236446344, 0.979933034257036, 0.9729305783875428, 0.9659294874279983, 0.9589366385178895, 0.9519590528787079, 0.9450038936007563, 0.9380784628235171, 0.93119019824772, 0.9243466689145556, 0.9175555701852274, 0.9108247178522829, 0.9041620413131097, 0.8975755757357009, 0.8910734531475097, 0.884663892380033, 0.8783551878048992, 0.8721556968018341, 0.8660738259051252, 0.8601180155832471, 0.8542967236163048, 0.8486184070479917, 0.8430915027029666, 0.8377244062769166, 0.8325254500251176, 0.8275028790959147, 0.8226648265780843, 0.8180192873552328, 0.8135740908859465, 0.8093368730548358, 0.8053150472664637, 0.8015157749807338, 0.79794593591399, 0.7946120981540662, 0.7915204884590232, 0.7886769630275132, 0.7860869790428058, 0.7837555673017457, 0.7816873062436331, 0.7798862976916663, 0.7783561446107938, 0.7770999311704042, 0.7761202053782281, 0.775418964523436, 0.7749976436326181, 0.7748571071028877, 0.7749976436326184, 0.7754189645234365, 0.7761202053782289, 0.7770999311704052, 0.7783561446107953, 0.779886297691668, 0.7816873062436351, 0.783755567301748, 0.7860869790428083, 0.7886769630275162, 0.7915204884590262, 0.7946120981540695, 0.7979459359139935, 0.8015157749807377, 0.8053150472664677, 0.8093368730548401, 0.813574090885951, 0.8180192873552375, 0.8226648265780891, 0.8275028790959199, 0.8325254500251228, 0.837724406276922, 0.8430915027029722, 0.8486184070479975, 0.8542967236163107, 0.8601180155832533, 0.8660738259051313, 0.8721556968018406, 0.8783551878049056, 0.8846638923800396, 0.8910734531475162, 0.8975755757357077, 0.9041620413131165, 0.9108247178522898, 0.9175555701852344, 0.9243466689145627, 0.931190198247727, 0.9380784628235241, 0.9450038936007634, 0.9519590528787151, 0.9589366385178967, 0.9659294874280056, 0.97293057838755, 0.9799330342570434, 0.9869301236446416, 0.9939152620799113, 1.0008820127480667, 1.0078240868336312, 1.0147353435190594, 1.0216097896804885, 1.0284415793194919, 1.035225012766519, 1.0419545356886453, 1.0486247379313354, 1.0552303522211648, 1.0617662527538512, 1.0682274536895067, 1.0746091075747726, 1.0809065037093875, 1.0871150664728084, 1.093230353624725, 1.0992480545916734, 1.1051639887504636, 1.110974103717787, 1.1166744736541316, 1.1222612975890374, 1.1277308977737004, 1.133079718066067, 1.1383043223527232, 1.1434013930111944, 1.1483677294156154, 1.1532002464881748, 1.157895973298238, 1.162452051710618, 1.1668657350840772, 1.1711343870208122, 1.1752554801673953, 1.1792265950673855, 1.1830454190656219, 1.186709745264039, 1.1902174715286853, 1.193566599547514, 1.1967552339384198, 1.1997815814069117, 1.2026439499527635, 1.205340748124935, 1.2078704843240424, 1.210231766151637, 1.2124232998055406, 1.2144438895205296, 1.2162924370536312, 1.217967941213363, 1.2194694974322569, 1.2207962973820552, 1.2219476286310098, 1.22292287434277, 1.223721513016387, 1.2243431182670232, 1.2247873586470281, 1.2250539975070693], [1.2451770608467454, 1.2450818125276264, 1.2447961160127314, 1.2443201166514561, 1.2436540567662118, 1.2427982757627207, 1.241753210284774, 1.2405193944137805, 1.2390974599135498, 1.2374881365208323, 1.2356922522822384, 1.2337107339382476, 1.2315446073551113, 1.2291949980055337, 1.2266631314991026, 1.2239503341635192, 1.221058033677758, 1.2179877597583433, 1.2147411449000145, 1.2113199251720868, 1.2077259410718824, 1.203961138436638, 1.2000275694153213, 1.1959273935018138, 1.1916628786309107, 1.187236402338584, 1.1826504529879096, 1.1779076310620158, 1.1730106505253222, 1.1679623402542367, 1.1627656455383348, 1.1574236296528697, 1.1519394755032495, 1.1463164873418545, 1.1405580925572456, 1.134667843535461, 1.128649419592645, 1.1225066289777557, 1.1162434109435013, 1.109863837882986, 1.1033721175287594, 1.0967725952100837, 1.0900697561632198, 1.0832682278883945, 1.0763727825458296, 1.06938833938176, 1.0623199671737618, 1.0551728866828967, 1.047952473098192, 1.0406642584567363, 1.0333139340202429, 1.0259073525862357, 1.0184505307090674, 1.0109496508027849, 1.0034110630943691, 0.9958412873921363, 0.9882470146300523, 0.9806351081444299, 0.9730126046349178, 0.9653867147569145, 0.9577648232875476, 0.9501544888022113, 0.9425634427933958, 0.9349995881582557, 0.9274709969761238, 0.919985907492107, 0.9125527202181127, 0.9051799930583243, 0.8978764353624179, 0.8906509008069259, 0.8835123790032984, 0.8764699857306639, 0.8695329516923077, 0.8627106096977432, 0.8560123801772738, 0.8494477549434007, 0.8430262791236273, 0.8367575312024289, 0.8306511011266103, 0.8247165664481636, 0.8189634665021677, 0.8134012746442735, 0.8080393686027825, 0.8028869990340453, 0.7979532564065052, 0.7932470363776353, 0.7887770038685864, 0.7845515560826515, 0.7805787847546654, 0.776866437957928, 0.773421881831931, 0.7702520626266081, 0.7673634694856754, 0.76476209841145, 0.7624534178650939, 0.7604423364584287, 0.7587331731854783, 0.7573296306231793, 0.7562347715011544, 0.7554509990002762, 0.7549800410897082, 0.7548229391532547, 0.7549800410897085, 0.7554509990002769, 0.7562347715011554, 0.7573296306231806, 0.7587331731854797, 0.7604423364584306, 0.7624534178650961, 0.7647620984114527, 0.7673634694856782, 0.7702520626266112, 0.7734218818319345, 0.7768664379579316, 0.7805787847546692, 0.7845515560826558, 0.7887770038685907, 0.7932470363776402, 0.7979532564065102, 0.8028869990340505, 0.8080393686027879, 0.8134012746442792, 0.8189634665021734, 0.8247165664481695, 0.8306511011266166, 0.8367575312024352, 0.8430262791236337, 0.8494477549434075, 0.8560123801772807, 0.8627106096977502, 0.8695329516923148, 0.8764699857306711, 0.8835123790033055, 0.8906509008069332, 0.8978764353624255, 0.9051799930583319, 0.9125527202181203, 0.9199859074921147, 0.9274709969761316, 0.9349995881582635, 0.9425634427934036, 0.9501544888022192, 0.9577648232875555, 0.9653867147569224, 0.9730126046349257, 0.9806351081444379, 0.98824701463006, 0.9958412873921441, 1.003411063094377, 1.0109496508027924, 1.018450530709075, 1.0259073525862432, 1.0333139340202504, 1.0406642584567434, 1.0479524730981995, 1.0551728866829042, 1.062319967173769, 1.0693883393817674, 1.0763727825458367, 1.0832682278884016, 1.0900697561632267, 1.0967725952100906, 1.103372117528766, 1.1098638378829926, 1.1162434109435078, 1.122506628977762, 1.1286494195926513, 1.134667843535467, 1.1405580925572514, 1.1463164873418603, 1.1519394755032555, 1.157423629652875, 1.1627656455383404, 1.167962340254242, 1.1730106505253275, 1.1779076310620207, 1.1826504529879145, 1.1872364023385886, 1.1916628786309151, 1.195927393501818, 1.2000275694153257, 1.203961138436642, 1.2077259410718864, 1.2113199251720903, 1.214741144900018, 1.2179877597583464, 1.2210580336777608, 1.2239503341635218, 1.226663131499105, 1.2291949980055366, 1.2315446073551135, 1.2337107339382496, 1.2356922522822402, 1.2374881365208341, 1.2390974599135514, 1.2405193944137816, 1.2417532102847753, 1.2427982757627218, 1.243654056766212, 1.2443201166514566, 1.244796116012732, 1.2450818125276268], [1.2659414712405423, 1.2658398506164996, 1.2655350381234578, 1.2650271819224754, 1.2643165290280336, 1.2634034254273376, 1.262288316247787, 1.2609717459730636, 1.259454358708415, 1.2577368984958344, 1.2558202096799738, 1.2537052373257451, 1.2513930276886942, 1.2488847287393594, 1.2461815907429479, 1.2432849668957862, 1.24019631402012, 1.2369171933189609, 1.2334492711927876, 1.2297943201200177, 1.2259542196032822, 1.2219309571836199, 1.2177266295248084, 1.2133434435701371, 1.2087837177739864, 1.204049883410648, 1.1991444859628613, 1.1940701865925742, 1.1888297636964351, 1.183426114548511, 1.1778622570326838, 1.1721413314671003, 1.1662666025229274, 1.1602414612395253, 1.1540694271379295, 1.1477541504342776, 1.1412994143544972, 1.1347091375511578, 1.1279873766229211, 1.1211383287364465, 1.11416633434992, 1.1070758800365919, 1.099871601405752, 1.092558286117517, 1.0851408769865292, 1.0776244751682529, 1.0700143434199, 1.0623159094261645, 1.0545347691778153, 1.046676690388826, 1.0387476159350204, 1.030753667294214, 1.0227011479644743, 1.0145965468333962, 1.0064465414671666, 0.998258001283656, 0.9900379905688002, 0.9817937712901149, 0.9735328056553175, 0.9652627583576955, 0.9569914984430982, 0.9487271007262427, 0.9404778466764693, 0.9322522246851979, 0.924058929619247, 0.9159068615559348, 0.9078051235876843, 0.8997630185758319, 0.8917900447257369, 0.8838958898483403, 0.8760904241673317, 0.868383691526409, 0.8607858988481263, 0.8533074036949637, 0.8459586997850053, 0.8387504003194441, 0.8316932189876072, 0.824797948527797, 0.8180754367395006, 0.8115365598648737, 0.8051921932852345, 0.7990531795118961, 0.7931302934901096, 0.7874342052801272, 0.7819754402301318, 0.7767643368114118, 0.7718110023458519, 0.7671252669183442, 0.7627166358306222, 0.7585942410164266, 0.7547667918987708, 0.7512425262260597, 0.7480291614724957, 0.7451338474271193, 0.742563120622624, 0.7403228612676322, 0.7384182533426684, 0.7368537484994381, 0.735633034364586, 0.7347590077930495, 0.7342337535433566, 0.7340585287594575, 0.7342337535433571, 0.7347590077930503, 0.7356330343645873, 0.7368537484994395, 0.7384182533426702, 0.7403228612676345, 0.7425631206226265, 0.745133847427122, 0.748029161472499, 0.7512425262260631, 0.7547667918987746, 0.7585942410164307, 0.7627166358306265, 0.7671252669183488, 0.7718110023458568, 0.7767643368114171, 0.7819754402301373, 0.787434205280133, 0.7931302934901157, 0.7990531795119025, 0.8051921932852408, 0.8115365598648804, 0.8180754367395074, 0.8247979485278039, 0.8316932189876142, 0.8387504003194515, 0.8459586997850128, 0.8533074036949713, 0.860785898848134, 0.8683836915264169, 0.8760904241673396, 0.8838958898483484, 0.8917900447257452, 0.89976301857584, 0.9078051235876926, 0.9159068615559431, 0.9240589296192553, 0.9322522246852061, 0.9404778466764777, 0.9487271007262513, 0.9569914984431066, 0.965262758357704, 0.973532805655326, 0.9817937712901232, 0.9900379905688087, 0.9982580012836645, 1.006446541467175, 1.0145965468334044, 1.0227011479644827, 1.0307536672942224, 1.0387476159350284, 1.0466766903888343, 1.0545347691778233, 1.0623159094261723, 1.070014343419908, 1.0776244751682607, 1.085140876986537, 1.0925582861175243, 1.0998716014057592, 1.1070758800365992, 1.1141663343499273, 1.1211383287364534, 1.1279873766229283, 1.1347091375511646, 1.1412994143545039, 1.1477541504342839, 1.1540694271379357, 1.1602414612395318, 1.1662666025229336, 1.172141331467106, 1.1778622570326898, 1.1834261145485165, 1.1888297636964409, 1.1940701865925796, 1.1991444859628664, 1.204049883410653, 1.2087837177739913, 1.2133434435701413, 1.2177266295248124, 1.2219309571836237, 1.2259542196032862, 1.2297943201200212, 1.233449271192791, 1.2369171933189642, 1.240196314020123, 1.2432849668957895, 1.2461815907429505, 1.248884728739362, 1.2513930276886964, 1.2537052373257476, 1.255820209679976, 1.2577368984958364, 1.2594543587084166, 1.2609717459730656, 1.262288316247788, 1.2634034254273385, 1.2643165290280345, 1.2650271819224757, 1.265535038123458, 1.2658398506164996], [1.2874160358524958, 1.2873080411921376, 1.2869841073466861, 1.2864443847481002, 1.2856891242000117, 1.2847186770035555, 1.2835334951340829, 1.2821341314693162, 1.2805212400696488, 1.27869557651148, 1.2766579982746, 1.2744094651848372, 1.2719510399133143, 1.2692838885338462, 1.2664092811401586, 1.2633285925247844, 1.260043302921661, 1.256554998814603, 1.2528653738140205, 1.2489762296043827, 1.2448894769651286, 1.240607136867862, 1.236131341652841, 1.2314643362879332, 1.2266084797133436, 1.2215662462755872, 1.2163402272542914, 1.2109331324855617, 1.2053477920857314, 1.1995871582794277, 1.1936543073359482, 1.1875524416179961, 1.1812848917468342, 1.1748551188879068, 1.168266717160916, 1.1615234161782275, 1.1546290837153217, 1.1475877285167662, 1.1404035032408764, 1.1330807075458302, 1.125623791319496, 1.1180373580546061, 1.1103261683701509, 1.1024951436789405, 1.0945493700001965, 1.0864941019147272, 1.0783347666587209, 1.070076968350405, 1.0617264923417482, 1.0532893096849922, 1.0447715817010435, 1.0361796646336083, 1.0275201143693633, 1.0187996912003872, 1.0100253646004753, 1.0012043179817989, 0.9923439533925863, 0.9834518961100691, 0.974535999075801, 0.9656043471126134, 0.9566652608538652, 0.947727300306286, 0.9387992679576173, 0.9298902113294096, 0.9210094248638538, 0.9121664510214322, 0.9033710804536407, 0.8946333511022125, 0.885963546063381, 0.8773721900430792, 0.8688700442168866, 0.8604680992975022, 0.8521775666029975, 0.844009866911739, 0.8359766168853195, 0.8280896128398774, 0.8203608116496615, 0.8128023085754861, 0.8054263118257566, 0.7982451136799197, 0.7912710580343799, 0.7845165042698651, 0.7779937873874968, 0.7717151744187594, 0.7656928171821611, 0.7599387015362448, 0.7544645933638431, 0.7492819816146588, 0.7444020188303637, 0.7398354596758399, 0.735592598098717, 0.7316832038333356, 0.7281164590505406, 0.7249008960270449, 0.7220443367631566, 0.7195538355114293, 0.717435625187765, 0.715695068618006, 0.714336615525487, 0.7133637660880872, 0.7127790417881182, 0.7125839641475042, 0.7127790417881187, 0.7133637660880878, 0.7143366155254882, 0.7156950686180076, 0.717435625187767, 0.7195538355114318, 0.7220443367631595, 0.724900896027048, 0.7281164590505441, 0.7316832038333395, 0.7355925980987214, 0.7398354596758443, 0.7444020188303686, 0.7492819816146639, 0.7544645933638486, 0.7599387015362506, 0.7656928171821673, 0.7717151744187657, 0.7779937873875035, 0.784516504269872, 0.791271058034387, 0.7982451136799269, 0.8054263118257641, 0.8128023085754938, 0.8203608116496693, 0.8280896128398855, 0.8359766168853275, 0.8440098669117474, 0.8521775666030059, 0.860468099297511, 0.8688700442168952, 0.8773721900430879, 0.88596354606339, 0.8946333511022214, 0.90337108045365, 0.9121664510214413, 0.921009424863863, 0.9298902113294187, 0.9387992679576265, 0.9477273003062953, 0.9566652608538743, 0.9656043471126227, 0.9745359990758101, 0.9834518961100784, 0.9923439533925954, 1.0012043179818078, 1.0100253646004844, 1.0187996912003965, 1.0275201143693724, 1.036179664633617, 1.0447715817010523, 1.053289309685001, 1.0617264923417569, 1.0700769683504137, 1.0783347666587295, 1.0864941019147356, 1.0945493700002047, 1.1024951436789485, 1.1103261683701589, 1.1180373580546141, 1.1256237913195037, 1.133080707545838, 1.1404035032408837, 1.1475877285167735, 1.1546290837153288, 1.1615234161782344, 1.168266717160923, 1.1748551188879135, 1.1812848917468406, 1.1875524416180026, 1.1936543073359545, 1.1995871582794337, 1.2053477920857374, 1.2109331324855672, 1.2163402272542971, 1.2215662462755923, 1.2266084797133487, 1.2314643362879378, 1.2361313416528457, 1.2406071368678662, 1.2448894769651329, 1.2489762296043867, 1.2528653738140243, 1.2565549988146067, 1.2600433029216642, 1.2633285925247877, 1.2664092811401613, 1.2692838885338493, 1.271951039913317, 1.2744094651848394, 1.2766579982746025, 1.278695576511482, 1.2805212400696508, 1.2821341314693175, 1.2835334951340847, 1.2847186770035564, 1.2856891242000124, 1.2864443847481009, 1.2869841073466866, 1.2873080411921378], [1.309579979428256, 1.3094656253155794, 1.3091226137074161, 1.3085510968192304, 1.3077513284297604, 1.3067236640107895, 1.3054685609094747, 1.303986578583881, 1.3022783788925612, 1.3003447264392098, 1.2981864889736086, 1.2958046378502825, 1.2932002485464775, 1.2903745012412677, 1.2873286814578173, 1.284064180771018, 1.2805824975829365, 1.2768852379687206, 1.272974116595846, 1.2688509577197757, 1.264517696259375, 1.2599763789556053, 1.255229165617299, 1.2502783304580147, 1.2451262635282325, 1.2397754722473655, 1.2342285830403186, 1.228488343083534, 1.2225576221657108, 1.2164394146685875, 1.210136841673393, 1.2036531531987642, 1.1969917305760973, 1.1901560889684615, 1.1831498800393083, 1.1759768947773155, 1.1686410664837181, 1.1611464739284902, 1.1534973446816366, 1.1456980586257073, 1.1377531516553965, 1.1296673195697182, 1.1214454221617631, 1.1130924875104042, 1.1046137164775016, 1.0960144874131281, 1.0873003610700986, 1.0784770857275499, 1.069550602521485, 1.0605270509780125, 1.0514127747424145, 1.042214327494132, 1.0329384790341916, 1.0235922215274584, 1.0141827758773072, 1.0047175982048002, 0.9952043863981545, 0.9856510866911021, 0.97606590022062, 0.966457289505343, 0.9568339847757067, 0.9472049900754334, 0.937579589041312, 0.9279673502543091, 0.9183781320398605, 0.9088220865787695, 0.8993096631725321, 0.8898516104882659, 0.8804589775888972, 0.8711431135341828, 0.8619156653178217, 0.8527885738858937, 0.8437740679627074, 0.8348846553926562, 0.8261331116917326, 0.8175324654910526, 0.8090959805482989, 0.8008371340027979, 0.7927695905575037, 0.7849071722880948, 0.77726382380728, 0.7698535725529084, 0.7626904840229755, 0.7557886118503108, 0.7491619426954077, 0.7428243360376955, 0.736789459063068, 0.7310707169772789, 0.7256811792184947, 0.7206335021943704, 0.715939849324853, 0.7116118093258228, 0.707660313814003, 0.7040955554429803, 0.700926907886051, 0.6981628490563947, 0.695810888991984, 0.6938775038259961, 0.6923680772095053, 0.6912868504502759, 0.6906368824805678, 0.6904200205717438, 0.6906368824805681, 0.6912868504502768, 0.6923680772095068, 0.6938775038259979, 0.6958108889919861, 0.6981628490563973, 0.700926907886054, 0.7040955554429837, 0.7076603138140068, 0.7116118093258271, 0.7159398493248577, 0.7206335021943754, 0.7256811792185002, 0.7310707169772845, 0.7367894590630741, 0.7428243360377019, 0.7491619426954146, 0.7557886118503178, 0.7626904840229829, 0.769853572552916, 0.7772638238072878, 0.7849071722881028, 0.7927695905575118, 0.8008371340028062, 0.8090959805483074, 0.8175324654910614, 0.8261331116917415, 0.8348846553926653, 0.8437740679627166, 0.8527885738859029, 0.8619156653178311, 0.8711431135341923, 0.8804589775889069, 0.8898516104882755, 0.8993096631725419, 0.908822086578779, 0.9183781320398704, 0.927967350254319, 0.937579589041322, 0.9472049900754432, 0.9568339847757167, 0.9664572895053529, 0.97606590022063, 0.9856510866911121, 0.9952043863981643, 1.00471759820481, 1.014182775877317, 1.0235922215274682, 1.0329384790342013, 1.0422143274941416, 1.051412774742424, 1.0605270509780218, 1.069550602521494, 1.0784770857275592, 1.0873003610701075, 1.096014487413137, 1.1046137164775105, 1.113092487510413, 1.1214454221617713, 1.1296673195697267, 1.137753151655405, 1.1456980586257153, 1.1534973446816446, 1.1611464739284982, 1.1686410664837257, 1.1759768947773226, 1.1831498800393156, 1.1901560889684686, 1.1969917305761044, 1.2036531531987709, 1.2101368416733995, 1.216439414668594, 1.222557622165717, 1.22848834308354, 1.2342285830403243, 1.2397754722473713, 1.2451262635282379, 1.2502783304580196, 1.2552291656173034, 1.2599763789556098, 1.2645176962593794, 1.2688509577197802, 1.2729741165958497, 1.2768852379687243, 1.2805824975829398, 1.2840641807710218, 1.2873286814578202, 1.2903745012412706, 1.2932002485464802, 1.295804637850285, 1.2981864889736106, 1.3003447264392118, 1.302278378892563, 1.303986578583883, 1.305468560909476, 1.3067236640107904, 1.3077513284297613, 1.3085510968192309, 1.3091226137074163, 1.3094656253155794], [1.3324118597838495, 1.3322911757895854, 1.3319291749878712, 1.3313260109480605, 1.3304819397062395, 1.3293973198963358, 1.3280726129344027, 1.3265083832568134, 1.3247052986133068, 1.3226641304160567, 1.32038575414614, 1.3178711498190152, 1.3151214025108477, 1.3121377029477492, 1.3089213481602395, 1.3054737422054972, 1.3017963969601933, 1.2978909329869905, 1.2937590804780439, 1.2894026802791156, 1.2848236849982102, 1.280024160202923, 1.2750062857110025, 1.2697723569789379, 1.2643247865937033, 1.2586661058731172, 1.252798966580621, 1.246726142760607, 1.2404505327007964, 1.2339751610285004, 1.227303180947964, 1.2204378766263433, 1.2133826657362121, 1.2061411021628428, 1.1987168788848195, 1.191113831036873, 1.1833359391640879, 1.1753873326768896, 1.1672722935164257, 1.1589952600400941, 1.150560831137049, 1.141973770583507, 1.1332390116475484, 1.1243616619528647, 1.1153470086105013, 1.1062005236270451, 1.0969278695969027, 1.0875349056852408, 1.0780276939067748, 1.068412505703862, 1.0586958288251904, 1.048884374503714, 1.0389850849292783, 1.0290051410075394, 1.0189519703921763, 1.008833255771986, 0.9986569433880463, 0.9884312517487047, 0.9781646805014464, 0.9678660194107411, 0.9575443573794338, 0.9472090914381726, 0.9368699356124627, 0.9265369295601814, 0.9162204468536009, 0.9059312027591012, 0.895680261344733, 0.8854790417206629, 0.8753393231903324, 0.8652732490611216, 0.8552933288326816, 0.8454124384493737, 0.8356438182710343, 0.8260010683844283, 0.8164981408473421, 0.8071493284296506, 0.7979692493925505, 0.7889728278303981, 0.7801752690915426, 0.7715920297977048, 0.7632387819986027, 0.7551313710325698, 0.747285766717754, 0.7397180075748567, 0.732444137883613, 0.7254801375029981, 0.7188418445401499, 0.7125448711346476, 0.706604512830845, 0.7010356522373249, 0.6958526579130229, 0.6910692796658242, 0.6866985416910745, 0.6827526352023418, 0.6792428124016535, 0.6761792837875922, 0.6735711208939659, 0.6714261665778576, 0.6697509549250672, 0.6685506427085716, 0.6678289541215771, 0.6675881402161504, 0.6678289541215776, 0.6685506427085726, 0.6697509549250686, 0.6714261665778595, 0.6735711208939683, 0.6761792837875952, 0.6792428124016568, 0.6827526352023454, 0.6866985416910788, 0.691069279665829, 0.6958526579130281, 0.7010356522373306, 0.7066045128308509, 0.7125448711346538, 0.7188418445401565, 0.7254801375030052, 0.7324441378836204, 0.7397180075748643, 0.7472857667177621, 0.755131371032578, 0.7632387819986111, 0.7715920297977134, 0.7801752690915514, 0.7889728278304072, 0.7979692493925598, 0.8071493284296601, 0.8164981408473517, 0.8260010683844382, 0.8356438182710442, 0.8454124384493837, 0.8552933288326917, 0.8652732490611317, 0.8753393231903427, 0.8854790417206733, 0.8956802613447437, 0.9059312027591119, 0.9162204468536116, 0.926536929560192, 0.9368699356124732, 0.9472090914381833, 0.9575443573794443, 0.9678660194107516, 0.9781646805014572, 0.988431251748715, 0.9986569433880569, 1.0088332557719963, 1.0189519703921868, 1.0290051410075496, 1.0389850849292883, 1.0488843745037242, 1.0586958288252006, 1.0684125057038718, 1.0780276939067845, 1.0875349056852506, 1.0969278695969127, 1.1062005236270545, 1.1153470086105108, 1.1243616619528738, 1.1332390116475572, 1.141973770583516, 1.1505608311370576, 1.1589952600401026, 1.1672722935164341, 1.175387332676898, 1.183335939164096, 1.1911138310368807, 1.198716878884827, 1.2061411021628503, 1.2133826657362197, 1.2204378766263502, 1.2273031809479709, 1.2339751610285072, 1.240450532700803, 1.246726142760613, 1.2527989665806272, 1.2586661058731232, 1.2643247865937088, 1.2697723569789434, 1.2750062857110076, 1.2800241602029279, 1.284823684998215, 1.2894026802791203, 1.2937590804780483, 1.2978909329869945, 1.3017963969601969, 1.3054737422055012, 1.3089213481602426, 1.3121377029477521, 1.3151214025108506, 1.3178711498190177, 1.3203857541461423, 1.3226641304160591, 1.3247052986133088, 1.3265083832568154, 1.3280726129344043, 1.329397319896337, 1.3304819397062402, 1.3313260109480607, 1.3319291749878712, 1.3322911757895854], [1.3558895885496056, 1.3557626179184399, 1.3553817575343081, 1.3547471619511744, 1.3538590888453201, 1.3527178991452522, 1.3513240572143785, 1.349678131087241, 1.3477807927603527, 1.345632818538912, 1.343235089440905, 1.3405885916603715, 1.3376944170918468, 1.3345537639182776, 1.3311679372649512, 1.3275383499222877, 1.323666523140618, 1.3195540875003768, 1.3152027838614524, 1.310614464395769, 1.305791093707504, 1.300734750045717, 1.2954476266145136, 1.2899320329862807, 1.2841903966239085, 1.2782252645183525, 1.2720393049483116, 1.2656353093692716, 1.2590161944396123, 1.2521850041919882, 1.2451449123586844, 1.2378992248601726, 1.2304513824666288, 1.2228049636427183, 1.2149636875864969, 1.2069314174738488, 1.1987121639204181, 1.1903100886735485, 1.1817295085472657, 1.1729748996138496, 1.164050901665991, 1.1549623229639572, 1.145714145282512, 1.1363115292725925, 1.1267598201528786, 1.1170645537463513, 1.107231462876767, 1.097266484139519, 1.0871757650606786, 1.076965671656968, 1.0666427964079968, 1.056213966650192, 1.0456862533993931, 1.0350669806059567, 1.0243637348423178, 1.0135843754181386, 1.0027370449123083, 0.9918301801039615, 0.9808725232761829, 0.9698731338559534, 0.9588414003419461, 0.9477870524577754, 0.9367201734519676, 0.9256512124470223, 0.914590996718191, 0.9035507437577777, 0.8925420729526261, 0.8815770166708217, 0.870668030518369, 0.8598280024876878, 0.8490702606772833, 0.8384085792161776, 0.8278571819780972, 0.8174307436197898, 0.8071443874262861, 0.7970136793949166, 0.7870546179414711, 0.7772836185684963, 0.7677174928005018, 0.7583734206674385, 0.7492689160104764, 0.7404217838976433, 0.7318500694763926, 0.7235719976609755, 0.7156059031597333, 0.7079701504956529, 0.7006830438662119, 0.6937627269274311, 0.687227072871528, 0.6810935654939891, 0.6753791723069892, 0.6701002111406137, 0.6652722120658846, 0.6609097768548198, 0.6570264385402351, 0.6536345239273117, 0.6507450221154736, 0.6483674621901795, 0.6465098032213065, 0.6451783395459152, 0.6443776240147955, 0.6441104114503944, 0.6443776240147959, 0.6451783395459163, 0.646509803221308, 0.6483674621901817, 0.6507450221154762, 0.653634523927315, 0.6570264385402389, 0.6609097768548239, 0.6652722120658894, 0.6701002111406189, 0.6753791723069948, 0.6810935654939954, 0.6872270728715345, 0.693762726927438, 0.7006830438662193, 0.7079701504956607, 0.7156059031597414, 0.7235719976609838, 0.7318500694764014, 0.7404217838976523, 0.7492689160104856, 0.7583734206674481, 0.7677174928005116, 0.7772836185685061, 0.7870546179414813, 0.797013679394927, 0.8071443874262967, 0.8174307436198006, 0.827857181978108, 0.8384085792161885, 0.8490702606772943, 0.8598280024876989, 0.8706680305183803, 0.8815770166708329, 0.8925420729526373, 0.903550743757789, 0.9145909967182023, 0.9256512124470335, 0.9367201734519788, 0.9477870524577867, 0.9588414003419573, 0.9698731338559645, 0.9808725232761942, 0.9918301801039728, 1.0027370449123194, 1.0135843754181497, 1.024363734842329, 1.0350669806059676, 1.045686253399404, 1.0562139666502026, 1.0666427964080072, 1.0769656716569784, 1.087175765060689, 1.0972664841395294, 1.1072314628767772, 1.1170645537463615, 1.1267598201528886, 1.1363115292726023, 1.145714145282521, 1.1549623229639665, 1.1640509016660003, 1.1729748996138585, 1.1817295085472748, 1.1903100886735571, 1.1987121639204268, 1.2069314174738572, 1.214963687586505, 1.222804963642726, 1.2304513824666368, 1.2378992248601801, 1.2451449123586917, 1.2521850041919953, 1.2590161944396192, 1.2656353093692783, 1.272039304948318, 1.2782252645183587, 1.2841903966239148, 1.2899320329862864, 1.2954476266145194, 1.3007347500457223, 1.3057910937075092, 1.3106144643957736, 1.315202783861457, 1.319554087500381, 1.3236665231406222, 1.3275383499222917, 1.3311679372649545, 1.3345537639182812, 1.3376944170918497, 1.3405885916603741, 1.343235089440908, 1.3456328185389141, 1.347780792760355, 1.3496781310872425, 1.3513240572143803, 1.3527178991452535, 1.3538590888453208, 1.3547471619511753, 1.3553817575343088, 1.3557626179184403], [1.3799904525392286, 1.3798572509060085, 1.379457697741481, 1.378791948276185, 1.3778602613116093, 1.3766629993465018, 1.375200628754553, 1.3734737200143028, 1.3714829479923782, 1.3692290922814172, 1.3667130375943028, 1.3639357742165896, 1.3608983985192933, 1.357602113534491, 1.3540482295964786, 1.3502381650515458, 1.3461734470397477, 1.3418557123523815, 1.3372867083692503, 1.3324682940801373, 1.3274024411953333, 1.3220912353504433, 1.3165368774111477, 1.3107416848840352, 1.3047080934401152, 1.2984386585581096, 1.291936057295162, 1.285203090193173, 1.2782426833295373, 1.271057890521706, 1.2636518956956357, 1.2560280154288725, 1.2481897016797454, 1.2401405447148857, 1.2318842762480715, 1.2234247728042158, 1.214766059323141, 1.2059123130186562, 1.1968678675093263, 1.18763721723822, 1.1782250221998083, 1.1686361129930873, 1.1588754962208476, 1.1489483602558497, 1.1388600813954308, 1.1286162304267318, 1.1182225796253142, 1.1076851102103167, 1.097010020279504, 1.086203733247499, 1.0752729068100804, 1.0642244424566292, 1.0530654955514966, 1.0418034860031358, 1.0304461095371664, 1.0190013495859713, 1.0074774898027636, 0.9958831272021412, 0.984227185921684, 0.9725189315899244, 0.9607679862746944, 0.9489843439721147, 0.9371783865799409, 0.9253609002792378, 0.9135430922249475, 0.9017366074184031, 0.8899535456027339, 0.8782064779849269, 0.8665084635456205, 0.854873064649105, 0.8433143616112164, 0.83184696582169, 0.8204860309502146, 0.8092472616922657, 0.7981469194326598, 0.787201824122987, 0.7764293515856701, 0.7658474253751764, 0.7554745022496049, 0.745329550238304, 0.7354320182392565, 0.7258017960508211, 0.7164591637442409, 0.7074247293252228, 0.6987193537245208, 0.6903640623084705, 0.6823799423196467, 0.6747880259522785, 0.6676091591407458, 0.6608638565919258, 0.6545721441171508, 0.6487533899038108, 0.6434261269890571, 0.6386078698294189, 0.6343149284637757, 0.6305622243006754, 0.6273631119792011, 0.6247292120112828, 0.6226702589739583, 0.6211939698545916, 0.6203059367473825, 0.6200095474607715, 0.6203059367473831, 0.6211939698545929, 0.62267025897396, 0.6247292120112853, 0.627363111979204, 0.6305622243006791, 0.6343149284637799, 0.6386078698294235, 0.6434261269890623, 0.6487533899038165, 0.6545721441171571, 0.6608638565919325, 0.6676091591407529, 0.674788025952286, 0.6823799423196547, 0.690364062308479, 0.6987193537245295, 0.7074247293252319, 0.7164591637442506, 0.7258017960508308, 0.7354320182392665, 0.7453295502383143, 0.7554745022496154, 0.7658474253751871, 0.7764293515856812, 0.7872018241229982, 0.7981469194326712, 0.8092472616922771, 0.8204860309502262, 0.8318469658217017, 0.8433143616112282, 0.8548730646491169, 0.8665084635456324, 0.878206477984939, 0.8899535456027461, 0.9017366074184152, 0.9135430922249596, 0.9253609002792499, 0.937178386579953, 0.9489843439721269, 0.9607679862747066, 0.9725189315899364, 0.984227185921696, 0.9958831272021532, 1.0074774898027756, 1.0190013495859829, 1.030446109537178, 1.041803486003147, 1.0530654955515082, 1.0642244424566405, 1.0752729068100915, 1.0862037332475103, 1.0970100202795148, 1.1076851102103276, 1.1182225796253251, 1.1286162304267422, 1.138860081395441, 1.14894836025586, 1.1588754962208576, 1.1686361129930973, 1.178225022199818, 1.1876372172382297, 1.1968678675093358, 1.2059123130186653, 1.2147660593231502, 1.2234247728042245, 1.23188427624808, 1.2401405447148939, 1.2481897016797538, 1.2560280154288803, 1.2636518956956435, 1.2710578905217134, 1.2782426833295444, 1.2852030901931801, 1.291936057295169, 1.298438658558116, 1.3047080934401214, 1.3107416848840412, 1.3165368774111534, 1.322091235350449, 1.327402441195339, 1.3324682940801424, 1.3372867083692552, 1.3418557123523862, 1.3461734470397517, 1.3502381650515496, 1.354048229596482, 1.357602113534495, 1.3608983985192966, 1.3639357742165923, 1.3667130375943055, 1.3692290922814196, 1.3714829479923807, 1.3734737200143048, 1.3752006287545548, 1.3766629993465032, 1.37786026131161, 1.378791948276186, 1.3794576977414816, 1.379857250906009], [1.4046911357233376, 1.404551769869118, 1.4041337241850638, 1.40343715433097, 1.4024623198198718, 1.4012095841385512, 1.3996794149171257, 1.3978723841486103, 1.3957891684595902, 1.3934305494334318, 1.390797413987707, 1.3878907548078054, 1.3847116708389988, 1.381261367839516, 1.3775411589975122, 1.3735524656151448, 1.3692968178633123, 1.3647758556109741, 1.359991329333367, 1.3549451011038187, 1.3496391456743055, 1.3440755516503462, 1.338256522766312, 1.3321843792677355, 1.3258615594077607, 1.3192906210654374, 1.3124742434941965, 1.3054152292094858, 1.2981165060252555, 1.290581129249715, 1.2828122840515794, 1.2748132880088718, 1.2665875938532227, 1.258138792423577, 1.2494706158442068, 1.2405869409430013, 1.231491792927119, 1.2221893493342741, 1.21268394427916, 1.2029800730158116, 1.1930823968380517, 1.1829957483415667, 1.1727251370725704, 1.1622757555894996, 1.151652985965633, 1.1408624067620043, 1.1299098005014045, 1.1188011616756508, 1.1075427053195426, 1.0961408761860705, 1.0846023585583076, 1.0729340867340518, 1.061143256219494, 1.0492373356679345, 1.037224079598662, 1.0251115419294394, 1.0129080903533567, 1.0006224215869433, 0.988263577511048, 0.9758409622188436, 0.963364359975941, 0.950843954085657, 0.9382903466374097, 0.9257145790974758, 0.9131281536783002, 0.9005430553944817, 0.8879717746796714, 0.8754273303981189, 0.8629232930365376, 0.8504738078054975, 0.8380936173137751, 0.8257980834032306, 0.8136032076452319, 0.8015256499020241, 0.7895827442478881, 0.777792511426034, 0.7661736668894673, 0.7547456233400109, 0.7435284865431314, 0.7325430430626597, 0.7218107384362604, 0.7113536442091325, 0.7011944121717203, 0.691356214121305, 0.6818626655034113, 0.672737731404662, 0.6640056135821747, 0.6556906175429656, 0.6478169991441983, 0.6404087907800399, 0.6334896079535207, 0.6270824378908983, 0.6212094128164266, 0.615891571526167, 0.611148613923624, 0.606998654136349, 0.6034579786400677, 0.600540816390986, 0.5982591282291296, 0.5966224227032313, 0.595637604944163, 0.5953088642766623, 0.5956376049441636, 0.5966224227032325, 0.5982591282291317, 0.6005408163909887, 0.6034579786400711, 0.6069986541363531, 0.6111486139236285, 0.6158915715261722, 0.6212094128164325, 0.6270824378909047, 0.6334896079535276, 0.6404087907800472, 0.6478169991442061, 0.655690617542974, 0.6640056135821835, 0.6727377314046712, 0.6818626655034209, 0.6913562141213149, 0.7011944121717307, 0.7113536442091432, 0.7218107384362713, 0.7325430430626708, 0.7435284865431429, 0.7547456233400225, 0.7661736668894793, 0.7777925114260462, 0.7895827442479003, 0.8015256499020365, 0.8136032076452443, 0.8257980834032431, 0.8380936173137876, 0.8504738078055103, 0.8629232930365504, 0.8754273303981316, 0.8879717746796844, 0.9005430553944945, 0.9131281536783133, 0.9257145790974887, 0.9382903466374227, 0.9508439540856699, 0.9633643599759539, 0.9758409622188566, 0.9882635775110608, 1.000622421586956, 1.0129080903533694, 1.0251115419294519, 1.0372240795986745, 1.0492373356679467, 1.061143256219506, 1.0729340867340638, 1.0846023585583193, 1.0961408761860825, 1.1075427053195541, 1.1188011616756623, 1.129909800501416, 1.1408624067620152, 1.1516529859656441, 1.1622757555895102, 1.1727251370725806, 1.182995748341577, 1.1930823968380622, 1.2029800730158215, 1.21268394427917, 1.222189349334284, 1.2314917929271283, 1.2405869409430104, 1.2494706158442157, 1.2581387924235858, 1.2665875938532316, 1.2748132880088803, 1.2828122840515874, 1.290581129249723, 1.2981165060252633, 1.3054152292094932, 1.3124742434942036, 1.3192906210654445, 1.3258615594077674, 1.3321843792677417, 1.338256522766318, 1.3440755516503518, 1.349639145674311, 1.3549451011038243, 1.359991329333372, 1.3647758556109786, 1.3692968178633165, 1.3735524656151492, 1.377541158997516, 1.3812613678395196, 1.3847116708390022, 1.3878907548078085, 1.39079741398771, 1.3934305494334347, 1.3957891684595929, 1.3978723841486125, 1.3996794149171277, 1.4012095841385523, 1.402462319819873, 1.4034371543309705, 1.404133724185064, 1.404551769869118], [1.4299677417862213, 1.42982228844288, 1.429385980372285, 1.4286589734751496, 1.4276415276608563, 1.4263340069602024, 1.4247368796841338, 1.4228507186293737, 1.4206762013321101, 1.4182141103711887, 1.4154653337225196, 1.412430865166723, 1.409111804752306, 1.405509359317015, 1.401624843070296, 1.3974596782401776, 1.3930153957882234, 1.3882936361966067, 1.3832961503317538, 1.3780248003894313, 1.372481560926634, 1.36666851998608, 1.3605878803196834, 1.3542419607179028, 1.3476331974524753, 1.3407641458406823, 1.3336374819399766, 1.3262560043825422, 1.318622636360146, 1.3107404277704844, 1.3026125575371428, 1.29424233611627, 1.2856332082041089, 1.2767887556606567, 1.2677127006659432, 1.2584089091266986, 1.248881394352582, 1.2391343210226164, 1.229172009464062, 1.218998940267644, 1.208619759264847, 1.1980392828948845, 1.1872625039909537, 1.1762945980175086, 1.1651409297924804, 1.1538070607306792, 1.1422987566469869, 1.1306219961603765, 1.1187829797422624, 1.1067881394551298, 1.0946441494298, 1.0823579371319734, 1.0699366954707759, 1.0573878958038512, 1.0447193018949144, 1.031938984880511, 1.019055339302779, 1.0060771002640831, 0.9930133617571819, 0.9798735962207591, 0.9666676753642811, 0.9534058922977429, 0.9400989849903221, 0.9267581610666036, 0.9133951239290101, 0.900022100169448, 0.8866518682008319, 0.8732977879988782, 0.8599738317948898, 0.8466946154997589, 0.833475430566357, 0.8203322759102062, 0.8072818894051333, 0.7943417783499067, 0.7815302481623662, 0.7688664283985056, 0.7563702950153324, 0.7440626875993, 0.7319653200694739, 0.7201007831412686, 0.7084925366103267, 0.6971648892979819, 0.6861429643049217, 0.6754526470677488, 0.6651205136285316, 0.6551737365389876, 0.6456399659611685, 0.6365471838297986, 0.6279235294410888, 0.6197970955572306, 0.61219569508276, 0.6051465995800331, 0.5986762523246933, 0.5928099602081998, 0.5875715704910828, 0.5829831400833138, 0.5790646065356932, 0.575833471110929, 0.573304505007955, 0.5714894899021729, 0.5703970033454343, 0.5700322582137787, 0.5703970033454351, 0.5714894899021743, 0.5733045050079572, 0.5758334711109319, 0.5790646065356968, 0.5829831400833183, 0.5875715704910879, 0.5928099602082054, 0.5986762523246997, 0.60514659958004, 0.6121956950827675, 0.6197970955572386, 0.6279235294410974, 0.6365471838298077, 0.6456399659611781, 0.6551737365389976, 0.6651205136285421, 0.6754526470677595, 0.686142964304933, 0.6971648892979935, 0.7084925366103384, 0.7201007831412806, 0.731965320069486, 0.7440626875993125, 0.756370295015345, 0.7688664283985187, 0.7815302481623793, 0.79434177834992, 0.8072818894051468, 0.8203322759102195, 0.8334754305663705, 0.8466946154997725, 0.8599738317949034, 0.873297787998892, 0.8866518682008458, 0.9000221001694616, 0.913395123929024, 0.9267581610666173, 0.9400989849903358, 0.9534058922977566, 0.9666676753642948, 0.9798735962207724, 0.9930133617571953, 1.0060771002640967, 1.0190553393027924, 1.031938984880524, 1.0447193018949275, 1.0573878958038643, 1.0699366954707887, 1.0823579371319862, 1.0946441494298125, 1.106788139455142, 1.1187829797422746, 1.1306219961603887, 1.1422987566469986, 1.153807060730691, 1.165140929792492, 1.17629459801752, 1.1872625039909648, 1.1980392828948956, 1.2086197592648578, 1.2189989402676542, 1.2291720094640721, 1.2391343210226267, 1.2488813943525918, 1.258408909126708, 1.2677127006659528, 1.2767887556606659, 1.285633208204118, 1.2942423361162787, 1.3026125575371512, 1.3107404277704926, 1.318622636360154, 1.32625600438255, 1.333637481939984, 1.3407641458406896, 1.3476331974524822, 1.3542419607179093, 1.3605878803196896, 1.366668519986086, 1.3724815609266399, 1.378024800389437, 1.383296150331759, 1.3882936361966118, 1.3930153957882279, 1.397459678240182, 1.4016248430703002, 1.405509359317019, 1.4091118047523095, 1.4124308651667261, 1.4154653337225227, 1.4182141103711912, 1.4206762013321128, 1.4228507186293757, 1.4247368796841355, 1.4263340069602037, 1.4276415276608572, 1.4286589734751503, 1.4293859803722857, 1.4298222884428802], [1.4557958172439769, 1.4556443619541763, 1.4551900480811135, 1.4544330316343368, 1.4533735726983266, 1.4520120355357886, 1.4503488887331604, 1.4483847053892238, 1.4461201633479899, 1.443556045477297, 1.4406932399948373, 1.437532740843619, 1.4340756481191856, 1.4303231685512154, 1.426276616042469, 1.421937412268401, 1.4173070873411218, 1.4123872805417885, 1.407179741125931, 1.4016863292066524, 1.3959090167211359, 1.389849888486391, 1.3835111433507261, 1.3768950954480232, 1.3700041755625276, 1.362840932612546, 1.355408035262189, 1.3477082736710932, 1.3397445613929089, 1.3315199374342863, 1.3230375684870912, 1.3143007513476748, 1.3053129155382048, 1.2960776261463427, 1.2865985869009346, 1.2768796435028882, 1.2669247872320184, 1.2567381588524125, 1.246324052840745, 1.2356869219640316, 1.2248313822355086, 1.2137622182797085, 1.2024843891403525, 1.1910030345674176, 1.1793234818226868, 1.1674512530461907, 1.1553920732293128, 1.1431518788438157, 1.13073682717978, 1.1181533064493079, 1.1054079467168758, 1.092507631721342, 1.0794595116588095, 1.0662710169997118, 1.0529498734175569, 1.039504117910586, 1.025942116201043, 1.0122725814995734, 0.9985045947242295, 0.9846476262643146, 0.9707115593784369, 0.9567067153131357, 0.9426438802226709, 0.9285343339612249, 0.9143898808049249, 0.9002228821415849, 0.8860462911395398, 0.8718736893717547, 0.8577193253256323, 0.8435981546704262, 0.8295258820803212, 0.8155190043193128, 0.8015948541808336, 0.7877716447374328, 0.7740685131903248, 0.7605055634121894, 0.7471039060465189, 0.7338856947614106, 0.7208741569548589, 0.7080936168746098, 0.6955695087542058, 0.6833283771883271, 0.6713978615913083, 0.6598066612265745, 0.648584476994303, 0.6377619259620544, 0.627370424570402, 0.6174420366031512, 0.6080092824454373, 0.5991049069284459, 0.590761604233753, 0.5830116999403899, 0.5758867923473787, 0.5694173576495442, 0.563632326280863, 0.558558640596216, 0.5542208068030497, 0.5506404563926544, 0.5478359339484408, 0.5458219288375057, 0.5446091677021494, 0.5442041827560231, 0.5446091677021503, 0.5458219288375072, 0.5478359339484433, 0.5506404563926575, 0.5542208068030537, 0.5585586405962207, 0.5636323262808686, 0.5694173576495505, 0.5758867923473858, 0.5830116999403977, 0.5907616042337612, 0.5991049069284548, 0.6080092824454467, 0.6174420366031613, 0.6273704245704126, 0.6377619259620653, 0.6485844769943143, 0.6598066612265863, 0.6713978615913205, 0.6833283771883396, 0.6955695087542183, 0.7080936168746228, 0.7208741569548721, 0.7338856947614241, 0.7471039060465325, 0.7605055634122032, 0.7740685131903389, 0.787771644737447, 0.801594854180848, 0.8155190043193269, 0.8295258820803355, 0.8435981546704407, 0.857719325325647, 0.8718736893717691, 0.8860462911395545, 0.9002228821415993, 0.9143898808049394, 0.9285343339612393, 0.9426438802226854, 0.9567067153131503, 0.9707115593784512, 0.9846476262643288, 0.9985045947242436, 1.0122725814995877, 1.025942116201057, 1.0395041179105997, 1.0529498734175706, 1.0662710169997252, 1.0794595116588228, 1.0925076317213553, 1.105407946716889, 1.1181533064493208, 1.1307368271797926, 1.1431518788438286, 1.1553920732293255, 1.1674512530462031, 1.1793234818226987, 1.1910030345674296, 1.202484389140364, 1.21376221827972, 1.2248313822355197, 1.2356869219640427, 1.246324052840756, 1.2567381588524231, 1.2669247872320286, 1.276879643502898, 1.2865985869009446, 1.2960776261463522, 1.3053129155382144, 1.314300751347684, 1.3230375684871, 1.331519937434295, 1.3397445613929173, 1.3477082736711012, 1.3554080352621969, 1.3628409326125532, 1.370004175562535, 1.3768950954480301, 1.383511143350733, 1.3898498884863972, 1.395909016721142, 1.4016863292066581, 1.4071797411259366, 1.4123872805417936, 1.4173070873411264, 1.4219374122684056, 1.426276616042473, 1.4303231685512194, 1.4340756481191894, 1.4375327408436225, 1.4406932399948402, 1.4435560454773, 1.4461201633479923, 1.448384705389226, 1.4503488887331628, 1.45201203553579, 1.4533735726983275, 1.4544330316343377, 1.4551900480811142, 1.4556443619541768], [1.482150375101679, 1.4819930111391635, 1.4815209712585165, 1.4807344114988006, 1.4796335919864712, 1.4782188770278355, 1.476490735239365, 1.474449739716752, 1.4720965682438332, 1.4694320035428061, 1.4664569335674098, 1.4631723518410493, 1.4595793578421365, 1.4556791574392336, 1.4514730633789144, 1.4469624958296246, 1.4421489829851677, 1.4370341617318647, 1.4316197783838451, 1.4259076894913765, 1.419899862727638, 1.4135983778598562, 1.407005427811282, 1.4001233198211065, 1.392954476710064, 1.3855014382601738, 1.3777668627178694, 1.369753528430567, 1.3614643356276719, 1.352902308357982, 1.3440705965965418, 1.334972478535176, 1.3256113630721968, 1.3159907925181953, 1.3061144455363276, 1.2959861403371855, 1.285609838150144, 1.274989646995054, 1.2641298257803095, 1.2530347887556754, 1.241709110350815, 1.2301575304332686, 1.2183849600226644, 1.2063964875012698, 1.1941973853645773, 1.1817931175595326, 1.1691893474622421, 1.1563919465515633, 1.1434070038399076, 1.1302408361278788, 1.1168999991550266, 1.1033912997250188, 1.0897218088899192, 1.0758988762849462, 1.0619301457120662, 1.0478235720779432, 1.0335874397990161, 1.0192303827936897, 1.0047614061885353, 0.9901899098718059, 0.9755257140330472, 0.9607790868316983, 0.9459607743397106, 0.9310820329025844, 0.9161546640588548, 0.9011910521487251, 0.8862042047267046, 0.8712077958688719, 0.8562162124304223, 0.8412446032606915, 0.8263089313174681, 0.811426028536171, 0.7966136531977162, 0.7818905493963135, 0.7672765080291328, 0.7527924285073065, 0.7384603801155197, 0.7243036616190486, 0.7103468573271036, 0.6966158873661737, 0.6831380493965722, 0.6699420484246416, 0.6570580107347717, 0.6445174773127267, 0.6323533714917381, 0.6205999349792257, 0.6092926259884296, 0.598467973000062, 0.5881633778282842, 0.5784168622909515, 0.5692667540172242, 0.5607513088825062, 0.5529082703175536, 0.5457743693011834, 0.5393847731170933, 0.5337724957073896, 0.5289677873178502, 0.5249975256004452, 0.5218846338269403, 0.5196475537733256, 0.5182998006521455, 0.517849624898321, 0.5182998006521464, 0.5196475537733274, 0.5218846338269431, 0.5249975256004489, 0.5289677873178547, 0.533772495707395, 0.5393847731170995, 0.5457743693011904, 0.5529082703175614, 0.5607513088825147, 0.5692667540172334, 0.5784168622909611, 0.5881633778282944, 0.5984679730000729, 0.609292625988441, 0.6205999349792376, 0.6323533714917505, 0.6445174773127395, 0.6570580107347849, 0.6699420484246552, 0.6831380493965857, 0.6966158873661877, 0.7103468573271178, 0.7243036616190629, 0.7384603801155344, 0.7527924285073213, 0.7672765080291478, 0.7818905493963287, 0.7966136531977313, 0.8114260285361862, 0.8263089313174833, 0.8412446032607069, 0.8562162124304378, 0.8712077958688873, 0.88620420472672, 0.9011910521487403, 0.9161546640588705, 0.9310820329025997, 0.9459607743397258, 0.9607790868317134, 0.9755257140330625, 0.9901899098718211, 1.0047614061885501, 1.0192303827937046, 1.033587439799031, 1.0478235720779578, 1.0619301457120809, 1.0758988762849604, 1.0897218088899334, 1.1033912997250326, 1.1168999991550401, 1.1302408361278924, 1.1434070038399209, 1.1563919465515766, 1.1691893474622552, 1.1817931175595453, 1.19419738536459, 1.2063964875012825, 1.2183849600226764, 1.2301575304332804, 1.241709110350827, 1.253034788755687, 1.2641298257803206, 1.2749896469950648, 1.2856098381501548, 1.295986140337196, 1.3061144455363378, 1.3159907925182055, 1.3256113630722068, 1.3349724785351853, 1.344070596596551, 1.352902308357991, 1.361464335627681, 1.3697535284305753, 1.3777668627178776, 1.3855014382601818, 1.3929544767100717, 1.4001233198211136, 1.4070054278112885, 1.4135983778598626, 1.4198998627276445, 1.425907689491382, 1.431619778383851, 1.4370341617318698, 1.4421489829851724, 1.4469624958296294, 1.4514730633789183, 1.4556791574392378, 1.4595793578421403, 1.4631723518410529, 1.4664569335674131, 1.469432003542809, 1.4720965682438358, 1.4744497397167544, 1.4764907352393675, 1.478218877027837, 1.4796335919864727, 1.4807344114988013, 1.481520971258517, 1.4819930111391637], [1.5090059190266825, 1.5088427463803278, 1.5083532804485815, 1.507537677269385, 1.5063961969593904, 1.5049292037945021, 1.5031371663234756, 1.501020657515417, 1.4985803549422805, 1.4958170409977214, 1.492731603153925, 1.4893250342583144, 1.4855984328723262, 1.481553003654763, 1.4771900577925285, 1.4725110134819275, 1.4675173964640467, 1.4622108406181438, 1.4565930886173764, 1.4506659926516554, 1.4444315152228941, 1.437891730018431, 1.43104882286899, 1.423905092798128, 1.4164629531708062, 1.4087249329494211, 1.4006936780664359, 1.3923719529235958, 1.3837626420286546, 1.3748687517815554, 1.3656934124231337, 1.3562398801606288, 1.346511539485639, 1.3365119057016226, 1.326244627679663, 1.3157134908629957, 1.3049224205427412, 1.2938754854294212, 1.2825769015472144, 1.27103103648047, 1.2592424140048728, 1.2472157191387694, 1.234955803653619, 1.2224676920863258, 1.2097565883003722, 1.196827882647246, 1.1836871597846839, 1.1703402072137632, 1.156793024602901, 1.1430518339734255, 1.1291230908285803, 1.115013496315669, 1.1007300105195497, 1.086279866994897, 1.0716705886545665, 1.056910005141993, 1.042006271826849, 1.0269678905750765, 1.0118037324567999, 0.9965230625683601, 0.981135567157537, 0.9656513832535839, 0.9500811310155373, 0.9344359490226857, 0.9187275327392552, 0.9029681763900951, 0.8871708184839546, 0.8713490912138566, 0.8555173739476003, 0.8396908509924326, 0.8238855737723929, 0.8081185274898964, 0.7924077022486655, 0.7767721684858824, 0.7612321563886505, 0.7458091387433535, 0.730525916374657, 0.7154067049609071, 0.7004772215510929, 0.6857647685421464, 0.6712983121928647, 0.6571085519450192, 0.6432279758937516, 0.6296908967108217, 0.61653346120642, 0.6037936255739818, 0.591511087286464, 0.5797271637307455, 0.5684846071530334, 0.5578273455610413, 0.5478001401422432, 0.5384481517787046, 0.5298164126083789, 0.5219492034570606, 0.5148893443453426, 0.5086774129302613, 0.5033509141492031, 0.4989434326601351, 0.49548380682078924, 0.492995367694664, 0.49149528777381407, 0.4909940809733175, 0.49149528777381507, 0.4929953676946661, 0.49548380682079224, 0.49894343266013913, 0.503350914149208, 0.5086774129302672, 0.5148893443453494, 0.5219492034570683, 0.5298164126083873, 0.538448151778714, 0.5478001401422531, 0.557827345561052, 0.5684846071530447, 0.5797271637307573, 0.5915110872864764, 0.6037936255739946, 0.6165334612064335, 0.6296908967108354, 0.6432279758937658, 0.6571085519450335, 0.6712983121928793, 0.6857647685421614, 0.7004772215511081, 0.7154067049609226, 0.7305259163746726, 0.7458091387433694, 0.7612321563886663, 0.7767721684858984, 0.7924077022486816, 0.8081185274899125, 0.8238855737724091, 0.8396908509924488, 0.8555173739476167, 0.8713490912138727, 0.887170818483971, 0.9029681763901112, 0.9187275327392714, 0.9344359490227018, 0.9500811310155534, 0.9656513832535999, 0.9811355671575528, 0.9965230625683761, 1.0118037324568154, 1.0269678905750923, 1.0420062718268643, 1.0569100051420082, 1.0716705886545816, 1.0862798669949119, 1.1007300105195643, 1.1150134963156837, 1.1291230908285945, 1.1430518339734397, 1.156793024602915, 1.170340207213777, 1.1836871597846974, 1.1968278826472591, 1.2097565883003856, 1.2224676920863387, 1.2349558036536317, 1.247215719138782, 1.2592424140048852, 1.2710310364804818, 1.2825769015472261, 1.293875485429433, 1.3049224205427525, 1.3157134908630068, 1.3262446276796735, 1.336511905701633, 1.3465115394856493, 1.3562398801606386, 1.3656934124231432, 1.3748687517815648, 1.3837626420286637, 1.3923719529236047, 1.4006936780664445, 1.4087249329494294, 1.4164629531708142, 1.4239050927981354, 1.4310488228689968, 1.437891730018438, 1.4444315152229008, 1.4506659926516616, 1.4565930886173821, 1.462210840618149, 1.4675173964640518, 1.4725110134819324, 1.477190057792533, 1.4815530036547675, 1.4855984328723304, 1.489325034258318, 1.4927316031539284, 1.4958170409977245, 1.4985803549422831, 1.5010206575154192, 1.5031371663234778, 1.5049292037945041, 1.5063961969593915, 1.5075376772693858, 1.5083532804485822, 1.5088427463803282], [1.5363364680146776, 1.5361675924383227, 1.5356610177215688, 1.5348168999148073, 1.533635499146994, 1.532117179693495, 1.53026241007187, 1.5280717631663852, 1.5255459163822889, 1.5226856518311493, 1.519491856548768, 1.5159655227474875, 1.5121077481049607, 1.5079197360917604, 1.5034027963405021, 1.4985583450594937, 1.4933879054942685, 1.4878931084407354, 1.48207569281409, 1.475937506278049, 1.4694805059394622, 1.4627067591138347, 1.4556184441678823, 1.4482178514457997, 1.4405073842866114, 1.4324895601406662, 1.424167011794122, 1.4155424887111279, 1.4066188585043318, 1.3973991085453852, 1.3878863477282306, 1.3780838083992124, 1.3679948484694007, 1.357622953726049, 1.346971740361743, 1.3360449577416533, 1.3248464914313198, 1.3133803665096473, 1.3016507511942652, 1.2896619608091553, 1.2774184621274975, 1.26492487812605, 1.2521859931911192, 1.2392067588203288, 1.2259922998689903, 1.2125479213949748, 1.1988791161616588, 1.1849915728647775, 1.1708911851559929, 1.1565840615436813, 1.142076536259996, 1.1273751811926993, 1.11248681899069, 1.0974185374636678, 1.0821777054090338, 1.0667719900130213, 1.0512093759882601, 1.0354981866265365, 1.019647106963442, 1.0036652092709364, 0.9875619811144508, 0.9713473562329394, 0.9550317485229418, 0.9386260894308808, 0.9221418690808301, 0.9055911814870024, 0.8889867742199583, 0.8723421029113296, 0.8556713909913445, 0.8389896950535719, 0.8223129762279249, 0.8056581779107672, 0.789043310143029, 0.7724875408347216, 0.7560112938960711, 0.7396363541378335, 0.723385978529379, 0.7072850130326893, 0.6913600137400332, 0.6756393704064184, 0.6601534296567808, 0.6449346141344959, 0.6300175326184523, 0.6154390746569036, 0.601238481552434, 0.587457383618891, 0.5741397915991034, 0.5613320281263755, 0.5490825833605248, 0.5374418777559644, 0.526461914753432, 0.5161958075448607, 0.5066971674999393, 0.4980193478713823, 0.49021454533549963, 0.48333277373456324, 0.4774207384822818, 0.47252065521103725, 0.46866907043330425, 0.4658957528195272, 0.4642227286412914, 0.4636635319853224, 0.46422272864129255, 0.4658957528195295, 0.46866907043330763, 0.4725206552110417, 0.47742073848228733, 0.48333277373456984, 0.4902145453355072, 0.49801934787139074, 0.5066971674999488, 0.5161958075448709, 0.5264619147534428, 0.5374418777559761, 0.5490825833605372, 0.5613320281263884, 0.5741397915991169, 0.5874573836189049, 0.6012384815524484, 0.6154390746569183, 0.6300175326184675, 0.6449346141345115, 0.6601534296567966, 0.6756393704064343, 0.6913600137400495, 0.7072850130327057, 0.7233859785293957, 0.7396363541378502, 0.756011293896088, 0.7724875408347386, 0.7890433101430461, 0.8056581779107841, 0.822312976227942, 0.8389896950535892, 0.8556713909913616, 0.8723421029113466, 0.8889867742199756, 0.9055911814870193, 0.9221418690808472, 0.9386260894308975, 0.9550317485229587, 0.9713473562329562, 0.9875619811144675, 1.003665209270953, 1.0196471069634585, 1.035498186626553, 1.0512093759882764, 1.066771990013037, 1.0821777054090498, 1.0974185374636833, 1.1124868189907053, 1.1273751811927144, 1.142076536260011, 1.1565840615436958, 1.1708911851560075, 1.184991572864792, 1.1988791161616728, 1.2125479213949888, 1.225992299869004, 1.2392067588203421, 1.252185993191132, 1.264924878126063, 1.2774184621275104, 1.2896619608091677, 1.3016507511942774, 1.3133803665096595, 1.3248464914313314, 1.3360449577416647, 1.346971740361754, 1.3576229537260598, 1.367994848469411, 1.3780838083992226, 1.3878863477282406, 1.3973991085453947, 1.406618858504341, 1.415542488711137, 1.424167011794131, 1.4324895601406746, 1.4405073842866198, 1.4482178514458073, 1.4556184441678899, 1.4627067591138418, 1.4694805059394687, 1.4759375062780555, 1.482075692814096, 1.4878931084407407, 1.4933879054942736, 1.498558345059499, 1.5034027963405068, 1.507919736091765, 1.5121077481049647, 1.5159655227474913, 1.5194918565487718, 1.5226856518311525, 1.5255459163822918, 1.5280717631663874, 1.5302624100718727, 1.5321171796934967, 1.5336354991469952, 1.5348168999148084, 1.5356610177215695, 1.5361675924383231], [1.564115581524634, 1.563941113653531, 1.563417762075247, 1.5625456829056896, 1.5613251363742418, 1.5597564868784373, 1.5578402030612402, 1.5555768579116738, 1.5529671288897589, 1.5500117980769637, 1.5467117523535778, 1.543067983604702, 1.5390815889567835, 1.534753771046901, 1.5300858383273104, 1.525079205408055, 1.5197353934407756, 1.5140560305472248, 1.5080428522963578, 1.5016977022342868, 1.4950225324718396, 1.488019404334942, 1.4806904890835757, 1.4730380687056324, 1.4650645367926265, 1.456772399504903, 1.448164276634745, 1.4392429027766096, 1.430011128614633, 1.4204719223385558, 1.410628371200322, 1.400483683224838, 1.3900411890897262, 1.3793043441904096, 1.3682767309085209, 1.3569620611034812, 1.3453641788491293, 1.3334870634395601, 1.3213348326908632, 1.3089117465682638, 1.2962222111713093, 1.2832707831132444, 1.2700621743346214, 1.2566012573955563, 1.242893071295916, 1.2289428278781698, 1.2147559188737393, 1.2003379236605025, 1.1856946178067456, 1.1708319824854185, 1.155756214852115, 1.1404737394909388, 1.1249912210444126, 1.1093155781570228, 1.0934539988770116, 1.077413957677805, 1.061203234279156, 1.0448299344689258, 1.0283025131495311, 1.0116297998586976, 0.9948210270423797, 0.977885861388688, 0.9608344385654337, 0.9436774017404166, 0.9264259443026591, 0.9090918572439992, 0.8916875817031032, 0.8742262672169189, 0.8567218362661247, 0.8391890557387867, 0.8216436159666362, 0.8041022180061836, 0.7865826698355013, 0.769103992107726, 0.7516865340319044, 0.7343520998245358, 0.7171240859701107, 0.7000276292192662, 0.6830897648052713, 0.6663395937321919, 0.6498084571321193, 0.6335301145480212, 0.6175409215120927, 0.6018799998966632, 0.5865893921656987, 0.5717141878256607, 0.5573026070903305, 0.5434060231428759, 0.530078900631842, 0.5173786245797249, 0.5053651913338157, 0.4941007324109844, 0.48364884416275067, 0.47407370231393986, 0.4654389517083772, 0.4578063786841137, 0.4512343961605593, 0.44577639816807896, 0.4414790679868561, 0.43838074759890805, 0.4365099903345916, 0.43588441847536596, 0.4365099903345928, 0.43838074759891066, 0.44147906798685993, 0.4457763981680839, 0.4512343961605655, 0.457806378684121, 0.4654389517083856, 0.4740737023139492, 0.48364884416276094, 0.49410073241099567, 0.5053651913338276, 0.5173786245797376, 0.5300789006318555, 0.5434060231428899, 0.5573026070903452, 0.5717141878256758, 0.5865893921657143, 0.6018799998966792, 0.6175409215121092, 0.6335301145480378, 0.6498084571321362, 0.6663395937322089, 0.6830897648052886, 0.7000276292192837, 0.7171240859701284, 0.7343520998245535, 0.7516865340319223, 0.769103992107744, 0.7865826698355192, 0.8041022180062016, 0.8216436159666541, 0.8391890557388048, 0.8567218362661427, 0.874226267216937, 0.8916875817031209, 0.909091857244017, 0.9264259443026771, 0.9436774017404344, 0.9608344385654514, 0.9778858613887057, 0.9948210270423972, 1.011629799858715, 1.028302513149548, 1.0448299344689427, 1.061203234279173, 1.0774139576778217, 1.093453998877028, 1.1093155781570387, 1.1249912210444286, 1.1404737394909548, 1.1557562148521305, 1.1708319824854339, 1.1856946178067609, 1.2003379236605174, 1.2147559188737542, 1.228942827878184, 1.24289307129593, 1.2566012573955703, 1.2700621743346348, 1.2832707831132577, 1.2962222111713224, 1.3089117465682767, 1.3213348326908758, 1.3334870634395724, 1.3453641788491415, 1.356962061103493, 1.3682767309085322, 1.3793043441904207, 1.3900411890897373, 1.4004836832248482, 1.410628371200332, 1.4204719223385658, 1.4300111286146429, 1.439242902776619, 1.448164276634754, 1.4567723995049116, 1.465064536792635, 1.4730380687056404, 1.480690489083583, 1.488019404334949, 1.4950225324718467, 1.5016977022342932, 1.5080428522963643, 1.5140560305472306, 1.519735393440781, 1.5250792054080604, 1.5300858383273155, 1.5347537710469052, 1.5390815889567877, 1.543067983604706, 1.546711752353581, 1.550011798076967, 1.5529671288897617, 1.555576857911676, 1.5578402030612426, 1.5597564868784388, 1.561325136374243, 1.56254568290569, 1.5634177620752476, 1.5639411136535313], [1.5923163850583166, 1.5921364395920308, 1.5915966552801728, 1.590697188391904, 1.5894382994031377, 1.5878203530378328, 1.5858438183264885, 1.583509268682502, 1.5808173819972755, 1.5777689407551698, 1.5743648321695938, 1.5706060483417819, 1.5664936864440138, 1.5620289489293155, 1.5572131437699208, 1.552047684727074, 1.546534091655063, 1.5406739908426805, 1.5344691153956929, 1.5279213056642593, 1.5210325097196686, 1.513804783885216, 1.5062402933265349, 1.4983413127072385, 1.4901102269163202, 1.4815495318744158, 1.472661835426735, 1.4634498583312723, 1.4539164353517697, 1.4440645164658559, 1.433897168199868, 1.4234175751030267, 1.4126290413749385, 1.4015349926618703, 1.3901389780388305, 1.378444672196308, 1.3664558778525204, 1.354176528414254, 1.3416106909118855, 1.3287625692369736, 1.3156365077139374, 1.3022369950408537, 1.2885686686383468, 1.2746363194499737, 1.260444897242488, 1.245999516459968, 1.231305462692115, 1.2163681998241431, 1.2011933779437163, 1.1857868420894668, 1.1701546419358768, 1.1543030425208989, 1.1382385361358023, 1.121967855511578, 1.105497988453013, 1.0888361940905718, 1.0719900209417115, 1.0549673269975992, 1.0377763020786848, 1.020425492733636, 1.002923829991118, 0.9852806603132738, 0.967505780143893, 0.9496094744936043, 0.9316025600592805, 0.9134964334355029, 0.8953031250424074, 0.8770353594663353, 0.8587066229867907, 0.840331239143952, 0.8219244532832125, 0.8035025270934048, 0.7850828442281256, 0.7666840281570318, 0.748326073424726, 0.730030491482822, 0.7118204721836744, 0.6937210618515792, 0.675759358538112, 0.6579647245686393, 0.6403690157271247, 0.6230068253181332, 0.6059157397809684, 0.5891366003855592, 0.5727137626755475, 0.5566953416059313, 0.5411334256451215, 0.5260842374442484, 0.5116082121349049, 0.4977699572575078, 0.4846380514665671, 0.4722846337164748, 0.46078473239182793, 0.4502152871597973, 0.44065382786685064, 0.4321767970319126, 0.42485753670602694, 0.4187640056255593, 0.41395634414656846, 0.4104844539298284, 0.40838579522348095, 0.4076836149416835, 0.4083857952234824, 0.41048445392983124, 0.41395634414657273, 0.418764005625565, 0.4248575367060339, 0.4321767970319208, 0.44065382786685997, 0.45021528715980763, 0.4607847323918393, 0.4722846337164871, 0.4846380514665801, 0.4977699572575217, 0.5116082121349194, 0.5260842374442636, 0.5411334256451371, 0.5566953416059475, 0.5727137626755643, 0.5891366003855762, 0.6059157397809859, 0.6230068253181509, 0.6403690157271426, 0.6579647245686575, 0.6757593585381304, 0.6937210618515978, 0.7118204721836929, 0.7300304914828407, 0.7483260734247448, 0.7666840281570508, 0.7850828442281444, 0.8035025270934237, 0.8219244532832315, 0.8403312391439709, 0.8587066229868096, 0.8770353594663539, 0.895303125042426, 0.9134964334355217, 0.9316025600592992, 0.9496094744936227, 0.9675057801439114, 0.9852806603132919, 1.0029238299911363, 1.0204254927336538, 1.0377763020787025, 1.0549673269976165, 1.0719900209417288, 1.0888361940905888, 1.1054979884530298, 1.1219678555115946, 1.1382385361358192, 1.1543030425209153, 1.170154641935893, 1.1857868420894828, 1.201193377943732, 1.2163681998241587, 1.2313054626921305, 1.2459995164599829, 1.2604448972425029, 1.2746363194499883, 1.2885686686383608, 1.3022369950408674, 1.315636507713951, 1.3287625692369867, 1.3416106909118983, 1.354176528414267, 1.3664558778525326, 1.3784446721963197, 1.390138978038842, 1.401534992661882, 1.41262904137495, 1.4234175751030376, 1.4338971681998787, 1.4440645164658656, 1.4539164353517797, 1.4634498583312823, 1.4726618354267442, 1.4815495318744252, 1.490110226916329, 1.4983413127072467, 1.506240293326543, 1.5138047838852238, 1.521032509719676, 1.527921305664266, 1.5344691153956993, 1.5406739908426863, 1.5465340916550687, 1.5520476847270794, 1.5572131437699257, 1.5620289489293206, 1.5664936864440178, 1.5706060483417856, 1.5743648321695976, 1.577768940755173, 1.5808173819972786, 1.5835092686825043, 1.585843818326491, 1.587820353037835, 1.5894382994031389, 1.5906971883919057, 1.5915966552801737, 1.5921364395920312], [1.620911596159626, 1.6207262911103784, 1.6201704281408038, 1.6192441637909225, 1.6179477589792188, 1.616281579030623, 1.614246093716285, 1.6118418773057541, 1.609069608632345, 1.6059300711726845, 1.6024241531415957, 1.598552847603704, 1.5943172526033595, 1.5897185713146904, 1.58475811221385, 1.5794372892757838, 1.5737576221981024, 1.567720736654969, 1.5613283645842106, 1.5545823445112252, 1.5474846219136376, 1.5400372496310617, 1.5322423883247924, 1.524102306992739, 1.5156193835454659, 1.5067961054497903, 1.497635070447077, 1.4881389873540667, 1.4783106769549121, 1.4681530729939725, 1.4576692232799209, 1.446862290912816, 1.435735555647024, 1.424292415404244, 1.4125363879524087, 1.4004711127679599, 1.3881003531008826, 1.3754279982640418, 1.3624580661707564, 1.3491947061472427, 1.335642202049594, 1.3218049757183792, 1.3076875908077923, 1.2932947570306321, 1.2786313348653158, 1.263702340776678, 1.2485129530086303, 1.2330685180138936, 1.2173745575941533, 1.2014367768332233, 1.1852610729163273, 1.1688535449405995, 1.152220504835583, 1.1353684895281395, 1.1183042745040321, 1.1010348889388744, 1.08356763259453, 1.065910094703822, 1.0480701750970915, 1.0300561078593158, 1.0118764878467652, 0.9935403004383274, 0.9750569549494152, 0.9564363221967332, 0.9376887767710256, 0.9188252446532893, 0.8998572568988061, 0.8807970102136671, 0.8616574353610125, 0.8424522744594518, 0.8231961683739127, 0.803904755548495, 0.7845947837892684, 0.7652842366677127, 0.7459924763747872, 0.726740404998892, 0.7075506463090253, 0.6884477501686225, 0.6694584216442319, 0.6506117766469597, 0.6319396254704814, 0.6134767847537376, 0.5952614170471328, 0.5773353951004331, 0.5597446849707286, 0.5425397377744368, 0.5257758740529511, 0.509513636974885, 0.4938190807453283, 0.4787639486659961, 0.46442568179319194, 0.4508871853572941, 0.4382362684606097, 0.4265646669225387, 0.4159665648275677, 0.40653655359967167, 0.3983670139171446, 0.39154497788263265, 0.3861486223205051, 0.382243645165008, 0.37987986231779436, 0.3790884038403738, 0.379879862317796, 0.3822436451650112, 0.38614862232050995, 0.39154497788263887, 0.3983670139171523, 0.4065365535996808, 0.41596656482757804, 0.4265646669225501, 0.4382362684606223, 0.45088718535730754, 0.46442568179320637, 0.4787639486660112, 0.49381908074534414, 0.5095136369749015, 0.5257758740529681, 0.5425397377744543, 0.5597446849707466, 0.5773353951004515, 0.5952614170471514, 0.6134767847537566, 0.6319396254705004, 0.650611776646979, 0.6694584216442514, 0.688447750168642, 0.707550646309045, 0.7267404049989118, 0.7459924763748069, 0.7652842366677325, 0.7845947837892882, 0.8039047555485148, 0.8231961683739326, 0.8424522744594717, 0.8616574353610322, 0.8807970102136867, 0.8998572568988258, 0.9188252446533086, 0.9376887767710449, 0.9564363221967525, 0.9750569549494342, 0.9935403004383464, 1.011876487846784, 1.0300561078593344, 1.04807017509711, 1.0659100947038402, 1.083567632594548, 1.101034888938892, 1.11830427450405, 1.1353684895281568, 1.1522205048356, 1.1688535449406166, 1.185261072916344, 1.2014367768332397, 1.2173745575941695, 1.2330685180139096, 1.248512953008646, 1.2637023407766936, 1.278631334865331, 1.2932947570306472, 1.307687590807807, 1.3218049757183938, 1.335642202049608, 1.3491947061472567, 1.36245806617077, 1.375427998264055, 1.3881003531008953, 1.4004711127679725, 1.412536387952421, 1.4242924154042556, 1.4357355556470357, 1.446862290912827, 1.4576692232799318, 1.4681530729939833, 1.4783106769549226, 1.4881389873540765, 1.4976350704470867, 1.5067961054497998, 1.5156193835454748, 1.5241023069927475, 1.5322423883248004, 1.5400372496310692, 1.5474846219136449, 1.5545823445112321, 1.5613283645842173, 1.5677207366549752, 1.5737576221981082, 1.5794372892757895, 1.5847581122138554, 1.5897185713146953, 1.5943172526033642, 1.5985528476037083, 1.6024241531415997, 1.6059300711726883, 1.609069608632348, 1.611841877305757, 1.614246093716288, 1.6162815790306249, 1.6179477589792204, 1.6192441637909234, 1.6201704281408045, 1.6207262911103786], [1.649873550808615, 1.6496830068133812, 1.6491114271445872, 1.6481589687558702, 1.646825893246419, 1.645112566875921, 1.6430194605860307, 1.6405471500288773, 1.637696315603318, 1.6344677424997978, 1.6308623207548438, 1.626881045316417, 1.6225250161215152, 1.617795438187644, 1.6126936217199632, 1.6072209822361716, 1.6013790407114146, 1.5951694237457796, 1.5885938637572306, 1.5816541992031377, 1.5743523748339086, 1.5666904419825842, 1.5586705588946907, 1.5502949911030606, 1.5415661118528492, 1.5324864025824934, 1.5230584534669802, 1.5132849640304287, 1.503168743835744, 1.4927127132599045, 1.4819199043643465, 1.470793461870932, 1.4593366442550915, 1.4475528249690095, 1.435445493809111, 1.4230182584436957, 1.4102748461183252, 1.3972191055585683, 1.38385500909193, 1.3701866550133353, 1.3562182702213645, 1.341954213155671, 1.327398977069647, 1.3125571936765468, 1.2974336372119573, 1.2820332289608516, 1.2663610423035356, 1.2504223083417314, 1.2342224221739568, 1.2177669498984318, 1.2010616364321023, 1.1841124142463058, 1.1669254131332665, 1.1495069711333747, 1.1318636467713372, 1.1140022327702386, 1.0959297714367409, 1.0776535719386477, 1.0591812297284742, 1.040520648404264, 1.021680064342512, 1.0026680744887337, 0.9834936677500995, 0.964166260503006, 0.9446957368080425, 0.9250924940172793, 0.9053674945661834, 0.8855323248669664, 0.8655992623641828, 0.8455813519794921, 0.8254924933631421, 0.8053475405872573, 0.7851624161620532, 0.7649542415311192, 0.7447414865042794, 0.7245441404110243, 0.7043839080934119, 0.6842844341851351, 0.6642715594107146, 0.6443736128334979, 0.6246217440031983, 0.605050298682692, 0.5856972410932666, 0.5666046241552029, 0.5478191066654604, 0.5293925122736205, 0.5113824188813901, 0.49385275796023975, 0.4768743904430562, 0.46052560856163444, 0.4448924909136486, 0.4300690116984874, 0.41615677671858753, 0.4032642334010131, 0.39150518848837546, 0.3809964779584966, 0.37185468450472736, 0.36419190190657397, 0.3581107060543971, 0.35369869231075335, 0.35102313472527163, 0.3501264491913849, 0.3510231347252735, 0.353698692310757, 0.3581107060544025, 0.364191901906581, 0.37185468450473597, 0.38099647795850683, 0.3915051884883869, 0.40326423340102574, 0.4161567767186014, 0.4300690116985022, 0.44489249091366423, 0.46052560856165087, 0.47687439044307334, 0.49385275796025757, 0.5113824188814086, 0.5293925122736393, 0.5478191066654796, 0.5666046241552223, 0.5856972410932865, 0.605050298682712, 0.6246217440032185, 0.6443736128335182, 0.6642715594107349, 0.6842844341851555, 0.7043839080934327, 0.7245441404110452, 0.7447414865043, 0.7649542415311401, 0.7851624161620738, 0.805347540587278, 0.8254924933631628, 0.8455813519795127, 0.8655992623642034, 0.8855323248669867, 0.9053674945662039, 0.9250924940172996, 0.9446957368080627, 0.9641662605030261, 0.9834936677501193, 1.0026680744887535, 1.0216800643425314, 1.040520648404283, 1.0591812297284933, 1.0776535719386666, 1.0959297714367597, 1.114002232770257, 1.1318636467713554, 1.1495069711333927, 1.1669254131332842, 1.184112414246323, 1.2010616364321194, 1.217766949898449, 1.2342224221739737, 1.2504223083417478, 1.266361042303552, 1.2820332289608676, 1.297433637211973, 1.312557193676562, 1.327398977069662, 1.3419542131556856, 1.3562182702213792, 1.3701866550133495, 1.383855009091944, 1.3972191055585819, 1.4102748461183388, 1.4230182584437083, 1.4354454938091237, 1.4475528249690217, 1.4593366442551037, 1.4707934618709435, 1.4819199043643578, 1.4927127132599154, 1.5031687438357548, 1.5132849640304389, 1.5230584534669904, 1.5324864025825031, 1.5415661118528583, 1.5502949911030695, 1.5586705588946992, 1.5666904419825924, 1.5743523748339163, 1.5816541992031452, 1.588593863757237, 1.5951694237457856, 1.6013790407114206, 1.6072209822361774, 1.6126936217199683, 1.6177954381876491, 1.6225250161215201, 1.626881045316421, 1.6308623207548478, 1.634467742499801, 1.6376963156033213, 1.6405471500288804, 1.6430194605860338, 1.645112566875923, 1.6468258932464204, 1.6481589687558713, 1.6491114271445881, 1.6496830068133819], [1.6791742301846384, 1.6789785698787945, 1.6783916414713393, 1.6774136024929234, 1.6760447154960907, 1.6742853480577007, 1.6721359727827725, 1.6695971673102232, 1.6666696143210884, 1.6633541015499844, 1.6596515218006913, 1.6555628729669136, 1.651089258059432, 1.6462318852410287, 1.6409920678707677, 1.6353712245593979, 1.6293708792378674, 1.6229926612411694, 1.616238305409985, 1.6091096522128647, 1.601608647891989, 1.5937373446358656, 1.5854979007826835, 1.5768925810584347, 1.5679237568543445, 1.558593906548622, 1.5489056158780783, 1.538861578365739, 1.5284645958112215, 1.5177175788513775, 1.5066235475994936, 1.4951856323722499, 1.4834070745146324, 1.4712912273341188, 1.4588415571567153, 1.4460616445188428, 1.432955185510652, 1.4195259932881512, 1.405777999773547, 1.3917152575654892, 1.377341942083512, 1.362662353973888, 1.3476809218074637, 1.3324022051038449, 1.3168308977206273, 1.300971831651323, 1.284829981281283, 1.2684104681574109, 1.2517185663348889, 1.2347597083727087, 1.21753949205964, 1.2000636879636533, 1.1823382479109412, 1.1643693145159317, 1.1461632319013153, 1.127726557767666, 1.1090660769961243, 1.0901888169955045, 1.0711020650377736, 1.0518133878640052, 1.0323306538876553, 1.0126620583745551, 0.9928161520408478, 0.9728018735829295, 0.9526285867393752, 0.9323061225863025, 0.9118448278875266, 0.8912556204626949, 0.8705500527042863, 0.8497403845726724, 0.828839667632631, 0.8078618419708234, 0.7868218481583288, 0.7657357568021849, 0.7446209186716978, 0.7234961388944159, 0.7023818792959302, 0.6813004936043535, 0.6602765009423297, 0.6393369037584826, 0.618511557051927, 0.597833596322065, 0.5773399319717752, 0.5570718176494316, 0.5370754988370705, 0.5174029452809491, 0.4981126657462926, 0.4792705948407481, 0.46095102766948287, 0.44323755686374217, 0.4262239359155283, 0.4100147510498077, 0.3947257310470527, 0.38048346428272134, 0.36742423546013664, 0.35569166200460534, 0.34543283453240736, 0.3367927872615716, 0.3299073749789531, 0.3248950103232337, 0.3218481501912821, 0.32082576981536165, 0.3218481501912842, 0.3248950103232378, 0.32990737497895917, 0.3367927872615795, 0.34543283453241713, 0.3556916620046167, 0.3674242354601494, 0.38048346428273544, 0.39472573104706804, 0.4100147510498239, 0.42622393591554536, 0.44323755686376004, 0.46095102766950136, 0.47927059484076723, 0.4981126657463122, 0.5174029452809692, 0.537075498837091, 0.5570718176494523, 0.5773399319717962, 0.5978335963220862, 0.6185115570519482, 0.639336903758504, 0.6602765009423511, 0.6813004936043752, 0.7023818792959519, 0.7234961388944375, 0.7446209186717194, 0.7657357568022067, 0.7868218481583504, 0.8078618419708451, 0.8288396676326524, 0.849740384572694, 0.8705500527043077, 0.8912556204627161, 0.911844827887548, 0.9323061225863235, 0.9526285867393961, 0.97280187358295, 0.9928161520408685, 1.0126620583745756, 1.0323306538876753, 1.0518133878640252, 1.0711020650377934, 1.090188816995524, 1.1090660769961436, 1.127726557767685, 1.1461632319013344, 1.1643693145159504, 1.1823382479109594, 1.2000636879636712, 1.2175394920596578, 1.234759708372726, 1.2517185663349062, 1.2684104681574275, 1.2848299812812998, 1.3009718316513392, 1.3168308977206435, 1.3324022051038606, 1.3476809218074792, 1.3626623539739033, 1.377341942083527, 1.3917152575655036, 1.4057779997735609, 1.4195259932881654, 1.4329551855106655, 1.4460616445188559, 1.4588415571567284, 1.4712912273341314, 1.4834070745146448, 1.4951856323722617, 1.5066235475995051, 1.5177175788513886, 1.5284645958112322, 1.5388615783657493, 1.5489056158780885, 1.5585939065486316, 1.567923756854354, 1.5768925810584435, 1.585497900782692, 1.593737344635874, 1.6016086478919969, 1.6091096522128723, 1.616238305409992, 1.622992661241176, 1.6293708792378738, 1.6353712245594039, 1.6409920678707735, 1.646231885241034, 1.6510892580594367, 1.655562872966918, 1.659651521800695, 1.663354101549988, 1.6666696143210917, 1.6695971673102261, 1.6721359727827751, 1.6742853480577027, 1.6760447154960922, 1.6774136024929245, 1.6783916414713402, 1.6789785698787951], [1.708785287772754, 1.7085846352226353, 1.7079827303353938, 1.7069797313984303, 1.7055759022176598, 1.7037716121080715, 1.7015673358809056, 1.6989636538278279, 1.6959612517026164, 1.6925609207009913, 1.6887635574393314, 1.6845701639331756, 1.6799818475765347, 1.6749998211231742, 1.6696254026712192, 1.6638600156525638, 1.6577051888287808, 1.6511625562953975, 1.6442338574966375, 1.6369209372529483, 1.629225745803886, 1.621150338869212, 1.6126968777313588, 1.6038676293427514, 1.5946649664618393, 1.5850913678221146, 1.5751494183388235, 1.5648418093585912, 1.5541713389577403, 1.5431409122956923, 1.5317535420305437, 1.520012348804679, 1.5079205618091538, 1.4954815194365472, 1.4826986700330884, 1.4695755727620825, 1.4561158985920555, 1.4423234314246098, 1.428202069378746, 1.4137558262504322, 1.3989888331684777, 1.383905340470367, 1.3685097198246752, 1.3528064666300599, 1.336800202724695, 1.3204956794444314, 1.3038977810730636, 1.2870115287339186, 1.2698420847787182, 1.252394757737453, 1.234675007901999, 1.216688453626641, 1.1984408784407912, 1.1799382390833124, 1.161186674584311, 1.1421925165395412, 1.1229623007451226, 1.1035027803868027, 1.0838209410092063, 1.0639240175273699, 1.0438195135864188, 1.0235152236269334, 1.0030192580749124, 0.9823400721483667, 0.9614864988598277, 0.9404677868984358, 0.9192936442003659, 0.8979742881665947, 0.8765205036677396, 0.8549437101934595, 0.8332560397665745, 0.8114704275591791, 0.7896007175309633, 0.7676617858722022, 0.7456696855910968, 0.7236418162551561, 0.701597123698503, 0.6795563354612016, 0.6575422388506001, 0.6355800098191601, 0.6136976023339489, 0.5919262095362652, 0.5703008096690096, 0.5488608113064065, 0.5276508135256205, 0.5067214967379385, 0.48613065799109095, 0.4659443991305957, 0.44623846490809965, 0.42709970749174814, 0.40862761912572393, 0.3909358200409114, 0.3741533082066993, 0.35842516799117147, 0.3439123017546822, 0.33078961560085923, 0.3192420118043222, 0.3094576063059774, 0.30161791213578837, 0.29588538524615204, 0.29238965885842294, 0.2912147122272459, 0.2923896588584253, 0.2958853852461567, 0.30161791213579536, 0.3094576063059865, 0.3192420118043332, 0.33078961560087194, 0.34391230175469645, 0.358425167991187, 0.3741533082067161, 0.3909358200409291, 0.4086276191257425, 0.4270997074917675, 0.4462384649081196, 0.4659443991306162, 0.48613065799111194, 0.5067214967379601, 0.5276508135256421, 0.5488608113064285, 0.5703008096690318, 0.5919262095362875, 0.6136976023339714, 0.6355800098191826, 0.6575422388506227, 0.6795563354612243, 0.7015971236985258, 0.7236418162551786, 0.7456696855911195, 0.7676617858722248, 0.7896007175309857, 0.8114704275592014, 0.8332560397665968, 0.8549437101934819, 0.8765205036677619, 0.8979742881666167, 0.9192936442003878, 0.9404677868984576, 0.9614864988598493, 0.982340072148388, 1.0030192580749338, 1.0235152236269545, 1.0438195135864394, 1.0639240175273905, 1.0838209410092268, 1.1035027803868227, 1.1229623007451424, 1.1421925165395608, 1.1611866745843304, 1.1799382390833315, 1.1984408784408103, 1.2166884536266596, 1.2346750079020175, 1.252394757737471, 1.269842084778736, 1.287011528733936, 1.3038977810730807, 1.3204956794444482, 1.3368002027247117, 1.352806466630076, 1.3685097198246912, 1.3839053404703827, 1.3989888331684932, 1.4137558262504473, 1.4282020693787607, 1.442323431424624, 1.4561158985920695, 1.469575572762096, 1.4826986700331017, 1.4954815194365603, 1.5079205618091664, 1.5200123488046913, 1.5317535420305555, 1.5431409122957036, 1.5541713389577514, 1.564841809358602, 1.575149418338834, 1.585091367822125, 1.5946649664618489, 1.6038676293427605, 1.6126968777313677, 1.6211503388692203, 1.629225745803894, 1.636920937252956, 1.6442338574966446, 1.6511625562954042, 1.6577051888287875, 1.66386001565257, 1.6696254026712245, 1.6749998211231796, 1.6799818475765391, 1.68457016393318, 1.688763557439335, 1.692560920700995, 1.69596125170262, 1.6989636538278305, 1.701567335880908, 1.7037716121080735, 1.705575902217661, 1.7069797313984314, 1.7079827303353943, 1.7085846352226361], [1.7386780767871457, 1.7384725569786033, 1.7378560506330987, 1.7368287169868584, 1.735390821419838, 1.733542735435247, 1.7312849366312055, 1.7286180086648517, 1.7255426412093173, 1.722059629904099, 1.7181698762994355, 1.7138743877954328, 1.709174277576776, 1.7040707645440043, 1.6985651732424376, 1.692658933790004, 1.686353581805348, 1.67965075833777, 1.6725522098007322, 1.6650597879108335, 1.657175449634397, 1.6489012571440098, 1.6402393777876392, 1.631192084073194, 1.6217617536717381, 1.6119508694428726, 1.6017620194862001, 1.5911978972231904, 1.5802613015142353, 1.5689551368161994, 1.5572824133863472, 1.5452462475391848, 1.5328498619634718, 1.5200965861074844, 1.506989856641524, 1.493533218007709, 1.4797303230682577, 1.4655849338647913, 1.4511009225027005, 1.4362822721763175, 1.4211330783525835, 1.4056575501331199, 1.389860011817138, 1.3737449046905212, 1.3573167890697377, 1.3405803466330541, 1.32354038307592, 1.3062018311324626, 1.2885697540108894, 1.270649349297399, 1.2524459533910854, 1.2339650465415073, 1.2152122585713105, 1.1961933753788327, 1.1769143463303056, 1.1573812926685554, 1.137600517085453, 1.1175785146294224, 1.0973219851478053, 1.0768378474977347, 1.056133255799497, 1.0352156180545193, 1.0140926175078513, 0.9927722372043358, 0.9712627882712417, 0.9495729425611291, 0.9277117704111707, 0.9056887844240157, 0.8835139903568381, 0.861197946427218, 0.8387518326167529, 0.8161875318880385, 0.7935177256431991, 0.7707560062616634, 0.7479170101852156, 0.7250165757990535, 0.7020719313248908, 0.6791019191398775, 0.6561272644151036, 0.6331708977888328, 0.6102583440157144, 0.587418191224049, 0.5646826586094434, 0.5420882840853399, 0.5196767574822397, 0.4974959290126656, 0.47560102618979677, 0.4540561138227194, 0.43293582859162394, 0.4123274076772114, 0.39233300283144096, 0.37307221610445296, 0.3546846956191704, 0.3373324704505623, 0.3212014669509931, 0.3065013384078275, 0.2934624110028237, 0.2823283534887884, 0.2733433922773581, 0.26673385523746246, 0.26268568838859196, 0.26132192321285425, 0.2626856883885948, 0.266733855237468, 0.2733433922773661, 0.2823283534887987, 0.29346241100283615, 0.30650133840784183, 0.32120146695100904, 0.33733247045057957, 0.35468469561918886, 0.37307221610447233, 0.3923330028314612, 0.4123274076772322, 0.4329358285916454, 0.4540561138227413, 0.47560102618981914, 0.49749592901268824, 0.5196767574822627, 0.5420882840853631, 0.5646826586094669, 0.5874181912240726, 0.610258344015738, 0.6331708977888564, 0.656127264415127, 0.6791019191399011, 0.7020719313249143, 0.7250165757990771, 0.7479170101852393, 0.7707560062616868, 0.7935177256432224, 0.8161875318880617, 0.8387518326167761, 0.861197946427241, 0.883513990356861, 0.9056887844240383, 0.9277117704111933, 0.9495729425611515, 0.9712627882712639, 0.9927722372043579, 1.014092617507873, 1.0352156180545409, 1.0561332557995182, 1.076837847497756, 1.0973219851478262, 1.1175785146294432, 1.1376005170854733, 1.1573812926685754, 1.1769143463303253, 1.1961933753788525, 1.2152122585713299, 1.2339650465415262, 1.252445953391104, 1.2706493492974176, 1.2885697540109076, 1.3062018311324806, 1.3235403830759378, 1.3405803466330712, 1.3573167890697548, 1.3737449046905381, 1.3898600118171545, 1.4056575501331359, 1.421133078352599, 1.4362822721763329, 1.4511009225027156, 1.465584933864806, 1.479730323068272, 1.493533218007723, 1.5069898566415376, 1.520096586107498, 1.5328498619634852, 1.5452462475391975, 1.5572824133863592, 1.5689551368162111, 1.5802613015142468, 1.5911978972232013, 1.601762019486211, 1.6119508694428832, 1.6217617536717484, 1.6311920840732033, 1.640239377787648, 1.6489012571440183, 1.657175449634405, 1.6650597879108415, 1.6725522098007397, 1.679650758337777, 1.6863535818053546, 1.6926589337900106, 1.6985651732424434, 1.70407076454401, 1.709174277576781, 1.7138743877954374, 1.71816987629944, 1.7220596299041027, 1.7255426412093209, 1.7286180086648548, 1.7312849366312084, 1.733542735435249, 1.7353908214198395, 1.7368287169868593, 1.7378560506330996, 1.7384725569786041], [1.768823677885037, 1.7686134162648677, 1.7679826848683293, 1.766931644081184, 1.7654605611925678, 1.7635698103644257, 1.7612598725889683, 1.758531335634421, 1.7553848939793926, 1.751821348736289, 1.747841607564263, 1.7434466845722905, 1.7386377002130564, 1.7334158811684204, 1.7277825602273496, 1.7217391761573064, 1.7152872735702116, 1.7084285027842157, 1.7011646196826746, 1.6934974855718592, 1.6854290670391043, 1.6769614358132952, 1.6680967686297696, 1.658837347101961, 1.6491855576023353, 1.6391438911554537, 1.6287149433462988, 1.6179014142473267, 1.606706108368095, 1.5951319346317188, 1.583181906382893, 1.570859141432718, 1.5581668621461848, 1.545108395578803, 1.5316871736696285, 1.5179067334987744, 1.5037707176184465, 1.489282874467621, 1.4744470588817098, 1.4592672327099563, 1.4437474655548885, 1.4278919356499786, 1.4117049308937302, 1.3951908500608075, 1.3783542042135575, 1.3611996183404202, 1.3437318332513943, 1.3259557077649038, 1.3078762212253308, 1.2894984763961372, 1.2708277027801307, 1.2518692604261443, 1.2326286442904717, 1.2131114892319979, 1.1933235757324996, 1.173270836448334, 1.1529593637172215, 1.1323954181645814, 1.111585438578577, 1.0905360532525534, 1.0692540930289134, 1.047746606320995, 1.026020876440803, 1.0040844416225179, 0.9819451182071164, 0.9596110275453436, 0.9370906272887426, 0.9143927478765754, 0.8915266351967428, 0.8685020006095792, 0.8453290797852597, 0.8220187021322324, 0.7985823730031862, 0.7750323713794043, 0.7513818663834202, 0.7276450567919742, 0.7038373387659189, 0.6799755083451225, 0.6560780069572989, 0.632165220365891, 0.6082598442675192, 0.5843873333098775, 0.5605764548347775, 0.5368599743818097, 0.5132755071380486, 0.489866578244943, 0.4666839451261408, 0.44378724624257254, 0.42124705134451595, 0.3991473947693952, 0.3775888682247264, 0.3566923187013075, 0.3366031156497392, 0.31749577846374727, 0.2995784320427041, 0.28309602003778994, 0.2683304293674694, 0.25559480086060293, 0.24521880127329798, 0.23752246495673277, 0.23277946464682847, 0.231176322114963, 0.23277946464683177, 0.2375224649567392, 0.24521880127330728, 0.2555948008606148, 0.26833042936748364, 0.2830960200378061, 0.2995784320427219, 0.31749577846376636, 0.3366031156497594, 0.35669231870132856, 0.3775888682247482, 0.3991473947694177, 0.42124705134453894, 0.4437872462425959, 0.4666839451261645, 0.489866578244967, 0.5132755071380728, 0.536859974381834, 0.560576454834802, 0.5843873333099021, 0.6082598442675438, 0.6321652203659154, 0.6560780069573234, 0.679975508345147, 0.7038373387659435, 0.7276450567919986, 0.7513818663834444, 0.7750323713794288, 0.7985823730032106, 0.8220187021322565, 0.8453290797852836, 0.868502000609603, 0.8915266351967664, 0.9143927478765989, 0.9370906272887658, 0.9596110275453665, 0.9819451182071394, 1.0040844416225405, 1.0260208764408254, 1.0477466063210177, 1.0692540930289351, 1.090536053252575, 1.1115854385785986, 1.1323954181646028, 1.1529593637172424, 1.1732708364483546, 1.1933235757325202, 1.2131114892320178, 1.2326286442904915, 1.2518692604261639, 1.2708277027801498, 1.2894984763961563, 1.3078762212253494, 1.3259557077649222, 1.3437318332514123, 1.361199618340438, 1.3783542042135748, 1.3951908500608246, 1.4117049308937468, 1.4278919356499948, 1.4437474655549047, 1.459267232709972, 1.474447058881725, 1.4892828744676363, 1.5037707176184614, 1.5179067334987886, 1.5316871736696422, 1.5451083955788167, 1.5581668621461984, 1.570859141432731, 1.5831819063829053, 1.595131934631731, 1.6067061083681067, 1.617901414247338, 1.62871494334631, 1.6391438911554643, 1.6491855576023455, 1.6588373471019706, 1.6680967686297792, 1.676961435813304, 1.685429067039113, 1.6934974855718674, 1.7011646196826824, 1.7084285027842228, 1.7152872735702183, 1.7217391761573129, 1.727782560227355, 1.7334158811684262, 1.7386377002130615, 1.7434466845722953, 1.7478416075642673, 1.751821348736293, 1.755384893979396, 1.7585313356344237, 1.761259872588971, 1.763569810364428, 1.7654605611925696, 1.7669316440811849, 1.7679826848683302, 1.768613416264868], [1.7991929271442884, 1.7989780492112952, 1.7983334693287212, 1.7972593492378275, 1.7957559584808982, 1.7938236743616065, 1.7914629818897365, 1.7886744737104472, 1.7854588500183495, 1.7818169184567185, 1.7777495940022263, 1.7732578988356555, 1.7683429621991196, 1.763006020240395, 1.7572484158450437, 1.751071598457109, 1.7444771238892354, 1.7374666541231825, 1.730041957101811, 1.7222049065137204, 1.7139574815718717, 1.705301766787651, 1.6962399517419933, 1.6867743308553593, 1.6769073031585426, 1.6666413720664999, 1.655979145157619, 1.6449233339611211, 1.633476753755547, 1.6216423233816435, 1.60942306507328, 1.596822104310475, 1.5838426696990324, 1.5704880928818203, 1.5567618084872927, 1.5426673541215146, 1.5282083704106855, 1.5133886011020017, 1.4982118932316433, 1.4826821973697715, 1.466803567953655, 1.450580163721469, 1.434016248260935, 1.4171161906888483, 1.3998844664796881, 1.3823256584639942, 1.3644444580200716, 1.346245666485915, 1.3277341968221295, 1.308915075561126, 1.2897934450831607, 1.270374566265949, 1.2506638215618524, 1.230666718565177, 1.210388894142201, 1.1898361192085232, 1.169014304252506, 1.1479295057205237, 1.1265879333999698, 1.1049959589602665, 1.0831601258413655, 1.061087160714573, 1.0387839867834092, 1.0162577392444023, 0.9935157832915462, 0.9705657351264805, 0.9474154865330282, 0.9240732336943122, 0.9005475110794057, 0.8768472314123661, 0.852981732969914, 0.8289608357486017, 0.8047949084159745, 0.7804949484366512, 0.7560726783749847, 0.7315406621630366, 0.7069124461425113, 0.6822027310180144, 0.6574275825992926, 0.6326046915011108, 0.6077536949997192, 0.5828965782698535, 0.5580581775899044, 0.5332668152643985, 0.508555105573518, 0.48396098378076063, 0.45952902701762494, 0.4353121576581401, 0.4113738472375535, 0.3877909715758536, 0.36465750206441583, 0.34208924364823806, 0.3202298216848459, 0.2992580232609614, 0.27939630758397865, 0.26091963152212355, 0.24416243547018726, 0.22951951371345325, 0.217433900696578, 0.20836363091248816, 0.20272308218560967, 0.20080707285571164, 0.2027230821856136, 0.20836363091249577, 0.21743390069658897, 0.22951951371346707, 0.24416243547020344, 0.2609196315221418, 0.27939630758399847, 0.2992580232609824, 0.32022982168486797, 0.342089243648261, 0.36465750206443936, 0.38779097157587755, 0.41137384723757797, 0.43531215765816483, 0.45952902701764997, 0.4839609837807859, 0.5085551055735436, 0.5332668152644239, 0.55805817758993, 0.5828965782698791, 0.6077536949997446, 0.6326046915011362, 0.6574275825993181, 0.6822027310180397, 0.7069124461425365, 0.7315406621630618, 0.7560726783750098, 0.7804949484366763, 0.8047949084159993, 0.8289608357486264, 0.8529817329699385, 0.8768472314123906, 0.9005475110794298, 0.9240732336943361, 0.9474154865330522, 0.970565735126504, 0.9935157832915695, 1.0162577392444254, 1.0387839867834323, 1.061087160714596, 1.083160125841388, 1.104995958960289, 1.1265879333999917, 1.1479295057205454, 1.1690143042525276, 1.1898361192085447, 1.210388894142222, 1.2306667185651978, 1.2506638215618728, 1.2703745662659687, 1.2897934450831803, 1.3089150755611454, 1.3277341968221488, 1.346245666485934, 1.36444445802009, 1.3823256584640122, 1.3998844664797059, 1.4171161906888656, 1.434016248260952, 1.450580163721486, 1.4668035679536715, 1.4826821973697875, 1.4982118932316588, 1.513388601102017, 1.5282083704107003, 1.5426673541215292, 1.5567618084873072, 1.5704880928818343, 1.5838426696990462, 1.596822104310488, 1.6094230650732924, 1.621642323381656, 1.6334767537555592, 1.6449233339611324, 1.6559791451576302, 1.6666413720665108, 1.6769073031585533, 1.6867743308553693, 1.6962399517420028, 1.70530176678766, 1.7139574815718803, 1.7222049065137286, 1.7300419571018189, 1.7374666541231896, 1.744477123889242, 1.7510715984571157, 1.7572484158450494, 1.7630060202404008, 1.768342962199125, 1.7732578988356602, 1.7777495940022308, 1.7818169184567225, 1.7854588500183532, 1.78867447371045, 1.7914629818897392, 1.7938236743616087, 1.7957559584808995, 1.7972593492378286, 1.7983334693287218, 1.7989780492112961], [1.8297564442776084, 1.8295370752200042, 1.8288790224853526, 1.8277824493785917, 1.8262476280428452, 1.824274939411828, 1.8218648731433733, 1.8190180275342203, 1.8157351094162615, 1.812016934034499, 1.8078644249069917, 1.803278613667141, 1.7982606398887075, 1.7928117508940102, 1.7869333015458229, 1.7806267540235374, 1.773893677584246, 1.7667357483094492, 1.7591547488382058, 1.7511525680875912, 1.7427312009614657, 1.733892748048622, 1.7246394153115228, 1.714973513766955, 1.7048974591600574, 1.6944137716333552, 1.6835250753925783, 1.6722340983712563, 1.6605436718962716, 1.6484567303568076, 1.635976310879381, 1.6231055530119478, 1.609847698420412, 1.5962060906012316, 1.5821841746142464, 1.567785496840335, 1.5530137047690484, 1.5378725468219807, 1.5223658722183524, 1.506497630890071, 1.4902718734544587, 1.4736927512538807, 1.4567645164727168, 1.4394915223434952, 1.4218782234556235, 1.4039291761819743, 1.3856490392407441, 1.3670425744124755, 1.3481146474350274, 1.3288702291026666, 1.3093143965993863, 1.2894523351012233, 1.2692893396877798, 1.2488308176096332, 1.228082290965929, 1.2070493998555385, 1.185737906075966, 1.1641536974571245, 1.1423027929326008, 1.1201913484697272, 1.0978256640023412, 1.0752121915375368, 1.0523575446410873, 1.0292685095470813, 1.005952058187511, 0.9824153634995385, 0.9586658174450154, 0.9347110522726542, 0.9105589656732556, 0.886217750629561, 0.8616959309537192, 0.8370024037491824, 0.8121464903462684, 0.7871379976634759, 0.7619872924694291, 0.7367053917033822, 0.7113040729109102, 0.6857960100423461, 0.6601949414515732, 0.6345158790718725, 0.6087753706457103, 0.5829918308482815, 0.5571859626019476, 0.5313812974507247, 0.5056048944441466, 0.47988825185356104, 0.4542685070484503, 0.42879002957971685, 0.40350655446570244, 0.37848406131234397, 0.353804685004515, 0.3295720479593858, 0.3059185257754867, 0.283015063333298, 0.2610841418890634, 0.24041609273655937, 0.22138757660358271, 0.20447766310362459, 0.19027041647096177, 0.17942417549889914, 0.17258506318876615, 0.17024355572239155, 0.17258506318877093, 0.17942417549890832, 0.19027041647097476, 0.20447766310364068, 0.22138757660360128, 0.24041609273657988, 0.26108414188908535, 0.28301506333332105, 0.30591852577551076, 0.3295720479594104, 0.3538046850045402, 0.37848406131236956, 0.4035065544657283, 0.42879002957974294, 0.4542685070484766, 0.4798882518535874, 0.5056048944441731, 0.5313812974507512, 0.5571859626019743, 0.5829918308483081, 0.6087753706457365, 0.6345158790718989, 0.6601949414515995, 0.6857960100423726, 0.7113040729109364, 0.7367053917034083, 0.7619872924694551, 0.7871379976635018, 0.8121464903462939, 0.8370024037492079, 0.8616959309537447, 0.8862177506295861, 0.9105589656732804, 0.9347110522726788, 0.95866581744504, 0.9824153634995628, 1.0059520581875352, 1.0292685095471052, 1.052357544641111, 1.07521219153756, 1.0978256640023645, 1.12019134846975, 1.1423027929326235, 1.164153697457147, 1.1857379060759883, 1.2070493998555603, 1.2280822909659506, 1.248830817609654, 1.2692893396878007, 1.2894523351012437, 1.3093143965994067, 1.3288702291026864, 1.3481146474350472, 1.3670425744124948, 1.3856490392407632, 1.4039291761819928, 1.4218782234556415, 1.4394915223435132, 1.4567645164727343, 1.4736927512538982, 1.4902718734544753, 1.5064976308900875, 1.5223658722183686, 1.5378725468219965, 1.5530137047690638, 1.56778549684035, 1.5821841746142609, 1.596206090601246, 1.6098476984204262, 1.6231055530119611, 1.6359763108793939, 1.6484567303568205, 1.6605436718962838, 1.6722340983712682, 1.6835250753925897, 1.6944137716333663, 1.7048974591600683, 1.7149735137669653, 1.7246394153115328, 1.733892748048631, 1.7427312009614746, 1.7511525680875997, 1.7591547488382135, 1.766735748309457, 1.7738936775842529, 1.7806267540235443, 1.7869333015458289, 1.7928117508940162, 1.7982606398887129, 1.803278613667146, 1.8078644249069962, 1.8120169340345031, 1.815735109416265, 1.8190180275342236, 1.8218648731433764, 1.82427493941183, 1.8262476280428466, 1.8277824493785928, 1.8288790224853535, 1.829537075220005], [1.8604846610560841, 1.8602609254319462, 1.8595897735885951, 1.8584713706023206, 1.8569059915639674, 1.8548940215245266, 1.8524359554190786, 1.8495323979691858, 1.8461840635638809, 1.842391776119428, 1.838156468918058, 1.8334791844259333, 1.8283610740906138, 1.8228033981183556, 1.8168075252316038, 1.810374932407092, 1.8035072045950018, 1.7962060344197004, 1.7884732218626198, 1.7803106739279033, 1.771720404291516, 1.7627045329345852, 1.7532652857618145, 1.743404994205906, 1.733126094819019, 1.7224311288523948, 1.7113227418254062, 1.699803683085407, 1.687876805359911, 1.6755450643027898, 1.6628115180363574, 1.6496793266914147, 1.636151751947552, 1.6222321565762738, 1.6079240039897849, 1.5932308577986172, 1.578156381381646, 1.562704337472457, 1.5468785877665239, 1.5306830925541846, 1.514121910385046, 1.4971991977701622, 1.4799192089291489, 1.4622862955903595, 1.4443049068533371, 1.4259795891240286, 1.4073149861347187, 1.3883158390623582, 1.368986986760947, 1.3493333661259814, 1.3293600126116976, 1.309072060925069, 1.2884747459243076, 1.2675734037541035, 1.246373473255172, 1.224880497692006, 1.2031001268503165, 1.1810381195647135, 1.1587003467481163, 1.136092795007566, 1.1132215709471156, 1.0900929062779559, 1.066713163879747, 1.043088844986383, 1.0192265977055108, 0.9951332271258819, 0.9708157073223864, 0.9462811956385072, 0.921537049713942, 0.8965908478367048, 0.8714504133411989, 0.8461238439561963, 0.8206195472422931, 0.7949462835648758, 0.7691132184502305, 0.7431299867027039, 0.717006771366807, 0.6907544015661182, 0.664384474535261, 0.6379095089181023, 0.611343138832405, 0.5847003615893345, 0.5579978567377899, 0.5312544009285324, 0.5044914129495652, 0.47773367769031944, 0.45101031910324685, 0.42435612413091334, 0.39781336784197374, 0.37143436375194916, 0.3452850765706691, 0.3194503084992961, 0.29404123369537816, 0.26920643987162796, 0.2451481443697971, 0.22214575147008286, 0.20058881508741594, 0.18101890044811622, 0.16417024236181552, 0.1509754211463707, 0.14246751607536998, 0.1395153389439158, 0.14246751607537597, 0.15097542114638204, 0.16417024236183111, 0.18101890044813504, 0.20058881508743717, 0.22214575147010587, 0.24514814436982135, 0.2692064398716531, 0.294041233695404, 0.31945030849932243, 0.34528507657069585, 0.37143436375197614, 0.3978133678420009, 0.4243561241309407, 0.45101031910327427, 0.47773367769034697, 0.5044914129495929, 0.5312544009285598, 0.5579978567378174, 0.5847003615893618, 0.6113431388324322, 0.6379095089181294, 0.6643844745352881, 0.6907544015661453, 0.7170067713668341, 0.7431299867027308, 0.7691132184502572, 0.7949462835649022, 0.8206195472423194, 0.8461238439562225, 0.8714504133412247, 0.8965908478367307, 0.9215370497139674, 0.9462811956385325, 0.9708157073224116, 0.9951332271259068, 1.0192265977055357, 1.0430888449864073, 1.066713163879771, 1.0900929062779798, 1.1132215709471394, 1.1360927950075894, 1.1587003467481394, 1.1810381195647361, 1.2031001268503387, 1.2248804976920282, 1.2463734732551937, 1.2675734037541249, 1.2884747459243289, 1.3090720609250903, 1.3293600126117182, 1.3493333661260016, 1.368986986760967, 1.388315839062378, 1.4073149861347383, 1.4259795891240474, 1.4443049068533558, 1.4622862955903777, 1.4799192089291666, 1.4971991977701797, 1.5141219103850632, 1.5306830925542012, 1.5468785877665403, 1.5627043374724732, 1.5781563813816617, 1.5932308577986325, 1.6079240039897995, 1.622232156576288, 1.6361517519475661, 1.649679326691428, 1.6628115180363707, 1.6755450643028025, 1.6878768053599236, 1.699803683085419, 1.7113227418254182, 1.7224311288524063, 1.7331260948190295, 1.7434049942059164, 1.753265285761824, 1.7627045329345945, 1.7717204042915253, 1.7803106739279118, 1.788473221862628, 1.7962060344197077, 1.8035072045950085, 1.8103749324070988, 1.81680752523161, 1.8228033981183613, 1.828361074090619, 1.8334791844259384, 1.8381564689180627, 1.8423917761194322, 1.8461840635638849, 1.8495323979691891, 1.8524359554190815, 1.8548940215245286, 1.8569059915639687, 1.858471370602322, 1.859589773588596, 1.860260925431947], [1.8913478499145329, 1.8911198713720723, 1.8904359914328355, 1.88929637714924, 1.887701306901918, 1.8856511703396643, 1.883146468295431, 1.8801878126784557, 1.876775926342604, 1.8729116429310653, 1.8685959066975297, 1.863829772304019, 1.8586144045955646, 1.8529510783519556, 1.8468411780167941, 1.8402861974041478, 1.8332877393831026, 1.8258475155405562, 1.8179673458226422, 1.809649158155192, 1.8008949880437055, 1.7917069781533348, 1.7820873778694377, 1.772038542839321, 1.7615629344958401, 1.7506631195636027, 1.7393417695485849, 1.7276016602120627, 1.7154456710298371, 1.70287678463785, 1.6898980862653794, 1.676512763157148, 1.6627241039858096, 1.6485354982564349, 1.6339504357048036, 1.6189725056915116, 1.603605396594121, 1.587852895199857, 1.5717188861016334, 1.5552073511005413, 1.5383223686183125, 1.5210681131237123, 1.5034488545773272, 1.4854689578997953, 1.4671328824692056, 1.448445181654169, 1.4294105023899795, 1.4100335848063354, 1.3903192619163185, 1.3702724593777855, 1.3498981953400064, 1.329201580390381, 1.3081878176184212, 1.2868622028169745, 1.26523012484397, 1.2432970661719263, 1.2210686036571878, 1.1985504095665285, 1.1757482529056078, 1.1526680011020591, 1.129315622106045, 1.1056971869834156, 1.0818188730916707, 1.057686967947481, 1.033307873917511, 1.008688113892846, 0.9838343381430862, 0.9587533325911199, 0.9334520288064646, 0.9079375160874691, 0.8822170560954273, 0.8562981006233209, 0.8301883132373978, 0.803895595733358, 0.7774281206176071, 0.750794371181682, 0.7240031912183369, 0.697063847079237, 0.669986105666676, 0.6427803331877345, 0.6154576212308607, 0.5880299491807931, 0.5605103955170775, 0.532913415685029, 0.5052552118374298, 0.4775542311843775, 0.4498318471810215, 0.4221133050213526, 0.394429056141703, 0.3668166764534911, 0.3393236787606508, 0.3120117250485135, 0.28496307983275804, 0.2582907303705947, 0.23215462121163874, 0.20678819608710633, 0.18254216743309326, 0.15995547822850043, 0.1398612826527609, 0.12350603786807961, 0.1125504828785645, 0.10865215008546714, 0.11255048287857237, 0.12350603786809393, 0.13986128265277983, 0.15995547822852252, 0.18254216743311746, 0.20678819608713195, 0.23215462121166525, 0.2582907303706219, 0.2849630798327857, 0.31201172504854147, 0.339323678760679, 0.3668166764535195, 0.39442905614173135, 0.4221133050213811, 0.44983184718104996, 0.477554231184406, 0.5052552118374583, 0.5329134156850575, 0.560510395517106, 0.5880299491808214, 0.6154576212308888, 0.6427803331877625, 0.6699861056667038, 0.6970638470792646, 0.7240031912183644, 0.7507943711817094, 0.7774281206176343, 0.8038955957333851, 0.8301883132374247, 0.8562981006233477, 0.8822170560954538, 0.9079375160874956, 0.9334520288064907, 0.9587533325911457, 0.983834338143112, 1.0086881138928714, 1.033307873917536, 1.0576869679475058, 1.0818188730916953, 1.1056971869834402, 1.1293156221060692, 1.152668001102083, 1.1757482529056316, 1.1985504095665518, 1.2210686036572111, 1.2432970661719491, 1.2652301248439923, 1.2868622028169967, 1.3081878176184432, 1.3292015803904023, 1.3498981953400273, 1.3702724593778062, 1.3903192619163387, 1.4100335848063557, 1.4294105023899994, 1.4484451816541881, 1.4671328824692247, 1.4854689578998141, 1.5034488545773455, 1.5210681131237302, 1.53832236861833, 1.5552073511005584, 1.57171888610165, 1.5878528951998736, 1.603605396594137, 1.618972505691527, 1.633950435704819, 1.6485354982564495, 1.6627241039858245, 1.6765127631571621, 1.6898980862653925, 1.7028767846378634, 1.71544567102985, 1.7276016602120747, 1.7393417695485969, 1.7506631195636142, 1.7615629344958514, 1.7720385428393315, 1.782087377869448, 1.7917069781533446, 1.8008949880437148, 1.8096491581552006, 1.8179673458226502, 1.8258475155405638, 1.8332877393831095, 1.8402861974041549, 1.8468411780168004, 1.8529510783519616, 1.8586144045955701, 1.863829772304024, 1.8685959066975342, 1.8729116429310695, 1.8767759263426078, 1.880187812678459, 1.8831464682954344, 1.8856511703396663, 1.8877013069019197, 1.889296377149241, 1.8904359914328366, 1.8911198713720725], [1.9223161527110013, 1.922084053745497, 1.9213878132627347, 1.920227600491053, 1.9186036974346452, 1.9165164988090209, 1.9139665119507128, 1.9109543567012592, 1.9074807652655374, 1.90354658204453, 1.899152763442606, 1.8943003776494334, 1.888990604396654, 1.88322473468945, 1.8770041705131741, 1.870330424515217, 1.8632051196623074, 1.8556299888734686, 1.847606874628867, 1.8391377285548176, 1.8302246109852365, 1.820869690499848, 1.8110752434395005, 1.8008436533989571, 1.790177410697572, 1.779079111828303, 1.7675514588855354, 1.7555972589722642, 1.7432194235871967, 1.7304209679924243, 1.7172050105623486, 1.7035747721146306, 1.6895335752239913, 1.6750848435197938, 1.6602321009684131, 1.644978971141521, 1.6293291764715214, 1.6132865374955176, 1.5968549720893375, 1.5800384946933246, 1.5628412155318028, 1.5452673398283459, 1.5273211670192561, 1.5090070899679453, 1.4903295941832795, 1.4712932570453308, 1.45190274704247, 1.4321628230242662, 1.4120783334752995, 1.391654215815744, 1.3708954957354462, 1.349807286569265, 1.3283947887226462, 1.3066632891578598, 1.284618160953044, 1.262264862948243, 1.2396089394950973, 1.2166560203297885, 1.19341182059241, 1.1698821410202636, 1.1460728683478398, 1.1219899759526801, 1.0976395247942157, 1.0730276647024437, 1.0481606360853963, 1.0230447721394471, 0.9976865016654296, 0.9720923526173988, 0.9462689565411563, 0.9202230540983304, 0.8939615019215347, 0.8674912811105284, 0.8408195077633394, 0.8139534460468516, 0.7869005244580134, 0.7596683561231438, 0.7322647642481797, 0.704697814195107, 0.6769758541601936, 0.649107567128732, 0.6211020377701366, 0.5929688393559723, 0.564718147848513, 0.5363608933613458, 0.5079089637884748, 0.4793754824429374, 0.45077519256937953, 0.4221249992352799, 0.39344474803596774, 0.3647583687928208, 0.33609559702627756, 0.3074946376956036, 0.27900641764988904, 0.25070161795496776, 0.2226827737112088, 0.1951060281858607, 0.16822211773739454, 0.14245709281517907, 0.11857543344055704, 0.09799511288167106, 0.08322896995952223, 0.07768384728899864, 0.08322896995953323, 0.09799511288168976, 0.1185754334405802, 0.14245709281520474, 0.1682221177374217, 0.19510602818588874, 0.22268277371123743, 0.25070161795499674, 0.27900641764991824, 0.30749463769563296, 0.3360955970263071, 0.36475836879285034, 0.39344474803599716, 0.4221249992353094, 0.4507751925694089, 0.4793754824429667, 0.5079089637885041, 0.5363608933613752, 0.5647181478485422, 0.5929688393560012, 0.6211020377701655, 0.6491075671287606, 0.676975854160222, 0.7046978141951354, 0.7322647642482079, 0.7596683561231717, 0.7869005244580412, 0.8139534460468794, 0.8408195077633669, 0.8674912811105557, 0.8939615019215618, 0.9202230540983573, 0.9462689565411829, 0.9720923526174252, 0.9976865016654558, 1.0230447721394729, 1.0481606360854219, 1.0730276647024692, 1.0976395247942408, 1.121989975952705, 1.1460728683478645, 1.1698821410202878, 1.193411820592434, 1.2166560203298122, 1.2396089394951206, 1.262264862948266, 1.284618160953067, 1.3066632891578824, 1.3283947887226681, 1.349807286569287, 1.3708954957354673, 1.391654215815765, 1.4120783334753204, 1.4321628230242869, 1.45190274704249, 1.47129325704535, 1.490329594183299, 1.5090070899679644, 1.5273211670192743, 1.545267339828364, 1.5628412155318203, 1.5800384946933423, 1.5968549720893546, 1.6132865374955345, 1.6293291764715379, 1.6449789711415366, 1.6602321009684287, 1.675084843519809, 1.6895335752240062, 1.703574772114645, 1.7172050105623624, 1.7304209679924376, 1.7432194235872098, 1.7555972589722766, 1.7675514588855477, 1.779079111828315, 1.7901774106975836, 1.8008436533989678, 1.811075243439511, 1.8208696904998574, 1.8302246109852458, 1.8391377285548267, 1.8476068746288752, 1.8556299888734766, 1.8632051196623152, 1.8703304245152241, 1.8770041705131806, 1.8832247346894564, 1.8889906043966596, 1.894300377649439, 1.8991527634426109, 1.9035465820445348, 1.9074807652655412, 1.9109543567012623, 1.913966511950716, 1.9165164988090233, 1.9186036974346468, 1.9202276004910546, 1.9213878132627358, 1.9220840537454977], [1.9533596096125903, 1.9531235113569507, 1.9524152737936546, 1.951235068519992, 1.9495831814861981, 1.9474600129275967, 1.944866077269632, 1.9418020030058256, 1.938268532548698, 1.934266522053705, 1.929796941216255, 1.9248608730418764, 1.919459513589615, 1.913594171688756, 1.9072662686289712, 1.9004773378240092, 1.8932290244490406, 1.8855230850518137, 1.8773613871377495, 1.8687459087291491, 1.8596787378986814, 1.8501620722773373, 1.8401982185370604, 1.8297895918482596, 1.818938715312445, 1.8076482193702357, 1.7959208411850056, 1.783759424002463, 1.7711669164864656, 1.758146372031416, 1.7447009480515845, 1.7308339052477604, 1.7165486068516416, 1.7018485178484155, 1.6867372041780249, 1.671218331915646, 1.6552956664319647, 1.6389730715338724, 1.6222545085862785, 1.6051440356157927, 1.5876458063971115, 1.5697640695230255, 1.5515031674590634, 1.5328675355839008, 1.5138617012167943, 1.4944902826334427, 1.4747579880718564, 1.4546696147300147, 1.4342300477573178, 1.4134442592421217, 1.3923173071979547, 1.3708543345513946, 1.3490605681350265, 1.326941317689427, 1.304501974878743, 1.281748012325184, 1.2586849826686277, 1.2353185176586257, 1.2116543272873865, 1.1876981989738826, 1.1634559968111478, 1.1389336608911766, 1.1141372067247193, 1.0890727247768188, 1.0637463801433764, 1.0381644123995346, 1.012333135657625, 0.9862589388811717, 0.9599482865125939, 0.9334077194865077, 0.9066438567188898, 0.8796633971862303, 0.8524731227399998, 0.8250799018429315, 0.7974906944684178, 0.7697125584779424, 0.7417526578913863, 0.7136182736020933, 0.6853168172787685, 0.6568558494634507, 0.628243103255222, 0.5994865155188154, 0.5705942683635976, 0.5415748448419198, 0.5124371046460406, 0.4831903884237157, 0.4538446638429222, 0.4244107338786899, 0.3949005400859227, 0.3653276148495324, 0.33570777458050577, 0.30606021654850457, 0.2764093199289719, 0.2467877351345683, 0.21724196556811293, 0.18784310465696927, 0.15870913183991997, 0.13005579167223102, 0.10232691659148421, 0.0765747291120776, 0.05565644496403768, 0.04664039038740978, 0.05565644496405471, 0.07657472911210234, 0.10232691659151197, 0.1300557916722601, 0.15870913183994975, 0.18784310465699938, 0.21724196556814324, 0.24678773513459876, 0.2764093199290024, 0.30606021654853505, 0.3357077745805363, 0.3653276148495628, 0.394900540085953, 0.42441073387872014, 0.45384466384295236, 0.4831903884237459, 0.5124371046460707, 0.5415748448419496, 0.5705942683636275, 0.5994865155188449, 0.6282431032552515, 0.6568558494634799, 0.6853168172787976, 0.7136182736021224, 0.7417526578914151, 0.769712558477971, 0.7974906944684461, 0.8250799018429597, 0.8524731227400278, 0.8796633971862581, 0.9066438567189173, 0.9334077194865351, 0.9599482865126211, 0.9862589388811986, 1.012333135657652, 1.038164412399561, 1.0637463801434026, 1.0890727247768448, 1.1141372067247448, 1.138933660891202, 1.1634559968111728, 1.1876981989739075, 1.2116543272874112, 1.2353185176586496, 1.2586849826686515, 1.2817480123252076, 1.3045019748787665, 1.3269413176894496, 1.3490605681350492, 1.3708543345514168, 1.3923173071979766, 1.4134442592421432, 1.4342300477573389, 1.4546696147300355, 1.474757988071877, 1.4944902826334625, 1.513861701216814, 1.53286753558392, 1.551503167459082, 1.5697640695230441, 1.5876458063971295, 1.6051440356158104, 1.6222545085862958, 1.6389730715338895, 1.6552956664319811, 1.671218331915662, 1.6867372041780406, 1.7018485178484313, 1.7165486068516567, 1.7308339052477746, 1.744700948051598, 1.7581463720314294, 1.7711669164864792, 1.783759424002476, 1.795920841185018, 1.8076482193702477, 1.8189387153124565, 1.8297895918482703, 1.8401982185370709, 1.8501620722773469, 1.859678737898691, 1.8687459087291587, 1.8773613871377581, 1.8855230850518216, 1.8932290244490482, 1.900477337824016, 1.9072662686289779, 1.9135941716887623, 1.9194595135896209, 1.9248608730418817, 1.9297969412162599, 1.9342665220537092, 1.9382685325487021, 1.9418020030058294, 1.9448660772696351, 1.9474600129275992, 1.9495831814862004, 1.9512350685199933, 1.9524152737936553, 1.9531235113569514], [1.984448188079657, 1.984208210125703, 1.9834883343188423, 1.9822887348100686, 1.9806097018043312, 1.9784516414904794, 1.9758150759432274, 1.9727006429971317, 1.96910909609264, 1.96504130409424, 1.9604982510807496, 1.9554810361078139, 1.9499908729426565, 1.9440290897711627, 1.9375971288773617, 1.9306965462953927, 1.9233290114340484, 1.9154963066739787, 1.9072003269376776, 1.8984430792323401, 1.8892266821657335, 1.879553365435184, 1.8694254692898258, 1.8588454439662498, 1.8478158490977, 1.8363393530969647, 1.8244187325131433, 1.8120568713624399, 1.7992567604331753, 1.7860214965652033, 1.772354281903919, 1.7582584231290745, 1.7437373306586041, 1.7287945178276924, 1.7134336000433041, 1.6976582939144287, 1.6814724163582873, 1.6648798836827627, 1.6478847106453323, 1.6304910094887877, 1.6127029889540438, 1.594524953270353, 1.5759613011232514, 1.5570165246005927, 1.5376952081170343, 1.5180020273173593, 1.4979417479590564, 1.477519224774593, 1.4567394003138456, 1.435607303767206, 1.4141280497698905, 1.3923068371880583, 1.370148947887368, 1.3476597454846921, 1.324844674083756, 1.301709256995576, 1.2782590954446582, 1.254499867262057, 1.2304373255665237, 1.206077297435168, 1.1814256825652587, 1.1564884519290723, 1.1312716464239896, 1.105781375520478, 1.0800238159110571, 1.0540052101639883, 1.0277318653861824, 1.0012101519008159, 0.974446501946376, 0.9474474084054578, 0.9202194235736794, 0.892769157981758, 0.8651032792872801, 0.8372285112573088, 0.8091516328691315, 0.780879477564721, 0.7524189327057356, 0.7237769392913571, 0.6949604920227721, 0.6659766398284065, 0.6368324870072932, 0.6075351952106766, 0.5780919865743277, 0.548510148452551, 0.5187970404165477, 0.4889601045103276, 0.45900688028576075, 0.42894502700559567, 0.39878235686917146, 0.3685268856772386, 0.33818691200184, 0.3077711447422449, 0.2772889165297433, 0.2467505576728371, 0.2161680900256445, 0.18555661050496494, 0.15493731735854227, 0.12434500048331583, 0.09385010320576291, 0.06364352007629748, 0.0345579064237627, 0.015551811920342959, 0.03455790642379102, 0.06364352007632823, 0.09385010320579418, 0.12434500048334725, 0.15493731735857375, 0.1855566105049964, 0.21616809002567594, 0.24675055767286846, 0.2772889165297747, 0.3077711447422761, 0.33818691200187123, 0.3685268856772697, 0.39878235686920255, 0.42894502700562653, 0.45900688028579156, 0.48896010451035843, 0.5187970404165784, 0.5485101484525814, 0.5780919865743581, 0.6075351952107068, 0.6368324870073231, 0.6659766398284364, 0.6949604920228019, 0.7237769392913866, 0.7524189327057648, 0.7808794775647503, 0.8091516328691605, 0.8372285112573374, 0.8651032792873088, 0.8927691579817865, 0.9202194235737075, 0.9474474084054857, 0.9744465019464037, 1.0012101519008432, 1.0277318653862098, 1.0540052101640152, 1.080023815911084, 1.1057813755205042, 1.1312716464240158, 1.156488451929098, 1.1814256825652842, 1.206077297435193, 1.2304373255665488, 1.2544998672620817, 1.2782590954446826, 1.3017092569955997, 1.3248446740837798, 1.3476597454847152, 1.370148947887391, 1.3923068371880807, 1.4141280497699127, 1.4356073037672277, 1.456739400313867, 1.477519224774614, 1.4979417479590773, 1.5180020273173793, 1.5376952081170545, 1.5570165246006125, 1.5759613011232703, 1.5945249532703716, 1.6127029889540623, 1.6304910094888057, 1.6478847106453498, 1.6648798836827798, 1.6814724163583041, 1.697658293914445, 1.71343360004332, 1.7287945178277078, 1.7437373306586195, 1.758258423129089, 1.7723542819039333, 1.786021496565217, 1.799256760433189, 1.8120568713624527, 1.8244187325131562, 1.836339353096977, 1.847815849097711, 1.858845443966261, 1.869425469289836, 1.8795533654351941, 1.889226682165743, 1.898443079232349, 1.9072003269376858, 1.9154963066739872, 1.9233290114340562, 1.9306965462954004, 1.9375971288773681, 1.9440290897711694, 1.949990872942662, 1.955481036107819, 1.9604982510807545, 1.9650413040942447, 1.9691090960926443, 1.9727006429971352, 1.9758150759432307, 1.9784516414904822, 1.9806097018043327, 1.9822887348100704, 1.983488334318843, 1.9842082101257037], [2.015551811920359, 2.01530807216807, 2.01457691187592, 2.0133585079238236, 2.011653155064198, 2.009461265850807, 2.0067833705391784, 2.003620116958603, 1.9999722703557572, 1.9958407132099947, 1.9912264450203332, 1.9861305820642159, 1.980554357128086, 1.9744991192098615, 1.9679663331933719, 1.9609575794948437, 1.953474553681534, 1.9455190660625934, 1.9370930412522762, 1.928198517705603, 1.918837647226601, 1.9090126944492405, 1.8987260362912115, 1.8879801613806755, 1.8767776694561464, 1.8651212707396543, 1.8530137852833628, 1.8404581422898028, 1.827457379405921, 1.8140146419911116, 1.8001331823594484, 1.7858163589963103, 1.771067635749623, 1.7558905809959402, 1.7402888667815963, 1.7242662679391776, 1.707826661179566, 1.690974024159822, 1.6737124345271803, 1.656046068939457, 1.6379792020621606, 1.619516205542635, 1.6006615469615613, 1.5814197887621726, 1.5617955871575535, 1.5417936910164094, 1.5214189407277265, 1.500676267044762, 1.4795706899088326, 1.4581073172534105, 1.4362913437890732, 1.4141280497698903, 1.3916227997418977, 1.3687810412743588, 1.3456083036745923, 1.322110196687227, 1.2982924091788464, 1.2741607078091088, 1.249720935689573, 1.2249790110316334, 1.199940925785183, 1.1746127442698822, 1.14900060180123, 1.123110703314022, 1.096949321986279, 1.0705227978673202, 1.043837536514433, 1.016900007643548, 0.9897167438005483, 0.9622943390614236, 0.9346394477714836, 0.9067587833364877, 0.8786591170819784, 0.8503472772016545, 0.8218301478216721, 0.79311466821592, 0.7642078322183837, 0.7351166878939576, 0.7058483375502316, 0.6764099382026356, 0.6468087026479155, 0.6170519013626908, 0.5871468655348042, 0.5571009916715634, 0.5269217484374376, 0.4966166866992735, 0.4661934542774682, 0.4356598177556318, 0.4050236951450074, 0.3742932057229879, 0.3434767479447449, 0.3125831250101714, 0.2816217549886015, 0.2506030390826852, 0.21953904506542016, 0.18844487023226536, 0.15734162333824564, 0.12626380760020947, 0.09528107871030649, 0.06458197524022186, 0.0349905650663745, 0.015551811920358946, 0.03499056506640336, 0.06458197524025314, 0.09528107871033827, 0.12626380760024136, 0.15734162333827767, 0.1884448702322973, 0.21953904506545208, 0.2506030390827171, 0.28162175498863334, 0.31258312501020313, 0.3434767479447767, 0.3742932057230195, 0.405023695145039, 0.4356598177556632, 0.46619345427749953, 0.4966166866993048, 0.5269217484374686, 0.5571009916715943, 0.5871468655348352, 0.6170519013627215, 0.646808702647946, 0.6764099382026659, 0.7058483375502617, 0.7351166878939874, 0.7642078322184135, 0.7931146682159494, 0.8218301478217016, 0.8503472772016837, 0.8786591170820074, 0.9067587833365163, 0.934639447771512, 0.9622943390614519, 0.9897167438005762, 1.0169000076435757, 1.0438375365144605, 1.0705227978673473, 1.0969493219863062, 1.1231107033140488, 1.1490006018012564, 1.1746127442699088, 1.199940925785209, 1.224979011031659, 1.2497209356895982, 1.2741607078091337, 1.2982924091788712, 1.3221101966872513, 1.3456083036746163, 1.3687810412743822, 1.391622799741921, 1.4141280497699136, 1.4362913437890958, 1.4581073172534327, 1.4795706899088543, 1.5006762670447835, 1.5214189407277476, 1.54179369101643, 1.561795587157574, 1.5814197887621926, 1.6006615469615806, 1.6195162055426544, 1.6379792020621797, 1.6560460689394754, 1.673712434527198, 1.6909740241598392, 1.7078266611795831, 1.724266267939194, 1.7402888667816123, 1.755890580995956, 1.7710676357496384, 1.7858163589963247, 1.8001331823594626, 1.8140146419911256, 1.8274573794059346, 1.840458142289816, 1.8530137852833755, 1.865121270739667, 1.876777669456158, 1.8879801613806868, 1.8987260362912222, 1.909012694449251, 1.9188376472266109, 1.9281985177056125, 1.937093041252285, 1.945519066062602, 1.953474553681542, 1.9609575794948513, 1.9679663331933783, 1.9744991192098686, 1.9805543571280917, 1.986130582064221, 1.9912264450203383, 1.995840713209999, 1.9999722703557614, 2.003620116958606, 2.0067833705391815, 2.0094612658508098, 2.0116531550642, 2.0133585079238245, 2.014576911875921, 2.0153080721680703], [2.046640390387426, 2.0463930049195564, 2.0456509084451997, 2.0444142807378602, 2.0426834213725593, 2.0404587496546256, 2.0377408045200283, 2.034530244407302, 2.030827847101084, 2.026634509547345, 2.021951247640345, 2.01677919598142, 2.011119607609651, 2.004973853704534, 1.9983434232607389, 1.991229922735085, 1.983635075665846, 1.9755607222645375, 1.967008818980324, 1.9579814380372171, 1.9484807669442366, 1.9385091079787253, 1.9280688776430206, 1.9171626060947038, 1.9057929365506576, 1.8939626246651935, 1.8816745378825086, 1.8689316547637682, 1.855737064289129, 1.8420939651350277, 1.8280056649271041, 1.8134755794691404, 1.7985072319484319, 1.7831042521180482, 1.7672703754564554, 1.751009442305039, 1.734325396984098, 1.717222286887922, 1.6997042615596436, 1.6817755717466025, 1.663440568437038, 1.6447037018790087, 1.625569520582535, 1.6060426703060573, 1.5861278930284468, 1.56583002590792, 1.5451540002294046, 1.5241048403420663, 1.5026876625889534, 1.4809076742309577, 1.4587701723676083, 1.436280542857568, 1.413444259242121, 1.3902668816754573, 1.3667540558661373, 1.3429115120348478, 1.3187450638944038, 1.2942606076589804, 1.2694641210908018, 1.244361662594007, 1.2189593703672563, 1.1932634616288718, 1.167280231931066, 1.1410160545832133, 1.1144773802083516, 1.0876707364623757, 1.0606027279520132, 1.0332800363960666, 1.0057094210850335, 0.9778977197078674, 0.9498518496322071, 0.9215788097472046, 0.8930856830079468, 0.864379639859839, 0.8354679427737629, 0.8063579521932612, 0.7770571342906473, 0.7475730710601368, 0.7179134734582071, 0.6880861985573076, 0.6580992720435055, 0.6279609179153314, 0.5976795980141689, 0.5672640651709738, 0.5367234355105874, 0.5060672881829283, 0.4753058051245524, 0.44444997051549323, 0.4135118614282585, 0.3825050816246454, 0.35144542711096977, 0.3203519404441438, 0.28924864440904763, 0.25816752123273295, 0.22715390855682865, 0.19627691452319856, 0.16565115314589401, 0.13548672861345973, 0.10621893567429927, 0.07889597174768917, 0.056461340729673556, 0.04664039038742575, 0.05646134072969199, 0.07889597174771555, 0.10621893567432865, 0.1354867286134904, 0.16565115314592535, 0.19627691452323018, 0.2271539085568605, 0.2581675212327649, 0.28924864440907955, 0.32035194044417575, 0.3514454271110017, 0.3825050816246772, 0.41351186142829033, 0.444449970515525, 0.4753058051245839, 0.50606728818296, 0.536723435510619, 0.5672640651710052, 0.5976795980142001, 0.6279609179153623, 0.6580992720435362, 0.6880861985573383, 0.7179134734582377, 0.7475730710601671, 0.7770571342906775, 0.8063579521932913, 0.8354679427737927, 0.8643796398598685, 0.8930856830079759, 0.9215788097472337, 0.949851849632236, 0.9778977197078961, 1.005709421085062, 1.0332800363960948, 1.0606027279520411, 1.0876707364624034, 1.1144773802083792, 1.1410160545832402, 1.1672802319310929, 1.1932634616288986, 1.2189593703672825, 1.244361662594033, 1.2694641210908275, 1.294260607659006, 1.3187450638944287, 1.3429115120348727, 1.3667540558661617, 1.390266881675481, 1.4134442592421448, 1.4362805428575913, 1.4587701723676314, 1.4809076742309801, 1.5026876625889756, 1.5241048403420883, 1.545154000229426, 1.565830025907941, 1.5861278930284672, 1.6060426703060775, 1.6255695205825547, 1.6447037018790283, 1.6634405684370568, 1.6817755717466212, 1.6997042615596616, 1.7172222868879397, 1.7343253969841153, 1.7510094423050557, 1.7672703754564714, 1.7831042521180642, 1.7985072319484476, 1.813475579469155, 1.8280056649271188, 1.842093965135042, 1.8557370642891429, 1.8689316547637815, 1.8816745378825215, 1.8939626246652062, 1.9057929365506694, 1.9171626060947151, 1.928068877643032, 1.9385091079787358, 1.948480766944247, 1.9579814380372265, 1.9670088189803332, 1.975560722264546, 1.9836350756658538, 1.9912299227350923, 1.998343423260746, 2.0049738537045405, 2.011119607609657, 2.0167791959814254, 2.02195124764035, 2.0266345095473492, 2.030827847101088, 2.0345302444073052, 2.037740804520032, 2.040458749654628, 2.042683421372561, 2.0444142807378616, 2.045650908445201, 2.0463930049195573], [2.0776838472890145, 2.077432930268637, 2.0766802401523283, 2.0754259597604907, 2.073670393746924, 2.0714139685285375, 2.0686572321870003, 2.065400854342374, 2.0616456259987963, 2.057392459362284, 2.052642387630767, 2.0473965647564403, 2.041656265180577, 2.035422883540936, 2.028697934351919, 2.021483051657667, 2.01377998865828, 2.005590617309376, 1.9969169278952386, 1.9877610285757972, 1.9781251449077317, 1.9680116193400115, 1.9574229106841996, 1.9463615935598955, 1.934830357815709, 1.9228320079262076, 1.9103694623653003, 1.897445752956582, 1.884064024201193, 1.8702275325838142, 1.855939645857458, 1.8412038423077963, 1.8260237099978252, 1.8104029459937485, 1.7943453555730486, 1.7778548514158186, 1.7609354527805345, 1.7435912846655737, 1.7258265769579353, 1.707645663570777, 1.6890529815715698, 1.6700530703028857, 1.6506505704980805, 1.6308502233944133, 1.6106568698464703, 1.5900754494431357, 1.5691109996317891, 1.5477686548539196, 1.5260536456969305, 1.5039712980676136, 1.481527032393575, 1.4587263628598603, 1.435574896689158, 1.4120783334752987, 1.3882424645813707, 1.3640731726156767, 1.3395764310010387, 1.3147583036557102, 1.2896249448074673, 1.2641825989664754, 1.238437601087425, 1.212396376957413, 1.1860654438534126, 1.159451411522246, 1.1325609835472557, 1.1054009591799199, 1.0779782357322947, 1.050299811648419, 1.0223727904010511, 0.9942043853962087, 0.9658019261143994, 0.9371728657775844, 0.9083247909094713, 0.8792654332601068, 0.8500026847030003, 0.8205446158969006, 0.7908994997531285, 0.761075841089452, 0.7310824143215777, 0.7009283117009031, 0.6706230055388714, 0.6401764291967095, 0.6095990835709767, 0.5789021786975146, 0.5480978244582663, 0.5171992910810566, 0.4862213706493111, 0.4551808877485387, 0.42409743523533905, 0.3929944583123118, 0.3619008925642759, 0.3308537107495656, 0.29990201328851734, 0.2691138461977139, 0.238588055646308, 0.20847591020479123, 0.1790226812450133, 0.15065207437263334, 0.12414521725603232, 0.10101549176324748, 0.08412710413871463, 0.07768384728901459, 0.08412710413872737, 0.1010154917632687, 0.12414521725605818, 0.15065207437266173, 0.17902268124504317, 0.20847591020482187, 0.23858805564633917, 0.26911384619774537, 0.29990201328854904, 0.3308537107495974, 0.3619008925643079, 0.3929944583123437, 0.42409743523537086, 0.45518088774857063, 0.48622137064934284, 0.5171992910810884, 0.548097824458298, 0.5789021786975461, 0.6095990835710081, 0.6401764291967407, 0.6706230055389024, 0.7009283117009342, 0.7310824143216086, 0.7610758410894827, 0.7908994997531591, 0.8205446158969311, 0.8500026847030306, 0.8792654332601368, 0.908324790909501, 0.9371728657776138, 0.9658019261144286, 0.9942043853962379, 1.02237279040108, 1.0502998116484477, 1.077978235732323, 1.1054009591799476, 1.1325609835472834, 1.1594514115222734, 1.1860654438534397, 1.2123963769574402, 1.2384376010874516, 1.2641825989665016, 1.2896249448074932, 1.314758303655736, 1.339576431001064, 1.3640731726157018, 1.3882424645813956, 1.412078333475323, 1.435574896689182, 1.458726362859884, 1.481527032393598, 1.5039712980676367, 1.5260536456969531, 1.5477686548539416, 1.5691109996318109, 1.5900754494431568, 1.6106568698464914, 1.6308502233944338, 1.6506505704981005, 1.6700530703029053, 1.6890529815715891, 1.707645663570796, 1.7258265769579535, 1.7435912846655917, 1.7609354527805523, 1.7778548514158357, 1.7943453555730653, 1.8104029459937647, 1.8260237099978414, 1.8412038423078116, 1.8559396458574728, 1.8702275325838287, 1.8840640242012074, 1.8974457529565956, 1.9103694623653136, 1.9228320079262202, 1.9348303578157209, 1.9463615935599066, 1.9574229106842107, 1.9680116193400221, 1.978125144907742, 1.9877610285758067, 1.9969169278952474, 2.0055906173093843, 2.0137799886582877, 2.021483051657675, 2.0286979343519254, 2.0354228835409427, 2.0416562651805834, 2.047396564756446, 2.052642387630772, 2.0573924593622888, 2.0616456259988003, 2.065400854342378, 2.0686572321870034, 2.07141396852854, 2.073670393746926, 2.0754259597604916, 2.076680240152329, 2.0774329302686376], [2.108652150085483, 2.108397813674186, 2.1076348664477407, 2.1063634944147904, 2.1045840075440925, 2.102296839696083, 2.099502548527139, 2.0962018153666135, 2.092395445066725, 2.088084365825435, 2.083269628982434, 2.077952408788411, 2.072134002147777, 2.0658158283350723, 2.058999428685273, 2.051686466258282, 2.0438787254778887, 2.035578111745526, 2.026786651029194, 2.0175064894279373, 2.0077398927123267, 1.9974892458414142, 1.9867570524566995, 1.9755459343536823, 1.9638586309316368, 1.9516979986223018, 1.9390670102982563, 1.9259687546618123, 1.9124064356153516, 1.8983833716141185, 1.8839029950025827, 1.8689688513356082, 1.853584598685779, 1.837754006938397, 1.8214809570758057, 1.804769440452901, 1.7876235580658792, 1.770047519816517, 1.7520456437745489, 1.7336223554410037, 1.7147821870157232, 1.6955297766726738, 1.6758698678471349, 1.6558073085393663, 1.635347050639979, 1.6144941492829323, 1.5932537622329088, 1.5716311493147788, 1.5496316718939651, 1.5272607924178572, 1.504524074029921, 1.481427180269993, 1.4579758748763547, 1.4341760217077286, 1.4100335848063341, 1.3855546286267368, 1.3607453184595106, 1.335611921083896, 1.3101608056898641, 1.284398445117527, 1.2583314174710125, 1.2319664081751047, 1.205310212556702, 1.178369739050067, 1.1511520131458282, 1.1236641822298077, 1.0959135214904592, 1.067907441114868, 1.039653495045424, 1.011159391635749, 0.9824330066297433, 0.9534823989977994, 0.9243158303076461, 0.8949417884953678, 0.8653690171509089, 0.8356065517642165, 0.8056637648250075, 0.7755504222767353, 0.7452767546602687, 0.714853547443023, 0.6842922566610011, 0.6536051583255766, 0.6228055434037727, 0.5919079751010079, 0.5609286325022378, 0.529885775726424, 0.49880038487446643, 0.46769705200271816, 0.4366052486842019, 0.4055611629845139, 0.374610419754654, 0.34381220562642667, 0.3132456878772784, 0.2830202841535214, 0.2532925759512772, 0.2242949587181315, 0.1963852784253082, 0.17013328589071428, 0.14646504420863626, 0.12686390153286498, 0.11348056693655068, 0.10865215008548304, 0.11348056693656039, 0.12686390153288238, 0.1464650442086588, 0.17013328589074014, 0.1963852784253362, 0.2242949587181608, 0.2532925759513074, 0.2830202841535522, 0.31324568787730955, 0.3438122056264582, 0.3746104197546858, 0.40556116298454575, 0.4366052486842338, 0.46769705200275, 0.49880038487449835, 0.5298857757264561, 0.5609286325022698, 0.5919079751010398, 0.6228055434038045, 0.6536051583256082, 0.6842922566610327, 0.7148535474430544, 0.7452767546602997, 0.7755504222767663, 0.8056637648250382, 0.8356065517642474, 0.8653690171509393, 0.894941788495398, 0.9243158303076762, 0.9534823989978292, 0.9824330066297728, 1.0111593916357786, 1.039653495045453, 1.0679074411148968, 1.0959135214904878, 1.123664182229836, 1.1511520131458564, 1.178369739050095, 1.2053102125567297, 1.231966408175132, 1.2583314174710396, 1.2843984451175536, 1.3101608056898906, 1.3356119210839221, 1.3607453184595364, 1.3855546286267624, 1.4100335848063592, 1.4341760217077533, 1.4579758748763791, 1.481427180270017, 1.5045240740299446, 1.5272607924178805, 1.549631671893988, 1.5716311493148012, 1.593253762232931, 1.6144941492829537, 1.6353470506400005, 1.6558073085393872, 1.6758698678471553, 1.6955297766726938, 1.7147821870157425, 1.7336223554410228, 1.7520456437745675, 1.7700475198165355, 1.7876235580658972, 1.8047694404529186, 1.8214809570758226, 1.8377540069384135, 1.853584598685795, 1.868968851335624, 1.883902995002598, 1.8983833716141332, 1.9124064356153658, 1.9259687546618263, 1.9390670102982699, 1.9516979986223146, 1.9638586309316488, 1.975545934353694, 1.9867570524567109, 1.997489245841425, 2.0077398927123373, 2.017506489427947, 2.026786651029203, 2.0355781117455343, 2.0438787254778967, 2.05168646625829, 2.05899942868528, 2.0658158283350794, 2.072134002147783, 2.0779524087884162, 2.0832696289824395, 2.0880843658254395, 2.0923954450667295, 2.0962018153666175, 2.0995025485271426, 2.1022968396960855, 2.1045840075440947, 2.1063634944147918, 2.1076348664477416, 2.1083978136741863], [2.139515338943932, 2.1392576932385614, 2.1384848192354404, 2.1371969062603813, 2.1353942698125525, 2.133077351498753, 2.1302467189414935, 2.12690306566099, 2.1230472109312024, 2.118680099610069, 2.113802801944153, 2.108416513347898, 2.102522554157788, 2.0961223693616877, 2.0892175283037036, 2.081809724364961, 2.073900774620698, 2.0654926194741625, 2.0565873222678337, 2.0471870688725278, 2.0372941672550464, 2.0269110470250546, 2.016040258961965, 2.004684474522675, 1.992846485331105, 1.9805292026505468, 1.9677356568399824, 1.954468996795604, 1.9407324893789268, 1.9265295188330163, 1.9118635861885123, 1.896738308661319, 1.8811574190440237, 1.8651247650933434, 1.848644308916145, 1.831720126356888, 1.8143564063896522, 1.7965574505183024, 1.7783276721887502, 1.759671596217776, 1.7405938582434164, 1.7210992042025592, 1.7011924898421267, 1.680878680271063, 1.6601628495613112, 1.6390501804070994, 1.6175459638531482, 1.5956555991039418, 1.5733845934279664, 1.550738562172901, 1.5277232289101672, 1.5043444257301128, 1.4806080937124766, 1.4565202836007756, 1.4320871567140077, 1.4073149861347174, 1.3822101582192285, 1.3567791744839828, 1.3310286539316802, 1.3049653358927649, 1.2785960834721375, 1.2519278877085012, 1.2249678725751776, 1.197723300977615, 1.170201581935416, 1.1424102791772317, 1.1143571214274537, 1.0860500147271872, 1.0574970572122062, 1.0287065568725626, 0.9996870529488595, 0.9704473417879914, 0.9409965081986251, 0.911343963630666, 0.8814994928766353, 0.8514733114886828, 0.821276136768487, 0.790919276083498, 0.7604147374852279, 0.7297753692894531, 0.6990150376242135, 0.668148854257457, 0.6371934717321694, 0.6061674696519179, 0.575091865943825, 0.5439908017647548, 0.5128924711052755, 0.481830400458039, 0.45084523734707194, 0.41998729103962656, 0.38932020448326227, 0.35892635716821447, 0.3289149599718182, 0.29943439270438094, 0.27069127185574476, 0.24298010580292917, 0.21672892723415205, 0.19256616480762503, 0.1714053652837583, 0.15450920126830833, 0.14341177530675722, 0.13951533894393164, 0.14341177530676513, 0.154509201268323, 0.17140536528377814, 0.19256616480764854, 0.21672892723417814, 0.24298010580295695, 0.27069127185577385, 0.2994343927044109, 0.3289149599718488, 0.35892635716824556, 0.38932020448329374, 0.4199872910396582, 0.45084523734710363, 0.48183040045807085, 0.5128924711053073, 0.5439908017647868, 0.575091865943857, 0.6061674696519498, 0.6371934717322014, 0.6681488542574886, 0.699015037624245, 0.7297753692894847, 0.7604147374852593, 0.7909192760835294, 0.8212761367685181, 0.8514733114887137, 0.881499492876666, 0.9113439636306966, 0.9409965081986557, 0.9704473417880215, 0.9996870529488895, 1.0287065568725924, 1.0574970572122357, 1.0860500147272163, 1.1143571214274826, 1.1424102791772603, 1.1702015819354448, 1.1977233009776431, 1.2249678725752056, 1.2519278877085287, 1.2785960834721648, 1.3049653358927917, 1.3310286539317067, 1.3567791744840088, 1.3822101582192545, 1.407314986134743, 1.432087156714033, 1.4565202836008002, 1.4806080937125012, 1.504344425730137, 1.527723228910191, 1.5507385621729244, 1.5733845934279893, 1.5956555991039645, 1.6175459638531708, 1.6390501804071211, 1.6601628495613328, 1.680878680271084, 1.701192489842147, 1.7210992042025794, 1.7405938582434362, 1.7596715962177956, 1.7783276721887689, 1.7965574505183208, 1.8143564063896704, 1.8317201263569054, 1.8486443089161624, 1.86512476509336, 1.88115741904404, 1.8967383086613347, 1.9118635861885276, 1.9265295188330311, 1.9407324893789413, 1.9544689967956177, 1.9677356568399957, 1.9805292026505597, 1.9928464853311172, 2.004684474522687, 2.0160402589619766, 2.0269110470250657, 2.037294167255057, 2.0471870688725375, 2.056587322267843, 2.065492619474171, 2.073900774620706, 2.081809724364969, 2.0892175283037107, 2.0961223693616944, 2.1025225541577943, 2.108416513347904, 2.113802801944158, 2.118680099610074, 2.123047210931207, 2.1269030656609935, 2.1302467189414966, 2.133077351498756, 2.1353942698125548, 2.1371969062603826, 2.1384848192354418, 2.139257693238562], [2.1702435557224073, 2.1699827087084027, 2.1692002319236163, 2.167896318127263, 2.1660712885431685, 2.1637255927975416, 2.1608598088319857, 2.157474642791895, 2.1535709288903986, 2.149149629248086, 2.144211833708765, 2.1387587596315623, 2.1327917516597266, 2.1263122814665225, 2.119321947478699, 2.1118224745780205, 2.103815713781457, 2.09530364190066, 2.0862883611814462, 2.07677209892407, 2.0667572070851645, 2.056246161862308, 2.0452415632622825, 2.0337461346542023, 2.0217627223087966, 2.009294294925288, 1.9963439431474357, 1.9829148790704902, 1.9690104357409806, 1.954634066651477, 1.939789345232673, 1.9244799643454213, 1.9087097357756242, 1.8924825897352067, 1.8758025743727842, 1.8586738552980324, 1.8411007151242527, 1.8230875530341553, 1.8046388843744903, 1.785759340285862, 1.7664536673748443, 1.7467267274364362, 1.7265834972359373, 1.7060290683605333, 1.6850686471522682, 1.6637075547356925, 1.6419512271553356, 1.619805215640333, 1.5972751870160544, 1.5743669242855398, 1.5510863274070206, 1.5274394142978664, 1.5034323221000996, 1.4790713087483094, 1.4543627548875082, 1.4293131661965113, 1.4039291761819723, 1.3782175495196807, 1.3521851860335183, 1.3258391254191173, 1.2991865528394324, 1.2722348055439971, 1.2449913806936228, 1.2174639446091235, 1.1896603437080469, 1.1615886174496448, 1.1332570136783457, 1.1046740068436702, 1.0758483196848612, 1.0467889491081577, 1.0175051971624818, 0.9880067082471731, 0.9583035139793269, 0.9284060875299825, 0.8983254097377418, 0.868073049966514, 0.8376612655484968, 0.8071031248249164, 0.7764126603802339, 0.745605061224826, 0.7146969156545672, 0.6837065206513355, 0.6526542795003635, 0.6215632175559157, 0.5904596579424018, 0.5593741161922382, 0.528342498088878, 0.49740772245183973, 0.46662194665945983, 0.43604965711701776, 0.40577201421351555, 0.3758930321287321, 0.34654845335457957, 0.3179185645063572, 0.29024666256414144, 0.26386520421274223, 0.23923109850637794, 0.21696804457933114, 0.19790278742326556, 0.1830582236398312, 0.17353674920945947, 0.17024355572240732, 0.17353674920946616, 0.18305822363984392, 0.19790278742328318, 0.21696804457935256, 0.23923109850640223, 0.2638652042127685, 0.29024666256416937, 0.31791856450638617, 0.3465484533546094, 0.3758930321287625, 0.4057720142135466, 0.436049657117049, 0.4666219466594914, 0.4974077224518715, 0.5283424980889099, 0.5593741161922701, 0.5904596579424338, 0.6215632175559478, 0.6526542795003955, 0.6837065206513674, 0.7146969156545989, 0.7456050612248577, 0.7764126603802655, 0.807103124824948, 0.8376612655485282, 0.8680730499665451, 0.8983254097377726, 0.9284060875300135, 0.9583035139793574, 0.9880067082472034, 1.017505197162512, 1.0467889491081876, 1.075848319684891, 1.1046740068436998, 1.1332570136783748, 1.1615886174496737, 1.1896603437080755, 1.2174639446091517, 1.2449913806936512, 1.2722348055440253, 1.29918655283946, 1.3258391254191446, 1.3521851860335452, 1.3782175495197073, 1.4039291761819985, 1.4293131661965373, 1.4543627548875337, 1.4790713087483347, 1.5034323221001247, 1.5274394142978907, 1.5510863274070448, 1.5743669242855634, 1.5972751870160777, 1.6198052156403564, 1.6419512271553582, 1.6637075547357145, 1.68506864715229, 1.7060290683605546, 1.726583497235958, 1.7467267274364568, 1.7664536673748645, 1.7857593402858818, 1.8046388843745094, 1.823087553034174, 1.841100715124271, 1.8586738552980502, 1.8758025743728015, 1.8924825897352238, 1.9087097357756406, 1.924479964345437, 1.9397893452326882, 1.954634066651492, 1.9690104357409952, 1.9829148790705042, 1.9963439431474497, 2.0092942949253016, 2.0217627223088095, 2.0337461346542147, 2.0452415632622944, 2.056246161862319, 2.0667572070851747, 2.0767720989240797, 2.0862883611814556, 2.095303641900669, 2.103815713781465, 2.111822474578028, 2.119321947478706, 2.1263122814665296, 2.132791751659733, 2.1387587596315685, 2.14421183370877, 2.1491496292480905, 2.153570928890403, 2.1574746427918985, 2.1608598088319897, 2.1637255927975443, 2.1660712885431703, 2.167896318127265, 2.169200231923618, 2.1699827087084036], [2.2008070728557274, 2.2005431303752494, 2.199751368369691, 2.1984319831350527, 2.1965853017925996, 2.194211782230849, 2.1913120130245294, 2.187886713330676, 2.1839367327621106, 2.1794630512385673, 2.174466778815823, 2.168949155493216, 2.162911551000018, 2.1563554645611864, 2.1492825246430947, 2.141694488679898, 2.133593242781303, 2.12498080142256, 2.115859307117622, 2.1062310300764904, 2.0960983678478984, 2.0854638449485865, 2.074330112480579, 2.0626999477379866, 2.050576253805059, 2.0379620591473557, 2.024860517198119, 2.0112749059421606, 1.997208627499799, 1.9826652077136688, 1.967648295741541, 1.9521616636586212, 1.936209206073183, 1.919794939759848, 1.9029230033152824, 1.8855976568416777, 1.8678232816639773, 1.8496043800875548, 1.8309455752038502, 1.8118516107524074, 1.7923273510488196, 1.7723777809893082, 1.7520080061440513, 1.7312232529530045, 1.710028869039797, 1.688430323661433, 1.6664332083140254, 1.6440432375176637, 1.621266249806887, 1.5981082089571554, 1.5745752054823166, 1.5506734584434474, 1.5264093176158202, 1.5017892660682304, 1.476819923217817, 1.4515080484340641, 1.4258605452782507, 1.3998844664796857, 1.3735870197681177, 1.3469755747034873, 1.3200576706705123, 1.292841026237551, 1.2653335501181302, 1.2375433540212182, 1.2094787677349181, 1.1811483568606678, 1.1525609437048525, 1.1237256319467808, 1.0946518358423964, 1.0653493149000948, 1.035828215189301, 1.0060991187283967, 0.9761731027652644, 0.9460618112369922, 0.9157775413101168, 0.8853333487070386, 0.8547431765837754, 0.8240220141303641, 0.7931860929456351, 0.7622531317724875, 0.7312426436231101, 0.7001763240399063, 0.6690785457504861, 0.637976994040065, 0.6069034898780823, 0.5758950657877057, 0.5449953849334982, 0.5142566301998142, 0.48374204168934254, 0.4535293540570041, 0.42371548629467287, 0.39442297127196474, 0.3658087761748523, 0.33807632234900503, 0.3114915441416717, 0.286403411318822, 0.26326774804368874, 0.24266904291522431, 0.22532658069911576, 0.21205935441839774, 0.20367911969315064, 0.2008070728557273, 0.20367911969315652, 0.21205935441840904, 0.22532658069913167, 0.24266904291524397, 0.2632677480437114, 0.28640341131884683, 0.3114915441416983, 0.33807632234903295, 0.3658087761748812, 0.3944229712719945, 0.42371548629470335, 0.453529354057035, 0.4837420416893738, 0.5142566301998457, 0.5449953849335298, 0.5758950657877373, 0.6069034898781144, 0.637976994040097, 0.6690785457505181, 0.7001763240399381, 0.7312426436231418, 0.7622531317725193, 0.793186092945667, 0.8240220141303957, 0.8547431765838068, 0.88533334870707, 0.9157775413101479, 0.9460618112370232, 0.9761731027652952, 1.0060991187284274, 1.0358282151893314, 1.065349314900125, 1.0946518358424264, 1.1237256319468105, 1.1525609437048818, 1.1811483568606969, 1.209478767734947, 1.2375433540212468, 1.2653335501181586, 1.2928410262375791, 1.3200576706705403, 1.3469755747035148, 1.3735870197681448, 1.3998844664797125, 1.425860545278277, 1.4515080484340903, 1.476819923217843, 1.5017892660682557, 1.526409317615845, 1.550673458443472, 1.574575205482341, 1.5981082089571794, 1.6212662498069108, 1.6440432375176872, 1.6664332083140485, 1.6884303236614555, 1.710028869039819, 1.7312232529530258, 1.7520080061440721, 1.772377780989329, 1.79232735104884, 1.8118516107524272, 1.8309455752038697, 1.8496043800875743, 1.867823281663996, 1.8855976568416954, 1.9029230033153, 1.919794939759865, 1.9362092060732001, 1.9521616636586374, 1.967648295741557, 1.9826652077136842, 1.997208627499814, 2.011274905942175, 2.0248605171981326, 2.037962059147369, 2.050576253805072, 2.062699947737999, 2.0743301124805904, 2.0854638449485976, 2.0960983678479086, 2.1062310300765006, 2.1158593071176313, 2.124980801422569, 2.133593242781312, 2.141694488679906, 2.149282524643102, 2.156355464561194, 2.162911551000024, 2.168949155493222, 2.174466778815829, 2.1794630512385726, 2.183936732762115, 2.18788671333068, 2.1913120130245325, 2.194211782230852, 2.196585301792601, 2.1984319831350545, 2.199751368369693, 2.2005431303752503], [2.2311763221149787, 2.2309093878481794, 2.230108651692429, 2.228774313571006, 2.226906706653874, 2.224506297304524, 2.2215736850057923, 2.2181096022648474, 2.21411491449764, 2.209590619893182, 2.204537849258062, 2.198957865841707, 2.1928520651429633, 2.186221974698663, 2.179069253854907, 2.1713956935219314, 2.163203215913477, 2.154493874271728, 2.1452698525789877, 2.135533465257391, 2.1252871568580924, 2.1145335017415268, 2.1032752037505067, 2.0915150958781075, 2.079256139932492, 2.0665014262010653, 2.053254173116592, 2.0395177269281977, 2.0252955613804837, 2.0105912774043397, 1.9954086028234261, 1.9797513920807421, 1.96362362599019, 1.9470294115185924, 1.9299729816042686, 1.9124586950189606, 1.8944910362807261, 1.8760746156263206, 1.8572141690526225, 1.8379145584378556, 1.8181807717547045, 1.7980179233889717, 1.7774312545792015, 1.756426133994738, 1.735008058472036, 1.7131826539317712, 1.6909556765024194, 1.6683330138796586, 1.6453206869551564, 1.6219248517532867, 1.5981518017200957, 1.574007970415621, 1.5494999346686562, 1.524634418262458, 1.4994182962310103, 1.4738585998586624, 1.4479625224916512, 1.42173742628876, 1.395190850060805, 1.368330518375622, 1.3411643521377619, 1.313700480891501, 1.2859472571436497, 1.2579132730610927, 1.2296073799695768, 1.20103871116841, 1.1722167086846487, 1.1431511547256665, 1.1138522087578133, 1.0843304513506185, 1.0545969361929046, 1.0246632520254455, 0.9945415966658634, 0.9642448658539029, 0.9337867603573842, 0.9031819157027018, 0.8724460600988841, 0.8415962077066035, 0.8106508964943511, 0.7796304827040629, 0.7485575076677974, 0.7174571577224346, 0.686357844741989, 0.6552919440133831, 0.6242967387378472, 0.5934156375886158, 0.5626997551336975, 0.5322099765856829, 0.5020196705486704, 0.472218268040699, 0.44291599262840553, 0.41425009772088, 0.38639301850989055, 0.35956281464054446, 0.33403602292807294, 0.3101622710177808, 0.2883782334463595, 0.26921514098045224, 0.25328902747497034, 0.24125852092663153, 0.23373826277268167, 0.23117632211497857, 0.2337382627726869, 0.24125852092664166, 0.2532890274749849, 0.26921514098047045, 0.2883782334463807, 0.31016227101780436, 0.3340360229280984, 0.35956281464057144, 0.3863930185099187, 0.4142500977209091, 0.4429159926284354, 0.47221826804072936, 0.5020196705487011, 0.5322099765857142, 0.5626997551337289, 0.5934156375886475, 0.624296738737879, 0.655291944013415, 0.6863578447420211, 0.7174571577224665, 0.7485575076678292, 0.7796304827040949, 0.8106508964943829, 0.8415962077066352, 0.8724460600989158, 0.9031819157027333, 0.9337867603574155, 0.964244865853934, 0.9945415966658944, 1.0246632520254764, 1.0545969361929353, 1.084330451350649, 1.1138522087578437, 1.1431511547256965, 1.1722167086846784, 1.2010387111684395, 1.2296073799696061, 1.2579132730611213, 1.2859472571436783, 1.3137004808915294, 1.34116435213779, 1.3683305183756496, 1.3951908500608323, 1.4217374262887872, 1.447962522491678, 1.4738585998586888, 1.4994182962310363, 1.5246344182624838, 1.5494999346686815, 1.574007970415646, 1.5981518017201204, 1.621924851753311, 1.64532068695518, 1.6683330138796821, 1.6909556765024425, 1.7131826539317936, 1.7350080584720584, 1.7564261339947598, 1.7774312545792228, 1.7980179233889926, 1.8181807717547247, 1.8379145584378755, 1.8572141690526422, 1.87607461562634, 1.8944910362807448, 1.9124586950189784, 1.9299729816042868, 1.9470294115186098, 1.963623625990207, 1.9797513920807586, 1.995408602823442, 2.0105912774043553, 2.025295561380499, 2.0395177269282123, 2.053254173116606, 2.066501426201079, 2.079256139932505, 2.09151509587812, 2.103275203750519, 2.114533501741538, 2.1252871568581035, 2.135533465257401, 2.1452698525789975, 2.1544938742717368, 2.163203215913486, 2.1713956935219394, 2.1790692538549146, 2.1862219746986695, 2.19285206514297, 2.1989578658417126, 2.2045378492580676, 2.209590619893187, 2.214114914497644, 2.218109602264851, 2.221573685005796, 2.2245062973045266, 2.2269067066538755, 2.228774313571008, 2.23010865169243, 2.2309093878481803], [2.26132192321287, 2.2610520986708, 2.2602426929238604, 2.2588939096002845, 2.257006088048565, 2.254579703289752, 2.2516153659509284, 2.248113822180138, 2.2440759535431134, 2.239502776902242, 2.2343954442782725, 2.228755242695389, 2.2225835940103447, 2.2158820547264586, 2.208652315793405, 2.2008962023937984, 2.1926156737177496, 2.1838128227266633, 2.174489875907724, 2.1646491930206397, 2.1542932668384362, 2.1434247228842214, 2.1320463191661108, 2.1201609459126827, 2.1077716253116203, 2.0948815112544605, 2.0814938890906824, 2.06761217539472, 2.0532399177498717, 2.038380794553494, 2.023038614848374, 2.007217318185694, 1.9909209745256193, 1.9741537841822352, 1.9569200778203009, 1.9392243165122003, 1.9210710918644203, 1.9024651262240393, 1.883411272976958, 1.8639145169510738, 1.8439799749392438, 1.8236128963587956, 1.802818664066483, 1.7816027953503153, 1.7599709431225388, 1.7379288973413556, 1.715482586692818, 1.692638080568744, 1.6694015913816787, 1.6457794772639212, 1.6217782452046383, 1.5974045546873052, 1.572665221899333, 1.5475672245970777, 1.52211770772281, 1.4963239898860479, 1.470193570840467, 1.4437341401099948, 1.4169535869444445, 1.3898600118171351, 1.3624617397155303, 1.3347673355225063, 1.3067856218423253, 1.2785256996940266, 1.2499969725787887, 1.2212091745305684, 1.192172402885832, 1.162897156664585, 1.1333943816491023, 1.1036755234890137, 1.0737525904649647, 1.0436382279253487, 1.013345806894299, 0.982889529964224, 0.9522845583722898, 0.9215471651700423, 0.890694920699014, 0.8597469182765402, 0.8287240502009326, 0.7976493470724071, 0.766548397221922, 0.7354498680463402, 0.704386157664881, 0.6733942140600974, 0.6425165704084265, 0.6118026604404933, 0.5813104972760792, 0.5511088240041498, 0.52127987443988, 0.4919229163099357, 0.46315878067097943, 0.43513559558293374, 0.40803590553033586, 0.38208520343554303, 0.3575615058663722, 0.33480476664540315, 0.3142234069395718, 0.2962929402914186, 0.28153915025368004, 0.2704976100432627, 0.2636463446573747, 0.2613219232128697, 0.2636463446573794, 0.270497610043272, 0.28153915025369336, 0.29629294029143555, 0.31422340693959167, 0.33480476664542547, 0.3575615058663965, 0.38208520343556907, 0.4080359055303632, 0.43513559558296205, 0.4631587806710087, 0.49192291630996554, 0.5212798744399104, 0.5511088240041806, 0.5813104972761104, 0.6118026604405247, 0.6425165704084581, 0.6733942140601292, 0.704386157664913, 0.735449868046372, 0.766548397221954, 0.7976493470724391, 0.8287240502009644, 0.8597469182765721, 0.8906949206990459, 0.921547165170074, 0.9522845583723211, 0.9828895299642553, 1.0133458068943302, 1.0436382279253797, 1.0737525904649956, 1.1036755234890445, 1.1333943816491328, 1.1628971566646151, 1.1921724028858622, 1.221209174530598, 1.249996972578818, 1.278525699694056, 1.3067856218423541, 1.3347673355225351, 1.3624617397155585, 1.3898600118171631, 1.4169535869444718, 1.4437341401100223, 1.4701935708404943, 1.4963239898860747, 1.5221177077228365, 1.5475672245971042, 1.5726652218993586, 1.5974045546873306, 1.621778245204663, 1.6457794772639456, 1.6694015913817026, 1.6926380805687675, 1.7154825866928418, 1.7379288973413785, 1.7599709431225612, 1.7816027953503375, 1.8028186640665043, 1.8236128963588172, 1.8439799749392647, 1.8639145169510938, 1.8834112729769779, 1.902465126224059, 1.921071091864439, 1.9392243165122185, 1.956920077820319, 1.9741537841822525, 1.9909209745256364, 2.0072173181857105, 2.0230386148483905, 2.0383807945535097, 2.0532399177498872, 2.0676121753947347, 2.0814938890906967, 2.094881511254474, 2.107771625311633, 2.120160945912695, 2.132046319166123, 2.1434247228842334, 2.1542932668384474, 2.1646491930206504, 2.1744898759077333, 2.1838128227266727, 2.1926156737177585, 2.200896202393807, 2.2086523157934126, 2.2158820547264657, 2.222583594010351, 2.228755242695395, 2.234395444278278, 2.239502776902247, 2.2440759535431183, 2.2481138221801418, 2.251615365950932, 2.254579703289755, 2.2570060880485667, 2.258893909600286, 2.2602426929238617, 2.2610520986708007], [2.2912147122272613, 2.290942096755034, 2.290124319473878, 2.288761587781978, 2.286854247315029, 2.2844027819044856, 2.281407813519423, 2.2778701021923284, 2.2737905459292462, 2.2691701806047897, 2.264010179842625, 2.2583118548821752, 2.2520766544323556, 2.245306164513325, 2.2380021082873265, 2.2301663458798484, 2.22180087419248, 2.212907826709002, 2.2034894732964108, 2.193548220002782, 2.183086608854084, 2.172107317652262, 2.160613159777181, 2.1486070839952895, 2.1360921742781485, 2.123071649634343, 2.1095488639586177, 2.095527305902547, 2.0810105987714564, 2.066002500452881, 2.050506903382377, 2.0345278345531796, 2.018069455576916, 2.001136062803399, 1.9837320875084494, 1.9658620961597324, 1.9475307907717818, 1.9287430093627091, 1.9095037265266093, 1.8898180541374194, 1.8696912422019287, 1.8491286798819127, 1.8281358967079144, 1.8067185640101742, 1.7848824965955887, 1.7626336547034938, 1.7399781462776025, 1.7169222295966373, 1.6934723163122776, 1.6696349749501, 1.645416934937405, 1.6208250912314415, 1.5958665096328057, 1.5705484328820125, 1.5448782876528262, 1.5188636925743448, 1.4925124674356396, 1.465832643752661, 1.4388324769080072, 1.4115204601110707, 1.3839053404703636, 1.355996137523122, 1.3278021646316427, 1.2993330537338033, 1.270598784030073, 1.2416097153051187, 1.2123766267240081, 1.1829107621175787, 1.153223882987138, 1.1233283307260231, 1.0932370998884802, 1.0629639247525946, 1.032523381946708, 1.0019310125677765, 0.9712034680544751, 0.9403586851383525, 0.909416096549395, 0.8783968858846675, 0.8473242972731818, 0.8162240133332862, 0.7851246186088728, 0.7540581704260013, 0.7230609052264285, 0.6921741162569892, 0.6614452484025252, 0.6309292682874762, 0.6006903826840958, 0.5708041953645064, 0.5413604102099654, 0.5124662025002339, 0.48425038176843244, 0.45686844026832113, 0.4305084872546344, 0.40539785320969157, 0.381809721828243, 0.3600684026081358, 0.34055072481393606, 0.32367965286910666, 0.30990524428923755, 0.29966892981849, 0.2933516242666895, 0.29121471222726114, 0.2933516242666939, 0.29966892981849863, 0.30990524428925, 0.3236796528691226, 0.34055072481395493, 0.36006840260815703, 0.3818097218282664, 0.40539785320971666, 0.4305084872546609, 0.4568684402683488, 0.48425038176846114, 0.5124662025002632, 0.5413604102099954, 0.570804195364537, 0.6006903826841267, 0.6309292682875075, 0.6614452484025567, 0.6921741162570209, 0.7230609052264604, 0.7540581704260331, 0.7851246186089047, 0.8162240133333182, 0.8473242972732138, 0.8783968858846994, 0.9094160965494269, 0.9403586851383843, 0.9712034680545067, 1.0019310125678078, 1.0325233819467394, 1.0629639247526257, 1.0932370998885113, 1.1233283307260542, 1.1532238829871686, 1.1829107621176094, 1.2123766267240383, 1.2416097153051486, 1.2705987840301027, 1.2993330537338326, 1.3278021646316718, 1.355996137523151, 1.3839053404703923, 1.4115204601110989, 1.4388324769080352, 1.4658326437526885, 1.492512467435667, 1.5188636925743717, 1.5448782876528528, 1.5705484328820387, 1.5958665096328315, 1.6208250912314668, 1.6454169349374304, 1.669634974950125, 1.6934723163123018, 1.7169222295966613, 1.7399781462776265, 1.7626336547035169, 1.7848824965956116, 1.8067185640101961, 1.8281358967079355, 1.8491286798819337, 1.8696912422019498, 1.8898180541374399, 1.9095037265266295, 1.928743009362729, 1.947530790771801, 1.9658620961597504, 1.9837320875084674, 2.001136062803417, 2.0180694555769327, 2.034527834553196, 2.050506903382393, 2.066002500452897, 2.0810105987714715, 2.0955273059025616, 2.1095488639586324, 2.123071649634357, 2.1360921742781613, 2.1486070839953015, 2.1606131597771934, 2.172107317652274, 2.1830866088540954, 2.1935482200027923, 2.2034894732964205, 2.2129078267090114, 2.2218008741924886, 2.2301663458798564, 2.2380021082873345, 2.245306164513333, 2.2520766544323623, 2.2583118548821814, 2.264010179842631, 2.2691701806047946, 2.273790545929251, 2.277870102192332, 2.2814078135194267, 2.2844027819044888, 2.286854247315031, 2.28876158778198, 2.29012431947388, 2.290942096755035], [2.320825769815377, 2.320550460604341, 2.3197246033805023, 2.318348409364541, 2.316422230567226, 2.3139465597540583, 2.31092203039613, 2.3073494166075963, 2.3032296330702167, 2.298563734945596, 2.293352917775822, 2.2875985173733615, 2.281302009701192, 2.2744650107442883, 2.2670892763737416, 2.2591767022049347, 2.2507293234513996, 2.241749314776133, 2.2322389901423794, 2.222200802666105, 2.2116373444726176, 2.200551346560068, 2.188945678672853, 2.176823349188259, 2.164187505020045, 2.1510414315430615, 2.137388552543413, 2.1232324301992014, 2.108576765097376, 2.0934253962928553, 2.077782301416744, 2.0616515968412332, 2.045037537909592, 2.027944519240662, 2.010377075118281, 1.9923398799773204, 1.973837748999367, 1.9548756388326374, 1.9354586484524723, 1.9155920201807728, 1.8952811408850019, 1.8745315433800023, 1.8533489080588386, 1.831739064782304, 1.8097079950606445, 1.7872618345655604, 1.7644068760157574, 1.7411495724853303, 1.7174965411912206, 1.6934545678240864, 1.6690306114963276, 1.644231810391989, 1.6190654882161064, 1.5935391615560996, 1.5676605482855255, 1.5414375771613456, 1.5148783987905008, 1.4879913981708046, 1.460785209045866, 1.4332687303551404, 1.4054511451096803, 1.3773419420835082, 1.3489509407819367, 1.3202883202343552, 1.2913646522634166, 1.2621909400094102, 1.2327786626433332, 1.2031398273914777, 1.1732870302268277, 1.1432335268690308, 1.1129933160889711, 1.082581237753578, 1.0520130885938803, 1.02130575936309, 0.9904773979082644, 0.9595476037555971, 0.9285376611650779, 0.897470819320521, 0.8663726304804124, 0.8352713596407944, 0.8041984826952927, 0.7731892943845313, 0.7422836526873406, 0.7115268928894211, 0.6809709524770375, 0.650675757173072, 0.6207109283967724, 0.5911578819299743, 0.5621123938472904, 0.533687707325223, 0.5060182326042711, 0.4792638343813113, 0.45361457737787175, 0.42929556923405304, 0.4065711476449631, 0.3857470645987922, 0.36716855396278025, 0.35121144364999973, 0.3382633311691722, 0.3286931591742262, 0.32281107199993037, 0.3208257698153768, 0.3228110719999345, 0.32869315917423414, 0.3382633311691838, 0.35121144365001467, 0.3671685539627981, 0.38574706459881253, 0.40657114764498553, 0.42929556923407725, 0.4536145773778974, 0.47926383438133824, 0.5060182326042992, 0.5336877073252518, 0.5621123938473199, 0.5911578819300044, 0.620710928396803, 0.650675757173103, 0.6809709524770687, 0.7115268928894525, 0.7422836526873724, 0.7731892943845631, 0.8041984826953246, 0.8352713596408263, 0.8663726304804443, 0.897470819320553, 0.9285376611651098, 0.9595476037556291, 0.990477397908296, 1.0213057593631216, 1.0520130885939118, 1.0825812377536093, 1.1129933160890024, 1.1432335268690617, 1.1732870302268583, 1.2031398273915084, 1.2327786626433637, 1.2621909400094402, 1.2913646522634463, 1.3202883202343847, 1.3489509407819662, 1.3773419420835373, 1.405451145109709, 1.4332687303551688, 1.4607852090458942, 1.4879913981708324, 1.5148783987905283, 1.5414375771613729, 1.5676605482855526, 1.5935391615561258, 1.6190654882161326, 1.6442318103920148, 1.6690306114963527, 1.693454567824111, 1.7174965411912453, 1.7411495724853545, 1.7644068760157814, 1.7872618345655837, 1.8097079950606678, 1.8317390647823262, 1.8533489080588603, 1.874531543380024, 1.895281140885023, 1.9155920201807932, 1.9354586484524927, 1.9548756388326574, 1.9738377489993864, 1.9923398799773386, 2.010377075118299, 2.0279445192406804, 2.04503753790961, 2.06165159684125, 2.0777823014167605, 2.093425396292871, 2.1085767650973914, 2.1232324301992165, 2.1373885525434275, 2.1510414315430757, 2.1641875050200587, 2.1768233491882714, 2.1889456786728654, 2.20055134656008, 2.2116373444726287, 2.2222008026661153, 2.2322389901423896, 2.241749314776142, 2.2507293234514085, 2.259176702204943, 2.267089276373749, 2.2744650107442963, 2.2813020097011987, 2.2875985173733677, 2.2933529177758274, 2.298563734945601, 2.3032296330702215, 2.3073494166076, 2.3109220303961338, 2.313946559754061, 2.316422230567228, 2.3183484093645426, 2.3197246033805037, 2.3205504606043417], [2.3501264491914, 2.3498485412991874, 2.349014889318994, 2.347625708334373, 2.345681356798712, 2.343182336506647, 2.3401292925544617, 2.3365230132899097, 2.33236443025201, 2.327654618101516, 2.322394794542876, 2.3165863202386654, 2.3102306987176227, 2.3033295762775663, 2.29588474188467, 2.2878981270707315, 2.279371805830295, 2.2703079945196882, 2.2607090517602617, 2.2505774783484047, 2.239915917175157, 2.2287271531585513, 2.2170141131921692, 2.204779866113753, 2.1920276226981072, 2.178760735679019, 2.1649826998053676, 2.1506971519372087, 2.1359078711881847, 2.120618779121352, 2.1048339400062437, 2.0885575611458798, 2.0717939932833986, 2.0545477310990643, 2.0368234138096453, 2.018625825883527, 1.9999598978865014, 1.9808307074749312, 1.9612434805549912, 1.941203592628989, 1.9207165703523257, 1.899788093327651, 1.8784239961661093, 1.8566302708494717, 1.8344130694313587, 1.8117787071208666, 1.7887336657977746, 1.765284598015284, 1.74143833155407, 1.7172018746005042, 1.6925824216324556, 1.6675873601083466, 1.6422242780694805, 1.6165009727824133, 1.5904254605678094, 1.5640059879853299, 1.5372510445713654, 1.5101693773586238, 1.4827700074447592, 1.4550622489225877, 1.4270557305385108, 1.3987604205103579, 1.3701866550133313, 1.3413451709358255, 1.3122471436191736, 1.2829042304311458, 1.253328621187742, 1.2235330966382316, 1.1935310964729842, 1.1633367986130014, 1.1329652119075386, 1.1024322848184887, 1.0717550332282968, 1.0409516911983379, 1.0100418893597942, 0.9790468666799272, 0.9479897226635657, 0.9168957186838694, 0.8857926391609663, 0.8547112258061589, 0.8236857012150388, 0.7927544018154079, 0.7619605446237143, 0.7313531574428002, 0.7009882079124623, 0.6709299727976629, 0.6412526941530742, 0.6120425717166246, 0.5834001376905427, 0.5554430450685516, 0.528309264063598, 0.5021606076670052, 0.47718637495535, 0.45360668216810984, 0.4316747224230146, 0.41167675637677276, 0.39392816032317246, 0.3787635541855952, 0.3665192916885639, 0.3575079123180733, 0.35198677612438073, 0.3501264491913999, 0.35198677612438456, 0.35750791231808077, 0.3665192916885749, 0.37876355418560936, 0.3939281603231895, 0.41167675637679224, 0.43167472242303623, 0.45360668216813327, 0.477186374955375, 0.5021606076670315, 0.5283092640636254, 0.5554430450685799, 0.5834001376905718, 0.6120425717166542, 0.6412526941531044, 0.6709299727976936, 0.7009882079124933, 0.7313531574428316, 0.7619605446237459, 0.7927544018154397, 0.8236857012150706, 0.8547112258061909, 0.8857926391609983, 0.9168957186839014, 0.9479897226635976, 0.979046866679959, 1.010041889359826, 1.0409516911983694, 1.0717550332283283, 1.10243228481852, 1.13296521190757, 1.1633367986130327, 1.193531096473015, 1.2235330966382625, 1.2533286211877726, 1.282904230431176, 1.3122471436192036, 1.3413451709358553, 1.3701866550133608, 1.3987604205103872, 1.4270557305385398, 1.4550622489226164, 1.4827700074447874, 1.5101693773586518, 1.537251044571393, 1.5640059879853572, 1.5904254605678365, 1.61650097278244, 1.6422242780695064, 1.6675873601083724, 1.692582421632481, 1.7172018746005295, 1.7414383315540949, 1.7652845980153085, 1.7887336657977986, 1.81177870712089, 1.8344130694313818, 1.8566302708494942, 1.878423996166131, 1.8997880933276725, 1.920716570352347, 1.9412035926290094, 1.9612434805550116, 1.9808307074749512, 1.999959897886521, 2.0186258258835457, 2.0368234138096635, 2.0545477310990825, 2.0717939932834164, 2.0885575611458966, 2.10483394000626, 2.120618779121368, 2.1359078711882002, 2.1506971519372238, 2.1649826998053827, 2.1787607356790333, 2.1920276226981206, 2.204779866113766, 2.2170141131921817, 2.228727153158563, 2.2399159171751686, 2.2505774783484154, 2.2607090517602715, 2.2703079945196976, 2.2793718058303045, 2.2878981270707395, 2.2958847418846777, 2.3033295762775743, 2.3102306987176293, 2.3165863202386716, 2.3223947945428813, 2.3276546181015214, 2.332364430252015, 2.3365230132899133, 2.3401292925544657, 2.34318233650665, 2.345681356798714, 2.347625708334374, 2.3490148893189953, 2.3498485412991883], [2.3790884038403886, 2.378807990217812, 2.377966822343191, 2.376565119191491, 2.3746032457064876, 2.372081712779275, 2.3690011772186437, 2.365362441713837, 2.361166454790294, 2.356414310759198, 2.3511072496617227, 2.3452466572091293, 2.338834064719954, 2.3318711490557695, 2.3243597325571685, 2.3163017829818457, 2.307699413446863, 2.2985548823774473, 2.2888705934649187, 2.278649095636648, 2.2678930830412507, 2.2566053950525666, 2.2447890162963726, 2.232447076704166, 2.2195828515988403, 2.2061997618175706, 2.1923013738778017, 2.177891400192847, 2.1629736993443145, 2.147552276419362, 2.13163128342162, 2.1152150197656447, 2.0983079328658043, 2.0809146188317698, 2.06303982328412, 2.04468844230516, 2.0258655235417793, 2.006576267479171, 1.9868260289064752, 1.9666203185979574, 1.9459648052362335, 1.9248653176073516, 1.903327847101298, 1.881358550555811, 1.8589637534863122, 1.8361499537504122, 1.8129238257019684, 1.7892922248971566, 1.7652621934236743, 1.7408409659342123, 1.7160359764769308, 1.6908548662291754, 1.665305492256377, 1.6393959374364253, 1.6131345217112552, 1.5865298148525782, 1.5595906509582496, 1.5323261449306733, 1.5047457112298264, 1.4768590852423111, 1.4486763476658155, 1.4202079523773716, 1.3914647583362252, 1.3624580661707524, 1.3331996602172453, 1.3037018569208276, 1.2739775606806114, 1.2440403284290464, 1.2139044444873963, 1.1835850075454908, 1.1530980319868078, 1.1224605662348774, 1.0916908313529257, 1.0608083838086857, 1.0298343071485183, 0.9987914383431258, 0.967704635811012, 0.9366010976410354, 0.9055107403720049, 0.8744666508959609, 0.8435056266757709, 0.8126688225271637, 0.7820025256789912, 0.7515590845606146, 0.7213980204525368, 0.6915873541289226, 0.6622051807175503, 0.6333415230985651, 0.6051004837342058, 0.5776026912329811, 0.5509879926672183, 0.5254182636739393, 0.5010800806890082, 0.4781868086711316, 0.45697939837984863, 0.4377248834036417, 0.42071130138397445, 0.4062377095916518, 0.394598385014931, 0.386061449835492, 0.3808440584937032, 0.37908840384038855, 0.38084405849370684, 0.3860614498354991, 0.39459838501494143, 0.4062377095916653, 0.42071130138399077, 0.43772488340366034, 0.4569793983798695, 0.4781868086711544, 0.5010800806890326, 0.5254182636739649, 0.5509879926672453, 0.577602691233009, 0.6051004837342343, 0.6333415230985944, 0.6622051807175802, 0.6915873541289531, 0.7213980204525676, 0.7515590845606458, 0.7820025256790226, 0.8126688225271953, 0.8435056266758026, 0.8744666508959927, 0.9055107403720367, 0.9366010976410672, 0.9677046358110439, 0.9987914383431576, 1.0298343071485503, 1.0608083838087177, 1.0916908313529574, 1.122460566234909, 1.1530980319868396, 1.183585007545522, 1.2139044444874274, 1.2440403284290775, 1.2739775606806423, 1.303701856920858, 1.3331996602172755, 1.3624580661707824, 1.3914647583362547, 1.4202079523774012, 1.4486763476658446, 1.4768590852423402, 1.5047457112298548, 1.5323261449307017, 1.5595906509582773, 1.5865298148526057, 1.6131345217112825, 1.639395937436452, 1.6653054922564037, 1.6908548662292016, 1.7160359764769566, 1.7408409659342376, 1.7652621934236992, 1.7892922248971812, 1.8129238257019928, 1.836149953750436, 1.8589637534863355, 1.881358550555834, 1.9033278471013204, 1.924865317607374, 1.9459648052362553, 1.9666203185979783, 1.9868260289064956, 2.006576267479191, 2.025865523541799, 2.044688442305179, 2.0630398232841385, 2.080914618831788, 2.098307932865822, 2.115215019765661, 2.131631283421637, 2.147552276419378, 2.1629736993443305, 2.1778914001928618, 2.192301373877817, 2.2061997618175853, 2.219582851598854, 2.232447076704179, 2.244789016296385, 2.256605395052578, 2.2678930830412622, 2.278649095636659, 2.288870593464929, 2.2985548823774566, 2.3076994134468722, 2.3163017829818546, 2.324359732557176, 2.331871149055777, 2.3388340647199612, 2.3452466572091355, 2.3511072496617285, 2.3564143107592033, 2.361166454790299, 2.365362441713841, 2.369001177218648, 2.3720817127792775, 2.3746032457064894, 2.376565119191493, 2.377966822343193, 2.3788079902178123], [2.407683614941698, 2.407400786465576, 2.4065523753326565, 2.405138604426379, 2.4031598452095264, 2.400616617710072, 2.3975095905019073, 2.393839580680991, 2.3896075538376276, 2.384814624025757, 2.379462053730303, 2.3735512538338144, 2.3670837835838396, 2.3600613505626558, 2.3524858106612228, 2.34435916805945, 2.335683575215107, 2.326461332864022, 2.3166948900344577, 2.3063868440789177, 2.29553994072697, 2.2841570741630584, 2.272241287133707, 2.259795771088987, 2.2468238663636106, 2.233329062403616, 2.2193149980452156, 2.2047854618530756, 2.189744392526095, 2.1741958793795964, 2.1581441629138087, 2.1415936354796234, 2.124548842053792, 2.107014481137106, 2.088995405790621, 2.0704966248267094, 2.0515233041736702, 2.032080768434794, 2.012174502665293, 1.991810154393281, 1.9709935359142121, 1.9497306268917862, 1.9280275773024882, 1.9058907107656413, 1.8833265283062588, 1.860341712604159, 1.8369431327899355, 1.8131378498565196, 1.7889331227645262, 1.7643364153304235, 1.7393554039991856, 1.7139979866176733, 1.688272292341967, 1.6621866928316353, 1.6357498149070002, 1.6089705548724336, 1.58185809474037, 1.554421920627892, 1.5266718436415365, 1.4986180236176625, 1.4702709961468914, 1.441641703383681, 1.412741529228339, 1.3835823395715536, 1.3541765284142497, 1.3245370708224669, 1.2946775838531452, 1.2646123967984397, 1.2343566323510993, 1.2039263006008745, 1.1733384081431013, 1.1426110850292297, 1.1117637328314867, 1.0808171977495273, 1.0497939734785782, 1.0187184395122073, 0.987617141697129, 0.9565191232220615, 0.9254563158350347, 0.8944640029624333, 0.8635813685469855, 0.8328521477896573, 0.8023253984577065, 0.7720564137670652, 0.742107799608109, 0.7125507392607264, 0.6834664663948319, 0.6549479599084516, 0.6271018586569576, 0.6000505654068261, 0.5739344605219003, 0.5489140683278294, 0.5251719038405691, 0.502913569306688, 0.48236747559894755, 0.4637823659886404, 0.4474216963055106, 0.433554008081084, 0.4224388867618337, 0.41430904447211747, 0.40935042796555193, 0.4076836149416981, 0.4093504279655554, 0.4143090444721242, 0.42243888676184366, 0.43355400808109684, 0.44742169630552625, 0.46378236598865835, 0.4823674755989677, 0.5029135693067099, 0.5251719038405926, 0.5489140683278545, 0.5739344605219266, 0.6000505654068534, 0.6271018586569858, 0.6549479599084804, 0.6834664663948614, 0.7125507392607566, 0.7421077996081396, 0.7720564137670963, 0.8023253984577376, 0.8328521477896889, 0.8635813685470173, 0.8944640029624651, 0.9254563158350666, 0.9565191232220934, 0.9876171416971611, 1.0187184395122393, 1.04979397347861, 1.0808171977495593, 1.1117637328315184, 1.1426110850292612, 1.1733384081431326, 1.2039263006009058, 1.2343566323511304, 1.2646123967984708, 1.2946775838531763, 1.3245370708224973, 1.35417652841428, 1.3835823395715836, 1.4127415292283687, 1.4416417033837106, 1.4702709961469207, 1.4986180236176914, 1.5266718436415654, 1.5544219206279202, 1.5818580947403977, 1.6089705548724613, 1.6357498149070273, 1.6621866928316622, 1.6882722923419935, 1.7139979866176995, 1.7393554039992114, 1.764336415330449, 1.7889331227645513, 1.8131378498565442, 1.8369431327899597, 1.860341712604183, 1.8833265283062823, 1.9058907107656644, 1.9280275773025106, 1.9497306268918082, 1.9709935359142339, 1.991810154393302, 2.0121745026653133, 2.0320807684348146, 2.0515233041736898, 2.0704966248267285, 2.0889954057906395, 2.1070144811371243, 2.12454884205381, 2.1415936354796403, 2.158144162913825, 2.1741958793796132, 2.1897443925261113, 2.20478546185309, 2.2193149980452302, 2.2333290624036306, 2.246823866363624, 2.2597957710889998, 2.272241287133719, 2.28415707416307, 2.295539940726982, 2.306386844078929, 2.316694890034468, 2.3264613328640316, 2.3356835752151164, 2.344359168059459, 2.352485810661231, 2.360061350562663, 2.3670837835838463, 2.3735512538338206, 2.379462053730309, 2.384814624025762, 2.3896075538376316, 2.3938395806809956, 2.397509590501911, 2.4006166177100754, 2.403159845209529, 2.405138604426381, 2.406552375332658, 2.407400786465576], [2.4358844184753803, 2.435599263986462, 2.434743876119476, 2.4333184816723343, 2.431323458636951, 2.428759336192647, 2.425626794697497, 2.4219266656782485, 2.417659931819578, 2.4128277269536667, 2.4074313360512543, 2.4014721952155424, 2.394951891680537, 2.387872163815631, 2.380234901138495, 2.3720421443385824, 2.3632960853138494, 2.3539990672235853, 2.344153584560587, 2.333762283246245, 2.3228279607525306, 2.3113535662552733, 2.2993422008235904, 2.2867971176508592, 2.27372172233317, 2.2601195732018295, 2.245994381717198, 2.2313500129318657, 2.2161904860320907, 2.2005199749673183, 2.18434280917869, 2.167663474438636, 2.1504866138149716, 2.1328170287743906, 2.114659680441946, 2.096019691034975, 2.076902345492041, 2.0573130933198622, 2.037257550683902, 2.0167415027713456, 1.9957709064586735, 1.9743518933199748, 1.9524907730166348, 1.9301940371141504, 1.9074683633776774, 1.8843206206045817, 1.8607578740599597, 1.8367873915898711, 1.8124166504971668, 1.7876533452764725, 1.7625053963183606, 1.7369809597083599, 1.7110884382645317, 1.6848364939783762, 1.6582340620482965, 1.631290366723403, 1.604014939208822, 1.5764176379227688, 1.5485086714415568, 1.520298624522703, 1.4917984876599617, 1.4630196906992894, 1.4339741411337565, 1.4046742678009547, 1.3751330708318301, 1.3453641788491246, 1.3153819145914882, 1.2852013703517007, 1.2548384948712337, 1.2243101936369472, 1.193634444888947, 1.1628304340831794, 1.131918710071778, 1.1009213668839255, 1.0698622557271993, 1.0387672327020674, 1.0076644487480484, 0.9765846895333842, 0.9455617743672035, 0.9146330247440565, 0.8838398147853288, 0.853228217528566, 0.8228497625557228, 0.7927623215267533, 0.7630311382579532, 0.7337300181817398, 0.7049426869770062, 0.6767643177967955, 0.6493032078429932, 0.6226825539362444, 0.5970422280269547, 0.5725403816668492, 0.5493546090498836, 0.5276822723144149, 0.5077394533787926, 0.4897578782279066, 0.4739791274917155, 0.4606455968772624, 0.4499881033900844, 0.4422107915230808, 0.43747497266628754, 0.43588441847538034, 0.43747497266629076, 0.44221079152308734, 0.44998810339009393, 0.46064559687727485, 0.47397912749173055, 0.48975787822792394, 0.507739453378812, 0.5276822723144363, 0.5493546090499067, 0.5725403816668737, 0.5970422280269806, 0.6226825539362711, 0.649303207843021, 0.6767643177968239, 0.7049426869770353, 0.7337300181817696, 0.7630311382579834, 0.792762321526784, 0.8228497625557539, 0.8532282175285973, 0.8838398147853603, 0.9146330247440881, 0.9455617743672352, 0.976584689533416, 1.0076644487480804, 1.0387672327020994, 1.0698622557272315, 1.1009213668839575, 1.1319187100718098, 1.1628304340832114, 1.1936344448889786, 1.2243101936369787, 1.2548384948712648, 1.2852013703517318, 1.315381914591519, 1.3453641788491553, 1.3751330708318603, 1.4046742678009847, 1.4339741411337865, 1.463019690699319, 1.4917984876599912, 1.520298624522732, 1.5485086714415854, 1.5764176379227974, 1.6040149392088503, 1.6312903667234313, 1.658234062048324, 1.6848364939784035, 1.7110884382645584, 1.7369809597083863, 1.7625053963183865, 1.7876533452764978, 1.812416650497192, 1.836787391589896, 1.8607578740599842, 1.8843206206046055, 1.9074683633777008, 1.9301940371141735, 1.9524907730166572, 1.974351893319997, 1.9957709064586948, 2.0167415027713664, 2.0372575506839223, 2.057313093319883, 2.0769023454920608, 2.096019691034994, 2.1146596804419646, 2.132817028774409, 2.1504866138149903, 2.167663474438654, 2.1843428091787067, 2.200519974967335, 2.216190486032107, 2.2313500129318804, 2.245994381717213, 2.260119573201844, 2.2737217223331836, 2.2867971176508726, 2.2993422008236024, 2.3113535662552853, 2.3228279607525426, 2.3337622832462555, 2.3441535845605976, 2.3539990672235955, 2.3632960853138587, 2.3720421443385913, 2.3802349011385027, 2.3878721638156386, 2.394951891680544, 2.401472195215549, 2.40743133605126, 2.4128277269536724, 2.4176599318195824, 2.421926665678253, 2.4256267946975005, 2.4287593361926496, 2.4313234586369536, 2.4333184816723357, 2.4347438761194766, 2.435599263986462], [2.4636635319853366, 2.4633761383305792, 2.462514034268843, 2.4610774505078568, 2.4590667715610195, 2.456482535748495, 2.4533254351994076, 2.449596315855794, 2.4452961774791744, 2.4404261736608057, 2.4349876118369003, 2.4289819533103096, 2.4224108132804094, 2.415275960883181, 2.407579319243734, 2.3993229655438193, 2.3905091311071764, 2.3811402015058856, 2.371218716691274, 2.3607473711532942, 2.349729014112727, 2.338166649751035, 2.3260634374831857, 2.3134226922793424, 2.300247885041924, 2.2865426430452347, 2.2723107504456, 2.2575561488708034, 2.2422829380985387, 2.2264953768346154, 2.2101978836028473, 2.1933950377597977, 2.1760915806490173, 2.1582924169110416, 2.140002615967184, 2.1212274136972344, 2.101972214333445, 2.082242592595776, 2.0620442960962695, 2.0413832480437586, 2.020265550283805, 1.9986974867130438, 1.9766855271118986, 1.9542363314451308, 1.9313567546859502, 1.908053852226542, 1.8843348859460614, 1.860207331016514, 1.8356788835377065, 1.8107574691048531, 1.7854512524266777, 1.7597686481283674, 1.7337183328927803, 1.7073092591154344, 1.6805506702744646, 1.6534521182466029, 1.6260234828350382, 1.5982749938156728, 1.5702172558558294, 1.5418612767152209, 1.5132184992044266, 1.4843008374531128, 1.4551207181309227, 1.4256911273709942, 1.39602566427253, 1.3661386020084825, 1.3360449577416482, 1.305760572762537, 1.2753022045114772, 1.2446876324427756, 1.2139357800387294, 1.183066855695415, 1.1521025156910418, 1.121066053022626, 1.0899826165692597, 1.0588794658207807, 1.027786267306224, 0.9967354398674223, 0.9657625570369504, 0.9349068159615991, 0.9042115834911496, 0.8737250310963881, 0.8435008709659785, 0.813599205592374, 0.7840875018134568, 0.7550416967431474, 0.7265474359885744, 0.6987014321421134, 0.671612911212544, 0.6454050832072113, 0.6202165268842789, 0.5962023145949659, 0.5735346202617995, 0.5524024566684206, 0.5330100928437382, 0.5155736404542124, 0.5003153218623412, 0.48745510842747347, 0.47719980336262063, 0.46973024253987106, 0.46518799514938153, 0.46366353198533655, 0.4651879951493847, 0.4697302425398772, 0.47719980336262985, 0.48745510842748546, 0.5003153218623557, 0.5155736404542292, 0.5330100928437572, 0.5524024566684415, 0.5735346202618219, 0.5962023145949897, 0.6202165268843043, 0.6454050832072379, 0.6716129112125714, 0.6987014321421418, 0.7265474359886034, 0.755041696743177, 0.784087501813487, 0.8135992055924044, 0.8435008709660095, 0.8737250310964192, 0.9042115834911809, 0.9349068159616306, 0.9657625570369821, 0.9967354398674542, 1.0277862673062559, 1.0588794658208127, 1.0899826165692919, 1.121066053022658, 1.1521025156910738, 1.1830668556954465, 1.2139357800387611, 1.2446876324428071, 1.2753022045115088, 1.3057605727625683, 1.3360449577416793, 1.3661386020085133, 1.3960256642725608, 1.4256911273710247, 1.455120718130953, 1.4843008374531428, 1.5132184992044564, 1.54186127671525, 1.5702172558558585, 1.5982749938157015, 1.6260234828350666, 1.6534521182466306, 1.6805506702744923, 1.7073092591154615, 1.7337183328928072, 1.759768648128394, 1.7854512524267039, 1.810757469104879, 1.835678883537732, 1.8602073310165388, 1.8843348859460862, 1.908053852226566, 1.931356754685974, 1.954236331445154, 1.9766855271119215, 1.9986974867130662, 2.0202655502838267, 2.04138324804378, 2.0620442960962904, 2.0822425925957964, 2.1019722143334656, 2.121227413697253, 2.140002615967203, 2.1582924169110607, 2.1760915806490355, 2.193395037759815, 2.210197883602865, 2.2264953768346314, 2.2422829380985543, 2.2575561488708193, 2.272310750445615, 2.2865426430452493, 2.300247885041938, 2.3134226922793557, 2.3260634374831985, 2.3381666497510474, 2.349729014112739, 2.360747371153305, 2.371218716691285, 2.3811402015058953, 2.3905091311071858, 2.399322965543828, 2.407579319243742, 2.415275960883189, 2.422410813280417, 2.428981953310316, 2.4349876118369065, 2.440426173660811, 2.4452961774791793, 2.449596315855798, 2.453325435199411, 2.456482535748498, 2.4590667715610217, 2.4610774505078585, 2.462514034268844, 2.46337613833058], [2.4909940809733313, 2.4907045330518747, 2.4898359674878416, 2.488388618883923, 2.486362878250302, 2.4837592930135575, 2.480578567029841, 2.4768215606030535, 2.472489290508953, 2.467582930026355, 2.4621038089768197, 2.456053413774456, 2.449433387487738, 2.4422455299154966, 2.434491797679533, 2.426174304336628, 2.417295320513029, 2.407857274064881, 2.3978627502684398, 2.3873144920443345, 2.376215400220615, 2.364568533839808, 2.3523771105157776, 2.3396445068467777, 2.326374258891762, 2.312570062717753, 2.2982357750268836, 2.283375413872642, 2.2679931594758345, 2.252093355151921, 2.235680508362594, 2.2187592919058887, 2.2013345452606305, 2.1834112761027917, 2.16499466201324, 2.146090052398575, 2.1267029706491822, 2.1068391165614027, 2.086504369053839, 2.0657047892113334, 2.0444466236941334, 2.0227363085542955, 2.0005804735064707, 1.9779859467060674, 1.9549597600944126, 1.9315091553780914, 1.9076415907182989, 1.8833647482159221, 1.8586865422894134, 1.8336151290555323, 1.8081589168380061, 1.782326577946415, 1.7561270618875031, 1.7295696101941649, 1.7026637730839715, 1.6754194281900665, 1.6478468016431573, 1.6199564918251874, 1.591759496164001, 1.5632672413952764, 1.5344916177845718, 1.5054450178803043, 1.4761403804599122, 1.4465912404387822, 1.4168117856376492, 1.3868169214524748, 1.35662234464528, 1.3262446276796573, 1.2957013152660435, 1.2650110350653665, 1.2341936248321244, 1.203270278666664, 1.1722637154990099, 1.141198373450384, 1.1101006343196658, 1.0789990831235972, 1.0479248083792048, 1.0169117496424114, 0.9859970996796523, 0.9552217694946188, 0.9246309251640091, 0.8942746058954003, 0.8642084326538892, 0.8344944157213195, 0.8052018670667832, 0.7764084185664192, 0.7482011387131646, 0.7206777268835728, 0.6939477434236494, 0.6681338034071804, 0.6433726196239965, 0.619815724886712, 0.5976296365120741, 0.5769951536308955, 0.5581054165002001, 0.5411623340432979, 0.5263710415323061, 0.5139322296313852, 0.5040325191929363, 0.496833527450494, 0.49246078831706025, 0.4909940809733314, 0.49246078831706325, 0.4968335274504999, 0.5040325191929452, 0.5139322296313967, 0.5263710415323201, 0.5411623340433143, 0.5581054165002185, 0.5769951536309159, 0.5976296365120961, 0.6198157248867354, 0.6433726196240215, 0.6681338034072064, 0.6939477434236765, 0.7206777268836007, 0.7482011387131933, 0.7764084185664484, 0.8052018670668131, 0.8344944157213499, 0.86420843265392, 0.8942746058954312, 0.9246309251640403, 0.9552217694946504, 0.9859970996796841, 1.0169117496424434, 1.0479248083792367, 1.0789990831236291, 1.1101006343196977, 1.141198373450416, 1.1722637154990416, 1.2032702786666958, 1.234193624832156, 1.2650110350653982, 1.2957013152660752, 1.3262446276796889, 1.3566223446453114, 1.3868169214525057, 1.41681178563768, 1.4465912404388126, 1.4761403804599427, 1.5054450178803347, 1.5344916177846013, 1.5632672413953057, 1.5917594961640302, 1.6199564918252165, 1.6478468016431858, 1.6754194281900945, 1.7026637730839993, 1.7295696101941922, 1.7561270618875302, 1.782326577946442, 1.8081589168380325, 1.8336151290555582, 1.858686542289439, 1.8833647482159475, 1.9076415907183235, 1.9315091553781154, 1.9549597600944362, 1.9779859467060907, 2.000580473506494, 2.022736308554318, 2.0444466236941556, 2.0657047892113547, 2.08650436905386, 2.106839116561423, 2.1267029706492027, 2.146090052398595, 2.164994662013259, 2.1834112761028104, 2.201334545260649, 2.218759291905906, 2.2356805083626115, 2.2520933551519375, 2.267993159475851, 2.2833754138726574, 2.2982357750268987, 2.3125700627177674, 2.326374258891776, 2.339644506846791, 2.3523771105157896, 2.3645685338398197, 2.3762154002206266, 2.387314492044345, 2.3978627502684504, 2.407857274064891, 2.417295320513038, 2.426174304336637, 2.434491797679541, 2.4422455299155046, 2.449433387487745, 2.4560534137744625, 2.462103808976825, 2.46758293002636, 2.4724892905089577, 2.476821560603058, 2.4805785670298444, 2.48375929301356, 2.486362878250304, 2.4883886188839246, 2.489835967487842, 2.490704533051875], [2.5178496248983344, 2.5175580057105655, 2.5166832276371878, 2.5152255291512344, 2.5131853077186825, 2.510563119815218, 2.507359680950482, 2.50357586570057, 2.499212707749807, 2.4942713999430377, 2.4887532943499475, 2.4826599023431735, 2.475992894692248, 2.468754101675717, 2.4609455132140665, 2.4525692790264646, 2.4436277088146316, 2.434123272477582, 2.42405860036139, 2.4134364835485673, 2.4022598741921644, 2.3905318859002316, 2.3782557941768725, 2.3654350369267942, 2.3520732150309325, 2.338174093001573, 2.3237415997262385, 2.308779829310568, 2.293293042031524, 2.2772856654134217, 2.26076229544063, 2.243727697922251, 2.226186810025763, 2.2081447419984346, 2.1896067790974065, 2.1705783837516512, 2.151065197981628, 2.1310730461053833, 2.1106079377631586, 2.0896760712962843, 2.06828383752036, 2.046437823937492, 2.0241448194377543, 2.001411819546183, 1.978246032278585, 1.9546548846773943, 1.9306460301078465, 1.9062273564051226, 1.881406994974917, 1.8561933309634797, 1.8305950146287349, 1.804620974061978, 1.7782804294302634, 1.751582908933355, 1.7245382666965436, 1.6971567028523893, 1.6694487861012044, 1.6414254790827447, 1.6130981669411262, 1.5844786895226086, 1.555579377713, 1.5264130944996628, 1.4969932814343925, 1.4673340112800257, 1.4374500477481322, 1.407356913380627, 1.3770709667980274, 1.3466094907354051, 1.31599079251819, 1.2852343188988167, 1.2543607874868004, 1.2233923373644309, 1.192352701892582, 1.1612674071796691, 1.1301640002126494, 1.0990723112287637, 1.0680247555296956, 1.0370566805831058, 1.0062067648784374, 0.9755174755339502, 0.9450355919764529, 0.9148128029571114, 0.884906383458006, 0.8553799562895908, 0.8263043398113263, 0.7977584774362231, 0.7698304353450915, 0.7426184407887831, 0.7162319129076388, 0.6907924095135319, 0.6664343755430062, 0.643305531975513, 0.6215666907373779, 0.6013907290854216, 0.5829604208603348, 0.5664648249908523, 0.552094003799805, 0.5400320144907836, 0.53044840004841, 0.5234887767065259, 0.5192654961488097, 0.5178496248983345, 0.5192654961488126, 0.5234887767065317, 0.5304484000484185, 0.5400320144907949, 0.5520940037998187, 0.566464824990868, 0.5829604208603529, 0.6013907290854414, 0.6215666907373995, 0.643305531975536, 0.6664343755430306, 0.6907924095135575, 0.7162319129076654, 0.7426184407888108, 0.7698304353451197, 0.797758477436252, 0.8263043398113561, 0.8553799562896209, 0.8849063834580366, 0.9148128029571422, 0.9450355919764841, 0.9755174755339815, 1.0062067648784692, 1.0370566805831376, 1.0680247555297273, 1.0990723112287955, 1.1301640002126812, 1.1612674071797011, 1.1923527018926139, 1.2233923373644628, 1.2543607874868319, 1.2852343188988484, 1.3159907925182215, 1.3466094907354367, 1.3770709667980587, 1.4073569133806578, 1.437450047748163, 1.4673340112800564, 1.4969932814344231, 1.5264130944996932, 1.5555793777130302, 1.5844786895226384, 1.6130981669411553, 1.6414254790827738, 1.669448786101233, 1.6971567028524177, 1.7245382666965714, 1.7515829089333825, 1.778280429430291, 1.8046209740620052, 1.8305950146287615, 1.856193330963506, 1.8814069949749426, 1.9062273564051477, 1.9306460301078714, 1.9546548846774183, 1.9782460322786088, 2.001411819546206, 2.0241448194377774, 2.0464378239375147, 2.068283837520382, 2.0896760712963065, 2.11060793776318, 2.131073046105404, 2.1510651979816484, 2.1705783837516717, 2.189606779097426, 2.2081447419984532, 2.2261868100257813, 2.2437276979222687, 2.2607622954406463, 2.2772856654134386, 2.29329304203154, 2.3087798293105837, 2.3237415997262536, 2.3381740930015877, 2.3520732150309467, 2.365435036926808, 2.378255794176886, 2.3905318859002436, 2.4022598741921763, 2.4134364835485784, 2.4240586003614006, 2.4341232724775916, 2.443627708814641, 2.4525692790264744, 2.4609455132140745, 2.4687541016757244, 2.4759928946922556, 2.4826599023431806, 2.4887532943499533, 2.494271399943043, 2.499212707749812, 2.5035758657005744, 2.507359680950486, 2.510563119815221, 2.5131853077186856, 2.515225529151236, 2.5166832276371887, 2.517558005710566], [2.5442041827560367, 2.5439105734552343, 2.543029826321043, 2.5415621836629136, 2.539508049346089, 2.536867988816251, 2.5336427291348538, 2.529833159025979, 2.5254403289358107, 2.5204654511060474, 2.514909899662902, 2.5087752107235426, 2.502063082522209, 2.494775375558473, 2.486914112770503, 2.478481479736529, 2.469479824908085, 2.4599116598790256, 2.4497796596947707, 2.439086663206687, 2.427835673477097, 2.41602985824094, 2.4036725504307532, 2.390767248772361, 2.377317618459391, 2.363327491915613, 2.3488008696549882, 2.333741921250386, 2.318154986423052, 2.3020445762661588, 2.285415374617221, 2.2682722395956825, 2.250620205323768, 2.2324644838506393, 2.2138104673020553, 2.1946637302802405, 2.1750300325413723, 2.1549153219811994, 2.134325737962804, 2.113267615024408, 2.0917474870095702, 2.0697720916671125, 2.0473483757737765, 2.0244835008390174, 2.001184849458643, 1.977460032392259, 1.95331689644893, 1.9287635332761943, 1.9038082891598471, 1.8784597759559463, 1.8527268832925416, 1.8266187921970833, 1.8001449903266025, 1.773315289002123, 1.7461398422767747, 1.7186291682994175, 1.6907941732729133, 1.6626461783493256, 1.6341969498542779, 1.6054587332905534, 1.5764442916381072, 1.5471669485454946, 1.5176406370980848, 1.4878799549533435, 1.4579002267552794, 1.427717574881499, 1.397348999740169, 1.3668124710238376, 1.3361270315460025, 1.3053129155381993, 1.2743916835737847, 1.2433863766125413, 1.2123216920298003, 1.1812241849049567, 1.1501224982935496, 1.119047626685483, 1.0880332173414087, 1.0571159146683071, 1.026335753191851, 0.995736604925301, 0.9653666868971138, 0.9352791340955159, 0.9055326418466207, 0.8761921792781666, 0.84732977150202, 0.8190253417656805, 0.7913675951702105, 0.7644549115450553, 0.7383961955410765, 0.7133116059352447, 0.6893330531328852, 0.6666043149125254, 0.6452805791771903, 0.6255271865131439, 0.6075173277982274, 0.5914284717398701, 0.5774373761732585, 0.5657136938318644, 0.5564124213720216, 0.5496657334453733, 0.5455750272374409, 0.5442041827560364, 0.5455750272374437, 0.549665733445379, 0.5564124213720298, 0.5657136938318754, 0.5774373761732717, 0.5914284717398856, 0.6075173277982451, 0.6255271865131633, 0.6452805791772114, 0.6666043149125479, 0.6893330531329093, 0.7133116059352699, 0.7383961955411029, 0.7644549115450824, 0.7913675951702384, 0.8190253417657094, 0.8473297715020495, 0.8761921792781965, 0.9055326418466512, 0.9352791340955466, 0.9653666868971449, 0.9957366049253322, 1.0263357531918824, 1.0571159146683389, 1.0880332173414402, 1.1190476266855147, 1.1501224982935816, 1.1812241849049887, 1.2123216920298323, 1.2433863766125728, 1.2743916835738165, 1.305312915538231, 1.336127031546034, 1.3668124710238694, 1.3973489997402, 1.42771757488153, 1.4579002267553103, 1.4878799549533739, 1.5176406370981155, 1.5471669485455253, 1.5764442916381374, 1.605458733290583, 1.6341969498543072, 1.6626461783493547, 1.6907941732729421, 1.7186291682994461, 1.7461398422768026, 1.7733152890021506, 1.8001449903266298, 1.82661879219711, 1.8527268832925685, 1.8784597759559727, 1.9038082891598729, 1.9287635332762196, 1.953316896448955, 1.9774600323922833, 2.001184849458667, 2.0244835008390414, 2.0473483757737996, 2.0697720916671356, 2.091747487009592, 2.1132676150244296, 2.134325737962825, 2.1549153219812207, 2.1750300325413927, 2.1946637302802605, 2.2138104673020744, 2.2324644838506584, 2.250620205323787, 2.2682722395957, 2.285415374617238, 2.3020445762661756, 2.318154986423068, 2.333741921250402, 2.348800869655004, 2.363327491915629, 2.377317618459405, 2.3907672487723732, 2.403672550430766, 2.4160298582409525, 2.427835673477109, 2.439086663206698, 2.4497796596947814, 2.4599116598790363, 2.469479824908094, 2.4784814797365375, 2.4869141127705108, 2.4947753755584805, 2.5020630825222163, 2.508775210723549, 2.5149098996629076, 2.5204654511060527, 2.525440328935816, 2.529833159025984, 2.5336427291348578, 2.5368679888162546, 2.5395080493460918, 2.5415621836629145, 2.5430298263210442, 2.543910573455235], [2.570032258213792, 2.569736738159881, 2.5688502600303904, 2.567373069928419, 2.565305578047175, 2.562648358702486, 2.5594021503791935, 2.5555678557923223, 2.5511465419642, 2.546139440318935, 2.540547946796002, 2.534373621984928, 2.527618191283446, 2.5202835450817593, 2.5123717389759657, 2.5038849940140393, 2.494825696978191, 2.4851964007078626, 2.4749998244680986, 2.464238854368528, 2.4529165438387923, 2.441036114166836, 2.428600955107159, 2.415614625566879, 2.4020808543782426, 2.388003541167136, 2.3733867573281087, 2.358234747117537, 2.342551928877747, 2.326342896406244, 2.309612420485708, 2.2923654505920457, 2.274607116799637, 2.256342731904985, 2.2375777937922483, 2.2183179880667456, 2.1985691909853706, 2.178337472716109, 2.1576291009624953, 2.1364505449929214, 2.1148084801193416, 2.09270979267512, 2.0701615855476585, 2.047171184328103, 2.023746144147978, 1.9998942572811798, 1.9756235615994906, 1.9509423499808594, 1.9258591807823493, 1.9003828895040427, 1.874522601786685, 1.8482877479046986, 1.8216880789377785, 1.7947336848290567, 1.7674350145662807, 1.7398028987551122, 1.7118485748913381, 1.6835837156820985, 1.6550204608162464, 1.6261714526416189, 1.5970498762735639, 1.5676695047359535, 1.538044749824659, 1.508190719485942, 1.4781232826204131, 1.4478591423593956, 1.417415919017159, 1.3868122441021236, 1.3560678669754342, 1.325203775978697, 1.294242336116264, 1.2632074456722882, 1.2321247144684528, 1.201021666821588, 1.1699279726338903, 1.1388757104281957, 1.107899666502784, 1.0770376746861063, 1.046331001361975, 1.0158247804205023, 0.9855685024375732, 0.9556165615066127, 0.9260288614747682, 0.8968714805069076, 0.8682173884301418, 0.8401472045784946, 0.8127499741095585, 0.7861239271633046, 0.7603771669730068, 0.7356282095982857, 0.7120062695305268, 0.6896511536236288, 0.6687125945547623, 0.6493488315904554, 0.6317242421379895, 0.6160058573570131, 0.6023586749630505, 0.590939823420152, 0.5818918314172479, 0.5753354892630804, 0.5713630021406789, 0.5700322582137918, 0.5713630021406816, 0.5753354892630859, 0.5818918314172559, 0.5909398234201627, 0.6023586749630634, 0.6160058573570283, 0.6317242421380067, 0.6493488315904744, 0.668712594554783, 0.6896511536236511, 0.7120062695305505, 0.7356282095983104, 0.7603771669730328, 0.7861239271633315, 0.8127499741095864, 0.840147204578523, 0.868217388430171, 0.8968714805069373, 0.9260288614747983, 0.9556165615066432, 0.9855685024376041, 1.0158247804205334, 1.0463310013620066, 1.077037674686138, 1.1078996665028158, 1.1388757104282274, 1.1699279726339225, 1.20102166682162, 1.232124714468485, 1.26320744567232, 1.294242336116296, 1.3252037759787285, 1.3560678669754658, 1.3868122441021553, 1.41741591901719, 1.447859142359427, 1.4781232826204442, 1.508190719485973, 1.5380447498246896, 1.5676695047359839, 1.597049876273594, 1.6261714526416484, 1.655020460816276, 1.6835837156821276, 1.711848574891367, 1.7398028987551406, 1.7674350145663087, 1.794733684829085, 1.8216880789378058, 1.848287747904726, 1.8745226017867116, 1.900382889504069, 1.9258591807823755, 1.9509423499808851, 1.9756235615995157, 1.9998942572812046, 2.023746144148002, 2.0471711843281266, 2.070161585547682, 2.0927097926751426, 2.1148084801193643, 2.1364505449929436, 2.157629100962517, 2.17833747271613, 2.198569190985391, 2.2183179880667656, 2.2375777937922674, 2.2563427319050042, 2.2746071167996558, 2.292365450592063, 2.3096124204857253, 2.3263428964062602, 2.342551928877763, 2.3582347471175535, 2.373386757328124, 2.388003541167151, 2.402080854378257, 2.4156146255668918, 2.428600955107172, 2.4410361141668484, 2.4529165438388048, 2.4642388543685394, 2.474999824468109, 2.485196400707873, 2.4948256969782, 2.503884994014048, 2.512371738975974, 2.5202835450817673, 2.527618191283453, 2.534373621984935, 2.540547946796008, 2.5461394403189406, 2.551146541964205, 2.5555678557923267, 2.5594021503791975, 2.5626483587024897, 2.565305578047177, 2.5673730699284203, 2.568850260030392, 2.569736738159882], [2.595308864276675, 2.595011511091673, 2.594119534815882, 2.5926331852948787, 2.5905528789645222, 2.5878791988912653, 2.584612894829535, 2.5807548832971157, 2.5763062476697822, 2.571268238296686, 2.5656422726383403, 2.5594299354293284, 2.5526329788682323, 2.545253322837602, 2.5372930551571846, 2.5287544318740243, 2.519639877593478, 2.509951985855662, 2.4996935195623413, 2.488867411459828, 2.477476764684045, 2.4655248533745557, 2.453015123365074, 2.4399511929587554, 2.426336853797397, 2.4121760718346383, 2.3974729884242927, 2.3822319215360506, 2.3664573671121047, 2.3501540005796238, 2.3333266785355655, 2.3159804406220523, 2.298120511612476, 2.2797523037306093, 2.2608814192274567, 2.2415136532432203, 2.2216549969847716, 2.2013116412524116, 2.1804899803534576, 2.159196616444459, 2.137438364348643, 2.115222256900571, 2.092555550876087, 2.069445733572518, 2.0459005301118802, 2.0219279115486675, 1.9975361038738002, 1.9727335980177012, 1.947529160968391, 1.921931848135218, 1.8959510171056388, 1.8695963429616327, 1.8428778353442108, 1.8158058574795857, 1.7883911474091883, 1.7606448416986593, 1.7325785019386166, 1.7042041443933136, 1.6755342732030054, 1.6465819176029766, 1.6173606736878057, 1.5878847513248613, 1.5581690269076136, 1.5282291027387218, 1.4980813739467012, 1.4677431039701798, 1.4372325097922243, 1.4065688582758629, 1.3757725751425653, 1.3448653683493514, 1.3138703678580734, 1.2828122840515734, 1.2517175873331081, 1.2206147117417006, 1.1895342857160895, 1.158509393425588, 1.1275758703288428, 1.0967726367775528, 1.0661420734867282, 1.0357304424519282, 1.0055883562729906, 0.9757712976564308, 0.9463401888605888, 0.9173620076815238, 0.8889104418211431, 0.8610665666022372, 0.8339195213909587, 0.8075671471342598, 0.7821165306165028, 0.7576843802492857, 0.7343971340546438, 0.7123906749323897, 0.6918095052874825, 0.6728052192849756, 0.6555341159829494, 0.6401538321062754, 0.6268189505952749, 0.6156756663764523, 0.6068557583043898, 0.600470302318191, 0.5966037229025488, 0.595308864276675, 0.5966037229025514, 0.6004703023181963, 0.6068557583043975, 0.6156756663764626, 0.6268189505952875, 0.6401538321062902, 0.6555341159829662, 0.6728052192849944, 0.6918095052875027, 0.7123906749324117, 0.7343971340546671, 0.7576843802493103, 0.7821165306165282, 0.8075671471342865, 0.8339195213909862, 0.8610665666022655, 0.888910441821172, 0.9173620076815534, 0.9463401888606188, 0.9757712976564611, 1.0055883562730215, 1.0357304424519593, 1.0661420734867595, 1.0967726367775843, 1.1275758703288743, 1.1585093934256196, 1.1895342857161215, 1.2206147117417323, 1.25171758733314, 1.2828122840516056, 1.3138703678581056, 1.3448653683493834, 1.375772575142597, 1.4065688582758944, 1.4372325097922558, 1.4677431039702111, 1.498081373946732, 1.5282291027387527, 1.5581690269076445, 1.587884751324892, 1.6173606736878359, 1.6465819176030063, 1.6755342732030352, 1.7042041443933431, 1.7325785019386455, 1.7606448416986877, 1.7883911474092165, 1.8158058574796134, 1.8428778353442385, 1.8695963429616596, 1.8959510171056657, 1.921931848135244, 1.9475291609684169, 1.972733598017727, 1.9975361038738253, 2.0219279115486923, 2.0459005301119046, 2.069445733572542, 2.0925555508761104, 2.1152222569005947, 2.137438364348666, 2.1591966164444814, 2.180489980353479, 2.201311641252433, 2.221654996984792, 2.2415136532432407, 2.260881419227477, 2.279752303730628, 2.2981205116124945, 2.3159804406220705, 2.333326678535583, 2.3501540005796415, 2.3664573671121216, 2.382231921536066, 2.3974729884243082, 2.4121760718346534, 2.426336853797411, 2.439951192958769, 2.453015123365087, 2.4655248533745677, 2.477476764684057, 2.488867411459839, 2.4996935195623524, 2.5099519858556727, 2.5196398775934883, 2.5287544318740336, 2.537293055157193, 2.54525332283761, 2.55263297886824, 2.559429935429335, 2.565642272638346, 2.5712682382966916, 2.5763062476697867, 2.5807548832971205, 2.584612894829539, 2.5878791988912684, 2.5905528789645245, 2.5926331852948805, 2.5941195348158828, 2.595011511091673], [2.620009547460784, 2.619710437085586, 2.6188131904664824, 2.6173180611324107, 2.6152254716632934, 2.61253601373807, 2.609250448202936, 2.605369705160783, 2.6008948840831465, 2.595827253946261, 2.5901682533931565, 2.583919490924056, 2.5770827451176928, 2.5696599648865432, 2.5616532697693524, 2.5530649502647753, 2.5438974682103987, 2.5341534572118976, 2.523835723127621, 2.512947244614465, 2.5014911737415235, 2.4894708366786755, 2.4768897344680356, 2.463751543886976, 2.4500601184123565, 2.4358194892965517, 2.421033866766982, 2.405707641362017, 2.3898453854174666, 2.3734518547193395, 2.3565319903401596, 2.339090920677945, 2.3211339637189825, 2.302666629547713, 2.283694623129614, 2.264223847395684, 2.2442604066603016, 2.2238106104076847, 2.202880977486129, 2.1814782407535644, 2.159609352222938, 2.137281488761473, 2.114502058404146, 2.091278707348763, 2.0676193277080546, 2.043532066103194, 2.0190253331934285, 1.994107814248089, 1.9687884808804172, 1.9430766040776413, 1.9169817686787303, 1.890513889470665, 1.8636832290961458, 1.8365004179908908, 1.808976476597428, 1.7811228401352057, 1.752951386244396, 1.7244744658637976, 1.6957049377523863, 1.6666562071203432, 1.6373422688997186, 1.6077777562584203, 1.5779779950452009, 1.5479590649490367, 1.5177378682652485, 1.4873322072842632, 1.456760871458602, 1.4260437356606683, 1.3952018710192151, 1.3642576700163167, 1.3332349877385257, 1.3021593014034785, 1.2710578905216998, 1.23996004029444, 1.208897271078296, 1.177903596944786, 1.147015816495674, 1.1162738391153773, 1.0857210496820506, 1.0554047143229082, 1.025376428954036, 0.9956926109103215, 0.9664150317088019, 0.9376113855926866, 0.9093558835951673, 0.8817298559994922, 0.8548223367798037, 0.828730591451862, 0.8035605344885087, 0.779426964214625, 0.756453522796304, 0.7347722686944677, 0.714522732597071, 0.6958503213179472, 0.6789039454581123, 0.6638327848795629, 0.6507821791120075, 0.6398887404007706, 0.6312749279024634, 0.6250434714217471, 0.6212721573940321, 0.620009547460784, 0.6212721573940347, 0.6250434714217521, 0.6312749279024712, 0.6398887404007808, 0.6507821791120201, 0.6638327848795774, 0.6789039454581287, 0.6958503213179656, 0.7145227325970909, 0.7347722686944892, 0.756453522796327, 0.7794269642146493, 0.8035605344885342, 0.8287305914518882, 0.8548223367798309, 0.88172985599952, 0.909355883595196, 0.937611385592716, 0.9664150317088319, 0.9956926109103517, 1.0253764289540666, 1.0554047143229388, 1.085721049682082, 1.116273839115409, 1.1470158164957058, 1.177903596944818, 1.208897271078328, 1.2399600402944717, 1.2710578905217316, 1.3021593014035102, 1.3332349877385579, 1.3642576700163485, 1.3952018710192466, 1.4260437356606999, 1.4567608714586338, 1.4873322072842947, 1.5177378682652798, 1.5479590649490678, 1.5779779950452317, 1.6077777562584512, 1.6373422688997488, 1.6666562071203732, 1.6957049377524158, 1.7244744658638274, 1.752951386244425, 1.7811228401352341, 1.8089764765974565, 1.8365004179909186, 1.8636832290961736, 1.8905138894706925, 1.9169817686787574, 1.9430766040776677, 1.9687884808804432, 1.9941078142481148, 2.019025333193454, 2.043532066103218, 2.0676193277080785, 2.091278707348787, 2.114502058404169, 2.1372814887614964, 2.1596093522229607, 2.181478240753587, 2.2028809774861506, 2.2238106104077064, 2.2442604066603224, 2.2642238473957046, 2.283694623129634, 2.3026666295477325, 2.321133963719001, 2.3390909206779633, 2.3565319903401765, 2.373451854719357, 2.389845385417483, 2.405707641362033, 2.4210338667669977, 2.4358194892965663, 2.4500601184123707, 2.46375154388699, 2.476889734468049, 2.4894708366786884, 2.501491173741535, 2.5129472446144767, 2.5238357231276316, 2.534153457211908, 2.543897468210409, 2.5530649502647846, 2.5616532697693604, 2.5696599648865512, 2.5770827451177, 2.5839194909240626, 2.590168253393163, 2.595827253946267, 2.6008948840831514, 2.6053697051607876, 2.60925044820294, 2.6125360137380733, 2.6152254716632966, 2.6173180611324125, 2.6188131904664833, 2.619710437085587], [2.6441104114504066, 2.643809618202594, 2.642907324170722, 2.64140378650046, 2.639299433804676, 2.636594866219067, 2.6332908554810994, 2.629388345033296, 2.6248884501522336, 2.61979245810495, 2.614101828334783, 2.6078181926790203, 2.6009433556211086, 2.5934792945805745, 2.5854281602442013, 2.5767922769424834, 2.567574143075824, 2.5577764315954887, 2.547401990544846, 2.5364538436670654, 2.5249351910860613, 2.512849410068213, 2.5002000558731345, 2.486990862702666, 2.47322574475813, 2.458908797416987, 2.444044298541096, 2.428636709930079, 2.412690678934625, 2.3962110402461305, 2.3792028178807243, 2.361671227377627, 2.3436216782338612, 2.3250597765996597, 2.305991328261478, 2.2864223419424285, 2.2663590329531496, 2.2458078272297355, 2.224775365799382, 2.203268509718927, 2.1812943455365392, 2.1588601913325287, 2.1359736034016477, 2.1126423836465253, 2.088874587760006, 2.0646785342834044, 2.040062814638087, 2.015036304239604, 1.9896081748169303, 1.9637879080745275, 1.9375853108521268, 1.9110105319566564, 1.884074080862923, 1.8567868485049217, 1.829160130408378, 1.8012056524478608, 1.772935599549101, 1.7443626476996297, 1.7154999996792557, 1.686361424977036, 1.6569613044241187, 1.6273146801431861, 1.5974373114961793, 1.5673457378037008, 1.5370573487130712, 1.5065904632085216, 1.4759644183874163, 1.4451996692713667, 1.414317901080781, 1.3833421555752237, 1.352296973248059, 1.3212085533584876, 1.290104933980862, 1.2590161944396059, 1.2279746826621518, 1.1970152700980765, 1.1661756368851814, 1.1354965898428782, 1.1050224155702295, 1.0748012703245151, 1.0448856073269717, 1.0153326405146312, 0.9862048413112727, 0.9575704614530354, 0.929504069950139, 0.9020870855342477, 0.8754082770735037, 0.8495641931575928, 0.8246594683025682, 0.8008069373635798, 0.7781274728549046, 0.7567494441200319, 0.7368076862626092, 0.71844186566252, 0.7017941443773256, 0.6870060847757167, 0.6742148036838882, 0.6635484826277284, 0.6551214595327159, 0.6490292488971532, 0.6453439337118627, 0.6441104114504065, 0.6453439337118652, 0.6490292488971582, 0.6551214595327234, 0.6635484826277382, 0.6742148036839004, 0.6870060847757309, 0.7017941443773417, 0.7184418656625381, 0.7368076862626287, 0.7567494441200531, 0.7781274728549272, 0.8008069373636038, 0.8246594683025931, 0.8495641931576189, 0.8754082770735305, 0.9020870855342754, 0.9295040699501675, 0.9575704614530645, 0.9862048413113024, 1.0153326405146612, 1.044885607327002, 1.0748012703245458, 1.1050224155702606, 1.1354965898429097, 1.166175636885213, 1.1970152700981083, 1.2279746826621836, 1.2590161944396379, 1.2901049339808943, 1.3212085533585196, 1.352296973248091, 1.3833421555752554, 1.414317901080813, 1.4451996692713984, 1.4759644183874479, 1.5065904632085527, 1.5370573487131025, 1.5673457378037314, 1.5974373114962097, 1.6273146801432163, 1.656961304424149, 1.6863614249770662, 1.7154999996792855, 1.7443626476996588, 1.7729355995491303, 1.8012056524478897, 1.829160130408407, 1.85678684850495, 1.884074080862951, 1.9110105319566837, 1.937585310852154, 1.9637879080745542, 1.9896081748169567, 2.01503630423963, 2.040062814638113, 2.0646785342834293, 2.088874587760031, 2.1126423836465493, 2.1359736034016716, 2.1588601913325522, 2.181294345536562, 2.203268509718949, 2.2247753657994043, 2.245807827229757, 2.2663590329531704, 2.2864223419424485, 2.3059913282614977, 2.325059776599679, 2.34362167823388, 2.3616712273776446, 2.379202817880742, 2.396211040246148, 2.4126906789346414, 2.428636709930095, 2.444044298541112, 2.4589087974170023, 2.473225744758145, 2.48699086270268, 2.500200055873148, 2.5128494100682253, 2.524935191086074, 2.5364538436670765, 2.547401990544857, 2.557776431595499, 2.567574143075834, 2.5767922769424922, 2.5854281602442097, 2.5934792945805825, 2.6009433556211166, 2.607818192679027, 2.6141018283347894, 2.6197924581049556, 2.6248884501522385, 2.6293883450333, 2.6332908554811034, 2.6365948662190704, 2.6392994338046782, 2.6414037865004616, 2.642907324170723, 2.643809618202595], [2.667588140216162, 2.6672857368485547, 2.6663786136378094, 2.664867031272626, 2.6627514242758767, 2.66003240106771, 2.65671074405499, 2.6527874097481696, 2.6482635289070213, 2.643140406717019, 2.63741952299846, 2.631102532450843, 2.624191264935373, 2.6166877257988816, 2.608594096242887, 2.5999127337419834, 2.590646172516252, 2.5807971240629097, 2.570368477753002, 2.5593633014995727, 2.547784842504403, 2.5356365280911977, 2.522921966633839, 2.509644948589291, 2.495809447645631, 2.48141962199681, 2.466479815756877, 2.450994560527712, 2.4349685771357414, 2.418406777554666, 2.401314267032999, 2.3836963464471452, 2.365558514902885, 2.3469064726105415, 2.3277461240617443, 2.3080835815387015, 2.287925168990165, 2.2672774263120083, 2.246147114074446, 2.224541218742574, 2.202466958442109, 2.179931789328013, 2.156943412620291, 2.133509782378559, 2.10963911409535, 2.085339894197437, 2.0606208905550343, 2.035491164110673, 2.009960081753017, 1.9840373305761645, 1.9577329336822402, 1.9310572677046822, 1.9040210822518095, 1.8766355214954635, 1.848912148158079, 1.8208629701840067, 1.7925004704177252, 1.763837639653415, 1.7348880134677684, 1.705665713301724, 1.6761854923176942, 1.6464627866277184, 1.6165137725656553, 1.5863554307639207, 1.5560056178931816, 1.5254831470325958, 1.494807877759088, 1.4640008171769152, 1.4330842332528457, 1.4020817819762184, 1.3710186500240198, 1.3399217147740112, 1.3088197236658732, 1.2777434950492594, 1.2467261427606005, 1.2158033267116366, 1.1850135317152997, 1.154398376567626, 1.1240029549780628, 1.0938762092008423, 1.0640713360432101, 1.0346462231526183, 1.0056639109147627, 0.977193071686902, 0.9493084931716274, 0.9220915462176549, 0.8956306089596645, 0.8700214088319494, 0.8453672317003136, 0.8217789336652918, 0.799374677175816, 0.7782793010775473, 0.7586232274053906, 0.740540810651319, 0.7241680533279444, 0.7096396502464939, 0.6970853864837099, 0.686625999577632, 0.678368717155658, 0.6724027807156268, 0.6687953414785864, 0.6675881402161622, 0.668795341478589, 0.6724027807156318, 0.6783687171556656, 0.6866259995776417, 0.6970853864837216, 0.7096396502465077, 0.7241680533279602, 0.7405408106513367, 0.75862322740541, 0.7782793010775682, 0.7993746771758383, 0.8217789336653154, 0.8453672317003383, 0.8700214088319751, 0.8956306089596913, 0.9220915462176824, 0.9493084931716559, 0.9771930716869309, 1.0056639109147922, 1.0346462231526483, 1.0640713360432406, 1.0938762092008731, 1.1240029549780939, 1.1543983765676573, 1.185013531715331, 1.2158033267116684, 1.2467261427606322, 1.2777434950492914, 1.308819723665905, 1.3399217147740428, 1.371018650024052, 1.40208178197625, 1.4330842332528775, 1.4640008171769472, 1.49480787775912, 1.5254831470326276, 1.5560056178932131, 1.5863554307639518, 1.6165137725656864, 1.6464627866277497, 1.6761854923177248, 1.7056657133017539, 1.7348880134677982, 1.7638376396534448, 1.7925004704177547, 1.8208629701840353, 1.8489121481581077, 1.8766355214954917, 1.9040210822518377, 1.93105726770471, 1.9577329336822673, 1.9840373305761911, 2.009960081753043, 2.0354911641106983, 2.0606208905550596, 2.085339894197462, 2.109639114095375, 2.1335097823785834, 2.156943412620315, 2.1799317893280366, 2.2024669584421317, 2.224541218742597, 2.2461471140744678, 2.26727742631203, 2.2879251689901863, 2.308083581538722, 2.3277461240617647, 2.346906472610561, 2.365558514902904, 2.383696346447163, 2.4013142670330163, 2.418406777554683, 2.4349685771357588, 2.450994560527728, 2.4664798157568923, 2.4814196219968254, 2.495809447645646, 2.5096449485893046, 2.5229219666338523, 2.53563652809121, 2.547784842504416, 2.5593633014995842, 2.570368477753013, 2.5807971240629195, 2.5906461725162617, 2.599912733741993, 2.6085940962428955, 2.6166877257988896, 2.6241912649353805, 2.6311025324508495, 2.6374195229984663, 2.643140406717025, 2.648263528907027, 2.6527874097481736, 2.656710744054994, 2.660032401067713, 2.662751424275879, 2.6648670312726273, 2.6663786136378107, 2.6672857368485547], [2.6904200205717554, 2.6901160783314664, 2.689204339656411, 2.6876850686979488, 2.6855587057549006, 2.682825867343961, 2.6794873462994064, 2.675544111903253, 2.6709973100473654, 2.665848263429347, 2.660098471784443, 2.6537496121560316, 2.6468035392077356, 2.639262285580561, 2.631128062298944, 2.6224032592301, 2.6130904456015203, 2.603192370582098, 2.5927119639328935, 2.581652336734252, 2.5700167821966664, 2.557808776563556, 2.545031980114961, 2.5316902382820787, 2.5177875828835683, 2.503328233495653, 2.488316598969249, 2.4727572791087082, 2.456655066528211, 2.440014948703482, 2.4228421102383084, 2.4051419353673107, 2.3869200107186574, 2.368182128362851, 2.348934289176448, 2.3291827065526256, 2.308933810493901, 2.288194252126071, 2.266970908676715, 2.2452708889662842, 2.2231015394651408, 2.2004704509758293, 2.177385466006527, 2.153854686909117, 2.1298864848637415, 2.105489509801158, 2.0806727013649007, 2.0554453010272726, 2.0298168654867705, 2.003797281489855, 1.9773967822373035, 1.9506259655549372, 1.9234958140306515, 1.8960177173447075, 1.8682034970485624, 1.8400654340795766, 1.811616299335169, 1.7828693876709947, 1.7538385557340228, 1.7245382640936426, 1.6949836241928133, 1.6651904507074546, 1.6351753199764631, 1.604955635247606, 1.5745496995766084, 1.5439767973184355, 1.5132572852610897, 1.4824126945728424, 1.4514658448624882, 1.4204409717867281, 1.389363869775362, 1.358262051577516, 1.3271649264515422, 1.296103998913998, 1.265113090009934, 1.2342285830403121, 1.2034896955450518, 1.1729387790404526, 1.1426216474786495, 1.1125879345434728, 1.0828914786044057, 1.053590732270879, 1.024749190843386, 0.9964358303367237, 0.968725540926198, 0.9416995354175602, 0.9154457044953312, 0.8900588810200176, 0.8656409647259535, 0.842300846928821, 0.8201540635035117, 0.7993220954719585, 0.7799312330393903, 0.7621109247474102, 0.7459915530081082, 0.7317016146770365, 0.7193643426037595, 0.7090938794290086, 0.700991200656415, 0.6951400660821866, 0.6916033379055933, 0.6904200205717552, 0.6916033379055957, 0.6951400660821914, 0.7009912006564223, 0.709093879429018, 0.7193643426037712, 0.7317016146770501, 0.7459915530081238, 0.7621109247474276, 0.7799312330394094, 0.7993220954719791, 0.820154063503534, 0.8423008469288444, 0.8656409647259781, 0.8900588810200432, 0.9154457044953577, 0.9416995354175876, 0.9687255409262262, 0.9964358303367525, 1.0247491908434154, 1.0535907322709088, 1.082891478604436, 1.1125879345435037, 1.1426216474786806, 1.172938779040484, 1.2034896955450833, 1.2342285830403439, 1.2651130900099659, 1.29610399891403, 1.327164926451574, 1.3582620515775479, 1.389363869775394, 1.4204409717867599, 1.45146584486252, 1.4824126945728742, 1.5132572852611212, 1.5439767973184668, 1.5745496995766397, 1.6049556352476368, 1.6351753199764945, 1.6651904507074855, 1.694983624192844, 1.7245382640936726, 1.753838555734053, 1.7828693876710247, 1.811616299335198, 1.8400654340796057, 1.868203497048591, 1.8960177173447357, 1.92349581403068, 1.9506259655549647, 1.9773967822373306, 2.003797281489882, 2.0298168654867967, 2.055445301027299, 2.0806727013649264, 2.1054895098011834, 2.1298864848637664, 2.153854686909141, 2.177385466006551, 2.200470450975853, 2.223101539465164, 2.2452708889663064, 2.266970908676737, 2.2881942521260923, 2.308933810493922, 2.3291827065526465, 2.3489342891764675, 2.368182128362871, 2.386920010718677, 2.405141935367329, 2.4228421102383266, 2.4400149487035, 2.456655066528228, 2.472757279108725, 2.488316598969265, 2.503328233495669, 2.517787582883583, 2.5316902382820925, 2.5450319801149752, 2.557808776563569, 2.570016782196679, 2.581652336734263, 2.5927119639329046, 2.6031923705821085, 2.6130904456015305, 2.622403259230109, 2.631128062298953, 2.639262285580569, 2.646803539207743, 2.653749612156038, 2.6600984717844494, 2.665848263429353, 2.6709973100473703, 2.6755441119032572, 2.6794873462994104, 2.6828258673439644, 2.6855587057549037, 2.687685068697951, 2.689204339656413, 2.690116078331467], [2.712583964147515, 2.7122785528353126, 2.7113624080693883, 2.7098357973771328, 2.7076991666888173, 2.704953140415128, 2.701598521556883, 2.6976362918481525, 2.6930676119343073, 2.687893821586945, 2.6821164399579693, 2.675737165875537, 2.6687578781849943, 2.661180636138355, 2.653007679836369, 2.6442414307277065, 2.6348844921703383, 2.6249396500607554, 2.614409873537307, 2.6032983157646, 2.5916083148066336, 2.5793433945971462, 2.5665072660165014, 2.553103828085402, 2.5391371692867533, 2.524611569028112, 2.5095314992584474, 2.493901626254272, 2.4777268125917398, 2.4610121193229757, 2.443762808376742, 2.4259843452056, 2.407682401704003, 2.3888628594242403, 2.369531813119992, 2.349695574650329, 2.329360677280479, 2.3085338804195294, 2.2872221748395627, 2.265432788425507, 2.243173192510413, 2.220451108856857, 2.197274517351954, 2.173651664491022, 2.149591072733464, 2.125101550823975, 2.100192205182928, 2.0748724524819013, 2.049152033533887, 2.0230410286431004, 1.9965498745765538, 1.969689383339091, 1.9424707629555322, 1.914905640488407, 1.8870060875477117, 1.8587846485806938, 1.8302543722652107, 1.8014288463702852, 1.7723222364925042, 1.7429493291275338, 1.7133255795927218, 1.6834671653801343, 1.6533910455899459, 1.6231150271723085, 1.5926578387919776, 1.562039213224116, 1.5312799792915224, 1.5004021644621384, 1.4694291093393483, 1.438385595393403, 1.4072979873956142, 1.3761943921208992, 1.3451048349685704, 1.3140614562014854, 1.2830987284993671, 1.2522536974351668, 1.2215662462755805, 1.1910793861270756, 1.1608395718298299, 1.1308970430569287, 1.1013061886952562, 1.0721259306329283, 1.043420120396191, 1.0152579384870861, 0.9877142815861916, 0.9608701168371648, 0.9348127751231802, 0.9096361466210859, 0.8854407322642617, 0.862333494731557, 0.8404274434255248, 0.8198408815237308, 0.8006962422699059, 0.7831184495725202, 0.7672327583036139, 0.7531620654494517, 0.7410237355636886, 0.730926050447727, 0.7229644664600547, 0.7172179310492722, 0.7137455571420509, 0.7125839641475152, 0.7137455571420531, 0.717217931049277, 0.7229644664600617, 0.7309260504477363, 0.7410237355637002, 0.7531620654494652, 0.7672327583036292, 0.7831184495725375, 0.8006962422699248, 0.8198408815237513, 0.8404274434255468, 0.8623334947315803, 0.8854407322642861, 0.9096361466211113, 0.9348127751232065, 0.9608701168371921, 0.9877142815862195, 1.0152579384871148, 1.0434201203962203, 1.072125930632958, 1.1013061886952864, 1.1308970430569594, 1.1608395718298608, 1.191079386127107, 1.2215662462756118, 1.2522536974351983, 1.2830987284993989, 1.3140614562015174, 1.3451048349686021, 1.3761943921209312, 1.4072979873956464, 1.4383855953934348, 1.46942910933938, 1.5004021644621701, 1.5312799792915543, 1.5620392132241476, 1.592657838792009, 1.6231150271723398, 1.6533910455899772, 1.6834671653801656, 1.7133255795927522, 1.742949329127564, 1.7723222364925342, 1.8014288463703152, 1.8302543722652402, 1.8587846485807227, 1.8870060875477408, 1.9149056404884355, 1.9424707629555602, 1.9696893833391187, 1.9965498745765813, 2.0230410286431275, 2.0491520335339137, 2.074872452481927, 2.1001922051829536, 2.1251015508239997, 2.149591072733489, 2.173651664491046, 2.197274517351978, 2.2204511088568806, 2.243173192510436, 2.2654327884255303, 2.287222174839585, 2.3085338804195517, 2.3293606772805004, 2.34969557465035, 2.3695318131200125, 2.38886285942426, 2.407682401704022, 2.4259843452056185, 2.4437628083767597, 2.461012119322994, 2.477726812591757, 2.493901626254288, 2.509531499258463, 2.5246115690281266, 2.539137169286768, 2.5531038280854164, 2.5665072660165142, 2.579343394597159, 2.591608314806646, 2.603298315764611, 2.6144098735373182, 2.6249396500607656, 2.634884492170348, 2.6442414307277162, 2.6530076798363775, 2.661180636138363, 2.668757878185002, 2.675737165875544, 2.6821164399579756, 2.687893821586951, 2.693067611934312, 2.6976362918481573, 2.7015985215568876, 2.7049531404151312, 2.7076991666888195, 2.709835797377134, 2.7113624080693897, 2.712278552835313], [2.7340585287594683, 2.733751716789256, 2.7328313711433596, 2.7312977626327033, 2.729151342664725, 2.7263927433278123, 2.7230227775107645, 2.7190424390584873, 2.714452902965549, 2.709255525609578, 2.703451845026894, 2.697043581233163, 2.6900326365923175, 2.6824210962374297, 2.6742112285477218, 2.665405485686401, 2.6560065042045804, 2.646017105717128, 2.6354402976569475, 2.6242792741148535, 2.6125374167730024, 2.6002182959406275, 2.587325671701719, 2.5738634951852895, 2.5598359099698915, 2.5452472536352677, 2.530102059475248, 2.514405058387456, 2.498161180956926, 2.4813755597524425, 2.464053531856312, 2.446200641650373, 2.4278226438833554, 2.4089255070473015, 2.389515417093568, 2.3695987815221433, 2.3491822338815247, 2.328272638720321, 2.3068770970361383, 2.2850029522721913, 2.262657796917544, 2.239849479772967, 2.216586113951273, 2.192876085688575, 2.1687280640515523, 2.1441510116353637, 2.1191541963576843, 2.0937472044664247, 2.0679399548923376, 2.0417427150930085, 2.0151661185519467, 1.9882211841158741, 1.9609193373750684, 1.933272434316158, 1.9052927875042935, 1.876993195082621, 1.848386972911759, 1.8194879902109977, 1.7903107091066628, 1.7608702285419118, 1.7311823330566942, 1.7012635470070765, 1.6711311948600025, 1.6408034682730814, 1.6102995007492136, 1.5796394507425617, 1.5488445941848488, 1.5179374274979212, 1.4869417822577164, 1.4558829527726767, 1.424787837931024, 1.3936850987483829, 1.3626053330991004, 1.33158126912583, 1.3006479787715182, 1.269843112737149, 1.2392071578993527, 1.2087837177739797, 1.1786198159200594, 1.148766221160822, 1.119277792052754, 1.090213836037645, 1.0616384760256627, 1.0336210136276904, 1.006236273734568, 0.9795649095133225, 0.9536936401170545, 0.9287153855924658, 0.9047292549637526, 0.8818403349785432, 0.8601592197121867, 0.8398012169243184, 0.8208851681452504, 0.8035318288087878, 0.7878617752662991, 0.7739928394271197, 0.7620371194740723, 0.7520976739481566, 0.7442650698269309, 0.7386140123377072, 0.7352003218706407, 0.7340585287594683, 0.7352003218706431, 0.738614012337712, 0.7442650698269379, 0.7520976739481658, 0.7620371194740835, 0.7739928394271329, 0.7878617752663142, 0.8035318288088047, 0.820885168145269, 0.8398012169243386, 0.8601592197122082, 0.881840334978566, 0.9047292549637769, 0.9287153855924908, 0.9536936401170804, 0.9795649095133495, 1.0062362737345956, 1.033621013627719, 1.0616384760256918, 1.0902138360376745, 1.119277792052784, 1.1487662211608527, 1.1786198159200902, 1.208783717774011, 1.239207157899384, 1.2698431127371805, 1.30064797877155, 1.3315812691258617, 1.3626053330991323, 1.3936850987484146, 1.4247878379310557, 1.455882952772709, 1.4869417822577484, 1.5179374274979531, 1.5488445941848805, 1.5796394507425935, 1.610299500749245, 1.6408034682731127, 1.6711311948600336, 1.7012635470071076, 1.7311823330567246, 1.7608702285419424, 1.7903107091066928, 1.8194879902110275, 1.8483869729117883, 1.8769931950826504, 1.9052927875043224, 1.9332724343161862, 1.9609193373750966, 1.988221184115902, 2.0151661185519743, 2.0417427150930356, 2.0679399548923643, 2.093747204466451, 2.11915419635771, 2.144151011635389, 2.168728064051577, 2.1928760856886, 2.216586113951297, 2.2398494797729906, 2.262657796917567, 2.2850029522722144, 2.30687709703616, 2.3282726387203425, 2.3491822338815456, 2.3695987815221633, 2.389515417093588, 2.4089255070473214, 2.4278226438833754, 2.4462006416503916, 2.464053531856331, 2.4813755597524607, 2.4981611809569437, 2.514405058387472, 2.5301020594752637, 2.5452472536352833, 2.5598359099699057, 2.573863495185303, 2.5873256717017328, 2.600218295940641, 2.612537416773015, 2.6242792741148646, 2.6354402976569586, 2.6460171057171387, 2.6560065042045897, 2.6654054856864104, 2.6742112285477306, 2.682421096237438, 2.6900326365923246, 2.6970435812331703, 2.7034518450269003, 2.709255525609584, 2.714452902965554, 2.7190424390584913, 2.723022777510768, 2.7263927433278154, 2.729151342664727, 2.731297762632705, 2.732831371143361, 2.7337517167892575], [2.7548229391532653, 2.754514793611544, 2.7535904483125244, 2.752050177252688, 2.7498944371531833, 2.7471238675509713, 2.7437392909277083, 2.739741712877633, 2.7351323223161295, 2.72991249173102, 2.7240837774790516, 2.7176479201304713, 2.7106068448650293, 2.702962661923226, 2.6947176671171085, 2.685874342405494, 2.6764353565390016, 2.6664035657809695, 2.6557820147109354, 2.6445739371180843, 2.6327827569928743, 2.620412089625853, 2.607465742823609, 2.593947718252807, 2.579862212924343, 2.56521362083085, 2.5500065347521037, 2.534245748244325, 2.517936257830945, 2.501083265414188, 2.4836921809287142, 2.4657686252607434, 2.447318433458415, 2.4283476582617816, 2.4088625739837073, 2.3888696807762115, 2.368375709320337, 2.347387625981633, 2.3259126384777806, 2.3039582021098277, 2.281532026614027, 2.2586420836974317, 2.235296615327289, 2.2115041428519517, 2.1872734770397027, 2.1626137291314516, 2.137534323014149, 2.1120450086338374, 2.0861558767808632, 2.059877375395022, 2.0332203275555094, 2.006195951339753, 1.9788158817567307, 1.9510921949845474, 1.9230374351691246, 1.8946646440711865, 1.8659873938826885, 1.8370198235717548, 1.8077766791574688, 1.778273358362915, 1.7485259601469674, 1.7185513396728789, 1.6883671693348596, 1.6579920065326863, 1.627445368958745, 1.5967478182412984, 1.565921052871159, 1.5349880114246977, 1.5039729871814456, 1.4729017553155426, 1.4418017139110029, 1.4107020401029162, 1.3796338626686668, 1.3486304523690917, 1.317727431247649, 1.2869630019074103, 1.2563781974631876, 1.2260171523604717, 1.1959273935018069, 1.166160150047281, 1.1367706787649143, 1.107818599788781, 1.0793682349748546, 1.0514889375998693, 1.024255397812239, 0.9977479029418862, 0.972052525517443, 0.9472612047814005, 0.9234716800237547, 0.9007872268898107, 0.8793161421056205, 0.8591709194522656, 0.8404670624408342, 0.8233214894429569, 0.8078505073807455, 0.7941673620695527, 0.7823794168360968, 0.7725850633237592, 0.764870523317802, 0.7593067486326163, 0.7559466564064954, 0.754822939153265, 0.7559466564064977, 0.7593067486326209, 0.7648705233178089, 0.7725850633237682, 0.7823794168361079, 0.7941673620695658, 0.8078505073807605, 0.8233214894429736, 0.8404670624408528, 0.8591709194522855, 0.8793161421056419, 0.9007872268898334, 0.9234716800237786, 0.9472612047814254, 0.972052525517469, 0.9977479029419131, 1.0242553978122666, 1.0514889375998975, 1.0793682349748834, 1.1078185997888106, 1.1367706787649443, 1.1661601500473116, 1.1959273935018377, 1.2260171523605028, 1.2563781974632189, 1.2869630019074418, 1.3177274312476808, 1.3486304523691237, 1.3796338626686988, 1.410702040102948, 1.4418017139110348, 1.4729017553155745, 1.5039729871814775, 1.5349880114247298, 1.5659210528711907, 1.5967478182413302, 1.627445368958777, 1.6579920065327174, 1.6883671693348905, 1.71855133967291, 1.748525960146998, 1.7782733583629453, 1.8077766791574994, 1.8370198235717845, 1.8659873938827183, 1.8946646440712156, 1.9230374351691537, 1.951092194984576, 1.9788158817567592, 2.006195951339781, 2.033220327555537, 2.0598773753950494, 2.08615587678089, 2.1120450086338636, 2.137534323014175, 2.162613729131477, 2.187273477039728, 2.211504142851976, 2.2352966153273126, 2.258642083697456, 2.28153202661405, 2.3039582021098504, 2.3259126384778033, 2.3473876259816553, 2.3683757093203583, 2.3888696807762324, 2.408862573983727, 2.4283476582618015, 2.4473184334584355, 2.4657686252607616, 2.4836921809287325, 2.5010832654142052, 2.517936257830962, 2.5342457482443415, 2.55000653475212, 2.5652136208308653, 2.579862212924358, 2.593947718252821, 2.607465742823623, 2.620412089625866, 2.6327827569928868, 2.644573937118096, 2.6557820147109465, 2.6664035657809806, 2.676435356539011, 2.685874342405503, 2.6947176671171174, 2.7029626619232334, 2.710606844865037, 2.7176479201304784, 2.724083777479058, 2.7299124917310253, 2.7351323223161352, 2.739741712877638, 2.7437392909277127, 2.747123867550975, 2.749894437153186, 2.75205017725269, 2.753590448312526, 2.7545147936115444], [2.7748571071028976, 2.774547693808068, 2.773619546276774, 2.772072941587942, 2.769908341604422, 2.767126393070619, 2.763727927750464, 2.7597139626070786, 2.755085700025818, 2.749844528082842, 2.743992020861727, 2.737529938821121, 2.7304602292168716, 2.722785026582562, 2.7145066532729034, 2.7056276200749716, 2.6961506268928774, 2.6860785635120856, 2.6754145104502727, 2.664161739902354, 2.6523237167880978, 2.639904099911612, 2.6269067432429285, 2.6133356973329263, 2.599195210873955, 2.584489732419762, 2.5692239122796288, 2.5534026046031495, 2.5370308696736577, 2.5201139764301277, 2.502657405239328, 2.484666850942183, 2.466148226200722, 2.4471076651746193, 2.4275515275593147, 2.407486403020966, 2.38691911606709, 2.36585673139583, 2.344306559771231, 2.32227616447694, 2.2997733684062807, 2.2768062618528986, 2.253383211073059, 2.2295128676984506, 2.2052041790869716, 2.180466399708644, 2.1553091036746035, 2.1297421985292186, 2.103775940438909, 2.0774209509264034, 2.050688235316125, 2.023589203075395, 1.9961356902573815, 1.9683399842754956, 1.9402148512654998, 1.9117735663212454, 1.8830299469230172, 1.85399838991425, 1.8246939124232067, 1.7951321971713803, 1.7653296426601768, 1.7353034187820027, 1.7050715284613578, 1.6746528759957546, 1.6440673428349335, 1.613335871609127, 1.582480559291789, 1.5515247604571836, 1.520493201665469, 1.489412108072952, 1.4583093434166636, 1.4272145645515408, 1.3961593917131447, 1.3651775956227141, 1.3343053024226292, 1.303581217200466, 1.2730468664916144, 1.2427468595965907, 1.2127291677504606, 1.1830454190656114, 1.1537512056492778, 1.124906397275201, 1.0965754533582093, 1.0688277216368545, 1.0417377078267613, 1.0153852955269982, 0.9898558898924389, 0.965240452221336, 0.9416353860625185, 0.9191422294358271, 0.8978671033762968, 0.8779198657704981, 0.8594129232447981, 0.8424596647796068, 0.8271725006664928, 0.8136605205117472, 0.8020268237654599, 0.7923656229150573, 0.784759267408359, 0.7792753773723049, 0.7759643007585225, 0.7748571071028976, 0.7759643007585247, 0.7792753773723096, 0.7847592674083657, 0.7923656229150663, 0.8020268237654709, 0.8136605205117602, 0.8271725006665076, 0.8424596647796234, 0.8594129232448162, 0.877919865770518, 0.8978671033763183, 0.9191422294358497, 0.9416353860625419, 0.9652404522213608, 0.9898558898924645, 1.0153852955270248, 1.0417377078267887, 1.0688277216368827, 1.0965754533582381, 1.1249063972752302, 1.1537512056493078, 1.1830454190656416, 1.2127291677504914, 1.2427468595966218, 1.2730468664916457, 1.3035812172004977, 1.3343053024226608, 1.3651775956227459, 1.3961593917131767, 1.4272145645515726, 1.458309343416696, 1.4894121080729843, 1.5204932016655008, 1.5515247604572153, 1.582480559291821, 1.6133358716091586, 1.644067342834965, 1.674652875995786, 1.7050715284613889, 1.7353034187820338, 1.7653296426602076, 1.795132197171411, 1.8246939124232369, 1.8539983899142802, 1.883029946923047, 1.9117735663212747, 1.9402148512655288, 1.968339984275524, 1.99613569025741, 2.023589203075423, 2.0506882353161524, 2.077420950926431, 2.1037759404389362, 2.1297421985292453, 2.1553091036746297, 2.1804663997086693, 2.205204179086997, 2.2295128676984755, 2.2533832110730834, 2.2768062618529226, 2.299773368406304, 2.3222761644769627, 2.3443065597712542, 2.3658567313958527, 2.386919116067112, 2.407486403020987, 2.427551527559335, 2.447107665174639, 2.4661482262007417, 2.484666850942202, 2.5026574052393458, 2.5201139764301455, 2.537030869673674, 2.553402604603166, 2.569223912279645, 2.5844897324197778, 2.59919521087397, 2.6133356973329405, 2.6269067432429423, 2.639904099911625, 2.6523237167881097, 2.664161739902366, 2.6754145104502842, 2.6860785635120963, 2.6961506268928876, 2.705627620074981, 2.7145066532729123, 2.72278502658257, 2.730460229216879, 2.7375299388211283, 2.7439920208617337, 2.7498445280828476, 2.755085700025823, 2.7597139626070826, 2.7637279277504683, 2.767126393070622, 2.7699083416044243, 2.7720729415879433, 2.773619546276776, 2.774547693808069], [2.794141650844761, 2.7938310344061787, 2.792899278434728, 2.7913466629838823, 2.789173654878216, 2.7863809078172546, 2.7829692625222164, 2.7789397469269934, 2.7742935764151424, 2.769032154105068, 2.7631570711860025, 2.756670107307857, 2.749573231028471, 2.7418686003223125, 2.7335585631551873, 2.7246456581300977, 2.7151326152099746, 2.705022356523686, 2.6943179972623748, 2.683022846673976, 2.6711404091645403, 2.658674385515898, 2.645628674230136, 2.63200737301243, 2.61781478040489, 2.603055397585341, 2.5877339303463347, 2.571855291271175, 2.555424602125404, 2.538447196484009, 2.5209286226166077, 2.502874646655089, 2.484291256070631, 2.4651846634896932, 2.4455613108815966, 2.425427874153606, 2.404791268193098, 2.3836586524004706, 2.3620374367610077, 2.3399352885089058, 2.3173601394423167, 2.294320193954477, 2.2708239378529638, 2.246880148046861, 2.222497903190297, 2.1976865953804405, 2.1724559430188615, 2.146816004957181, 2.1207771960614057, 2.0943503043443776, 2.067546509832547, 2.0403774053520407, 2.012855019439921, 1.9849918416098828, 1.9568008502276266, 1.9282955432801012, 1.8994899723549474, 1.870398780182078, 1.8410372421286834, 1.8114213120822644, 1.781567673203733, 1.751493794084284, 1.7212179908955805, 1.6907594961825183, 1.6601385350109332, 1.6293764092480623, 1.5984955908198795, 1.5675198248542077, 1.5364742436783922, 1.5053854926904555, 1.4742818691563175, 1.4431934749936397, 1.4121523845726975, 1.3811928284798263, 1.3503513940276235, 1.319667243029923, 1.2891823469524046, 1.2589417389560116, 1.2289937815140064, 1.1993904471368726, 1.1701876082037261, 1.141445329886712, 1.1132281575747933, 1.0856053869707731, 1.058651301089714, 1.0324453537185128, 1.0070722735855213, 0.9826220577581447, 0.959189817063583, 0.9368754313160116, 0.9157829688671861, 0.8960198248625433, 0.8776955372588838, 0.8609202509254809, 0.8458028195396691, 0.8324485632448813, 0.8209567364626542, 0.8114178020756133, 0.8039106502843892, 0.7984999355733866, 0.7952337252536711, 0.7941416508447611, 0.7952337252536734, 0.7984999355733913, 0.8039106502843958, 0.8114178020756221, 0.8209567364626651, 0.832448563244894, 0.8458028195396836, 0.8609202509254974, 0.877695537258902, 0.8960198248625628, 0.915782968867207, 0.936875431316034, 0.9591898170636064, 0.9826220577581692, 1.0070722735855469, 1.0324453537185392, 1.0586513010897414, 1.0856053869708011, 1.113228157574822, 1.1414453298867413, 1.170187608203756, 1.1993904471369028, 1.228993781514037, 1.2589417389560424, 1.2891823469524357, 1.3196672430299545, 1.350351394027655, 1.381192828479858, 1.4121523845727293, 1.4431934749936717, 1.4742818691563497, 1.5053854926904875, 1.536474243678424, 1.56751982485424, 1.5984955908199112, 1.629376409248094, 1.660138535010965, 1.69075949618255, 1.721217990895612, 1.7514937940843156, 1.781567673203764, 1.811421312082295, 1.8410372421287138, 1.8703987801821085, 1.8994899723549776, 1.9282955432801305, 1.9568008502276557, 1.984991841609912, 2.0128550194399493, 2.0403774053520687, 2.0675465098325745, 2.094350304344405, 2.1207771960614323, 2.1468160049572074, 2.1724559430188877, 2.197686595380466, 2.222497903190322, 2.2468801480468863, 2.2708239378529878, 2.294320193954501, 2.31736013944234, 2.339935288508929, 2.36203743676103, 2.383658652400493, 2.4047912681931196, 2.4254278741536277, 2.445561310881617, 2.4651846634897128, 2.4842912560706507, 2.5028746466551075, 2.5209286226166254, 2.5384471964840274, 2.555424602125422, 2.5718552912711914, 2.587733930346351, 2.603055397585357, 2.6178147804049057, 2.6320073730124447, 2.645628674230149, 2.6586743855159107, 2.671140409164553, 2.683022846673988, 2.6943179972623863, 2.705022356523697, 2.715132615209985, 2.724645658130107, 2.733558563155196, 2.741868600322321, 2.7495732310284784, 2.7566701073078637, 2.763157071186009, 2.7690321541050738, 2.7742935764151473, 2.778939746926998, 2.782969262522221, 2.7863809078172577, 2.789173654878218, 2.791346662983884, 2.7928992784347293, 2.7938310344061787], [2.8126579138282577, 2.8123461577049422, 2.8114109836329657, 2.809852674528005, 2.8076717019889466, 2.804868726407715, 2.8014445971244144, 2.7974003526291744, 2.7927372208125156, 2.7874566192664663, 2.7815601556391116, 2.7750496280457235, 2.7679270255400947, 2.7601945286502225, 2.7518545099830316, 2.742909534903382, 2.733362362293263, 2.7232159453976936, 2.7124734327645954, 2.701138169286642, 2.689213697353947, 2.6767037581273283, 2.663612292942884, 2.649943444859667, 2.6357015603634126, 2.6208911912405637, 2.605517096638187, 2.5895842453269595, 2.5730978181860236, 2.556063210930414, 2.5384860371037337, 2.5203721313610434, 2.5017275530693786, 2.482558590256045, 2.4628717639378714, 2.442673832867934, 2.421971798739987, 2.400772911894942, 2.3790846775782826, 2.3569148628024124, 2.3342715038735165, 2.3111629146488317, 2.287597695597155, 2.2635847437432086, 2.2391332635851304, 2.214252779083978, 2.188953146834909, 2.163244570541659, 2.137137616929305, 2.1106432332452036, 2.0837727665145658, 2.0565379847356566, 2.02895110022016, 2.0010247953071683, 1.9727722507046772, 1.9442071767406661, 1.9153438478370517, 1.8861971405542335, 1.8567825755918106, 1.827116364172505, 1.7972154592814642, 1.7670976122819135, 1.7367814354804274, 1.7062864712704624, 1.6756332685405386, 1.6448434670924035, 1.613939890872844, 1.582946650878016, 1.5518892586374482, 1.5207947512211741, 1.4896918287306826, 1.458611005223036, 1.427584773964922, 1.3966477878028882, 1.365837055245896, 1.335192152558758, 1.3047554517249584, 1.2745723635110935, 1.244691593999762, 1.2151654117904838, 1.1860499215275147, 1.1574053374217277, 1.1292962479133624, 1.1017918595064333, 1.0749662040548715, 1.0488982894098882, 1.0236721684526293, 0.9993768963781611, 0.9761063411010975, 0.9539588075033251, 0.9330364339143966, 0.9134443199721182, 0.8952893503420941, 0.8786786902029626, 0.8637179471555405, 0.8505090207463055, 0.8391476942400402, 0.8297210609469349, 0.8223049146005594, 0.8169612636082183, 0.8137361454247116, 0.8126579138282576, 0.8137361454247138, 0.8169612636082227, 0.8223049146005661, 0.8297210609469438, 0.8391476942400509, 0.8505090207463182, 0.8637179471555548, 0.8786786902029788, 0.8952893503421119, 0.9134443199721375, 0.9330364339144174, 0.9539588075033473, 0.9761063411011209, 0.9993768963781854, 1.0236721684526549, 1.0488982894099146, 1.0749662040548988, 1.1017918595064613, 1.129296247913391, 1.157405337421757, 1.1860499215275446, 1.215165411790514, 1.2446915939997925, 1.2745723635111246, 1.3047554517249897, 1.3351921525587893, 1.3658370552459276, 1.39664778780292, 1.4275847739649539, 1.4586110052230683, 1.4896918287307146, 1.5207947512212063, 1.5518892586374804, 1.5829466508780479, 1.6139398908728755, 1.644843467092435, 1.67563326854057, 1.7062864712704933, 1.7367814354804585, 1.7670976122819444, 1.797215459281495, 1.8271163641725356, 1.8567825755918412, 1.8861971405542635, 1.9153438478370817, 1.9442071767406957, 1.9727722507047065, 2.001024795307197, 2.0289511002201883, 2.0565379847356846, 2.0837727665145938, 2.1106432332452307, 2.137137616929332, 2.1632445705416856, 2.188953146834936, 2.214252779084004, 2.2391332635851557, 2.2635847437432335, 2.287597695597179, 2.3111629146488557, 2.3342715038735395, 2.356914862802435, 2.3790846775783057, 2.4007729118949643, 2.421971798740009, 2.4426738328679547, 2.462871763937892, 2.4825585902560654, 2.501727553069398, 2.520372131361062, 2.5384860371037523, 2.5560632109304318, 2.573097818186041, 2.5895842453269764, 2.605517096638204, 2.6208911912405797, 2.6357015603634273, 2.649943444859681, 2.663612292942898, 2.676703758127341, 2.689213697353959, 2.701138169286654, 2.712473432764606, 2.7232159453977043, 2.733362362293273, 2.742909534903391, 2.7518545099830405, 2.7601945286502314, 2.767927025540102, 2.7750496280457306, 2.781560155639118, 2.787456619266472, 2.792737220812521, 2.797400352629179, 2.801444597124418, 2.8048687264077183, 2.8076717019889488, 2.8098526745280066, 2.8114109836329675, 2.8123461577049436], [2.8303879827648046, 2.830075149323747, 2.829136744213406, 2.827573053095184, 2.8253845521479772, 2.822571908183717, 2.8191359788105457, 2.815077812645051, 2.8103986495754114, 2.80509992107775, 2.799183250588425, 2.7926504539354964, 2.7855035398330643, 2.7777447104427333, 2.7693763620069856, 2.7604010855598506, 2.7508216677208837, 2.740641091579142, 2.729862537674571, 2.7184893850849945, 2.7065252126277515, 2.6939738001859412, 2.6808391301702277, 2.66712538912824, 2.6528369695147984, 2.6379784716374783, 2.6225547057934384, 2.606570694614996, 2.590031675643138, 2.5729431041500104, 2.555310656233512, 2.537140232209363, 2.518437960328533, 2.4992102008506816, 2.479463550507293, 2.459204847391581, 2.438441176315984, 2.417179874682179, 2.3954285389131593, 2.373195031502016, 2.350487488737692, 2.327314329174281, 2.3036842629174257, 2.2796063018091077, 2.255089770600797, 2.2301443192144856, 2.204779936201891, 2.1790069635239364, 2.1528361127859337, 2.126278483078583, 2.099345580591304, 2.0720493401826423, 2.0444021491126945, 2.01641687316495, 1.9881068854097756, 1.959486097889227, 1.930568996533126, 1.9013706796496077, 1.8719069003697182, 1.842194113465289, 1.8122495270021814, 1.7820911593370143, 1.751737902014371, 1.7212095891726649, 1.6905270741194933, 1.65971231379004, 1.6287884618529571, 1.5977799712743117, 1.5667127071877167, 1.5356140709422497, 1.5045131362019386, 1.4734407979416855, 1.4424299351117484, 1.4115155876095646, 1.380735147982361, 1.3501285679594628, 1.3197385794454801, 1.2896109289530402, 1.2597946235665236, 1.2303421853483367, 1.2013099095617676, 1.1727581201210642, 1.1447514132246346, 1.1173588771296987, 1.0906542724656065, 1.064716153393425, 1.0396279054255873, 1.0154776710772864, 0.9923581301662288, 0.9703660981696908, 0.9496019045018124, 0.9301685140472246, 0.9121703610999459, 0.8957118763108529, 0.8808957053211036, 0.8678206426880591, 0.8565793355152468, 0.847255845293019, 0.8399231895296114, 0.834641011118665, 0.8314535369338389, 0.8303879827648046, 0.8314535369338413, 0.8346410111186693, 0.839923189529618, 0.8472558452930276, 0.8565793355152574, 0.8678206426880716, 0.8808957053211179, 0.895711876310869, 0.9121703610999635, 0.9301685140472437, 0.9496019045018331, 0.9703660981697128, 0.992358130166252, 1.0154776710773106, 1.0396279054256126, 1.064716153393451, 1.0906542724656334, 1.1173588771297265, 1.1447514132246632, 1.1727581201210935, 1.2013099095617972, 1.2303421853483665, 1.2597946235665543, 1.289610928953071, 1.319738579445511, 1.3501285679594943, 1.3807351479823928, 1.4115155876095964, 1.4424299351117804, 1.473440797941717, 1.5045131362019706, 1.5356140709422819, 1.5667127071877485, 1.5977799712743435, 1.6287884618529889, 1.6597123137900716, 1.6905270741195246, 1.7212095891726964, 1.7517379020144022, 1.7820911593370456, 1.8122495270022125, 1.84219411346532, 1.8719069003697482, 1.9013706796496377, 1.930568996533156, 1.9594860978892565, 1.9881068854098045, 2.0164168731649785, 2.044402149112723, 2.0720493401826707, 2.0993455805913315, 2.12627848307861, 2.1528361127859608, 2.179006963523963, 2.2047799362019176, 2.230144319214512, 2.2550897706008217, 2.2796063018091326, 2.3036842629174497, 2.327314329174305, 2.350487488737716, 2.37319503150204, 2.395428538913182, 2.4171798746822013, 2.4384411763160054, 2.4592048473916015, 2.479463550507313, 2.499210200850702, 2.518437960328553, 2.5371402322093815, 2.5553106562335306, 2.5729431041500277, 2.5900316756431554, 2.606570694615013, 2.622554705793455, 2.637978471637494, 2.652836969514813, 2.667125389128254, 2.680839130170242, 2.693973800185955, 2.7065252126277644, 2.718489385085006, 2.729862537674583, 2.7406410915791524, 2.7508216677208934, 2.7604010855598604, 2.7693763620069944, 2.7777447104427417, 2.7855035398330714, 2.792650453935503, 2.799183250588432, 2.8050999210777556, 2.810398649575417, 2.815077812645055, 2.81913597881055, 2.82257190818372, 2.82538455214798, 2.8275730530951857, 2.829136744213407, 2.8300751493237475], [2.8473147049577845, 2.8470008555317854, 2.8460594033413966, 2.8444906366734384, 2.8422950360861194, 2.8394732745300293, 2.8360262175189646, 2.8319549233520633, 2.8272606433891245, 2.821944822381474, 2.816009098861153, 2.8094553055917504, 2.802285470084646, 2.7945018151850047, 2.786106759732427, 2.777102919301732, 2.76749310703003, 2.7572803345368997, 2.7464678129452382, 2.735058954011146, 2.723057371372066, 2.710466881923331, 2.697291507334291, 2.6835354757162784, 2.66920322345589, 2.6542993972283644, 2.638828856207265, 2.622796674488263, 2.6062081437465254, 2.589068776149115, 2.57138430754589, 2.5531607009646846, 2.5344041504390606, 2.5151210851997456, 2.4953181742639057, 2.4750023314598244, 2.45418072092833, 2.4328607631464454, 2.4110501415233694, 2.3887568096240073, 2.3659889990809138, 2.3427552282618316, 2.319064311766963, 2.294925370837867, 2.270347844768514, 2.2453415034185364, 2.2199164609394186, 2.194083190836116, 2.1678525424997406, 2.1412357593615265, 2.1142444988344278, 2.086890854226649, 2.0591873788312562, 2.031147112417976, 2.002783610377536, 1.9741109757956055, 1.9451438947627142, 1.9158976752586336, 1.886388289984634, 1.8566324235548888, 1.826647524499001, 1.7964518625709323, 1.766064591905237, 1.7355058206086826, 1.7047966874231584, 1.673959446142642, 1.6430175585108378, 1.611995796363852, 1.5809203538098093, 1.5498189702490244, 1.5187210650267564, 1.4876578844657888, 1.456662661935223, 1.4257707914583524, 1.3950200151251573, 1.3644506242273284, 1.3341056735430048, 1.3040312075250273, 1.274276496243536, 1.2448942777476335, 1.2159410019829542, 1.1874770694723975, 1.1595670555815025, 1.1322799083099118, 1.1056891041710535, 1.079872742895095, 1.054913557554506, 1.0308988125319494, 1.007920057958081, 0.9860727064770556, 0.9654553973068226, 0.9461691146078026, 0.9283160333318126, 0.911998077108406, 0.897315190113558, 0.8843633483199058, 0.8732323639995466, 0.8640035683645814, 0.8567474868265822, 0.8515216444451315, 0.8483686503565612, 0.8473147049577844, 0.8483686503565633, 0.8515216444451358, 0.8567474868265885, 0.8640035683645898, 0.8732323639995572, 0.8843633483199181, 0.8973151901135722, 0.911998077108422, 0.92831603333183, 0.9461691146078216, 0.9654553973068432, 0.9860727064770775, 1.0079200579581038, 1.0308988125319734, 1.0549135575545312, 1.079872742895121, 1.1056891041710806, 1.1322799083099395, 1.159567055581531, 1.1874770694724264, 1.2159410019829837, 1.2448942777476637, 1.2742764962435664, 1.304031207525058, 1.3341056735430359, 1.36445062422736, 1.395020015125189, 1.425770791458384, 1.456662661935255, 1.4876578844658208, 1.5187210650267884, 1.5498189702490563, 1.5809203538098413, 1.6119957963638838, 1.6430175585108693, 1.6739594461426734, 1.70479668742319, 1.7355058206087137, 1.766064591905268, 1.7964518625709633, 1.826647524499032, 1.8566324235549196, 1.8863882899846645, 1.9158976752586638, 1.945143894762744, 1.974110975795635, 2.002783610377566, 2.0311471124180054, 2.059187378831285, 2.0868908542266773, 2.1142444988344553, 2.1412357593615536, 2.1678525424997677, 2.1940831908361433, 2.2199164609394457, 2.245341503418562, 2.2703478447685397, 2.294925370837892, 2.3190643117669874, 2.342755228261856, 2.365988999080937, 2.3887568096240304, 2.411050141523392, 2.4328607631464676, 2.4541807209283517, 2.4750023314598453, 2.4953181742639257, 2.515121085199766, 2.53440415043908, 2.5531607009647033, 2.571384307545909, 2.5890687761491322, 2.606208143746543, 2.6227966744882805, 2.6388288562072817, 2.65429939722838, 2.669203223455904, 2.683535475716292, 2.697291507334305, 2.710466881923345, 2.7230573713720787, 2.7350589540111576, 2.7464678129452493, 2.75728033453691, 2.76749310703004, 2.777102919301741, 2.7861067597324363, 2.7945018151850136, 2.802285470084654, 2.8094553055917575, 2.8160090988611595, 2.8219448223814796, 2.82726064338913, 2.8319549233520673, 2.836026217518969, 2.839473274530033, 2.8422950360861217, 2.84449063667344, 2.846059403341398, 2.847000855531786], [2.86342170489667, 2.8631068998416827, 2.8621625815978384, 2.8605890409535215, 2.858386762639648, 2.8555564254558323, 2.8520989024484753, 2.8480152611422973, 2.8433067638272145, 2.8379748679029713, 2.832021226284373, 2.8254476878704837, 2.8182562980816477, 2.810449299468759, 2.8020291323997633, 2.792998435828997, 2.7833600481556227, 2.7731170081781022, 2.762272556152432, 2.75083013496264, 2.738793391412946, 2.7261661776519017, 2.7129525527399005, 2.699156784372512, 2.6847833507733525, 2.669836942771515, 2.6543224660800346, 2.638245043793462, 2.621610019124353, 2.6044229584004093, 2.5866896543460816, 2.5684161296747945, 2.5496086410204737, 2.530273683239873, 2.5104179941202935, 2.4900485595307207, 2.4691726190581593, 2.4477976721751635, 2.4259314849891345, 2.403582097629134, 2.3807578323316014, 2.3574673022926507, 2.3337194213616086, 2.30952341465819, 2.2848888302042645, 2.259825551670702, 2.234343812350335, 2.20845421047979, 2.1821677260459174, 2.155495739226946, 2.1284500506344255, 2.101042903539639, 2.073287008287672, 2.0451955691237833, 2.0167823136803964, 1.9880615253989846, 1.9590480791895264, 1.9297574806611721, 1.900205909291291, 1.8704102659362218, 1.8403882251256063, 1.8101582926229685, 1.779739868777654, 1.749153318236679, 1.718420046628245, 1.6875625848700957, 1.6566046817931421, 1.6255714058007462, 1.5944892563023754, 1.563386285661259, 1.532292232371595, 1.5012386661217223, 1.470259145292706, 1.4393893872704453, 1.4086674516929878, 1.3781339363874558, 1.3478321852413346, 1.3178085065631475, 1.288112399573821, 1.2587967854828859, 1.229918238090163, 1.2015372069614685, 1.1737182239112651, 1.1465300807598138, 1.1200459631253206, 1.0943435214278585, 1.0695048564718037, 1.0456163932069125, 1.022768612969505, 1.0010556122829193, 0.9805744559529087, 0.9614242946975926, 0.9437052239503197, 0.9275168717249421, 0.9129567201464613, 0.900118187357758, 0.8890885229255453, 0.8799465982242614, 0.8727606999267522, 0.8675864550932191, 0.8644650256887061, 0.8634217048966701, 0.8644650256887082, 0.8675864550932234, 0.8727606999267585, 0.8799465982242699, 0.8890885229255558, 0.9001181873577702, 0.9129567201464753, 0.9275168717249579, 0.9437052239503372, 0.9614242946976116, 0.9805744559529289, 1.001055612282941, 1.0227686129695277, 1.0456163932069364, 1.0695048564718288, 1.0943435214278847, 1.1200459631253474, 1.1465300807598413, 1.1737182239112933, 1.2015372069614971, 1.2299182380901923, 1.2587967854829154, 1.2881123995738515, 1.3178085065631782, 1.3478321852413655, 1.3781339363874867, 1.4086674516930193, 1.4393893872704768, 1.4702591452927378, 1.501238666121754, 1.5322922323716273, 1.563386285661291, 1.5944892563024071, 1.6255714058007784, 1.656604681793174, 1.6875625848701277, 1.7184200466282764, 1.7491533182367103, 1.7797398687776853, 1.8101582926229998, 1.8403882251256374, 1.8704102659362527, 1.9002059092913215, 1.9297574806612026, 1.9590480791895566, 1.988061525399014, 2.016782313680426, 2.0451955691238126, 2.073287008287701, 2.1010429035396676, 2.1284500506344535, 2.1554957392269745, 2.1821677260459444, 2.208454210479817, 2.2343438123503616, 2.2598255516707275, 2.2848888302042902, 2.309523414658215, 2.3337194213616326, 2.3574673022926746, 2.380757832331626, 2.403582097629157, 2.425931484989157, 2.447797672175186, 2.4691726190581815, 2.4900485595307416, 2.510417994120315, 2.5302736832398933, 2.5496086410204932, 2.568416129674813, 2.5866896543460998, 2.6044229584004275, 2.62161001912437, 2.6382450437934786, 2.654322466080051, 2.669836942771531, 2.684783350773368, 2.6991567843725264, 2.712952552739914, 2.726166177651914, 2.7387933914129583, 2.7508301349626523, 2.762272556152443, 2.773117008178113, 2.7833600481556333, 2.792998435829007, 2.8020291323997717, 2.810449299468767, 2.8182562980816552, 2.825447687870491, 2.8320212262843794, 2.837974867902977, 2.8433067638272194, 2.848015261142302, 2.8520989024484793, 2.8555564254558354, 2.8583867626396504, 2.860589040953523, 2.86216258159784, 2.8631068998416827], [2.878693400099275, 2.8783776988512155, 2.877430692819312, 2.875852675166386, 2.8736441345840045, 2.8708057554235262, 2.867338417881073, 2.863243198237932, 2.85852136915837, 2.853174400047279, 2.8472039574705668, 2.8406119056417185, 2.8334003069784504, 2.825571422733966, 2.81712771370788, 2.808071841042522, 2.7984066671109735, 2.788135256503928, 2.7772608771231866, 2.765787001390476, 2.753717307581104, 2.741055681292981, 2.7278062170625317, 2.7139732201401854, 2.6995612084393508, 2.684574914674121, 2.6690192887024358, 2.652899500093028, 2.636220940936238, 2.6189892289207215, 2.601210210700184, 2.582889965576621, 2.564034809529094, 2.5446512996199098, 2.5247462388131874, 2.5043266812442146, 2.483399937981826, 2.4619735833301877, 2.440055461721051, 2.4176536952526253, 2.394776691936923, 2.3714331547237104, 2.347632091376128, 2.3233828252807984, 2.298695007283727, 2.273578628652802, 2.2480440352781503, 2.222101943233231, 2.195763455832367, 2.169040082334657, 2.141943758459881, 2.1144868688993665, 2.0866822720238827, 2.0585433270116495, 2.0300839236426134, 2.001318515030383, 1.9722621535907277, 1.9429305305753874, 1.9133400195321548, 1.8835077240866416, 1.8534515304777315, 1.8231901653170302, 1.792743259082131, 1.7621314158933667, 1.7313762901626584, 1.7005006707393442, 1.6695285732090461, 1.6384853410243745, 1.6073977561561423, 1.5762941599448383, 1.5452045847966869, 1.514160897296653, 1.4831969531894096, 1.452348764492317, 1.4216546787315363, 1.3911555699085023, 1.3608950402788393, 1.3309196313236125, 1.3012790413723812, 1.2720263461532992, 1.2432182170498403, 1.21491512999114, 1.1871815556571774, 1.160086119024819, 1.1337017132354075, 1.1081055494049177, 1.0833791204823855, 1.0596080538633785, 1.0368818245982887, 1.015293299282306, 0.9949380808269711, 0.9759136271807439, 0.9583181236249185, 0.9422490993458632, 0.9278017950496512, 0.9150673092709656, 0.904130575625168, 0.8950682493106837, 0.8879466053155933, 0.8828195688670023, 0.8797270064679892, 0.8786934000992751, 0.8797270064679912, 0.8828195688670066, 0.8879466053155997, 0.8950682493106921, 0.9041305756251783, 0.9150673092709777, 0.9278017950496651, 0.9422490993458791, 0.9583181236249358, 0.9759136271807629, 0.9949380808269914, 1.0152932992823278, 1.0368818245983116, 1.0596080538634023, 1.0833791204824104, 1.1081055494049437, 1.1337017132354343, 1.1600861190248466, 1.1871815556572058, 1.2149151299911687, 1.2432182170498696, 1.272026346153329, 1.3012790413724113, 1.330919631323643, 1.3608950402788704, 1.3911555699085334, 1.4216546787315676, 1.4523487644923487, 1.4831969531894418, 1.5141608972966851, 1.5452045847967188, 1.5762941599448705, 1.6073977561561748, 1.6384853410244065, 1.6695285732090779, 1.7005006707393757, 1.7313762901626901, 1.7621314158933983, 1.7927432590821621, 1.8231901653170612, 1.8534515304777621, 1.883507724086672, 1.9133400195321852, 1.9429305305754174, 1.9722621535907576, 2.0013185150304134, 2.030083923642643, 2.0585433270116784, 2.0866822720239115, 2.114486868899395, 2.1419437584599095, 2.1690400823346847, 2.1957634558323944, 2.2221019432332576, 2.248044035278177, 2.2735786286528277, 2.298695007283753, 2.3233828252808233, 2.347632091376153, 2.371433154723734, 2.394776691936947, 2.4176536952526484, 2.440055461721074, 2.46197358333021, 2.483399937981847, 2.5043266812442364, 2.524746238813208, 2.54465129961993, 2.5640348095291134, 2.58288996557664, 2.601210210700202, 2.6189892289207393, 2.636220940936255, 2.652899500093045, 2.669019288702452, 2.684574914674137, 2.699561208439366, 2.7139732201402, 2.7278062170625454, 2.7410556812929943, 2.7537173075811174, 2.7657870013904877, 2.7772608771231986, 2.7881352565039386, 2.7984066671109837, 2.8080718410425307, 2.8171277137078894, 2.825571422733975, 2.8334003069784583, 2.8406119056417256, 2.8472039574705725, 2.8531744000472847, 2.8585213691583755, 2.8632431982379365, 2.8673384178810766, 2.87080575542353, 2.8736441345840067, 2.8758526751663878, 2.877430692819313, 2.878377698851216], [2.8931150161867976, 2.8927984773178146, 2.8918489591709386, 2.890266757153295, 2.888052363700023, 2.8852064684099203, 2.8817299582368845, 2.8776239177386813, 2.8728896293850457, 2.867528573927576, 2.8615424308344046, 2.8549330787930827, 2.847702596285721, 2.8398532622409225, 2.8313875567676803, 2.8223081619770363, 2.8126179628979573, 2.8023200484946202, 2.7914177127930606, 2.779914456125968, 2.7678139865053297, 2.755120221133568, 2.741837288064887, 2.7279695280296843, 2.71352149643613, 2.698497965564371, 2.6829039269703028, 2.6667445941174717, 2.650025405257454, 2.632752026580983, 2.6149303556642676, 2.596566525237258, 2.577666907303215, 2.5582381176417806, 2.538287020730868, 2.5178207351261492, 2.4968466393407245, 2.4753723782717567, 2.453405870225498, 2.430955314597265, 2.4080292002686012, 2.384636314790113, 2.360785754425436, 2.3364869351394377, 2.3117496046222796, 2.286583855450337, 2.26100013949539, 2.235009283704991, 2.2086225073895878, 2.1818514411660517, 2.154708147722695, 2.127205144587905, 2.099355429103285, 2.071172505822716, 2.0426704165812746, 2.0138637735024787, 1.9847677952389524, 1.9553983467704352, 1.9257719831139237, 1.8959059973336612, 1.8658184732733374, 1.8355283434688716, 1.8050554527368774, 1.774420627970406, 1.7436457547085216, 1.7127538610777537, 1.6817692097290409, 1.6507173984098664, 1.6196254698134576, 1.588522031329029, 1.55743738527144, 1.5264036700851369, 1.4954550128832216, 1.4646276934818268, 1.4339603198028423, 1.4034940141201753, 1.373272609087062, 1.3433428517704866, 1.3137546129948847, 1.2845610981190518, 1.255819053894612, 1.227588964242232, 1.1999352256041607, 1.172926289981175, 1.1466347608671885, 1.1211374241401433, 1.0965151927181198, 1.0728529407169454, 1.050239200355539, 1.0287656935043163, 1.0085266702655453, 0.9896180301299019, 0.9721362079115968, 0.956176817537278, 0.941833062215457, 0.9291939392957269, 0.9183422911253867, 0.9093527772820512, 0.9022898655744989, 0.8972059553780473, 0.8941397534231477, 0.8931150161867976, 0.8941397534231499, 0.8972059553780514, 0.9022898655745051, 0.9093527772820597, 0.9183422911253969, 0.929193939295739, 0.9418330622154709, 0.9561768175372936, 0.9721362079116138, 0.9896180301299206, 1.0085266702655655, 1.0287656935043379, 1.0502392003555616, 1.0728529407169693, 1.0965151927181447, 1.121137424140169, 1.146634760867215, 1.172926289981202, 1.1999352256041889, 1.2275889642422608, 1.2558190538946412, 1.2845610981190816, 1.3137546129949151, 1.3433428517705173, 1.373272609087093, 1.4034940141202068, 1.4339603198028739, 1.4646276934818585, 1.4954550128832533, 1.5264036700851684, 1.557437385271472, 1.5885220313290611, 1.6196254698134893, 1.6507173984098988, 1.6817692097290726, 1.7127538610777855, 1.7436457547085529, 1.7744206279704373, 1.8050554527369087, 1.8355283434689031, 1.8658184732733685, 1.8959059973336922, 1.9257719831139544, 1.9553983467704654, 1.9847677952389826, 2.013863773502509, 2.0426704165813043, 2.071172505822745, 2.099355429103314, 2.127205144587933, 2.1547081477227232, 2.1818514411660797, 2.2086225073896153, 2.2350092837050184, 2.2610001394954167, 2.286583855450363, 2.3117496046223054, 2.336486935139463, 2.3607857544254602, 2.384636314790137, 2.408029200268625, 2.4309553145972886, 2.4534058702255206, 2.475372378271779, 2.4968466393407462, 2.51782073512617, 2.538287020730889, 2.558238117641801, 2.577666907303235, 2.596566525237277, 2.614930355664286, 2.632752026581001, 2.650025405257472, 2.6667445941174894, 2.6829039269703188, 2.698497965564387, 2.7135214964361443, 2.727969528029699, 2.741837288064901, 2.7551202211335815, 2.767813986505342, 2.77991445612598, 2.791417712793072, 2.802320048494632, 2.812617962897967, 2.8223081619770456, 2.831387556767689, 2.839853262240931, 2.8477025962857287, 2.8549330787930893, 2.8615424308344104, 2.867528573927583, 2.8728896293850505, 2.877623917738686, 2.881729958236888, 2.885206468409923, 2.8880523637000257, 2.890266757153297, 2.8918489591709395, 2.8927984773178155], [2.9066726011770783, 2.9063552824512664, 2.9054034254374206, 2.9038173276540773, 2.901597485058263, 2.898744592185454, 2.895259542347079, 2.891143427887131, 2.8863975404998983, 2.8810233716113514, 2.8750226128271703, 2.868397156450947, 2.8611490960766157, 2.8532807272597602, 2.8447945482730232, 2.8356932609514938, 2.8259797716346395, 2.8156571922120595, 2.8047288412811366, 2.7931982454254913, 2.7810691406240613, 2.7683454738016002, 2.755031404532475, 2.74113130691076, 2.726649771600928, 2.7115916080847717, 2.6959618471217066, 2.679765743441235, 2.663008778688138, 2.64569666464292, 2.627835346742196, 2.6094310079260548, 2.5904900728420306, 2.571019212438187, 2.5510253489809256, 2.530515661536632, 2.509497591960059, 2.4879788514365697, 2.4659674276300065, 2.443471592493072, 2.4204999108027985, 2.3970612494898997, 2.3731647878377653, 2.34882002863445, 2.324036810369508, 2.2988253205768077, 2.273196110434813, 2.2471601107471724, 2.2207286494390264, 2.193913470718278, 2.1667267560663293, 2.139181147239511, 2.111289771480824, 2.0830662691617348, 2.0545248240956897, 2.0256801967888984, 1.9965477609197362, 1.9671435433659121, 1.9374842681282172, 1.9075874045310761, 1.877471220112999, 1.8471548386538468, 1.8166583038199682, 1.7860026489416316, 1.7552099734684288, 1.724303526675435, 1.6933077992132732, 1.6622486231052873, 1.6311532807901292, 1.6000506237821255, 1.5689712014669666, 1.5379474004565323, 1.5070135947814183, 1.4762063069871352, 1.4455643799006426, 1.4151291584243482, 1.3849446801670209, 1.3550578730029563, 1.325518756725984, 1.2963806447947726, 1.2677003407118286, 1.2395383218066482, 1.2119589010814897, 1.185030355326171, 1.1588250049525175, 1.133419228031064, 1.108893388001293, 1.0853316517428164, 1.0628216725334123, 1.0414541114128242, 1.0213219712817465, 1.0025197214474844, 0.9851421970395323, 0.9692832683766159, 0.9550342902449983, 0.9424823598385809, 0.9317084337035432, 0.9227853763808174, 0.9157760336319458, 0.9107314377000684, 0.9076892575801194, 0.9066726011770783, 0.9076892575801216, 0.9107314377000726, 0.9157760336319521, 0.9227853763808255, 0.9317084337035534, 0.9424823598385929, 0.9550342902450122, 0.9692832683766316, 0.9851421970395494, 1.002519721447503, 1.0213219712817667, 1.0414541114128455, 1.062821672533435, 1.0853316517428402, 1.1088933880013176, 1.1334192280310897, 1.158825004952544, 1.185030355326198, 1.2119589010815175, 1.239538321806677, 1.2677003407118574, 1.296380644794802, 1.3255187567260143, 1.355057873002987, 1.3849446801670517, 1.4151291584243795, 1.4455643799006739, 1.4762063069871667, 1.50701359478145, 1.5379474004565639, 1.5689712014669985, 1.6000506237821577, 1.631153280790161, 1.6622486231053195, 1.6933077992133052, 1.7243035266754667, 1.7552099734684605, 1.7860026489416632, 1.8166583038199997, 1.8471548386538785, 1.87747122011303, 1.9075874045311074, 1.9374842681282476, 1.9671435433659425, 1.9965477609197662, 2.0256801967889286, 2.054524824095719, 2.083066269161764, 2.1112897714808527, 2.1391811472395394, 2.1667267560663577, 2.193913470718306, 2.2207286494390535, 2.2471601107471995, 2.273196110434839, 2.2988253205768334, 2.3240368103695337, 2.348820028634475, 2.3731647878377897, 2.3970612494899237, 2.4204999108028225, 2.4434715924930956, 2.4659674276300287, 2.4879788514365924, 2.5094975919600806, 2.530515661536653, 2.5510253489809465, 2.5710192124382076, 2.590490072842051, 2.6094310079260734, 2.6278353467422146, 2.645696664642937, 2.663008778688156, 2.679765743441252, 2.6959618471217226, 2.7115916080847873, 2.7266497716009432, 2.741131306910775, 2.755031404532489, 2.7683454738016136, 2.781069140624074, 2.793198245425504, 2.804728841281148, 2.81565719221207, 2.8259797716346498, 2.8356932609515035, 2.844794548273032, 2.853280727259769, 2.861149096076623, 2.8683971564509543, 2.875022612827177, 2.881023371611357, 2.8863975404999036, 2.891143427887135, 2.8952595423470835, 2.898744592185457, 2.9015974850582658, 2.903817327654079, 2.9054034254374215, 2.906355282451267], [2.9193530389822415, 2.9190349974108027, 2.9180809725184713, 2.916491263799775, 2.914266370507734, 2.911406991797838, 2.9079140269312136, 2.9037885755385338, 2.899031937946737, 2.8936456155711245, 2.8876313113758325, 2.8809909304063086, 2.873726580397862, 2.865840572465013, 2.857335421876938, 2.848213848924962, 2.8384787798887454, 2.828133348108544, 2.817180895171708, 2.8056249722224558, 2.793469341404842, 2.7807179774498643, 2.7673750694187076, 2.7534450226153018, 2.738932460682622, 2.7238422278985652, 2.7081793916887196, 2.691949245375014, 2.6751573111810076, 2.657809343516581, 2.6399113325669337, 2.621469508213173, 2.6024903443143854, 2.582980563383933, 2.5629471416959078, 2.5423973148610948, 2.521338583915649, 2.4997787219699146, 2.4777257814694233, 2.455188102125265, 2.4321743195766685, 2.4086933748548764, 2.3847545247242783, 2.360367352984393, 2.3355417828246714, 2.3102880903333674, 2.284616919271949, 2.2585392972377876, 2.232066653350278, 2.205210837609219, 2.177984142089273, 2.1503993241508246, 2.1224696318655587, 2.0942088318747873, 2.0656312399199703, 2.0367517543080753, 2.007585892599486, 1.9781498318329753, 1.9484604526307745, 1.9185353875568094, 1.8883930741323167, 1.8580528129448972, 1.8275348313187405, 1.7968603530442793, 1.7660516746933366, 1.735132249068903, 1.7041267763543226, 1.6730613035311805, 1.6419633326239358, 1.610861938296102, 1.5797878952597606, 1.5487738158573576, 1.5178542980196241, 1.4870660835805136, 1.4564482266203556, 1.426042271089187, 1.3958924364066432, 1.3660458090121754, 1.3365525369156697, 1.3074660231380761, 1.2788431124996662, 1.2507442644809115, 1.2232337028313287, 1.1963795302412343, 1.1702537937631572, 1.1449324838705561, 1.1204954472432085, 1.0970261908396024, 1.0746115529409295, 1.05334121613821, 1.0333070383082201, 1.0146021811836423, 0.9973200228546129, 0.9815528509792532, 0.9673903478289495, 0.9549178961970571, 0.9442147555569073, 0.9353521787158074, 0.9283915578463188, 0.9233827019856842, 0.9203623527674555, 0.9193530389822417, 0.9203623527674575, 0.9233827019856884, 0.9283915578463249, 0.9353521787158156, 0.9442147555569173, 0.954917896197069, 0.9673903478289633, 0.9815528509792686, 0.99732002285463, 1.0146021811836607, 1.0333070383082401, 1.0533412161382312, 1.074611552940952, 1.0970261908396262, 1.1204954472432334, 1.1449324838705819, 1.1702537937631836, 1.1963795302412616, 1.2232337028313567, 1.2507442644809401, 1.278843112499695, 1.307466023138106, 1.3365525369156996, 1.3660458090122058, 1.3958924364066738, 1.4260422710892182, 1.456448226620387, 1.4870660835805452, 1.5178542980196557, 1.5487738158573896, 1.5797878952597924, 1.6108619382961338, 1.6419633326239678, 1.6730613035312125, 1.7041267763543544, 1.7351322490689347, 1.766051674693368, 1.796860353044311, 1.8275348313187716, 1.8580528129449283, 1.8883930741323478, 1.91853538755684, 1.9484604526308051, 1.9781498318330062, 2.0075858925995167, 2.0367517543081046, 2.0656312399199996, 2.0942088318748167, 2.122469631865587, 2.1503993241508534, 2.1779841420893016, 2.2052108376092465, 2.2320666533503055, 2.2585392972378147, 2.284616919271976, 2.310288090333393, 2.3355417828246967, 2.3603673529844182, 2.384754524724303, 2.4086933748549004, 2.432174319576692, 2.4551881021252884, 2.4777257814694456, 2.4997787219699372, 2.5213385839156706, 2.542397314861116, 2.562947141695929, 2.582980563383953, 2.6024903443144045, 2.621469508213193, 2.639911332566952, 2.657809343516599, 2.6751573111810254, 2.691949245375031, 2.708179391688736, 2.7238422278985803, 2.7389324606826375, 2.753445022615317, 2.767375069418722, 2.780717977449877, 2.7934693414048546, 2.8056249722224678, 2.81718089517172, 2.8281333481085547, 2.838478779888756, 2.848213848924972, 2.857335421876947, 2.8658405724650216, 2.8737265803978698, 2.8809909304063153, 2.887631311375839, 2.8936456155711303, 2.899031937946743, 2.9037885755385378, 2.907914026931218, 2.9114069917978407, 2.914266370507736, 2.9164912637997777, 2.918080972518472, 2.9190349974108036], [2.9311440620976645, 2.9308253539935265, 2.9298693301156065, 2.928276291796699, 2.926046741356086, 2.923181382247236, 2.9196811192662198, 2.915547058822383, 2.910780509273404, 2.905382981327298, 2.8993561885144468, 2.892702047733278, 2.885422679873757, 2.8775204105234495, 2.868997770761518, 2.859857498046682, 2.850102537205861, 2.8397360415309607, 2.8287613739920796, 2.8171821085762376, 2.8050020317617, 2.792225144138922, 2.7788556621902654, 2.7648980202417768, 2.7503568726016296, 2.735237095901195, 2.719543791656242, 2.7032822890674124, 2.686458148080944, 2.6690771627325667, 2.6511453647997176, 2.632669027789553, 2.6136546712928777, 2.5941090657369936, 2.574039237573606, 2.553452474941415, 2.5323563338468507, 2.510758644910608, 2.488667520732311, 2.4660913639307105, 2.443038875922519, 2.419519066509152, 2.3955412643475706, 2.3711151283889285, 2.3462506603771285, 2.320958218508564, 2.2952485323644676, 2.269132719238444, 2.2426223019940674, 2.2157292286008676, 2.1884658935118746, 2.160845161062066, 2.1328803910847602, 2.104585466962295, 2.075974826348243, 2.0470634948210167, 2.017867122753039, 1.9884020257055577, 1.9586852286866392, 1.9287345146385797, 1.8985684775505878, 1.8682065806225268, 1.8376692199349818, 1.8069777941087635, 1.776154780461637, 1.7452238181894666, 1.714209799110261, 1.683138966509174, 1.6520390226054662, 1.6209392451227171, 1.5898706133732063, 1.5588659441565387, 1.527960037608825, 1.497189832906835, 1.466594573413027, 1.4362159804201047, 1.4060984340920408, 1.376289159473066, 1.34683841451497, 1.317799675923165, 1.289229817211995, 1.261189271664978, 1.233742170904459, 1.2069564474994732, 1.1809038875286062, 1.1556601163676208, 1.1313044983629654, 1.1079199287473582, 1.0855924945259479, 1.0644109805992514, 1.0444661986822825, 1.0258501202773718, 1.0086548016858008, 0.9929710992693522, 0.9788871870355021, 0.9664869057315154, 0.955847991907325, 0.9470402549784054, 0.9401237876213427, 0.9351473068977227, 0.9321467274731243, 0.9311440620976645, 0.9321467274731263, 0.9351473068977268, 0.940123787621349, 0.9470402549784136, 0.9558479919073348, 0.9664869057315273, 0.9788871870355156, 0.9929710992693673, 1.0086548016858177, 1.0258501202773902, 1.0444661986823025, 1.0644109805992725, 1.0855924945259703, 1.1079199287473815, 1.1313044983629899, 1.155660116367646, 1.1809038875286326, 1.2069564474995, 1.233742170904487, 1.2611892716650064, 1.2892298172120238, 1.3177996759231942, 1.3468384145150003, 1.3762891594730966, 1.4060984340920717, 1.436215980420136, 1.4665945734130583, 1.4971898329068665, 1.5279600376088565, 1.5588659441565704, 1.589870613373238, 1.6209392451227491, 1.6520390226054982, 1.683138966509206, 1.714209799110293, 1.7452238181894981, 1.7761547804616689, 1.806977794108795, 1.8376692199350133, 1.868206580622558, 1.8985684775506189, 1.9287345146386108, 1.9586852286866696, 1.9884020257055883, 2.0178671227530693, 2.0470634948210464, 2.075974826348273, 2.104585466962325, 2.132880391084789, 2.1608451610620945, 2.188465893511903, 2.2157292286008956, 2.242622301994095, 2.2691327192384714, 2.2952485323644938, 2.32095821850859, 2.3462506603771542, 2.3711151283889533, 2.395541264347596, 2.419519066509177, 2.4430388759225425, 2.4660913639307345, 2.4886675207323337, 2.5107586449106307, 2.532356333846872, 2.5534524749414365, 2.5740392375736265, 2.594109065737014, 2.6136546712928976, 2.6326690277895723, 2.6511453647997363, 2.669077162732584, 2.6864581480809617, 2.70328228906743, 2.7195437916562586, 2.735237095901211, 2.7503568726016447, 2.764898020241791, 2.7788556621902796, 2.792225144138936, 2.8050020317617124, 2.8171821085762496, 2.8287613739920903, 2.8397360415309714, 2.850102537205871, 2.8598574980466918, 2.8689977707615273, 2.8775204105234584, 2.8854226798737646, 2.892702047733285, 2.8993561885144534, 2.9053829813273038, 2.910780509273409, 2.915547058822387, 2.919681119266224, 2.9231813822472392, 2.9260467413560884, 2.928276291796702, 2.929869330115608, 2.930825353993527], [2.942034263469994, 2.9417149445018995, 2.940757088598037, 2.939160998789659, 2.936927180229092, 2.934056340340877, 2.9305493890349976, 2.926407438983799, 2.921631805964707, 2.916224009271363, 2.9101857721962783, 2.9035190225886787, 2.8962258934917373, 2.8883087238640144, 2.879770059390526, 2.8706126533895255, 2.8608394678217954, 2.850453674409993, 2.8394586558763946, 2.827858007308247, 2.8156555376608927, 2.8028552714098, 2.789461450363768, 2.7754785356527143, 2.7609112099047888, 2.745764379628903, 2.7300431778203453, 2.713752966808768, 2.696899341369693, 2.67948813212265, 2.6615254092412517, 2.6430174865029, 2.6239709257084396, 2.6043925415049642, 2.5842894066481272, 2.5636688577438123, 2.5425385015128383, 2.5209062216265714, 2.4987801861659933, 2.4761688557618506, 2.453080992479168, 2.429525669515589, 2.405512281789872, 2.381050557504378, 2.3561505707737056, 2.3308227554207415, 2.305077920051483, 2.2789272645310037, 2.252382397995121, 2.2254553585456107, 2.1981586347914326, 2.170505189414364, 2.1425084849548313, 2.1141825120326216, 2.085541820237623, 2.0566015519477645, 2.0273774793549633, 1.9978860450049614, 1.9681444061833753, 1.9381704835078117, 1.907983014114028, 1.8776016098523785, 1.8470468209381896, 1.81634020552513, 1.7855044056924843, 1.7545632303532632, 1.7235417455975248, 1.6924663729803024, 1.6613649962413861, 1.630267076898636, 1.5992037790796783, 1.5682081038389066, 1.5373150330354235, 1.5065616826079677, 1.4759874647568814, 1.4456342581093697, 1.415546584377902, 1.3857717892946584, 1.3563602246873456, 1.3273654274227988, 1.2988442895563501, 1.2708572123658886, 1.2434682350126516, 1.216745126372598, 1.1907594261753374, 1.165586419076664, 1.1413050228500718, 1.117997569774076, 1.09574945887912, 1.0746486564691033, 1.0547850238074798, 1.0362494546629273, 1.0191328121163223, 1.0035246640507993, 0.9895118301683672, 0.9771767697860372, 0.966595857992562, 0.9578376162035364, 0.9509609793133736, 0.9460136927356172, 0.94303093601274, 0.9420342634699939, 0.9430309360127421, 0.9460136927356213, 0.9509609793133798, 0.9578376162035444, 0.966595857992572, 0.9771767697860488, 0.9895118301683807, 1.0035246640508146, 1.0191328121163392, 1.0362494546629457, 1.0547850238074998, 1.0746486564691242, 1.0957494588791423, 1.1179975697740991, 1.1413050228500963, 1.1655864190766891, 1.1907594261753636, 1.2167451263726248, 1.2434682350126793, 1.2708572123659172, 1.2988442895563792, 1.3273654274228284, 1.3563602246873758, 1.3857717892946888, 1.4155465843779327, 1.4456342581094004, 1.4759874647569127, 1.5065616826079995, 1.5373150330354552, 1.5682081038389384, 1.5992037790797102, 1.6302670768986678, 1.6613649962414183, 1.6924663729803344, 1.7235417455975568, 1.754563230353295, 1.785504405692516, 1.8163402055251616, 1.8470468209382207, 1.8776016098524098, 1.9079830141140588, 1.938170483507843, 1.9681444061834061, 1.9978860450049916, 2.027377479354994, 2.0566015519477943, 2.0855418202376526, 2.114182512032651, 2.14250848495486, 2.170505189414393, 2.198158634791461, 2.225455358545639, 2.252382397995149, 2.2789272645310312, 2.3050779200515095, 2.3308227554207672, 2.356150570773731, 2.3810505575044036, 2.405512281789897, 2.4295256695156136, 2.453080992479192, 2.4761688557618746, 2.4987801861660155, 2.5209062216265936, 2.54253850151286, 2.5636688577438336, 2.5842894066481477, 2.6043925415049847, 2.62397092570846, 2.6430174865029192, 2.661525409241271, 2.6794881321226685, 2.696899341369711, 2.713752966808785, 2.7300431778203618, 2.7457643796289193, 2.7609112099048034, 2.7754785356527285, 2.7894614503637816, 2.802855271409814, 2.8156555376609056, 2.8278580073082593, 2.839458655876406, 2.8504536744100046, 2.8608394678218056, 2.870612653389535, 2.8797700593905358, 2.8883087238640237, 2.896225893491745, 2.9035190225886853, 2.910185772196285, 2.916224009271369, 2.921631805964713, 2.9264074389838033, 2.9305493890350016, 2.9340563403408795, 2.9369271802290946, 2.939160998789661, 2.940757088598038, 2.941714944501901], [2.9520131075327343, 2.951693232778823, 2.950733710036222, 2.949134843892949, 2.9468971420980243, 2.944021315715746, 2.9405082793433315, 2.9363591513935257, 2.9315752544443257, 2.9261581156584557, 2.920109467275725, 2.9134312471819763, 2.9061255995588713, 2.8981948756193665, 2.8896416344343616, 2.8804686438566645, 2.870678881549128, 2.860275536124569, 2.8492620084059, 2.837641912815762, 2.825419078905906, 2.8125975530375618, 2.7991816002251557, 2.785175706156916, 2.770584579407189, 2.7554131538567366, 2.7396665913387577, 2.723350284530114, 2.7064698601090216, 2.6890311822024917, 2.6710403561489935, 2.65250373260419, 2.6334279120202617, 2.6138197495321798, 2.5936863602874984, 2.5730351252596897, 2.5518736975888903, 2.5302100094981426, 2.5080522798378317, 2.4854090223161576, 2.46228905447905, 2.438701507509174, 2.414655836920432, 2.390161834231907, 2.365229639713417, 2.3398697563039224, 2.3140930648140303, 2.2879108405347646, 2.261334771386801, 2.234376977757544, 2.207050034187804, 2.1793669930855497, 2.151341410661312, 2.1229873752983424, 2.0943195385906725, 2.0653531493037085, 2.036104090535001, 2.006588920377136, 1.9768249164102283, 1.9468301243778903, 1.9166234114274059, 1.8862245243214846, 1.8556541530545472, 1.8249340003297105, 1.794086857371893, 1.763136686565494, 1.7321087114090157, 1.7010295142700311, 1.6699271423971416, 1.6388312225948576, 1.607773084884801, 1.5767858953525082, 1.5459047982013068, 1.515167066788547, 1.4846122630872014, 1.454282404576714, 1.424222136997045, 1.394478910672459, 1.365103157198198, 1.3361484621553466, 1.30767172815133, 1.2797333208577752, 1.252397188830473, 1.2257309457682581, 1.1998059015551141, 1.1746970260399152, 1.1504828272154797, 1.1272451235213614, 1.1050686887668222, 1.084040748103027, 1.0642503050987842, 1.0457872838612383, 1.0287414768178365, 1.0132012986020473, 0.9992523595101913, 0.9869758877867836, 0.976447047499516, 0.9677332162603991, 0.9608923022356392, 0.9559711901595545, 0.9530044089755835, 0.9520131075327342, 0.9530044089755856, 0.9559711901595583, 0.9608923022356451, 0.9677332162604071, 0.976447047499526, 0.9869758877867952, 0.9992523595102046, 1.0132012986020624, 1.0287414768178533, 1.0457872838612567, 1.064250305098804, 1.0840407481030478, 1.1050686887668444, 1.1272451235213847, 1.150482827215504, 1.1746970260399403, 1.1998059015551406, 1.2257309457682852, 1.2523971888305008, 1.2797333208578032, 1.307671728151359, 1.336148462155376, 1.3651031571982275, 1.3944789106724895, 1.424222136997076, 1.454282404576745, 1.4846122630872332, 1.5151670667885784, 1.5459047982013383, 1.57678589535254, 1.6077730848848328, 1.6388312225948896, 1.6699271423971738, 1.7010295142700629, 1.7321087114090479, 1.7631366865655258, 1.7940868573719249, 1.824934000329742, 1.8556541530545783, 1.8862245243215159, 1.9166234114274372, 1.9468301243779214, 1.9768249164102587, 2.0065889203771663, 2.0361040905350314, 2.0653531493037387, 2.0943195385907023, 2.122987375298372, 2.151341410661341, 2.1793669930855786, 2.2070500341878323, 2.234376977757572, 2.2613347713868284, 2.2879108405347917, 2.3140930648140574, 2.3398697563039486, 2.365229639713443, 2.390161834231933, 2.4146558369204563, 2.4387015075091982, 2.462289054479074, 2.4854090223161807, 2.508052279837855, 2.530210009498165, 2.5518736975889125, 2.573035125259711, 2.5936863602875193, 2.6138197495322, 2.6334279120202813, 2.6525037326042096, 2.6710403561490126, 2.68903118220251, 2.706469860109039, 2.7233502845301314, 2.739666591338774, 2.755413153856753, 2.770584579407205, 2.7851757061569304, 2.7991816002251704, 2.812597553037575, 2.825419078905919, 2.837641912815774, 2.8492620084059115, 2.8602755361245804, 2.8706788815491384, 2.8804686438566742, 2.8896416344343705, 2.898194875619375, 2.9061255995588793, 2.913431247181984, 2.9201094672757315, 2.9261581156584615, 2.9315752544443314, 2.93635915139353, 2.940508279343336, 2.9440213157157498, 2.9468971420980266, 2.949134843892951, 2.950733710036223, 2.9516932327788243], [2.9610709403987285, 2.9607505643996306, 2.9597895383924087, 2.958188168378462, 2.9559469644643337, 2.953066641018828, 2.9495481168946363, 2.945392515716104, 2.9406011662352896, 2.9351756027589877, 2.929117565649867, 2.9224290019054666, 2.9151120658193315, 2.9071691197291902, 2.8986027348576964, 2.889415692251924, 2.8796109838285466, 2.869191813532357, 2.858161598616633, 2.8465239710547103, 2.8342827790930847, 2.82144208895738, 2.808006186723624, 2.7939795803684686, 2.7793670020132977, 2.764173410378581, 2.748403993466359, 2.7320641714904506, 2.715159600075772, 2.69769617375021, 2.679680029754638, 2.661117552199107, 2.6420153765958485, 2.6223803948026516, 2.6022197604133015, 2.581540894635306, 2.560351492698928, 2.538659530845764, 2.5164732739497437, 2.4938012838285224, 2.4706524283088194, 2.447035891115456, 2.4229611826605946, 2.3984381518171722, 2.373476998768702, 2.348088289036641, 2.322282968796425, 2.2960723816041284, 2.2694682866676077, 2.2424828788090125, 2.215128810279758, 2.1874192146045597, 2.1593677326479357, 2.130988541114812, 2.1022963837164794, 2.0733066052542024, 2.0440351888951485, 2.01449879693897, 1.984714815398039, 1.9547014027397178, 1.9244775431647503, 1.8940631048210563, 1.8634789033761185, 1.8327467713924108, 1.8018896339672457, 1.7709315911087642, 1.7398980073205996, 1.708815608855207, 1.6777125890650466, 1.6466187222255637, 1.6155654861163908, 1.5845861935176755, 1.5537161325950544, 1.5229927158949355, 1.4924556373342752, 1.462147036125584, 1.4321116660053816, 1.4023970674071868, 1.3730537393112845, 1.344135306386421, 1.3156986756900244, 1.2878041755985468, 1.2605156677977452, 1.2339006210979417, 1.208030133610739, 1.182978887540547, 1.1588250186809979, 1.1356498809176023, 1.113537684968805, 1.0925749906835844, 1.0728500339630438, 1.0544518733228574, 1.037469347750141, 1.0219898471552187, 1.0080979093898845, 0.9958736730509532, 0.9853912320771245, 0.9767169548168967, 0.9699078446009081, 0.9650100284326358, 0.9620574629199502, 0.9610709403987284, 0.9620574629199521, 0.9650100284326398, 0.9699078446009142, 0.9767169548169046, 0.9853912320771345, 0.9958736730509649, 1.0080979093898979, 1.0219898471552338, 1.0374693477501575, 1.0544518733228756, 1.0728500339630636, 1.0925749906836055, 1.1135376849688268, 1.1356498809176256, 1.1588250186810223, 1.182978887540572, 1.2080301336107653, 1.2339006210979686, 1.260515667797773, 1.2878041755985752, 1.3156986756900533, 1.34413530638645, 1.3730537393113145, 1.402397067407217, 1.4321116660054123, 1.462147036125615, 1.4924556373343065, 1.5229927158949672, 1.5537161325950866, 1.5845861935177072, 1.6155654861164226, 1.646618722225596, 1.6777125890650786, 1.708815608855239, 1.7398980073206314, 1.7709315911087957, 1.8018896339672774, 1.8327467713924424, 1.8634789033761496, 1.8940631048210874, 1.9244775431647811, 1.9547014027397487, 1.9847148153980696, 2.0144987969390007, 2.044035188895178, 2.0733066052542326, 2.1022963837165096, 2.1309885411148413, 2.1593677326479646, 2.187419214604588, 2.215128810279786, 2.24248287880904, 2.2694682866676357, 2.296072381604156, 2.3222829687964515, 2.348088289036667, 2.3734769987687283, 2.3984381518171976, 2.422961182660619, 2.44703589111548, 2.4706524283088434, 2.493801283828546, 2.516473273949767, 2.538659530845787, 2.5603514926989503, 2.5815408946353275, 2.6022197604133224, 2.622380394802672, 2.642015376595869, 2.661117552199126, 2.6796800297546572, 2.697696173750228, 2.71515960007579, 2.732064171490467, 2.748403993466376, 2.7641734103785964, 2.7793670020133123, 2.7939795803684833, 2.8080061867236386, 2.8214420889573932, 2.8342827790930976, 2.846523971054722, 2.858161598616645, 2.8691918135323675, 2.879610983828556, 2.8894156922519336, 2.8986027348577053, 2.907169119729199, 2.915112065819339, 2.9224290019054737, 2.929117565649874, 2.9351756027589935, 2.940601166235294, 2.945392515716108, 2.9495481168946402, 2.9530666410188315, 2.955946964464336, 2.9581881683784643, 2.95978953839241, 2.960750564399632], [2.9691989991996697, 2.968878176011151, 2.9679158088583253, 2.966312205011093, 2.964067876691841, 2.9611835412351186, 2.9576601213128226, 2.9534987452265793, 2.9487007472694797, 2.9432676681598444, 2.9372012555502254, 2.9305034646153856, 2.9231764587235975, 2.9152226101961696, 2.9066445011607946, 2.8974449245049385, 2.8876268849362527, 2.877193600157719, 2.8661485021661055, 2.85449523868314, 2.8422376747298137, 2.8293798943552098, 2.8159262025323915, 2.8018811272350694, 2.787249421710083, 2.772036066962148, 2.7562462744688774, 2.7398854891457427, 2.7229593925825237, 2.705473906574773, 2.687435196976026, 2.668849677898922, 2.6497240162960085, 2.630065136953908, 2.6098802279377145, 2.5891767465259576, 2.567962425680294, 2.54624528109833, 2.524033618902551, 2.501336044023473, 2.478161469340674, 2.454519125651541, 2.430418572544317, 2.4058697102594464, 2.380882792631411, 2.355468441212158, 2.3296376606871085, 2.303401855705463, 2.2767728492583386, 2.2497629027511588, 2.222384737930753, 2.1946515608429404, 2.166577088012928, 2.138175575058785, 2.1094618479675167, 2.0804513372838582, 2.0511601154837877, 2.021604937827753, 1.9918032870125573, 1.961773421965327, 1.9315344311476033, 1.9011062907615588, 1.8705099282727433, 1.83976729168327, 1.8089014250042454, 1.777936550384204, 1.7468981573483793, 1.7158130995879732, 1.684709699704234, 1.6536178622529625, 1.6225691953432146, 1.5915971409098282, 1.5607371135911865, 1.5300266478870637, 1.4995055529295347, 1.469216073753057, 1.4392030573754835, 1.4095141212753872, 1.3801998209468997, 1.3513138121063613, 1.322913001794308, 1.2950576810491445, 1.2678116300275877, 1.2412421844382002, 1.2154202499997233, 1.1904202494460876, 1.166319984549053, 1.1432003939684647, 1.121145186806316, 1.1002403319557543, 1.0805733851873092, 1.0622326399109212, 1.0453060941479568, 1.0298802357314942, 1.0160386601123834, 1.003860549924026, 0.9934190616332043, 0.9847796805689468, 0.9779986192731485, 0.9731213431154347, 0.9701813092936102, 0.9691989991996697, 0.9701813092936123, 0.9731213431154386, 0.9779986192731545, 0.9847796805689547, 0.9934190616332139, 1.0038605499240378, 1.0160386601123967, 1.0298802357315093, 1.0453060941479735, 1.0622326399109394, 1.0805733851873287, 1.1002403319557748, 1.1211451868063382, 1.1432003939684878, 1.1663199845490773, 1.1904202494461127, 1.2154202499997493, 1.2412421844382273, 1.2678116300276152, 1.2950576810491727, 1.3229130017943367, 1.3513138121063906, 1.38019982094693, 1.4095141212754176, 1.4392030573755141, 1.469216073753088, 1.4995055529295658, 1.530026647887095, 1.5607371135912183, 1.59159714090986, 1.6225691953432468, 1.653617862252995, 1.684709699704266, 1.7158130995880054, 1.7468981573484113, 1.7779365503842357, 1.8089014250042774, 1.8397672916833017, 1.870509928272775, 1.9011062907615903, 1.9315344311476343, 1.9617734219653582, 1.991803287012588, 2.0216049378277834, 2.051160115483818, 2.0804513372838884, 2.1094618479675464, 2.1381755750588143, 2.166577088012957, 2.1946515608429693, 2.2223847379307813, 2.2497629027511867, 2.276772849258366, 2.3034018557054896, 2.329637660687135, 2.3554684412121842, 2.3808827926314367, 2.4058697102594717, 2.4304185725443412, 2.4545191256515655, 2.4781614693406975, 2.5013360440234966, 2.5240336189025743, 2.546245281098353, 2.5679624256803164, 2.589176746525979, 2.609880227937736, 2.630065136953928, 2.649724016296029, 2.668849677898942, 2.6874351969760446, 2.7054739065747913, 2.7229593925825415, 2.739885489145759, 2.7562462744688943, 2.7720360669621646, 2.7872494217100985, 2.8018811272350845, 2.815926202532406, 2.829379894355223, 2.842237674729826, 2.8544952386831524, 2.866148502166118, 2.8771936001577307, 2.887626884936263, 2.8974449245049487, 2.9066445011608026, 2.915222610196178, 2.923176458723605, 2.930503464615393, 2.9372012555502316, 2.94326766815985, 2.948700747269485, 2.9534987452265846, 2.9576601213128266, 2.9611835412351217, 2.964067876691843, 2.966312205011094, 2.967915808858327, 2.968878176011151], [2.97638942056361, 2.976068203808789, 2.975104656331007, 2.973499086522444, 2.9712520084774585, 2.9683641421544857, 2.964836413604386, 2.960669955266891, 2.9558661063373415, 2.950426413206417, 2.9443526299760543, 2.937646719055373, 2.930310851840917, 2.9223474094862083, 2.913758983766206, 2.9045483780429446, 2.8947186083393808, 2.8842729045291957, 2.873214711651187, 2.8615476913577313, 2.8492757235077564, 2.8364029079157174, 2.8229335662691577, 2.8088722442286707, 2.7942237137253567, 2.7789929754723337, 2.7631852617083728, 2.7468060391934546, 2.729861012477856, 2.7123561274684342, 2.694297575317921, 2.675691796665519, 2.656545486259684, 2.636865597996893, 2.616659350413385, 2.595934232670323, 2.5746980110766837, 2.552958736198356, 2.5307247506065695, 2.5080046973238455, 2.484807529031228, 2.461142518106697, 2.437019267571392, 2.4124477230276717, 2.3874381856811526, 2.362001326547785, 2.336148201956795, 2.3098902704709974, 2.283239411357704, 2.2562079447562073, 2.228808653701722, 2.201054808180791, 2.172960191409505, 2.1445391285435638, 2.1158065180481143, 2.0867778659755563, 2.0574693234208783, 2.0278977274465673, 1.9980806457923723, 1.9680364257089498, 1.9377842472780327, 1.9073441816046701, 1.8767372542881415, 1.8459855145961421, 1.8151121107799266, 1.7841413719739914, 1.753098897119558, 1.722011651332729, 1.690908070100784, 1.659818171627474, 1.6287736775526298, 1.5978081421332928, 1.5669570897813099, 1.5362581605917824, 1.5057512631513361, 1.4754787334655517, 1.4454854982693206, 1.4158192402585714, 1.3865305618821668, 1.3576731432352853, 1.3293038882809116, 1.301483052083598, 1.2742743399742174, 1.24774496760463, 1.2219656687608755, 1.1970106356942753, 1.1729573747752273, 1.1498864587224376, 1.1278811558407866, 1.107026917023639, 1.087410703209558, 1.0691201400144876, 1.052242492814954, 1.0368634648967192, 1.023065833371175, 1.010927951931785, 1.0005221651732557, 0.9919131945640142, 0.9851565692222263, 0.9802971831588023, 0.9773680625587519, 0.9763894205636101, 0.977368062558754, 0.9802971831588063, 0.9851565692222322, 0.9919131945640222, 1.0005221651732656, 1.0109279519317966, 1.0230658333711884, 1.0368634648967343, 1.0522424928149705, 1.0691201400145056, 1.0874107032095774, 1.10702691702366, 1.1278811558408086, 1.1498864587224606, 1.1729573747752517, 1.1970106356943002, 1.2219656687609015, 1.2477449676046568, 1.2742743399742449, 1.3014830520836262, 1.3293038882809405, 1.357673143235315, 1.3865305618821966, 1.4158192402586016, 1.4454854982693512, 1.4754787334655828, 1.5057512631513672, 1.536258160591814, 1.5669570897813416, 1.5978081421333248, 1.6287736775526618, 1.6598181716275058, 1.690908070100816, 1.7220116513327612, 1.7530988971195895, 1.7841413719740231, 1.8151121107799584, 1.8459855145961737, 1.876737254288173, 1.9073441816047016, 1.9377842472780642, 1.9680364257089809, 1.9980806457924034, 2.027897727446598, 2.057469323420909, 2.0867778659755865, 2.115806518048144, 2.144539128543593, 2.1729601914095342, 2.2010548081808197, 2.2288086537017504, 2.2562079447562358, 2.283239411357731, 2.309890270471024, 2.3361482019568216, 2.362001326547811, 2.387438185681178, 2.4124477230276975, 2.4370192675714173, 2.4611425181067212, 2.4848075290312517, 2.508004697323869, 2.530724750606592, 2.5529587361983785, 2.574698011076706, 2.5959342326703445, 2.6166593504134057, 2.6368655979969136, 2.656545486259704, 2.675691796665539, 2.69429757531794, 2.7123561274684524, 2.729861012477875, 2.7468060391934714, 2.7631852617083896, 2.7789929754723497, 2.794223713725372, 2.808872244228685, 2.8229335662691715, 2.8364029079157307, 2.8492757235077693, 2.8615476913577433, 2.8732147116511983, 2.884272904529206, 2.894718608339391, 2.904548378042955, 2.913758983766215, 2.9223474094862167, 2.9303108518409244, 2.93764671905538, 2.944352629976061, 2.950426413206422, 2.9558661063373473, 2.9606699552668956, 2.9648364136043903, 2.9683641421544884, 2.971252008477461, 2.973499086522447, 2.975104656331008, 2.9760682038087904], [2.9826352482222664, 2.9823136911434576, 2.9813491230185547, 2.9797418532146627, 2.977492397452301, 2.974601477969253, 2.9710700237516376, 2.966899170833888, 2.962090262669821, 2.9566448505775313, 2.950564694261317, 2.9438517624144684, 2.936508233407278, 2.9285364960652696, 2.9199391505432835, 2.9107190093017272, 2.9008790981920507, 2.8904226576592467, 2.8793531440700426, 2.867674231176321, 2.855389811724257, 2.842503999220725, 2.829021129869625, 2.8149457646919798, 2.8002826918450077, 2.7850369291567674, 2.769213726894537, 2.7528185707868116, 2.7358571853206017, 2.7183355373377824, 2.7002598399564284, 2.6816365568454863, 2.6624724068837846, 2.642774369237288, 2.622549688891664, 2.601805882680726, 2.580550745855159, 2.5587923592400923, 2.5365390970347472, 2.5137996353124192, 2.4905829612846317, 2.466898383399416, 2.4427555423503686, 2.4181644230805293, 2.3931353678731813, 2.3676790906305643, 2.34180669245118, 2.315529678627016, 2.288859977193611, 2.2618099591785374, 2.2343924607076886, 2.206620807143654, 2.1785088394467103, 2.150070942966286, 2.121322078889516, 2.0922778185932995, 2.0629543811673337, 2.033368674397529, 2.003538339521928, 1.9734818000942476, 1.9432183153130336, 1.912768038196307, 1.8821520790015411, 1.8513925743074657, 1.8205127621857529, 1.7895370638947548, 1.758491172521104, 1.7274021489742675, 1.696298525699157, 1.6652104184063787, 1.634169646021051, 1.6032098589096704, 1.5723666752488727, 1.5416778251360825, 1.5111833016937235, 1.4809255179669094, 1.4509494678381243, 1.4213028884583214, 1.392036420798457, 1.3632037638364582, 1.3348618165940924, 1.307070800717396, 1.2798943545597803, 1.253399587809355, 1.2276570836665925, 1.202740833537791, 1.1787280873366333, 1.155699101025556, 1.1337367623044001, 1.1129260757651345, 1.0933534908326517, 1.0751060598682067, 1.0582704203274735, 1.0429316040773475, 1.0291716888313198, 1.017068320689994, 1.006693151983196, 0.9981102534792825, 0.9913745725948272, 0.9865305173501867, 0.9836107475038185, 0.9826352482222663, 0.9836107475038204, 0.9865305173501907, 0.9913745725948331, 0.9981102534792903, 1.0066931519832059, 1.0170683206900053, 1.0291716888313331, 1.0429316040773622, 1.05827042032749, 1.0751060598682247, 1.0933534908326712, 1.1129260757651553, 1.1337367623044219, 1.155699101025579, 1.1787280873366575, 1.2027408335378162, 1.227657083666619, 1.2533995878093818, 1.2798943545598076, 1.3070708007174239, 1.3348618165941213, 1.3632037638364876, 1.3920364207984868, 1.4213028884583514, 1.4509494678381551, 1.4809255179669405, 1.511183301693755, 1.5416778251361143, 1.5723666752489047, 1.6032098589097024, 1.6341696460210826, 1.665210418406411, 1.696298525699189, 1.7274021489742997, 1.7584911725211356, 1.7895370638947865, 1.8205127621857844, 1.851392574307497, 1.8821520790015727, 1.9127680381963386, 1.9432183153130649, 1.9734818000942786, 2.003538339521959, 2.0333686743975594, 2.062954381167364, 2.0922778185933297, 2.1213220788895457, 2.1500709429663156, 2.1785088394467396, 2.206620807143683, 2.2343924607077166, 2.2618099591785654, 2.2888599771936384, 2.3155296786270436, 2.341806692451207, 2.367679090630591, 2.3931353678732075, 2.4181644230805546, 2.4427555423503935, 2.4668983833994402, 2.4905829612846557, 2.5137996353124428, 2.5365390970347708, 2.5587923592401154, 2.5805507458551813, 2.6018058826807478, 2.622549688891685, 2.642774369237309, 2.6624724068838055, 2.6816365568455054, 2.700259839956448, 2.718335537337801, 2.7358571853206195, 2.752818570786829, 2.7692137268945536, 2.7850369291567834, 2.8002826918450237, 2.8149457646919944, 2.829021129869639, 2.8425039992207384, 2.8553898117242698, 2.8676742311763332, 2.879353144070054, 2.890422657659257, 2.900879098192061, 2.910719009301737, 2.9199391505432923, 2.9285364960652784, 2.9365082334072854, 2.943851762414475, 2.9505646942613235, 2.956644850577537, 2.9620902626698267, 2.966899170833892, 2.971070023751642, 2.9746014779692564, 2.9774923974523033, 2.979741853214665, 2.981349123018556, 2.9823136911434585], [2.987930439740759, 2.987608595250959, 2.9866431651684984, 2.9850344596870553, 2.9827829959058634, 2.979889497995208, 2.9763548974298066, 2.9721803332917665, 2.9673671526453345, 2.9619169109861416, 2.955831372768227, 2.9491125120126225, 2.941762513001938, 2.933783771065926, 2.925178893463706, 2.9159507003689975, 2.90610222596542, 2.8956367196597297, 2.8845576474216865, 2.872868693260103, 2.86057376084566, 2.847676975292037, 2.834182685108086, 2.8200954643349525, 2.805420114883397, 2.790161669087978, 2.774325392496329, 2.757916786913467, 2.7409415937229045, 2.723405797508371, 2.7053156300021706, 2.68667757438859, 2.6674983699934605, 2.647785017393841, 2.6275447839849813, 2.606785210045231, 2.5855141153433387, 2.5637396063368314, 2.541470084014746, 2.518714252443037, 2.4954811280765736, 2.47178004990769, 2.4476206905279967, 2.4230130681874558, 2.397967559942817, 2.372494915996318, 2.346606275335214, 2.320313182793274, 2.29362760766691, 2.2665619640311925, 2.239129132914632, 2.211342486506484, 2.1832159145862726, 2.154763853382518, 2.1260013170860126, 2.0969439322626404, 2.067607975431352, 2.038010414094493, 2.008168951529857, 1.9781020756763201, 1.947829112467018, 1.917370283985174, 1.8867467718366517, 1.8559807861488746, 1.8250956406160155, 1.7941158340129746, 1.7630671385926175, 1.731976695758069, 1.7008731193597073, 1.6697866068986034, 1.6387490588168665, 1.6077942059112174, 1.5769577447076752, 1.5462774803687311, 1.515793476353763, 1.4855482096000185, 1.4555867294146096, 1.425956817545103, 1.3967091460046943, 1.3678974281462977, 1.339578557191526, 1.3118127249181015, 1.2846635115008627, 1.2581979356193553, 1.23248645195555, 1.2076028812215454, 1.1836242560514276, 1.160630564706183, 1.1387043738942715, 1.1179303124937052, 1.0983944000159294, 1.0801832077267528, 1.0633828468195585, 1.048077787140478, 1.0343495216267093, 1.0222751053612562, 1.0119256129941716, 1.0033645727404419, 0.9966464473305362, 0.9918152400765299, 0.9889033057272915, 0.987930439740759, 0.9889033057272933, 0.9918152400765339, 0.9966464473305423, 1.0033645727404499, 1.0119256129941814, 1.0222751053612675, 1.0343495216267224, 1.0480777871404932, 1.063382846819575, 1.0801832077267708, 1.0983944000159487, 1.1179303124937259, 1.1387043738942935, 1.1606305647062058, 1.1836242560514516, 1.2076028812215704, 1.232486451955576, 1.2581979356193822, 1.2846635115008902, 1.31181272491813, 1.3395785571915548, 1.3678974281463272, 1.396709146004724, 1.4259568175451334, 1.45558672941464, 1.4855482096000494, 1.5157934763537941, 1.5462774803687624, 1.5769577447077066, 1.6077942059112493, 1.6387490588168983, 1.6697866068986353, 1.7008731193597388, 1.731976695758101, 1.7630671385926493, 1.7941158340130066, 1.8250956406160472, 1.8559807861489066, 1.8867467718366835, 1.917370283985206, 1.9478291124670493, 1.978102075676351, 2.008168951529888, 2.0380104140945234, 2.0676079754313825, 2.0969439322626706, 2.1260013170860423, 2.1547638533825477, 2.183215914586302, 2.2113424865065126, 2.2391291329146608, 2.2665619640312205, 2.2936276076669375, 2.3203131827933006, 2.346606275335241, 2.372494915996344, 2.3979675599428427, 2.423013068187481, 2.4476206905280216, 2.4717800499077143, 2.495481128076597, 2.5187142524430612, 2.5414700840147693, 2.5637396063368545, 2.5855141153433605, 2.6067852100452527, 2.627544783985002, 2.6477850173938604, 2.667498369993481, 2.6866775743886095, 2.705315630002189, 2.72340579750839, 2.740941593722922, 2.757916786913484, 2.7743253924963454, 2.7901616690879942, 2.805420114883413, 2.820095464334967, 2.8341826851081, 2.84767697529205, 2.8605737608456727, 2.872868693260115, 2.884557647421698, 2.8956367196597412, 2.90610222596543, 2.915950700369008, 2.9251788934637153, 2.9337837710659342, 2.941762513001946, 2.949112512012629, 2.955831372768233, 2.9619169109861474, 2.96736715264534, 2.972180333291772, 2.976354897429811, 2.9798894979952117, 2.982782995905866, 2.9850344596870566, 2.9866431651684993, 2.987608595250959], [2.9922698723632783, 2.9919477930973577, 2.9909816589122444, 2.989371780679016, 2.9871186766267956, 2.984223072509598, 2.980685901841596, 2.976508306202524, 2.971691635615422, 2.9662374489994625, 2.9601475147011156, 2.9534238111075037, 2.946068527346343, 2.9380840640775165, 2.9294730343819597, 2.920238264754224, 2.9103827962058255, 2.8999098854872556, 2.888823006437381, 2.8771258514698372, 2.864822333207003, 2.85191658627318, 2.838412969259705, 2.8243160668759884, 2.8096306923017393, 2.79436188975711, 2.778514937309035, 2.7620953499337655, 2.7451088828574113, 2.7275615351983835, 2.709459553937793, 2.690809438246311, 2.671617944198646, 2.651892089909673, 2.6316391611294407, 2.6108667173377893, 2.589582598383089, 2.5677949317138484, 2.545512140256517, 2.5227429509978716, 2.49949640433592, 2.4757818642693383, 2.4516090295021336, 2.4269879455475616, 2.4019290179233392, 2.3764430265389977, 2.3505411413858344, 2.3242349396504505, 2.2975364243843184, 2.270458044874336, 2.2430127188728806, 2.2152138568605992, 2.1870753885310243, 2.158611791703188, 2.1298381238866, 2.1007700567423604, 2.0714239137045056, 2.0418167110469407, 2.011966202703105, 1.9818909291674789, 1.9516102708296463, 1.9211445061120545, 1.8905148748008507, 1.859743646973801, 1.8288541979385347, 1.7978710895957524, 1.7668201586326002, 1.7357286119271829, 1.7046251295012753, 1.6735399752884694, 1.6425051158816242, 1.611554347277173, 1.5807234294331733, 1.5500502281894197, 1.519574863745452, 1.4893398644377, 1.4593903239797825, 1.4297740596082968, 1.4005417676880947, 1.3717471722555348, 1.3434471606999223, 1.3157018992960114, 1.2885749196134146, 1.2621331649754097, 1.2364469841873718, 1.211590057817378, 1.1876392405600265, 1.1646743018894659, 1.1427775466233605, 1.1220332975594423, 1.1025272244420972, 1.0843455076042767, 1.0675738310795801, 1.052296208995408, 1.0385936605622792, 1.026542762487529, 1.0162141221977552, 1.007670829388329, 1.0009669552651335, 0.996146176373397, 0.9932406012807955, 0.9922698723632783, 0.9932406012807976, 0.996146176373401, 1.0009669552651392, 1.007670829388337, 1.0162141221977652, 1.02654276248754, 1.0385936605622927, 1.0522962089954226, 1.0675738310795966, 1.0843455076042945, 1.1025272244421163, 1.122033297559463, 1.1427775466233827, 1.1646743018894887, 1.1876392405600504, 1.2115900578174028, 1.2364469841873977, 1.2621331649754366, 1.2885749196134422, 1.3157018992960394, 1.3434471606999507, 1.3717471722555636, 1.4005417676881247, 1.429774059608327, 1.459390323979813, 1.4893398644377311, 1.5195748637454831, 1.5500502281894515, 1.5807234294332049, 1.6115543472772043, 1.6425051158816564, 1.6735399752885014, 1.7046251295013073, 1.7357286119272148, 1.7668201586326322, 1.7978710895957843, 1.828854197938566, 1.8597436469738324, 1.8905148748008824, 1.9211445061120862, 1.9516102708296772, 1.9818909291675102, 2.0119662027031358, 2.0418167110469714, 2.0714239137045363, 2.1007700567423906, 2.1298381238866297, 2.158611791703217, 2.1870753885310537, 2.215213856860628, 2.243012718872909, 2.270458044874364, 2.2975364243843455, 2.3242349396504776, 2.3505411413858615, 2.3764430265390244, 2.401929017923365, 2.4269879455475873, 2.4516090295021584, 2.475781864269363, 2.4994964043359444, 2.522742950997895, 2.5455121402565397, 2.5677949317138715, 2.589582598383111, 2.610866717337811, 2.631639161129462, 2.651892089909693, 2.6716179441986667, 2.69080943824633, 2.709459553937811, 2.727561535198402, 2.745108882857429, 2.7620953499337824, 2.778514937309052, 2.794361889757126, 2.8096306923017558, 2.824316066876003, 2.8384129692597186, 2.8519165862731928, 2.864822333207016, 2.877125851469849, 2.8888230064373928, 2.8999098854872667, 2.9103827962058357, 2.920238264754234, 2.9294730343819686, 2.9380840640775245, 2.9460685273463505, 2.9534238111075113, 2.9601475147011223, 2.966237448999468, 2.9716916356154277, 2.9765083062025286, 2.9806859018416, 2.9842230725096006, 2.987118676626798, 2.9893717806790177, 2.990981658912246, 2.9919477930973586], [2.99564934796902, 2.9953270863346497, 2.9943604052199713, 2.9927496160236116, 2.990495237854647, 2.9875979977004854, 2.9840588306636056, 2.97987888026886, 2.975059498843553, 2.9696022479730426, 2.9635088990351424, 2.9567814338171656, 2.949422045220048, 2.941433138054585, 2.932817329935496, 2.9235774522796887, 2.913716551415862, 2.903237889813341, 2.892144947438885, 2.880441423251118, 2.86813123684318, 2.8552185302452617, 2.8417076698997823, 2.827603248823229, 2.8129100889699608, 2.7976332438147544, 2.781778001172396, 2.7653498862743566, 2.7483546651244355, 2.730798348157272, 2.7126871942258606, 2.6940277149466088, 2.6748266794331395, 2.655091119452936, 2.634828335044102, 2.614045900633005, 2.5927516716973904, 2.570953792023735, 2.548660701612219, 2.525881145287752, 2.50262418208099, 2.478899195449414, 2.4547159044151443, 2.4300843757035224, 2.4050150369744703, 2.3795186912474153, 2.3536065326301627, 2.327290163472566, 2.3005816130772683, 2.273493358112243, 2.2460383448833445, 2.218230013639697, 2.1900823251005432, 2.16160978940906, 2.132827497736777, 2.103751156781359, 2.0743971264207044, 2.0447824608072556, 2.0149249532079123, 1.9848431849165384, 1.954556578587209, 1.9240854563562768, 1.8934511031389545, 1.862675835500047, 1.8317830765068959, 1.8007974369730422, 1.769744803490626, 1.7386524336241043, 1.7075490585925923, 1.67646499369685, 1.6454322566419592, 1.6144846937587625, 1.5836581139247867, 1.5529904297152166, 1.5225218049606726, 1.4922948074330395, 1.4623545648032277, 1.4327489212940667, 1.4035285915657822, 1.3747473073008933, 1.3464619506849782, 1.318732667504192, 1.291622950909974, 1.2651996850703229, 1.2395331360034292, 1.2146968749871612, 1.1907676182278923, 1.1678249651931367, 1.1459510174753014, 1.125229860636624, 1.1057468936119312, 1.0875879943424585, 1.0708385167390009, 1.055582123019843, 1.0418994668517394, 1.029866756059681, 1.0195542380052116, 1.0110246646185324, 1.0043318056742327, 0.9995190862355928, 0.99661842546098, 0.9956493479690199, 0.9966184254609819, 0.9995190862355966, 1.0043318056742387, 1.0110246646185401, 1.0195542380052218, 1.0298667560596924, 1.0418994668517525, 1.0555821230198579, 1.0708385167390173, 1.0875879943424764, 1.1057468936119508, 1.1252298606366447, 1.1459510174753231, 1.1678249651931598, 1.1907676182279163, 1.2146968749871863, 1.2395331360034552, 1.2651996850703497, 1.2916229509100017, 1.3187326675042201, 1.346461950685007, 1.3747473073009226, 1.403528591565812, 1.4327489212940974, 1.4623545648032583, 1.4922948074330704, 1.5225218049607039, 1.552990429715248, 1.5836581139248185, 1.6144846937587944, 1.6454322566419912, 1.676464993696882, 1.7075490585926245, 1.738652433624136, 1.769744803490658, 1.8007974369730737, 1.8317830765069276, 1.8626758355000785, 1.8934511031389858, 1.9240854563563086, 1.9545565785872399, 1.984843184916569, 2.0149249532079434, 2.0447824608072858, 2.0743971264207346, 2.1037511567813887, 2.132827497736807, 2.161609789409089, 2.190082325100572, 2.218230013639726, 2.246038344883373, 2.273493358112271, 2.300581613077296, 2.3272901634725933, 2.3536065326301903, 2.379518691247441, 2.4050150369744965, 2.4300843757035477, 2.454715904415169, 2.4788991954494386, 2.5026241820810142, 2.5258811452877756, 2.5486607016122425, 2.5709537920237575, 2.5927516716974126, 2.614045900633026, 2.634828335044123, 2.655091119452957, 2.67482667943316, 2.6940277149466283, 2.7126871942258792, 2.7307983481572906, 2.748354665124453, 2.765349886274374, 2.7817780011724125, 2.797633243814771, 2.8129100889699763, 2.827603248823244, 2.841707669899797, 2.8552185302452755, 2.8681312368431926, 2.8804414232511295, 2.8921449474388967, 2.9032378898133517, 2.913716551415872, 2.923577452279698, 2.932817329935505, 2.941433138054594, 2.949422045220056, 2.9567814338171727, 2.963508899035149, 2.969602247973049, 2.9750594988435584, 2.9798788802688647, 2.9840588306636096, 2.9875979977004894, 2.9904952378546494, 2.9927496160236142, 2.994360405219973, 2.995327086334651], [2.9980655971335954, 2.997743205361963, 2.996776133961177, 2.9951646947070567, 2.992909407337824, 2.9900109997227386, 2.986470408099886, 2.9822887773848334, 2.977467461552377, 2.9720080240941265, 2.965912238555217, 2.9591820891539893, 2.951819771489098, 2.943827693339079, 2.935208475560109, 2.92596495308835, 2.916100176054008, 2.9056174110150397, 2.894520142319258, 2.8828120736044935, 2.8704971294474397, 2.8575794571728688, 2.8440634288359874, 2.82995364339199, 2.815254929068126, 2.7999723459550885, 2.7841111888360657, 2.767676990273505, 2.7506755239755245, 2.7331128084658904, 2.7149951110837334, 2.6963289523415876, 2.677121110672966, 2.6573786276036344, 2.637108813383865, 2.6163192531225006, 2.5950178134674244, 2.573212649881254, 2.550912214565665, 2.528125265092798, 2.5048608738077216, 2.4811284380720133, 2.456937691425164, 2.4322987157477995, 2.4072219545187403, 2.3817182272666186, 2.3557987453263856, 2.3294751290214637, 2.3027594264036977, 2.2756641336956465, 2.248202217593224, 2.2203871396012245, 2.192232882589995, 2.163753979778318, 2.1349655463655686, 2.1058833140552267, 2.076523668731843, 2.0469036915743186, 2.017041203909629, 1.986954816132462, 1.9566639810370938, 1.926189051927359, 1.8955513458878055, 1.864773212612541, 1.833878109196109, 1.8028906812905625, 1.7718368510215954, 1.7407439120303565, 1.7096406319612993, 1.67855736264411, 1.6475261581116478, 1.6165809004466916, 1.5857574332467457, 1.555093702224913, 1.524629902110084, 1.4944086285535976, 1.4644750331720822, 1.4348769791362739, 1.4056651938317397, 1.3768934140503784, 1.3486185179068382, 1.3209006362068387, 1.2938032343358041, 1.2673931539209635, 1.241740601616894, 1.2169190704871937, 1.1930051777743136, 1.1700784016029575, 1.1482206986583867, 1.1275159854936365, 1.1080494682674913, 1.0899068098172549, 1.0731731293774398, 1.0579318391533965, 1.0442633332556117, 1.0322435577136568, 1.0219425044662152, 1.0134226859343587, 1.0067376582198766, 1.0019306681693896, 0.9990335007415136, 0.9980655971335952, 0.9990335007415155, 1.0019306681693936, 1.0067376582198824, 1.0134226859343665, 1.0219425044662247, 1.0322435577136684, 1.0442633332556248, 1.0579318391534116, 1.0731731293774562, 1.0899068098172728, 1.1080494682675108, 1.1275159854936576, 1.1482206986584085, 1.1700784016029806, 1.1930051777743373, 1.216919070487219, 1.24174060161692, 1.2673931539209902, 1.2938032343358317, 1.3209006362068667, 1.348618517906867, 1.3768934140504083, 1.4056651938317695, 1.4348769791363043, 1.4644750331721126, 1.4944086285536282, 1.5246299021101155, 1.5550937022249443, 1.585757433246777, 1.6165809004467233, 1.64752615811168, 1.6785573626441417, 1.7096406319613315, 1.7407439120303887, 1.7718368510216274, 1.8028906812905945, 1.8338781091961411, 1.8647732126125722, 1.8955513458878372, 1.9261890519273905, 1.9566639810371251, 1.9869548161324928, 2.0170412039096592, 2.0469036915743493, 2.0765236687318733, 2.105883314055257, 2.1349655463655983, 2.1637539797783476, 2.1922328825900244, 2.220387139601253, 2.2482022175932523, 2.275664133695675, 2.302759426403725, 2.3294751290214912, 2.355798745326412, 2.3817182272666453, 2.4072219545187665, 2.432298715747825, 2.456937691425188, 2.4811284380720386, 2.504860873807746, 2.5281252650928216, 2.5509122145656886, 2.5732126498812766, 2.595017813467447, 2.6163192531225223, 2.637108813383886, 2.6573786276036553, 2.677121110672987, 2.6963289523416063, 2.7149951110837525, 2.733112808465908, 2.7506755239755423, 2.767676990273522, 2.784111188836083, 2.7999723459551054, 2.815254929068141, 2.8299536433920043, 2.8440634288360016, 2.8575794571728825, 2.870497129447453, 2.8828120736045055, 2.8945201423192697, 2.9056174110150503, 2.916100176054018, 2.92596495308836, 2.9352084755601178, 2.9438276933390872, 2.951819771489106, 2.959182089153997, 2.9659122385552235, 2.9720080240941322, 2.9774674615523824, 2.9822887773848388, 2.9864704080998905, 2.990010999722742, 2.9929094073378266, 2.995164694707058, 2.9967761339611787, 2.9977432053619633], [2.9995162822919883, 2.99919381248834, 2.9982265070669647, 2.9966146780301406, 2.9943588454938235, 2.9914597378567254, 2.9879182920387337, 2.9837356537903816, 2.978913178075594, 2.973452429530464, 2.967355183001345, 2.960623424166123, 2.953259350243103, 2.9452653707925838, 2.936644108616832, 2.927398400764866, 2.917531299649202, 2.9070460742824737, 2.895946211642714, 2.8842354181769543, 2.8719176214537945, 2.858996971976608, 2.84547784517022, 2.831364843555071, 2.816662799124249, 2.8013767759401778, 2.7855120729693343, 2.769074227175071, 2.7520690168904713, 2.7345024654952086, 2.716380845422573, 2.697710682525281, 2.67849876083132, 2.658752127723974, 2.6384780995833665, 2.6176842679303594, 2.5963785061174174, 2.5745689766152857, 2.552264138948904, 2.52947275834101, 2.5062039151274442, 2.4824670150141936, 2.4582718002529123, 2.4336283618188848, 2.4085471526834494, 2.3830390022815795, 2.3571151322849007, 2.330787173800865, 2.3040671861301374, 2.2769676772266525, 2.249501626018197, 2.2216825067599046, 2.1935243156086845, 2.1650415996233967, 2.1362494884134815, 2.107163728677727, 2.0778007218947394, 2.048177565447374, 2.018312097484485, 1.9882229458445537, 1.9579295813864206, 1.9274523760916529, 1.8968126663200582, 1.8660328216129798, 1.8351363194464896, 1.8041478263360182, 1.7730932856822252, 1.7420000127211368, 1.7108967968947564, 1.6798140118854155, 1.6487837334503515, 1.6178398650431534, 1.587018271004504, 1.5563569168327083, 1.525896015689237, 1.4956781798380243, 1.4657485751398567, 1.4361550760036526, 1.4069484173138251, 1.3781823387879242, 1.3499137159574668, 1.3222026705027836, 1.2951126510211852, 1.268710473502024, 1.2430663088911926, 1.218253603265246, 1.1943489144721593, 1.1714316478683584, 1.1495836732972278, 1.1288888060846423, 1.1094321369873812, 1.0912992001355921, 1.074574974406585, 1.0593427225355803, 1.0456826835142758, 1.0336706469673362, 1.0233764522812274, 1.0148624688668106, 1.008182125270955, 1.0033785619707922, 1.0004834838382897, 0.9995162822919884, 1.0004834838382919, 1.003378561970796, 1.008182125270961, 1.0148624688668184, 1.0233764522812367, 1.0336706469673478, 1.045682683514289, 1.0593427225355954, 1.0745749744066013, 1.0912992001356099, 1.1094321369874003, 1.1288888060846627, 1.1495836732972495, 1.1714316478683813, 1.194348914472183, 1.218253603265271, 1.2430663088912186, 1.268710473502051, 1.2951126510212128, 1.3222026705028118, 1.3499137159574954, 1.3781823387879535, 1.4069484173138551, 1.4361550760036828, 1.465748575139887, 1.4956781798380554, 1.525896015689268, 1.55635691683274, 1.5870182710045353, 1.6178398650431849, 1.648783733450383, 1.6798140118854474, 1.7108967968947881, 1.7420000127211688, 1.7730932856822574, 1.8041478263360502, 1.8351363194465218, 1.8660328216130115, 1.89681266632009, 1.9274523760916846, 1.9579295813864523, 1.9882229458445848, 2.0183120974845155, 2.048177565447405, 2.0778007218947696, 2.1071637286777567, 2.1362494884135113, 2.165041599623426, 2.193524315608714, 2.2216825067599335, 2.249501626018225, 2.2769676772266805, 2.304067186130165, 2.330787173800892, 2.3571151322849273, 2.3830390022816057, 2.408547152683475, 2.43362836181891, 2.4582718002529367, 2.482467015014218, 2.506203915127468, 2.5294727583410346, 2.552264138948927, 2.5745689766153084, 2.5963785061174396, 2.6176842679303816, 2.6384780995833874, 2.658752127723994, 2.678498760831341, 2.6977106825253006, 2.7163808454225915, 2.734502465495227, 2.7520690168904887, 2.7690742271750874, 2.7855120729693503, 2.8013767759401937, 2.8166627991242645, 2.8313648435550856, 2.8454778451702336, 2.8589969719766217, 2.8719176214538074, 2.8842354181769667, 2.8959462116427255, 2.907046074282485, 2.9175312996492124, 2.9273984007648757, 2.9366441086168407, 2.9452653707925927, 2.9532593502431106, 2.9606234241661307, 2.9673551830013514, 2.97345242953047, 2.9789131780755995, 2.983735653790386, 2.9879182920387377, 2.991459737856729, 2.994358845493826, 2.996614678030142, 2.9982265070669656, 2.999193812488341], [3.0, 2.999677504194068, 2.9987101207910003, 2.997098161868588, 2.9948421476687392, 2.991942806766705, 2.988401076309713, 2.9842181023267096, 2.9793952401114328, 2.9739340546815924, 2.96783632131742, 2.96110402618347, 2.9537393670380996, 2.9457447540357156, 2.9371228106274834, 2.927876374566925, 2.918008499027559, 2.907522453840494, 2.8964217268607664, 2.8847100254720894, 2.872391278240657, 2.8594696367296866, 2.845949477487531, 2.831835404223384, 2.817132250185963, 2.8018450807619644, 2.7859791963126668, 2.769540135268778, 2.7525336775054314, 2.73496584802134, 2.716842920948255, 2.6981714239193764, 2.678958142827934, 2.659210127010139, 2.6389346948898282, 2.6181394401256193, 2.596832238305251, 2.5750212542359208, 2.5527149498840433, 2.5299220930229334, 2.5066517666523693, 2.4829133792601352, 2.4587166760022225, 2.4340717508857153, 2.4089890600463186, 2.3834794362212492, 2.3575541045277544, 2.3312246996679384, 2.3045032846919513, 2.2774023714639533, 2.2499349429886575, 2.2221144777707926, 2.193954976395436, 2.1654709905339162, 2.1366776545979196, 2.1075907202832984, 2.078226594265017, 2.0486023793252537, 2.0187359192177876, 1.9886458475929094, 1.958351641327715, 1.9278736786258825, 1.8972333022679102, 1.8664528884058247, 1.8355559213037362, 1.8045670744249098, 1.7735122982541318, 1.742418915217197, 1.711315722012353, 1.6802330995953667, 1.649203130952895, 1.6182597266487537, 1.5874387579232352, 1.5567781968534804, 1.5263182627274532, 1.4961015733274858, 1.4661732992419205, 1.4365813186040413, 1.4073763687752252, 1.378612190424997, 1.350345658200505, 1.3226368907175428, 1.295549330956093, 1.2691497863407857, 1.2435084158996748, 1.2186986500373664, 1.1947970268011252, 1.1718829272976403, 1.1500381924401608, 1.1293466038419477, 1.109893213836369, 1.091763513710301, 1.0750424356299084, 1.0598131925963747, 1.0461559719972728, 1.034146511433914, 1.023854599558435, 1.015342558226969, 1.0086637735756747, 1.003861350718125, 1.0009669679025603, 0.9999999999999999, 1.0009669679025626, 1.0038613507181289, 1.0086637735756805, 1.015342558226977, 1.023854599558445, 1.0341465114339252, 1.0461559719972862, 1.0598131925963896, 1.0750424356299246, 1.0917635137103192, 1.1098932138363884, 1.1293466038419684, 1.1500381924401826, 1.1718829272976632, 1.1947970268011494, 1.2186986500373913, 1.2435084158997007, 1.2691497863408125, 1.2955493309561206, 1.3226368907175707, 1.350345658200534, 1.3786121904250266, 1.4073763687752552, 1.4365813186040717, 1.4661732992419512, 1.4961015733275167, 1.5263182627274845, 1.5567781968535117, 1.5874387579232667, 1.6182597266487855, 1.649203130952927, 1.6802330995953987, 1.7113157220123851, 1.742418915217229, 1.773512298254164, 1.8045670744249418, 1.835555921303768, 1.8664528884058562, 1.8972333022679417, 1.9278736786259139, 1.9583516413277464, 1.9886458475929405, 2.0187359192178183, 2.0486023793252843, 2.078226594265047, 2.1075907202833286, 2.1366776545979493, 2.165470990533946, 2.1939549763954647, 2.2221144777708215, 2.2499349429886855, 2.2774023714639813, 2.3045032846919793, 2.331224699667965, 2.3575541045277815, 2.3834794362212763, 2.408989060046345, 2.4340717508857406, 2.4587166760022474, 2.4829133792601596, 2.5066517666523938, 2.529922093022957, 2.5527149498840664, 2.5750212542359434, 2.5968322383052733, 2.61813944012564, 2.638934694889849, 2.6592101270101605, 2.678958142827954, 2.698171423919396, 2.7168429209482743, 2.734965848021358, 2.752533677505449, 2.7695401352687954, 2.7859791963126836, 2.80184508076198, 2.8171322501859786, 2.8318354042233986, 2.8459494774875456, 2.8594696367297003, 2.87239127824067, 2.884710025472102, 2.8964217268607775, 2.9075224538405053, 2.9180084990275703, 2.927876374566935, 2.9371228106274923, 2.945744754035725, 2.9537393670381076, 2.9611040261834765, 2.9678363213174266, 2.9739340546815987, 2.979395240111438, 2.9842181023267145, 2.9884010763097173, 2.9919428067667075, 2.9948421476687415, 2.997098161868591, 2.998710120791002, 2.9996775041940684], [2.9995162822919874, 2.9991938124883393, 2.9982265070669634, 2.9966146780301397, 2.9943588454938226, 2.9914597378567245, 2.987918292038733, 2.9837356537903807, 2.9789131780755933, 2.973452429530463, 2.9673551830013443, 2.9606234241661222, 2.953259350243102, 2.945265370792583, 2.936644108616831, 2.927398400764865, 2.9175312996492013, 2.907046074282473, 2.895946211642713, 2.8842354181769534, 2.8719176214537936, 2.858996971976607, 2.845477845170219, 2.83136484355507, 2.8166627991242477, 2.801376775940177, 2.785512072969333, 2.76907422717507, 2.7520690168904705, 2.7345024654952077, 2.716380845422572, 2.69771068252528, 2.678498760831319, 2.658752127723973, 2.6384780995833657, 2.6176842679303585, 2.5963785061174165, 2.5745689766152853, 2.5522641389489027, 2.5294727583410097, 2.506203915127443, 2.482467015014193, 2.458271800252911, 2.4336283618188834, 2.4085471526834485, 2.383039002281578, 2.3571151322848993, 2.3307871738008643, 2.3040671861301365, 2.2769676772266516, 2.249501626018196, 2.2216825067599033, 2.1935243156086837, 2.165041599623396, 2.1362494884134806, 2.1071637286777256, 2.0778007218947385, 2.0481775654473737, 2.018312097484484, 1.9882229458445528, 1.95792958138642, 1.9274523760916522, 1.8968126663200575, 1.8660328216129791, 1.835136319446489, 1.8041478263360171, 1.7730932856822246, 1.742000012721136, 1.7108967968947555, 1.6798140118854143, 1.6487837334503503, 1.6178398650431522, 1.5870182710045027, 1.5563569168327078, 1.5258960156892358, 1.4956781798380234, 1.4657485751398558, 1.4361550760036517, 1.4069484173138243, 1.3781823387879233, 1.349913715957466, 1.322202670502783, 1.2951126510211846, 1.2687104735020232, 1.2430663088911917, 1.2182536032652451, 1.1943489144721584, 1.1714316478683575, 1.1495836732972267, 1.1288888060846414, 1.1094321369873803, 1.091299200135591, 1.074574974406584, 1.0593427225355796, 1.0456826835142747, 1.0336706469673353, 1.0233764522812263, 1.0148624688668098, 1.0081821252709542, 1.0033785619707911, 1.0004834838382888, 0.9995162822919874, 1.0004834838382908, 1.0033785619707951, 1.0081821252709602, 1.0148624688668175, 1.0233764522812359, 1.0336706469673467, 1.0456826835142883, 1.0593427225355945, 1.0745749744066007, 1.091299200135609, 1.1094321369873994, 1.128888806084662, 1.1495836732972486, 1.1714316478683806, 1.1943489144721824, 1.2182536032652702, 1.2430663088912177, 1.2687104735020498, 1.295112651021212, 1.3222026705028112, 1.3499137159574945, 1.3781823387879526, 1.4069484173138542, 1.436155076003682, 1.4657485751398864, 1.4956781798380545, 1.5258960156892671, 1.556356916832739, 1.5870182710045346, 1.617839865043184, 1.648783733450382, 1.6798140118854465, 1.7108967968947875, 1.742000012721168, 1.7730932856822563, 1.804147826336049, 1.835136319446521, 1.8660328216130109, 1.896812666320089, 1.9274523760916837, 1.9579295813864512, 1.988222945844584, 2.0183120974845146, 2.048177565447404, 2.0778007218947687, 2.107163728677756, 2.1362494884135104, 2.1650415996234247, 2.193524315608713, 2.221682506759932, 2.2495016260182243, 2.2769676772266796, 2.304067186130164, 2.3307871738008914, 2.357115132284927, 2.3830390022816044, 2.4085471526834747, 2.433628361818909, 2.458271800252936, 2.4824670150142176, 2.5062039151274673, 2.529472758341033, 2.5522641389489262, 2.5745689766153075, 2.596378506117439, 2.6176842679303807, 2.638478099583387, 2.6587521277239934, 2.67849876083134, 2.6977106825252997, 2.7163808454225906, 2.7345024654952264, 2.752069016890488, 2.7690742271750866, 2.7855120729693494, 2.801376775940193, 2.8166627991242636, 2.8313648435550847, 2.8454778451702327, 2.8589969719766204, 2.8719176214538065, 2.884235418176966, 2.8959462116427246, 2.907046074282484, 2.9175312996492115, 2.927398400764875, 2.9366441086168398, 2.9452653707925918, 2.9532593502431097, 2.96062342416613, 2.9673551830013505, 2.973452429530469, 2.9789131780755986, 2.983735653790385, 2.987918292038737, 2.991459737856728, 2.994358845493825, 2.996614678030141, 2.9982265070669647, 2.99919381248834], [2.998065597133593, 2.997743205361961, 2.9967761339611747, 2.995164694707055, 2.992909407337822, 2.990010999722737, 2.986470408099884, 2.9822887773848317, 2.977467461552375, 2.9720080240941247, 2.9659122385552146, 2.959182089153987, 2.951819771489096, 2.943827693339077, 2.935208475560107, 2.925964953088348, 2.9161001760540057, 2.905617411015038, 2.8945201423192564, 2.8828120736044913, 2.8704971294474384, 2.8575794571728665, 2.8440634288359856, 2.829953643391988, 2.8152549290681237, 2.7999723459550867, 2.7841111888360635, 2.7676769902735034, 2.7506755239755223, 2.7331128084658878, 2.714995111083731, 2.6963289523415854, 2.6771211106729647, 2.6573786276036326, 2.6371088133838625, 2.616319253122499, 2.5950178134674227, 2.5732126498812526, 2.5509122145656633, 2.5281252650927963, 2.5048608738077194, 2.4811284380720116, 2.456937691425162, 2.4322987157477978, 2.4072219545187385, 2.381718227266617, 2.3557987453263833, 2.3294751290214624, 2.302759426403696, 2.275664133695645, 2.2482022175932217, 2.2203871396012227, 2.1922328825899933, 2.1637539797783165, 2.134965546365567, 2.105883314055225, 2.0765236687318414, 2.0469036915743173, 2.017041203909627, 1.9869548161324602, 1.9566639810370923, 1.926189051927357, 1.8955513458878037, 1.864773212612539, 1.8338781091961076, 1.8028906812905607, 1.7718368510215938, 1.7407439120303547, 1.7096406319612978, 1.678557362644108, 1.647526158111646, 1.6165809004466898, 1.585757433246744, 1.555093702224911, 1.5246299021100826, 1.4944086285535954, 1.4644750331720802, 1.434876979136272, 1.4056651938317377, 1.376893414050377, 1.3486185179068364, 1.320900636206837, 1.2938032343358024, 1.2673931539209615, 1.2417406016168921, 1.2169190704871917, 1.1930051777743116, 1.170078401602956, 1.1482206986583847, 1.127515985493635, 1.1080494682674895, 1.0899068098172529, 1.073173129377438, 1.057931839153395, 1.0442633332556095, 1.0322435577136548, 1.0219425044662132, 1.013422685934357, 1.0067376582198746, 1.0019306681693876, 0.9990335007415116, 0.9980655971335932, 0.9990335007415135, 1.0019306681693916, 1.0067376582198806, 1.0134226859343647, 1.021942504466223, 1.0322435577136662, 1.044263333255623, 1.0579318391534096, 1.0731731293774545, 1.0899068098172708, 1.1080494682675088, 1.1275159854936554, 1.1482206986584067, 1.1700784016029786, 1.1930051777743358, 1.2169190704872168, 1.2417406016169181, 1.2673931539209884, 1.2938032343358299, 1.3209006362068652, 1.3486185179068648, 1.376893414050406, 1.4056651938317677, 1.4348769791363025, 1.4644750331721108, 1.4944086285536264, 1.5246299021101137, 1.5550937022249425, 1.5857574332467756, 1.6165809004467215, 1.647526158111678, 1.6785573626441401, 1.7096406319613295, 1.7407439120303867, 1.7718368510216258, 1.8028906812905925, 1.8338781091961394, 1.8647732126125705, 1.8955513458878352, 1.9261890519273885, 1.9566639810371236, 1.9869548161324915, 2.0170412039096575, 2.0469036915743475, 2.076523668731872, 2.105883314055255, 2.1349655463655965, 2.163753979778346, 2.192232882590022, 2.220387139601251, 2.24820221759325, 2.2756641336956736, 2.3027594264037234, 2.3294751290214895, 2.3557987453264104, 2.381718227266643, 2.4072219545187648, 2.432298715747823, 2.456937691425187, 2.481128438072036, 2.5048608738077434, 2.5281252650928194, 2.550912214565686, 2.573212649881275, 2.5950178134674453, 2.616319253122521, 2.637108813383884, 2.6573786276036526, 2.6771211106729846, 2.696328952341605, 2.7149951110837502, 2.7331128084659064, 2.75067552397554, 2.7676769902735208, 2.7841111888360803, 2.7999723459551036, 2.8152549290681397, 2.8299536433920025, 2.8440634288359994, 2.8575794571728803, 2.870497129447451, 2.8828120736045033, 2.894520142319268, 2.905617411015049, 2.916100176054016, 2.925964953088358, 2.935208475560116, 2.9438276933390854, 2.951819771489104, 2.9591820891539946, 2.9659122385552212, 2.9720080240941305, 2.977467461552381, 2.982288777384837, 2.9864704080998883, 2.99001099972274, 2.9929094073378244, 2.9951646947070563, 2.9967761339611765, 2.9977432053619615], [2.995649347969017, 2.995327086334647, 2.994360405219968, 2.992749616023609, 2.990495237854644, 2.9875979977004823, 2.9840588306636024, 2.9798788802688576, 2.97505949884355, 2.9696022479730395, 2.9635088990351393, 2.9567814338171625, 2.949422045220045, 2.9414331380545824, 2.9328173299354927, 2.9235774522796856, 2.9137165514158587, 2.903237889813338, 2.892144947438882, 2.880441423251115, 2.8681312368431775, 2.8552185302452586, 2.8417076698997796, 2.827603248823226, 2.8129100889699576, 2.797633243814752, 2.7817780011723925, 2.765349886274354, 2.7483546651244324, 2.7307983481572693, 2.7126871942258584, 2.694027714946606, 2.674826679433137, 2.655091119452934, 2.634828335044099, 2.6140459006330024, 2.5927516716973877, 2.570953792023732, 2.5486607016122163, 2.5258811452877494, 2.5026241820809876, 2.478899195449411, 2.4547159044151416, 2.4300843757035198, 2.405015036974467, 2.379518691247412, 2.35360653263016, 2.3272901634725636, 2.3005816130772656, 2.2734933581122405, 2.246038344883342, 2.218230013639695, 2.1900823251005406, 2.161609789409057, 2.1328274977367743, 2.1037511567813567, 2.0743971264207017, 2.044782460807253, 2.0149249532079097, 1.984843184916535, 1.954556578587206, 1.9240854563562744, 1.893451103138952, 1.8626758355000446, 1.8317830765068936, 1.8007974369730397, 1.7697448034906236, 1.7386524336241016, 1.7075490585925897, 1.6764649936968472, 1.6454322566419566, 1.6144846937587598, 1.583658113924784, 1.552990429715214, 1.52252180496067, 1.4922948074330369, 1.462354564803225, 1.4327489212940643, 1.4035285915657796, 1.3747473073008907, 1.3464619506849758, 1.3187326675041893, 1.2916229509099717, 1.2651996850703202, 1.2395331360034265, 1.2146968749871583, 1.1907676182278895, 1.167824965193134, 1.1459510174752985, 1.1252298606366211, 1.1057468936119286, 1.0875879943424553, 1.070838516738998, 1.0555821230198403, 1.0418994668517363, 1.029866756059678, 1.019554238005209, 1.0110246646185297, 1.0043318056742299, 0.9995190862355898, 0.996618425460977, 0.9956493479690169, 0.9966184254609789, 0.9995190862355938, 1.0043318056742356, 1.0110246646185372, 1.019554238005219, 1.0298667560596892, 1.0418994668517496, 1.0555821230198552, 1.0708385167390144, 1.0875879943424736, 1.105746893611948, 1.125229860636642, 1.1459510174753205, 1.1678249651931571, 1.1907676182279134, 1.2146968749871834, 1.2395331360034523, 1.2651996850703469, 1.291622950909999, 1.3187326675042175, 1.3464619506850044, 1.37474730730092, 1.4035285915658096, 1.4327489212940945, 1.4623545648032557, 1.4922948074330677, 1.5225218049607012, 1.552990429715245, 1.5836581139248158, 1.6144846937587916, 1.6454322566419888, 1.6764649936968794, 1.7075490585926216, 1.7386524336241336, 1.7697448034906553, 1.8007974369730715, 1.831783076506925, 1.8626758355000763, 1.8934511031389836, 1.9240854563563061, 1.9545565785872374, 1.9848431849165666, 2.0149249532079407, 2.044782460807283, 2.074397126420732, 2.103751156781387, 2.132827497736804, 2.1616097894090864, 2.1900823251005694, 2.2182300136397237, 2.24603834488337, 2.2734933581122685, 2.3005816130772927, 2.3272901634725907, 2.353606532630187, 2.379518691247439, 2.4050150369744934, 2.4300843757035455, 2.4547159044151665, 2.478899195449436, 2.5026241820810116, 2.5258811452877725, 2.54866070161224, 2.570953792023755, 2.5927516716974104, 2.6140459006330237, 2.63482833504412, 2.6550911194529534, 2.6748266794331568, 2.6940277149466247, 2.7126871942258766, 2.7307983481572875, 2.74835466512445, 2.765349886274371, 2.78177800117241, 2.7976332438147677, 2.812910088969974, 2.8276032488232405, 2.841707669899794, 2.8552185302452724, 2.8681312368431904, 2.8804414232511264, 2.8921449474388936, 2.903237889813349, 2.91371655141587, 2.9235774522796953, 2.932817329935502, 2.941433138054591, 2.949422045220053, 2.9567814338171696, 2.963508899035146, 2.9696022479730457, 2.9750594988435553, 2.979878880268862, 2.9840588306636064, 2.9875979977004863, 2.9904952378546463, 2.992749616023611, 2.99436040521997, 2.995327086334648], [2.9922698723632744, 2.9919477930973533, 2.990981658912241, 2.9893717806790114, 2.9871186766267916, 2.984223072509594, 2.980685901841592, 2.97650830620252, 2.971691635615418, 2.9662374489994585, 2.9601475147011116, 2.9534238111074997, 2.946068527346339, 2.938084064077512, 2.9294730343819557, 2.92023826475422, 2.9103827962058215, 2.8999098854872516, 2.888823006437377, 2.8771258514698332, 2.8648223332069995, 2.8519165862731755, 2.8384129692597004, 2.8243160668759844, 2.8096306923017362, 2.794361889757106, 2.7785149373090317, 2.762095349933761, 2.7451088828574077, 2.72756153519838, 2.709459553937789, 2.6908094382463066, 2.6716179441986423, 2.6518920899096687, 2.631639161129437, 2.6108667173377857, 2.5895825983830854, 2.567794931713845, 2.5455121402565135, 2.522742950997868, 2.499496404335917, 2.4757818642693348, 2.45160902950213, 2.426987945547557, 2.401929017923336, 2.376443026538994, 2.3505411413858313, 2.3242349396504465, 2.297536424384314, 2.270458044874332, 2.243012718872877, 2.2152138568605957, 2.187075388531021, 2.158611791703184, 2.1298381238865964, 2.1007700567423573, 2.071423913704502, 2.041816711046937, 2.0119662027031016, 1.9818909291674753, 1.9516102708296423, 1.9211445061120511, 1.8905148748008473, 1.8597436469737973, 1.828854197938531, 1.7978710895957488, 1.7668201586325967, 1.7357286119271793, 1.704625129501272, 1.673539975288466, 1.6425051158816208, 1.6115543472771692, 1.58072342943317, 1.5500502281894164, 1.5195748637454487, 1.4893398644376967, 1.4593903239797792, 1.4297740596082933, 1.4005417676880911, 1.371747172255531, 1.3434471606999185, 1.3157018992960077, 1.288574919613411, 1.2621331649754062, 1.236446984187368, 1.2115900578173744, 1.1876392405600227, 1.1646743018894623, 1.1427775466233567, 1.1220332975594385, 1.1025272244420932, 1.0843455076042727, 1.0675738310795764, 1.0522962089954042, 1.0385936605622754, 1.026542762487525, 1.0162141221977512, 1.007670829388325, 1.0009669552651295, 0.9961461763733932, 0.9932406012807915, 0.9922698723632744, 0.9932406012807936, 0.9961461763733972, 1.0009669552651355, 1.0076708293883327, 1.0162141221977612, 1.0265427624875363, 1.0385936605622887, 1.0522962089954186, 1.0675738310795928, 1.084345507604291, 1.1025272244421125, 1.1220332975594591, 1.142777546623379, 1.1646743018894852, 1.1876392405600467, 1.2115900578173993, 1.2364469841873942, 1.2621331649754328, 1.2885749196134386, 1.3157018992960359, 1.3434471606999472, 1.3717471722555603, 1.400541767688121, 1.4297740596083237, 1.4593903239798096, 1.4893398644377276, 1.5195748637454798, 1.5500502281894477, 1.5807234294332015, 1.6115543472772007, 1.6425051158816528, 1.673539975288498, 1.704625129501304, 1.7357286119272113, 1.7668201586326289, 1.7978710895957808, 1.8288541979385624, 1.8597436469738293, 1.8905148748008793, 1.9211445061120827, 1.9516102708296739, 1.9818909291675064, 2.0119662027031326, 2.041816711046968, 2.0714239137045323, 2.1007700567423875, 2.1298381238866257, 2.1586117917032137, 2.1870753885310505, 2.215213856860624, 2.2430127188729054, 2.27045804487436, 2.297536424384342, 2.3242349396504736, 2.350541141385858, 2.376443026539021, 2.401929017923362, 2.426987945547583, 2.451609029502155, 2.475781864269359, 2.4994964043359413, 2.522742950997892, 2.545512140256536, 2.5677949317138675, 2.5895825983831076, 2.6108667173378066, 2.6316391611294576, 2.6518920899096896, 2.671617944198663, 2.690809438246326, 2.7094595539378075, 2.727561535198398, 2.745108882857426, 2.7620953499337784, 2.7785149373090485, 2.7943618897571225, 2.809630692301751, 2.824316066875999, 2.8384129692597146, 2.851916586273189, 2.8648223332070124, 2.877125851469845, 2.8888230064373888, 2.8999098854872627, 2.9103827962058317, 2.92023826475423, 2.9294730343819646, 2.9380840640775205, 2.9460685273463465, 2.9534238111075073, 2.9601475147011183, 2.966237448999464, 2.9716916356154237, 2.976508306202524, 2.980685901841596, 2.9842230725095966, 2.9871186766267943, 2.9893717806790137, 2.990981658912242, 2.9919477930973546], [2.987930439740754, 2.987608595250954, 2.986643165168493, 2.9850344596870504, 2.9827829959058585, 2.9798894979952033, 2.9763548974298017, 2.9721803332917616, 2.9673671526453296, 2.9619169109861367, 2.9558313727682215, 2.9491125120126176, 2.941762513001933, 2.9337837710659214, 2.925178893463702, 2.9159507003689926, 2.9061022259654146, 2.895636719659725, 2.884557647421681, 2.872868693260098, 2.860573760845655, 2.847676975292033, 2.8341826851080807, 2.8200954643349476, 2.805420114883392, 2.790161669087973, 2.7743253924963236, 2.757916786913462, 2.7409415937228996, 2.7234057975083665, 2.705315630002166, 2.686677574388585, 2.667498369993456, 2.647785017393836, 2.6275447839849764, 2.6067852100452265, 2.5855141153433334, 2.5637396063368274, 2.541470084014741, 2.518714252443033, 2.4954811280765683, 2.4717800499076854, 2.4476206905279922, 2.4230130681874513, 2.397967559942812, 2.3724949159963136, 2.3466062753352093, 2.320313182793269, 2.293627607666906, 2.266561964031188, 2.239129132914628, 2.2113424865064792, 2.183215914586268, 2.1547638533825135, 2.126001317086008, 2.096943932262636, 2.067607975431348, 2.0380104140944884, 2.0081689515298526, 1.9781020756763155, 1.947829112467014, 1.9173702839851698, 1.8867467718366475, 1.8559807861488704, 1.825095640616011, 1.7941158340129704, 1.7630671385926133, 1.7319766957580647, 1.7008731193597029, 1.669786606898599, 1.6387490588168618, 1.6077942059112134, 1.5769577447076704, 1.5462774803687267, 1.5157934763537586, 1.485548209600014, 1.4555867294146057, 1.4259568175450985, 1.3967091460046899, 1.3678974281462934, 1.3395785571915217, 1.311812724918097, 1.2846635115008584, 1.258197935619351, 1.2324864519555456, 1.2076028812215407, 1.1836242560514232, 1.160630564706178, 1.1387043738942668, 1.1179303124937006, 1.0983944000159247, 1.0801832077267481, 1.0633828468195539, 1.0480777871404732, 1.0343495216267045, 1.022275105361251, 1.0119256129941667, 1.003364572740437, 0.9966464473305312, 0.9918152400765249, 0.9889033057272865, 0.987930439740754, 0.9889033057272884, 0.9918152400765288, 0.9966464473305373, 1.0033645727404448, 1.0119256129941765, 1.0222751053612626, 1.034349521626718, 1.0480777871404883, 1.0633828468195705, 1.0801832077267661, 1.098394400015944, 1.1179303124937212, 1.1387043738942888, 1.1606305647062014, 1.1836242560514474, 1.2076028812215658, 1.2324864519555714, 1.2581979356193775, 1.2846635115008858, 1.3118127249181255, 1.3395785571915504, 1.3678974281463225, 1.3967091460047198, 1.4259568175451292, 1.455586729414636, 1.4855482096000452, 1.5157934763537897, 1.546277480368758, 1.5769577447077021, 1.6077942059112447, 1.6387490588168938, 1.6697866068986313, 1.7008731193597348, 1.7319766957580964, 1.763067138592645, 1.794115834013002, 1.8250956406160426, 1.855980786148902, 1.886746771836679, 1.9173702839852016, 1.9478291124670453, 1.9781020756763468, 2.0081689515298833, 2.038010414094519, 2.0676079754313785, 2.096943932262666, 2.126001317086038, 2.154763853382543, 2.183215914586297, 2.211342486506508, 2.239129132914656, 2.266561964031216, 2.293627607666933, 2.320313182793296, 2.3466062753352364, 2.3724949159963393, 2.397967559942838, 2.423013068187476, 2.447620690528017, 2.4717800499077103, 2.4954811280765923, 2.518714252443056, 2.5414700840147644, 2.5637396063368496, 2.585514115343356, 2.6067852100452478, 2.6275447839849972, 2.647785017393856, 2.667498369993476, 2.686677574388604, 2.7053156300021843, 2.7234057975083847, 2.740941593722917, 2.7579167869134795, 2.774325392496341, 2.790161669087989, 2.8054201148834084, 2.8200954643349623, 2.8341826851080953, 2.847676975292046, 2.8605737608456674, 2.87286869326011, 2.8845576474216927, 2.895636719659736, 2.906102225965425, 2.915950700369003, 2.9251788934637104, 2.9337837710659294, 2.941762513001941, 2.9491125120126243, 2.955831372768228, 2.9619169109861425, 2.967367152645335, 2.972180333291767, 2.976354897429806, 2.979889497995207, 2.9827829959058607, 2.9850344596870517, 2.9866431651684944, 2.987608595250954], [2.9826352482222607, 2.982313691143452, 2.981349123018549, 2.979741853214657, 2.977492397452295, 2.9746014779692467, 2.971070023751632, 2.966899170833882, 2.962090262669815, 2.956644850577525, 2.950564694261311, 2.9438517624144627, 2.936508233407271, 2.9285364960652633, 2.9199391505432772, 2.910719009301722, 2.900879098192045, 2.89042265765924, 2.8793531440700373, 2.8676742311763155, 2.8553898117242507, 2.8425039992207193, 2.829021129869619, 2.8149457646919744, 2.8002826918450023, 2.7850369291567607, 2.769213726894531, 2.7528185707868063, 2.7358571853205964, 2.718335537337777, 2.700259839956423, 2.681636556845481, 2.6624724068837784, 2.6427743692372827, 2.622549688891658, 2.6018058826807207, 2.5805507458551538, 2.558792359240087, 2.5365390970347423, 2.5137996353124143, 2.4905829612846264, 2.46689838339941, 2.4427555423503633, 2.4181644230805235, 2.3931353678731764, 2.3676790906305594, 2.3418066924511747, 2.315529678627011, 2.2888599771936056, 2.2618099591785326, 2.2343924607076824, 2.2066208071436493, 2.178508839446705, 2.1500709429662805, 2.1213220788895106, 2.092277818593294, 2.0629543811673283, 2.033368674397524, 2.0035383395219233, 1.9734818000942425, 1.943218315313028, 1.9127680381963017, 1.882152079001536, 1.8513925743074606, 1.8205127621857473, 1.7895370638947494, 1.7584911725210988, 1.7274021489742626, 1.6962985256991518, 1.665210418406374, 1.634169646021046, 1.6032098589096653, 1.5723666752488679, 1.5416778251360774, 1.5111833016937184, 1.480925517966904, 1.4509494678381194, 1.4213028884583159, 1.392036420798452, 1.3632037638364527, 1.3348618165940873, 1.3070708007173903, 1.2798943545597747, 1.2533995878093496, 1.227657083666587, 1.2027408335377856, 1.1787280873366277, 1.1556991010255504, 1.1337367623043946, 1.112926075765129, 1.0933534908326457, 1.075106059868201, 1.0582704203274678, 1.0429316040773415, 1.0291716888313143, 1.0170683206899882, 1.0066931519831903, 0.9981102534792766, 0.9913745725948213, 0.9865305173501808, 0.9836107475038126, 0.9826352482222604, 0.9836107475038147, 0.9865305173501848, 0.9913745725948274, 0.9981102534792846, 1.0066931519832, 1.0170683206899995, 1.0291716888313276, 1.0429316040773564, 1.0582704203274842, 1.075106059868219, 1.0933534908326654, 1.1129260757651498, 1.1337367623044166, 1.1556991010255737, 1.1787280873366517, 1.2027408335378107, 1.2276570836666132, 1.2533995878093764, 1.2798943545598023, 1.3070708007174185, 1.3348618165941162, 1.3632037638364825, 1.3920364207984814, 1.4213028884583463, 1.4509494678381496, 1.4809255179669352, 1.5111833016937495, 1.5416778251361087, 1.5723666752488996, 1.6032098589096972, 1.634169646021078, 1.6652104184064058, 1.6962985256991838, 1.727402148974295, 1.7584911725211307, 1.7895370638947814, 1.8205127621857793, 1.8513925743074922, 1.8821520790015678, 1.9127680381963335, 1.9432183153130596, 1.9734818000942733, 2.003538339521954, 2.0333686743975545, 2.0629543811673585, 2.0922778185933244, 2.1213220788895404, 2.1500709429663103, 2.1785088394467342, 2.2066208071436777, 2.2343924607077112, 2.2618099591785605, 2.2888599771936335, 2.3155296786270387, 2.3418066924512013, 2.3676790906305856, 2.393135367873202, 2.4181644230805492, 2.4427555423503877, 2.466898383399435, 2.4905829612846504, 2.5137996353124374, 2.536539097034765, 2.558792359240109, 2.5805507458551755, 2.601805882680742, 2.622549688891679, 2.642774369237303, 2.6624724068837997, 2.6816365568455, 2.7002598399564426, 2.7183355373377953, 2.7358571853206137, 2.752818570786823, 2.7692137268945483, 2.7850369291567776, 2.8002826918450174, 2.814945764691988, 2.8290211298696337, 2.842503999220733, 2.8553898117242635, 2.8676742311763275, 2.879353144070049, 2.8904226576592515, 2.900879098192055, 2.910719009301731, 2.919939150543286, 2.928536496065272, 2.936508233407279, 2.9438517624144693, 2.9505646942613177, 2.9566448505775305, 2.962090262669821, 2.9668991708338863, 2.9710700237516363, 2.9746014779692507, 2.9774923974522975, 2.9797418532146587, 2.9813491230185503, 2.9823136911434522], [2.9763894205636032, 2.9760682038087825, 2.9751046563309997, 2.9734990865224376, 2.9712520084774514, 2.9683641421544786, 2.964836413604379, 2.960669955266884, 2.955866106337335, 2.9504264132064097, 2.9443526299760476, 2.9376467190553663, 2.93031085184091, 2.9223474094862016, 2.913758983766199, 2.9045483780429384, 2.894718608339374, 2.884272904529188, 2.87321471165118, 2.8615476913577247, 2.84927572350775, 2.8364029079157107, 2.8229335662691515, 2.8088722442286636, 2.7942237137253496, 2.778992975472327, 2.763185261708366, 2.7468060391934483, 2.72986101247785, 2.712356127468428, 2.6942975753179144, 2.675691796665513, 2.656545486259678, 2.636865597996887, 2.616659350413378, 2.5959342326703165, 2.574698011076677, 2.5529587361983492, 2.530724750606563, 2.508004697323839, 2.4848075290312215, 2.46114251810669, 2.437019267571386, 2.412447723027666, 2.3874381856811455, 2.3620013265477784, 2.3361482019567883, 2.309890270470991, 2.283239411357698, 2.2562079447562016, 2.228808653701716, 2.2010548081807846, 2.1729601914094987, 2.1445391285435575, 2.115806518048108, 2.0867778659755505, 2.057469323420872, 2.0278977274465606, 1.998080645792366, 1.9680364257089435, 1.9377842472780267, 1.9073441816046641, 1.8767372542881353, 1.8459855145961364, 1.815112110779921, 1.7841413719739856, 1.753098897119552, 1.722011651332723, 1.6909080701007777, 1.659818171627468, 1.6287736775526238, 1.597808142133287, 1.566957089781304, 1.5362581605917767, 1.5057512631513301, 1.4754787334655453, 1.4454854982693146, 1.4158192402585656, 1.3865305618821604, 1.3576731432352795, 1.3293038882809054, 1.3014830520835918, 1.2742743399742111, 1.2477449676046235, 1.2219656687608693, 1.1970106356942687, 1.1729573747752213, 1.1498864587224313, 1.12788115584078, 1.1070269170236327, 1.0874107032095515, 1.069120140014481, 1.0522424928149472, 1.0368634648967128, 1.0230658333711684, 1.0109279519317784, 1.000522165173249, 0.9919131945640075, 0.9851565692222194, 0.9802971831587954, 0.977368062558745, 0.9763894205636032, 0.9773680625587471, 0.9802971831587997, 0.9851565692222255, 0.9919131945640154, 1.0005221651732588, 1.0109279519317897, 1.0230658333711817, 1.0368634648967276, 1.0522424928149638, 1.069120140014499, 1.0874107032095712, 1.1070269170236535, 1.127881155840802, 1.1498864587224542, 1.1729573747752455, 1.1970106356942938, 1.2219656687608953, 1.2477449676046504, 1.274274339974239, 1.30148305208362, 1.3293038882809343, 1.3576731432353086, 1.3865305618821904, 1.415819240258596, 1.445485498269345, 1.4754787334655763, 1.5057512631513614, 1.536258160591808, 1.5669570897813356, 1.5978081421333188, 1.6287736775526556, 1.6598181716275, 1.6909080701008101, 1.7220116513327552, 1.753098897119584, 1.7841413719740171, 1.8151121107799526, 1.8459855145961679, 1.876737254288167, 1.9073441816046954, 1.9377842472780578, 1.968036425708975, 1.9980806457923972, 2.0278977274465912, 2.057469323420903, 2.0867778659755802, 2.115806518048138, 2.1445391285435864, 2.172960191409528, 2.2010548081808134, 2.2288086537017446, 2.2562079447562295, 2.2832394113577257, 2.3098902704710182, 2.336148201956815, 2.3620013265478046, 2.3874381856811717, 2.4124477230276913, 2.4370192675714106, 2.461142518106715, 2.4848075290312455, 2.5080046973238623, 2.530724750606586, 2.5529587361983723, 2.5746980110766993, 2.5959342326703383, 2.6166593504133995, 2.636865597996907, 2.6565454862596978, 2.675691796665532, 2.6942975753179335, 2.7123561274684462, 2.7298610124778677, 2.746806039193465, 2.7631852617083834, 2.7789929754723426, 2.794223713725365, 2.808872244228678, 2.8229335662691653, 2.836402907915724, 2.849275723507763, 2.861547691357737, 2.8732147116511917, 2.8842729045291997, 2.8947186083393843, 2.904548378042948, 2.9137589837662077, 2.9223474094862096, 2.9303108518409173, 2.9376467190553734, 2.9443526299760543, 2.950426413206416, 2.9558661063373406, 2.960669955266889, 2.9648364136043837, 2.9683641421544817, 2.9712520084774536, 2.9734990865224393, 2.9751046563310015, 2.9760682038087833], [2.9691989991996617, 2.968878176011143, 2.9679158088583177, 2.966312205011085, 2.964067876691833, 2.9611835412351106, 2.9576601213128146, 2.953498745226572, 2.9487007472694717, 2.9432676681598364, 2.937201255550217, 2.9305034646153776, 2.923176458723589, 2.915222610196162, 2.906644501160786, 2.897444924504931, 2.887626884936245, 2.877193600157712, 2.8661485021660984, 2.8544952386831324, 2.8422376747298057, 2.829379894355202, 2.815926202532384, 2.801881127235062, 2.7872494217100754, 2.7720360669621407, 2.7562462744688703, 2.7398854891457347, 2.722959392582516, 2.705473906574765, 2.6874351969760184, 2.668849677898915, 2.649724016296001, 2.6300651369539, 2.6098802279377074, 2.58917674652595, 2.567962425680287, 2.5462452810983223, 2.524033618902544, 2.501336044023466, 2.4781614693406664, 2.4545191256515335, 2.430418572544309, 2.4058697102594393, 2.380882792631404, 2.355468441212151, 2.3296376606871014, 2.303401855705456, 2.2767728492583315, 2.2497629027511516, 2.2223847379307458, 2.194651560842934, 2.166577088012921, 2.138175575058778, 2.1094618479675096, 2.0804513372838516, 2.05116011548378, 2.021604937827746, 1.9918032870125504, 1.96177342196532, 1.9315344311475962, 1.901106290761552, 1.8705099282727362, 1.8397672916832628, 1.8089014250042386, 1.777936550384197, 1.7468981573483724, 1.7158130995879668, 1.6847096997042275, 1.6536178622529556, 1.622569195343208, 1.5915971409098215, 1.5607371135911796, 1.5300266478870563, 1.4995055529295278, 1.4692160737530502, 1.4392030573754768, 1.4095141212753801, 1.380199820946893, 1.3513138121063542, 1.322913001794301, 1.2950576810491374, 1.2678116300275806, 1.2412421844381931, 1.2154202499997158, 1.1904202494460803, 1.1663199845490455, 1.1432003939684574, 1.1211451868063087, 1.1002403319557468, 1.0805733851873016, 1.0622326399109137, 1.045306094147949, 1.0298802357314867, 1.0160386601123756, 1.0038605499240185, 0.9934190616331963, 0.9847796805689388, 0.9779986192731406, 0.9731213431154269, 0.9701813092936024, 0.9691989991996618, 0.9701813092936045, 0.9731213431154307, 0.9779986192731466, 0.984779680568947, 0.9934190616332061, 1.00386054992403, 1.0160386601123892, 1.0298802357315018, 1.045306094147966, 1.0622326399109316, 1.0805733851873212, 1.1002403319557674, 1.121145186806331, 1.1432003939684805, 1.1663199845490697, 1.1904202494461054, 1.215420249999742, 1.2412421844382202, 1.267811630027608, 1.2950576810491656, 1.3229130017943298, 1.3513138121063837, 1.380199820946923, 1.4095141212754103, 1.4392030573755072, 1.4692160737530813, 1.499505552929559, 1.5300266478870879, 1.5607371135912114, 1.5915971409098533, 1.62256919534324, 1.6536178622529878, 1.6847096997042594, 1.7158130995879985, 1.7468981573484044, 1.7779365503842288, 1.8089014250042703, 1.8397672916832948, 1.8705099282727682, 1.9011062907615834, 1.9315344311476275, 1.9617734219653513, 1.9918032870125815, 2.0216049378277767, 2.051160115483811, 2.0804513372838813, 2.109461847967539, 2.138175575058807, 2.16657708801295, 2.194651560842962, 2.2223847379307746, 2.2497629027511796, 2.276772849258359, 2.3034018557054825, 2.329637660687128, 2.355468441212177, 2.3808827926314295, 2.4058697102594646, 2.4304185725443337, 2.4545191256515584, 2.478161469340691, 2.50133604402349, 2.524033618902567, 2.5462452810983454, 2.567962425680309, 2.589176746525972, 2.6098802279377282, 2.6300651369539203, 2.649724016296021, 2.668849677898934, 2.6874351969760366, 2.7054739065747837, 2.7229593925825344, 2.7398854891457516, 2.7562462744688863, 2.7720360669621567, 2.787249421710091, 2.8018811272350765, 2.8159262025323977, 2.829379894355215, 2.8422376747298186, 2.8544952386831444, 2.86614850216611, 2.877193600157723, 2.887626884936255, 2.8974449245049407, 2.9066445011607955, 2.91522261019617, 2.923176458723597, 2.930503464615385, 2.9372012555502236, 2.943267668159842, 2.948700747269477, 2.9534987452265766, 2.9576601213128186, 2.9611835412351137, 2.9640678766918356, 2.966312205011086, 2.967915808858319, 2.968878176011143], [2.9610709403987197, 2.960750564399622, 2.9597895383923998, 2.9581881683784537, 2.955946964464325, 2.953066641018819, 2.949548116894628, 2.945392515716095, 2.9406011662352802, 2.935175602758979, 2.9291175656498583, 2.9224290019054573, 2.915112065819322, 2.9071691197291822, 2.8986027348576875, 2.8894156922519145, 2.8796109838285373, 2.869191813532348, 2.858161598616624, 2.846523971054702, 2.8342827790930754, 2.821442088957372, 2.808006186723616, 2.79397958036846, 2.779367002013289, 2.764173410378572, 2.7484039934663507, 2.732064171490442, 2.715159600075763, 2.697696173750202, 2.6796800297546306, 2.661117552199098, 2.6420153765958405, 2.622380394802644, 2.602219760413293, 2.5815408946352982, 2.5603514926989197, 2.538659530845756, 2.5164732739497353, 2.4938012838285144, 2.4706524283088114, 2.4470358911154477, 2.422961182660586, 2.3984381518171647, 2.373476998768694, 2.3480882890366326, 2.322282968796417, 2.296072381604121, 2.2694682866676, 2.242482878809005, 2.21512881027975, 2.1874192146045517, 2.1593677326479277, 2.130988541114804, 2.1022963837164723, 2.0733066052541953, 2.0440351888951405, 2.0144987969389625, 1.9847148153980312, 1.9547014027397098, 1.9244775431647427, 1.8940631048210486, 1.8634789033761108, 1.832746771392403, 1.8018896339672383, 1.7709315911087564, 1.7398980073205919, 1.7088156088551993, 1.6777125890650386, 1.6466187222255564, 1.615565486116383, 1.5845861935176684, 1.553716132595047, 1.5229927158949277, 1.492455637334268, 1.4621470361255762, 1.4321116660053739, 1.402397067407179, 1.373053739311277, 1.3441353063864132, 1.3156986756900166, 1.287804175598539, 1.2605156677977374, 1.2339006210979337, 1.2080301336107313, 1.1829788875405385, 1.1588250186809899, 1.1356498809175943, 1.1135376849687966, 1.0925749906835762, 1.0728500339630356, 1.0544518733228487, 1.0374693477501329, 1.0219898471552102, 1.0080979093898759, 0.9958736730509448, 0.9853912320771159, 0.976716954816888, 0.9699078446008993, 0.9650100284326271, 0.9620574629199414, 0.9610709403987197, 0.9620574629199433, 0.9650100284326311, 0.9699078446009053, 0.976716954816896, 0.9853912320771259, 0.9958736730509564, 1.0080979093898892, 1.0219898471552253, 1.0374693477501493, 1.0544518733228672, 1.072850033963055, 1.092574990683597, 1.1135376849688188, 1.1356498809176174, 1.158825018681014, 1.182978887540564, 1.2080301336107573, 1.2339006210979606, 1.2605156677977651, 1.2878041755985674, 1.3156986756900455, 1.3441353063864425, 1.3730537393113071, 1.4023970674072097, 1.4321116660054047, 1.4621470361256073, 1.492455637334299, 1.5229927158949594, 1.5537161325950786, 1.5845861935176997, 1.6155654861164148, 1.6466187222255888, 1.6777125890650708, 1.7088156088552315, 1.739898007320624, 1.7709315911087884, 1.80188963396727, 1.8327467713924348, 1.863478903376142, 1.89406310482108, 1.9244775431647736, 1.954701402739741, 1.9847148153980623, 2.014498796938993, 2.0440351888951707, 2.073306605254225, 2.1022963837165016, 2.1309885411148333, 2.159367732647957, 2.18741921460458, 2.215128810279778, 2.2424828788090325, 2.2694682866676277, 2.2960723816041475, 2.3222829687964435, 2.3480882890366592, 2.3734769987687203, 2.3984381518171896, 2.422961182660611, 2.447035891115472, 2.4706524283088354, 2.493801283828538, 2.5164732739497584, 2.5386595308457784, 2.5603514926989424, 2.581540894635319, 2.6022197604133144, 2.6223803948026636, 2.64201537659586, 2.6611175521991175, 2.6796800297546484, 2.6976961737502196, 2.715159600075781, 2.732064171490459, 2.748403993466367, 2.764173410378588, 2.7793670020133043, 2.793979580368475, 2.8080061867236297, 2.8214420889573844, 2.8342827790930882, 2.8465239710547134, 2.8581615986166358, 2.869191813532359, 2.8796109838285475, 2.889415692251925, 2.8986027348576964, 2.9071691197291902, 2.91511206581933, 2.922429001905465, 2.929117565649865, 2.9351756027589846, 2.940601166235286, 2.9453925157160996, 2.9495481168946314, 2.9530666410188227, 2.955946964464327, 2.9581881683784554, 2.959789538392401, 2.960750564399623], [2.9520131075327245, 2.9516932327788132, 2.950733710036212, 2.9491348438929395, 2.9468971420980146, 2.9440213157157364, 2.9405082793433217, 2.9363591513935154, 2.931575254444316, 2.926158115658446, 2.9201094672757155, 2.9134312471819666, 2.9061255995588615, 2.8981948756193563, 2.8896416344343523, 2.880468643856655, 2.870678881549119, 2.8602755361245595, 2.84926200840589, 2.8376419128157524, 2.825419078905896, 2.8125975530375524, 2.7991816002251464, 2.785175706156906, 2.77058457940718, 2.7554131538567277, 2.7396665913387483, 2.7233502845301047, 2.706469860109012, 2.689031182202483, 2.671040356148984, 2.6525037326041807, 2.6334279120202524, 2.61381974953217, 2.593686360287489, 2.5730351252596804, 2.5518736975888814, 2.5302100094981332, 2.508052279837823, 2.4854090223161482, 2.4622890544790406, 2.4387015075091645, 2.414655836920423, 2.390161834231898, 2.365229639713408, 2.339869756303914, 2.3140930648140214, 2.2879108405347557, 2.261334771386792, 2.234376977757535, 2.207050034187796, 2.1793669930855417, 2.151341410661303, 2.122987375298334, 2.094319538590664, 2.0653531493037005, 2.0361040905349927, 2.0065889203771277, 1.9768249164102198, 1.946830124377882, 1.9166234114273977, 1.8862245243214761, 1.8556541530545385, 1.824934000329702, 1.794086857371885, 1.7631366865654858, 1.7321087114090072, 1.7010295142700225, 1.6699271423971331, 1.6388312225948494, 1.6077730848847929, 1.5767858953525, 1.5459047982012983, 1.5151670667885386, 1.484612263087193, 1.4542824045767055, 1.4242221369970363, 1.3944789106724507, 1.365103157198189, 1.336148462155338, 1.3076717281513213, 1.2797333208577666, 1.2523971888304641, 1.2257309457682493, 1.1998059015551052, 1.1746970260399063, 1.1504828272154708, 1.1272451235213523, 1.105068688766813, 1.0840407481030179, 1.0642503050987748, 1.0457872838612288, 1.028741476817827, 1.0132012986020378, 0.9992523595101818, 0.9869758877867739, 0.9764470474995063, 0.9677332162603894, 0.9608923022356295, 0.9559711901595447, 0.9530044089755739, 0.9520131075327244, 0.9530044089755758, 0.9559711901595486, 0.9608923022356355, 0.9677332162603975, 0.9764470474995163, 0.9869758877867857, 0.9992523595101953, 1.013201298602053, 1.0287414768178438, 1.0457872838612472, 1.0642503050987948, 1.084040748103039, 1.1050686887668353, 1.1272451235213756, 1.1504828272154952, 1.1746970260399314, 1.1998059015551317, 1.2257309457682763, 1.252397188830492, 1.2797333208577946, 1.3076717281513506, 1.3361484621553676, 1.365103157198219, 1.3944789106724809, 1.4242221369970673, 1.4542824045767366, 1.4846122630872245, 1.5151670667885702, 1.54590479820133, 1.5767858953525318, 1.6077730848848246, 1.6388312225948813, 1.6699271423971656, 1.7010295142700549, 1.7321087114090394, 1.7631366865655174, 1.7940868573719166, 1.8249340003297336, 1.8556541530545698, 1.8862245243215074, 1.916623411427429, 1.9468301243779131, 1.9768249164102505, 2.006588920377158, 2.036104090535023, 2.06535314930373, 2.094319538590694, 2.1229873752983632, 2.1513414106613324, 2.17936699308557, 2.207050034187824, 2.2343769777575635, 2.2613347713868195, 2.287910840534783, 2.3140930648140485, 2.3398697563039397, 2.365229639713434, 2.3901618342319235, 2.4146558369204474, 2.438701507509189, 2.4622890544790645, 2.4854090223161713, 2.5080522798378455, 2.5302100094981554, 2.551873697588903, 2.573035125259702, 2.59368636028751, 2.613819749532191, 2.633427912020272, 2.6525037326042007, 2.671040356149003, 2.6890311822025006, 2.7064698601090296, 2.723350284530122, 2.7396665913387652, 2.7554131538567437, 2.770584579407195, 2.785175706156921, 2.7991816002251606, 2.8125975530375658, 2.8254190789059095, 2.837641912815765, 2.8492620084059017, 2.86027553612457, 2.8706788815491286, 2.8804686438566645, 2.8896416344343607, 2.898194875619365, 2.9061255995588695, 2.913431247181974, 2.9201094672757217, 2.9261581156584517, 2.9315752544443217, 2.9363591513935203, 2.940508279343326, 2.94402131571574, 2.946897142098017, 2.9491348438929412, 2.9507337100362134, 2.9516932327788146], [2.942034263469983, 2.941714944501889, 2.940757088598026, 2.9391609987896485, 2.9369271802290813, 2.934056340340866, 2.9305493890349865, 2.9264074389837886, 2.9216318059646964, 2.9162240092713527, 2.9101857721962676, 2.9035190225886676, 2.8962258934917267, 2.888308723864004, 2.8797700593905162, 2.870612653389515, 2.860839467821785, 2.850453674409983, 2.8394586558763844, 2.8278580073082367, 2.8156555376608816, 2.8028552714097894, 2.789461450363757, 2.775478535652704, 2.7609112099047777, 2.7457643796288926, 2.730043177820335, 2.7137529668087574, 2.6968993413696825, 2.6794881321226396, 2.6615254092412415, 2.64301748650289, 2.62397092570843, 2.604392541504954, 2.584289406648117, 2.5636688577438025, 2.542538501512828, 2.520906221626561, 2.4987801861659826, 2.4761688557618404, 2.4530809924791583, 2.42952566951558, 2.4055122817898624, 2.381050557504368, 2.356150570773695, 2.3308227554207317, 2.3050779200514726, 2.2789272645309944, 2.252382397995112, 2.2254553585456014, 2.1981586347914233, 2.1705051894143543, 2.142508484954822, 2.114182512032612, 2.0855418202376135, 2.0566015519477547, 2.0273774793549544, 1.9978860450049518, 1.9681444061833662, 1.9381704835078029, 1.9079830141140184, 1.8776016098523693, 1.8470468209381803, 1.816340205525121, 1.785504405692475, 1.754563230353254, 1.7235417455975155, 1.6924663729802933, 1.6613649962413772, 1.6302670768986267, 1.5992037790796692, 1.5682081038388975, 1.537315033035414, 1.5065616826079589, 1.4759874647568718, 1.4456342581093604, 1.4155465843778925, 1.3857717892946488, 1.3563602246873363, 1.3273654274227893, 1.2988442895563406, 1.270857212365879, 1.2434682350126418, 1.2167451263725884, 1.1907594261753276, 1.1655864190766543, 1.1413050228500619, 1.117997569774066, 1.09574945887911, 1.0746486564690931, 1.0547850238074696, 1.0362494546629168, 1.019132812116312, 1.003524664050789, 0.9895118301683569, 0.9771767697860266, 0.9665958579925513, 0.9578376162035257, 0.950960979313363, 0.9460136927356064, 0.9430309360127292, 0.9420342634699831, 0.9430309360127312, 0.9460136927356105, 0.950960979313369, 0.9578376162035337, 0.9665958579925614, 0.9771767697860383, 0.9895118301683703, 1.0035246640508042, 1.0191328121163288, 1.0362494546629353, 1.0547850238074894, 1.0746486564691142, 1.095749458879132, 1.1179975697740896, 1.1413050228500865, 1.1655864190766796, 1.190759426175354, 1.2167451263726154, 1.2434682350126696, 1.2708572123659074, 1.2988442895563697, 1.3273654274228188, 1.3563602246873663, 1.3857717892946793, 1.4155465843779234, 1.4456342581093915, 1.4759874647569033, 1.5065616826079904, 1.5373150330354461, 1.5682081038389293, 1.599203779079701, 1.6302670768986587, 1.6613649962414094, 1.6924663729803253, 1.7235417455975475, 1.7545632303532857, 1.7855044056925065, 1.8163402055251525, 1.8470468209382116, 1.8776016098524002, 1.90798301411405, 1.9381704835078335, 1.968144406183397, 1.997886045004982, 2.027377479354984, 2.0566015519477845, 2.085541820237643, 2.1141825120326416, 2.142508484954851, 2.170505189414383, 2.1981586347914512, 2.225455358545629, 2.252382397995139, 2.2789272645310215, 2.3050779200514997, 2.330822755420758, 2.356150570773721, 2.381050557504394, 2.4055122817898873, 2.429525669515604, 2.453080992479182, 2.476168855761864, 2.4987801861660057, 2.520906221626584, 2.5425385015128503, 2.563668857743824, 2.584289406648138, 2.6043925415049745, 2.62397092570845, 2.643017486502909, 2.6615254092412606, 2.679488132122658, 2.6968993413697, 2.7137529668087748, 2.730043177820352, 2.745764379628909, 2.760911209904793, 2.7754785356527183, 2.789461450363771, 2.8028552714098036, 2.815655537660895, 2.827858007308249, 2.839458655876396, 2.8504536744099935, 2.8608394678217954, 2.8706126533895246, 2.879770059390525, 2.888308723864013, 2.896225893491734, 2.903519022588675, 2.9101857721962743, 2.9162240092713585, 2.921631805964702, 2.9264074389837926, 2.930549389034991, 2.934056340340869, 2.9369271802290835, 2.9391609987896503, 2.940757088598027, 2.94171494450189], [2.931144062097653, 2.930825353993515, 2.9298693301155945, 2.9282762917966876, 2.9260467413560742, 2.9231813822472246, 2.919681119266208, 2.9155470588223715, 2.910780509273392, 2.9053829813272865, 2.899356188514435, 2.8927020477332666, 2.8854226798737455, 2.877520410523438, 2.8689977707615064, 2.859857498046671, 2.850102537205849, 2.8397360415309496, 2.8287613739920676, 2.8171821085762256, 2.805002031761689, 2.7922251441389108, 2.7788556621902543, 2.7648980202417657, 2.7503568726016185, 2.7352370959011836, 2.71954379165623, 2.7032822890674018, 2.6864581480809324, 2.6690771627325556, 2.6511453647997065, 2.6326690277895426, 2.6136546712928665, 2.5941090657369825, 2.5740392375735954, 2.5534524749414045, 2.5323563338468396, 2.5107586449105974, 2.4886675207323, 2.4660913639307003, 2.443038875922508, 2.419519066509142, 2.3955412643475604, 2.371115128388918, 2.3462506603771174, 2.320958218508553, 2.2952485323644565, 2.2691327192384336, 2.242622301994057, 2.215729228600857, 2.1884658935118644, 2.160845161062056, 2.13288039108475, 2.104585466962285, 2.075974826348233, 2.0470634948210065, 2.017867122753029, 1.988402025705548, 1.9586852286866292, 1.9287345146385697, 1.8985684775505778, 1.868206580622517, 1.8376692199349722, 1.8069777941087535, 1.7761547804616271, 1.7452238181894566, 1.714209799110251, 1.683138966509164, 1.6520390226054564, 1.6209392451227074, 1.5898706133731961, 1.558865944156529, 1.527960037608815, 1.4971898329068247, 1.466594573413017, 1.4362159804200947, 1.4060984340920306, 1.3762891594730557, 1.3468384145149601, 1.3177996759231547, 1.2892298172119847, 1.2611892716649675, 1.2337421709044485, 1.2069564474994627, 1.1809038875285955, 1.1556601163676103, 1.1313044983629545, 1.1079199287473473, 1.0855924945259372, 1.0644109805992406, 1.0444661986822714, 1.0258501202773607, 1.0086548016857897, 0.9929710992693408, 0.9788871870354906, 0.9664869057315042, 0.9558479919073133, 0.9470402549783938, 0.9401237876213311, 0.9351473068977111, 0.9321467274731127, 0.9311440620976529, 0.9321467274731147, 0.9351473068977152, 0.9401237876213374, 0.947040254978402, 0.9558479919073234, 0.9664869057315159, 0.9788871870355043, 0.9929710992693562, 1.0086548016858066, 1.0258501202773789, 1.0444661986822912, 1.0644109805992616, 1.0855924945259592, 1.1079199287473707, 1.1313044983629792, 1.1556601163676357, 1.180903887528622, 1.2069564474994896, 1.2337421709044767, 1.2611892716649962, 1.2892298172120136, 1.3177996759231843, 1.3468384145149903, 1.3762891594730862, 1.4060984340920617, 1.4362159804201258, 1.466594573413048, 1.4971898329068565, 1.527960037608847, 1.5588659441565607, 1.5898706133732279, 1.620939245122739, 1.6520390226054884, 1.683138966509196, 1.714209799110283, 1.745223818189488, 1.7761547804616586, 1.806977794108785, 1.8376692199350033, 1.868206580622548, 1.8985684775506093, 1.9287345146386004, 1.9586852286866598, 1.9884020257055783, 2.017867122753059, 2.0470634948210362, 2.0759748263482622, 2.1045854669623147, 2.1328803910847784, 2.1608451610620842, 2.1884658935118924, 2.215729228600885, 2.2426223019940847, 2.2691327192384607, 2.295248532364483, 2.3209582185085798, 2.346250660377143, 2.3711151283889427, 2.3955412643475853, 2.4195190665091664, 2.443038875922532, 2.4660913639307234, 2.488667520732323, 2.51075864491062, 2.5323563338468613, 2.553452474941426, 2.574039237573616, 2.5941090657370034, 2.613654671292887, 2.6326690277895617, 2.651145364799726, 2.669077162732573, 2.6864581480809497, 2.7032822890674186, 2.719543791656247, 2.7352370959012, 2.750356872601633, 2.76489802024178, 2.7788556621902685, 2.7922251441389245, 2.8050020317617013, 2.8171821085762385, 2.828761373992079, 2.8397360415309603, 2.85010253720586, 2.85985749804668, 2.8689977707615153, 2.8775204105234464, 2.8854226798737534, 2.892702047733273, 2.899356188514442, 2.9053829813272922, 2.9107805092733976, 2.9155470588223755, 2.9196811192662127, 2.9231813822472277, 2.9260467413560765, 2.9282762917966902, 2.9298693301155962, 2.9308253539935154], [2.919353038982229, 2.9190349974107903, 2.918080972518459, 2.9164912637997635, 2.914266370507721, 2.911406991797825, 2.907914026931201, 2.903788575538521, 2.8990319379467246, 2.8936456155711117, 2.8876313113758196, 2.880990930406296, 2.8737265803978493, 2.8658405724650007, 2.857335421876926, 2.8482138489249493, 2.8384787798887334, 2.8281333481085316, 2.8171808951716955, 2.805624972222443, 2.7934693414048293, 2.7807179774498523, 2.7673750694186956, 2.75344502261529, 2.73893246068261, 2.7238422278985523, 2.7081793916887076, 2.6919492453750022, 2.6751573111809956, 2.657809343516569, 2.639911332566922, 2.621469508213162, 2.6024903443143725, 2.5829805633839213, 2.562947141695896, 2.542397314861083, 2.521338583915637, 2.4997787219699026, 2.477725781469412, 2.455188102125253, 2.432174319576657, 2.4086933748548645, 2.384754524724267, 2.360367352984382, 2.33554178282466, 2.3102880903333562, 2.284616919271938, 2.2585392972377765, 2.232066653350267, 2.205210837609208, 2.177984142089262, 2.1503993241508135, 2.1224696318655476, 2.0942088318747762, 2.0656312399199592, 2.036751754308064, 2.0075858925994754, 1.9781498318329642, 1.9484604526307638, 1.9185353875567985, 1.8883930741323058, 1.8580528129448861, 1.8275348313187292, 1.7968603530442686, 1.7660516746933257, 1.7351322490688923, 1.7041267763543118, 1.67306130353117, 1.6419633326239254, 1.6108619382960914, 1.57978789525975, 1.5487738158573472, 1.5178542980196137, 1.4870660835805027, 1.456448226620345, 1.4260422710891758, 1.3958924364066323, 1.3660458090121645, 1.3365525369156588, 1.3074660231380653, 1.278843112499655, 1.2507442644809004, 1.2232337028313178, 1.196379530241223, 1.170253793763146, 1.1449324838705446, 1.1204954472431972, 1.097026190839591, 1.074611552940918, 1.053341216138198, 1.0333070383082084, 1.01460218118363, 0.9973200228546009, 0.9815528509792409, 0.9673903478289373, 0.9549178961970448, 0.9442147555568947, 0.935352178715795, 0.9283915578463061, 0.9233827019856715, 0.9203623527674429, 0.9193530389822292, 0.9203623527674449, 0.9233827019856758, 0.9283915578463124, 0.9353521787158031, 0.9442147555569049, 0.9549178961970566, 0.9673903478289511, 0.9815528509792563, 0.9973200228546177, 1.0146021811836488, 1.0333070383082281, 1.0533412161382194, 1.0746115529409401, 1.0970261908396144, 1.1204954472432216, 1.1449324838705701, 1.170253793763172, 1.1963795302412503, 1.2232337028313456, 1.250744264480929, 1.278843112499684, 1.307466023138095, 1.336552536915689, 1.366045809012195, 1.395892436406663, 1.426042271089207, 1.456448226620376, 1.4870660835805343, 1.517854298019645, 1.5487738158573787, 1.5797878952597817, 1.6108619382961236, 1.641963332623957, 1.673061303531202, 1.7041267763543437, 1.735132249068924, 1.7660516746933574, 1.7968603530443004, 1.8275348313187614, 1.8580528129449179, 1.8883930741323367, 1.918535387556829, 1.9484604526307943, 1.9781498318329953, 2.0075858925995056, 2.036751754308094, 2.0656312399199885, 2.0942088318748056, 2.1224696318655765, 2.1503993241508423, 2.17798414208929, 2.2052108376092354, 2.232066653350294, 2.258539297237803, 2.284616919271964, 2.3102880903333816, 2.3355417828246856, 2.3603673529844067, 2.3847545247242916, 2.408693374854889, 2.4321743195766805, 2.4551881021252764, 2.4777257814694345, 2.499778721969925, 2.521338583915659, 2.542397314861104, 2.5629471416959175, 2.5829805633839413, 2.602490344314393, 2.6214695082131807, 2.6399113325669403, 2.657809343516587, 2.675157311181014, 2.691949245375019, 2.708179391688724, 2.723842227898568, 2.738932460682625, 2.753445022615304, 2.7673750694187094, 2.780717977449865, 2.793469341404842, 2.8056249722224553, 2.8171808951717066, 2.8281333481085422, 2.838478779888744, 2.8482138489249595, 2.8573354218769342, 2.8658405724650087, 2.873726580397857, 2.880990930406303, 2.8876313113758263, 2.8936456155711174, 2.8990319379467304, 2.9037885755385258, 2.907914026931205, 2.9114069917978287, 2.9142663705077236, 2.916491263799765, 2.9180809725184598, 2.9190349974107908], [2.906672601177065, 2.906355282451253, 2.905403425437407, 2.903817327654064, 2.9015974850582498, 2.8987445921854404, 2.8952595423470657, 2.8911434278871178, 2.886397540499885, 2.881023371611338, 2.875022612827157, 2.868397156450934, 2.8611490960766024, 2.853280727259747, 2.8447945482730104, 2.835693260951481, 2.8259797716346267, 2.815657192212046, 2.8047288412811238, 2.7931982454254785, 2.781069140624048, 2.768345473801587, 2.7550314045324624, 2.7411313069107472, 2.7266497716009153, 2.711591608084759, 2.6959618471216937, 2.679765743441222, 2.663008778688125, 2.645696664642907, 2.627835346742183, 2.609431007926042, 2.590490072842018, 2.5710192124381748, 2.551025348980913, 2.5305156615366196, 2.5094975919600464, 2.4879788514365573, 2.4659674276299937, 2.4434715924930597, 2.4204999108027856, 2.3970612494898877, 2.3731647878377533, 2.3488200286344374, 2.324036810369496, 2.2988253205767952, 2.2731961104348, 2.247160110747161, 2.220728649439014, 2.193913470718266, 2.1667267560663177, 2.1391811472394995, 2.1112897714808123, 2.0830662691617228, 2.0545248240956777, 2.0256801967888864, 1.9965477609197242, 1.9671435433659006, 1.9374842681282054, 1.9075874045310646, 1.8774712201129875, 1.8471548386538352, 1.8166583038199566, 1.78600264894162, 1.7552099734684172, 1.7243035266754236, 1.6933077992132621, 1.6622486231052758, 1.6311532807901177, 1.6000506237821142, 1.568971201466955, 1.5379474004565208, 1.5070135947814067, 1.4762063069871239, 1.4455643799006308, 1.4151291584243368, 1.3849446801670091, 1.3550578730029448, 1.3255187567259725, 1.2963806447947608, 1.2677003407118166, 1.2395383218066365, 1.2119589010814775, 1.1850303553261587, 1.1588250049525053, 1.133419228031052, 1.1088933880012808, 1.0853316517428042, 1.0628216725333999, 1.0414541114128117, 1.021321971281734, 1.0025197214474715, 0.9851421970395193, 0.9692832683766032, 0.9550342902449852, 0.9424823598385675, 0.93170843370353, 0.922785376380804, 0.9157760336319325, 0.910731437700055, 0.907689257580106, 0.9066726011770648, 0.9076892575801082, 0.910731437700059, 0.9157760336319388, 0.9227853763808122, 0.9317084337035402, 0.9424823598385798, 0.9550342902449991, 0.9692832683766186, 0.9851421970395364, 1.0025197214474901, 1.021321971281754, 1.0414541114128328, 1.0628216725334225, 1.0853316517428278, 1.1088933880013054, 1.1334192280310775, 1.158825004952532, 1.185030355326186, 1.2119589010815055, 1.239538321806665, 1.2677003407118457, 1.2963806447947905, 1.3255187567260027, 1.3550578730029752, 1.3849446801670402, 1.415129158424368, 1.4455643799006623, 1.4762063069871554, 1.5070135947814387, 1.5379474004565523, 1.568971201466987, 1.600050623782146, 1.6311532807901497, 1.662248623105308, 1.6933077992132939, 1.7243035266754554, 1.7552099734684485, 1.7860026489416516, 1.816658303819988, 1.8471548386538665, 1.8774712201130184, 1.9075874045310952, 1.9374842681282363, 1.9671435433659308, 1.9965477609197548, 2.0256801967889166, 2.0545248240957075, 2.083066269161752, 2.111289771480841, 2.1391811472395275, 2.1667267560663457, 2.1939134707182935, 2.2207286494390415, 2.247160110747188, 2.2731961104348275, 2.2988253205768214, 2.3240368103695217, 2.348820028634463, 2.3731647878377773, 2.3970612494899117, 2.4204999108028096, 2.443471592493083, 2.4659674276300168, 2.48797885143658, 2.5094975919600677, 2.530515661536641, 2.551025348980934, 2.571019212438195, 2.590490072842038, 2.6094310079260605, 2.6278353467422018, 2.645696664642925, 2.663008778688143, 2.679765743441239, 2.6959618471217097, 2.711591608084775, 2.7266497716009304, 2.7411313069107615, 2.755031404532476, 2.768345473801601, 2.7810691406240613, 2.793198245425491, 2.8047288412811353, 2.8156571922120572, 2.8259797716346364, 2.8356932609514907, 2.844794548273019, 2.8532807272597553, 2.86114909607661, 2.868397156450941, 2.8750226128271636, 2.881023371611344, 2.8863975404998903, 2.8911434278871218, 2.89525954234707, 2.8987445921854436, 2.901597485058252, 2.9038173276540657, 2.905403425437408, 2.9063552824512535], [2.8931150161867834, 2.8927984773178004, 2.891848959170924, 2.890266757153281, 2.888052363700009, 2.885206468409906, 2.8817299582368703, 2.877623917738668, 2.8728896293850315, 2.867528573927563, 2.86154243083439, 2.854933078793069, 2.8477025962857074, 2.8398532622409087, 2.8313875567676665, 2.8223081619770216, 2.8126179628979435, 2.8023200484946065, 2.791417712793047, 2.779914456125954, 2.767813986505316, 2.7551202211335544, 2.741837288064873, 2.7279695280296705, 2.713521496436116, 2.6984979655643566, 2.682903926970289, 2.6667445941174583, 2.650025405257441, 2.6327520265809694, 2.614930355664254, 2.5965665252372445, 2.5776669073032017, 2.5582381176417677, 2.5382870207308543, 2.517820735126136, 2.4968466393407107, 2.4753723782717434, 2.453405870225484, 2.4309553145972522, 2.408029200268588, 2.3846363147900997, 2.360785754425423, 2.336486935139425, 2.3117496046222668, 2.2865838554503233, 2.2610001394953776, 2.2350092837049784, 2.2086225073895753, 2.1818514411660392, 2.1547081477226824, 2.1272051445878923, 2.0993554291032726, 2.071172505822703, 2.042670416581262, 2.0138637735024663, 1.9847677952389402, 1.955398346770423, 1.9257719831139113, 1.895905997333649, 1.8658184732733252, 1.8355283434688594, 1.8050554527368647, 1.7744206279703938, 1.7436457547085091, 1.7127538610777417, 1.6817692097290289, 1.6507173984098544, 1.6196254698134454, 1.5885220313290167, 1.557437385271428, 1.5264036700851247, 1.4954550128832091, 1.4646276934818148, 1.4339603198028301, 1.4034940141201633, 1.37327260908705, 1.343342851770474, 1.3137546129948723, 1.2845610981190392, 1.2558190538945995, 1.2275889642422197, 1.199935225604148, 1.172926289981162, 1.1466347608671756, 1.1211374241401304, 1.096515192718107, 1.0728529407169323, 1.0502392003555259, 1.028765693504303, 1.0085266702655318, 0.9896180301298881, 0.9721362079115831, 0.9561768175372642, 0.9418330622154432, 0.9291939392957129, 0.9183422911253725, 0.9093527772820371, 0.9022898655744847, 0.897205955378033, 0.8941397534231333, 0.8931150161867832, 0.8941397534231356, 0.8972059553780373, 0.9022898655744909, 0.9093527772820453, 0.9183422911253828, 0.929193939295725, 0.9418330622154569, 0.9561768175372798, 0.9721362079116003, 0.989618030129907, 1.0085266702655518, 1.0287656935043243, 1.0502392003555483, 1.072852940716956, 1.0965151927181316, 1.1211374241401562, 1.1466347608672023, 1.1729262899811894, 1.1999352256041758, 1.227588964242248, 1.2558190538946288, 1.2845610981190692, 1.3137546129949025, 1.3433428517705048, 1.3732726090870808, 1.4034940141201944, 1.4339603198028616, 1.4646276934818463, 1.4954550128832411, 1.5264036700851566, 1.5574373852714598, 1.588522031329049, 1.6196254698134775, 1.6507173984098864, 1.6817692097290604, 1.7127538610777735, 1.7436457547085407, 1.774420627970425, 1.8050554527368963, 1.835528343468891, 1.8658184732733567, 1.8959059973336798, 1.925771983113942, 1.955398346770453, 1.9847677952389704, 2.013863773502496, 2.042670416581292, 2.0711725058227324, 2.099355429103301, 2.1272051445879208, 2.1547081477227104, 2.1818514411660668, 2.2086225073896024, 2.235009283705005, 2.261000139495404, 2.2865838554503495, 2.3117496046222925, 2.33648693513945, 2.3607857544254474, 2.384636314790124, 2.408029200268612, 2.430955314597275, 2.453405870225507, 2.475372378271766, 2.496846639340733, 2.5178207351261563, 2.538287020730875, 2.5582381176417877, 2.5776669073032217, 2.5965665252372636, 2.614930355664273, 2.632752026580987, 2.650025405257458, 2.666744594117475, 2.6829039269703054, 2.6984979655643735, 2.713521496436131, 2.7279695280296847, 2.7418372880648874, 2.7551202211335677, 2.7678139865053284, 2.779914456125966, 2.7914177127930584, 2.802320048494617, 2.8126179628979533, 2.822308161977031, 2.831387556767675, 2.8398532622409176, 2.8477025962857145, 2.8549330787930756, 2.8615424308343966, 2.8675285739275687, 2.872889629385037, 2.877623917738672, 2.8817299582368743, 2.885206468409909, 2.888052363700011, 2.8902667571532827, 2.8918489591709253, 2.8927984773178013], [2.8786934000992597, 2.8783776988512004, 2.877430692819297, 2.875852675166371, 2.8736441345839894, 2.870805755423511, 2.8673384178810575, 2.8632431982379174, 2.8585213691583546, 2.853174400047264, 2.847203957470551, 2.840611905641703, 2.8334003069784357, 2.825571422733951, 2.8171277137078654, 2.8080718410425063, 2.7984066671109584, 2.7881352565039124, 2.777260877123172, 2.7657870013904606, 2.7537173075810895, 2.7410556812929667, 2.7278062170625166, 2.7139732201401707, 2.6995612084393366, 2.6845749146741067, 2.669019288702421, 2.6528995000930133, 2.636220940936223, 2.618989228920707, 2.6012102107001693, 2.5828899655766064, 2.5640348095290793, 2.5446512996198956, 2.5247462388131727, 2.5043266812442013, 2.4833999379818117, 2.461973583330174, 2.440055461721037, 2.4176536952526106, 2.394776691936909, 2.371433154723696, 2.3476320913761137, 2.323382825280784, 2.2986950072837136, 2.273578628652788, 2.2480440352781366, 2.2221019432332176, 2.1957634558323536, 2.1690400823346434, 2.1419437584598677, 2.1144868688993532, 2.08668227202387, 2.0585433270116362, 2.0300839236426005, 2.0013185150303703, 1.9722621535907146, 1.9429305305753741, 1.9133400195321415, 1.8835077240866285, 1.8534515304777182, 1.823190165317017, 1.792743259082118, 1.7621314158933539, 1.7313762901626453, 1.7005006707393313, 1.669528573209033, 1.6384853410243616, 1.6073977561561297, 1.5762941599448255, 1.5452045847966742, 1.5141608972966403, 1.483196953189397, 1.4523487644923043, 1.4216546787315234, 1.3911555699084892, 1.3608950402788262, 1.3309196313235994, 1.301279041372368, 1.272026346153286, 1.243218217049827, 1.2149151299911265, 1.187181555657164, 1.1600861190248055, 1.133701713235394, 1.1081055494049044, 1.0833791204823715, 1.0596080538633645, 1.0368818245982747, 1.0152932992822918, 0.9949380808269568, 0.9759136271807296, 0.9583181236249039, 0.9422490993458487, 0.9278017950496363, 0.9150673092709508, 0.9041305756251529, 0.8950682493106685, 0.887946605315578, 0.8828195688669873, 0.879727006467974, 0.8786934000992599, 0.8797270064679761, 0.8828195688669914, 0.8879466053155843, 0.8950682493106772, 0.9041305756251633, 0.915067309270963, 0.9278017950496504, 0.9422490993458643, 0.9583181236249212, 0.9759136271807484, 0.994938080826977, 1.0152932992823136, 1.0368818245982974, 1.0596080538633883, 1.0833791204823962, 1.10810554940493, 1.1337017132354206, 1.160086119024833, 1.1871815556571923, 1.2149151299911551, 1.2432182170498565, 1.272026346153316, 1.3012790413723982, 1.3309196313236298, 1.360895040278857, 1.3911555699085207, 1.4216546787315547, 1.4523487644923356, 1.4831969531894287, 1.514160897296672, 1.545204584796706, 1.5762941599448574, 1.6073977561561617, 1.6384853410243936, 1.6695285732090648, 1.700500670739363, 1.7313762901626772, 1.7621314158933856, 1.7927432590821493, 1.8231901653170481, 1.8534515304777492, 1.883507724086659, 1.9133400195321721, 1.9429305305754043, 1.9722621535907443, 2.0013185150304, 2.03008392364263, 2.058543327011665, 2.086682272023898, 2.1144868688993816, 2.1419437584598957, 2.169040082334671, 2.1957634558323806, 2.2221019432332443, 2.2480440352781637, 2.273578628652814, 2.298695007283739, 2.3233828252808095, 2.347632091376139, 2.37143315472372, 2.3947766919369333, 2.4176536952526346, 2.4400554617210597, 2.461973583330196, 2.4833999379818334, 2.5043266812442218, 2.5247462388131936, 2.544651299619915, 2.564034809529099, 2.5828899655766255, 2.6012102107001875, 2.6189892289207246, 2.636220940936241, 2.6528995000930298, 2.669019288702437, 2.6845749146741222, 2.699561208439351, 2.7139732201401854, 2.7278062170625303, 2.7410556812929796, 2.753717307581102, 2.765787001390472, 2.7772608771231835, 2.788135256503924, 2.7984066671109686, 2.808071841042516, 2.8171277137078743, 2.8255714227339594, 2.8334003069784433, 2.84061190564171, 2.847203957470558, 2.8531744000472696, 2.85852136915836, 2.8632431982379214, 2.867338417881061, 2.8708057554235142, 2.8736441345839916, 2.8758526751663727, 2.8774306928192974, 2.878377698851201], [2.863421704896654, 2.863106899841666, 2.8621625815978224, 2.860589040953505, 2.858386762639632, 2.8555564254558163, 2.8520989024484593, 2.8480152611422813, 2.8433067638271985, 2.8379748679029553, 2.832021226284357, 2.8254476878704677, 2.8182562980816317, 2.810449299468743, 2.802029132399747, 2.7929984358289817, 2.783360048155607, 2.7731170081780867, 2.762272556152416, 2.7508301349626243, 2.73879339141293, 2.7261661776518857, 2.7129525527398846, 2.699156784372496, 2.6847833507733374, 2.6698369427715, 2.6543224660800195, 2.638245043793446, 2.621610019124338, 2.604422958400394, 2.5866896543460656, 2.568416129674779, 2.5496086410204586, 2.5302736832398582, 2.510417994120279, 2.4900485595307056, 2.4691726190581447, 2.447797672175149, 2.4259314849891194, 2.4035820976291196, 2.380757832331587, 2.357467302292636, 2.3337194213615935, 2.3095234146581753, 2.2848888302042503, 2.2598255516706875, 2.2343438123503203, 2.208454210479776, 2.182167726045903, 2.155495739226932, 2.1284500506344113, 2.101042903539625, 2.073287008287658, 2.045195569123769, 2.016782313680382, 1.9880615253989706, 1.9590480791895128, 1.9297574806611584, 1.9002059092912773, 1.870410265936208, 1.840388225125593, 1.810158292622955, 1.7797398687776402, 1.7491533182366654, 1.7184200466282311, 1.6875625848700821, 1.6566046817931284, 1.6255714058007324, 1.5944892563023614, 1.5633862856612453, 1.5322922323715817, 1.5012386661217088, 1.4702591452926923, 1.4393893872704318, 1.408667451692974, 1.378133936387442, 1.3478321852413209, 1.3178085065631335, 1.2881123995738073, 1.2587967854828717, 1.2299182380901488, 1.2015372069614543, 1.173718223911251, 1.1465300807597996, 1.1200459631253061, 1.094343521427844, 1.069504856471789, 1.0456163932068978, 1.02276861296949, 1.0010556122829044, 0.9805744559528936, 0.9614242946975774, 0.9437052239503043, 0.9275168717249267, 0.9129567201464455, 0.9001181873577423, 0.8890885229255295, 0.8799465982242454, 0.872760699926736, 0.867586455093203, 0.86446502568869, 0.863421704896654, 0.8644650256886921, 0.8675864550932072, 0.8727606999267425, 0.8799465982242538, 0.8890885229255401, 0.9001181873577545, 0.9129567201464597, 0.9275168717249423, 0.9437052239503217, 0.9614242946975963, 0.9805744559529138, 1.001055612282926, 1.0227686129695128, 1.0456163932069218, 1.0695048564718141, 1.09434352142787, 1.120045963125333, 1.146530080759827, 1.1737182239112791, 1.2015372069614831, 1.2299182380901783, 1.2587967854829016, 1.2881123995738375, 1.3178085065631644, 1.347832185241352, 1.3781339363874732, 1.4086674516930056, 1.4393893872704635, 1.4702591452927245, 1.5012386661217405, 1.5322922323716135, 1.5633862856612775, 1.5944892563023934, 1.6255714058007646, 1.6566046817931601, 1.687562584870114, 1.7184200466282629, 1.7491533182366965, 1.7797398687776715, 1.8101582926229862, 1.8403882251256238, 1.8704102659362387, 1.9002059092913077, 1.9297574806611881, 1.9590480791895428, 1.9880615253990004, 2.016782313680412, 2.0451955691237984, 2.073287008287687, 2.1010429035396534, 2.1284500506344393, 2.1554957392269594, 2.18216772604593, 2.2084542104798026, 2.2343438123503474, 2.2598255516707138, 2.284888830204276, 2.3095234146582, 2.3337194213616184, 2.35746730229266, 2.3807578323316108, 2.403582097629142, 2.425931484989142, 2.4477976721751715, 2.469172619058167, 2.4900485595307265, 2.5104179941202993, 2.5302736832398782, 2.5496086410204786, 2.568416129674798, 2.5866896543460847, 2.604422958400412, 2.621610019124355, 2.638245043793463, 2.654322466080036, 2.669836942771516, 2.684783350773352, 2.699156784372511, 2.7129525527398988, 2.726166177651899, 2.738793391412943, 2.7508301349626363, 2.7622725561524275, 2.773117008178097, 2.783360048155617, 2.792998435828991, 2.802029132399756, 2.8104492994687518, 2.8182562980816392, 2.825447687870475, 2.8320212262843634, 2.837974867902961, 2.8433067638272043, 2.8480152611422858, 2.8520989024484633, 2.8555564254558194, 2.8583867626396344, 2.860589040953507, 2.862162581597824, 2.8631068998416667], [2.8473147049577676, 2.8470008555317685, 2.8460594033413797, 2.8444906366734215, 2.842295036086103, 2.839473274530012, 2.8360262175189477, 2.8319549233520456, 2.8272606433891077, 2.8219448223814565, 2.8160090988611355, 2.809455305591734, 2.802285470084629, 2.7945018151849883, 2.7861067597324096, 2.7771029193017154, 2.7674931070300133, 2.757280334536883, 2.746467812945221, 2.7350589540111296, 2.7230573713720494, 2.7104668819233146, 2.697291507334274, 2.6835354757162615, 2.669203223455873, 2.654299397228347, 2.6388288562072484, 2.622796674488247, 2.6062081437465094, 2.589068776149099, 2.571384307545874, 2.5531607009646686, 2.534404150439044, 2.5151210851997297, 2.4953181742638897, 2.4750023314598084, 2.4541807209283144, 2.432860763146429, 2.411050141523354, 2.388756809623992, 2.365988999080898, 2.342755228261816, 2.319064311766947, 2.2949253708378516, 2.270347844768499, 2.2453415034185213, 2.219916460939404, 2.194083190836101, 2.1678525424997255, 2.1412357593615114, 2.1142444988344127, 2.0868908542266342, 2.059187378831241, 2.0311471124179614, 2.0027836103775214, 1.9741109757955908, 1.945143894762699, 1.9158976752586192, 1.8863882899846192, 1.8566324235548743, 1.8266475244989862, 1.7964518625709178, 1.7660645919052225, 1.735505820608668, 1.7047966874231437, 1.6739594461426275, 1.6430175585108233, 1.6119957963638376, 1.5809203538097951, 1.5498189702490102, 1.5187210650267422, 1.4876578844657746, 1.456662661935209, 1.4257707914583377, 1.395020015125143, 1.3644506242273142, 1.3341056735429901, 1.3040312075250124, 1.2742764962435218, 1.2448942777476188, 1.2159410019829395, 1.1874770694723824, 1.1595670555814879, 1.1322799083098969, 1.1056891041710384, 1.0798727428950796, 1.0549135575544906, 1.0308988125319338, 1.0079200579580652, 0.9860727064770397, 0.9654553973068067, 0.9461691146077864, 0.9283160333317962, 0.9119980771083898, 0.8973151901135414, 0.8843633483198894, 0.87323236399953, 0.8640035683645646, 0.8567474868265652, 0.8515216444451146, 0.8483686503565442, 0.8473147049577674, 0.8483686503565465, 0.8515216444451189, 0.8567474868265719, 0.864003568364573, 0.8732323639995405, 0.8843633483199016, 0.8973151901135556, 0.9119980771084057, 0.9283160333318138, 0.9461691146078055, 0.9654553973068274, 0.9860727064770617, 1.0079200579580883, 1.0308988125319578, 1.0549135575545159, 1.0798727428951058, 1.1056891041710653, 1.1322799083099244, 1.1595670555815163, 1.1874770694724115, 1.2159410019829688, 1.244894277747649, 1.2742764962435518, 1.3040312075250435, 1.3341056735430215, 1.3644506242273455, 1.3950200151251746, 1.4257707914583695, 1.4566626619352407, 1.4876578844658066, 1.518721065026774, 1.5498189702490421, 1.5809203538098273, 1.6119957963638698, 1.6430175585108548, 1.6739594461426592, 1.7047966874231757, 1.7355058206086995, 1.7660645919052538, 1.796451862570949, 1.8266475244990172, 1.8566324235549048, 1.8863882899846498, 1.9158976752586494, 1.9451438947627293, 1.9741109757956201, 2.002783610377551, 2.0311471124179907, 2.05918737883127, 2.0868908542266618, 2.1142444988344407, 2.141235759361539, 2.1678525424997526, 2.194083190836128, 2.21991646093943, 2.245341503418547, 2.2703478447685246, 2.294925370837877, 2.3190643117669714, 2.3427552282618405, 2.3659889990809213, 2.388756809624015, 2.411050141523377, 2.4328607631464516, 2.4541807209283357, 2.4750023314598293, 2.4953181742639106, 2.51512108519975, 2.534404150439064, 2.5531607009646873, 2.571384307545893, 2.5890687761491167, 2.6062081437465268, 2.6227966744882636, 2.6388288562072653, 2.6542993972283635, 2.6692032234558876, 2.6835354757162757, 2.6972915073342887, 2.710466881923328, 2.723057371372062, 2.735058954011141, 2.7464678129452325, 2.757280334536893, 2.7674931070300235, 2.7771029193017247, 2.786106759732419, 2.7945018151849967, 2.8022854700846365, 2.809455305591741, 2.816009098861142, 2.8219448223814623, 2.827260643389113, 2.8319549233520505, 2.836026217518952, 2.839473274530016, 2.842295036086105, 2.844490636673423, 2.846059403341381, 2.8470008555317685], [2.830387982764787, 2.8300751493237293, 2.8291367442133883, 2.827573053095166, 2.8253845521479595, 2.8225719081836993, 2.819135978810528, 2.815077812645033, 2.8103986495753936, 2.805099921077732, 2.799183250588408, 2.7926504539354786, 2.785503539833046, 2.7777447104427155, 2.7693763620069682, 2.760401085559833, 2.7508216677208663, 2.7406410915791244, 2.729862537674554, 2.7184893850849767, 2.7065252126277337, 2.6939738001859244, 2.680839130170211, 2.667125389128223, 2.652836969514781, 2.637978471637461, 2.6225547057934215, 2.606570694614979, 2.590031675643121, 2.572943104149994, 2.5553106562334955, 2.5371402322093464, 2.5184379603285167, 2.4992102008506656, 2.4794635505072766, 2.459204847391564, 2.4384411763159677, 2.417179874682162, 2.395428538913143, 2.373195031502, 2.350487488737676, 2.3273143291742646, 2.3036842629174092, 2.2796063018090917, 2.255089770600781, 2.23014431921447, 2.204779936201875, 2.1790069635239204, 2.152836112785918, 2.126278483078567, 2.0993455805912884, 2.0720493401826268, 2.044402149112679, 2.0164168731649346, 1.98810688540976, 1.9594860978892112, 1.930568996533111, 1.9013706796495924, 1.8719069003697029, 1.8421941134652742, 1.8122495270021668, 1.7820911593369995, 1.751737902014356, 1.72120958917265, 1.6905270741194782, 1.659712313790025, 1.628788461852942, 1.5977799712742966, 1.5667127071877016, 1.535614070942235, 1.5045131362019237, 1.4734407979416706, 1.4424299351117333, 1.4115155876095498, 1.3807351479823462, 1.350128567959448, 1.319738579445465, 1.2896109289530253, 1.2597946235665083, 1.2303421853483214, 1.2013099095617523, 1.1727581201210489, 1.144751413224619, 1.1173588771296832, 1.0906542724655908, 1.064716153393409, 1.0396279054255713, 1.0154776710772702, 0.9923581301662124, 0.9703660981696743, 0.9496019045017957, 0.9301685140472077, 0.912170361099929, 0.8957118763108358, 0.8808957053210865, 0.8678206426880417, 0.8565793355152292, 0.8472558452930014, 0.8399231895295937, 0.8346410111186471, 0.8314535369338212, 0.8303879827647869, 0.8314535369338235, 0.8346410111186515, 0.8399231895296002, 0.8472558452930099, 0.85657933551524, 0.8678206426880541, 0.8808957053211008, 0.895711876310852, 0.9121703610999466, 0.930168514047227, 0.9496019045018166, 0.9703660981696963, 0.9923581301662356, 1.0154776710772946, 1.0396279054255966, 1.0647161533934353, 1.0906542724656176, 1.117358877129711, 1.1447514132246475, 1.172758120121078, 1.2013099095617819, 1.2303421853483512, 1.259794623566539, 1.2896109289530562, 1.319738579445496, 1.3501285679594792, 1.380735147982378, 1.4115155876095815, 1.4424299351117655, 1.4734407979417021, 1.504513136201956, 1.535614070942267, 1.5667127071877338, 1.5977799712743288, 1.628788461852974, 1.6597123137900567, 1.6905270741195095, 1.721209589172681, 1.751737902014387, 1.7820911593370308, 1.8122495270021977, 1.842194113465305, 1.871906900369733, 1.9013706796496224, 1.9305689965331405, 1.959486097889241, 1.9881068854097894, 2.0164168731649634, 2.044402149112708, 2.072049340182655, 2.099345580591316, 2.1262784830785946, 2.152836112785945, 2.1790069635239466, 2.2047799362019016, 2.230144319214496, 2.255089770600806, 2.279606301809117, 2.3036842629174337, 2.3273143291742886, 2.3504874887376994, 2.3731950315020236, 2.3954285389131655, 2.4171798746821844, 2.438441176315989, 2.459204847391585, 2.4794635505072966, 2.499210200850685, 2.5184379603285363, 2.537140232209365, 2.555310656233514, 2.5729431041500113, 2.590031675643139, 2.606570694614996, 2.622554705793438, 2.637978471637477, 2.6528369695147958, 2.6671253891282367, 2.6808391301702246, 2.6939738001859372, 2.7065252126277466, 2.718489385084989, 2.729862537674565, 2.740641091579135, 2.750821667720876, 2.760401085559842, 2.7693763620069767, 2.7777447104427244, 2.785503539833054, 2.7926504539354857, 2.7991832505884138, 2.805099921077738, 2.810398649575399, 2.815077812645037, 2.8191359788105324, 2.8225719081837033, 2.825384552147962, 2.827573053095168, 2.8291367442133892, 2.8300751493237297], [2.812657913828239, 2.812346157704924, 2.811410983632947, 2.8098526745279866, 2.807671701988928, 2.804868726407697, 2.8014445971243958, 2.7974003526291558, 2.7927372208124974, 2.7874566192664476, 2.781560155639093, 2.7750496280457053, 2.7679270255400756, 2.7601945286502048, 2.7518545099830134, 2.7429095349033634, 2.7333623622932444, 2.723215945397675, 2.712473432764577, 2.701138169286623, 2.6892136973539285, 2.6767037581273105, 2.663612292942866, 2.649943444859648, 2.6357015603633944, 2.6208911912405455, 2.6055170966381693, 2.5895842453269418, 2.573097818186006, 2.5560632109303967, 2.5384860371037163, 2.5203721313610257, 2.5017275530693612, 2.482558590256028, 2.462871763937854, 2.442673832867917, 2.4219717987399703, 2.400772911894925, 2.3790846775782653, 2.3569148628023955, 2.334271503873499, 2.3111629146488144, 2.287597695597138, 2.2635847437431917, 2.2391332635851136, 2.214252779083962, 2.188953146834893, 2.1632445705416425, 2.137137616929289, 2.110643233245187, 2.0837727665145493, 2.0565379847356406, 2.0289511002201435, 2.0010247953071523, 1.972772250704661, 1.9442071767406504, 1.915343847837036, 1.886197140554218, 1.8567825755917946, 1.8271163641724892, 1.7972154592814482, 1.7670976122818978, 1.7367814354804116, 1.7062864712704464, 1.675633268540523, 1.644843467092388, 1.6139398908728284, 1.5829466508780006, 1.5518892586374327, 1.5207947512211588, 1.489691828730667, 1.4586110052230208, 1.4275847739649064, 1.3966477878028727, 1.3658370552458803, 1.3351921525587422, 1.304755451724943, 1.274572363511078, 1.244691593999746, 1.2151654117904682, 1.1860499215274989, 1.157405337421712, 1.1292962479133464, 1.1017918595064171, 1.074966204054855, 1.0488982894098717, 1.0236721684526127, 0.9993768963781441, 0.9761063411010806, 0.9539588075033081, 0.9330364339143793, 0.9134443199721006, 0.8952893503420766, 0.8786786902029448, 0.8637179471555226, 0.8505090207462875, 0.8391476942400219, 0.8297210609469168, 0.822304914600541, 0.8169612636081998, 0.8137361454246931, 0.812657913828239, 0.8137361454246953, 0.8169612636082043, 0.8223049146005476, 0.8297210609469255, 0.8391476942400327, 0.8505090207463002, 0.863717947155537, 0.8786786902029611, 0.8952893503420942, 0.91344431997212, 0.9330364339144003, 0.9539588075033302, 0.9761063411011038, 0.9993768963781685, 1.0236721684526382, 1.0488982894098982, 1.0749662040548822, 1.101791859506445, 1.129296247913375, 1.1574053374217408, 1.1860499215275286, 1.215165411790498, 1.2446915939997767, 1.2745723635111086, 1.304755451724974, 1.3351921525587738, 1.365837055245912, 1.3966477878029044, 1.4275847739649383, 1.4586110052230528, 1.489691828730699, 1.5207947512211906, 1.5518892586374646, 1.5829466508780325, 1.6139398908728604, 1.6448434670924197, 1.6756332685405546, 1.7062864712704777, 1.736781435480443, 1.7670976122819289, 1.797215459281479, 1.82711636417252, 1.8567825755918252, 1.8861971405542481, 1.9153438478370657, 1.9442071767406797, 1.9727722507046903, 2.001024795307181, 2.0289511002201723, 2.056537984735668, 2.0837727665145773, 2.1106432332452147, 2.1371376169293157, 2.163244570541669, 2.1889531468349186, 2.214252779083987, 2.239133263585139, 2.263584743743217, 2.287597695597162, 2.311162914648839, 2.3342715038735227, 2.356914862802418, 2.3790846775782883, 2.400772911894947, 2.421971798739992, 2.442673832867938, 2.462871763937875, 2.4825585902560476, 2.5017275530693803, 2.5203721313610448, 2.538486037103734, 2.5560632109304144, 2.573097818186023, 2.5895842453269586, 2.605517096638186, 2.6208911912405615, 2.63570156036341, 2.649943444859663, 2.66361229294288, 2.6767037581273234, 2.6892136973539413, 2.7011381692866356, 2.7124734327645883, 2.723215945397686, 2.7333623622932546, 2.742909534903373, 2.7518545099830223, 2.760194528650213, 2.767927025540083, 2.7750496280457115, 2.7815601556390996, 2.7874566192664534, 2.7927372208125023, 2.7974003526291606, 2.8014445971244, 2.8048687264076997, 2.80767170198893, 2.809852674527988, 2.811410983632949, 2.812346157704925], [2.7941416508447414, 2.793831034406159, 2.7928992784347084, 2.791346662983863, 2.789173654878197, 2.7863809078172355, 2.782969262522197, 2.7789397469269748, 2.774293576415123, 2.769032154105049, 2.763157071185983, 2.7566701073078375, 2.7495732310284517, 2.7418686003222934, 2.7335585631551687, 2.7246456581300778, 2.7151326152099555, 2.7050223565236675, 2.6943179972623565, 2.6830228466739574, 2.6711404091645217, 2.6586743855158788, 2.645628674230117, 2.6320073730124114, 2.6178147804048715, 2.603055397585323, 2.587733930346316, 2.5718552912711563, 2.555424602125386, 2.5384471964839905, 2.520928622616589, 2.50287464665507, 2.484291256070613, 2.465184663489675, 2.4455613108815784, 2.4254278741535886, 2.4047912681930796, 2.3836586524004533, 2.36203743676099, 2.3399352885088875, 2.317360139442299, 2.2943201939544595, 2.270823937852946, 2.2468801480468437, 2.222497903190279, 2.197686595380423, 2.1724559430188446, 2.1468160049571634, 2.1207771960613884, 2.0943503043443608, 2.06754650983253, 2.0403774053520234, 2.012855019439904, 1.9849918416098662, 1.9568008502276097, 1.9282955432800846, 1.899489972354931, 1.8703987801820618, 1.841037242128667, 1.811421312082248, 1.7815676732037167, 1.751493794084268, 1.721217990895564, 1.6907594961825023, 1.660138535010917, 1.629376409248046, 1.5984955908198633, 1.5675198248541917, 1.536474243678376, 1.5053854926904395, 1.4742818691563013, 1.4431934749936237, 1.4121523845726813, 1.38119282847981, 1.350351394027607, 1.319667243029907, 1.2891823469523882, 1.2589417389559951, 1.22899378151399, 1.199390447136856, 1.1701876082037095, 1.1414453298866953, 1.1132281575747764, 1.0856053869707563, 1.058651301089697, 1.0324453537184954, 1.007072273585504, 0.982622057758127, 0.9591898170635653, 0.9368754313159937, 0.9157829688671679, 0.8960198248625251, 0.8776955372588654, 0.8609202509254623, 0.8458028195396502, 0.8324485632448624, 0.8209567364626352, 0.8114178020755941, 0.8039106502843698, 0.7984999355733673, 0.7952337252536517, 0.7941416508447416, 0.7952337252536541, 0.7984999355733717, 0.8039106502843766, 0.8114178020756029, 0.820956736462646, 0.8324485632448752, 0.8458028195396647, 0.8609202509254787, 0.8776955372588836, 0.8960198248625446, 0.915782968867189, 0.9368754313160161, 0.9591898170635887, 0.9826220577581516, 1.0070722735855293, 1.032445353718522, 1.0586513010897243, 1.0856053869707845, 1.113228157574805, 1.1414453298867246, 1.1701876082037392, 1.1993904471368864, 1.2289937815140204, 1.2589417389560258, 1.2891823469524195, 1.3196672430299385, 1.3503513940276388, 1.3811928284798418, 1.412152384572713, 1.4431934749936555, 1.4742818691563335, 1.5053854926904713, 1.5364742436784082, 1.5675198248542235, 1.5984955908198952, 1.6293764092480778, 1.6601385350109488, 1.6907594961825336, 1.7212179908955958, 1.751493794084299, 1.7815676732037475, 1.8114213120822784, 1.8410372421286973, 1.8703987801820918, 1.8994899723549608, 1.928295543280114, 1.9568008502276388, 1.9849918416098948, 2.012855019439933, 2.0403774053520514, 2.0675465098325576, 2.0943503043443883, 2.120777196061415, 2.14681600495719, 2.172455943018871, 2.1976865953804485, 2.222497903190305, 2.2468801480468685, 2.2708239378529704, 2.2943201939544835, 2.3173601394423224, 2.3399352885089106, 2.362037436761012, 2.383658652400475, 2.4047912681931014, 2.425427874153609, 2.445561310881599, 2.4651846634896946, 2.4842912560706325, 2.5028746466550897, 2.5209286226166068, 2.5384471964840087, 2.555424602125403, 2.5718552912711727, 2.5877339303463325, 2.6030553975853374, 2.6178147804048866, 2.632007373012426, 2.64562867423013, 2.6586743855158916, 2.6711404091645345, 2.683022846673969, 2.694317997262368, 2.7050223565236777, 2.7151326152099653, 2.724645658130088, 2.7335585631551775, 2.7418686003223014, 2.7495732310284597, 2.7566701073078446, 2.7631570711859896, 2.7690321541050547, 2.774293576415128, 2.7789397469269788, 2.7829692625222013, 2.786380907817238, 2.789173654878199, 2.791346662983865, 2.7928992784347098, 2.7938310344061597], [2.7748571071028776, 2.7745476938080476, 2.773619546276754, 2.7720729415879215, 2.7699083416044017, 2.7671263930705985, 2.763727927750444, 2.759713962607058, 2.755085700025798, 2.749844528082822, 2.7439920208617075, 2.7375299388211016, 2.730460229216851, 2.722785026582542, 2.7145066532728834, 2.705627620074952, 2.6961506268928583, 2.6860785635120656, 2.675414510450253, 2.6641617399023345, 2.652323716788078, 2.639904099911592, 2.626906743242909, 2.6133356973329067, 2.599195210873936, 2.5844897324197427, 2.5692239122796097, 2.55340260460313, 2.537030869673638, 2.520113976430108, 2.502657405239308, 2.4846668509421646, 2.466148226200703, 2.4471076651746, 2.427551527559296, 2.407486403020947, 2.3869191160670713, 2.3658567313958114, 2.344306559771213, 2.322276164476922, 2.2997733684062625, 2.2768062618528804, 2.2533832110730407, 2.2295128676984324, 2.2052041790869534, 2.180466399708626, 2.1553091036745857, 2.129742198529201, 2.1037759404388914, 2.0774209509263857, 2.050688235316107, 2.0235892030753777, 1.9961356902573646, 1.9683399842754783, 1.9402148512654824, 1.9117735663212279, 1.8830299469229999, 1.853998389914233, 1.8246939124231898, 1.7951321971713634, 1.7653296426601597, 1.7353034187819856, 1.705071528461341, 1.6746528759957378, 1.6440673428349164, 1.6133358716091102, 1.5824805592917723, 1.5515247604571667, 1.5204932016654522, 1.4894121080729354, 1.4583093434166472, 1.4272145645515242, 1.396159391713128, 1.3651775956226977, 1.3343053024226124, 1.3035812172004495, 1.2730468664915977, 1.2427468595965734, 1.212729167750444, 1.1830454190655944, 1.1537512056492607, 1.1249063972751834, 1.096575453358192, 1.068827721636837, 1.0417377078267436, 1.0153852955269802, 0.9898558898924207, 0.9652404522213179, 0.9416353860625001, 0.9191422294358086, 0.8978671033762783, 0.8779198657704792, 0.8594129232447789, 0.8424596647795874, 0.8271725006664733, 0.8136605205117275, 0.8020268237654401, 0.7923656229150374, 0.7847592674083388, 0.7792753773722848, 0.7759643007585023, 0.7748571071028774, 0.7759643007585045, 0.7792753773722895, 0.7847592674083456, 0.7923656229150463, 0.8020268237654512, 0.8136605205117404, 0.8271725006664882, 0.8424596647796041, 0.859412923244797, 0.877919865770499, 0.8978671033762995, 0.919142229435831, 0.9416353860625237, 0.9652404522213427, 0.9898558898924465, 1.0153852955270068, 1.041737707826771, 1.0688277216368651, 1.0965754533582206, 1.1249063972752127, 1.1537512056492905, 1.1830454190656245, 1.2127291677504743, 1.2427468595966045, 1.2730468664916288, 1.303581217200481, 1.334305302422644, 1.3651775956227294, 1.39615939171316, 1.4272145645515564, 1.4583093434166792, 1.4894121080729672, 1.5204932016654842, 1.5515247604571987, 1.5824805592918039, 1.613335871609142, 1.6440673428349482, 1.6746528759957693, 1.705071528461372, 1.7353034187820167, 1.7653296426601905, 1.7951321971713936, 1.82469391242322, 1.8539983899142631, 1.8830299469230296, 1.9117735663212574, 1.9402148512655113, 1.968339984275507, 1.9961356902573926, 2.0235892030754057, 2.050688235316135, 2.077420950926413, 2.1037759404389185, 2.1297421985292275, 2.155309103674612, 2.1804663997086515, 2.2052041790869787, 2.2295128676984572, 2.2533832110730647, 2.2768062618529044, 2.299773368406286, 2.3222761644769445, 2.3443065597712356, 2.3658567313958336, 2.386919116067093, 2.407486403020968, 2.4275515275593165, 2.4471076651746198, 2.466148226200723, 2.4846668509421823, 2.5026574052393267, 2.520113976430126, 2.537030869673655, 2.5534026046031464, 2.569223912279626, 2.5844897324197587, 2.5991952108739507, 2.6133356973329205, 2.6269067432429227, 2.6399040999116052, 2.6523237167880906, 2.664161739902346, 2.6754145104502642, 2.686078563512076, 2.6961506268928677, 2.705627620074961, 2.714506653272892, 2.72278502658255, 2.7304602292168583, 2.7375299388211087, 2.7439920208617137, 2.749844528082827, 2.755085700025803, 2.7597139626070626, 2.7637279277504483, 2.7671263930706016, 2.7699083416044044, 2.772072941587923, 2.7736195462767554, 2.7745476938080484], [2.754822939153244, 2.754514793611523, 2.7535904483125035, 2.7520501772526673, 2.7498944371531624, 2.747123867550951, 2.743739290927688, 2.7397417128776125, 2.7351323223161086, 2.7299124917309987, 2.7240837774790303, 2.7176479201304504, 2.710606844865009, 2.702962661923205, 2.694717667117088, 2.6858743424054725, 2.6764353565389802, 2.6664035657809495, 2.655782014710915, 2.644573937118063, 2.632782756992853, 2.620412089625833, 2.607465742823589, 2.593947718252787, 2.579862212924323, 2.5652136208308294, 2.550006534752084, 2.5342457482443046, 2.517936257830925, 2.501083265414168, 2.4836921809286943, 2.4657686252607234, 2.4473184334583955, 2.4283476582617625, 2.4088625739836873, 2.388869680776192, 2.368375709320318, 2.347387625981614, 2.325912638477762, 2.3039582021098086, 2.2815320266140073, 2.258642083697413, 2.2352966153272695, 2.211504142851933, 2.187273477039684, 2.1626137291314333, 2.13753432301413, 2.1120450086338187, 2.0861558767808446, 2.0598773753950037, 2.0332203275554908, 2.0061959513397354, 1.9788158817567125, 1.9510921949845295, 1.9230374351691066, 1.8946646440711685, 1.8659873938826708, 1.8370198235717368, 1.8077766791574512, 1.7782733583628973, 1.7485259601469496, 1.7185513396728611, 1.6883671693348419, 1.6579920065326685, 1.6274453689587278, 1.596747818241281, 1.5659210528711414, 1.5349880114246806, 1.5039729871814285, 1.4729017553155253, 1.4418017139109855, 1.410702040102899, 1.3796338626686497, 1.3486304523690744, 1.3177274312476317, 1.286963001907393, 1.2563781974631703, 1.2260171523604542, 1.1959273935017896, 1.1661601500472636, 1.1367706787648968, 1.1078185997887633, 1.0793682349748366, 1.051488937599851, 1.0242553978122206, 0.9977479029418678, 0.9720525255174246, 0.9472612047813816, 0.9234716800237357, 0.9007872268897914, 0.879316142105601, 0.8591709194522459, 0.8404670624408146, 0.8233214894429368, 0.8078505073807252, 0.7941673620695323, 0.782379416836076, 0.7725850633237384, 0.7648705233177812, 0.7593067486325954, 0.7559466564064744, 0.754822939153244, 0.7559466564064767, 0.7593067486326001, 0.7648705233177882, 0.7725850633237474, 0.7823794168360872, 0.7941673620695454, 0.8078505073807403, 0.8233214894429536, 0.8404670624408328, 0.859170919452266, 0.8793161421056224, 0.9007872268898143, 0.9234716800237596, 0.9472612047814066, 0.9720525255174505, 0.9977479029418946, 1.0242553978122482, 1.0514889375998795, 1.0793682349748657, 1.1078185997887928, 1.1367706787649265, 1.166160150047294, 1.1959273935018202, 1.2260171523604853, 1.2563781974632013, 1.2869630019074243, 1.3177274312476632, 1.3486304523691062, 1.3796338626686813, 1.4107020401029309, 1.4418017139110177, 1.4729017553155574, 1.50397298718146, 1.5349880114247125, 1.5659210528711733, 1.5967478182413126, 1.6274453689587594, 1.6579920065327, 1.6883671693348732, 1.7185513396728924, 1.7485259601469805, 1.7782733583629278, 1.8077766791574814, 1.8370198235717672, 1.8659873938827005, 1.8946646440711978, 1.9230374351691355, 1.9510921949845583, 1.9788158817567407, 2.006195951339763, 2.0332203275555187, 2.059877375395031, 2.086155876780871, 2.112045008633845, 2.1375343230141564, 2.162613729131458, 2.187273477039709, 2.211504142851958, 2.235296615327294, 2.258642083697437, 2.281532026614031, 2.3039582021098313, 2.3259126384777837, 2.347387625981636, 2.3683757093203393, 2.388869680776213, 2.4088625739837077, 2.4283476582617816, 2.447318433458415, 2.465768625260742, 2.483692180928712, 2.501083265414186, 2.5179362578309425, 2.534245748244321, 2.5500065347520997, 2.5652136208308454, 2.5798622129243376, 2.5939477182528012, 2.607465742823602, 2.6204120896258454, 2.632782756992866, 2.644573937118075, 2.655782014710926, 2.6664035657809597, 2.6764353565389905, 2.6858743424054827, 2.6947176671170965, 2.702962661923213, 2.7106068448650165, 2.717647920130457, 2.7240837774790365, 2.729912491731005, 2.7351323223161135, 2.7397417128776165, 2.7437392909276914, 2.747123867550954, 2.749894437153165, 2.752050177252669, 2.753590448312505, 2.7545147936115235], [2.7340585287594465, 2.733751716789235, 2.7328313711433374, 2.731297762632682, 2.729151342664703, 2.7263927433277906, 2.7230227775107423, 2.7190424390584655, 2.7144529029655273, 2.709255525609557, 2.7034518450268727, 2.6970435812331415, 2.6900326365922953, 2.6824210962374084, 2.6742112285477004, 2.66540548568638, 2.6560065042045586, 2.6460171057171067, 2.6354402976569267, 2.6242792741148318, 2.612537416772981, 2.6002182959406066, 2.5873256717016986, 2.5738634951852677, 2.55983590996987, 2.545247253635247, 2.530102059475227, 2.5144050583874353, 2.4981611809569055, 2.4813755597524225, 2.4640535318562926, 2.446200641650352, 2.4278226438833355, 2.408925507047282, 2.3895154170935475, 2.369598781522123, 2.3491822338815043, 2.3282726387203008, 2.306877097036118, 2.2850029522721718, 2.2626577969175234, 2.239849479772947, 2.2165861139512533, 2.1928760856885554, 2.1687280640515327, 2.144151011635344, 2.1191541963576648, 2.0937472044664056, 2.0679399548923185, 2.0417427150929894, 2.015166118551928, 1.9882211841158552, 1.9609193373750495, 1.9332724343161394, 1.9052927875042749, 1.8769931950826027, 1.8483869729117401, 1.8194879902109795, 1.7903107091066444, 1.7608702285418936, 1.7311823330566758, 1.7012635470070585, 1.6711311948599845, 1.6408034682730634, 1.6102995007491958, 1.579639450742544, 1.548844594184831, 1.5179374274979034, 1.4869417822576987, 1.4558829527726591, 1.424787837931006, 1.393685098748365, 1.3626053330990824, 1.3315812691258122, 1.3006479787715004, 1.269843112737131, 1.2392071578993347, 1.2087837177739618, 1.1786198159200414, 1.1487662211608038, 1.1192777920527357, 1.0902138360376266, 1.061638476025644, 1.0336210136276718, 1.006236273734549, 0.9795649095133035, 0.9536936401170352, 0.9287153855924464, 0.9047292549637331, 0.8818403349785232, 0.8601592197121666, 0.8398012169242983, 0.8208851681452298, 0.803531828808767, 0.7878617752662782, 0.7739928394270986, 0.7620371194740508, 0.7520976739481352, 0.7442650698269092, 0.7386140123376855, 0.735200321870619, 0.7340585287594465, 0.7352003218706213, 0.7386140123376903, 0.7442650698269162, 0.7520976739481444, 0.762037119474062, 0.7739928394271118, 0.7878617752662932, 0.8035318288087839, 0.8208851681452485, 0.8398012169243185, 0.8601592197121882, 0.8818403349785462, 0.9047292549637572, 0.9287153855924716, 0.9536936401170614, 0.9795649095133304, 1.006236273734577, 1.0336210136277002, 1.0616384760256732, 1.090213836037656, 1.119277792052766, 1.1487662211608343, 1.178619815920072, 1.2087837177739928, 1.2392071578993662, 1.2698431127371628, 1.3006479787715322, 1.331581269125844, 1.3626053330991144, 1.3936850987483969, 1.424787837931038, 1.4558829527726913, 1.4869417822577304, 1.5179374274979351, 1.5488445941848628, 1.5796394507425755, 1.610299500749227, 1.6408034682730948, 1.6711311948600158, 1.7012635470070894, 1.7311823330567067, 1.7608702285419242, 1.7903107091066748, 1.819487990211009, 1.84838697291177, 1.8769931950826317, 1.9052927875043038, 1.933272434316168, 1.960919337375078, 1.988221184115883, 2.0151661185519556, 2.0417427150930165, 2.0679399548923456, 2.093747204466432, 2.1191541963576905, 2.1441510116353695, 2.168728064051558, 2.1928760856885803, 2.2165861139512772, 2.239849479772971, 2.2626577969175465, 2.2850029522721944, 2.30687709703614, 2.3282726387203225, 2.3491822338815265, 2.3695987815221438, 2.389515417093568, 2.4089255070473015, 2.4278226438833546, 2.4462006416503708, 2.4640535318563104, 2.4813755597524403, 2.4981611809569224, 2.5144050583874513, 2.5301020594752432, 2.5452472536352624, 2.5598359099698853, 2.5738634951852823, 2.587325671701712, 2.6002182959406195, 2.6125374167729936, 2.6242792741148437, 2.6354402976569373, 2.646017105717117, 2.6560065042045684, 2.665405485686389, 2.6742112285477093, 2.682421096237417, 2.690032636592303, 2.697043581233149, 2.703451845026879, 2.7092555256095623, 2.714452902965532, 2.7190424390584704, 2.7230227775107467, 2.7263927433277937, 2.7291513426647054, 2.7312977626326833, 2.732831371143339, 2.733751716789236], [2.712583964147493, 2.71227855283529, 2.7113624080693657, 2.70983579737711, 2.707699166688795, 2.704953140415106, 2.701598521556862, 2.6976362918481303, 2.6930676119342847, 2.6878938215869232, 2.682116439957947, 2.6757371658755154, 2.6687578781849726, 2.661180636138333, 2.6530076798363473, 2.6442414307276847, 2.634884492170317, 2.6249396500607336, 2.6144098735372854, 2.603298315764578, 2.591608314806612, 2.5793433945971245, 2.566507266016479, 2.553103828085381, 2.5391371692867315, 2.52461156902809, 2.5095314992584257, 2.49390162625425, 2.477726812591719, 2.4610121193229553, 2.4437628083767207, 2.425984345205579, 2.4076824017039815, 2.3888628594242194, 2.3695318131199716, 2.3496955746503088, 2.329360677280458, 2.308533880419509, 2.2872221748395423, 2.265432788425487, 2.2431731925103926, 2.2204511088568366, 2.197274517351934, 2.173651664491002, 2.1495910727334437, 2.1251015508239544, 2.100192205182908, 2.074872452481881, 2.0491520335338675, 2.023041028643081, 1.9965498745765342, 1.9696893833390714, 1.9424707629555131, 1.9149056404883875, 1.8870060875476926, 1.8587846485806743, 1.8302543722651918, 1.8014288463702666, 1.7723222364924853, 1.742949329127515, 1.7133255795927032, 1.683467165380116, 1.6533910455899277, 1.6231150271722903, 1.592657838791959, 1.5620392132240977, 1.5312799792915044, 1.50040216446212, 1.4694291093393301, 1.4383855953933846, 1.407297987395596, 1.3761943921208808, 1.345104834968552, 1.3140614562014674, 1.283098728499349, 1.2522536974351486, 1.221566246275562, 1.1910793861270572, 1.1608395718298115, 1.1308970430569103, 1.1013061886952378, 1.0721259306329096, 1.0434201203961722, 1.015257938487067, 0.9877142815861722, 0.9608701168371454, 0.9348127751231604, 0.9096361466210662, 0.8854407322642416, 0.8623334947315368, 0.8404274434255042, 0.81984088152371, 0.8006962422698848, 0.7831184495724989, 0.7672327583035924, 0.7531620654494301, 0.7410237355636666, 0.7309260504477049, 0.7229644664600324, 0.7172179310492498, 0.7137455571420285, 0.7125839641474928, 0.7137455571420308, 0.7172179310492547, 0.7229644664600395, 0.7309260504477142, 0.7410237355636782, 0.7531620654494435, 0.7672327583036077, 0.7831184495725162, 0.8006962422699039, 0.8198408815237305, 0.8404274434255262, 0.8623334947315601, 0.885440732264266, 0.9096361466210915, 0.9348127751231867, 0.9608701168371726, 0.9877142815862002, 1.0152579384870957, 1.0434201203962015, 1.0721259306329394, 1.1013061886952678, 1.130897043056941, 1.1608395718298423, 1.1910793861270885, 1.2215662462755936, 1.25225369743518, 1.283098728499381, 1.3140614562014994, 1.345104834968584, 1.376194392120913, 1.407297987395628, 1.4383855953934164, 1.469429109339362, 1.5004021644621517, 1.531279979291536, 1.562039213224129, 1.5926578387919903, 1.6231150271723211, 1.6533910455899583, 1.6834671653801467, 1.7133255795927338, 1.7429493291275453, 1.7723222364925155, 1.801428846370296, 1.8302543722652214, 1.8587846485807038, 1.8870060875477217, 1.9149056404884162, 1.942470762955541, 1.9696893833390992, 1.9965498745765617, 2.0230410286431075, 2.049152033533894, 2.0748724524819075, 2.1001922051829336, 2.12510155082398, 2.149591072733469, 2.173651664491026, 2.197274517351958, 2.2204511088568606, 2.2431731925104157, 2.2654327884255094, 2.2872221748395645, 2.3085338804195312, 2.329360677280479, 2.3496955746503287, 2.369531813119991, 2.388862859424239, 2.4076824017040015, 2.4259843452055976, 2.4437628083767384, 2.4610121193229726, 2.4777268125917353, 2.493901626254267, 2.509531499258442, 2.5246115690281057, 2.5391371692867466, 2.553103828085395, 2.566507266016493, 2.5793433945971374, 2.5916083148066242, 2.6032983157645897, 2.614409873537296, 2.6249396500607443, 2.6348844921703267, 2.6442414307276936, 2.6530076798363558, 2.6611806361383414, 2.66875787818498, 2.675737165875522, 2.6821164399579533, 2.6878938215869286, 2.69306761193429, 2.6976362918481347, 2.7015985215568654, 2.704953140415109, 2.707699166688797, 2.709835797377112, 2.7113624080693675, 2.712278552835291], [2.6904200205717324, 2.6901160783314433, 2.689204339656389, 2.687685068697926, 2.6855587057548775, 2.682825867343938, 2.6794873462993833, 2.6755441119032293, 2.6709973100473423, 2.6658482634293246, 2.6600984717844205, 2.6537496121560085, 2.646803539207713, 2.6392622855805383, 2.631128062298921, 2.622403259230077, 2.613090445601498, 2.6031923705820756, 2.592711963932871, 2.5816523367342294, 2.570016782196644, 2.557808776563534, 2.545031980114939, 2.5316902382820565, 2.5177875828835465, 2.5033282334956306, 2.488316598969227, 2.472757279108686, 2.456655066528189, 2.440014948703461, 2.422842110238287, 2.405141935367289, 2.3869200107186357, 2.3681821283628297, 2.3489342891764267, 2.3291827065526043, 2.3089338104938797, 2.2881942521260497, 2.2669709086766936, 2.2452708889662634, 2.22310153946512, 2.2004704509758084, 2.1773854660065064, 2.153854686909096, 2.129886484863721, 2.1054895098011377, 2.08067270136488, 2.055445301027252, 2.02981686548675, 2.003797281489835, 1.9773967822372835, 1.9506259655549174, 1.9234958140306317, 1.896017717344688, 1.8682034970485428, 1.840065434079557, 1.8116162993351494, 1.7828693876709754, 1.753838555734004, 1.7245382640936233, 1.694983624192794, 1.6651904507074355, 1.6351753199764445, 1.604955635247587, 1.5745496995765893, 1.5439767973184164, 1.5132572852610708, 1.4824126945728235, 1.4514658448624695, 1.4204409717867095, 1.3893638697753434, 1.3582620515774972, 1.3271649264515235, 1.2961039989139795, 1.2651130900099155, 1.2342285830402935, 1.203489695545033, 1.1729387790404338, 1.1426216474786304, 1.112587934543454, 1.0828914786043864, 1.05359073227086, 1.0247491908433666, 0.996435830336704, 0.9687255409261782, 0.9416995354175403, 0.9154457044953112, 0.8900588810199973, 0.8656409647259329, 0.8423008469288003, 0.8201540635034907, 0.7993220954719371, 0.7799312330393686, 0.7621109247473883, 0.7459915530080861, 0.7317016146770142, 0.7193643426037368, 0.7090938794289857, 0.7009912006563921, 0.6951400660821635, 0.6916033379055702, 0.6904200205717321, 0.6916033379055727, 0.6951400660821683, 0.7009912006563993, 0.7090938794289952, 0.7193643426037486, 0.7317016146770278, 0.7459915530081017, 0.7621109247474058, 0.7799312330393877, 0.7993220954719579, 0.8201540635035128, 0.8423008469288237, 0.8656409647259574, 0.8900588810200228, 0.9154457044953375, 0.9416995354175677, 0.9687255409262063, 0.9964358303367329, 1.0247491908433959, 1.0535907322708895, 1.0828914786044168, 1.1125879345434846, 1.1426216474786615, 1.1729387790404648, 1.2034896955450647, 1.234228583040325, 1.2651130900099472, 1.2961039989140113, 1.3271649264515553, 1.3582620515775292, 1.3893638697753754, 1.4204409717867412, 1.451465844862501, 1.4824126945728555, 1.5132572852611024, 1.5439767973184482, 1.5745496995766208, 1.6049556352476182, 1.6351753199764756, 1.6651904507074666, 1.6949836241928247, 1.7245382640936533, 1.7538385557340337, 1.7828693876710053, 1.811616299335179, 1.8400654340795861, 1.8682034970485715, 1.8960177173447161, 1.9234958140306602, 1.950625965554945, 1.9773967822373106, 2.0037972814898617, 2.0298168654867768, 2.0554453010272784, 2.080672701364906, 2.105489509801163, 2.129886484863746, 2.1538546869091206, 2.1773854660065304, 2.200470450975832, 2.2231015394651426, 2.2452708889662856, 2.2669709086767162, 2.2881942521260714, 2.3089338104939006, 2.329182706552625, 2.3489342891764466, 2.3681821283628497, 2.3869200107186552, 2.405141935367307, 2.422842110238305, 2.4400149487034777, 2.4566550665282056, 2.4727572791087025, 2.4883165989692433, 2.503328233495646, 2.517787582883561, 2.5316902382820703, 2.545031980114953, 2.5578087765635473, 2.5700167821966566, 2.581652336734241, 2.5927119639328815, 2.6031923705820854, 2.613090445601508, 2.622403259230086, 2.63112806229893, 2.6392622855805463, 2.6468035392077205, 2.653749612156015, 2.6600984717844263, 2.66584826342933, 2.6709973100473476, 2.675544111903234, 2.6794873462993873, 2.6828258673439414, 2.6855587057548806, 2.687685068697928, 2.68920433965639, 2.6901160783314437], [2.6675881402161385, 2.6672857368485308, 2.666378613637786, 2.664867031272602, 2.662751424275853, 2.6600324010676863, 2.6567107440549664, 2.6527874097481456, 2.648263528906998, 2.643140406716996, 2.637419522998437, 2.6311025324508193, 2.6241912649353494, 2.616687725798858, 2.608594096242864, 2.59991273374196, 2.590646172516229, 2.580797124062886, 2.570368477752979, 2.559363301499549, 2.547784842504381, 2.5356365280911746, 2.522921966633816, 2.509644948589268, 2.495809447645608, 2.4814196219967872, 2.4664798157568537, 2.4509945605276893, 2.4349685771357192, 2.4184067775546434, 2.4013142670329763, 2.383696346447123, 2.365558514902863, 2.3469064726105193, 2.327746124061723, 2.3080835815386798, 2.287925168990143, 2.267277426311987, 2.2461471140744242, 2.224541218742553, 2.2024669584420873, 2.179931789327992, 2.1569434126202705, 2.1335097823785376, 2.109639114095329, 2.085339894197416, 2.0606208905550134, 2.0354911641106517, 2.009960081752996, 1.9840373305761436, 1.95773293368222, 1.9310572677046618, 1.9040210822517896, 1.8766355214954433, 1.8489121481580588, 1.8208629701839865, 1.7925004704177057, 1.7638376396533955, 1.7348880134677487, 1.7056657133017041, 1.676185492317675, 1.6464627866276993, 1.6165137725656364, 1.5863554307639014, 1.5560056178931625, 1.525483147032577, 1.4948078777590694, 1.4640008171768961, 1.4330842332528266, 1.4020817819761993, 1.371018650024001, 1.339921714773992, 1.3088197236658539, 1.2777434950492408, 1.2467261427605816, 1.2158033267116177, 1.1850135317152806, 1.1543983765676067, 1.1240029549780435, 1.0938762092008232, 1.0640713360431908, 1.0346462231525986, 1.005663910914743, 0.977193071686882, 0.9493084931716074, 0.9220915462176346, 0.895630608959644, 0.8700214088319286, 0.8453672317002925, 0.8217789336652706, 0.7993746771757945, 0.7782793010775254, 0.7586232274053685, 0.7405408106512965, 0.7241680533279217, 0.7096396502464709, 0.6970853864836866, 0.6866259995776086, 0.6783687171556345, 0.6724027807156032, 0.6687953414785627, 0.6675881402161384, 0.6687953414785652, 0.6724027807156082, 0.6783687171556421, 0.6866259995776184, 0.6970853864836986, 0.7096396502464848, 0.7241680533279377, 0.7405408106513144, 0.7586232274053878, 0.7782793010775463, 0.7993746771758168, 0.8217789336652942, 0.8453672317003174, 0.8700214088319543, 0.8956306089596706, 0.9220915462176622, 0.9493084931716357, 0.9771930716869109, 1.0056639109147725, 1.0346462231526286, 1.064071336043221, 1.0938762092008538, 1.1240029549780746, 1.1543983765676382, 1.185013531715312, 1.2158033267116493, 1.246726142760613, 1.2777434950492725, 1.308819723665886, 1.3399217147740239, 1.371018650024033, 1.4020817819762312, 1.4330842332528586, 1.4640008171769276, 1.4948078777591007, 1.5254831470326082, 1.5560056178931936, 1.5863554307639323, 1.616513772565667, 1.64646278662773, 1.6761854923177057, 1.7056657133017343, 1.7348880134677784, 1.763837639653425, 1.7925004704177347, 1.8208629701840156, 1.8489121481580877, 1.8766355214954715, 1.9040210822518173, 1.9310572677046893, 1.957732933682247, 1.9840373305761703, 2.0099600817530225, 2.035491164110678, 2.060620890555039, 2.085339894197441, 2.1096391140953537, 2.133509782378562, 2.156943412620294, 2.1799317893280157, 2.20246695844211, 2.2245412187425755, 2.2461471140744464, 2.267277426312009, 2.2879251689901645, 2.3080835815386997, 2.3277461240617425, 2.3469064726105393, 2.365558514902882, 2.383696346447141, 2.401314267032994, 2.4184067775546607, 2.434968577135736, 2.4509945605277057, 2.4664798157568697, 2.4814196219968023, 2.4958094476456227, 2.509644948589282, 2.522921966633829, 2.5356365280911874, 2.547784842504393, 2.559363301499561, 2.5703684777529903, 2.580797124062897, 2.5906461725162386, 2.599912733741969, 2.608594096242872, 2.6166877257988665, 2.6241912649353565, 2.631102532450826, 2.6374195229984427, 2.6431404067170017, 2.648263528907003, 2.6527874097481496, 2.656710744054971, 2.6600324010676895, 2.6627514242758554, 2.6648670312726037, 2.666378613637787, 2.667285736848531], [2.644110411450382, 2.6438096182025697, 2.6429073241706975, 2.6414037865004354, 2.6392994338046516, 2.6365948662190424, 2.633290855481075, 2.629388345033272, 2.624888450152209, 2.6197924581049254, 2.6141018283347592, 2.6078181926789963, 2.6009433556210846, 2.5934792945805505, 2.5854281602441773, 2.576792276942459, 2.5675741430758, 2.5577764315954648, 2.547401990544822, 2.5364538436670414, 2.5249351910860374, 2.5128494100681884, 2.500200055873111, 2.4869908627026422, 2.4732257447581065, 2.4589087974169637, 2.4440442985410726, 2.428636709930055, 2.412690678934602, 2.3962110402461074, 2.3792028178807016, 2.361671227377604, 2.343621678233838, 2.3250597765996366, 2.3059913282614555, 2.2864223419424063, 2.266359032953127, 2.2458078272297133, 2.22477536579936, 2.2032685097189044, 2.1812943455365175, 2.1588601913325065, 2.135973603401626, 2.1126423836465036, 2.088874587759985, 2.064678534283383, 2.0400628146380653, 2.015036304239583, 1.9896081748169092, 1.9637879080745062, 1.9375853108521062, 1.9110105319566357, 1.8840740808629024, 1.8567868485049013, 1.8291601304083576, 1.8012056524478404, 1.7729355995490808, 1.7443626476996095, 1.7154999996792357, 1.686361424977016, 1.6569613044240987, 1.6273146801431664, 1.597437311496159, 1.5673457378036812, 1.5370573487130517, 1.5065904632085019, 1.4759644183873968, 1.4451996692713474, 1.4143179010807614, 1.3833421555752041, 1.3522969732480397, 1.3212085533584685, 1.2901049339808428, 1.2590161944395866, 1.2279746826621323, 1.1970152700980572, 1.166175636885162, 1.1354965898428586, 1.1050224155702097, 1.0748012703244954, 1.0448856073269517, 1.0153326405146113, 0.9862048413112525, 0.957570461453015, 0.9295040699501186, 0.9020870855342268, 0.8754082770734827, 0.8495641931575716, 0.8246594683025467, 0.800806937363558, 0.7781274728548825, 0.7567494441200094, 0.7368076862625865, 0.7184418656624971, 0.7017941443773023, 0.6870060847756931, 0.6742148036838644, 0.6635484826277044, 0.6551214595326919, 0.6490292488971289, 0.6453439337118383, 0.6441104114503821, 0.6453439337118408, 0.6490292488971339, 0.6551214595326992, 0.6635484826277143, 0.6742148036838768, 0.6870060847757072, 0.7017941443773186, 0.7184418656625151, 0.7368076862626062, 0.7567494441200309, 0.7781274728549051, 0.8008069373635819, 0.8246594683025718, 0.8495641931575977, 0.8754082770735095, 0.9020870855342547, 0.9295040699501469, 0.9575704614530444, 0.9862048413112822, 1.0153326405146414, 1.0448856073269823, 1.0748012703245262, 1.105022415570241, 1.1354965898428901, 1.1661756368851937, 1.197015270098089, 1.227974682662164, 1.2590161944396183, 1.290104933980875, 1.3212085533585003, 1.3522969732480714, 1.383342155575236, 1.4143179010807936, 1.445199669271379, 1.4759644183874283, 1.5065904632085332, 1.5370573487130827, 1.567345737803712, 1.5974373114961897, 1.6273146801431966, 1.656961304424129, 1.686361424977046, 1.7154999996792653, 1.7443626476996386, 1.77293559954911, 1.8012056524478692, 1.8291601304083864, 1.8567868485049297, 1.8840740808629302, 1.911010531956663, 1.9375853108521333, 1.9637879080745333, 1.9896081748169359, 2.015036304239609, 2.040062814638091, 2.064678534283408, 2.0888745877600097, 2.1126423836465276, 2.13597360340165, 2.15886019133253, 2.18129434553654, 2.2032685097189266, 2.2247753657993816, 2.2458078272297346, 2.266359032953148, 2.2864223419424263, 2.305991328261475, 2.325059776599656, 2.3436216782338573, 2.3616712273776215, 2.379202817880719, 2.3962110402461247, 2.4126906789346183, 2.428636709930072, 2.444044298541089, 2.458908797416979, 2.473225744758121, 2.486990862702656, 2.5002000558731243, 2.5128494100682017, 2.5249351910860502, 2.5364538436670525, 2.547401990544833, 2.557776431595475, 2.5675741430758094, 2.576792276942468, 2.5854281602441858, 2.5934792945805585, 2.600943355621092, 2.607818192679003, 2.6141018283347655, 2.6197924581049308, 2.624888450152214, 2.6293883450332762, 2.6332908554810786, 2.6365948662190455, 2.639299433804654, 2.641403786500438, 2.6429073241706984, 2.6438096182025705], [2.620009547460759, 2.6197104370855606, 2.618813190466457, 2.6173180611323854, 2.6152254716632686, 2.6125360137380453, 2.609250448202911, 2.6053697051607583, 2.6008948840831216, 2.5958272539462364, 2.590168253393132, 2.5839194909240315, 2.5770827451176674, 2.569659964886518, 2.5616532697693275, 2.5530649502647504, 2.5438974682103748, 2.5341534572118736, 2.523835723127597, 2.512947244614441, 2.501491173741499, 2.489470836678651, 2.476889734468011, 2.463751543886952, 2.4500601184123316, 2.4358194892965277, 2.4210338667669578, 2.405707641361993, 2.3898453854174426, 2.373451854719316, 2.3565319903401356, 2.339090920677922, 2.3211339637189594, 2.3026666295476894, 2.2836946231295907, 2.2642238473956615, 2.2442604066602785, 2.223810610407662, 2.2028809774861062, 2.1814782407535422, 2.1596093522229154, 2.1372814887614506, 2.1145020584041236, 2.091278707348741, 2.0676193277080324, 2.0435320661031713, 2.0190253331934067, 1.994107814248067, 1.9687884808803955, 1.9430766040776195, 1.9169817686787092, 1.890513889470644, 1.863683229096125, 1.8365004179908693, 1.8089764765974068, 1.7811228401351844, 1.7529513862443755, 1.7244744658637774, 1.6957049377523654, 1.6666562071203226, 1.6373422688996984, 1.6077777562584004, 1.5779779950451809, 1.5479590649490167, 1.5177378682652283, 1.4873322072842432, 1.4567608714585822, 1.4260437356606481, 1.3952018710191951, 1.3642576700162967, 1.333234987738506, 1.3021593014034587, 1.2710578905216803, 1.2399600402944202, 1.2088972710782762, 1.1779035969447662, 1.1470158164956545, 1.1162738391153575, 1.0857210496820306, 1.055404714322888, 1.0253764289540157, 0.9956926109103011, 0.9664150317087814, 0.937611385592666, 0.9093558835951464, 0.8817298559994712, 0.8548223367797825, 0.8287305914518402, 0.803560534488487, 0.7794269642146028, 0.7564535227962815, 0.7347722686944448, 0.7145227325970478, 0.6958503213179239, 0.6789039454580885, 0.6638327848795388, 0.6507821791119833, 0.6398887404007461, 0.6312749279024387, 0.625043471421722, 0.6212721573940071, 0.6200095474607589, 0.6212721573940095, 0.6250434714217272, 0.6312749279024464, 0.639888740400756, 0.6507821791119957, 0.6638327848795532, 0.678903945458105, 0.6958503213179423, 0.7145227325970678, 0.7347722686944663, 0.7564535227963045, 0.779426964214627, 0.8035605344885122, 0.8287305914518667, 0.8548223367798097, 0.8817298559994992, 0.9093558835951752, 0.9376113855926953, 0.9664150317088114, 0.9956926109103313, 1.0253764289540463, 1.0554047143229188, 1.085721049682062, 1.1162738391153888, 1.147015816495686, 1.1779035969447982, 1.2088972710783081, 1.239960040294452, 1.271057890521712, 1.3021593014034905, 1.3332349877385377, 1.3642576700163287, 1.3952018710192269, 1.4260437356606799, 1.4567608714586138, 1.487332207284274, 1.5177378682652596, 1.5479590649490476, 1.5779779950452113, 1.6077777562584308, 1.6373422688997288, 1.6666562071203526, 1.6957049377523954, 1.7244744658638065, 1.7529513862444046, 1.7811228401352135, 1.8089764765974354, 1.8365004179908977, 1.8636832290961527, 1.8905138894706712, 1.916981768678736, 1.943076604077646, 1.9687884808804215, 1.9941078142480932, 2.0190253331934325, 2.0435320661031966, 2.067619327708057, 2.091278707348765, 2.114502058404147, 2.1372814887614746, 2.159609352222938, 2.181478240753564, 2.202880977486128, 2.223810610407684, 2.2442604066602994, 2.264223847395681, 2.2836946231296107, 2.302666629547709, 2.3211339637189785, 2.33909092067794, 2.3565319903401534, 2.373451854719333, 2.389845385417459, 2.4057076413620093, 2.4210338667669737, 2.4358194892965424, 2.4500601184123467, 2.463751543886966, 2.476889734468025, 2.4894708366786644, 2.5014911737415115, 2.5129472446144527, 2.523835723127608, 2.534153457211884, 2.543897468210384, 2.5530649502647593, 2.561653269769336, 2.5696599648865264, 2.5770827451176754, 2.5839194909240377, 2.590168253393138, 2.595827253946242, 2.6008948840831265, 2.605369705160762, 2.6092504482029146, 2.6125360137380484, 2.6152254716632712, 2.6173180611323876, 2.6188131904664584, 2.619710437085562], [2.5953088642766495, 2.595011511091647, 2.594119534815856, 2.592633185294853, 2.5905528789644965, 2.5878791988912404, 2.5846128948295095, 2.5807548832970904, 2.5763062476697565, 2.5712682382966605, 2.5656422726383155, 2.559429935429303, 2.552632978868207, 2.5452533228375764, 2.537293055157159, 2.5287544318739994, 2.5196398775934536, 2.509951985855637, 2.499693519562316, 2.488867411459803, 2.4774767646840203, 2.4655248533745304, 2.4530151233650495, 2.4399511929587314, 2.426336853797372, 2.4121760718346135, 2.3974729884242683, 2.3822319215360257, 2.3664573671120803, 2.3501540005796, 2.333326678535541, 2.315980440622029, 2.298120511612452, 2.2797523037305853, 2.2608814192274336, 2.2415136532431967, 2.221654996984748, 2.201311641252388, 2.1804899803534346, 2.159196616444436, 2.1374383643486206, 2.1152222569005485, 2.0925555508760643, 2.069445733572495, 2.0459005301118576, 2.0219279115486453, 1.9975361038737778, 1.9727335980176792, 1.9475291609683687, 1.921931848135196, 1.8959510171056175, 1.869596342961611, 1.8428778353441893, 1.8158058574795644, 1.7883911474091667, 1.7606448416986378, 1.7325785019385957, 1.704204144393293, 1.6755342732029848, 1.6465819176029557, 1.6173606736877852, 1.5878847513248406, 1.5581690269075934, 1.5282291027387016, 1.4980813739466805, 1.4677431039701596, 1.4372325097922043, 1.4065688582758427, 1.3757725751425454, 1.3448653683493317, 1.3138703678580534, 1.2828122840515535, 1.2517175873330884, 1.2206147117416806, 1.1895342857160696, 1.1585093934255677, 1.1275758703288228, 1.0967726367775326, 1.066142073486708, 1.035730442451908, 1.0055883562729702, 0.9757712976564104, 0.9463401888605681, 0.917362007681503, 0.8889104418211219, 0.8610665666022159, 0.8339195213909372, 0.807567147134238, 0.7821165306164805, 0.7576843802492633, 0.7343971340546209, 0.7123906749323666, 0.691809505287459, 0.6728052192849518, 0.6555341159829252, 0.640153832106251, 0.6268189505952501, 0.6156756663764271, 0.6068557583043644, 0.6004703023181654, 0.5966037229025231, 0.5953088642766493, 0.5966037229025258, 0.6004703023181708, 0.6068557583043722, 0.6156756663764376, 0.6268189505952626, 0.6401538321062656, 0.655534115982942, 0.6728052192849705, 0.6918095052874793, 0.7123906749323884, 0.7343971340546444, 0.7576843802492879, 0.7821165306165061, 0.8075671471342647, 0.8339195213909646, 0.8610665666022441, 0.8889104418211509, 0.9173620076815325, 0.9463401888605981, 0.9757712976564406, 1.005588356273001, 1.0357304424519391, 1.0661420734867393, 1.0967726367775643, 1.1275758703288543, 1.1585093934255997, 1.1895342857161015, 1.2206147117417125, 1.25171758733312, 1.2828122840515854, 1.3138703678580852, 1.3448653683493634, 1.375772575142577, 1.4065688582758742, 1.4372325097922354, 1.467743103970191, 1.4980813739467116, 1.5282291027387325, 1.558169026907624, 1.5878847513248713, 1.6173606736878154, 1.6465819176029854, 1.6755342732030145, 1.7042041443933222, 1.7325785019386246, 1.7606448416986666, 1.7883911474091951, 1.8158058574795921, 1.842877835344217, 1.8695963429616378, 1.8959510171056444, 1.9219318481352223, 1.947529160968395, 1.9727335980177045, 1.9975361038738033, 2.02192791154867, 2.045900530111882, 2.0694457335725187, 2.092555550876088, 2.115222256900571, 2.1374383643486428, 2.159196616444458, 2.1804899803534563, 2.2013116412524094, 2.221654996984768, 2.2415136532432167, 2.2608814192274527, 2.279752303730605, 2.298120511612471, 2.3159804406220466, 2.3333266785355584, 2.350154000579617, 2.3664573671120968, 2.382231921536042, 2.397472988424284, 2.412176071834629, 2.426336853797386, 2.4399511929587447, 2.4530151233650628, 2.465524853374543, 2.4774767646840328, 2.488867411459815, 2.499693519562327, 2.5099519858556474, 2.519639877593463, 2.5287544318740083, 2.5372930551571677, 2.545253322837585, 2.552632978868214, 2.55942993542931, 2.5656422726383212, 2.571268238296666, 2.576306247669762, 2.580754883297095, 2.5846128948295135, 2.587879198891243, 2.590552878964499, 2.5926331852948548, 2.5941195348158574, 2.595011511091647], [2.5700322582137654, 2.569736738159855, 2.568850260030364, 2.5673730699283928, 2.5653055780471488, 2.56264835870246, 2.559402150379167, 2.555567855792296, 2.5511465419641737, 2.546139440318909, 2.5405479467959755, 2.534373621984902, 2.52761819128342, 2.5202835450817336, 2.5123717389759395, 2.503884994014013, 2.4948256969781646, 2.485196400707837, 2.474999824468073, 2.4642388543685017, 2.4529165438387666, 2.4410361141668107, 2.4286009551071333, 2.4156146255668527, 2.4020808543782173, 2.3880035411671106, 2.373386757328083, 2.3582347471175122, 2.342551928877722, 2.326342896406219, 2.309612420485683, 2.292365450592021, 2.2746071167996127, 2.2563427319049607, 2.237577793792224, 2.2183179880667216, 2.1985691909853466, 2.178337472716085, 2.1576291009624717, 2.136450544992898, 2.114808480119318, 2.0927097926750964, 2.0701615855476354, 2.04717118432808, 2.0237461441479545, 1.999894257281157, 1.9756235615994677, 1.9509423499808367, 1.925859180782327, 1.9003828895040202, 1.8745226017866625, 1.8482877479046769, 1.8216880789377563, 1.794733684829035, 1.7674350145662587, 1.7398028987550909, 1.7118485748913164, 1.6835837156820765, 1.6550204608162251, 1.6261714526415976, 1.5970498762735428, 1.5676695047359326, 1.5380447498246381, 1.5081907194859214, 1.4781232826203925, 1.4478591423593747, 1.4174159190171383, 1.3868122441021034, 1.356067866975414, 1.3252037759786766, 1.2942423361162438, 1.2632074456722677, 1.2321247144684326, 1.2010216668215676, 1.16992797263387, 1.1388757104281753, 1.1078996665027636, 1.077037674686086, 1.0463310013619547, 1.0158247804204816, 0.9855685024375523, 0.9556165615065918, 0.9260288614747472, 0.8968714805068865, 0.8682173884301205, 0.8401472045784729, 0.8127499741095368, 0.7861239271632824, 0.7603771669729843, 0.7356282095982628, 0.7120062695305037, 0.6896511536236052, 0.6687125945547384, 0.649348831590431, 0.6317242421379647, 0.6160058573569881, 0.6023586749630251, 0.5909398234201264, 0.5818918314172218, 0.5753354892630542, 0.5713630021406526, 0.5700322582137655, 0.5713630021406554, 0.5753354892630597, 0.58189183141723, 0.590939823420137, 0.602358674963038, 0.6160058573570032, 0.631724242137982, 0.6493488315904502, 0.6687125945547591, 0.6896511536236275, 0.7120062695305274, 0.7356282095982877, 0.7603771669730103, 0.7861239271633093, 0.8127499741095644, 0.8401472045785013, 0.8682173884301495, 0.8968714805069162, 0.9260288614747773, 0.9556165615066224, 0.9855685024375834, 1.015824780420513, 1.046331001361986, 1.0770376746861174, 1.1078996665027956, 1.138875710428207, 1.169927972633902, 1.2010216668215998, 1.2321247144684646, 1.2632074456722997, 1.2942423361162756, 1.3252037759787085, 1.3560678669754453, 1.386812244102135, 1.4174159190171698, 1.4478591423594065, 1.4781232826204236, 1.5081907194859525, 1.5380447498246692, 1.567669504735963, 1.5970498762735728, 1.6261714526416275, 1.6550204608162546, 1.6835837156821063, 1.7118485748913455, 1.739802898755119, 1.7674350145662872, 1.794733684829063, 1.8216880789377836, 1.848287747904704, 1.8745226017866894, 1.9003828895040467, 1.925859180782353, 1.9509423499808622, 1.9756235615994928, 1.9998942572811815, 2.023746144147979, 2.0471711843281035, 2.0701615855476585, 2.092709792675119, 2.1148084801193403, 2.13645054499292, 2.157629100962493, 2.1783374727161062, 2.198569190985367, 2.2183179880667416, 2.237577793792244, 2.2563427319049794, 2.2746071167996313, 2.2923654505920386, 2.3096124204857, 2.326342896406236, 2.3425519288777386, 2.358234747117528, 2.373386757328099, 2.3880035411671257, 2.4020808543782315, 2.415614625566867, 2.428600955107146, 2.4410361141668226, 2.4529165438387786, 2.4642388543685136, 2.474999824468083, 2.485196400707847, 2.4948256969781744, 2.503884994014023, 2.5123717389759483, 2.5202835450817416, 2.5276181912834272, 2.5343736219849085, 2.5405479467959813, 2.546139440318915, 2.551146541964178, 2.5555678557923005, 2.5594021503791704, 2.562648358702463, 2.565305578047151, 2.5673730699283945, 2.5688502600303655, 2.5697367381598557], [2.5442041827560096, 2.5439105734552077, 2.543029826321016, 2.541562183662887, 2.5395080493460624, 2.536867988816225, 2.5336427291348267, 2.529833159025953, 2.525440328935784, 2.520465451106021, 2.5149098996628743, 2.508775210723516, 2.502063082522183, 2.494775375558447, 2.4869141127704766, 2.4784814797365025, 2.4694798249080585, 2.4599116598790003, 2.4497796596947445, 2.4390866632066603, 2.427835673477071, 2.416029858240914, 2.403672550430727, 2.390767248772334, 2.377317618459365, 2.3633274919155878, 2.3488008696549625, 2.333741921250361, 2.318154986423026, 2.3020445762661335, 2.285415374617196, 2.268272239595657, 2.250620205323743, 2.2324644838506145, 2.2138104673020305, 2.1946637302802166, 2.175030032541348, 2.154915321981175, 2.13432573796278, 2.113267615024384, 2.091747487009546, 2.069772091667089, 2.047348375773753, 2.024483500838994, 2.0011848494586193, 1.9774600323922356, 1.9533168964489067, 1.928763533276171, 1.9038082891598243, 1.8784597759559234, 1.852726883292519, 1.8266187921970607, 1.80014499032658, 1.7733152890021007, 1.7461398422767525, 1.7186291682993955, 1.6907941732728915, 1.662646178349304, 1.6341969498542561, 1.6054587332905317, 1.5764442916380859, 1.5471669485454735, 1.5176406370980637, 1.4878799549533224, 1.4579002267552583, 1.427717574881478, 1.397348999740148, 1.366812471023817, 1.336127031545982, 1.3053129155381786, 1.2743916835737643, 1.2433863766125206, 1.21232169202978, 1.1812241849049363, 1.1501224982935292, 1.1190476266854623, 1.088033217341388, 1.0571159146682865, 1.0263357531918302, 0.9957366049252803, 0.9653666868970929, 0.9352791340954949, 0.9055326418465997, 0.8761921792781453, 0.8473297715019986, 0.8190253417656588, 0.7913675951701882, 0.7644549115450329, 0.738396195541054, 0.7133116059352216, 0.6893330531328616, 0.6666043149125014, 0.6452805791771662, 0.6255271865131192, 0.6075173277982023, 0.5914284717398446, 0.5774373761732325, 0.5657136938318382, 0.5564124213719951, 0.5496657334453466, 0.5455750272374141, 0.5442041827560096, 0.5455750272374169, 0.5496657334453523, 0.5564124213720033, 0.5657136938318491, 0.5774373761732459, 0.5914284717398601, 0.60751732779822, 0.6255271865131387, 0.6452805791771872, 0.6666043149125241, 0.6893330531328857, 0.7133116059352468, 0.7383961955410802, 0.7644549115450601, 0.7913675951702163, 0.8190253417656875, 0.847329771502028, 0.8761921792781753, 0.90553264184663, 0.9352791340955255, 0.9653666868971241, 0.9957366049253115, 1.0263357531918618, 1.0571159146683182, 1.0880332173414198, 1.1190476266854943, 1.1501224982935612, 1.1812241849049683, 1.2123216920298119, 1.2433863766125524, 1.2743916835737958, 1.3053129155382104, 1.3361270315460136, 1.3668124710238487, 1.3973489997401796, 1.4277175748815092, 1.4579002267552894, 1.487879954953353, 1.5176406370980942, 1.5471669485455037, 1.576444291638116, 1.6054587332905614, 1.6341969498542854, 1.662646178349333, 1.6907941732729204, 1.7186291682994241, 1.7461398422767804, 1.7733152890021284, 1.8001449903266074, 1.8266187921970878, 1.8527268832925456, 1.8784597759559498, 1.90380828915985, 1.9287635332761965, 1.953316896448932, 1.97746003239226, 2.0011848494586433, 2.024483500839018, 2.047348375773776, 2.069772091667112, 2.0917474870095685, 2.1132676150244056, 2.134325737962801, 2.1549153219811963, 2.1750300325413687, 2.1946637302802365, 2.21381046730205, 2.2324644838506336, 2.250620205323762, 2.268272239595675, 2.2854153746172132, 2.3020445762661508, 2.318154986423042, 2.3337419212503767, 2.348800869654978, 2.3633274919156024, 2.37731761845938, 2.390767248772348, 2.40367255043074, 2.416029858240926, 2.4278356734770834, 2.439086663206672, 2.449779659694755, 2.4599116598790096, 2.4694798249080674, 2.4784814797365113, 2.4869141127704846, 2.4947753755584547, 2.50206308252219, 2.508775210723522, 2.5149098996628805, 2.5204654511060265, 2.5254403289357885, 2.5298331590259573, 2.5336427291348307, 2.5368679888162275, 2.5395080493460647, 2.541562183662888, 2.543029826321017, 2.5439105734552085], [2.5178496248983073, 2.517558005710538, 2.5166832276371602, 2.515225529151207, 2.513185307718656, 2.5105631198151914, 2.507359680950455, 2.503575865700543, 2.49921270774978, 2.4942713999430106, 2.488753294349921, 2.482659902343147, 2.4759928946922214, 2.4687541016756893, 2.4609455132140394, 2.4525692790264384, 2.443627708814605, 2.4341232724775552, 2.4240586003613633, 2.4134364835485407, 2.402259874192138, 2.3905318859002045, 2.3782557941768467, 2.3654350369267685, 2.3520732150309063, 2.3381740930015473, 2.3237415997262123, 2.3087798293105424, 2.293293042031498, 2.277285665413396, 2.260762295440604, 2.2437276979222256, 2.226186810025738, 2.2081447419984097, 2.1896067790973817, 2.170578383751627, 2.151065197981603, 2.1310730461053584, 2.110607937763134, 2.08967607129626, 2.0682838375203354, 2.046437823937468, 2.0241448194377307, 2.0014118195461585, 1.978246032278561, 1.9546548846773701, 1.9306460301078228, 1.906227356405099, 1.881406994974894, 1.8561933309634568, 1.8305950146287124, 1.804620974061955, 1.7782804294302412, 1.7515829089333326, 1.7245382666965212, 1.697156702852367, 1.6694487861011824, 1.641425479082723, 1.6130981669411042, 1.584478689522587, 1.5555793777129787, 1.5264130944996412, 1.4969932814343714, 1.4673340112800046, 1.4374500477481111, 1.4073569133806059, 1.3770709667980068, 1.3466094907353843, 1.315990792518169, 1.285234318898796, 1.2543607874867795, 1.2233923373644102, 1.1923527018925615, 1.1612674071796487, 1.1301640002126287, 1.099072311228743, 1.068024755529675, 1.0370566805830852, 1.0062067648784168, 0.9755174755339293, 0.945035591976432, 0.9148128029570904, 0.8849063834579849, 0.8553799562895695, 0.8263043398113048, 0.797758477436201, 0.7698304353450692, 0.7426184407887607, 0.716231912907616, 0.6907924095135087, 0.6664343755429825, 0.6433055319754889, 0.6215666907373535, 0.6013907290853966, 0.5829604208603095, 0.5664648249908265, 0.5520940037997788, 0.540032014490757, 0.5304484000483831, 0.5234887767064987, 0.5192654961487824, 0.5178496248983072, 0.5192654961487854, 0.5234887767065046, 0.5304484000483916, 0.5400320144907682, 0.5520940037997925, 0.5664648249908422, 0.5829604208603275, 0.6013907290854165, 0.621566690737375, 0.643305531975512, 0.666434375543007, 0.6907924095135344, 0.7162319129076425, 0.7426184407887881, 0.7698304353450977, 0.7977584774362301, 0.8263043398113344, 0.8553799562895995, 0.8849063834580154, 0.9148128029571212, 0.9450355919764633, 0.9755174755339608, 1.0062067648784483, 1.037056680583117, 1.0680247555297067, 1.099072311228775, 1.1301640002126607, 1.1612674071796807, 1.1923527018925935, 1.2233923373644422, 1.2543607874868115, 1.2852343188988278, 1.3159907925182008, 1.3466094907354158, 1.3770709667980379, 1.4073569133806367, 1.437450047748142, 1.4673340112800348, 1.4969932814344016, 1.5264130944996717, 1.5555793777130087, 1.5844786895226164, 1.6130981669411333, 1.6414254790827516, 1.6694487861012115, 1.6971567028523955, 1.7245382666965494, 1.75158290893336, 1.778280429430268, 1.804620974061982, 1.8305950146287386, 1.8561933309634826, 1.8814069949749195, 1.9062273564051246, 1.9306460301078479, 1.9546548846773948, 1.978246032278585, 2.001411819546182, 2.0241448194377534, 2.0464378239374907, 2.0682838375203576, 2.0896760712962816, 2.1106079377631555, 2.1310730461053797, 2.151065197981623, 2.1705783837516464, 2.189606779097401, 2.208144741998429, 2.2261868100257565, 2.243727697922243, 2.2607622954406215, 2.2772856654134124, 2.293293042031514, 2.308779829310558, 2.323741599726228, 2.338174093001562, 2.35207321503092, 2.365435036926782, 2.3782557941768596, 2.390531885900217, 2.4022598741921497, 2.4134364835485522, 2.424058600361374, 2.434123272477566, 2.4436277088146143, 2.4525692790264473, 2.4609455132140483, 2.4687541016756978, 2.4759928946922285, 2.4826599023431535, 2.4887532943499266, 2.494271399943016, 2.4992127077497845, 2.503575865700547, 2.507359680950459, 2.510563119815194, 2.5131853077186577, 2.515225529151209, 2.5166832276371616, 2.517558005710539], [2.4909940809733033, 2.4907045330518467, 2.4898359674878137, 2.488388618883895, 2.4863628782502745, 2.48375929301353, 2.480578567029813, 2.4768215606030264, 2.472489290508925, 2.4675829300263272, 2.462103808976792, 2.4560534137744283, 2.449433387487711, 2.4422455299154695, 2.434491797679506, 2.4261743043366004, 2.4172953205130017, 2.407857274064854, 2.397862750268413, 2.387314492044307, 2.3762154002205875, 2.3645685338397806, 2.3523771105157505, 2.3396445068467506, 2.3263742588917355, 2.3125700627177266, 2.298235775026857, 2.2833754138726157, 2.2679931594758083, 2.252093355151895, 2.2356805083625684, 2.2187592919058625, 2.201334545260605, 2.1834112761027664, 2.1649946620132146, 2.1460900523985496, 2.1267029706491565, 2.106839116561377, 2.086504369053814, 2.065704789211308, 2.044446623694109, 2.022736308554271, 2.0005804735064467, 1.9779859467060428, 1.9549597600943882, 1.9315091553780674, 1.9076415907182749, 1.8833647482158984, 1.8586865422893897, 1.833615129055509, 1.8081589168379832, 1.7823265779463917, 1.7561270618874802, 1.729569610194142, 1.7026637730839491, 1.6754194281900439, 1.647846801643135, 1.6199564918251654, 1.591759496163979, 1.5632672413952544, 1.5344916177845498, 1.5054450178802827, 1.476140380459891, 1.4465912404387606, 1.4168117856376277, 1.3868169214524535, 1.356622344645259, 1.3262446276796367, 1.2957013152660226, 1.2650110350653456, 1.2341936248321035, 1.2032702786666434, 1.1722637154989892, 1.1411983734503635, 1.1101006343196451, 1.0789990831235765, 1.0479248083791841, 1.0169117496423905, 0.9859970996796316, 0.9552217694945979, 0.9246309251639879, 0.8942746058953791, 0.8642084326538679, 0.834494415721298, 0.8052018670667613, 0.7764084185663972, 0.7482011387131424, 0.7206777268835503, 0.6939477434236265, 0.6681338034071571, 0.6433726196239726, 0.6198157248866877, 0.5976296365120494, 0.5769951536308704, 0.5581054165001744, 0.5411623340432717, 0.5263710415322794, 0.5139322296313581, 0.504032519192909, 0.49683352745046633, 0.49246078831703244, 0.49099408097330355, 0.49246078831703544, 0.49683352745047227, 0.5040325191929179, 0.5139322296313696, 0.5263710415322934, 0.5411623340432881, 0.5581054165001929, 0.5769951536308908, 0.5976296365120715, 0.6198157248867111, 0.6433726196239977, 0.6681338034071831, 0.6939477434236535, 0.7206777268835781, 0.748201138713171, 0.7764084185664264, 0.8052018670667912, 0.8344944157213283, 0.8642084326538987, 0.8942746058954101, 0.9246309251640193, 0.9552217694946296, 0.9859970996796632, 1.0169117496424225, 1.0479248083792159, 1.0789990831236083, 1.1101006343196769, 1.1411983734503954, 1.172263715499021, 1.2032702786666751, 1.2341936248321355, 1.2650110350653774, 1.2957013152660541, 1.3262446276796678, 1.35662234464529, 1.3868169214524844, 1.4168117856376585, 1.4465912404387913, 1.476140380459921, 1.505445017880313, 1.5344916177845798, 1.5632672413952835, 1.5917594961640082, 1.619956491825194, 1.6478468016431636, 1.675419428190072, 1.7026637730839769, 1.7295696101941695, 1.7561270618875076, 1.7823265779464186, 1.8081589168380097, 1.8336151290555347, 1.8586865422894154, 1.8833647482159237, 1.9076415907182998, 1.9315091553780916, 1.954959760094412, 1.9779859467060663, 2.0005804735064694, 2.022736308554294, 2.0444466236941308, 2.06570478921133, 2.086504369053835, 2.106839116561398, 2.126702970649177, 2.146090052398569, 2.1649946620132337, 2.1834112761027846, 2.201334545260623, 2.2187592919058807, 2.235680508362585, 2.252093355151912, 2.2679931594758247, 2.2833754138726308, 2.298235775026872, 2.3125700627177403, 2.3263742588917493, 2.3396445068467644, 2.3523771105157634, 2.3645685338397926, 2.376215400220599, 2.387314492044318, 2.3978627502684233, 2.407857274064864, 2.4172953205130105, 2.4261743043366093, 2.4344917976795144, 2.442245529915477, 2.4494333874877174, 2.456053413774435, 2.4621038089767975, 2.467582930026333, 2.47248929050893, 2.4768215606030304, 2.480578567029817, 2.4837592930135326, 2.4863628782502762, 2.488388618883897, 2.489835967487814, 2.4907045330518476], [2.463663531985308, 2.4633761383305512, 2.462514034268815, 2.461077450507829, 2.459066771560991, 2.4564825357484668, 2.453325435199379, 2.449596315855766, 2.4452961774791464, 2.4404261736607777, 2.4349876118368723, 2.428981953310281, 2.422410813280382, 2.4152759608831538, 2.407579319243706, 2.3993229655437913, 2.390509131107149, 2.3811402015058576, 2.3712187166912466, 2.3607473711532667, 2.3497290141127, 2.3381666497510083, 2.3260634374831586, 2.3134226922793153, 2.3002478850418973, 2.2865426430452076, 2.2723107504455733, 2.2575561488707776, 2.2422829380985116, 2.226495376834589, 2.2101978836028215, 2.193395037759771, 2.176091580648991, 2.1582924169110154, 2.140002615967158, 2.1212274136972082, 2.10197221433342, 2.0822425925957506, 2.0620442960962446, 2.0413832480437333, 2.020265550283779, 1.998697486713019, 1.9766855271118742, 1.9542363314451061, 1.9313567546859258, 1.9080538522265176, 1.8843348859460372, 1.86020733101649, 1.8356788835376827, 1.8107574691048294, 1.7854512524266541, 1.759768648128344, 1.733718332892757, 1.7073092591154113, 1.6805506702744417, 1.65345211824658, 1.6260234828350155, 1.5982749938156504, 1.5702172558558074, 1.5418612767151987, 1.5132184992044047, 1.4843008374530908, 1.455120718130901, 1.425691127370973, 1.3960256642725086, 1.3661386020084612, 1.336044957741627, 1.305760572762516, 1.2753022045114564, 1.2446876324427547, 1.2139357800387085, 1.1830668556953938, 1.1521025156910212, 1.121066053022605, 1.089982616569239, 1.0588794658207603, 1.0277862673062033, 0.9967354398674017, 0.9657625570369296, 0.9349068159615782, 0.9042115834911286, 0.873725031096367, 0.8435008709659574, 0.8135992055923523, 0.7840875018134352, 0.7550416967431254, 0.7265474359885522, 0.698701432142091, 0.6716129112125211, 0.6454050832071881, 0.6202165268842551, 0.5962023145949414, 0.5735346202617746, 0.5524024566683953, 0.5330100928437123, 0.515573640454186, 0.5003153218623142, 0.4874551084274461, 0.47719980336259293, 0.469730242539843, 0.4651879951493533, 0.46366353198530824, 0.46518799514935644, 0.4697302425398492, 0.4771998033626021, 0.48745510842745804, 0.5003153218623287, 0.5155736404542027, 0.5330100928437312, 0.5524024566684161, 0.5735346202617971, 0.5962023145949655, 0.6202165268842804, 0.6454050832072145, 0.6716129112125484, 0.6987014321421191, 0.7265474359885811, 0.755041696743155, 0.7840875018134652, 0.8135992055923831, 0.8435008709659882, 0.8737250310963981, 0.90421158349116, 0.93490681596161, 0.9657625570369611, 0.9967354398674334, 1.027786267306235, 1.058879465820792, 1.089982616569271, 1.121066053022637, 1.152102515691053, 1.1830668556954256, 1.2139357800387403, 1.2446876324427862, 1.275302204511488, 1.3057605727625472, 1.336044957741658, 1.3661386020084918, 1.396025664272539, 1.4256911273710031, 1.4551207181309311, 1.4843008374531212, 1.5132184992044342, 1.541861276715228, 1.5702172558558363, 1.598274993815679, 1.626023482835044, 1.6534521182466082, 1.6805506702744692, 1.7073092591154384, 1.7337183328927839, 1.7597686481283707, 1.7854512524266803, 1.810757469104855, 1.835678883537708, 1.860207331016515, 1.884334885946062, 1.9080538522265418, 1.9313567546859496, 1.9542363314451296, 1.9766855271118966, 1.9986974867130414, 2.0202655502838014, 2.0413832480437546, 2.062044296096265, 2.082242592595771, 2.10197221433344, 2.121227413697228, 2.1400026159671772, 2.1582924169110345, 2.1760915806490093, 2.1933950377597884, 2.210197883602838, 2.226495376834605, 2.242282938098528, 2.2575561488707927, 2.272310750445588, 2.2865426430452223, 2.300247885041911, 2.3134226922793286, 2.3260634374831715, 2.33816664975102, 2.3497290141127114, 2.360747371153278, 2.3712187166912573, 2.3811402015058674, 2.390509131107158, 2.3993229655438006, 2.4075793192437134, 2.415275960883161, 2.4224108132803885, 2.428981953310288, 2.4349876118368785, 2.440426173660783, 2.4452961774791513, 2.44959631585577, 2.453325435199383, 2.4564825357484694, 2.4590667715609937, 2.46107745050783, 2.4625140342688154, 2.4633761383305517], [2.4358844184753514, 2.435599263986433, 2.4347438761194473, 2.4333184816723055, 2.431323458636922, 2.428759336192618, 2.425626794697468, 2.4219266656782192, 2.417659931819549, 2.4128277269536382, 2.407431336051226, 2.4014721952155136, 2.3949518916805084, 2.387872163815602, 2.3802349011384667, 2.372042144338554, 2.363296085313821, 2.3539990672235573, 2.344153584560559, 2.3337622832462173, 2.322827960752503, 2.311353566255246, 2.2993422008235624, 2.2867971176508317, 2.2737217223331423, 2.260119573201802, 2.245994381717171, 2.2313500129318387, 2.216190486032064, 2.2005199749672912, 2.1843428091786627, 2.1676634744386094, 2.1504866138149454, 2.1328170287743644, 2.1146596804419198, 2.096019691034949, 2.0769023454920155, 2.057313093319837, 2.037257550683876, 2.01674150277132, 1.995770906458648, 1.9743518933199498, 1.95249077301661, 1.9301940371141257, 1.9074683633776528, 1.8843206206045573, 1.8607578740599355, 1.8367873915898472, 1.8124166504971428, 1.7876533452764485, 1.7625053963183368, 1.7369809597083363, 1.7110884382645082, 1.6848364939783531, 1.6582340620482736, 1.6312903667233802, 1.6040149392087995, 1.5764176379227466, 1.548508671441534, 1.5202986245226806, 1.4917984876599395, 1.4630196906992674, 1.4339741411337348, 1.404674267800933, 1.3751330708318084, 1.3453641788491033, 1.315381914591467, 1.2852013703516796, 1.2548384948712126, 1.224310193636926, 1.1936344448889258, 1.1628304340831588, 1.1319187100717574, 1.1009213668839049, 1.0698622557271786, 1.0387672327020465, 1.0076644487480277, 0.9765846895333633, 0.9455617743671828, 0.9146330247440355, 0.8838398147853079, 0.853228217528545, 0.8228497625557016, 0.792762321526732, 0.7630311382579315, 0.733730018181718, 0.7049426869769839, 0.6767643177967729, 0.6493032078429702, 0.622682553936221, 0.597042228026931, 0.5725403816668249, 0.5493546090498588, 0.5276822723143895, 0.5077394533787666, 0.48975787822788, 0.47397912749168836, 0.4606455968772346, 0.4499881033900563, 0.4422107915230523, 0.43747497266625884, 0.4358844184753516, 0.4374749726662622, 0.4422107915230588, 0.4499881033900658, 0.46064559687724704, 0.4739791274917034, 0.4897578782278973, 0.5077394533787861, 0.5276822723144109, 0.549354609049882, 0.5725403816668494, 0.5970422280269568, 0.6226825539362479, 0.6493032078429981, 0.6767643177968016, 0.7049426869770133, 0.7337300181817478, 0.763031138257962, 0.7927623215267627, 0.8228497625557327, 0.8532282175285762, 0.8838398147853395, 0.9146330247440673, 0.9455617743672147, 0.9765846895333953, 1.00766444874806, 1.0387672327020787, 1.0698622557272106, 1.1009213668839368, 1.1319187100717891, 1.1628304340831905, 1.1936344448889578, 1.2243101936369576, 1.254838494871244, 1.2852013703517107, 1.3153819145914978, 1.345364178849134, 1.375133070831839, 1.4046742678009634, 1.4339741411337648, 1.4630196906992972, 1.491798487659969, 1.5202986245227097, 1.548508671441563, 1.576417637922775, 1.6040149392088277, 1.6312903667234082, 1.658234062048301, 1.68483649397838, 1.7110884382645353, 1.736980959708363, 1.7625053963183628, 1.7876533452764742, 1.8124166504971682, 1.8367873915898718, 1.8607578740599597, 1.8843206206045808, 1.9074683633776761, 1.9301940371141488, 1.9524907730166323, 1.9743518933199717, 1.9957709064586697, 2.0167415027713416, 2.0372575506838975, 2.0573130933198573, 2.076902345492035, 2.0960196910349684, 2.114659680441939, 2.132817028774383, 2.1504866138149636, 2.167663474438627, 2.1843428091786796, 2.200519974967308, 2.21619048603208, 2.2313500129318533, 2.245994381717185, 2.2601195732018167, 2.273721722333156, 2.2867971176508446, 2.299342200823575, 2.3113535662552573, 2.3228279607525146, 2.333762283246228, 2.3441535845605697, 2.353999067223567, 2.3632960853138303, 2.372042144338563, 2.3802349011384747, 2.3878721638156097, 2.394951891680515, 2.4014721952155202, 2.407431336051231, 2.412827726953643, 2.417659931819554, 2.4219266656782237, 2.4256267946974717, 2.428759336192621, 2.431323458636925, 2.4333184816723064, 2.4347438761194478, 2.435599263986433], [2.4076836149416687, 2.407400786465547, 2.4065523753326272, 2.4051386044263503, 2.403159845209497, 2.400616617710043, 2.3975095905018775, 2.3938395806809614, 2.389607553837598, 2.384814624025728, 2.379462053730274, 2.3735512538337855, 2.3670837835838103, 2.360061350562627, 2.352485810661194, 2.3443591680594213, 2.335683575215078, 2.3264613328639934, 2.3166948900344293, 2.3063868440788897, 2.295539940726942, 2.28415707416303, 2.2722412871336792, 2.2597957710889585, 2.2468238663635822, 2.233329062403588, 2.2193149980451876, 2.204785461853048, 2.189744392526068, 2.174195879379569, 2.1581441629137816, 2.1415936354795964, 2.1245488420537653, 2.1070144811370795, 2.088995405790594, 2.070496624826683, 2.0515233041736436, 2.032080768434768, 2.0121745026652667, 1.9918101543932554, 1.9709935359141866, 1.9497306268917607, 1.928027577302463, 1.9058907107656167, 1.8833265283062337, 1.8603417126041346, 1.8369431327899108, 1.8131378498564954, 1.788933122764502, 1.7643364153303995, 1.7393554039991617, 1.7139979866176496, 1.688272292341943, 1.6621866928316118, 1.6357498149069771, 1.6089705548724107, 1.5818580947403473, 1.554421920627869, 1.5266718436415139, 1.4986180236176398, 1.4702709961468692, 1.441641703383659, 1.412741529228317, 1.383582339571532, 1.354176528414228, 1.3245370708224453, 1.2946775838531241, 1.2646123967984186, 1.2343566323510782, 1.2039263006008534, 1.1733384081430804, 1.142611085029209, 1.111763732831466, 1.080817197749507, 1.0497939734785577, 1.0187184395121867, 0.9876171416971087, 0.9565191232220408, 0.9254563158350141, 0.8944640029624126, 0.8635813685469649, 0.8328521477896366, 0.8023253984576852, 0.7720564137670443, 0.7421077996080876, 0.7125507392607048, 0.6834664663948098, 0.6549479599084291, 0.6271018586569348, 0.600050565406803, 0.5739344605218766, 0.5489140683278052, 0.5251719038405442, 0.5029135693066624, 0.4823674755989215, 0.46378236598861367, 0.4474216963054832, 0.43355400808105604, 0.42243888676180524, 0.41430904447208855, 0.40935042796552285, 0.4076836149416689, 0.4093504279655262, 0.4143090444720953, 0.4224388867618152, 0.433554008081069, 0.44742169630549883, 0.4637823659886316, 0.48236747559894166, 0.5029135693066845, 0.5251719038405679, 0.5489140683278303, 0.5739344605219029, 0.6000505654068302, 0.627101858656963, 0.654947959908458, 0.6834664663948394, 0.7125507392607348, 0.7421077996081182, 0.7720564137670751, 0.8023253984577166, 0.8328521477896679, 0.8635813685469964, 0.8944640029624443, 0.9254563158350461, 0.9565191232220728, 0.9876171416971407, 1.0187184395122186, 1.0497939734785895, 1.0808171977495387, 1.1117637328314978, 1.1426110850292406, 1.173338408143112, 1.2039263006008847, 1.2343566323511095, 1.26461239679845, 1.2946775838531548, 1.324537070822476, 1.3541765284142584, 1.3835823395715618, 1.412741529228347, 1.4416417033836888, 1.4702709961468987, 1.498618023617669, 1.5266718436415427, 1.5544219206278977, 1.5818580947403753, 1.6089705548724382, 1.6357498149070044, 1.6621866928316387, 1.6882722923419697, 1.713997986617676, 1.7393554039991876, 1.764336415330425, 1.788933122764527, 1.81313784985652, 1.836943132789935, 1.8603417126041581, 1.883326528306257, 1.9058907107656393, 1.9280275773024853, 1.9497306268917831, 1.9709935359142083, 1.9918101543932765, 2.0121745026652875, 2.0320807684347884, 2.0515233041736636, 2.0704966248267023, 2.088995405790613, 2.1070144811370977, 2.124548842053783, 2.1415936354796137, 2.158144162913798, 2.1741958793795857, 2.1897443925260838, 2.2047854618530627, 2.2193149980452023, 2.233329062403602, 2.246823866363596, 2.259795771088972, 2.2722412871336912, 2.2841570741630415, 2.2955399407269534, 2.3063868440789004, 2.316694890034439, 2.326461332864003, 2.3356835752150875, 2.3443591680594302, 2.3524858106612023, 2.360061350562634, 2.3670837835838174, 2.373551253833792, 2.3794620537302795, 2.3848146240257333, 2.3896075538376027, 2.393839580680966, 2.397509590501882, 2.400616617710046, 2.4031598452094998, 2.4051386044263516, 2.4065523753326286, 2.407400786465547], [2.379088403840359, 2.378807990217782, 2.3779668223431627, 2.3765651191914614, 2.3746032457064574, 2.372081712779245, 2.3690011772186144, 2.365362441713807, 2.361166454790265, 2.3564143107591686, 2.3511072496616934, 2.3452466572091, 2.3388340647199244, 2.3318711490557402, 2.3243597325571397, 2.3163017829818164, 2.307699413446834, 2.2985548823774185, 2.28887059346489, 2.2786490956366197, 2.267893083041222, 2.256605395052538, 2.244789016296344, 2.2324470767041373, 2.2195828515988123, 2.206199761817543, 2.192301373877774, 2.177891400192819, 2.162973699344287, 2.1475522764193347, 2.131631283421593, 2.115215019765617, 2.098307932865777, 2.0809146188317427, 2.0630398232840927, 2.0446884423051332, 2.0258655235417526, 2.0065762674791445, 1.9868260289064492, 1.966620318597931, 1.945964805236208, 1.924865317607326, 1.9033278471012725, 1.881358550555786, 1.8589637534862873, 1.8361499537503876, 1.8129238257019435, 1.789292224897132, 1.76526219342365, 1.7408409659341881, 1.7160359764769069, 1.6908548662291516, 1.6653054922563537, 1.6393959374364016, 1.613134521711232, 1.586529814852555, 1.5595906509582265, 1.5323261449306507, 1.5047457112298037, 1.4768590852422887, 1.4486763476657936, 1.4202079523773496, 1.3914647583362032, 1.3624580661707308, 1.3331996602172238, 1.303701856920806, 1.27397756068059, 1.2440403284290256, 1.2139044444873752, 1.18358500754547, 1.1530980319867874, 1.122460566234857, 1.091690831352905, 1.0608083838086655, 1.029834307148498, 0.9987914383431054, 0.9677046358109918, 0.9366010976410148, 0.9055107403719844, 0.8744666508959403, 0.8435056266757504, 0.8126688225271431, 0.7820025256789703, 0.7515590845605936, 0.7213980204525156, 0.6915873541289014, 0.6622051807175285, 0.6333415230985431, 0.6051004837341832, 0.5776026912329583, 0.5509879926671949, 0.5254182636739153, 0.5010800806889836, 0.4781868086711063, 0.4569793983798226, 0.4377248834036149, 0.42071130138394697, 0.40623770959162353, 0.3945983850149023, 0.38606144983546276, 0.3808440584936737, 0.37908840384035897, 0.3808440584936773, 0.38606144983546997, 0.3945983850149127, 0.406237709591637, 0.4207113013839632, 0.43772488340363347, 0.45697939837984336, 0.47818680867112895, 0.5010800806890079, 0.5254182636739408, 0.5509879926672218, 0.5776026912329861, 0.605100483734212, 0.6333415230985723, 0.6622051807175584, 0.6915873541289317, 0.7213980204525465, 0.7515590845606248, 0.7820025256790017, 0.8126688225271745, 0.843505626675782, 0.8744666508959722, 0.9055107403720164, 0.9366010976410469, 0.9677046358110236, 0.9987914383431373, 1.0298343071485299, 1.0608083838086972, 1.0916908313529368, 1.1224605662348883, 1.153098031986819, 1.1835850075455012, 1.2139044444874063, 1.2440403284290564, 1.273977560680621, 1.3037018569208367, 1.333199660217254, 1.3624580661707606, 1.3914647583362327, 1.4202079523773792, 1.4486763476658229, 1.4768590852423176, 1.5047457112298321, 1.532326144930679, 1.5595906509582547, 1.5865298148525824, 1.613134521711259, 1.6393959374364284, 1.6653054922563801, 1.6908548662291776, 1.7160359764769326, 1.7408409659342137, 1.765262193423675, 1.7892922248971566, 1.812923825701968, 1.836149953750411, 1.8589637534863102, 1.8813585505558086, 1.9033278471012944, 1.924865317607348, 1.9459648052362293, 1.966620318597952, 1.9868260289064696, 2.006576267479165, 2.0258655235417726, 2.0446884423051523, 2.0630398232841114, 2.080914618831761, 2.098307932865795, 2.115215019765634, 2.1316312834216093, 2.147552276419351, 2.1629736993443034, 2.177891400192834, 2.192301373877789, 2.206199761817557, 2.2195828515988256, 2.23244707670415, 2.244789016296356, 2.2566053950525498, 2.2678930830412334, 2.2786490956366303, 2.2888705934648996, 2.2985548823774278, 2.307699413446843, 2.3163017829818253, 2.324359732557147, 2.3318711490557478, 2.3388340647199315, 2.345246657209106, 2.3511072496616987, 2.356414310759173, 2.3611664547902698, 2.3653624417138115, 2.369001177218618, 2.3720817127792477, 2.37460324570646, 2.3765651191914627, 2.377966822343163, 2.378807990217783], [2.35012644919137, 2.3498485412991577, 2.349014889318964, 2.347625708334343, 2.3456813567986816, 2.343182336506617, 2.340129292554432, 2.3365230132898795, 2.3323644302519804, 2.3276546181014863, 2.3223947945428463, 2.316586320238635, 2.3102306987175925, 2.303329576277537, 2.2958847418846404, 2.2878981270707017, 2.279371805830266, 2.270307994519659, 2.260709051760232, 2.2505774783483754, 2.2399159171751277, 2.228727153158522, 2.217014113192141, 2.204779866113724, 2.192027622698079, 2.1787607356789906, 2.1649826998053396, 2.1506971519371807, 2.1359078711881563, 2.1206187791213242, 2.104833940006216, 2.0885575611458522, 2.071793993283371, 2.054547731099037, 2.036823413809618, 2.0186258258835, 1.9999598978864748, 1.9808307074749045, 1.9612434805549648, 1.9412035926289626, 1.9207165703523, 1.8997880933276248, 1.8784239961660834, 1.8566302708494462, 1.8344130694313334, 1.8117787071208415, 1.7887336657977497, 1.7652845980152594, 1.7414383315540456, 1.71720187460048, 1.6925824216324312, 1.6675873601083224, 1.6422242780694565, 1.61650097278239, 1.590425460567786, 1.5640059879853068, 1.5372510445713423, 1.5101693773586011, 1.4827700074447365, 1.4550622489225653, 1.4270557305384883, 1.3987604205103359, 1.3701866550133093, 1.341345170935804, 1.312247143619152, 1.2829042304311244, 1.2533286211877208, 1.2235330966382105, 1.1935310964729633, 1.1633367986129806, 1.132965211907518, 1.102432284818468, 1.0717550332282764, 1.0409516911983174, 1.0100418893597738, 0.9790468666799069, 0.9479897226635456, 0.9168957186838492, 0.8857926391609461, 0.8547112258061387, 0.8236857012150184, 0.7927544018153876, 0.7619605446236938, 0.7313531574427795, 0.7009882079124414, 0.6709299727976419, 0.6412526941530529, 0.6120425717166029, 0.5834001376905206, 0.5554430450685289, 0.5283092640635748, 0.5021606076669815, 0.47718637495532557, 0.45360668216808464, 0.4316747224229887, 0.41167675637674606, 0.39392816032314487, 0.3787635541855669, 0.366519291688535, 0.35750791231804374, 0.35198677612435086, 0.3501264491913699, 0.35198677612435475, 0.3575079123180513, 0.3665192916885459, 0.37876355418558105, 0.39392816032316197, 0.41167675637676543, 0.43167472242301025, 0.4536066821681082, 0.4771863749553505, 0.5021606076670078, 0.5283092640636023, 0.5554430450685572, 0.5834001376905495, 0.6120425717166326, 0.641252694153083, 0.6709299727976725, 0.7009882079124725, 0.7313531574428109, 0.7619605446237254, 0.7927544018154192, 0.8236857012150502, 0.8547112258061706, 0.8857926391609781, 0.9168957186838813, 0.9479897226635775, 0.979046866679939, 1.0100418893598058, 1.040951691198349, 1.071755033228308, 1.1024322848184995, 1.1329652119075493, 1.1633367986130119, 1.1935310964729942, 1.2235330966382414, 1.2533286211877515, 1.2829042304311546, 1.3122471436191823, 1.3413451709358335, 1.370186655013339, 1.3987604205103654, 1.4270557305385174, 1.455062248922594, 1.4827700074447647, 1.510169377358629, 1.5372510445713696, 1.564005987985334, 1.590425460567813, 1.6165009727824164, 1.6422242780694827, 1.6675873601083484, 1.692582421632457, 1.717201874600505, 1.74143833155407, 1.7652845980152834, 1.7887336657977733, 1.8117787071208649, 1.8344130694313565, 1.8566302708494686, 1.8784239961661056, 1.8997880933276468, 1.9207165703523212, 1.9412035926289835, 1.961243480554985, 1.9808307074749243, 1.9999598978864943, 2.018625825883519, 2.036823413809637, 2.054547731099055, 2.071793993283389, 2.088557561145869, 2.104833940006232, 2.1206187791213402, 2.1359078711881723, 2.1506971519371954, 2.1649826998053543, 2.1787607356790044, 2.1920276226980926, 2.2047798661137366, 2.2170141131921532, 2.228727153158534, 2.2399159171751397, 2.250577478348386, 2.260709051760242, 2.2703079945196687, 2.279371805830275, 2.28789812707071, 2.295884741884648, 2.3033295762775445, 2.3102306987175996, 2.316586320238642, 2.322394794542852, 2.3276546181014917, 2.332364430251985, 2.336523013289884, 2.3401292925544355, 2.34318233650662, 2.3456813567986843, 2.347625708334344, 2.349014889318965, 2.349848541299158], [2.3208257698153467, 2.3205504606043106, 2.319724603380472, 2.3183484093645106, 2.3164222305671953, 2.313946559754027, 2.3109220303961, 2.3073494166075657, 2.303229633070187, 2.298563734945566, 2.293352917775792, 2.2875985173733313, 2.281302009701162, 2.274465010744259, 2.2670892763737114, 2.259176702204905, 2.2507293234513703, 2.241749314776103, 2.2322389901423496, 2.222200802666076, 2.2116373444725888, 2.200551346560039, 2.188945678672824, 2.17682334918823, 2.164187505020017, 2.151041431543032, 2.1373885525433844, 2.123232430199173, 2.108576765097348, 2.093425396292827, 2.0777823014167165, 2.0616515968412052, 2.0450375379095647, 2.0279445192406347, 2.0103770751182535, 1.9923398799772931, 1.9738377489993402, 1.9548756388326103, 1.9354586484524454, 1.9155920201807461, 1.8952811408849757, 1.8745315433799763, 1.8533489080588128, 1.8317390647822782, 1.8097079950606194, 1.787261834565535, 1.764406876015732, 1.7411495724853054, 1.7174965411911962, 1.693454567824062, 1.6690306114963032, 1.644231810391965, 1.6190654882160829, 1.5935391615560761, 1.5676605482855022, 1.5414375771613225, 1.5148783987904777, 1.4879913981707817, 1.4607852090458433, 1.433268730355118, 1.4054511451096579, 1.3773419420834863, 1.348950940781915, 1.3202883202343336, 1.291364652263395, 1.262190940009389, 1.232778662643312, 1.2031398273914566, 1.173287030226807, 1.1432335268690101, 1.1129933160889505, 1.0825812377535575, 1.0520130885938603, 1.0213057593630699, 0.9904773979082444, 0.9595476037555775, 0.928537661165058, 0.8974708193205012, 0.8663726304803927, 0.8352713596407747, 0.8041984826952728, 0.7731892943845113, 0.7422836526873205, 0.7115268928894009, 0.6809709524770171, 0.6506757571730515, 0.6207109283967516, 0.5911578819299531, 0.5621123938472687, 0.5336877073252008, 0.5060182326042485, 0.479263834381288, 0.45361457737784777, 0.42929556923402823, 0.4065711476449374, 0.3857470645987657, 0.3671685539627527, 0.3512114436499713, 0.33826333116914303, 0.32869315917419645, 0.3228110719999002, 0.3208257698153465, 0.3228110719999043, 0.32869315917420444, 0.33826333116915464, 0.35121144364998635, 0.36716855396277065, 0.38574706459878594, 0.4065711476449598, 0.42929556923405243, 0.45361457737787336, 0.4792638343813149, 0.5060182326042765, 0.5336877073252296, 0.5621123938472983, 0.5911578819299832, 0.6207109283967821, 0.6506757571730823, 0.6809709524770484, 0.7115268928894323, 0.7422836526873523, 0.7731892943845431, 0.8041984826953047, 0.8352713596408066, 0.8663726304804246, 0.8974708193205331, 0.9285376611650901, 0.9595476037556091, 0.990477397908276, 1.0213057593631016, 1.0520130885938916, 1.0825812377535888, 1.1129933160889818, 1.1432335268690412, 1.1732870302268377, 1.2031398273914875, 1.2327786626433426, 1.262190940009419, 1.291364652263425, 1.3202883202343632, 1.3489509407819442, 1.3773419420835156, 1.4054511451096867, 1.4332687303551461, 1.4607852090458715, 1.4879913981708095, 1.514878398790505, 1.5414375771613493, 1.5676605482855288, 1.5935391615561023, 1.619065488216109, 1.6442318103919908, 1.6690306114963285, 1.6934545678240867, 1.7174965411912206, 1.7411495724853296, 1.7644068760157559, 1.7872618345655582, 1.809707995060642, 1.8317390647823009, 1.8533489080588346, 1.8745315433799976, 1.8952811408849968, 1.9155920201807668, 1.9354586484524658, 1.9548756388326303, 1.9738377489993593, 1.9923398799773115, 2.010377075118272, 2.0279445192406524, 2.045037537909582, 2.061651596841222, 2.077782301416733, 2.0934253962928424, 2.1085767650973635, 2.123232430199188, 2.137388552543399, 2.151041431543047, 2.16418750502003, 2.176823349188242, 2.188945678672836, 2.2005513465600504, 2.2116373444725994, 2.2222008026660864, 2.23223899014236, 2.2417493147761127, 2.2507293234513788, 2.259176702204913, 2.267089276373719, 2.274465010744266, 2.2813020097011685, 2.287598517373338, 2.2933529177757976, 2.2985637349455708, 2.3032296330701914, 2.3073494166075696, 2.3109220303961036, 2.3139465597540307, 2.316422230567198, 2.318348409364512, 2.3197246033804735, 2.320550460604311], [2.2912147122272306, 2.2909420967550034, 2.2901243194738483, 2.288761587781947, 2.286854247314998, 2.2844027819044554, 2.281407813519393, 2.277870102192298, 2.273790545929216, 2.269170180604759, 2.264010179842595, 2.258311854882145, 2.2520766544323254, 2.245306164513295, 2.2380021082872963, 2.2301663458798178, 2.2218008741924504, 2.212907826708972, 2.2034894732963806, 2.1935482200027523, 2.1830866088540546, 2.1721073176522325, 2.1606131597771516, 2.14860708399526, 2.136092174278119, 2.1230716496343143, 2.1095488639585893, 2.0955273059025186, 2.081010598771428, 2.066002500452853, 2.050506903382349, 2.0345278345531512, 2.018069455576888, 2.0011360628033716, 1.9837320875084221, 1.965862096159705, 1.9475307907717547, 1.9287430093626823, 1.9095037265265826, 1.8898180541373928, 1.8696912422019023, 1.8491286798818865, 1.8281358967078882, 1.8067185640101484, 1.7848824965955632, 1.7626336547034689, 1.7399781462775776, 1.7169222295966124, 1.693472316312253, 1.6696349749500758, 1.6454169349373806, 1.6208250912314177, 1.595866509632782, 1.570548432881989, 1.5448782876528027, 1.5188636925743215, 1.4925124674356167, 1.465832643752638, 1.4388324769079848, 1.4115204601110483, 1.3839053404703416, 1.3559961375231002, 1.3278021646316212, 1.299333053733782, 1.2705987840300517, 1.2416097153050978, 1.2123766267239873, 1.182910762117558, 1.1532238829871175, 1.123328330726003, 1.09323709988846, 1.0629639247525746, 1.0325233819466881, 1.0019310125677567, 0.9712034680544555, 0.9403586851383329, 0.9094160965493756, 0.878396885884648, 0.8473242972731624, 0.8162240133332669, 0.7851246186088534, 0.7540581704259819, 0.723060905226409, 0.6921741162569697, 0.6614452484025054, 0.6309292682874562, 0.6006903826840755, 0.5708041953644859, 0.5413604102099444, 0.5124662025002124, 0.48425038176841045, 0.4568684402682984, 0.43050848725461094, 0.4053978532096673, 0.3818097218282178, 0.3600684026081096, 0.3405507248139088, 0.3236796528690784, 0.3099052442892084, 0.29966892981846016, 0.2933516242666591, 0.29121471222723055, 0.2933516242666635, 0.2996689298184687, 0.30990524428922084, 0.3236796528690943, 0.3405507248139276, 0.3600684026081308, 0.3818097218282411, 0.40539785320969235, 0.4305084872546374, 0.4568684402683261, 0.484250381768439, 0.5124662025002417, 0.5413604102099744, 0.5708041953645163, 0.6006903826841065, 0.6309292682874875, 0.6614452484025369, 0.6921741162570013, 0.7230609052264408, 0.7540581704260138, 0.7851246186088854, 0.8162240133332989, 0.8473242972731944, 0.8783968858846798, 0.9094160965494075, 0.9403586851383646, 0.9712034680544871, 1.0019310125677883, 1.0325233819467194, 1.0629639247526057, 1.0932370998884908, 1.1233283307260336, 1.1532238829871482, 1.1829107621175887, 1.2123766267240175, 1.2416097153051278, 1.2705987840300814, 1.2993330537338112, 1.3278021646316502, 1.3559961375231293, 1.3839053404703703, 1.4115204601110767, 1.4388324769080125, 1.465832643752666, 1.492512467435644, 1.5188636925743486, 1.5448782876528293, 1.570548432882015, 1.595866509632808, 1.620825091231443, 1.645416934937406, 1.6696349749501003, 1.693472316312277, 1.7169222295966362, 1.7399781462776012, 1.7626336547034915, 1.7848824965955858, 1.8067185640101708, 1.8281358967079098, 1.8491286798819078, 1.8696912422019234, 1.8898180541374137, 1.9095037265266026, 1.928743009362702, 1.9475307907717738, 1.9658620961597233, 1.9837320875084403, 2.0011360628033894, 2.018069455576905, 2.034527834553168, 2.0505069033823653, 2.066002500452869, 2.081010598771443, 2.0955273059025328, 2.1095488639586035, 2.1230716496343276, 2.1360921742781325, 2.1486070839952722, 2.160613159777164, 2.172107317652244, 2.1830866088540657, 2.1935482200027625, 2.2034894732963903, 2.2129078267089817, 2.2218008741924584, 2.230166345879826, 2.2380021082873043, 2.245306164513303, 2.2520766544323316, 2.2583118548821512, 2.2640101798426007, 2.2691701806047644, 2.2737905459292205, 2.277870102192302, 2.281407813519396, 2.284402781904458, 2.2868542473150004, 2.2887615877819494, 2.290124319473849, 2.2909420967550043], [2.2613219232128388, 2.261052098670769, 2.2602426929238297, 2.2588939096002534, 2.257006088048534, 2.2545797032897212, 2.2516153659508977, 2.248113822180107, 2.2440759535430828, 2.2395027769022113, 2.234395444278242, 2.228755242695358, 2.2225835940103136, 2.2158820547264284, 2.208652315793375, 2.200896202393768, 2.1926156737177194, 2.1838128227266336, 2.174489875907694, 2.16464919302061, 2.1542932668384065, 2.1434247228841925, 2.1320463191660814, 2.1201609459126534, 2.107771625311591, 2.0948815112544312, 2.0814938890906536, 2.0676121753946917, 2.053239917749843, 2.0383807945534658, 2.023038614848346, 2.0072173181856656, 1.9909209745255914, 1.9741537841822072, 1.9569200778202733, 1.9392243165121728, 1.921071091864393, 1.9024651262240122, 1.8834112729769314, 1.863914516951047, 1.8439799749392176, 1.8236128963587694, 1.802818664066457, 1.7816027953502895, 1.759970943122513, 1.7379288973413303, 1.715482586692793, 1.692638080568719, 1.669401591381654, 1.6457794772638967, 1.6217782452046139, 1.5974045546872813, 1.5726652218993094, 1.5475672245970542, 1.5221177077227868, 1.4963239898860248, 1.4701935708404443, 1.4437341401099724, 1.4169535869444219, 1.389860011817113, 1.3624617397155083, 1.3347673355224845, 1.3067856218423037, 1.2785256996940053, 1.2499969725787676, 1.2212091745305476, 1.1921724028858114, 1.1628971566645645, 1.1333943816490821, 1.1036755234889934, 1.073752590464945, 1.0436382279253291, 1.0133458068942793, 0.9828895299642044, 0.9522845583722703, 0.9215471651700232, 0.890694920698995, 0.8597469182765212, 0.8287240502009137, 0.7976493470723883, 0.7665483972219032, 0.7354498680463213, 0.7043861576648622, 0.6733942140600785, 0.6425165704084074, 0.611802660440474, 0.5813104972760597, 0.55110882400413, 0.5212798744398598, 0.4919229163099149, 0.4631587806709582, 0.43513559558291176, 0.40803590553031316, 0.38208520343551944, 0.35756150586634755, 0.33480476664537745, 0.3142234069395449, 0.29629294029139064, 0.2815391502536509, 0.27049761004323264, 0.26364634465734405, 0.2613219232128388, 0.2636463446573488, 0.27049761004324197, 0.28153915025366427, 0.29629294029140757, 0.3142234069395648, 0.33480476664539977, 0.35756150586637186, 0.3820852034355455, 0.4080359055303404, 0.4351355955829401, 0.4631587806709874, 0.4919229163099449, 0.5212798744398902, 0.5511088240041608, 0.5813104972760909, 0.6118026604405054, 0.642516570408439, 0.6733942140601102, 0.704386157664894, 0.7354498680463533, 0.766548397221935, 0.7976493470724203, 0.8287240502009455, 0.8597469182765531, 0.8906949206990269, 0.9215471651700549, 0.952284558372302, 0.9828895299642358, 1.0133458068943106, 1.04363822792536, 1.0737525904649756, 1.1036755234890243, 1.1333943816491125, 1.1628971566645947, 1.1921724028858414, 1.221209174530577, 1.249996972578797, 1.2785256996940344, 1.3067856218423328, 1.3347673355225131, 1.3624617397155367, 1.389860011817141, 1.4169535869444496, 1.4437341401099997, 1.4701935708404714, 1.4963239898860514, 1.5221177077228132, 1.5475672245970802, 1.5726652218993347, 1.5974045546873064, 1.6217782452046385, 1.6457794772639212, 1.669401591381678, 1.6926380805687427, 1.7154825866928163, 1.737928897341353, 1.7599709431225354, 1.7816027953503117, 1.8028186640664783, 1.8236128963587905, 1.843979974939238, 1.863914516951067, 1.8834112729769512, 1.902465126224032, 1.921071091864412, 1.9392243165121907, 1.956920077820291, 1.9741537841822245, 1.9909209745256082, 2.007217318185682, 2.023038614848362, 2.0383807945534813, 2.053239917749858, 2.067612175394706, 2.0814938890906673, 2.0948815112544454, 2.107771625311604, 2.1201609459126654, 2.1320463191660934, 2.1434247228842036, 2.1542932668384176, 2.1646491930206206, 2.174489875907703, 2.183812822726643, 2.1926156737177283, 2.2008962023937766, 2.208652315793382, 2.215882054726435, 2.2225835940103202, 2.2287552426953647, 2.234395444278247, 2.239502776902216, 2.244075953543087, 2.248113822180111, 2.2516153659509013, 2.254579703289724, 2.257006088048536, 2.2588939096002547, 2.2602426929238306, 2.2610520986707696], [2.2311763221149477, 2.2309093878481483, 2.230108651692398, 2.228774313570975, 2.2269067066538426, 2.224506297304493, 2.2215736850057617, 2.2181096022648163, 2.2141149144976087, 2.209590619893151, 2.204537849258031, 2.1989578658416757, 2.192852065142933, 2.186221974698632, 2.179069253854877, 2.171395693521901, 2.1632032159134473, 2.1544938742716977, 2.1452698525789575, 2.135533465257361, 2.1252871568580627, 2.114533501741497, 2.103275203750477, 2.091515095878078, 2.079256139932463, 2.066501426201036, 2.0532541731165628, 2.039517726928169, 2.025295561380455, 2.0105912774043113, 1.9954086028233975, 1.979751392080714, 1.9636236259901618, 1.947029411518565, 1.929972981604241, 1.912458695018933, 1.8944910362806988, 1.8760746156262935, 1.8572141690525956, 1.837914558437829, 1.818180771754678, 1.7980179233889453, 1.7774312545791757, 1.756426133994712, 1.7350080584720105, 1.7131826539317456, 1.690955676502394, 1.6683330138796337, 1.6453206869551316, 1.6219248517532623, 1.5981518017200715, 1.574007970415597, 1.5494999346686325, 1.5246344182624345, 1.499418296230987, 1.4738585998586393, 1.4479625224916284, 1.4217374262887374, 1.3951908500607826, 1.3683305183755996, 1.34116435213774, 1.3137004808914792, 1.2859472571436283, 1.2579132730610714, 1.229607379969556, 1.2010387111683893, 1.1722167086846282, 1.1431511547256463, 1.1138522087577936, 1.0843304513505987, 1.054596936192885, 1.0246632520254264, 0.9945415966658442, 0.9642448658538839, 0.9337867603573654, 0.9031819157026831, 0.8724460600988658, 0.8415962077065852, 0.8106508964943328, 0.7796304827040447, 0.7485575076677792, 0.7174571577224165, 0.6863578447419709, 0.6552919440133649, 0.6242967387378288, 0.5934156375885974, 0.5626997551336788, 0.532209976585664, 0.5020196705486509, 0.47221826804067923, 0.44291599262838516, 0.4142500977208591, 0.3863930185098688, 0.3595628146405218, 0.33403602292804924, 0.3101622710177559, 0.28837823344633323, 0.2692151409804246, 0.2532890274749414, 0.24125852092660144, 0.23373826277265083, 0.23117632211494746, 0.23373826277265605, 0.24125852092661162, 0.25328902747495596, 0.2692151409804428, 0.28837823344635444, 0.31016227101777943, 0.3340360229280747, 0.3595628146405488, 0.38639301850989693, 0.4142500977208881, 0.4429159926284151, 0.4722182680407096, 0.5020196705486818, 0.5322099765856951, 0.5626997551337102, 0.5934156375886289, 0.6242967387378606, 0.6552919440133967, 0.6863578447420029, 0.7174571577224483, 0.748557507667811, 0.7796304827040765, 0.8106508964943645, 0.8415962077066169, 0.8724460600988974, 0.9031819157027146, 0.9337867603573968, 0.9642448658539151, 0.9945415966658752, 1.024663252025457, 1.0545969361929157, 1.0843304513506293, 1.1138522087578238, 1.1431511547256765, 1.172216708684658, 1.2010387111684186, 1.2296073799695855, 1.2579132730611002, 1.2859472571436572, 1.3137004808915078, 1.3411643521377683, 1.3683305183756276, 1.3951908500608101, 1.4217374262887645, 1.447962522491655, 1.4738585998586657, 1.4994182962310132, 1.5246344182624605, 1.549499934668658, 1.5740079704156218, 1.5981518017200962, 1.6219248517532865, 1.645320686955155, 1.6683330138796575, 1.6909556765024174, 1.713182653931768, 1.7350080584720329, 1.7564261339947338, 1.7774312545791968, 1.7980179233889664, 1.8181807717546983, 1.837914558437849, 1.8572141690526154, 1.8760746156263128, 1.8944910362807177, 1.9124586950189513, 1.9299729816042588, 1.947029411518582, 1.9636236259901787, 1.9797513920807304, 1.995408602823413, 2.010591277404327, 2.02529556138047, 2.039517726928183, 2.0532541731165765, 2.0665014262010493, 2.0792561399324754, 2.09151509587809, 2.103275203750489, 2.114533501741508, 2.1252871568580733, 2.1355334652573714, 2.1452698525789673, 2.1544938742717066, 2.1632032159134553, 2.171395693521909, 2.179069253854884, 2.1862219746986393, 2.1928520651429393, 2.1989578658416815, 2.2045378492580365, 2.209590619893156, 2.2141149144976136, 2.21810960226482, 2.221573685005765, 2.2245062973044956, 2.226906706653845, 2.228774313570977, 2.230108651692399, 2.230909387848149], [2.200807072855696, 2.2005431303752183, 2.1997513683696606, 2.1984319831350216, 2.1965853017925676, 2.1942117822308176, 2.1913120130244974, 2.187886713330645, 2.183936732762079, 2.1794630512385362, 2.1744667788157925, 2.168949155493185, 2.1629115509999868, 2.1563554645611562, 2.149282524643064, 2.1416944886798674, 2.1335932427812723, 2.1249808014225295, 2.1158593071175913, 2.1062310300764597, 2.0960983678478677, 2.0854638449485567, 2.074330112480549, 2.062699947737957, 2.0505762538050303, 2.037962059147326, 2.0248605171980896, 2.0112749059421318, 1.9972086274997702, 1.9826652077136402, 1.9676482957415127, 1.9521616636585928, 1.936209206073155, 1.9197949397598202, 1.9029230033152544, 1.8855976568416501, 1.86782328166395, 1.8496043800875275, 1.830945575203823, 1.8118516107523803, 1.7923273510487934, 1.7723777809892816, 1.7520080061440249, 1.7312232529529785, 1.7100288690397718, 1.6884303236614076, 1.6664332083140003, 1.644043237517639, 1.6212662498068624, 1.5981082089571315, 1.5745752054822924, 1.5506734584434236, 1.5264093176157965, 1.501789266068207, 1.476819923217794, 1.4515080484340415, 1.4258605452782278, 1.3998844664796635, 1.3735870197680957, 1.3469755747034653, 1.320057670670491, 1.2928410262375296, 1.265333550118109, 1.2375433540211975, 1.2094787677348977, 1.1811483568606473, 1.1525609437048325, 1.123725631946761, 1.094651835842377, 1.0653493149000752, 1.035828215189282, 1.006099118728378, 0.9761731027652457, 0.9460618112369736, 0.9157775413100986, 0.8853333487070206, 0.8547431765837574, 0.8240220141303465, 0.7931860929456176, 0.76225313177247, 0.7312426436230927, 0.7001763240398889, 0.6690785457504688, 0.6379769940400476, 0.606903489878065, 0.575895065787688, 0.5449953849334804, 0.5142566301997963, 0.4837420416893244, 0.45352935405698547, 0.42371548629465383, 0.39442297127194503, 0.3658087761748317, 0.33807632234898355, 0.3114915441416491, 0.2864034113187981, 0.26326774804366343, 0.24266904291519736, 0.2253265806990873, 0.2120593544183678, 0.20367911969311972, 0.200807072855696, 0.20367911969312558, 0.21205935441837906, 0.22532658069910316, 0.24266904291521701, 0.263267748043686, 0.286403411318823, 0.31149154414167574, 0.33807632234901147, 0.3658087761748607, 0.3944229712719748, 0.42371548629468425, 0.45352935405701633, 0.48374204168935553, 0.5142566301998278, 0.5449953849335122, 0.5758950657877199, 0.6069034898780968, 0.6379769940400796, 0.6690785457505007, 0.7001763240399208, 0.7312426436231244, 0.7622531317725019, 0.7931860929456493, 0.8240220141303781, 0.854743176583789, 0.8853333487070518, 0.9157775413101298, 0.9460618112370048, 0.9761731027652766, 1.0060991187284085, 1.0358282151893123, 1.0653493149001056, 1.0946518358424069, 1.1237256319467908, 1.152560943704862, 1.1811483568606767, 1.2094787677349266, 1.2375433540212262, 1.2653335501181378, 1.2928410262375578, 1.3200576706705187, 1.3469755747034928, 1.3735870197681228, 1.3998844664796901, 1.4258605452782545, 1.4515080484340674, 1.4768199232178199, 1.5017892660682322, 1.5264093176158215, 1.5506734584434483, 1.5745752054823166, 1.5981082089571552, 1.621266249806886, 1.644043237517662, 1.666433208314023, 1.68843032366143, 1.7100288690397936, 1.7312232529530003, 1.7520080061440457, 1.7723777809893024, 1.7923273510488136, 1.8118516107524005, 1.8309455752038424, 1.8496043800875466, 1.8678232816639688, 1.8855976568416684, 1.9029230033152724, 1.9197949397598366, 1.9362092060731715, 1.9521616636586085, 1.967648295741528, 1.9826652077136553, 1.9972086274997853, 2.011274905942146, 2.0248605171981033, 2.0379620591473393, 2.050576253805043, 2.0626999477379693, 2.0743301124805607, 2.0854638449485674, 2.0960983678478784, 2.10623103007647, 2.115859307117601, 2.1249808014225384, 2.1335932427812807, 2.1416944886798754, 2.149282524643071, 2.1563554645611633, 2.162911550999993, 2.1689491554931912, 2.1744667788157974, 2.179463051238541, 2.183936732762084, 2.1878867133306494, 2.1913120130245014, 2.1942117822308203, 2.19658530179257, 2.198431983135023, 2.1997513683696615, 2.2005431303752188], [2.170243555722376, 2.169982708708371, 2.1692002319235852, 2.1678963181272315, 2.166071288543137, 2.16372559279751, 2.1608598088319546, 2.157474642791864, 2.153570928890367, 2.1491496292480545, 2.1442118337087335, 2.1387587596315316, 2.1327917516596955, 2.1263122814664914, 2.1193219474786678, 2.1118224745779894, 2.103815713781426, 2.0953036419006295, 2.0862883611814156, 2.0767720989240397, 2.066757207085134, 2.056246161862277, 2.045241563262253, 2.0337461346541725, 2.021762722308767, 2.0092942949252586, 1.9963439431474064, 1.9829148790704607, 1.9690104357409517, 1.9546340666514481, 1.9397893452326442, 1.9244799643453931, 1.908709735775596, 1.892482589735179, 1.8758025743727562, 1.8586738552980044, 1.8411007151242254, 1.823087553034128, 1.8046388843744632, 1.7857593402858352, 1.766453667374818, 1.7467267274364098, 1.7265834972359113, 1.7060290683605073, 1.685068647152243, 1.6637075547356672, 1.6419512271553103, 1.6198052156403082, 1.59727518701603, 1.5743669242855154, 1.5510863274069966, 1.5274394142978427, 1.503432322100076, 1.479071308748286, 1.4543627548874851, 1.4293131661964886, 1.40392917618195, 1.3782175495196585, 1.3521851860334966, 1.3258391254190958, 1.299186552839411, 1.2722348055439763, 1.2449913806936024, 1.217463944609103, 1.1896603437080266, 1.1615886174496248, 1.133257013678326, 1.104674006843651, 1.075848319684842, 1.0467889491081388, 1.0175051971624631, 0.9880067082471549, 0.9583035139793088, 0.9284060875299647, 0.8983254097377241, 0.8680730499664965, 0.8376612655484796, 0.8071031248248994, 0.7764126603802171, 0.7456050612248093, 0.7146969156545505, 0.683706520651319, 0.652654279500347, 0.6215632175558994, 0.5904596579423854, 0.5593741161922218, 0.5283424980888615, 0.49740772245182296, 0.46662194665944295, 0.4360496571170005, 0.40577201421349784, 0.37589303212871383, 0.3465484533545605, 0.3179185645063372, 0.29024666256412046, 0.2638652042127198, 0.23923109850635393, 0.2169680445793053, 0.19790278742323775, 0.18305822363980156, 0.17353674920942846, 0.17024355572237582, 0.17353674920943515, 0.1830582236398143, 0.19790278742325537, 0.21696804457932672, 0.23923109850637822, 0.2638652042127461, 0.2902466625641483, 0.31791856450636624, 0.34654845335459034, 0.37589303212874425, 0.4057720142135289, 0.4360496571170317, 0.4666219466594744, 0.49740772245185483, 0.5283424980888932, 0.5593741161922536, 0.5904596579424174, 0.6215632175559314, 0.652654279500379, 0.6837065206513507, 0.7146969156545823, 0.745605061224841, 0.7764126603802486, 0.8071031248249309, 0.8376612655485111, 0.8680730499665278, 0.8983254097377549, 0.9284060875299958, 0.9583035139793393, 0.9880067082471852, 1.0175051971624933, 1.0467889491081688, 1.0758483196848716, 1.1046740068436804, 1.1332570136783553, 1.161588617449654, 1.1896603437080553, 1.217463944609131, 1.2449913806936304, 1.2722348055440043, 1.2991865528394388, 1.3258391254191229, 1.3521851860335234, 1.3782175495196851, 1.403929176181976, 1.4293131661965146, 1.4543627548875107, 1.4790713087483114, 1.503432322100101, 1.527439414297867, 1.5510863274070208, 1.5743669242855391, 1.597275187016053, 1.619805215640331, 1.641951227155333, 1.6637075547356894, 1.6850686471522645, 1.7060290683605286, 1.7265834972359317, 1.7467267274364306, 1.7664536673748379, 1.7857593402858547, 1.8046388843744823, 1.8230875530341466, 1.8411007151242436, 1.858673855298022, 1.8758025743727735, 1.8924825897351956, 1.9087097357756124, 1.924479964345409, 1.9397893452326593, 1.9546340666514632, 1.9690104357409663, 1.982914879070475, 1.9963439431474204, 2.0092942949252715, 2.0217627223087797, 2.0337461346541845, 2.0452415632622643, 2.0562461618622883, 2.0667572070851445, 2.0767720989240495, 2.086288361181425, 2.0953036419006383, 2.103815713781435, 2.1118224745779974, 2.119321947478675, 2.1263122814664985, 2.1327917516597017, 2.138758759631537, 2.144211833708739, 2.1491496292480594, 2.1535709288903715, 2.1574746427918674, 2.1608598088319577, 2.1637255927975128, 2.1660712885431392, 2.1678963181272337, 2.1692002319235866, 2.169982708708372], [2.1395153389439, 2.13925769323853, 2.138484819235409, 2.1371969062603497, 2.135394269812521, 2.1330773514987214, 2.1302467189414616, 2.1269030656609584, 2.1230472109311704, 2.1186800996100383, 2.1138028019441215, 2.108416513347866, 2.102522554157757, 2.096122369361656, 2.089217528303673, 2.08180972436493, 2.073900774620667, 2.065492619474132, 2.056587322267803, 2.047187068872497, 2.037294167255016, 2.0269110470250244, 2.0160402589619344, 2.0046844745226453, 1.9928464853310748, 1.980529202650517, 1.9677356568399529, 1.9544689967955746, 1.9407324893788973, 1.9265295188329872, 1.9118635861884834, 1.8967383086612906, 1.8811574190439952, 1.8651247650933154, 1.8486443089161169, 1.83172012635686, 1.8143564063896247, 1.796557450518275, 1.7783276721887231, 1.7596715962177492, 1.7405938582433897, 1.7210992042025328, 1.7011924898421007, 1.6808786802710372, 1.6601628495612857, 1.6390501804070743, 1.617545963853123, 1.5956555991039172, 1.5733845934279418, 1.5507385621728766, 1.5277232289101432, 1.504344425730089, 1.480608093712453, 1.4565202836007523, 1.432087156713985, 1.4073149861346947, 1.3822101582192066, 1.3567791744839608, 1.3310286539316587, 1.3049653358927438, 1.2785960834721166, 1.2519278877084805, 1.2249678725751572, 1.1977233009775947, 1.1702015819353964, 1.1424102791772122, 1.1143571214274344, 1.0860500147271683, 1.0574970572121878, 1.0287065568725442, 0.9996870529488414, 0.9704473417879738, 0.9409965081986077, 0.9113439636306487, 0.8814994928766182, 0.851473311488666, 0.8212761367684706, 0.7909192760834819, 0.7604147374852119, 0.7297753692894374, 0.6990150376241978, 0.6681488542574414, 0.6371934717321541, 0.6061674696519027, 0.5750918659438099, 0.5439908017647396, 0.5128924711052603, 0.4818304004580236, 0.45084523734705645, 0.4199872910396109, 0.38932020448324617, 0.358926357168198, 0.32891495997180104, 0.2994343927043629, 0.27069127185572567, 0.24298010580290869, 0.21672892723412993, 0.19256616480760083, 0.17140536528373174, 0.15450920126827933, 0.1434117753067263, 0.13951533894389997, 0.1434117753067342, 0.15450920126829398, 0.17140536528375155, 0.19256616480762437, 0.216728927234156, 0.2429801058029365, 0.27069127185575476, 0.29943439270439287, 0.3289149599718316, 0.358926357168229, 0.38932020448327764, 0.4199872910396425, 0.4508452373470882, 0.4818304004580555, 0.5128924711052921, 0.5439908017647715, 0.5750918659438419, 0.6061674696519346, 0.6371934717321861, 0.6681488542574733, 0.6990150376242293, 0.729775369289469, 0.7604147374852434, 0.7909192760835131, 0.8212761367685016, 0.851473311488697, 0.881499492876649, 0.9113439636306794, 0.940996508198638, 0.9704473417880038, 0.9996870529488714, 1.0287065568725742, 1.057497057212217, 1.0860500147271974, 1.1143571214274632, 1.1424102791772408, 1.1702015819354248, 1.197723300977623, 1.2249678725751851, 1.2519278877085083, 1.2785960834721437, 1.3049653358927706, 1.3310286539316853, 1.356779174483987, 1.3822101582192325, 1.4073149861347205, 1.4320871567140103, 1.4565202836007771, 1.4806080937124777, 1.5043444257301133, 1.527723228910167, 1.5507385621729004, 1.5733845934279649, 1.5956555991039396, 1.6175459638531453, 1.639050180407096, 1.660162849561307, 1.6808786802710582, 1.7011924898421213, 1.721099204202553, 1.7405938582434095, 1.7596715962177687, 1.7783276721887418, 1.7965574505182937, 1.814356406389643, 1.8317201263568776, 1.8486443089161344, 1.865124765093332, 1.8811574190440117, 1.8967383086613063, 1.9118635861884985, 1.9265295188330018, 1.940732489378912, 1.9544689967955882, 1.9677356568399662, 1.9805292026505301, 1.9928464853310872, 2.004684474522657, 2.016040258961946, 2.026911047025035, 2.0372941672550264, 2.047187068872507, 2.0565873222678124, 2.0654926194741408, 2.073900774620675, 2.081809724364938, 2.0892175283036796, 2.0961223693616633, 2.1025225541577632, 2.1084165133478723, 2.113802801944127, 2.1186800996100428, 2.123047210931175, 2.1269030656609624, 2.130246718941465, 2.133077351498724, 2.1353942698125232, 2.1371969062603506, 2.13848481923541, 2.1392576932385303], [2.1086521500854514, 2.108397813674154, 2.1076348664477087, 2.1063634944147585, 2.104584007544061, 2.1022968396960513, 2.099502548527108, 2.0962018153665825, 2.092395445066694, 2.0880843658254036, 2.0832696289824026, 2.0779524087883794, 2.072134002147746, 2.065815828335041, 2.058999428685242, 2.0516864662582512, 2.0438787254778576, 2.035578111745495, 2.026786651029163, 2.0175064894279067, 2.007739892712297, 1.997489245841384, 1.9867570524566691, 1.9755459343536523, 1.9638586309316068, 1.9516979986222724, 1.9390670102982268, 1.9259687546617827, 1.9124064356153225, 1.8983833716140894, 1.883902995002554, 1.8689688513355796, 1.8535845986857509, 1.8377540069383684, 1.821480957075778, 1.8047694404528736, 1.7876235580658515, 1.7700475198164898, 1.7520456437745213, 1.7336223554409769, 1.7147821870156965, 1.6955297766726476, 1.6758698678471091, 1.6558073085393403, 1.6353470506399537, 1.614494149282907, 1.593253762232884, 1.571631149314754, 1.5496316718939407, 1.5272607924178327, 1.5045240740298973, 1.4814271802699694, 1.4579758748763316, 1.4341760217077058, 1.4100335848063117, 1.3855546286267149, 1.3607453184594887, 1.3356119210838744, 1.3101608056898426, 1.2843984451175061, 1.258331417470992, 1.2319664081750843, 1.205310212556682, 1.1783697390500474, 1.1511520131458088, 1.1236641822297886, 1.0959135214904405, 1.0679074411148495, 1.0396534950454057, 1.0111593916357313, 0.982433006629726, 0.9534823989977822, 0.9243158303076293, 0.8949417884953512, 0.8653690171508925, 0.8356065517642006, 0.8056637648249919, 0.7755504222767199, 0.7452767546602534, 0.7148535474430082, 0.6842922566609866, 0.6536051583255622, 0.6228055434037586, 0.5919079751009939, 0.5609286325022239, 0.5298857757264104, 0.4988003848744527, 0.4676970520027044, 0.4366052486841881, 0.40556116298449996, 0.3746104197546398, 0.3438122056264122, 0.3132456878772634, 0.2830202841535057, 0.2532925759512606, 0.2242949587181136, 0.19638527842528866, 0.17013328589069254, 0.14646504420861173, 0.1268639015328373, 0.1134805669365201, 0.10865215008545126, 0.11348056693652982, 0.12686390153285465, 0.1464650442086343, 0.1701332858907184, 0.19638527842531667, 0.2242949587181429, 0.2532925759512908, 0.2830202841535365, 0.3132456878772947, 0.3438122056264437, 0.37461041975467163, 0.4055611629845318, 0.43660524868422007, 0.46769705200273637, 0.4988003848744847, 0.5298857757264422, 0.5609286325022559, 0.5919079751010258, 0.6228055434037904, 0.6536051583255938, 0.6842922566610181, 0.7148535474430396, 0.7452767546602846, 0.7755504222767509, 0.8056637648250227, 0.8356065517642313, 0.8653690171509231, 0.8949417884953815, 0.9243158303076594, 0.9534823989978121, 0.9824330066297555, 1.0111593916357609, 1.039653495045435, 1.0679074411148783, 1.0959135214904692, 1.123664182229817, 1.1511520131458368, 1.1783697390500751, 1.2053102125567094, 1.2319664081751118, 1.258331417471019, 1.284398445117533, 1.310160805689869, 1.3356119210839006, 1.3607453184595144, 1.38555462862674, 1.4100335848063366, 1.4341760217077306, 1.457975874876356, 1.4814271802699934, 1.5045240740299208, 1.527260792417856, 1.5496316718939636, 1.5716311493147763, 1.5932537622329062, 1.6144941492829286, 1.635347050639975, 1.6558073085393612, 1.675869867847129, 1.6955297766726674, 1.7147821870157158, 1.7336223554409957, 1.7520456437745402, 1.7700475198165082, 1.7876235580658695, 1.8047694404528907, 1.8214809570757944, 1.837754006938385, 1.8535845986857669, 1.8689688513355953, 1.883902995002569, 1.8983833716141036, 1.9124064356153367, 1.925968754661797, 1.9390670102982406, 1.9516979986222855, 1.9638586309316188, 1.975545934353664, 1.9867570524566807, 1.9974892458413949, 2.0077398927123067, 2.017506489427917, 2.0267866510291723, 2.035578111745504, 2.0438787254778656, 2.051686466258259, 2.0589994286852495, 2.065815828335048, 2.072134002147752, 2.077952408788385, 2.083269628982408, 2.0880843658254085, 2.092395445066698, 2.096201815366586, 2.0995025485271115, 2.102296839696054, 2.1045840075440627, 2.1063634944147602, 2.10763486644771, 2.108397813674155], [2.077683847288983, 2.077432930268605, 2.0766802401522964, 2.0754259597604587, 2.0736703937468923, 2.0714139685285065, 2.0686572321869687, 2.065400854342343, 2.0616456259987648, 2.057392459362253, 2.0526423876307356, 2.047396564756409, 2.041656265180546, 2.0354228835409045, 2.0286979343518876, 2.021483051657636, 2.013779988658248, 2.0055906173093447, 1.9969169278952075, 1.9877610285757663, 1.9781251449077013, 1.9680116193399813, 1.9574229106841696, 1.9463615935598653, 1.934830357815679, 1.922832007926178, 1.9103694623652707, 1.8974457529565523, 1.8840640242011641, 1.8702275325837854, 1.855939645857429, 1.841203842307768, 1.8260237099977967, 1.8104029459937203, 1.7943453555730204, 1.777854851415791, 1.760935452780507, 1.7435912846655464, 1.725826576957908, 1.7076456635707502, 1.6890529815715434, 1.6700530703028593, 1.6506505704980547, 1.6308502233943878, 1.6106568698464452, 1.5900754494431104, 1.569110999631764, 1.547768654853895, 1.5260536456969063, 1.50397129806759, 1.4815270323935512, 1.458726362859837, 1.435574896689135, 1.4120783334752762, 1.3882424645813483, 1.3640731726156547, 1.3395764310010172, 1.314758303655689, 1.2896249448074462, 1.2641825989664548, 1.2384376010874047, 1.2123963769573933, 1.186065443853393, 1.1594514115222267, 1.1325609835472368, 1.1054009591799012, 1.0779782357322767, 1.050299811648401, 1.0223727904010336, 0.9942043853961917, 0.9658019261143826, 0.937172865777568, 0.9083247909094553, 0.8792654332600911, 0.8500026847029849, 0.8205446158968858, 0.7908994997531138, 0.7610758410894376, 0.7310824143215636, 0.7009283117008893, 0.6706230055388579, 0.6401764291966963, 0.6095990835709638, 0.5789021786975019, 0.5480978244582538, 0.5171992910810442, 0.48622137064929893, 0.4551808877485268, 0.4240974352353271, 0.3929944583122999, 0.361900892564264, 0.3308537107495535, 0.2999020132885049, 0.269113846197701, 0.23858805564629446, 0.2084759102047767, 0.17902268124499734, 0.15065207437261527, 0.12414521725601123, 0.10101549176322236, 0.08412710413868502, 0.07768384728898271, 0.08412710413869776, 0.10101549176324356, 0.12414521725603711, 0.15065207437264366, 0.1790226812450272, 0.20847591020480738, 0.23858805564632565, 0.26911384619773254, 0.29990201328853666, 0.3308537107495853, 0.361900892564296, 0.3929944583123319, 0.424097435235359, 0.45518088774855864, 0.48622137064933074, 0.5171992910810761, 0.5480978244582856, 0.5789021786975336, 0.6095990835709953, 0.6401764291967276, 0.6706230055388891, 0.7009283117009204, 0.7310824143215946, 0.7610758410894684, 0.7908994997531442, 0.8205446158969161, 0.8500026847030151, 0.879265433260121, 0.9083247909094849, 0.9371728657775974, 0.9658019261144121, 0.9942043853962208, 1.0223727904010622, 1.05029981164843, 1.077978235732305, 1.1054009591799292, 1.1325609835472645, 1.1594514115222543, 1.1860654438534204, 1.2123963769574204, 1.2384376010874314, 1.2641825989664812, 1.2896249448074724, 1.3147583036557147, 1.3395764310010425, 1.36407317261568, 1.3882424645813731, 1.4120783334753004, 1.4355748966891593, 1.4587263628598606, 1.4815270323935747, 1.5039712980676125, 1.526053645696929, 1.5477686548539171, 1.5691109996317858, 1.5900754494431317, 1.610656869846466, 1.6308502233944082, 1.6506505704980747, 1.6700530703028793, 1.6890529815715627, 1.707645663570769, 1.7258265769579266, 1.7435912846655646, 1.7609354527805248, 1.7778548514158081, 1.794345355573037, 1.8104029459937365, 1.8260237099978132, 1.841203842307783, 1.8559396458574442, 1.8702275325837998, 1.8840640242011781, 1.897445752956566, 1.9103694623652843, 1.9228320079261907, 1.934830357815691, 1.9463615935598768, 1.9574229106841807, 1.968011619339992, 1.9781251449077115, 1.9877610285757759, 1.996916927895217, 2.005590617309353, 2.0137799886582566, 2.021483051657644, 2.0286979343518947, 2.035422883540911, 2.041656265180552, 2.047396564756415, 2.052642387630741, 2.0573924593622577, 2.0616456259987688, 2.0654008543423465, 2.068657232186972, 2.0714139685285087, 2.073670393746894, 2.0754259597604605, 2.0766802401522977, 2.077432930268606], [2.046640390387394, 2.0463930049195245, 2.0456509084451677, 2.0444142807378283, 2.042683421372528, 2.0404587496545936, 2.0377408045199967, 2.0345302444072697, 2.0308278471010524, 2.026634509547313, 2.0219512476403136, 2.0167791959813886, 2.01111960760962, 2.0049738537045023, 1.9983434232607078, 1.9912299227350538, 1.9836350756658152, 1.9755607222645064, 1.9670088189802934, 1.9579814380371863, 1.9484807669442064, 1.938509107978695, 1.9280688776429904, 1.9171626060946738, 1.9057929365506276, 1.8939626246651637, 1.8816745378824788, 1.8689316547637391, 1.8557370642891, 1.842093965134999, 1.8280056649270755, 1.8134755794691115, 1.7985072319484035, 1.7831042521180203, 1.7672703754564274, 1.7510094423050115, 1.7343253969840706, 1.7172222868878948, 1.6997042615596165, 1.6817755717465759, 1.6634405684370117, 1.6447037018789827, 1.6255695205825091, 1.606042670306032, 1.5861278930284215, 1.5658300259078952, 1.54515400022938, 1.524104840342042, 1.5026876625889296, 1.4809076742309342, 1.458770172367585, 1.436280542857545, 1.4134442592420986, 1.3902668816754349, 1.3667540558661153, 1.3429115120348263, 1.3187450638943825, 1.2942606076589596, 1.2694641210907813, 1.2443616625939868, 1.2189593703672366, 1.1932634616288522, 1.1672802319310467, 1.1410160545831944, 1.1144773802083334, 1.0876707364623577, 1.0606027279519956, 1.0332800363960497, 1.0057094210850166, 0.977897719707851, 0.949851849632191, 0.9215788097471891, 0.8930856830079315, 0.8643796398598242, 0.8354679427737486, 0.8063579521932471, 0.7770571342906336, 0.7475730710601234, 0.7179134734581942, 0.6880861985572949, 0.6580992720434933, 0.6279609179153195, 0.5976795980141573, 0.5672640651709626, 0.5367234355105766, 0.5060672881829178, 0.475305805124542, 0.44444997051548324, 0.41351186142824875, 0.38250508162463576, 0.3514454271109602, 0.3203519404441344, 0.2892486444090381, 0.25816752123272335, 0.22715390855681877, 0.19627691452318813, 0.1656511531458827, 0.1354867286134469, 0.10621893567428393, 0.0788959717476695, 0.0564613407296469, 0.04664039038739381, 0.056461340729665334, 0.07889597174769589, 0.1062189356743133, 0.13548672861347758, 0.16565115314591403, 0.19627691452321977, 0.2271539085568506, 0.25816752123275527, 0.2892486444090701, 0.3203519404441663, 0.35144542711099214, 0.3825050816246676, 0.4135118614282805, 0.4444499705155149, 0.47530580512457365, 0.5060672881829494, 0.536723435510608, 0.567264065170994, 0.5976795980141886, 0.6279609179153505, 0.6580992720435241, 0.6880861985573257, 0.7179134734582248, 0.7475730710601537, 0.7770571342906638, 0.8063579521932772, 0.8354679427737782, 0.8643796398598538, 0.8930856830079607, 0.9215788097472182, 0.9498518496322201, 0.9778977197078798, 1.005709421085045, 1.033280036396078, 1.0606027279520236, 1.0876707364623854, 1.114477380208361, 1.1410160545832215, 1.1672802319310736, 1.1932634616288789, 1.2189593703672628, 1.2443616625940128, 1.2694641210908069, 1.2942606076589849, 1.3187450638944076, 1.3429115120348512, 1.36675405586614, 1.390266881675459, 1.413444259242122, 1.4362805428575682, 1.4587701723676079, 1.4809076742309566, 1.5026876625889516, 1.524104840342064, 1.5451540002294015, 1.5658300259079163, 1.5861278930284424, 1.6060426703060522, 1.6255695205825287, 1.6447037018790023, 1.6634405684370306, 1.6817755717465945, 1.6997042615596345, 1.7172222868879126, 1.734325396984088, 1.7510094423050284, 1.7672703754564436, 1.783104252118036, 1.7985072319484192, 1.8134755794691266, 1.8280056649270902, 1.842093965135013, 1.8557370642891138, 1.868931654763752, 1.881674537882492, 1.8939626246651764, 1.9057929365506396, 1.9171626060946851, 1.9280688776430017, 1.9385091079787056, 1.9484807669442163, 1.957981438037196, 1.967008818980302, 1.9755607222645148, 1.983635075665823, 1.9912299227350612, 1.9983434232607147, 2.0049738537045094, 2.0111196076096256, 2.016779195981394, 2.021951247640318, 2.0266345095473173, 2.030827847101057, 2.0345302444072733, 2.03774080452, 2.0404587496545963, 2.042683421372529, 2.0444142807378296, 2.045650908445169, 2.0463930049195254], [2.015551811920327, 2.015308072168038, 2.014576911875888, 2.0133585079237917, 2.011653155064166, 2.0094612658507756, 2.006783370539147, 2.003620116958571, 1.9999722703557254, 1.9958407132099627, 1.9912264450203017, 1.9861305820641844, 1.9805543571280546, 1.9744991192098302, 1.9679663331933404, 1.9609575794948124, 1.9534745536815032, 1.9455190660625628, 1.9370930412522451, 1.9281985177055725, 1.9188376472265702, 1.90901269444921, 1.898726036291181, 1.8879801613806457, 1.8767776694561167, 1.8651212707396247, 1.8530137852833333, 1.840458142289774, 1.8274573794058917, 1.8140146419910828, 1.80013318235942, 1.7858163589962819, 1.7710676357495947, 1.7558905809959124, 1.7402888667815686, 1.7242662679391503, 1.7078266611795387, 1.6909740241597948, 1.6737124345271537, 1.656046068939431, 1.6379792020621349, 1.6195162055426096, 1.600661546961536, 1.5814197887621475, 1.5617955871575286, 1.5417936910163845, 1.5214189407277023, 1.500676267044738, 1.4795706899088086, 1.4581073172533872, 1.4362913437890503, 1.4141280497698678, 1.3916227997418753, 1.3687810412743369, 1.3456083036745705, 1.322110196687206, 1.2982924091788255, 1.2741607078090882, 1.2497209356895531, 1.2249790110316137, 1.1999409257851636, 1.1746127442698635, 1.1490006018012116, 1.123110703314004, 1.0969493219862612, 1.0705227978673026, 1.0438375365144161, 1.0169000076435313, 0.9897167438005322, 0.9622943390614079, 0.9346394477714682, 0.9067587833364728, 0.8786591170819642, 0.8503472772016405, 0.8218301478216588, 0.7931146682159068, 0.7642078322183711, 0.7351166878939451, 0.7058483375502198, 0.6764099382026242, 0.6468087026479046, 0.6170519013626804, 0.5871468655347942, 0.5571009916715537, 0.5269217484374283, 0.4966166866992647, 0.46619345427745984, 0.4356598177556238, 0.4050236951449999, 0.37429320572298064, 0.34347674794473804, 0.3125831250101649, 0.2816217549885953, 0.2506030390826793, 0.21953904506541447, 0.18844487023225975, 0.15734162333824003, 0.12626380760020356, 0.09528107871029981, 0.06458197524021321, 0.03499056506635985, 0.015551811920326975, 0.0349905650663887, 0.06458197524024448, 0.09528107871033158, 0.1262638076002355, 0.15734162333827206, 0.18844487023229173, 0.21953904506544644, 0.2506030390827112, 0.2816217549886272, 0.31258312501019664, 0.3434767479447698, 0.3742932057230123, 0.4050236951450314, 0.4356598177556552, 0.46619345427749115, 0.496616686699296, 0.5269217484374595, 0.5571009916715846, 0.5871468655348251, 0.617051901362711, 0.646808702647935, 0.6764099382026545, 0.7058483375502499, 0.7351166878939752, 0.7642078322184009, 0.7931146682159365, 0.8218301478216881, 0.8503472772016698, 0.8786591170819931, 0.9067587833365015, 0.9346394477714969, 0.9622943390614362, 0.9897167438005603, 1.0169000076435593, 1.0438375365144437, 1.07052279786733, 1.0969493219862883, 1.1231107033140306, 1.149000601801238, 1.1746127442698895, 1.1999409257851896, 1.2249790110316394, 1.2497209356895784, 1.2741607078091133, 1.2982924091788504, 1.3221101966872302, 1.3456083036745947, 1.3687810412743604, 1.3916227997418986, 1.4141280497698907, 1.436291343789073, 1.4581073172534094, 1.4795706899088306, 1.5006762670447595, 1.5214189407277234, 1.5417936910164052, 1.561795587157549, 1.5814197887621673, 1.600661546961555, 1.6195162055426287, 1.6379792020621535, 1.6560460689394492, 1.6737124345271717, 1.6909740241598124, 1.7078266611795558, 1.7242662679391667, 1.7402888667815848, 1.755890580995928, 1.7710676357496105, 1.7858163589962968, 1.8001331823594342, 1.8140146419910967, 1.8274573794059055, 1.8404581422897868, 1.8530137852833461, 1.8651212707396374, 1.8767776694561285, 1.8879801613806566, 1.8987260362911917, 1.9090126944492203, 1.9188376472265805, 1.928198517705582, 1.937093041252254, 1.945519066062571, 1.9534745536815108, 1.9609575794948202, 1.9679663331933472, 1.9744991192098367, 1.9805543571280604, 1.9861305820641895, 1.9912264450203068, 1.9958407132099674, 1.9999722703557297, 2.0036201169585746, 2.00678337053915, 2.009461265850778, 2.011653155064168, 2.013358507923793, 2.014576911875889, 2.0153080721680383], [1.984448188079625, 1.984208210125671, 1.9834883343188103, 1.9822887348100366, 1.980609701804299, 1.9784516414904478, 1.9758150759431954, 1.9727006429971, 1.9691090960926088, 1.9650413040942085, 1.960498251080718, 1.9554810361077821, 1.949990872942625, 1.9440290897711314, 1.9375971288773306, 1.9306965462953618, 1.9233290114340176, 1.915496306673948, 1.9072003269376467, 1.8984430792323095, 1.889226682165703, 1.8795533654351537, 1.8694254692897954, 1.8588454439662199, 1.8478158490976702, 1.8363393530969352, 1.824418732513114, 1.8120568713624106, 1.7992567604331464, 1.7860214965651744, 1.7723542819038907, 1.7582584231290463, 1.7437373306585762, 1.7287945178276645, 1.7134336000432764, 1.6976582939144014, 1.6814724163582602, 1.6648798836827359, 1.6478847106453056, 1.6304910094887612, 1.612702988954018, 1.5945249532703274, 1.575961301123226, 1.5570165246005678, 1.5376952081170097, 1.518002027317335, 1.4979417479590322, 1.4775192247745692, 1.4567394003138223, 1.4356073037671828, 1.414128049769868, 1.392306837188036, 1.370148947887346, 1.3476597454846706, 1.324844674083735, 1.3017092569955553, 1.2782590954446378, 1.254499867262037, 1.2304373255665044, 1.2060772974351486, 1.18142568256524, 1.1564884519290537, 1.1312716464239716, 1.1057813755204604, 1.08002381591104, 1.0540052101639719, 1.0277318653861662, 1.0012101519008, 0.9744465019463607, 0.9474474084054428, 0.920219423573665, 0.8927691579817442, 0.8651032792872667, 0.8372285112572957, 0.809151632869119, 0.7808794775647089, 0.752418932705724, 0.7237769392913461, 0.6949604920227617, 0.6659766398283963, 0.6368324870072837, 0.6075351952106676, 0.5780919865743191, 0.548510148452543, 0.5187970404165403, 0.48896010451032074, 0.4590068802857543, 0.42894502700558984, 0.3987823568691663, 0.36852688567723396, 0.33818691200183604, 0.3077711447422415, 0.2772889165297407, 0.24675055767283513, 0.2161680900256433, 0.1855566105049646, 0.154937317358543, 0.12434500048331784, 0.09385010320576674, 0.06364352007630433, 0.03455790642377664, 0.01555181192037493, 0.03455790642380496, 0.06364352007633506, 0.09385010320579798, 0.12434500048334926, 0.15493731735857447, 0.18555661050499606, 0.21616809002567472, 0.2467505576728665, 0.277288916529772, 0.3077711447422728, 0.33818691200186723, 0.36852688567726516, 0.39878235686919733, 0.4289450270056207, 0.4590068802857852, 0.48896010451035143, 0.5187970404165709, 0.5485101484525734, 0.5780919865743497, 0.6075351952106978, 0.6368324870073137, 0.6659766398284263, 0.6949604920227914, 0.7237769392913757, 0.7524189327057532, 0.7808794775647382, 0.8091516328691479, 0.8372285112573244, 0.8651032792872951, 0.8927691579817724, 0.920219423573693, 0.9474474084054709, 0.9744465019463883, 1.0012101519008274, 1.0277318653861933, 1.0540052101639987, 1.0800238159110667, 1.1057813755204866, 1.1312716464239976, 1.15648845192908, 1.1814256825652656, 1.2060772974351737, 1.230437325566529, 1.2544998672620618, 1.278259095444662, 1.301709256995579, 1.324844674083759, 1.347659745484694, 1.370148947887369, 1.3923068371880583, 1.41412804976989, 1.4356073037672048, 1.4567394003138436, 1.4775192247745905, 1.4979417479590533, 1.5180020273173553, 1.5376952081170299, 1.5570165246005876, 1.575961301123245, 1.5945249532703465, 1.6127029889540365, 1.6304910094887797, 1.6478847106453232, 1.6648798836827534, 1.6814724163582773, 1.6976582939144178, 1.7134336000432926, 1.7287945178276802, 1.7437373306585915, 1.7582584231290608, 1.7723542819039049, 1.7860214965651884, 1.79925676043316, 1.8120568713624234, 1.8244187325131265, 1.8363393530969472, 1.8478158490976817, 1.858845443966231, 1.8694254692898058, 1.8795533654351637, 1.8892266821657127, 1.8984430792323184, 1.9072003269376554, 1.9154963066739565, 1.9233290114340251, 1.9306965462953691, 1.937597128877337, 1.944029089771138, 1.9499908729426307, 1.9554810361077875, 1.960498251080723, 1.9650413040942127, 1.9691090960926123, 1.9727006429971035, 1.975815075943199, 1.97845164149045, 1.9806097018043007, 1.9822887348100382, 1.9834883343188114, 1.9842082101256717], [1.9533596096125583, 1.9531235113569188, 1.9524152737936227, 1.95123506851996, 1.9495831814861666, 1.9474600129275648, 1.9448660772696003, 1.9418020030057939, 1.938268532548666, 1.934266522053673, 1.9297969412162235, 1.9248608730418448, 1.9194595135895838, 1.9135941716887246, 1.90726626862894, 1.9004773378239779, 1.8932290244490095, 1.8855230850517828, 1.8773613871377188, 1.868745908729119, 1.859678737898651, 1.850162072277307, 1.8401982185370303, 1.8297895918482296, 1.8189387153124155, 1.8076482193702061, 1.7959208411849763, 1.783759424002434, 1.771166916486437, 1.7581463720313872, 1.7447009480515558, 1.7308339052477322, 1.7165486068516136, 1.701848517848388, 1.6867372041779973, 1.6712183319156189, 1.6552956664319376, 1.638973071533846, 1.6222545085862523, 1.6051440356157665, 1.5876458063970857, 1.569764069523, 1.5515031674590385, 1.5328675355838763, 1.51386170121677, 1.4944902826334185, 1.474757988071833, 1.4546696147299916, 1.434230047757295, 1.413444259242099, 1.3923173071979322, 1.3708543345513726, 1.3490605681350047, 1.3269413176894056, 1.3045019748787223, 1.2817480123251639, 1.2586849826686077, 1.2353185176586061, 1.2116543272873677, 1.1876981989738642, 1.1634559968111293, 1.1389336608911587, 1.1141372067247017, 1.0890727247768022, 1.06374638014336, 1.0381644123995188, 1.0123331356576097, 0.9862589388811568, 0.9599482865125795, 0.9334077194864937, 0.9066438567188763, 0.8796633971862173, 0.8524731227399873, 0.8250799018429193, 0.7974906944684063, 0.7697125584779316, 0.7417526578913759, 0.7136182736020836, 0.6853168172787591, 0.656855849463442, 0.628243103255214, 0.5994865155188078, 0.5705942683635906, 0.5415748448419135, 0.512437104646035, 0.4831903884237107, 0.453844663842918, 0.4244107338786864, 0.39490054008591996, 0.36532761484953047, 0.3357077745805047, 0.3060602165485044, 0.27640931992897283, 0.2467877351345704, 0.21724196556811634, 0.18784310465697424, 0.15870913183992696, 0.13005579167224057, 0.10232691659149741, 0.07657472911209624, 0.055656444964064175, 0.04664039038744172, 0.0556564449640812, 0.07657472911212099, 0.10232691659152518, 0.13005579167226966, 0.15870913183995675, 0.18784310465700435, 0.21724196556814662, 0.24678773513460078, 0.27640931992900325, 0.30606021654853494, 0.33570777458053525, 0.3653276148495609, 0.3949005400859503, 0.4244107338787167, 0.4538446638429482, 0.4831903884237409, 0.5124371046460651, 0.5415748448419434, 0.5705942683636206, 0.5994865155188375, 0.6282431032552434, 0.6568558494634712, 0.6853168172787882, 0.7136182736021125, 0.7417526578914048, 0.7697125584779603, 0.7974906944684347, 0.8250799018429478, 0.8524731227400153, 0.8796633971862452, 0.9066438567189039, 0.9334077194865211, 0.9599482865126067, 0.9862589388811835, 1.0123331356576364, 1.0381644123995453, 1.0637463801433864, 1.089072724776828, 1.1141372067247275, 1.1389336608911844, 1.1634559968111546, 1.1876981989738888, 1.211654327287392, 1.2353185176586303, 1.2586849826686315, 1.2817480123251874, 1.3045019748787456, 1.3269413176894285, 1.3490605681350276, 1.3708543345513948, 1.3923173071979542, 1.4134442592421206, 1.434230047757316, 1.4546696147300122, 1.4747579880718533, 1.4944902826334385, 1.5138617012167899, 1.5328675355838954, 1.5515031674590571, 1.5697640695230188, 1.5876458063971037, 1.6051440356157842, 1.6222545085862696, 1.638973071533863, 1.6552956664319545, 1.6712183319156348, 1.686737204178013, 1.7018485178484033, 1.7165486068516291, 1.7308339052477468, 1.7447009480515698, 1.758146372031401, 1.7711669164864505, 1.7837594240024468, 1.795920841184989, 1.8076482193702181, 1.8189387153124268, 1.8297895918482405, 1.8401982185370407, 1.8501620722773169, 1.8596787378986603, 1.868745908729128, 1.8773613871377277, 1.885523085051791, 1.893229024449017, 1.900477337823985, 1.9072662686289468, 1.9135941716887308, 1.919459513589589, 1.9248608730418506, 1.9297969412162284, 1.9342665220536779, 1.9382685325486702, 1.9418020030057976, 1.944866077269603, 1.947460012927567, 1.9495831814861682, 1.951235068519961, 1.9524152737936238, 1.9531235113569194], [1.9223161527109696, 1.9220840537454653, 1.921387813262703, 1.9202276004910215, 1.9186036974346135, 1.9165164988089893, 1.9139665119506812, 1.9109543567012277, 1.9074807652655057, 1.9035465820444988, 1.8991527634425747, 1.8943003776494018, 1.8889906043966227, 1.8832247346894186, 1.8770041705131433, 1.870330424515186, 1.8632051196622768, 1.855629988873438, 1.8476068746288365, 1.8391377285547874, 1.8302246109852065, 1.820869690499818, 1.8110752434394708, 1.8008436533989276, 1.790177410697543, 1.7790791118282738, 1.7675514588855066, 1.7555972589722355, 1.7432194235871683, 1.7304209679923959, 1.7172050105623207, 1.7035747721146026, 1.6895335752239637, 1.6750848435197665, 1.6602321009683862, 1.6449789711414942, 1.629329176471495, 1.6132865374954914, 1.5968549720893115, 1.580038494693299, 1.5628412155317772, 1.5452673398283208, 1.5273211670192315, 1.509007089967921, 1.4903295941832557, 1.4712932570453072, 1.4519027470424468, 1.4321628230242434, 1.412078333475277, 1.3916542158157217, 1.3708954957354242, 1.3498072865692436, 1.328394788722625, 1.3066632891578394, 1.2846181609530238, 1.2622648629482232, 1.2396089394950778, 1.2166560203297696, 1.1934118205923914, 1.1698821410202456, 1.1460728683478223, 1.121989975952663, 1.097639524794199, 1.0730276647024277, 1.0481606360853806, 1.023044772139432, 0.9976865016654148, 0.9720923526173847, 0.9462689565411426, 0.9202230540983172, 0.8939615019215221, 0.8674912811105163, 0.840819507763328, 0.8139534460468405, 0.7869005244580032, 0.7596683561231339, 0.7322647642481706, 0.7046978141950985, 0.6769758541601857, 0.6491075671287246, 0.6211020377701301, 0.5929688393559663, 0.5647181478485078, 0.5363608933613414, 0.5079089637884712, 0.4793754824429344, 0.4507751925693774, 0.4221249992352788, 0.39344474803596746, 0.36475836879282164, 0.3360955970262795, 0.30749463769560664, 0.2790064176498935, 0.25070161795497375, 0.2226827737112165, 0.19510602818587053, 0.16822211773740697, 0.14245709281519472, 0.11857543344057674, 0.0979951128816957, 0.08322896995955179, 0.07768384728903052, 0.08322896995956279, 0.09799511288171439, 0.11857543344059991, 0.1424570928152204, 0.16822211773743417, 0.1951060281858986, 0.22268277371124515, 0.2507016179550027, 0.2790064176499227, 0.307494637695636, 0.3360955970263089, 0.36475836879285106, 0.39344474803599694, 0.42212499923530816, 0.4507751925694069, 0.4793754824429638, 0.5079089637885005, 0.5363608933613706, 0.564718147848537, 0.5929688393559953, 0.6211020377701589, 0.6491075671287535, 0.6769758541602141, 0.7046978141951269, 0.7322647642481986, 0.7596683561231621, 0.7869005244580309, 0.8139534460468685, 0.8408195077633556, 0.8674912811105436, 0.8939615019215492, 0.920223054098344, 0.9462689565411693, 0.9720923526174111, 0.997686501665441, 1.0230447721394578, 1.0481606360854063, 1.073027664702453, 1.097639524794224, 1.1219899759526881, 1.1460728683478472, 1.1698821410202698, 1.1934118205924156, 1.2166560203297931, 1.2396089394951013, 1.2622648629482462, 1.2846181609530465, 1.3066632891578618, 1.3283947887226473, 1.3498072865692656, 1.3708954957354458, 1.3916542158157428, 1.4120783334752978, 1.4321628230242638, 1.4519027470424668, 1.4712932570453268, 1.490329594183275, 1.50900708996794, 1.5273211670192497, 1.5452673398283392, 1.562841215531795, 1.5800384946933164, 1.5968549720893286, 1.6132865374955083, 1.6293291764715112, 1.64497897114151, 1.6602321009684016, 1.6750848435197816, 1.6895335752239786, 1.703574772114617, 1.7172050105623342, 1.7304209679924092, 1.743219423587181, 1.755597258972248, 1.7675514588855186, 1.7790791118282854, 1.790177410697554, 1.800843653398938, 1.8110752434394812, 1.8208696904998276, 1.8302246109852158, 1.8391377285547963, 1.8476068746288448, 1.855629988873446, 1.8632051196622843, 1.870330424515193, 1.8770041705131495, 1.883224734689425, 1.8889906043966285, 1.8943003776494074, 1.899152763442579, 1.9035465820445032, 1.9074807652655097, 1.9109543567012308, 1.9139665119506846, 1.9165164988089918, 1.918603697434615, 1.9202276004910228, 1.921387813262704, 1.922084053745466], [1.8913478499145011, 1.8911198713720405, 1.8904359914328037, 1.8892963771492082, 1.8877013069018866, 1.8856511703396326, 1.8831464682953998, 1.8801878126784242, 1.8767759263425723, 1.872911642931034, 1.8685959066974984, 1.8638297723039874, 1.8586144045955333, 1.8529510783519247, 1.8468411780167633, 1.8402861974041171, 1.8332877393830715, 1.8258475155405254, 1.8179673458226115, 1.8096491581551615, 1.8008949880436758, 1.7917069781533048, 1.782087377869408, 1.7720385428392917, 1.761562934495811, 1.7506631195635738, 1.739341769548556, 1.727601660212034, 1.7154456710298085, 1.7028767846378219, 1.6898980862653512, 1.6765127631571202, 1.6627241039857823, 1.6485354982564078, 1.6339504357047767, 1.6189725056914852, 1.6036053965940948, 1.587852895199831, 1.5717188861016076, 1.5552073511005162, 1.5383223686182876, 1.5210681131236876, 1.503448854577303, 1.4854689578997713, 1.4671328824691818, 1.4484451816541457, 1.4294105023899566, 1.4100335848063128, 1.3903192619162963, 1.3702724593777638, 1.3498981953399851, 1.32920158039036, 1.3081878176184008, 1.2868622028169545, 1.2652301248439504, 1.243297066171907, 1.2210686036571694, 1.1985504095665103, 1.17574825290559, 1.1526680011020418, 1.1293156221060279, 1.1056971869833991, 1.0818188730916547, 1.0576869679474656, 1.0333078739174961, 1.0086881138928316, 0.9838343381430724, 0.9587533325911066, 0.9334520288064518, 0.907937516087457, 0.8822170560954158, 0.85629810062331, 0.8301883132373874, 0.8038955957333481, 0.777428120617598, 0.7507943711816735, 0.7240031912183291, 0.6970638470792297, 0.6699861056666695, 0.6427803331877288, 0.6154576212308556, 0.5880299491807888, 0.560510395517074, 0.5329134156850264, 0.5052552118374279, 0.4775542311843767, 0.4498318471810216, 0.4221133050213538, 0.39442905614170526, 0.3668166764534946, 0.3393236787606555, 0.3120117250485197, 0.2849630798327658, 0.25829073037060424, 0.23215462121165034, 0.20678819608712037, 0.18254216743311008, 0.15995547822852046, 0.13986128265278458, 0.12350603786810706, 0.11255048287859502, 0.10865215008549892, 0.11255048287860289, 0.12350603786812141, 0.13986128265280354, 0.15995547822854256, 0.18254216743313428, 0.206788196087146, 0.2321546212116769, 0.25829073037063144, 0.2849630798327935, 0.31201172504854763, 0.33932367876068376, 0.3668166764535229, 0.3944290561417336, 0.4221133050213822, 0.4498318471810501, 0.47755423118440515, 0.5052552118374565, 0.5329134156850549, 0.5605103955171026, 0.588029949180817, 0.6154576212308837, 0.6427803331877567, 0.6699861056666975, 0.6970638470792575, 0.7240031912183567, 0.7507943711817009, 0.7774281206176252, 0.8038955957333753, 0.8301883132374144, 0.8562981006233367, 0.8822170560954423, 0.9079375160874833, 0.9334520288064779, 0.9587533325911325, 0.9838343381430981, 1.0086881138928572, 1.0333078739175212, 1.0576869679474905, 1.0818188730916793, 1.1056971869834238, 1.1293156221060523, 1.1526680011020654, 1.1757482529056136, 1.1985504095665336, 1.2210686036571923, 1.2432970661719296, 1.2652301248439726, 1.2868622028169765, 1.3081878176184225, 1.3292015803903816, 1.349898195340006, 1.3702724593777844, 1.3903192619163165, 1.410033584806333, 1.4294105023899764, 1.4484451816541648, 1.467132882469201, 1.48546895789979, 1.503448854577321, 1.5210681131237054, 1.5383223686183052, 1.555207351100533, 1.5717188861016245, 1.5878528951998476, 1.6036053965941108, 1.6189725056915005, 1.6339504357047918, 1.6485354982564224, 1.662724103985797, 1.6765127631571344, 1.6898980862653648, 1.702876784637835, 1.7154456710298214, 1.727601660212046, 1.7393417695485682, 1.7506631195635853, 1.761562934495822, 1.772038542839302, 1.782087377869418, 1.7917069781533144, 1.8008949880436849, 1.8096491581551704, 1.81796734582262, 1.8258475155405332, 1.833287739383079, 1.840286197404124, 1.8468411780167697, 1.8529510783519307, 1.858614404595539, 1.8638297723039925, 1.8685959066975033, 1.8729116429310382, 1.8767759263425763, 1.8801878126784275, 1.8831464682954027, 1.885651170339635, 1.8877013069018882, 1.8892963771492093, 1.8904359914328048, 1.8911198713720407], [1.8604846610560526, 1.8602609254319147, 1.8595897735885636, 1.858471370602289, 1.8569059915639357, 1.8548940215244951, 1.8524359554190473, 1.8495323979691545, 1.84618406356385, 1.8423917761193969, 1.8381564689180272, 1.8334791844259024, 1.8283610740905827, 1.822803398118325, 1.8168075252315734, 1.8103749324070615, 1.8035072045949714, 1.7962060344196702, 1.7884732218625898, 1.7803106739278733, 1.7717204042914865, 1.7627045329345554, 1.753265285761785, 1.743404994205877, 1.73312609481899, 1.7224311288523664, 1.711322741825378, 1.6998036830853789, 1.6878768053598827, 1.675545064302762, 1.6628115180363299, 1.6496793266913872, 1.6361517519475248, 1.622232156576247, 1.607924003989758, 1.5932308577985914, 1.5781563813816202, 1.5627043374724316, 1.5468785877664986, 1.5306830925541595, 1.5141219103850214, 1.4971991977701378, 1.479919208929125, 1.462286295590336, 1.444304906853314, 1.4259795891240057, 1.4073149861346965, 1.3883158390623362, 1.3689869867609255, 1.34933336612596, 1.3293600126116767, 1.3090720609250488, 1.2884747459242876, 1.267573403754084, 1.2463734732551526, 1.2248804976919876, 1.2031001268502983, 1.1810381195646957, 1.1587003467480992, 1.1360927950075494, 1.1132215709470994, 1.0900929062779403, 1.0667131638797318, 1.0430888449863682, 1.0192265977054968, 0.9951332271258683, 0.9708157073223734, 0.9462811956384949, 0.9215370497139302, 0.8965908478366936, 0.8714504133411883, 0.8461238439561864, 0.8206195472422839, 0.7949462835648672, 0.7691132184502225, 0.7431299867026967, 0.7170067713668007, 0.6907544015661125, 0.6643844745352561, 0.637909508918098, 0.6113431388324015, 0.5847003615893318, 0.5579978567377881, 0.5312544009285315, 0.5044914129495655, 0.4777336776903207, 0.4510103191032491, 0.4243561241309168, 0.39781336784197835, 0.37143436375195515, 0.3452850765706766, 0.3194503084993052, 0.294041233695389, 0.2692064398716408, 0.24514814436981208, 0.2221457514701003, 0.20058881508743606, 0.18101890044813926, 0.16417024236184158, 0.15097542114639959, 0.14246751607540087, 0.13951533894394746, 0.1424675160754069, 0.1509754211464109, 0.16417024236185718, 0.1810189004481581, 0.2005888150874573, 0.2221457514701233, 0.24514814436983634, 0.2692064398716659, 0.29404123369541485, 0.31945030849933154, 0.3452850765707034, 0.37143436375198213, 0.3978133678420056, 0.42435612413094415, 0.45101031910327655, 0.47773367769034825, 0.504491412949593, 0.5312544009285589, 0.5579978567378158, 0.5847003615893592, 0.6113431388324289, 0.6379095089181251, 0.664384474535283, 0.6907544015661394, 0.7170067713668276, 0.7431299867027236, 0.7691132184502492, 0.7949462835648937, 0.8206195472423101, 0.8461238439562125, 0.8714504133412142, 0.8965908478367196, 0.9215370497139558, 0.9462811956385202, 0.9708157073223986, 0.9951332271258932, 1.0192265977055217, 1.0430888449863929, 1.066713163879756, 1.090092906277964, 1.1132215709471234, 1.1360927950075728, 1.1587003467481223, 1.1810381195647186, 1.203100126850321, 1.2248804976920098, 1.2463734732551748, 1.2675734037541055, 1.2884747459243087, 1.3090720609250697, 1.3293600126116973, 1.3493333661259805, 1.3689869867609454, 1.388315839062356, 1.4073149861347158, 1.4259795891240246, 1.4443049068533325, 1.4622862955903542, 1.4799192089291429, 1.4971991977701555, 1.5141219103850387, 1.5306830925541766, 1.5468785877665154, 1.5627043374724476, 1.5781563813816357, 1.5932308577986065, 1.607924003989773, 1.6222321565762614, 1.6361517519475393, 1.649679326691401, 1.6628115180363432, 1.675545064302775, 1.6878768053598951, 1.6998036830853906, 1.7113227418253896, 1.7224311288523775, 1.7331260948190008, 1.743404994205887, 1.7532652857617947, 1.762704532934565, 1.7717204042914954, 1.780310673927882, 1.7884732218625976, 1.7962060344196775, 1.8035072045949785, 1.8103749324070686, 1.8168075252315796, 1.8228033981183307, 1.8283610740905882, 1.8334791844259075, 1.8381564689180314, 1.842391776119401, 1.8461840635638536, 1.8495323979691578, 1.8524359554190502, 1.8548940215244976, 1.8569059915639374, 1.8584713706022904, 1.8595897735885645, 1.8602609254319156], [1.8297564442775769, 1.829537075219973, 1.828879022485321, 1.82778244937856, 1.8262476280428137, 1.8242749394117967, 1.821864873143342, 1.819018027534189, 1.81573510941623, 1.8120169340344674, 1.8078644249069606, 1.8032786136671102, 1.798260639888677, 1.7928117508939796, 1.7869333015457922, 1.7806267540235072, 1.7738936775842156, 1.766735748309419, 1.7591547488381758, 1.7511525680875613, 1.742731200961436, 1.7338927480485922, 1.7246394153114937, 1.7149735137669262, 1.7048974591600285, 1.6944137716333263, 1.68352507539255, 1.672234098371228, 1.6605436718962436, 1.6484567303567803, 1.6359763108793535, 1.6231055530119205, 1.6098476984203856, 1.5962060906012052, 1.5821841746142202, 1.567785496840309, 1.553013704769023, 1.5378725468219554, 1.5223658722183273, 1.5064976308900462, 1.4902718734544342, 1.473692751253857, 1.4567645164726932, 1.4394915223434719, 1.4218782234556007, 1.403929176181952, 1.3856490392407221, 1.3670425744124537, 1.348114647435006, 1.3288702291026457, 1.309314396599366, 1.2894523351012035, 1.2692893396877605, 1.2488308176096141, 1.2280822909659104, 1.2070493998555205, 1.1857379060759485, 1.1641536974571074, 1.1423027929325844, 1.1201913484697112, 1.0978256640023258, 1.075212191537522, 1.0523575446410731, 1.0292685095470675, 1.0059520581874979, 0.982415363499526, 0.9586658174450035, 0.934711052272643, 0.9105589656732448, 0.8862177506295507, 0.8616959309537098, 0.8370024037491737, 0.8121464903462602, 0.7871379976634685, 0.7619872924694223, 0.7367053917033763, 0.7113040729109051, 0.6857960100423418, 0.6601949414515695, 0.6345158790718697, 0.6087753706457084, 0.5829918308482807, 0.5571859626019477, 0.5313812974507258, 0.5056048944441487, 0.4798882518535642, 0.4542685070484547, 0.42879002957972256, 0.40350655446570943, 0.3784840613123524, 0.353804685004525, 0.3295720479593975, 0.30591852577550027, 0.28301506333331355, 0.26108414188908113, 0.2404160927365794, 0.22138757660360522, 0.20447766310364965, 0.19027041647098925, 0.17942417549892867, 0.17258506318879716, 0.17024355572242306, 0.1725850631888019, 0.17942417549893785, 0.1902704164710022, 0.20447766310366572, 0.22138757660362376, 0.24041609273659992, 0.26108414188910306, 0.28301506333333654, 0.30591852577552425, 0.32957204795942213, 0.35380468500455015, 0.37848406131237794, 0.4035065544657353, 0.42879002957974865, 0.4542685070484809, 0.4798882518535907, 0.5056048944441752, 0.5313812974507522, 0.5571859626019743, 0.5829918308483072, 0.6087753706457348, 0.6345158790718961, 0.660194941451596, 0.6857960100423681, 0.7113040729109311, 0.7367053917034023, 0.7619872924694483, 0.7871379976634945, 0.8121464903462858, 0.837002403749199, 0.8616959309537352, 0.8862177506295759, 0.9105589656732698, 0.9347110522726676, 0.958665817445028, 0.98241536349955, 1.005952058187522, 1.0292685095470913, 1.0523575446410967, 1.0752121915375454, 1.097825664002349, 1.1201913484697341, 1.142302792932607, 1.1641536974571296, 1.1857379060759707, 1.2070493998555423, 1.2280822909659321, 1.2488308176096354, 1.2692893396877811, 1.289452335101224, 1.3093143965993863, 1.3288702291026657, 1.3481146474350258, 1.367042574412473, 1.3856490392407412, 1.4039291761819703, 1.4218782234556189, 1.4394915223434899, 1.4567645164727105, 1.473692751253874, 1.4902718734544511, 1.5064976308900628, 1.5223658722183437, 1.5378725468219714, 1.553013704769038, 1.5677854968403242, 1.5821841746142347, 1.5962060906012197, 1.6098476984203995, 1.6231055530119338, 1.6359763108793663, 1.6484567303567927, 1.6605436718962558, 1.6722340983712398, 1.6835250753925615, 1.6944137716333374, 1.704897459160039, 1.7149735137669357, 1.7246394153115032, 1.7338927480486013, 1.7427312009614448, 1.7511525680875697, 1.7591547488381833, 1.7667357483094266, 1.7738936775842225, 1.7806267540235137, 1.7869333015457982, 1.7928117508939854, 1.798260639888682, 1.803278613667115, 1.807864424906965, 1.8120169340344716, 1.8157351094162337, 1.8190180275341923, 1.821864873143345, 1.824274939411799, 1.8262476280428153, 1.8277824493785613, 1.828879022485322, 1.8295370752199736], [1.799192927144257, 1.798978049211264, 1.7983334693286899, 1.7972593492377964, 1.7957559584808667, 1.7938236743615752, 1.791462981889705, 1.7886744737104159, 1.7854588500183186, 1.7818169184566877, 1.7777495940021952, 1.7732578988356247, 1.7683429621990892, 1.7630060202403643, 1.7572484158450132, 1.751071598457079, 1.744477123889205, 1.7374666541231523, 1.730041957101781, 1.7222049065136904, 1.7139574815718424, 1.7053017667876218, 1.6962399517419644, 1.6867743308553307, 1.6769073031585142, 1.6666413720664714, 1.6559791451575911, 1.6449233339610931, 1.6334767537555195, 1.621642323381616, 1.6094230650732528, 1.596822104310448, 1.5838426696990056, 1.5704880928817941, 1.556761808487267, 1.542667354121489, 1.5282083704106602, 1.5133886011019766, 1.4982118932316184, 1.482682197369747, 1.466803567953631, 1.4505801637214455, 1.434016248260912, 1.4171161906888254, 1.3998844664796657, 1.3823256584639725, 1.36444445802005, 1.346245666485894, 1.3277341968221088, 1.3089150755611059, 1.289793445083141, 1.2703745662659296, 1.2506638215618338, 1.2306667185651587, 1.210388894142183, 1.1898361192085058, 1.1690143042524892, 1.1479295057205074, 1.126587933399954, 1.1049959589602514, 1.0831601258413508, 1.061087160714559, 1.0387839867833955, 1.0162577392443892, 0.9935157832915338, 0.9705657351264687, 0.9474154865330172, 0.9240732336943017, 0.9005475110793958, 0.8768472314123571, 0.8529817329699055, 0.828960835748594, 0.8047949084159676, 0.7804949484366451, 0.7560726783749793, 0.7315406621630317, 0.7069124461425075, 0.6822027310180113, 0.6574275825992906, 0.6326046915011094, 0.6077536949997189, 0.5828965782698543, 0.5580581775899062, 0.5332668152644012, 0.5085551055735221, 0.48396098378076574, 0.4595290270176313, 0.4353121576581478, 0.41137384723756265, 0.38779097157586423, 0.36465750206442804, 0.3420892436482521, 0.3202298216848617, 0.29925802326097917, 0.2793963075839985, 0.2609196315221456, 0.24416243547021146, 0.22951951371347962, 0.21743390069660629, 0.20836363091251806, 0.20272308218564059, 0.20080707285574295, 0.20272308218564453, 0.20836363091252566, 0.21743390069661725, 0.22951951371349338, 0.24416243547022765, 0.2609196315221638, 0.2793963075840183, 0.2992580232610002, 0.3202298216848838, 0.3420892436482749, 0.36465750206445163, 0.38779097157588827, 0.4113738472375871, 0.4353121576581725, 0.45952902701765636, 0.48396098378079094, 0.5085551055735476, 0.5332668152644267, 0.5580581775899318, 0.5828965782698797, 0.6077536949997444, 0.632604691501135, 0.657427582599316, 0.6822027310180367, 0.7069124461425328, 0.7315406621630571, 0.7560726783750044, 0.7804949484366701, 0.8047949084159923, 0.8289608357486188, 0.8529817329699301, 0.8768472314123816, 0.9005475110794201, 0.9240732336943257, 0.9474154865330412, 0.9705657351264925, 0.9935157832915574, 1.0162577392444125, 1.0387839867834188, 1.061087160714582, 1.0831601258413734, 1.1049959589602738, 1.126587933399976, 1.147929505720529, 1.1690143042525107, 1.1898361192085272, 1.210388894142204, 1.2306667185651794, 1.2506638215618542, 1.2703745662659496, 1.2897934450831605, 1.3089150755611254, 1.327734196822128, 1.346245666485913, 1.3644444580200685, 1.3823256584639905, 1.3998844664796837, 1.417116190688843, 1.434016248260929, 1.4505801637214624, 1.4668035679536475, 1.4826821973697633, 1.4982118932316342, 1.5133886011019921, 1.5282083704106753, 1.5426673541215035, 1.5567618084872812, 1.570488092881808, 1.5838426696990198, 1.596822104310461, 1.6094230650732655, 1.6216423233816286, 1.6334767537555317, 1.6449233339611045, 1.6559791451576025, 1.6666413720664823, 1.6769073031585244, 1.6867743308553405, 1.696239951741974, 1.7053017667876307, 1.713957481571851, 1.7222049065136988, 1.7300419571017889, 1.7374666541231598, 1.744477123889212, 1.7510715984570853, 1.7572484158450195, 1.7630060202403701, 1.768342962199094, 1.7732578988356293, 1.7777495940021997, 1.7818169184566914, 1.785458850018322, 1.788674473710419, 1.791462981889708, 1.7938236743615772, 1.7957559584808684, 1.7972593492377977, 1.7983334693286905, 1.7989780492112648], [1.768823677885006, 1.7686134162648366, 1.7679826848682982, 1.7669316440811527, 1.765460561192537, 1.7635698103643949, 1.7612598725889375, 1.7585313356343901, 1.755384893979362, 1.7518213487362584, 1.7478416075642327, 1.74344668457226, 1.7386377002130258, 1.7334158811683902, 1.7277825602273194, 1.7217391761572765, 1.7152872735701818, 1.7084285027841861, 1.7011646196826453, 1.6934974855718299, 1.6854290670390755, 1.6769614358132663, 1.6680967686297408, 1.6588373471019326, 1.649185557602307, 1.6391438911554255, 1.6287149433462709, 1.6179014142472992, 1.6067061083680676, 1.5951319346316921, 1.5831819063828663, 1.5708591414326913, 1.5581668621461584, 1.5451083955787774, 1.531687173669603, 1.5179067334987493, 1.5037707176184216, 1.4892828744675963, 1.4744470588816854, 1.4592672327099323, 1.4437474655548652, 1.4278919356499555, 1.4117049308937075, 1.3951908500607852, 1.3783542042135355, 1.361199618340399, 1.3437318332513732, 1.3259557077648831, 1.3078762212253106, 1.289498476396118, 1.2708277027801114, 1.2518692604261257, 1.2326286442904533, 1.2131114892319799, 1.1933235757324825, 1.173270836448317, 1.1529593637172053, 1.132395418164566, 1.111585438578562, 1.0905360532525388, 1.0692540930288994, 1.0477466063209817, 1.0260208764407903, 1.0040844416225059, 0.9819451182071051, 0.9596110275453328, 0.9370906272887325, 0.914392747876566, 0.891526635196734, 0.8685020006095711, 0.8453290797852525, 0.8220187021322258, 0.7985823730031807, 0.7750323713793994, 0.751381866383416, 0.727645056791971, 0.7038373387659164, 0.6799755083451209, 0.6560780069572982, 0.6321652203658912, 0.6082598442675206, 0.5843873333098799, 0.5605764548347808, 0.5368599743818142, 0.5132755071380543, 0.48986657824495, 0.46668394512614897, 0.4437872462425822, 0.42124705134452706, 0.39914739476940786, 0.37758886822474064, 0.3566923187013234, 0.336603115649757, 0.317495778463767, 0.2995784320427257, 0.2830960200378134, 0.2683304293674949, 0.25559480086063013, 0.24521880127332674, 0.23752246495676277, 0.2327794646468593, 0.23117632211499411, 0.2327794646468626, 0.2375224649567692, 0.2452188012733361, 0.25559480086064207, 0.268330429367509, 0.2830960200378296, 0.2995784320427435, 0.317495778463786, 0.33660311564977724, 0.35669231870134455, 0.3775888682247625, 0.3991473947694303, 0.42124705134455004, 0.44378724624260557, 0.4666839451261728, 0.48986657824497404, 0.5132755071380786, 0.5368599743818385, 0.5605764548348053, 0.5843873333099044, 0.608259844267545, 0.6321652203659157, 0.6560780069573228, 0.6799755083451454, 0.7038373387659409, 0.7276450567919953, 0.7513818663834403, 0.7750323713794237, 0.7985823730032047, 0.8220187021322499, 0.8453290797852763, 0.8685020006095948, 0.8915266351967576, 0.9143927478765894, 0.9370906272887557, 0.9596110275453558, 0.9819451182071278, 1.0040844416225285, 1.0260208764408127, 1.0477466063210041, 1.0692540930289214, 1.0905360532525605, 1.1115854385785833, 1.1323954181645872, 1.1529593637172262, 1.173270836448338, 1.193323575732503, 1.213111489232, 1.2326286442904733, 1.2518692604261452, 1.2708277027801307, 1.2894984763961368, 1.3078762212253292, 1.3259557077649016, 1.3437318332513912, 1.3611996183404165, 1.3783542042135528, 1.3951908500608026, 1.4117049308937237, 1.4278919356499722, 1.4437474655548812, 1.4592672327099483, 1.474447058881701, 1.4892828744676114, 1.5037707176184365, 1.5179067334987635, 1.5316871736696167, 1.5451083955787908, 1.558166862146172, 1.5708591414327042, 1.5831819063828783, 1.5951319346317039, 1.6067061083680794, 1.6179014142473105, 1.628714943346282, 1.6391438911554361, 1.649185557602317, 1.6588373471019422, 1.6680967686297503, 1.6769614358132752, 1.6854290670390837, 1.6934974855718379, 1.7011646196826529, 1.708428502784193, 1.7152872735701885, 1.721739176157283, 1.7277825602273253, 1.7334158811683957, 1.738637700213031, 1.7434466845722647, 1.747841607564237, 1.7518213487362628, 1.7553848939793653, 1.7585313356343932, 1.7612598725889401, 1.7635698103643966, 1.7654605611925382, 1.7669316440811538, 1.7679826848682991, 1.7686134162648368], [1.7386780767871148, 1.7384725569785728, 1.737856050633068, 1.7368287169868275, 1.735390821419807, 1.7335427354352166, 1.7312849366311749, 1.728618008664821, 1.725542641209287, 1.7220596299040685, 1.7181698762994049, 1.7138743877954024, 1.709174277576746, 1.7040707645439745, 1.6985651732424076, 1.6926589337899745, 1.6863535818053181, 1.6796507583377405, 1.6725522098007028, 1.6650597879108044, 1.657175449634368, 1.6489012571439814, 1.6402393777876105, 1.6311920840731657, 1.62176175367171, 1.611950869442845, 1.6017620194861726, 1.5911978972231633, 1.5802613015142084, 1.5689551368161725, 1.557282413386321, 1.5452462475391588, 1.532849861963446, 1.5200965861074591, 1.5069898566414988, 1.4935332180076843, 1.4797303230682328, 1.465584933864767, 1.4511009225026767, 1.436282272176294, 1.4211330783525604, 1.4056575501330972, 1.3898600118171158, 1.3737449046904995, 1.3573167890697162, 1.340580346633033, 1.3235403830758994, 1.3062018311324426, 1.2885697540108698, 1.2706493492973798, 1.252445953391067, 1.233965046541489, 1.215212258571293, 1.1961933753788156, 1.176914346330289, 1.1573812926685392, 1.1376005170854375, 1.1175785146294077, 1.097321985147791, 1.0768378474977212, 1.0561332557994838, 1.0352156180545067, 1.0140926175078395, 0.9927722372043247, 0.9712627882712311, 0.9495729425611193, 0.9277117704111617, 0.9056887844240074, 0.8835139903568305, 0.8611979464272111, 0.8387518326167467, 0.816187531888033, 0.7935177256431943, 0.7707560062616595, 0.7479170101852128, 0.7250165757990514, 0.7020719313248897, 0.6791019191398774, 0.6561272644151043, 0.6331708977888345, 0.6102583440157172, 0.5874181912240529, 0.5646826586094486, 0.542088284085346, 0.5196767574822472, 0.4974959290126743, 0.47560102618980676, 0.4540561138227307, 0.43293582859163676, 0.41232740767722575, 0.392333002831457, 0.3730722161044706, 0.35468469561918975, 0.3373324704505834, 0.321201466951016, 0.30650133840785204, 0.2934624110028499, 0.28232835348881613, 0.2733433922773871, 0.2667338552374925, 0.26268568838862255, 0.2613219232128851, 0.2626856883886254, 0.266733855237498, 0.2733433922773951, 0.28232835348882646, 0.29346241100286236, 0.3065013384078664, 0.32120146695103186, 0.33733247045060066, 0.3546846956192082, 0.37307221610449004, 0.3923330028314772, 0.4123274076772466, 0.43293582859165824, 0.45405611382275274, 0.47560102618982913, 0.49749592901269696, 0.5196767574822702, 0.5420882840853692, 0.5646826586094719, 0.5874181912240765, 0.6102583440157406, 0.6331708977888582, 0.6561272644151278, 0.6791019191399009, 0.7020719313249132, 0.725016575799075, 0.7479170101852363, 0.7707560062616831, 0.7935177256432177, 0.8161875318880564, 0.8387518326167699, 0.861197946427234, 0.8835139903568533, 0.90568878442403, 0.9277117704111844, 0.9495729425611418, 0.9712627882712533, 0.9927722372043468, 1.014092617507861, 1.0352156180545284, 1.0561332557995053, 1.0768378474977423, 1.097321985147812, 1.1175785146294284, 1.137600517085458, 1.1573812926685596, 1.176914346330309, 1.1961933753788354, 1.2152122585713123, 1.2339650465415082, 1.2524459533910854, 1.2706493492973985, 1.288569754010888, 1.3062018311324606, 1.3235403830759171, 1.3405803466330504, 1.3573167890697335, 1.3737449046905161, 1.389860011817132, 1.4056575501331132, 1.4211330783525762, 1.4362822721763095, 1.4511009225026916, 1.4655849338647817, 1.4797303230682473, 1.493533218007698, 1.5069898566415123, 1.5200965861074722, 1.5328498619634594, 1.545246247539171, 1.557282413386333, 1.5689551368161843, 1.58026130151422, 1.5911978972231742, 1.6017620194861835, 1.6119508694428555, 1.6217617536717202, 1.6311920840731753, 1.6402393777876196, 1.6489012571439896, 1.6571754496343762, 1.6650597879108122, 1.6725522098007104, 1.6796507583377476, 1.686353581805325, 1.692658933789981, 1.6985651732424134, 1.7040707645439799, 1.709174277576751, 1.713874387795407, 1.7181698762994093, 1.7220596299040722, 1.7255426412092905, 1.7286180086648242, 1.7312849366311778, 1.7335427354352184, 1.7353908214198086, 1.7368287169868288, 1.737856050633069, 1.7384725569785733], [1.7087852877727236, 1.7085846352226046, 1.7079827303353632, 1.7069797313983996, 1.7055759022176296, 1.7037716121080413, 1.7015673358808754, 1.698963653827798, 1.6959612517025864, 1.6925609207009615, 1.6887635574393012, 1.6845701639331458, 1.6799818475765047, 1.6749998211231445, 1.6696254026711894, 1.6638600156525345, 1.657705188828752, 1.6511625562953685, 1.6442338574966089, 1.6369209372529197, 1.6292257458038573, 1.6211503388691835, 1.6126968777313309, 1.6038676293427234, 1.5946649664618113, 1.5850913678220875, 1.5751494183387962, 1.5648418093585643, 1.5541713389577136, 1.543140912295666, 1.5317535420305177, 1.5200123488046535, 1.5079205618091285, 1.495481519436522, 1.482698670033064, 1.4695755727620583, 1.4561158985920313, 1.442323431424586, 1.4282020693787227, 1.4137558262504095, 1.398988833168455, 1.3839053404703447, 1.3685097198246534, 1.3528064666300388, 1.3368002027246744, 1.320495679444411, 1.3038977810730439, 1.2870115287338992, 1.269842084778699, 1.2523947577374346, 1.2346750079019813, 1.2166884536266238, 1.1984408784407743, 1.179938239083296, 1.1611866745842951, 1.142192516539526, 1.122962300745108, 1.1035027803867885, 1.083820941009193, 1.063924017527357, 1.0438195135864063, 1.0235152236269216, 1.0030192580749016, 0.9823400721483564, 0.9614864988598182, 0.940467786898427, 0.9192936442003578, 0.8979742881665874, 0.8765205036677329, 0.8549437101934537, 0.8332560397665694, 0.8114704275591748, 0.78960071753096, 0.7676617858721997, 0.7456696855910951, 0.7236418162551552, 0.7015971236985031, 0.6795563354612029, 0.6575422388506024, 0.6355800098191632, 0.6136976023339532, 0.5919262095362706, 0.5703008096690161, 0.5488608113064143, 0.5276508135256294, 0.5067214967379489, 0.48613065799110267, 0.4659443991306087, 0.4462384649081141, 0.4270997074917641, 0.40862761912574136, 0.3909358200409304, 0.37415330820672, 0.35842516799119367, 0.343912301754706, 0.33078961560088455, 0.31924201180434897, 0.30945760630600544, 0.30161791213581746, 0.2958853852461819, 0.29238965885845336, 0.29121471222727646, 0.29238965885845575, 0.2958853852461867, 0.30161791213582445, 0.3094576063060145, 0.3192420118043599, 0.33078961560089726, 0.34391230175472026, 0.35842516799120927, 0.3741533082067367, 0.3909358200409482, 0.40862761912575996, 0.4270997074917834, 0.446238464908134, 0.4659443991306292, 0.4861306579911236, 0.5067214967379703, 0.5276508135256511, 0.5488608113064362, 0.5703008096690384, 0.5919262095362928, 0.6136976023339755, 0.6355800098191857, 0.6575422388506249, 0.6795563354612254, 0.7015971236985259, 0.7236418162551779, 0.7456696855911177, 0.7676617858722222, 0.7896007175309823, 0.8114704275591972, 0.8332560397665917, 0.854943710193476, 0.876520503667755, 0.8979742881666093, 0.9192936442003797, 0.9404677868984486, 0.9614864988598397, 0.9823400721483777, 1.0030192580749226, 1.023515223626943, 1.0438195135864272, 1.0639240175273774, 1.0838209410092132, 1.1035027803868085, 1.122962300745128, 1.1421925165395457, 1.1611866745843147, 1.179938239083315, 1.1984408784407932, 1.2166884536266422, 1.2346750079019995, 1.2523947577374526, 1.2698420847787169, 1.2870115287339168, 1.303897781073061, 1.3204956794444278, 1.3368002027246908, 1.352806466630055, 1.3685097198246694, 1.3839053404703605, 1.3989888331684706, 1.4137558262504244, 1.4282020693787374, 1.4423234314246007, 1.4561158985920455, 1.4695755727620714, 1.4826986700330769, 1.4954815194365352, 1.5079205618091414, 1.520012348804666, 1.5317535420305297, 1.5431409122956776, 1.554171338957725, 1.564841809358575, 1.5751494183388068, 1.5850913678220977, 1.594664966461821, 1.6038676293427327, 1.61269687773134, 1.621150338869192, 1.6292257458038655, 1.6369209372529272, 1.644233857496616, 1.6511625562953753, 1.6577051888287582, 1.6638600156525407, 1.6696254026711952, 1.67499982112315, 1.6799818475765096, 1.6845701639331503, 1.6887635574393052, 1.692560920700965, 1.69596125170259, 1.6989636538278006, 1.7015673358808778, 1.7037716121080433, 1.7055759022176304, 1.706979731398401, 1.7079827303353643, 1.7085846352226057], [1.679174230184608, 1.6789785698787643, 1.6783916414713091, 1.6774136024928932, 1.6760447154960607, 1.6742853480576705, 1.6721359727827423, 1.6695971673101933, 1.6666696143210584, 1.6633541015499547, 1.6596515218006613, 1.6555628729668836, 1.6510892580594023, 1.6462318852409994, 1.6409920678707384, 1.6353712245593688, 1.6293708792378385, 1.6229926612411405, 1.616238305409956, 1.6091096522128363, 1.6016086478919607, 1.5937373446358378, 1.5854979007826555, 1.576892581058407, 1.5679237568543174, 1.5585939065485948, 1.5489056158780514, 1.5388615783657125, 1.528464595811195, 1.5177175788513515, 1.5066235475994678, 1.4951856323722243, 1.4834070745146075, 1.4712912273340941, 1.4588415571566908, 1.4460616445188186, 1.4329551855106286, 1.4195259932881283, 1.4057779997735242, 1.3917152575654665, 1.37734194208349, 1.3626623539738663, 1.3476809218074426, 1.3324022051038242, 1.3168308977206071, 1.300971831651303, 1.2848299812812636, 1.268410468157392, 1.2517185663348704, 1.234759708372691, 1.2175394920596228, 1.2000636879636364, 1.182338247910925, 1.1643693145159164, 1.1461632319013004, 1.1277265577676514, 1.1090660769961103, 1.0901888169954912, 1.071102065037761, 1.0518133878639933, 1.0323306538876438, 1.0126620583745445, 0.9928161520408378, 0.97280187358292, 0.9526285867393666, 0.9323061225862945, 0.9118448278875196, 0.8912556204626885, 0.8705500527042809, 0.8497403845726678, 0.8288396676326268, 0.8078618419708204, 0.7868218481583263, 0.7657357568021835, 0.7446209186716973, 0.7234961388944164, 0.7023818792959315, 0.6813004936043561, 0.6602765009423331, 0.6393369037584871, 0.6185115570519325, 0.5978335963220719, 0.5773399319717831, 0.5570718176494407, 0.537075498837081, 0.5174029452809608, 0.4981126657463056, 0.4792705948407624, 0.4609510276694986, 0.44323755686375943, 0.4262239359155469, 0.41001475104982776, 0.39472573104707437, 0.3804834642827445, 0.3674242354601611, 0.3556916620046311, 0.3454328345324344, 0.33679278726159967, 0.3299073749789821, 0.32489501032326334, 0.3218481501913122, 0.3208257698153919, 0.32184815019131435, 0.32489501032326756, 0.3299073749789882, 0.33679278726160766, 0.34543283453244417, 0.35569166200464253, 0.36742423546017394, 0.3804834642827585, 0.39472573104708963, 0.4100147510498441, 0.426223935915564, 0.4432375568637772, 0.4609510276695172, 0.47927059484078155, 0.4981126657463252, 0.5174029452809809, 0.5370754988371013, 0.5570718176494613, 0.5773399319718042, 0.597833596322093, 0.6185115570519538, 0.6393369037585085, 0.6602765009423547, 0.6813004936043776, 0.7023818792959533, 0.723496138894438, 0.744620918671719, 0.7657357568022052, 0.7868218481583481, 0.8078618419708419, 0.8288396676326484, 0.8497403845726892, 0.8705500527043021, 0.8912556204627097, 0.9118448278875406, 0.9323061225863155, 0.9526285867393876, 0.9728018735829406, 0.9928161520408585, 1.0126620583745647, 1.0323306538876642, 1.051813387864013, 1.0711020650377805, 1.0901888169955107, 1.1090660769961296, 1.1277265577676705, 1.1461632319013193, 1.1643693145159348, 1.1823382479109432, 1.2000636879636544, 1.2175394920596405, 1.2347597083727082, 1.2517185663348878, 1.268410468157409, 1.2848299812812805, 1.3009718316513195, 1.3168308977206233, 1.3324022051038398, 1.347680921807458, 1.3626623539738816, 1.377341942083505, 1.3917152575654814, 1.4057779997735382, 1.419525993288142, 1.4329551855106422, 1.446061644518832, 1.4588415571567042, 1.4712912273341068, 1.48340707451462, 1.4951856323722363, 1.5066235475994794, 1.5177175788513628, 1.5284645958112062, 1.5388615783657227, 1.5489056158780616, 1.5585939065486047, 1.5679237568543267, 1.5768925810584158, 1.5854979007826642, 1.5937373446358458, 1.6016086478919684, 1.6091096522128434, 1.6162383054099632, 1.6229926612411472, 1.6293708792378445, 1.635371224559375, 1.6409920678707437, 1.6462318852410045, 1.651089258059407, 1.655562872966888, 1.659651521800665, 1.6633541015499582, 1.6666696143210618, 1.669597167310196, 1.672135972782745, 1.6742853480576725, 1.676044715496062, 1.677413602492894, 1.6783916414713098, 1.6789785698787647], [1.649873550808585, 1.6496830068133512, 1.6491114271445573, 1.6481589687558407, 1.646825893246389, 1.6451125668758912, 1.643019460586001, 1.6405471500288478, 1.6376963156032884, 1.6344677424997682, 1.6308623207548145, 1.6268810453163878, 1.6225250161214861, 1.617795438187615, 1.6126936217199344, 1.6072209822361427, 1.601379040711386, 1.595169423745751, 1.588593863757202, 1.58165419920311, 1.5743523748338808, 1.566690441982557, 1.5586705588946634, 1.5502949911030335, 1.541566111852822, 1.532486402582467, 1.523058453466954, 1.5132849640304027, 1.5031687438357184, 1.492712713259879, 1.4819199043643214, 1.4707934618709073, 1.459336644255067, 1.4475528249689853, 1.4354454938090873, 1.4230182584436721, 1.4102748461183023, 1.3972191055585454, 1.3838550090919077, 1.3701866550133135, 1.3562182702213432, 1.3419542131556499, 1.3273989770696266, 1.3125571936765266, 1.2974336372119375, 1.2820332289608325, 1.266361042303517, 1.2504223083417132, 1.234222422173939, 1.2177669498984145, 1.2010616364320856, 1.1841124142462898, 1.1669254131332512, 1.1495069711333599, 1.131863646771323, 1.114002232770225, 1.0959297714367278, 1.077653571938635, 1.0591812297284622, 1.0405206484042526, 1.0216800643425012, 1.0026680744887237, 0.9834936677500904, 0.9641662605029976, 0.944695736808035, 0.9250924940172726, 0.9053674945661773, 0.885532324866961, 0.8655992623641783, 0.8455813519794882, 0.8254924933631391, 0.8053475405872554, 0.785162416162052, 0.764954241531119, 0.7447414865042801, 0.724544140411026, 0.7043839080934146, 0.6842844341851387, 0.6642715594107192, 0.6443736128335037, 0.6246217440032052, 0.6050502986827, 0.5856972410932758, 0.5666046241552133, 0.5478191066654721, 0.5293925122736334, 0.5113824188814045, 0.4938527579602553, 0.47687439044307317, 0.4605256085616527, 0.4448924909136683, 0.4300690116985085, 0.41615677671860996, 0.4032642334010368, 0.39150518848840044, 0.3809964779585228, 0.3718546845047546, 0.36419190190660217, 0.358110706054426, 0.35369869231078294, 0.3510231347253015, 0.3501264491914149, 0.35102313472530333, 0.35369869231078654, 0.35811070605443146, 0.3641919019066092, 0.37185468450476333, 0.3809964779585329, 0.39150518848841187, 0.4032642334010495, 0.41615677671862383, 0.43006901169852324, 0.4448924909136839, 0.4605256085616692, 0.4768743904430903, 0.4938527579602731, 0.5113824188814228, 0.5293925122736524, 0.5478191066654912, 0.5666046241552327, 0.5856972410932958, 0.6050502986827202, 0.6246217440032253, 0.644373612833524, 0.6642715594107397, 0.6842844341851593, 0.7043839080934352, 0.7245441404110468, 0.7447414865043007, 0.7649542415311399, 0.7851624161620726, 0.8053475405872761, 0.8254924933631598, 0.8455813519795089, 0.8655992623641988, 0.8855323248669814, 0.9053674945661978, 0.9250924940172927, 0.9446957368080551, 0.9641662605030175, 0.9834936677501103, 1.0026680744887435, 1.0216800643425208, 1.040520648404272, 1.0591812297284815, 1.077653571938654, 1.0959297714367466, 1.1140022327702435, 1.1318636467713412, 1.1495069711333779, 1.1669254131332687, 1.184112414246307, 1.201061636432103, 1.2177669498984316, 1.234222422173956, 1.2504223083417296, 1.2663610423035334, 1.2820332289608483, 1.2974336372119535, 1.3125571936765421, 1.3273989770696415, 1.3419542131556648, 1.3562182702213577, 1.3701866550133277, 1.3838550090919215, 1.3972191055585592, 1.4102748461183157, 1.4230182584436848, 1.4354454938091, 1.4475528249689975, 1.4593366442550793, 1.4707934618709189, 1.4819199043643325, 1.4927127132598899, 1.5031687438357288, 1.5132849640304127, 1.5230584534669638, 1.5324864025824767, 1.5415661118528314, 1.5502949911030421, 1.5586705588946719, 1.5666904419825647, 1.5743523748338886, 1.581654199203117, 1.588593863757209, 1.5951694237457574, 1.601379040711392, 1.6072209822361485, 1.6126936217199395, 1.6177954381876198, 1.6225250161214906, 1.6268810453163915, 1.6308623207548183, 1.6344677424997718, 1.6376963156032918, 1.6405471500288504, 1.6430194605860036, 1.6451125668758932, 1.6468258932463902, 1.6481589687558418, 1.6491114271445582, 1.649683006813352], [1.6209115961595966, 1.6207262911103486, 1.620170428140774, 1.6192441637908928, 1.617947758979189, 1.6162815790305933, 1.6142460937162562, 1.611841877305725, 1.609069608632316, 1.6059300711726556, 1.6024241531415666, 1.5985528476036752, 1.594317252603331, 1.5897185713146618, 1.5847581122138215, 1.579437289275755, 1.5737576221980742, 1.567720736654941, 1.561328364584183, 1.5545823445111975, 1.5474846219136102, 1.5400372496310346, 1.5322423883247653, 1.5241023069927127, 1.5156193835454395, 1.5067961054497643, 1.497635070447051, 1.4881389873540412, 1.4783106769548868, 1.4681530729939474, 1.4576692232798962, 1.4468622909127915, 1.435735555647, 1.42429241540422, 1.4125363879523853, 1.4004711127679368, 1.38810035310086, 1.3754279982640196, 1.3624580661707346, 1.3491947061472214, 1.3356422020495733, 1.3218049757183588, 1.3076875908077723, 1.2932947570306126, 1.278631334865297, 1.2637023407766597, 1.2485129530086123, 1.2330685180138763, 1.2173745575941362, 1.2014367768332068, 1.1852610729163116, 1.1688535449405841, 1.152220504835568, 1.1353684895281253, 1.1183042745040184, 1.1010348889388613, 1.0835676325945178, 1.0659100947038105, 1.0480701750970807, 1.0300561078593053, 1.0118764878467557, 0.9935403004383183, 0.9750569549494069, 0.9564363221967258, 0.9376887767710189, 0.9188252446532834, 0.899857256898801, 0.8807970102136626, 0.8616574353610089, 0.8424522744594491, 0.823196168373911, 0.8039047555484942, 0.7845947837892684, 0.7652842366677135, 0.7459924763747889, 0.7267404049988947, 0.7075506463090292, 0.6884477501686274, 0.6694584216442379, 0.6506117766469667, 0.6319396254704895, 0.6134767847537469, 0.5952614170471432, 0.5773353951004447, 0.5597446849707415, 0.5425397377744509, 0.5257758740529664, 0.5095136369749016, 0.49381908074534625, 0.4787639486660153, 0.4644256817932125, 0.4508871853573158, 0.4382362684606327, 0.4265646669225628, 0.41596656482759303, 0.40653655359969804, 0.3983670139171719, 0.3915449778826607, 0.3861486223205339, 0.38224364516503717, 0.3798798623178239, 0.3790884038404034, 0.37987986231782545, 0.38224364516504034, 0.3861486223205386, 0.39154497788266696, 0.3983670139171796, 0.40653655359970714, 0.41596656482760336, 0.4265646669225742, 0.43823626846064523, 0.4508871853573293, 0.46442568179322674, 0.4787639486660304, 0.493819080745362, 0.509513636974918, 0.5257758740529835, 0.5425397377744684, 0.5597446849707594, 0.5773353951004631, 0.5952614170471618, 0.6134767847537658, 0.6319396254705085, 0.6506117766469859, 0.6694584216442573, 0.6884477501686469, 0.7075506463090487, 0.7267404049989146, 0.7459924763748088, 0.7652842366677334, 0.7845947837892882, 0.8039047555485139, 0.8231961683739308, 0.8424522744594689, 0.8616574353610286, 0.8807970102136823, 0.8998572568988207, 0.9188252446533026, 0.9376887767710382, 0.9564363221967451, 0.9750569549494261, 0.9935403004383374, 1.0118764878467743, 1.030056107859324, 1.0480701750970989, 1.0659100947038285, 1.0835676325945358, 1.101034888938879, 1.1183042745040361, 1.135368489528143, 1.1522205048355854, 1.1688535449406012, 1.1852610729163282, 1.201436776833223, 1.2173745575941524, 1.2330685180138923, 1.248512953008628, 1.263702340776675, 1.278631334865312, 1.2932947570306275, 1.3076875908077867, 1.3218049757183734, 1.3356422020495873, 1.3491947061472354, 1.3624580661707484, 1.375427998264033, 1.3881003531008727, 1.4004711127679494, 1.4125363879523973, 1.424292415404232, 1.4357355556470117, 1.4468622909128028, 1.457669223279907, 1.4681530729939583, 1.478310676954897, 1.488138987354051, 1.4976350704470607, 1.5067961054497736, 1.5156193835454481, 1.524102306992721, 1.5322423883247736, 1.5400372496310422, 1.5474846219136176, 1.5545823445112046, 1.5613283645841893, 1.5677207366549475, 1.5737576221980802, 1.5794372892757609, 1.5847581122138268, 1.5897185713146667, 1.5943172526033353, 1.5985528476036794, 1.6024241531415706, 1.605930071172659, 1.6090696086323186, 1.6118418773057277, 1.6142460937162584, 1.6162815790305955, 1.6179477589791904, 1.6192441637908939, 1.620170428140775, 1.620726291110349], [1.5923163850582873, 1.5921364395920017, 1.5915966552801437, 1.5906971883918752, 1.5894382994031087, 1.5878203530378037, 1.5858438183264594, 1.5835092686824728, 1.5808173819972469, 1.577768940755141, 1.574364832169565, 1.5706060483417528, 1.5664936864439853, 1.5620289489292876, 1.5572131437698926, 1.5520476847270461, 1.5465340916550352, 1.5406739908426523, 1.5344691153956656, 1.5279213056642322, 1.5210325097196415, 1.5138047838851891, 1.5062402933265087, 1.4983413127072123, 1.4901102269162942, 1.48154953187439, 1.4726618354267091, 1.4634498583312474, 1.4539164353517449, 1.444064516465831, 1.4338971681998438, 1.423417575103003, 1.412629041374915, 1.4015349926618472, 1.3901389780388074, 1.3784446721962855, 1.3664558778524984, 1.3541765284142324, 1.3416106909118644, 1.328762569236953, 1.3156365077139172, 1.302236995040834, 1.2885686686383275, 1.2746363194499548, 1.2604448972424698, 1.2459995164599502, 1.2313054626920976, 1.2163681998241265, 1.2011933779437, 1.1857868420894513, 1.1701546419358617, 1.1543030425208842, 1.1382385361357885, 1.1219678555115644, 1.105497988453, 1.0888361940905598, 1.0719900209417, 1.054967326997588, 1.0377763020786746, 1.0204254927336267, 1.0029238299911094, 0.9852806603132656, 0.9675057801438857, 0.949609474493598, 0.9316025600592747, 0.9134964334354979, 0.8953031250424031, 0.8770353594663318, 0.8587066229867882, 0.8403312391439504, 0.8219244532832118, 0.8035025270934049, 0.7850828442281266, 0.7666840281570338, 0.7483260734247288, 0.7300304914828258, 0.7118204721836794, 0.6937210618515853, 0.6757593585381191, 0.6579647245686475, 0.640369015727134, 0.6230068253181434, 0.6059157397809799, 0.5891366003855718, 0.5727137626755613, 0.5566953416059462, 0.5411334256451377, 0.5260842374442658, 0.5116082121349236, 0.4977699572575277, 0.4846380514665881, 0.47228463371649704, 0.4607847323918513, 0.4502152871598218, 0.4406538278668761, 0.432176797031939, 0.4248575367060542, 0.41876400562558724, 0.4139563441465969, 0.4104844539298572, 0.40838579522351004, 0.4076836149417127, 0.4083857952235115, 0.41048445392986005, 0.41395634414660115, 0.41876400562559285, 0.424857536706061, 0.43217679703194717, 0.44065382786688545, 0.4502152871598321, 0.4607847323918627, 0.4722846337165093, 0.4846380514666012, 0.4977699572575416, 0.5116082121349381, 0.526084237444281, 0.5411334256451533, 0.5566953416059626, 0.572713762675578, 0.5891366003855888, 0.6059157397809973, 0.6230068253181612, 0.6403690157271519, 0.6579647245686657, 0.6757593585381374, 0.6937210618516038, 0.7118204721836979, 0.7300304914828446, 0.7483260734247477, 0.7666840281570527, 0.7850828442281454, 0.8035025270934237, 0.8219244532832306, 0.8403312391439692, 0.8587066229868071, 0.8770353594663507, 0.8953031250424218, 0.9134964334355167, 0.9316025600592933, 0.9496094744936163, 0.9675057801439041, 0.9852806603132841, 1.0029238299911276, 1.0204254927336445, 1.0377763020786925, 1.0549673269976059, 1.0719900209417175, 1.0888361940905766, 1.1054979884530172, 1.1219678555115813, 1.138238536135805, 1.1543030425209007, 1.170154641935878, 1.1857868420894673, 1.2011933779437158, 1.2163681998241418, 1.231305462692113, 1.2459995164599649, 1.2604448972424842, 1.2746363194499692, 1.2885686686383415, 1.3022369950408477, 1.3156365077139305, 1.328762569236966, 1.3416106909118772, 1.3541765284142453, 1.3664558778525109, 1.3784446721962975, 1.3901389780388191, 1.4015349926618588, 1.4126290413749263, 1.4234175751030136, 1.4338971681998545, 1.4440645164658417, 1.4539164353517549, 1.4634498583312567, 1.472661835426719, 1.4815495318743994, 1.4901102269163031, 1.4983413127072205, 1.5062402933265162, 1.5138047838851967, 1.521032509719649, 1.5279213056642391, 1.534469115395672, 1.5406739908426585, 1.546534091655041, 1.5520476847270517, 1.5572131437698975, 1.5620289489292922, 1.5664936864439893, 1.570606048341757, 1.5743648321695687, 1.5777689407551443, 1.5808173819972497, 1.5835092686824752, 1.585843818326462, 1.5878203530378059, 1.58943829940311, 1.5906971883918763, 1.5915966552801444, 1.592136439592002], [1.5641155815246053, 1.5639411136535022, 1.5634177620752183, 1.5625456829056605, 1.561325136374213, 1.5597564868784088, 1.5578402030612115, 1.5555768579116451, 1.5529671288897304, 1.5500117980769357, 1.5467117523535496, 1.5430679836046741, 1.5390815889567555, 1.534753771046873, 1.5300858383272828, 1.5250792054080275, 1.5197353934407483, 1.5140560305471975, 1.5080428522963312, 1.5016977022342604, 1.495022532471813, 1.4880194043349158, 1.4806904890835497, 1.4730380687056066, 1.4650645367926012, 1.4567723995048776, 1.4481642766347198, 1.439242902776585, 1.4300111286146087, 1.4204719223385318, 1.4106283712002983, 1.4004836832248146, 1.3900411890897033, 1.379304344190387, 1.3682767309084987, 1.3569620611034594, 1.345364178849108, 1.3334870634395393, 1.3213348326908427, 1.3089117465682436, 1.2962222111712896, 1.2832707831132253, 1.2700621743346026, 1.2566012573955379, 1.242893071295898, 1.2289428278781525, 1.2147559188737227, 1.2003379236604863, 1.18569461780673, 1.1708319824854034, 1.1557562148521006, 1.140473739490925, 1.1249912210443993, 1.10931557815701, 1.0934539988769998, 1.0774139576777937, 1.0612032342791455, 1.0448299344689158, 1.0283025131495216, 1.011629799858689, 0.994821027042372, 0.9778858613886809, 0.9608344385654274, 0.943677401740411, 0.9264259443026545, 0.909091857243995, 0.8916875817030998, 0.8742262672169165, 0.8567218362661233, 0.8391890557387861, 0.8216436159666363, 0.8041022180061848, 0.7865826698355034, 0.7691039921077291, 0.7516865340319084, 0.7343520998245407, 0.7171240859701167, 0.7000276292192732, 0.6830897648052793, 0.6663395937322009, 0.6498084571321295, 0.6335301145480324, 0.617540921512105, 0.6018799998966767, 0.5865893921657134, 0.5717141878256765, 0.5573026070903475, 0.543406023142894, 0.5300789006318612, 0.5173786245797453, 0.5053651913338372, 0.494100732411007, 0.48364884416277426, 0.47407370231396445, 0.46543895170840266, 0.45780637868414, 0.45123439616058636, 0.4457763981681066, 0.4414790679868843, 0.4383807475989366, 0.4365099903346202, 0.4358844184753947, 0.4365099903346215, 0.43838074759893914, 0.441479067986888, 0.4457763981681116, 0.4512343961605925, 0.45780637868414725, 0.46543895170841104, 0.4740737023139737, 0.48364884416278464, 0.49410073241101815, 0.5053651913338493, 0.5173786245797579, 0.5300789006318747, 0.5434060231429081, 0.5573026070903622, 0.5717141878256916, 0.5865893921657289, 0.6018799998966927, 0.6175409215121215, 0.6335301145480492, 0.6498084571321463, 0.666339593732218, 0.6830897648052965, 0.7000276292192906, 0.7171240859701343, 0.7343520998245585, 0.7516865340319263, 0.769103992107747, 0.7865826698355213, 0.8041022180062026, 0.8216436159666544, 0.8391890557388041, 0.8567218362661412, 0.8742262672169344, 0.8916875817031178, 0.909091857244013, 0.9264259443026722, 0.9436774017404288, 0.9608344385654449, 0.9778858613886986, 0.9948210270423893, 1.0116297998587063, 1.0283025131495387, 1.0448299344689327, 1.061203234279162, 1.0774139576778103, 1.0934539988770162, 1.109315578157026, 1.1249912210444155, 1.1404737394909408, 1.155756214852116, 1.170831982485419, 1.1856946178067453, 1.2003379236605014, 1.2147559188737376, 1.2289428278781669, 1.2428930712959123, 1.256601257395552, 1.270062174334616, 1.2832707831132386, 1.2962222111713029, 1.3089117465682565, 1.3213348326908552, 1.3334870634395515, 1.34536417884912, 1.356962061103471, 1.36827673090851, 1.3793043441903983, 1.3900411890897144, 1.400483683224825, 1.4106283712003085, 1.420471922338542, 1.4300111286146187, 1.439242902776594, 1.4481642766347291, 1.4567723995048867, 1.4650645367926096, 1.4730380687056148, 1.4806904890835573, 1.488019404334923, 1.49502253247182, 1.5016977022342668, 1.5080428522963376, 1.5140560305472037, 1.5197353934407536, 1.5250792054080327, 1.5300858383272877, 1.5347537710468777, 1.53908158895676, 1.5430679836046781, 1.5467117523535532, 1.5500117980769388, 1.5529671288897338, 1.5555768579116476, 1.5578402030612142, 1.5597564868784104, 1.5613251363742144, 1.5625456829056614, 1.563417762075219, 1.5639411136535026], [1.5363364680146492, 1.5361675924382945, 1.5356610177215406, 1.5348168999147793, 1.5336354991469654, 1.5321171796934667, 1.5302624100718418, 1.5280717631663567, 1.5255459163822604, 1.5226856518311216, 1.5194918565487403, 1.5159655227474598, 1.512107748104933, 1.5079197360917331, 1.5034027963404748, 1.4985583450594668, 1.4933879054942416, 1.4878931084407085, 1.482075692814063, 1.4759375062780227, 1.469480505939436, 1.4627067591138092, 1.455618444167857, 1.4482178514457744, 1.4405073842865865, 1.4324895601406413, 1.4241670117940979, 1.415542488711104, 1.406618858504308, 1.3973991085453616, 1.3878863477282077, 1.3780838083991895, 1.367994848469378, 1.357622953726027, 1.3469717403617214, 1.336044957741632, 1.3248464914312992, 1.313380366509627, 1.3016507511942452, 1.2896619608091358, 1.2774184621274787, 1.2649248781260316, 1.2521859931911012, 1.2392067588203113, 1.2259922998689732, 1.2125479213949584, 1.1988791161616426, 1.1849915728647622, 1.170891185155978, 1.1565840615436669, 1.1420765362599823, 1.1273751811926862, 1.1124868189906774, 1.097418537463656, 1.082177705409023, 1.0667719900130108, 1.0512093759882501, 1.0354981866265274, 1.0196471069634336, 1.0036652092709286, 0.987561981114444, 0.9713473562329332, 0.9550317485229363, 0.938626089430876, 0.9221418690808262, 0.9055911814869994, 0.8889867742199562, 0.8723421029113281, 0.8556713909913438, 0.8389896950535723, 0.822312976227926, 0.8056581779107692, 0.789043310143032, 0.7724875408347255, 0.7560112938960761, 0.7396363541378393, 0.7233859785293859, 0.7072850130326973, 0.6913600137400423, 0.6756393704064283, 0.6601534296567919, 0.6449346141345081, 0.6300175326184654, 0.6154390746569179, 0.6012384815524494, 0.5874573836189075, 0.574139791599121, 0.5613320281263943, 0.5490825833605446, 0.5374418777559852, 0.5264619147534537, 0.5161958075448835, 0.5066971674999631, 0.4980193478714069, 0.490214545335525, 0.4833327737345893, 0.47742073848230865, 0.47252065521106457, 0.468669070433332, 0.46589575281955525, 0.46422272864131964, 0.4636635319853507, 0.4642227286413208, 0.46589575281955753, 0.4686690704333354, 0.472520655211069, 0.47742073848231414, 0.48333277373459593, 0.49021454533553255, 0.4980193478714154, 0.5066971674999725, 0.5161958075448937, 0.5264619147534646, 0.5374418777559968, 0.5490825833605568, 0.5613320281264071, 0.5741397915991344, 0.5874573836189214, 0.6012384815524638, 0.6154390746569327, 0.6300175326184808, 0.6449346141345237, 0.6601534296568077, 0.6756393704064444, 0.6913600137400585, 0.7072850130327137, 0.7233859785294025, 0.7396363541378562, 0.7560112938960928, 0.7724875408347425, 0.7890433101430488, 0.8056581779107863, 0.8223129762279431, 0.8389896950535896, 0.855671390991361, 0.8723421029113453, 0.8889867742199733, 0.9055911814870163, 0.9221418690808433, 0.9386260894308929, 0.955031748522953, 0.9713473562329499, 0.9875619811144605, 1.0036652092709453, 1.0196471069634498, 1.0354981866265438, 1.0512093759882664, 1.0667719900130268, 1.0821777054090387, 1.0974185374636714, 1.112486818990693, 1.1273751811927013, 1.1420765362599972, 1.1565840615436815, 1.1708911851559924, 1.1849915728647764, 1.198879116161657, 1.2125479213949724, 1.2259922998689867, 1.2392067588203246, 1.2521859931911141, 1.2649248781260445, 1.2774184621274913, 1.2896619608091484, 1.3016507511942574, 1.313380366509639, 1.3248464914313107, 1.3360449577416431, 1.3469717403617325, 1.3576229537260376, 1.367994848469389, 1.3780838083991998, 1.3878863477282173, 1.3973991085453712, 1.4066188585043178, 1.4155424887111128, 1.4241670117941065, 1.4324895601406498, 1.4405073842865947, 1.448217851445782, 1.4556184441678641, 1.4627067591138159, 1.469480505939443, 1.475937506278029, 1.482075692814069, 1.487893108440714, 1.4933879054942467, 1.498558345059472, 1.5034027963404795, 1.5079197360917376, 1.512107748104937, 1.5159655227474638, 1.5194918565487436, 1.5226856518311245, 1.5255459163822636, 1.5280717631663596, 1.5302624100718443, 1.5321171796934685, 1.5336354991469672, 1.53481689991478, 1.5356610177215408, 1.5361675924382947], [1.5090059190266547, 1.5088427463803, 1.5083532804485538, 1.5075376772693572, 1.5063961969593629, 1.5049292037944746, 1.503137166323448, 1.5010206575153895, 1.498580354942253, 1.495817040997694, 1.492731603153898, 1.489325034258287, 1.4855984328722993, 1.4815530036547362, 1.477190057792502, 1.472511013481901, 1.4675173964640205, 1.4622108406181178, 1.4565930886173504, 1.4506659926516299, 1.4444315152228688, 1.437891730018406, 1.431048822868965, 1.4239050927981034, 1.416462953170782, 1.4087249329493972, 1.4006936780664123, 1.3923719529235725, 1.3837626420286313, 1.3748687517815328, 1.3656934124231115, 1.3562398801606066, 1.3465115394856173, 1.3365119057016013, 1.3262446276796418, 1.3157134908629753, 1.304922420542721, 1.293875485429402, 1.282576901547195, 1.2710310364804511, 1.2592424140048546, 1.2472157191387514, 1.2349558036536017, 1.2224676920863091, 1.209756588300356, 1.1968278826472303, 1.1836871597846685, 1.1703402072137483, 1.156793024602887, 1.143051833973412, 1.1291230908285674, 1.1150134963156568, 1.100730010519538, 1.0862798669948859, 1.071670588654556, 1.0569100051419833, 1.04200627182684, 1.0269678905750683, 1.0118037324567921, 0.9965230625683533, 0.9811355671575307, 0.9656513832535784, 0.9500811310155326, 0.9344359490226818, 0.9187275327392521, 0.9029681763900926, 0.8871708184839531, 0.8713490912138561, 0.8555173739476007, 0.8396908509924337, 0.823885573772395, 0.8081185274898994, 0.7924077022486695, 0.7767721684858871, 0.7612321563886563, 0.7458091387433604, 0.7305259163746648, 0.7154067049609159, 0.7004772215511027, 0.6857647685421571, 0.6712983121928764, 0.6571085519450319, 0.6432279758937656, 0.6296908967108367, 0.616533461206436, 0.6037936255739987, 0.591511087286482, 0.5797271637307646, 0.5684846071530535, 0.5578273455610624, 0.5478001401422652, 0.5384481517787275, 0.5298164126084026, 0.5219492034570852, 0.5148893443453678, 0.5086774129302872, 0.5033509141492295, 0.498943432660162, 0.4954838068208166, 0.49299536769469166, 0.4914952877738419, 0.49099408097334535, 0.4914952877738429, 0.49299536769469365, 0.4954838068208196, 0.49894343266016605, 0.5033509141492345, 0.5086774129302932, 0.5148893443453747, 0.5219492034570928, 0.5298164126084112, 0.5384481517787368, 0.5478001401422752, 0.557827345561073, 0.5684846071530648, 0.5797271637307764, 0.5915110872864945, 0.6037936255740117, 0.6165334612064495, 0.6296908967108504, 0.6432279758937798, 0.6571085519450464, 0.6712983121928912, 0.6857647685421722, 0.7004772215511179, 0.7154067049609313, 0.7305259163746803, 0.7458091387433762, 0.761232156388672, 0.7767721684859034, 0.7924077022486855, 0.8081185274899155, 0.8238855737724111, 0.83969085099245, 0.8555173739476168, 0.8713490912138722, 0.8871708184839694, 0.9029681763901088, 0.9187275327392683, 0.9344359490226979, 0.9500811310155488, 0.9656513832535946, 0.9811355671575466, 0.996523062568369, 1.0118037324568079, 1.0269678905750839, 1.0420062718268552, 1.0569100051419984, 1.0716705886545712, 1.0862798669949008, 1.1007300105195525, 1.1150134963156715, 1.1291230908285816, 1.1430518339734261, 1.1567930246029008, 1.1703402072137623, 1.183687159784682, 1.1968278826472434, 1.2097565883003694, 1.222467692086322, 1.2349558036536141, 1.247215719138764, 1.2592424140048668, 1.2710310364804631, 1.2825769015472068, 1.2938754854294132, 1.3049224205427323, 1.3157134908629862, 1.3262446276796525, 1.3365119057016117, 1.3465115394856277, 1.3562398801606166, 1.3656934124231208, 1.3748687517815419, 1.3837626420286404, 1.392371952923581, 1.4006936780664208, 1.4087249329494054, 1.4164629531707897, 1.423905092798111, 1.4310488228689722, 1.4378917300184124, 1.4444315152228755, 1.450665992651636, 1.4565930886173561, 1.4622108406181233, 1.4675173964640256, 1.472511013481906, 1.4771900577925063, 1.4815530036547406, 1.4855984328723033, 1.4893250342582907, 1.492731603153901, 1.4958170409976972, 1.4985803549422558, 1.501020657515392, 1.5031371663234503, 1.5049292037944766, 1.506396196959364, 1.507537677269358, 1.5083532804485544, 1.5088427463803005], [1.4821503751016516, 1.481993011139136, 1.4815209712584887, 1.4807344114987728, 1.4796335919864443, 1.4782188770278082, 1.476490735239338, 1.474449739716725, 1.4720965682438063, 1.4694320035427793, 1.4664569335673832, 1.4631723518410227, 1.4595793578421103, 1.4556791574392072, 1.451473063378888, 1.4469624958295986, 1.4421489829851417, 1.4370341617318392, 1.4316197783838198, 1.4259076894913512, 1.4198998627276134, 1.4135983778598316, 1.4070054278112574, 1.4001233198210825, 1.39295447671004, 1.3855014382601505, 1.3777668627178459, 1.3697535284305438, 1.3614643356276495, 1.3529023083579597, 1.34407059659652, 1.3349724785351544, 1.3256113630721758, 1.3159907925181746, 1.306114445536307, 1.2959861403371655, 1.2856098381501244, 1.2749896469950346, 1.2641298257802909, 1.2530347887556574, 1.2417091103507973, 1.230157530433251, 1.218384960022648, 1.2063964875012538, 1.1941973853645618, 1.1817931175595175, 1.1691893474622275, 1.1563919465515493, 1.143407003839894, 1.130240836127866, 1.1168999991550141, 1.103391299725007, 1.0897218088899083, 1.0758988762849357, 1.0619301457120565, 1.0478235720779343, 1.0335874397990081, 1.0192303827936824, 1.0047614061885282, 0.9901899098717999, 0.975525714033042, 0.9607790868316937, 0.9459607743397068, 0.9310820329025815, 0.9161546640588526, 0.9011910521487236, 0.8862042047267039, 0.8712077958688722, 0.8562162124304236, 0.8412446032606936, 0.826308931317471, 0.8114260285361748, 0.7966136531977208, 0.7818905493963192, 0.7672765080291395, 0.7527924285073141, 0.7384603801155283, 0.7243036616190581, 0.7103468573271142, 0.6966158873661853, 0.6831380493965847, 0.6699420484246552, 0.6570580107347863, 0.6445174773127422, 0.6323533714917547, 0.6205999349792433, 0.6092926259884482, 0.5984679730000816, 0.5881633778283045, 0.5784168622909727, 0.5692667540172464, 0.5607513088825292, 0.5529082703175774, 0.5457743693012078, 0.5393847731171185, 0.5337724957074154, 0.5289677873178764, 0.5249975256004719, 0.5218846338269671, 0.5196475537733528, 0.5182998006521728, 0.5178496248983484, 0.5182998006521738, 0.5196475537733547, 0.5218846338269699, 0.5249975256004754, 0.528967787317881, 0.5337724957074207, 0.5393847731171246, 0.5457743693012148, 0.5529082703175852, 0.5607513088825377, 0.5692667540172555, 0.5784168622909824, 0.588163377828315, 0.5984679730000925, 0.6092926259884596, 0.6205999349792553, 0.6323533714917671, 0.6445174773127549, 0.6570580107347994, 0.6699420484246686, 0.6831380493965983, 0.6966158873661994, 0.7103468573271284, 0.7243036616190726, 0.7384603801155429, 0.7527924285073289, 0.7672765080291543, 0.7818905493963343, 0.796613653197736, 0.8114260285361901, 0.8263089313174862, 0.841244603260709, 0.856216212430439, 0.8712077958688875, 0.8862042047267195, 0.901191052148739, 0.9161546640588683, 0.9310820329025968, 0.9459607743397221, 0.960779086831709, 0.9755257140330572, 0.9901899098718149, 1.0047614061885433, 1.019230382793697, 1.0335874397990228, 1.0478235720779487, 1.0619301457120711, 1.07589887628495, 1.0897218088899223, 1.103391299725021, 1.116899999155028, 1.1302408361278795, 1.1434070038399073, 1.1563919465515624, 1.1691893474622406, 1.1817931175595302, 1.1941973853645742, 1.2063964875012663, 1.2183849600226597, 1.2301575304332633, 1.241709110350809, 1.2530347887556688, 1.264129825780302, 1.274989646995046, 1.285609838150135, 1.2959861403371757, 1.3061144455363172, 1.3159907925181848, 1.3256113630721857, 1.3349724785351638, 1.3440705965965292, 1.3529023083579685, 1.3614643356276581, 1.3697535284305522, 1.3777668627178543, 1.385501438260158, 1.3929544767100472, 1.4001233198210896, 1.4070054278112643, 1.4135983778598382, 1.4198998627276194, 1.4259076894913572, 1.4316197783838254, 1.4370341617318445, 1.4421489829851468, 1.4469624958296032, 1.4514730633788924, 1.4556791574392112, 1.4595793578421141, 1.463172351841026, 1.4664569335673863, 1.4694320035427826, 1.4720965682438087, 1.474449739716727, 1.4764907352393402, 1.47821887702781, 1.4796335919864454, 1.480734411498774, 1.4815209712584896, 1.4819930111391364], [1.45579581724395, 1.4556443619541495, 1.4551900480810867, 1.45443303163431, 1.4533735726982997, 1.452012035535762, 1.4503488887331337, 1.4483847053891974, 1.4461201633479634, 1.443556045477271, 1.4406932399948111, 1.437532740843593, 1.4340756481191597, 1.4303231685511897, 1.4262766160424432, 1.4219374122683752, 1.4173070873410964, 1.4123872805417634, 1.407179741125906, 1.4016863292066277, 1.3959090167211112, 1.389849888486367, 1.3835111433507021, 1.3768950954479997, 1.3700041755625043, 1.3628409326125228, 1.3554080352621662, 1.3477082736710708, 1.339744561392887, 1.3315199374342646, 1.3230375684870699, 1.314300751347654, 1.3053129155381842, 1.2960776261463225, 1.2865985869009149, 1.2768796435028686, 1.2669247872319993, 1.256738158852394, 1.2463240528407271, 1.235686921964014, 1.2248313822354915, 1.2137622182796919, 1.2024843891403363, 1.191003034567402, 1.1793234818226717, 1.1674512530461763, 1.1553920732292988, 1.1431518788438026, 1.1307368271797673, 1.118153306449296, 1.1054079467168643, 1.0925076317213311, 1.079459511658799, 1.0662710169997023, 1.0529498734175478, 1.0395041179105777, 1.0259421162010356, 1.0122725814995668, 0.9985045947242235, 0.9846476262643091, 0.9707115593784323, 0.9567067153131319, 0.9426438802226678, 0.9285343339612226, 0.9143898808049234, 0.9002228821415842, 0.8860462911395399, 0.8718736893717557, 0.8577193253256344, 0.843598154670429, 0.8295258820803249, 0.8155190043193172, 0.8015948541808392, 0.7877716447374393, 0.7740685131903322, 0.7605055634121977, 0.7471039060465281, 0.7338856947614208, 0.7208741569548701, 0.7080936168746219, 0.6955695087542187, 0.683328377188341, 0.6713978615913233, 0.6598066612265905, 0.6485844769943199, 0.6377619259620723, 0.6273704245704208, 0.617442036603171, 0.6080092824454578, 0.5991049069284672, 0.590761604233775, 0.5830116999404128, 0.5758867923474024, 0.5694173576495684, 0.5636323262808878, 0.5585586405962413, 0.5542208068030755, 0.5506404563926804, 0.5478359339484672, 0.5458219288375323, 0.5446091677021763, 0.54420418275605, 0.544609167702177, 0.5458219288375339, 0.5478359339484697, 0.5506404563926838, 0.5542208068030795, 0.5585586405962462, 0.5636323262808934, 0.5694173576495747, 0.5758867923474095, 0.5830116999404206, 0.5907616042337833, 0.5991049069284761, 0.6080092824454671, 0.6174420366031809, 0.6273704245704312, 0.6377619259620833, 0.6485844769943312, 0.6598066612266021, 0.6713978615913354, 0.6833283771883536, 0.6955695087542314, 0.7080936168746349, 0.7208741569548833, 0.7338856947614343, 0.7471039060465418, 0.7605055634122115, 0.7740685131903462, 0.7877716447374534, 0.8015948541808533, 0.8155190043193317, 0.8295258820803394, 0.8435981546704435, 0.857719325325649, 0.8718736893717701, 0.8860462911395547, 0.9002228821415987, 0.914389880804938, 0.9285343339612371, 0.9426438802226823, 0.9567067153131465, 0.9707115593784468, 0.9846476262643235, 0.9985045947242376, 1.0122725814995808, 1.0259421162010496, 1.0395041179105915, 1.0529498734175617, 1.0662710169997156, 1.0794595116588126, 1.0925076317213445, 1.1054079467168774, 1.1181533064493088, 1.1307368271797802, 1.1431518788438153, 1.1553920732293115, 1.1674512530461887, 1.1793234818226837, 1.191003034567414, 1.2024843891403478, 1.2137622182797034, 1.2248313822355026, 1.2356869219640252, 1.246324052840738, 1.2567381588524045, 1.2669247872320097, 1.2768796435028786, 1.2865985869009247, 1.296077626146332, 1.3053129155381937, 1.3143007513476628, 1.3230375684870785, 1.3315199374342732, 1.3397445613928953, 1.347708273671079, 1.355408035262174, 1.3628409326125304, 1.3700041755625116, 1.3768950954480066, 1.383511143350709, 1.3898498884863733, 1.3959090167211174, 1.4016863292066333, 1.4071797411259115, 1.4123872805417685, 1.4173070873411011, 1.42193741226838, 1.4262766160424472, 1.4303231685511937, 1.434075648119163, 1.4375327408435963, 1.4406932399948138, 1.4435560454772736, 1.446120163347966, 1.4483847053891996, 1.4503488887331362, 1.4520120355357633, 1.4533735726983008, 1.4544330316343108, 1.4551900480810873, 1.45564436195415], [1.4299677417861951, 1.4298222884428535, 1.4293859803722586, 1.428658973475123, 1.4276415276608299, 1.4263340069601764, 1.4247368796841076, 1.422850718629348, 1.4206762013320846, 1.4182141103711627, 1.4154653337224943, 1.4124308651666975, 1.409111804752281, 1.4055093593169898, 1.4016248430702711, 1.3974596782401525, 1.3930153957881988, 1.3882936361965823, 1.3832961503317296, 1.3780248003894076, 1.3724815609266103, 1.366668519986056, 1.3605878803196596, 1.3542419607178797, 1.3476331974524525, 1.34076414584066, 1.3336374819399544, 1.3262560043825202, 1.3186226363601248, 1.3107404277704633, 1.302612557537122, 1.2942423361162498, 1.2856332082040887, 1.2767887556606372, 1.2677127006659243, 1.2584089091266801, 1.2488813943525638, 1.2391343210225987, 1.2291720094640446, 1.218998940267627, 1.2086197592648307, 1.1980392828948685, 1.1872625039909386, 1.1762945980174937, 1.1651409297924662, 1.1538070607306656, 1.1422987566469738, 1.130621996160364, 1.1187829797422506, 1.1067881394551184, 1.0946441494297894, 1.0823579371319634, 1.0699366954707665, 1.0573878958038425, 1.0447193018949061, 1.0319389848805036, 1.0190553393027724, 1.0060771002640772, 0.9930133617571765, 0.9798735962207543, 0.9666676753642774, 0.9534058922977399, 0.94009898499032, 0.9267581610666021, 0.9133951239290096, 0.900022100169448, 0.8866518682008329, 0.8732977879988802, 0.8599738317948925, 0.8466946154997624, 0.8334754305663614, 0.8203322759102115, 0.8072818894051397, 0.7943417783499137, 0.781530248162374, 0.7688664283985145, 0.7563702950153421, 0.7440626875993108, 0.7319653200694856, 0.7201007831412811, 0.7084925366103402, 0.6971648892979965, 0.686142964304937, 0.6754526470677649, 0.6651205136285488, 0.6551737365390056, 0.6456399659611873, 0.6365471838298183, 0.6279235294411093, 0.6197970955572519, 0.612195695082782, 0.6051465995800558, 0.5986762523247166, 0.5928099602082236, 0.5875715704911072, 0.5829831400833387, 0.5790646065357186, 0.5758334711109545, 0.5733045050079809, 0.5714894899021989, 0.5703970033454606, 0.570032258213805, 0.5703970033454613, 0.5714894899022005, 0.5733045050079831, 0.5758334711109575, 0.5790646065357221, 0.5829831400833432, 0.5875715704911123, 0.5928099602082293, 0.598676252324723, 0.6051465995800628, 0.6121956950827896, 0.6197970955572599, 0.6279235294411178, 0.6365471838298274, 0.645639965961197, 0.6551737365390157, 0.6651205136285593, 0.6754526470677757, 0.6861429643049483, 0.697164889298008, 0.7084925366103519, 0.7201007831412932, 0.7319653200694977, 0.7440626875993233, 0.7563702950153549, 0.7688664283985275, 0.7815302481623871, 0.7943417783499271, 0.8072818894051528, 0.8203322759102248, 0.833475430566375, 0.8466946154997761, 0.859973831794906, 0.8732977879988938, 0.8866518682008467, 0.9000221001694618, 0.9133951239290234, 0.9267581610666159, 0.9400989849903335, 0.9534058922977536, 0.9666676753642909, 0.979873596220768, 0.9930133617571901, 1.0060771002640907, 1.0190553393027855, 1.031938984880517, 1.0447193018949192, 1.0573878958038554, 1.0699366954707794, 1.0823579371319763, 1.0946441494298018, 1.1067881394551307, 1.1187829797422626, 1.130621996160376, 1.1422987566469858, 1.1538070607306772, 1.1651409297924775, 1.1762945980175052, 1.1872625039909495, 1.1980392828948796, 1.2086197592648413, 1.2189989402676378, 1.2291720094640548, 1.239134321022609, 1.2488813943525738, 1.2584089091266897, 1.2677127006659337, 1.2767887556606465, 1.285633208204098, 1.2942423361162583, 1.3026125575371303, 1.3107404277704713, 1.3186226363601328, 1.326256004382528, 1.3336374819399621, 1.3407641458406676, 1.3476331974524596, 1.3542419607178862, 1.3605878803196663, 1.3666685199860624, 1.372481560926616, 1.3780248003894129, 1.3832961503317345, 1.3882936361965874, 1.3930153957882032, 1.397459678240157, 1.4016248430702751, 1.4055093593169936, 1.4091118047522846, 1.4124308651667006, 1.4154653337224974, 1.4182141103711656, 1.4206762013320868, 1.4228507186293498, 1.4247368796841098, 1.4263340069601775, 1.427641527660831, 1.4286589734751243, 1.4293859803722595, 1.429822288442854], [1.404691135723312, 1.4045517698690921, 1.404133724185038, 1.403437154330944, 1.4024623198198465, 1.401209584138526, 1.3996794149171004, 1.397872384148585, 1.3957891684595651, 1.3934305494334072, 1.390797413987682, 1.3878907548077806, 1.384711670838974, 1.3812613678394914, 1.3775411589974875, 1.3735524656151208, 1.369296817863288, 1.3647758556109504, 1.3599913293333439, 1.3549451011037956, 1.3496391456742824, 1.3440755516503233, 1.3382565227662893, 1.3321843792677133, 1.325861559407739, 1.319290621065416, 1.312474243494175, 1.3054152292094647, 1.298116506025235, 1.2905811292496947, 1.2828122840515594, 1.2748132880088525, 1.2665875938532034, 1.2581387924235583, 1.2494706158441884, 1.240586940942983, 1.2314917929271014, 1.222189349334257, 1.2126839442791435, 1.2029800730157956, 1.1930823968380362, 1.1829957483415516, 1.1727251370725555, 1.1622757555894856, 1.1516529859656197, 1.1408624067619915, 1.1299098005013923, 1.118801161675639, 1.1075427053195315, 1.0961408761860598, 1.0846023585582976, 1.0729340867340424, 1.0611432562194854, 1.0492373356679265, 1.0372240795986547, 1.0251115419294328, 1.012908090353351, 1.000622421586938, 0.9882635775110435, 0.97584096221884, 0.963364359975938, 0.9508439540856547, 0.9382903466374083, 0.925714579097475, 0.9131281536783002, 0.9005430553944825, 0.8879717746796729, 0.8754273303981215, 0.8629232930365409, 0.8504738078055017, 0.83809361731378, 0.8257980834032365, 0.8136032076452386, 0.8015256499020318, 0.7895827442478967, 0.7777925114260434, 0.7661736668894777, 0.7547456233400222, 0.7435284865431435, 0.7325430430626726, 0.7218107384362742, 0.7113536442091472, 0.701194412171736, 0.6913562141213213, 0.6818626655034284, 0.6727377314046801, 0.6640056135821936, 0.6556906175429852, 0.6478169991442185, 0.6404087907800609, 0.6334896079535425, 0.6270824378909208, 0.6212094128164496, 0.6158915715261906, 0.6111486139236479, 0.6069986541363735, 0.6034579786400925, 0.6005408163910112, 0.598259128229155, 0.5966224227032567, 0.5956376049441885, 0.5953088642766879, 0.5956376049441893, 0.596622422703258, 0.5982591282291571, 0.6005408163910138, 0.603457978640096, 0.6069986541363775, 0.6111486139236526, 0.6158915715261957, 0.6212094128164554, 0.6270824378909271, 0.6334896079535494, 0.6404087907800684, 0.6478169991442264, 0.6556906175429936, 0.6640056135822023, 0.6727377314046894, 0.6818626655034381, 0.6913562141213313, 0.7011944121717463, 0.7113536442091579, 0.7218107384362851, 0.7325430430626838, 0.743528486543155, 0.7547456233400338, 0.7661736668894895, 0.7777925114260554, 0.7895827442479089, 0.8015256499020441, 0.8136032076452512, 0.8257980834032492, 0.8380936173137927, 0.8504738078055146, 0.8629232930365538, 0.8754273303981343, 0.8879717746796859, 0.9005430553944954, 0.9131281536783133, 0.9257145790974879, 0.9382903466374212, 0.9508439540856678, 0.9633643599759509, 0.9758409622188527, 0.9882635775110562, 1.0006224215869506, 1.0129080903533636, 1.0251115419294452, 1.0372240795986671, 1.0492373356679385, 1.0611432562194973, 1.0729340867340544, 1.0846023585583093, 1.0961408761860718, 1.1075427053195432, 1.1188011616756504, 1.1299098005014037, 1.1408624067620023, 1.1516529859656308, 1.1622757555894963, 1.1727251370725662, 1.1829957483415618, 1.1930823968380464, 1.2029800730158053, 1.2126839442791535, 1.2221893493342668, 1.2314917929271108, 1.2405869409429922, 1.2494706158441975, 1.258138792423567, 1.2665875938532123, 1.2748132880088605, 1.2828122840515677, 1.2905811292497025, 1.2981165060252426, 1.305415229209472, 1.312474243494182, 1.319290621065423, 1.3258615594077456, 1.3321843792677195, 1.3382565227662953, 1.3440755516503293, 1.3496391456742882, 1.3549451011038007, 1.3599913293333488, 1.364775855610955, 1.3692968178632925, 1.3735524656151248, 1.3775411589974913, 1.3812613678394952, 1.3847116708389775, 1.3878907548077837, 1.3907974139876849, 1.3934305494334098, 1.3957891684595674, 1.3978723841485872, 1.3996794149171026, 1.401209584138527, 1.4024623198198474, 1.403437154330945, 1.4041337241850385, 1.4045517698690924], [1.3799904525392033, 1.3798572509059837, 1.379457697741456, 1.37879194827616, 1.377860261311584, 1.3766629993464767, 1.3752006287545278, 1.373473720014278, 1.3714829479923534, 1.3692290922813926, 1.3667130375942782, 1.363935774216565, 1.360898398519269, 1.357602113534467, 1.3540482295964544, 1.3502381650515218, 1.346173447039724, 1.3418557123523582, 1.3372867083692273, 1.3324682940801142, 1.3274024411953107, 1.3220912353504215, 1.316536877411126, 1.3107416848840132, 1.304708093440094, 1.298438658558088, 1.2919360572951413, 1.2852030901931526, 1.2782426833295168, 1.2710578905216863, 1.2636518956956162, 1.2560280154288535, 1.2481897016797268, 1.2401405447148672, 1.2318842762480535, 1.2234247728041987, 1.214766059323124, 1.2059123130186398, 1.1968678675093105, 1.1876372172382046, 1.1782250221997934, 1.1686361129930731, 1.1588754962208336, 1.1489483602558366, 1.138860081395418, 1.1286162304267193, 1.1182225796253027, 1.1076851102103056, 1.0970100202794935, 1.086203733247489, 1.075272906810071, 1.0642244424566205, 1.0530654955514887, 1.0418034860031284, 1.0304461095371598, 1.019001349585965, 1.0074774898027585, 0.9958831272021367, 0.9842271859216803, 0.9725189315899214, 0.9607679862746921, 0.948984343972113, 0.9371783865799401, 0.9253609002792378, 0.913543092224948, 0.9017366074184048, 0.8899535456027362, 0.87820647798493, 0.8665084635456244, 0.8548730646491098, 0.8433143616112221, 0.8318469658216965, 0.8204860309502219, 0.8092472616922738, 0.7981469194326689, 0.7872018241229968, 0.7764293515856808, 0.765847425375188, 0.7554745022496172, 0.7453295502383173, 0.7354320182392706, 0.725801796050836, 0.7164591637442568, 0.7074247293252395, 0.698719353724538, 0.6903640623084886, 0.6823799423196656, 0.674788025952298, 0.6676091591407661, 0.6608638565919467, 0.6545721441171725, 0.6487533899038328, 0.6434261269890796, 0.6386078698294421, 0.6343149284637993, 0.6305622243006994, 0.6273631119792253, 0.6247292120113075, 0.6226702589739831, 0.6211939698546166, 0.6203059367474075, 0.6200095474607966, 0.6203059367474082, 0.6211939698546178, 0.6226702589739849, 0.6247292120113098, 0.6273631119792283, 0.6305622243007031, 0.6343149284638036, 0.6386078698294467, 0.643426126989085, 0.6487533899038386, 0.6545721441171787, 0.6608638565919535, 0.6676091591407732, 0.6747880259523057, 0.6823799423196736, 0.6903640623084971, 0.698719353724547, 0.7074247293252486, 0.7164591637442663, 0.7258017960508458, 0.7354320182392806, 0.7453295502383277, 0.7554745022496278, 0.7658474253751988, 0.7764293515856918, 0.787201824123008, 0.7981469194326802, 0.8092472616922854, 0.8204860309502334, 0.8318469658217083, 0.8433143616112339, 0.8548730646491218, 0.8665084635456364, 0.8782064779849421, 0.8899535456027484, 0.9017366074184167, 0.9135430922249603, 0.9253609002792499, 0.9371783865799521, 0.9489843439721253, 0.9607679862747043, 0.9725189315899334, 0.9842271859216923, 0.9958831272021487, 1.0074774898027703, 1.019001349585977, 1.0304461095371713, 1.0418034860031398, 1.0530654955515002, 1.064224442456632, 1.0752729068100824, 1.0862037332475003, 1.0970100202795046, 1.1076851102103165, 1.1182225796253136, 1.12861623042673, 1.1388600813954282, 1.1489483602558466, 1.1588754962208436, 1.168636112993083, 1.1782250221998032, 1.187637217238214, 1.1968678675093196, 1.2059123130186489, 1.214766059323133, 1.2234247728042071, 1.2318842762480622, 1.2401405447148757, 1.2481897016797352, 1.2560280154288612, 1.263651895695624, 1.2710578905216936, 1.2782426833295246, 1.2852030901931595, 1.2919360572951482, 1.298438658558095, 1.3047080934401, 1.3107416848840192, 1.3165368774111312, 1.3220912353504266, 1.3274024411953163, 1.3324682940801194, 1.337286708369232, 1.3418557123523627, 1.346173447039728, 1.3502381650515265, 1.3540482295964582, 1.3576021135344705, 1.360898398519272, 1.363935774216568, 1.3667130375942806, 1.369229092281395, 1.3714829479923556, 1.3734737200142801, 1.3752006287545298, 1.3766629993464778, 1.3778602613115853, 1.3787919482761606, 1.3794576977414563, 1.3798572509059837], [1.355889588549581, 1.3557626179184155, 1.3553817575342837, 1.35474716195115, 1.3538590888452955, 1.3527178991452278, 1.3513240572143543, 1.3496781310872166, 1.3477807927603285, 1.3456328185388877, 1.3432350894408813, 1.3405885916603473, 1.3376944170918232, 1.3345537639182543, 1.3311679372649277, 1.3275383499222644, 1.3236665231405953, 1.319554087500354, 1.3152027838614302, 1.3106144643957467, 1.3057910937074821, 1.3007347500456954, 1.2954476266144923, 1.2899320329862596, 1.284190396623888, 1.2782252645183316, 1.2720393049482914, 1.2656353093692518, 1.2590161944395928, 1.252185004191969, 1.245144912358666, 1.2378992248601544, 1.2304513824666108, 1.2228049636427007, 1.21496368758648, 1.2069314174738324, 1.198712163920402, 1.1903100886735325, 1.1817295085472506, 1.1729748996138347, 1.1640509016659768, 1.1549623229639434, 1.1457141452824986, 1.1363115292725798, 1.1267598201528664, 1.1170645537463397, 1.107231462876756, 1.0972664841395088, 1.0871757650606688, 1.076965671656959, 1.066642796407988, 1.056213966650184, 1.0456862533993858, 1.0350669806059503, 1.0243637348423118, 1.0135843754181335, 1.0027370449123036, 0.9918301801039576, 0.9808725232761798, 0.9698731338559509, 0.9588414003419444, 0.9477870524577743, 0.9367201734519675, 0.9256512124470229, 0.9145909967181922, 0.9035507437577799, 0.8925420729526289, 0.8815770166708256, 0.8706680305183736, 0.8598280024876931, 0.8490702606772895, 0.8384085792161848, 0.827857181978105, 0.8174307436197986, 0.8071443874262957, 0.7970136793949271, 0.7870546179414823, 0.7772836185685081, 0.7677174928005145, 0.7583734206674521, 0.7492689160104907, 0.7404217838976584, 0.7318500694764086, 0.7235719976609922, 0.7156059031597508, 0.707970150495671, 0.7006830438662307, 0.6937627269274507, 0.6872270728715482, 0.6810935654940099, 0.6753791723070105, 0.6701002111406354, 0.6652722120659069, 0.6609097768548425, 0.6570264385402583, 0.6536345239273353, 0.6507450221154975, 0.6483674621902037, 0.6465098032213307, 0.6451783395459396, 0.6443776240148199, 0.6441104114504189, 0.6443776240148205, 0.6451783395459407, 0.6465098032213322, 0.6483674621902058, 0.6507450221155001, 0.6536345239273386, 0.657026438540262, 0.6609097768548469, 0.6652722120659118, 0.6701002111406408, 0.675379172307016, 0.6810935654940159, 0.6872270728715546, 0.6937627269274576, 0.700683043866238, 0.7079701504956788, 0.7156059031597588, 0.7235719976610006, 0.7318500694764174, 0.7404217838976676, 0.7492689160104999, 0.7583734206674615, 0.7677174928005243, 0.777283618568518, 0.7870546179414925, 0.7970136793949374, 0.8071443874263062, 0.8174307436198093, 0.8278571819781158, 0.8384085792161955, 0.8490702606773005, 0.8598280024877043, 0.8706680305183848, 0.8815770166708365, 0.8925420729526403, 0.9035507437577912, 0.9145909967182038, 0.9256512124470342, 0.9367201734519788, 0.9477870524577859, 0.9588414003419556, 0.9698731338559622, 0.980872523276191, 0.991830180103969, 1.002737044912315, 1.0135843754181446, 1.024363734842323, 1.0350669806059611, 1.0456862533993967, 1.0562139666501946, 1.0666427964079988, 1.0769656716569693, 1.0871757650606795, 1.0972664841395188, 1.107231462876766, 1.1170645537463497, 1.1267598201528763, 1.1363115292725898, 1.1457141452825077, 1.1549623229639527, 1.1640509016659861, 1.1729748996138438, 1.1817295085472592, 1.1903100886735414, 1.1987121639204106, 1.2069314174738406, 1.214963687586488, 1.2228049636427087, 1.2304513824666188, 1.2378992248601617, 1.245144912358673, 1.2521850041919764, 1.2590161944395997, 1.2656353093692583, 1.2720393049482979, 1.2782252645183383, 1.284190396623894, 1.2899320329862651, 1.2954476266144976, 1.3007347500457005, 1.3057910937074872, 1.3106144643957511, 1.3152027838614344, 1.3195540875003582, 1.323666523140599, 1.3275383499222684, 1.3311679372649314, 1.3345537639182576, 1.3376944170918261, 1.3405885916603504, 1.3432350894408838, 1.3456328185388902, 1.3477807927603307, 1.3496781310872186, 1.3513240572143561, 1.3527178991452293, 1.3538590888452966, 1.3547471619511506, 1.3553817575342844, 1.3557626179184157], [1.3324118597838257, 1.3322911757895615, 1.3319291749878472, 1.3313260109480365, 1.3304819397062155, 1.329397319896312, 1.328072612934379, 1.3265083832567899, 1.3247052986132835, 1.3226641304160336, 1.3203857541461166, 1.3178711498189923, 1.3151214025108249, 1.3121377029477264, 1.3089213481602173, 1.305473742205475, 1.3017963969601711, 1.2978909329869686, 1.2937590804780223, 1.289402680279094, 1.284823684998189, 1.280024160202902, 1.2750062857109818, 1.2697723569789177, 1.264324786593683, 1.2586661058730972, 1.2527989665806014, 1.2467261427605878, 1.2404505327007778, 1.233975161028482, 1.227303180947946, 1.2204378766263255, 1.213382665736195, 1.2061411021628259, 1.198716878884803, 1.1911138310368572, 1.1833359391640723, 1.1753873326768745, 1.1672722935164113, 1.15899526004008, 1.1505608311370352, 1.1419737705834938, 1.1332390116475357, 1.1243616619528527, 1.11534700861049, 1.1062005236270342, 1.0969278695968925, 1.087534905685231, 1.0780276939067657, 1.0684125057038536, 1.0586958288251826, 1.0488843745037069, 1.0389850849292717, 1.0290051410075334, 1.018951970392171, 1.0088332557719812, 0.9986569433880427, 0.9884312517487014, 0.9781646805014441, 0.9678660194107394, 0.9575443573794329, 0.9472090914381721, 0.9368699356124631, 0.9265369295601826, 0.9162204468536029, 0.9059312027591039, 0.8956802613447366, 0.8854790417206672, 0.8753393231903372, 0.8652732490611273, 0.8552933288326882, 0.8454124384493811, 0.8356438182710425, 0.8260010683844373, 0.8164981408473518, 0.807149328429661, 0.7979692493925619, 0.7889728278304103, 0.7801752690915554, 0.7715920297977186, 0.7632387819986172, 0.755131371032585, 0.74728576671777, 0.7397180075748733, 0.7324441378836303, 0.725480137503016, 0.7188418445401684, 0.7125448711346667, 0.7066045128308649, 0.7010356522373452, 0.6958526579130437, 0.6910692796658457, 0.6866985416910963, 0.682752635202364, 0.679242812401676, 0.676179283787615, 0.6735711208939892, 0.671426166577881, 0.6697509549250908, 0.6685506427085953, 0.6678289541216008, 0.6675881402161743, 0.6678289541216013, 0.6685506427085963, 0.6697509549250923, 0.6714261665778829, 0.6735711208939915, 0.676179283787618, 0.6792428124016794, 0.6827526352023677, 0.6866985416911007, 0.6910692796658504, 0.695852657913049, 0.7010356522373508, 0.7066045128308708, 0.712544871134673, 0.7188418445401752, 0.7254801375030232, 0.7324441378836377, 0.7397180075748809, 0.747285766717778, 0.7551313710325931, 0.7632387819986255, 0.7715920297977271, 0.7801752690915644, 0.7889728278304194, 0.7979692493925711, 0.8071493284296706, 0.8164981408473615, 0.8260010683844474, 0.8356438182710524, 0.8454124384493911, 0.8552933288326984, 0.8652732490611377, 0.8753393231903478, 0.8854790417206775, 0.895680261344747, 0.9059312027591144, 0.9162204468536136, 0.9265369295601932, 0.9368699356124739, 0.9472090914381829, 0.9575443573794435, 0.9678660194107499, 0.9781646805014546, 0.988431251748712, 0.998656943388053, 1.0088332557719915, 1.0189519703921817, 1.0290051410075436, 1.0389850849292819, 1.0488843745037169, 1.0586958288251929, 1.0684125057038634, 1.0780276939067757, 1.087534905685241, 1.0969278695969022, 1.1062005236270438, 1.1153470086104995, 1.1243616619528618, 1.1332390116475448, 1.1419737705835027, 1.150560831137044, 1.1589952600400886, 1.1672722935164197, 1.175387332676883, 1.1833359391640805, 1.191113831036865, 1.1987168788848106, 1.2061411021628334, 1.2133826657362023, 1.2204378766263326, 1.2273031809479529, 1.2339751610284886, 1.2404505327007842, 1.2467261427605942, 1.2527989665806076, 1.2586661058731035, 1.2643247865936886, 1.2697723569789228, 1.275006285710987, 1.280024160202907, 1.2848236849981938, 1.2894026802790988, 1.2937590804780266, 1.2978909329869728, 1.301796396960175, 1.3054737422054787, 1.3089213481602204, 1.3121377029477295, 1.3151214025108278, 1.3178711498189948, 1.3203857541461193, 1.3226641304160358, 1.3247052986132855, 1.3265083832567917, 1.328072612934381, 1.3293973198963132, 1.3304819397062164, 1.3313260109480372, 1.3319291749878477, 1.3322911757895617], [1.309579979428233, 1.309465625315556, 1.3091226137073928, 1.3085510968192071, 1.307751328429737, 1.3067236640107667, 1.3054685609094516, 1.303986578583858, 1.3022783788925385, 1.3003447264391872, 1.2981864889735861, 1.2958046378502603, 1.2932002485464555, 1.2903745012412453, 1.2873286814577953, 1.2840641807709967, 1.280582497582915, 1.2768852379686997, 1.2729741165958248, 1.268850957719755, 1.2645176962593543, 1.259976378955585, 1.2552291656172787, 1.250278330457995, 1.2451262635282128, 1.2397754722473464, 1.2342285830402997, 1.2284883430835154, 1.2225576221656926, 1.2164394146685698, 1.2101368416733758, 1.2036531531987473, 1.1969917305760809, 1.1901560889684453, 1.1831498800392928, 1.1759768947773002, 1.1686410664837033, 1.161146473928476, 1.1534973446816226, 1.145698058625694, 1.1377531516553836, 1.1296673195697058, 1.1214454221617514, 1.1130924875103931, 1.104613716477491, 1.096014487413118, 1.0873003610700889, 1.078477085727541, 1.0695506025214767, 1.0605270509780047, 1.0514127747424074, 1.0422143274941253, 1.0329384790341858, 1.0235922215274533, 1.0141827758773025, 1.0047175982047962, 0.9952043863981512, 0.9856510866910997, 0.9760659002206182, 0.9664572895053419, 0.9568339847757064, 0.9472049900754336, 0.9375795890413131, 0.927967350254311, 0.918378132039863, 0.9088220865787727, 0.899309663172536, 0.8898516104882706, 0.8804589775889028, 0.8711431135341889, 0.8619156653178288, 0.8527885738859015, 0.8437740679627159, 0.8348846553926655, 0.8261331116917427, 0.8175324654910634, 0.8090959805483104, 0.8008371340028101, 0.7927695905575168, 0.7849071722881086, 0.7772638238072945, 0.7698535725529236, 0.7626904840229913, 0.7557886118503273, 0.7491619426954249, 0.7428243360377133, 0.7367894590630863, 0.7310707169772979, 0.7256811792185143, 0.7206335021943904, 0.7159398493248735, 0.7116118093258438, 0.7076603138140242, 0.7040955554430021, 0.700926907886073, 0.698162849056417, 0.6958108889920065, 0.6938775038260189, 0.6923680772095285, 0.691286850450299, 0.690636882480591, 0.690420020571767, 0.6906368824805914, 0.6912868504502999, 0.6923680772095298, 0.6938775038260208, 0.6958108889920086, 0.6981628490564197, 0.7009269078860761, 0.7040955554430056, 0.7076603138140282, 0.711611809325848, 0.7159398493248781, 0.7206335021943954, 0.7256811792185196, 0.7310707169773035, 0.7367894590630925, 0.7428243360377198, 0.7491619426954317, 0.7557886118503342, 0.7626904840229988, 0.7698535725529312, 0.7772638238073022, 0.7849071722881166, 0.7927695905575249, 0.8008371340028184, 0.8090959805483191, 0.8175324654910722, 0.8261331116917516, 0.8348846553926746, 0.8437740679627251, 0.8527885738859108, 0.8619156653178383, 0.8711431135341985, 0.8804589775889123, 0.8898516104882804, 0.8993096631725458, 0.9088220865787825, 0.9183781320398728, 0.9279673502543206, 0.937579589041323, 0.9472049900754437, 0.9568339847757162, 0.9664572895053518, 0.9760659002206281, 0.9856510866911095, 0.995204386398161, 1.004717598204806, 1.0141827758773123, 1.0235922215274629, 1.0329384790341953, 1.042214327494135, 1.0514127747424167, 1.0605270509780138, 1.0695506025214858, 1.07847708572755, 1.087300361070098, 1.0960144874131268, 1.1046137164774998, 1.1130924875104018, 1.1214454221617596, 1.1296673195697144, 1.1377531516553918, 1.1456980586257017, 1.1534973446816306, 1.1611464739284838, 1.1686410664837108, 1.1759768947773073, 1.1831498800393, 1.1901560889684524, 1.1969917305760878, 1.203653153198754, 1.2101368416733824, 1.2164394146685762, 1.2225576221656989, 1.2284883430835214, 1.2342285830403057, 1.2397754722473522, 1.2451262635282183, 1.250278330458, 1.2552291656172834, 1.2599763789555896, 1.2645176962593592, 1.2688509577197595, 1.2729741165958288, 1.2768852379687032, 1.2805824975829183, 1.284064180771, 1.2873286814577987, 1.2903745012412486, 1.2932002485464582, 1.2958046378502628, 1.2981864889735883, 1.3003447264391892, 1.3022783788925403, 1.30398657858386, 1.3054685609094532, 1.3067236640107676, 1.3077513284297382, 1.3085510968192076, 1.309122613707393, 1.3094656253155563], [1.2874160358524733, 1.2873080411921152, 1.2869841073466637, 1.2864443847480778, 1.2856891241999893, 1.284718677003533, 1.283533495134061, 1.282134131469294, 1.2805212400696269, 1.278695576511458, 1.2766579982745783, 1.2744094651848155, 1.2719510399132927, 1.269283888533825, 1.266409281140137, 1.2633285925247635, 1.2600433029216402, 1.2565549988145825, 1.252865373814, 1.2489762296043627, 1.2448894769651089, 1.2406071368678424, 1.2361313416528217, 1.231464336287914, 1.226608479713325, 1.2215662462755685, 1.2163402272542732, 1.2109331324855441, 1.205347792085714, 1.1995871582794106, 1.1936543073359316, 1.1875524416179801, 1.1812848917468182, 1.1748551188878915, 1.1682667171609011, 1.1615234161782129, 1.1546290837153075, 1.1475877285167526, 1.1404035032408633, 1.1330807075458178, 1.125623791319484, 1.1180373580545946, 1.11032616837014, 1.10249514367893, 1.0945493700001865, 1.0864941019147178, 1.078334766658712, 1.0700769683503968, 1.0617264923417407, 1.0532893096849851, 1.044771581701037, 1.0361796646336023, 1.0275201143693582, 1.0187996912003825, 1.0100253646004713, 1.0012043179817953, 0.9923439533925836, 0.9834518961100671, 0.9745359990757997, 0.9656043471126128, 0.9566652608538652, 0.9477273003062868, 0.9387992679576187, 0.9298902113294117, 0.9210094248638566, 0.9121664510214358, 0.9033710804536452, 0.8946333511022175, 0.8859635460633869, 0.8773721900430855, 0.868870044216894, 0.8604680992975104, 0.8521775666030064, 0.8440098669117485, 0.8359766168853296, 0.8280896128398884, 0.8203608116496731, 0.8128023085754985, 0.8054263118257697, 0.7982451136799333, 0.7912710580343942, 0.7845165042698801, 0.7779937873875125, 0.7717151744187756, 0.765692817182178, 0.7599387015362623, 0.7544645933638611, 0.7492819816146772, 0.7444020188303829, 0.7398354596758594, 0.735592598098737, 0.7316832038333559, 0.7281164590505612, 0.724900896027066, 0.7220443367631779, 0.719553835511451, 0.717435625187787, 0.715695068618028, 0.7143366155255092, 0.7133637660881095, 0.7127790417881408, 0.7125839641475267, 0.7127790417881411, 0.7133637660881101, 0.7143366155255104, 0.7156950686180296, 0.7174356251877889, 0.7195538355114535, 0.7220443367631808, 0.7249008960270692, 0.7281164590505648, 0.7316832038333599, 0.7355925980987412, 0.7398354596758637, 0.7444020188303876, 0.7492819816146824, 0.7544645933638666, 0.7599387015362681, 0.7656928171821841, 0.771715174418782, 0.777993787387519, 0.784516504269887, 0.7912710580344013, 0.7982451136799407, 0.8054263118257771, 0.8128023085755062, 0.8203608116496809, 0.8280896128398965, 0.8359766168853379, 0.8440098669117568, 0.8521775666030146, 0.8604680992975189, 0.8688700442169026, 0.8773721900430944, 0.8859635460633957, 0.8946333511022265, 0.9033710804536543, 0.9121664510214449, 0.9210094248638658, 0.929890211329421, 0.9387992679576281, 0.9477273003062961, 0.9566652608538743, 0.965604347112622, 0.9745359990758089, 0.9834518961100764, 0.9923439533925928, 1.0012043179818044, 1.0100253646004804, 1.0187996912003918, 1.027520114369367, 1.0361796646336112, 1.044771581701046, 1.0532893096849938, 1.061726492341749, 1.0700769683504052, 1.0783347666587206, 1.086494101914726, 1.0945493700001947, 1.1024951436789379, 1.1103261683701477, 1.1180373580546026, 1.1256237913194915, 1.1330807075458253, 1.1404035032408706, 1.14758772851676, 1.1546290837153146, 1.1615234161782197, 1.168266717160908, 1.174855118887898, 1.181284891746825, 1.1875524416179863, 1.1936543073359378, 1.1995871582794166, 1.20534779208572, 1.2109331324855497, 1.216340227254279, 1.221566246275574, 1.2266084797133299, 1.2314643362879187, 1.2361313416528263, 1.2406071368678468, 1.244889476965113, 1.2489762296043665, 1.2528653738140039, 1.256554998814586, 1.2600433029216436, 1.2633285925247666, 1.2664092811401402, 1.2692838885338278, 1.2719510399132954, 1.274409465184818, 1.2766579982745807, 1.2786955765114603, 1.2805212400696289, 1.2821341314692953, 1.2835334951340622, 1.2847186770035341, 1.28568912419999, 1.2864443847480784, 1.2869841073466641, 1.2873080411921154], [1.2659414712405206, 1.2658398506164779, 1.265535038123436, 1.2650271819224537, 1.264316529028012, 1.2634034254273159, 1.2622883162477652, 1.2609717459730423, 1.2594543587083935, 1.257736898495813, 1.255820209679953, 1.2537052373257243, 1.2513930276886733, 1.248884728739339, 1.2461815907429272, 1.243284966895766, 1.2401963140200998, 1.236917193318941, 1.2334492711927678, 1.2297943201199981, 1.225954219603263, 1.2219309571836008, 1.21772662952479, 1.2133434435701187, 1.2087837177739684, 1.2040498834106301, 1.1991444859628437, 1.1940701865925574, 1.1888297636964187, 1.1834261145484946, 1.1778622570326678, 1.1721413314670848, 1.1662666025229123, 1.1602414612395107, 1.154069427137915, 1.1477541504342637, 1.141299414354484, 1.1347091375511447, 1.1279873766229087, 1.1211383287364345, 1.1141663343499086, 1.1070758800365808, 1.0998716014057417, 1.092558286117507, 1.0851408769865198, 1.077624475168244, 1.0700143434198919, 1.062315909426157, 1.0545347691778082, 1.0466766903888196, 1.0387476159350146, 1.0307536672942086, 1.0227011479644696, 1.0145965468333922, 1.0064465414671633, 0.9982580012836534, 0.990037990568798, 0.9817937712901134, 0.9735328056553169, 0.9652627583576955, 0.9569914984430987, 0.948727100726244, 0.9404778466764712, 0.9322522246852005, 0.9240589296192502, 0.9159068615559388, 0.907805123587689, 0.8997630185758373, 0.8917900447257432, 0.8838958898483472, 0.8760904241673392, 0.8683836915264173, 0.8607858988481352, 0.8533074036949734, 0.8459586997850157, 0.8387504003194551, 0.8316932189876188, 0.8247979485278092, 0.8180754367395137, 0.8115365598648874, 0.8051921932852487, 0.799053179511911, 0.7931302934901251, 0.7874342052801432, 0.7819754402301483, 0.776764336811429, 0.7718110023458694, 0.7671252669183622, 0.7627166358306408, 0.7585942410164456, 0.7547667918987904, 0.7512425262260796, 0.7480291614725159, 0.7451338474271396, 0.7425631206226448, 0.7403228612676532, 0.7384182533426896, 0.7368537484994595, 0.7356330343646077, 0.7347590077930711, 0.7342337535433784, 0.7340585287594793, 0.7342337535433787, 0.7347590077930719, 0.7356330343646088, 0.736853748499461, 0.7384182533426914, 0.7403228612676555, 0.7425631206226474, 0.7451338474271426, 0.7480291614725192, 0.751242526226083, 0.754766791898794, 0.7585942410164497, 0.7627166358306453, 0.7671252669183669, 0.7718110023458745, 0.7767643368114343, 0.7819754402301539, 0.787434205280149, 0.7931302934901312, 0.7990531795119173, 0.805192193285255, 0.811536559864894, 0.8180754367395204, 0.8247979485278162, 0.8316932189876259, 0.8387504003194626, 0.8459586997850232, 0.8533074036949809, 0.8607858988481429, 0.8683836915264251, 0.8760904241673472, 0.8838958898483553, 0.8917900447257513, 0.8997630185758454, 0.9078051235876973, 0.9159068615559471, 0.9240589296192587, 0.9322522246852087, 0.9404778466764797, 0.9487271007262527, 0.9569914984431073, 0.965262758357704, 0.9735328056553254, 0.981793771290122, 0.9900379905688065, 0.9982580012836618, 1.0064465414671715, 1.0145965468334004, 1.022701147964478, 1.030753667294217, 1.0387476159350226, 1.0466766903888276, 1.0545347691778162, 1.062315909426165, 1.0700143434198999, 1.0776244751682518, 1.0851408769865276, 1.0925582861175145, 1.099871601405749, 1.107075880036588, 1.1141663343499157, 1.1211383287364416, 1.1279873766229158, 1.134709137551152, 1.1412994143544906, 1.14775415043427, 1.1540694271379215, 1.160241461239517, 1.1662666025229185, 1.1721413314670908, 1.1778622570326738, 1.1834261145485, 1.1888297636964242, 1.1940701865925627, 1.1991444859628488, 1.204049883410635, 1.208783717773973, 1.2133434435701234, 1.2177266295247937, 1.221930957183605, 1.2259542196032671, 1.229794320120002, 1.2334492711927711, 1.2369171933189445, 1.2401963140201029, 1.243284966895769, 1.2461815907429303, 1.2488847287393414, 1.2513930276886756, 1.2537052373257263, 1.255820209679955, 1.257736898495815, 1.2594543587083953, 1.260971745973044, 1.2622883162477667, 1.263403425427317, 1.264316529028013, 1.2650271819224541, 1.2655350381234363, 1.2658398506164779], [1.2451770608467245, 1.2450818125276055, 1.2447961160127106, 1.244320116651435, 1.2436540567661911, 1.2427982757627, 1.241753210284753, 1.2405193944137598, 1.2390974599135294, 1.237488136520812, 1.235692252282218, 1.2337107339382274, 1.2315446073550913, 1.229194998005514, 1.2266631314990828, 1.2239503341634996, 1.2210580336777388, 1.2179877597583244, 1.214741144899996, 1.211319925172068, 1.2077259410718642, 1.2039611384366198, 1.2000275694153035, 1.1959273935017962, 1.1916628786308934, 1.1872364023385669, 1.182650452987893, 1.1779076310619996, 1.1730106505253064, 1.1679623402542214, 1.16276564553832, 1.1574236296528548, 1.1519394755032355, 1.1463164873418408, 1.140558092557232, 1.1346678435354478, 1.1286494195926324, 1.1225066289777434, 1.1162434109434896, 1.1098638378829746, 1.1033721175287485, 1.0967725952100735, 1.0900697561632102, 1.0832682278883854, 1.076372782545821, 1.0693883393817523, 1.062319967173754, 1.0551728866828898, 1.0479524730981855, 1.0406642584567303, 1.0333139340202377, 1.025907352586231, 1.0184505307090634, 1.0109496508027813, 1.0034110630943662, 0.9958412873921342, 0.9882470146300507, 0.980635108144429, 0.9730126046349176, 0.965386714756915, 0.9577648232875485, 0.9501544888022131, 0.9425634427933982, 0.9349995881582586, 0.9274709969761274, 0.9199859074921113, 0.9125527202181178, 0.90517999305833, 0.8978764353624242, 0.8906509008069328, 0.8835123790033058, 0.8764699857306724, 0.8695329516923168, 0.8627106096977527, 0.8560123801772841, 0.8494477549434116, 0.8430262791236387, 0.8367575312024411, 0.8306511011266232, 0.8247165664481769, 0.8189634665021817, 0.8134012746442881, 0.8080393686027976, 0.8028869990340609, 0.7979532564065213, 0.793247036377652, 0.7887770038686034, 0.784551556082669, 0.7805787847546832, 0.7768664379579464, 0.7734218818319499, 0.7702520626266272, 0.7673634694856949, 0.7647620984114698, 0.7624534178651139, 0.7604423364584489, 0.7587331731854986, 0.7573296306231999, 0.7562347715011751, 0.755450999000297, 0.754980041089729, 0.7548229391532756, 0.7549800410897294, 0.7554509990002977, 0.7562347715011761, 0.7573296306232012, 0.7587331731855003, 0.7604423364584509, 0.7624534178651161, 0.7647620984114725, 0.7673634694856977, 0.7702520626266304, 0.7734218818319532, 0.7768664379579501, 0.7805787847546872, 0.7845515560826734, 0.7887770038686079, 0.7932470363776569, 0.7979532564065264, 0.8028869990340661, 0.8080393686028031, 0.8134012746442937, 0.8189634665021874, 0.824716566448183, 0.8306511011266294, 0.8367575312024473, 0.8430262791236454, 0.8494477549434184, 0.856012380177291, 0.8627106096977597, 0.8695329516923239, 0.8764699857306795, 0.8835123790033131, 0.8906509008069403, 0.8978764353624317, 0.9051799930583375, 0.9125527202181255, 0.919985907492119, 0.9274709969761352, 0.9349995881582662, 0.942563442793406, 0.9501544888022209, 0.9577648232875564, 0.9653867147569226, 0.9730126046349254, 0.9806351081444368, 0.9882470146300586, 0.995841287392142, 1.0034110630943742, 1.010949650802789, 1.0184505307090708, 1.0259073525862386, 1.033313934020245, 1.0406642584567378, 1.047952473098193, 1.055172886682897, 1.0623199671737615, 1.0693883393817591, 1.0763727825458282, 1.0832682278883925, 1.0900697561632169, 1.0967725952100804, 1.1033721175287552, 1.1098638378829813, 1.116243410943496, 1.12250662897775, 1.1286494195926386, 1.1346678435354538, 1.140558092557238, 1.1463164873418465, 1.1519394755032413, 1.1574236296528606, 1.1627656455383253, 1.1679623402542265, 1.1730106505253115, 1.1779076310620045, 1.182650452987898, 1.1872364023385718, 1.1916628786308978, 1.1959273935018004, 1.200027569415308, 1.203961138436624, 1.207725941071868, 1.2113199251720717, 1.2147411448999992, 1.2179877597583275, 1.2210580336777417, 1.2239503341635025, 1.2266631314990852, 1.2291949980055168, 1.2315446073550937, 1.2337107339382296, 1.2356922522822202, 1.237488136520814, 1.239097459913531, 1.2405193944137611, 1.2417532102847546, 1.2427982757627012, 1.2436540567661913, 1.2443201166514357, 1.2447961160127112, 1.245081812527606], [1.2251428928970922, 1.225053997507049, 1.2247873586470075, 1.2243431182670026, 1.2237215130163663, 1.2229228743427496, 1.2219476286309885, 1.220796297382034, 1.2194694974322358, 1.217967941213342, 1.2162924370536101, 1.2144438895205083, 1.2124232998055195, 1.2102317661516155, 1.2078704843240216, 1.2053407481249134, 1.2026439499527424, 1.1997815814068906, 1.1967552339383987, 1.193566599547493, 1.1902174715286642, 1.186709745264018, 1.183045419065601, 1.1792265950673648, 1.1752554801673747, 1.1711343870207915, 1.1668657350840566, 1.162452051710598, 1.157895973298218, 1.153200246488155, 1.1483677294155963, 1.1434013930111755, 1.138304322352704, 1.1330797180660481, 1.1277308977736822, 1.1222612975890194, 1.1166744736541139, 1.1109741037177694, 1.1051639887504465, 1.0992480545916565, 1.0932303536247088, 1.0871150664727924, 1.0809065037093724, 1.0746091075747577, 1.0682274536894918, 1.0617662527538367, 1.055230352221151, 1.0486247379313218, 1.0419545356886326, 1.0352250127665066, 1.02844157931948, 1.0216097896804772, 1.014735343519049, 1.0078240868336212, 1.000882012748057, 0.9939152620799024, 0.9869301236446334, 0.9799330342570356, 0.9729305783875428, 0.9659294874279991, 0.9589366385178907, 0.9519590528787097, 0.9450038936007588, 0.9380784628235205, 0.931190198247724, 0.9243466689145604, 0.9175555701852325, 0.9108247178522889, 0.9041620413131162, 0.897575575735708, 0.8910734531475175, 0.8846638923800413, 0.8783551878049083, 0.8721556968018439, 0.8660738259051354, 0.8601180155832581, 0.8542967236163163, 0.8486184070480038, 0.8430915027029794, 0.8377244062769299, 0.8325254500251315, 0.8275028790959291, 0.8226648265780991, 0.8180192873552482, 0.8135740908859623, 0.8093368730548521, 0.8053150472664805, 0.801515774980751, 0.7979459359140076, 0.7946120981540841, 0.7915204884590417, 0.7886769630275319, 0.7860869790428248, 0.783755567301765, 0.7816873062436527, 0.7798862976916859, 0.7783561446108136, 0.7770999311704241, 0.7761202053782482, 0.775418964523456, 0.7749976436326381, 0.7748571071029079, 0.7749976436326386, 0.7754189645234567, 0.7761202053782491, 0.7770999311704252, 0.7783561446108151, 0.7798862976916876, 0.7816873062436547, 0.7837555673017671, 0.7860869790428273, 0.7886769630275348, 0.7915204884590445, 0.7946120981540874, 0.7979459359140111, 0.8015157749807548, 0.8053150472664845, 0.8093368730548564, 0.8135740908859669, 0.8180192873552529, 0.822664826578104, 0.8275028790959343, 0.8325254500251367, 0.8377244062769353, 0.8430915027029849, 0.8486184070480096, 0.8542967236163223, 0.8601180155832642, 0.8660738259051417, 0.8721556968018502, 0.8783551878049147, 0.884663892380048, 0.8910734531475242, 0.8975755757357148, 0.9041620413131229, 0.9108247178522958, 0.9175555701852397, 0.9243466689145673, 0.9311901982477311, 0.9380784628235276, 0.9450038936007662, 0.9519590528787172, 0.9589366385178979, 0.9659294874280062, 0.97293057838755, 0.9799330342570427, 0.9869301236446405, 0.9939152620799095, 1.0008820127480642, 1.0078240868336281, 1.0147353435190558, 1.0216097896804843, 1.028441579319487, 1.0352250127665137, 1.0419545356886393, 1.048624737931329, 1.055230352221158, 1.0617662527538434, 1.0682274536894985, 1.0746091075747641, 1.0809065037093786, 1.0871150664727989, 1.0932303536247148, 1.0992480545916627, 1.1051639887504525, 1.1109741037177754, 1.1166744736541196, 1.122261297589025, 1.1277308977736877, 1.1330797180660537, 1.1383043223527096, 1.1434013930111804, 1.148367729415601, 1.1532002464881599, 1.1578959732982228, 1.1624520517106025, 1.1668657350840612, 1.171134387020796, 1.175255480167379, 1.1792265950673686, 1.1830454190656048, 1.1867097452640218, 1.190217471528668, 1.1935665995474962, 1.1967552339384018, 1.1997815814068935, 1.202643949952745, 1.205340748124916, 1.207870484324024, 1.210231766151618, 1.2124232998055215, 1.2144438895205103, 1.216292437053612, 1.2179679412133437, 1.2194694974322373, 1.220796297382035, 1.22194762863099, 1.2229228743427505, 1.2237215130163668, 1.2243431182670033, 1.224787358647008, 1.2250539975070494], [1.205858349155229, 1.2057757683623092, 1.2055280719527088, 1.2051153978510445, 1.2045379759888288, 1.20379612839026, 1.2028902692924501, 1.201820905300214, 1.2005886355755675, 1.1991941520621279, 1.197638239744611, 1.1959217769436696, 1.1940457356463163, 1.192011181872204, 1.1898192760760329, 1.1874712735863688, 1.1849685250811421, 1.1823124771000924, 1.1795046725944038, 1.1765467515137338, 1.1734404514308119, 1.1701876082037161, 1.1667901566758738, 1.163250131413743, 1.1595696674820328, 1.155751001256198, 1.1517964712717923, 1.147708519110113, 1.1434896903193588, 1.139142635370315, 1.1346701106453152, 1.1300749794589506, 1.1253602131086593, 1.1205288919529752, 1.1155842065147876, 1.1105294586065149, 1.1053680624735671, 1.1001035459519155, 1.094739551634934, 1.0892798380439976, 1.0837282807965325, 1.0780888737643792, 1.0723657302143945, 1.0665630839222047, 1.0606852902489303, 1.0547368271694944, 1.0487222962398433, 1.0426464234890163, 1.036514060220505, 1.0303301837057535, 1.0240998977509495, 1.0178284331164662, 1.0115211477664194, 1.0051835269238296, 0.9988211829048225, 0.9924398547031736, 0.9860454072943364, 0.9796438306258906, 0.973241238259139, 0.9668438656244216, 0.9604580678505846, 0.9540903171270622, 0.9477471995551706, 0.9414354114435944, 0.9351617550016939, 0.9289331333832693, 0.9227565450328423, 0.9166390772864741, 0.910587899179681, 0.9046102534162764, 0.8987134474540144, 0.8929048436658719, 0.8871918485397625, 0.8815819008845202, 0.8760824590162154, 0.8707009869063399, 0.8654449392821726, 0.8603217456797402, 0.855338793461245, 0.8505034098215704, 0.8458228428224758, 0.841304241508196, 0.8369546351722469, 0.8327809118620558, 0.8287897962253592, 0.8249878268197974, 0.8213813330244342, 0.8179764117086352, 0.8147789038294142, 0.8117943711425187, 0.8090280732247344, 0.8064849450146354, 0.8041695750858923, 0.8020861848708204, 0.8002386090518285, 0.7986302773344918, 0.7972641978080114, 0.7961429420867635, 0.7952686324105528, 0.7946429308612872, 0.7942670308303844, 0.794141650844771, 0.7942670308303846, 0.7946429308612877, 0.7952686324105535, 0.7961429420867644, 0.7972641978080127, 0.7986302773344933, 0.8002386090518302, 0.8020861848708224, 0.8041695750858946, 0.806484945014638, 0.809028073224737, 0.8117943711425217, 0.8147789038294173, 0.8179764117086387, 0.8213813330244377, 0.8249878268198014, 0.8287897962253633, 0.8327809118620599, 0.8369546351722515, 0.8413042415082006, 0.8458228428224804, 0.8505034098215752, 0.8553387934612499, 0.8603217456797453, 0.8654449392821778, 0.8707009869063455, 0.876082459016221, 0.881581900884526, 0.8871918485397683, 0.8929048436658777, 0.8987134474540203, 0.9046102534162825, 0.9105878991796871, 0.9166390772864803, 0.9227565450328487, 0.9289331333832754, 0.9351617550017004, 0.9414354114436008, 0.9477471995551772, 0.9540903171270688, 0.960458067850591, 0.966843865624428, 0.9732412382591455, 0.9796438306258972, 0.9860454072943432, 0.9924398547031801, 0.9988211829048291, 1.005183526923836, 1.0115211477664259, 1.0178284331164726, 1.0240998977509557, 1.0303301837057597, 1.0365140602205112, 1.0426464234890225, 1.0487222962398497, 1.0547368271695003, 1.0606852902489363, 1.0665630839222104, 1.0723657302144003, 1.0780888737643852, 1.0837282807965383, 1.0892798380440034, 1.0947395516349396, 1.1001035459519208, 1.1053680624735727, 1.11052945860652, 1.1155842065147927, 1.12052889195298, 1.1253602131086642, 1.1300749794589553, 1.13467011064532, 1.1391426353703196, 1.1434896903193634, 1.1477085191101173, 1.1517964712717967, 1.1557510012562022, 1.1595696674820368, 1.1632501314137464, 1.1667901566758774, 1.1701876082037195, 1.1734404514308152, 1.1765467515137369, 1.1795046725944067, 1.1823124771000952, 1.1849685250811446, 1.1874712735863715, 1.1898192760760349, 1.1920111818722061, 1.194045735646318, 1.1959217769436714, 1.1976382397446128, 1.1991941520621294, 1.2005886355755688, 1.2018209053002151, 1.2028902692924517, 1.203796128390261, 1.2045379759888295, 1.2051153978510447, 1.2055280719527093, 1.2057757683623096], [1.187342086171733, 1.1872657614138327, 1.1870368315505901, 1.186655429827572, 1.1861217783680427, 1.1854361882439555, 1.1845990595753704, 1.1836108816583129, 1.1824722331211077, 1.181183782109215, 1.1797462864985881, 1.1781605941375803, 1.1764276431174043, 1.1745484620711424, 1.172524170501276, 1.1703559791356841, 1.1680451903120175, 1.1655931983903163, 1.1630014901936838, 1.1602716454767672, 1.1574053374217184, 1.1544043331612266, 1.1512704943281031, 1.1480057776307906, 1.144612235454032, 1.1410920164837761, 1.1374473663552347, 1.1336806283228, 1.1297942439503208, 1.1257907538199818, 1.121672798257766, 1.1174431180731677, 1.1131045553104926, 1.1086600540087022, 1.104112660966355, 1.0994655265077418, 1.0947219052458175, 1.0898851568369914, 1.0849587467222488, 1.0799462468484289, 1.0748513363628018, 1.0696778022733213, 1.0644295400661277, 1.0591105542710018, 1.0537249589645457, 1.04827697819986, 1.042770946350442, 1.0372113083549022, 1.0316026198479296, 1.0259495471616817, 1.0202568671805117, 1.0145294670305816, 1.0087723435845612, 1.0029906027601836, 0.9971894585900213, 0.9913742320384125, 0.9855503495400517, 0.9797233412333887, 0.9738988388606488, 0.9680825733050671, 0.9622803717348002, 0.9564981543220286, 0.9507419305049825, 0.9450177947600963, 0.9393319218512456, 0.933690561523097, 0.928100032606078, 0.9225667165013832, 0.9170970500158477, 0.9116975175184912, 0.9063746423931253, 0.9011349777646757, 0.8959850964808435, 0.8909315803354779, 0.8859810085255612, 0.8811399453400636, 0.876414927086103, 0.8718124482658374, 0.8673389470262901, 0.8630007899138189, 0.8588042559750937, 0.8547555202571485, 0.8508606367701975, 0.8471255209882546, 0.8435559319740358, 0.8401574542258815, 0.8369354793553119, 0.8338951877140472, 0.8310415300986262, 0.8283792096688454, 0.8259126642228801, 0.8236460489768306, 0.8215832199993638, 0.8197277184528613, 0.8180827557908702, 0.8166512000575896, 0.8154355634285241, 0.8144379911223356, 0.8136602518023683, 0.8131037295724874, 0.8127694176559459, 0.8126579138282671, 0.812769417655946, 0.813103729572488, 0.813660251802369, 0.8144379911223366, 0.8154355634285253, 0.8166512000575907, 0.8180827557908718, 0.8197277184528631, 0.821583219999366, 0.8236460489768328, 0.8259126642228826, 0.8283792096688479, 0.831041530098629, 0.8338951877140504, 0.8369354793553151, 0.840157454225885, 0.8435559319740394, 0.8471255209882582, 0.8508606367702015, 0.8547555202571527, 0.8588042559750978, 0.8630007899138235, 0.8673389470262945, 0.8718124482658421, 0.8764149270861078, 0.8811399453400685, 0.8859810085255663, 0.890931580335483, 0.8959850964808486, 0.9011349777646811, 0.9063746423931307, 0.9116975175184965, 0.9170970500158533, 0.9225667165013888, 0.9281000326060839, 0.9336905615231028, 0.9393319218512516, 0.9450177947601021, 0.9507419305049882, 0.9564981543220346, 0.9622803717348062, 0.9680825733050729, 0.9738988388606546, 0.9797233412333947, 0.9855503495400576, 0.9913742320384182, 0.9971894585900271, 1.0029906027601894, 1.0087723435845672, 1.0145294670305876, 1.0202568671805174, 1.0259495471616875, 1.031602619847935, 1.0372113083549082, 1.0427709463504475, 1.0482769781998655, 1.0537249589645512, 1.059110554271007, 1.064429540066133, 1.0696778022733269, 1.0748513363628072, 1.0799462468484342, 1.084958746722254, 1.0898851568369967, 1.0947219052458224, 1.0994655265077464, 1.1041126609663596, 1.1086600540087068, 1.1131045553104972, 1.117443118073172, 1.12167279825777, 1.1257907538199858, 1.1297942439503248, 1.1336806283228038, 1.1374473663552385, 1.14109201648378, 1.1446122354540358, 1.1480057776307941, 1.1512704943281062, 1.1544043331612297, 1.1574053374217212, 1.16027164547677, 1.1630014901936865, 1.165593198390319, 1.16804519031202, 1.1703559791356861, 1.172524170501278, 1.1745484620711446, 1.1764276431174063, 1.1781605941375821, 1.1797462864985897, 1.1811837821092164, 1.182472233121109, 1.1836108816583137, 1.1845990595753715, 1.1854361882439566, 1.186121778368043, 1.1866554298275727, 1.1870368315505908, 1.1872657614138333], [1.1696120172351863, 1.1695418685059997, 1.1693314649475264, 1.1689809344580584, 1.1684904902381796, 1.167860430845886, 1.1670911402736894, 1.1661830880476551, 1.1651368293482731, 1.163953005153077, 1.1626323424008633, 1.1611756541773535, 1.1595838399221021, 1.1578578856564137, 1.1559988642319778, 1.1540079355999004, 1.1518863470997267, 1.1496354337679935, 1.1472566186657802, 1.1447514132246255, 1.142121417610091, 1.1393683211021393, 1.1364939024913738, 1.1335000304900484, 1.1303886641566068, 1.1271618533323406, 1.123821739088568, 1.1203705541825366, 1.1168106235200144, 1.113144364622299, 1.1093742880950928, 1.105502998096398, 1.1015331928002619, 1.0974676648528496, 1.0933093018169335, 1.0890610866004868, 1.084726097864606, 1.08030751040552, 1.0758085955049135, 1.07123272124225, 1.066583352762183, 1.0618640524895095, 1.05707848028347, 1.0522303935224686, 1.0473236471095693, 1.0423621933883251, 1.0373500819576995, 1.03229145937398, 1.0271905687267304, 1.0220517490749084, 1.0168794347283912, 1.0116781543592015, 1.006452529925825, 1.0012072753930772, 0.9959471952290999, 0.9906771826601878, 0.9854022176633522, 0.9801273646757769, 0.9748577699996669, 0.9695986588804476, 0.9643553322358565, 0.9591331630132252, 0.9539375921521787, 0.9487741241301422, 0.9436483220684495, 0.9385658023775416, 0.9335322289207484, 0.9285533066775128, 0.9236347748886499, 0.9187823996684059, 0.9140019660706696, 0.9092992695997727, 0.904680107159869, 0.9001502674409481, 0.8957155207441087, 0.8913816082537942, 0.8871542307702633, 0.8830390369215941, 0.8790416108809833, 0.87516745962193, 0.8714219997510204, 0.8678105439653814, 0.8643382871893377, 0.8610102924522657, 0.8578314765769868, 0.8548065957551004, 0.8519402310923175, 0.8492367742129127, 0.8467004130177542, 0.844335117694798, 0.8421446270843101, 0.8401324355032713, 0.8383017801342769, 0.8366556290836928, 0.8351966702117604, 0.8339273008337333, 0.8328496183859603, 0.8319654121441085, 0.8312761560725427, 0.8307830028743062, 0.8304867793003529, 0.8303879827648137, 0.830486779300353, 0.8307830028743066, 0.8312761560725433, 0.8319654121441092, 0.8328496183859613, 0.8339273008337345, 0.8351966702117617, 0.8366556290836945, 0.8383017801342787, 0.8401324355032733, 0.8421446270843124, 0.8443351176948002, 0.8467004130177567, 0.8492367742129153, 0.8519402310923204, 0.8548065957551035, 0.85783147657699, 0.861010292452269, 0.8643382871893411, 0.867810543965385, 0.8714219997510241, 0.875167459621934, 0.8790416108809872, 0.8830390369215982, 0.8871542307702677, 0.8913816082537986, 0.8957155207441132, 0.9001502674409527, 0.9046801071598737, 0.9092992695997774, 0.9140019660706744, 0.9187823996684109, 0.9236347748886549, 0.9285533066775177, 0.9335322289207535, 0.9385658023775467, 0.943648322068455, 0.9487741241301476, 0.9539375921521841, 0.9591331630132306, 0.964355332235862, 0.9695986588804529, 0.9748577699996723, 0.9801273646757823, 0.9854022176633577, 0.9906771826601932, 0.9959471952291055, 1.0012072753930825, 1.0064525299258302, 1.0116781543592068, 1.0168794347283965, 1.0220517490749137, 1.0271905687267355, 1.0322914593739854, 1.0373500819577046, 1.0423621933883305, 1.0473236471095744, 1.0522303935224737, 1.0570784802834747, 1.0618640524895144, 1.066583352762188, 1.071232721242255, 1.0758085955049181, 1.0803075104055246, 1.0847260978646105, 1.089061086600491, 1.093309301816938, 1.0974676648528539, 1.1015331928002663, 1.105502998096402, 1.1093742880950965, 1.1131443646223027, 1.1168106235200181, 1.1203705541825402, 1.1238217390885716, 1.127161853332344, 1.13038866415661, 1.1335000304900515, 1.1364939024913767, 1.1393683211021421, 1.1421214176100938, 1.1447514132246281, 1.1472566186657827, 1.1496354337679957, 1.1518863470997287, 1.1540079355999027, 1.1559988642319794, 1.1578578856564157, 1.159583839922104, 1.1611756541773548, 1.1626323424008647, 1.1639530051530784, 1.1651368293482744, 1.166183088047656, 1.1670911402736905, 1.1678604308458864, 1.16849049023818, 1.1689809344580586, 1.1693314649475268, 1.169541868506], [1.152685295042207, 1.1526212197615529, 1.1524290345447585, 1.152108861275091, 1.1516609031171832, 1.1510854445557532, 1.1503828514496828, 1.149553571101327, 1.1485981323408772, 1.1475171456255748, 1.1463113031535075, 1.1449813789916814, 1.1435282292180138, 1.1419527920768135, 1.1402560881472807, 1.1384392205244587, 1.1365033750120235, 1.1344498203261837, 1.1322799083099033, 1.1299950741565283, 1.1275968366418145, 1.125086798363219, 1.1224666459851875, 1.119738150489036, 1.116903167425851, 1.1139636371706843, 1.110921585176115, 1.1077791222230577, 1.10453844466648, 1.1012018346734591, 1.097771660450739, 1.0942503764587055, 1.0906405236083696, 1.0869447294376648, 1.0831657082630073, 1.079306261301725, 1.0753692767605694, 1.0713577298851278, 1.0672746829645212, 1.0631232852853236, 1.0589067730281685, 1.054628469100006, 1.0502917828944627, 1.0459002099722117, 1.0414573316527174, 1.0369668145081314, 1.032432409749547, 1.0278579524952198, 1.023247360909763, 1.018604635202735, 1.0139338564744362, 1.0092391853961695, 1.0045248607116453, 0.9997951975457033, 0.9950545855060322, 0.9903074865631332, 0.9855584326934174, 0.9808120232700293, 0.9760729221858017, 0.971345854692662, 0.9666356039418494, 0.961947007209502, 0.9572849517925096, 0.9526543705600828, 0.9480602371472143, 0.9435075607771765, 0.9390013807014023, 0.934546760246562, 0.9301487804603783, 0.9258125333497643, 0.9215431147071901, 0.9173456165238243, 0.9132251189909615, 0.9091866820944974, 0.9052353368107986, 0.9013760759161714, 0.8976138444262701, 0.8939535296861634, 0.8903999511363653, 0.8869578497848767, 0.8836318774201452, 0.8804265856047407, 0.8773464144944294, 0.8743956815320888, 0.8715785700705009, 0.868899117982364, 0.8663612063198076, 0.8639685480891713, 0.8617246772097336, 0.8596329377273557, 0.8576964733555557, 0.8559182174172705, 0.854300883260449, 0.8528469552195747, 0.8515586801932308, 0.8504380599048632, 0.8494868439099782, 0.8487065234081599, 0.8480983259125467, 0.8476632108228402, 0.8474018659406182, 0.847314704957793, 0.8474018659406183, 0.8476632108228405, 0.8480983259125471, 0.8487065234081606, 0.8494868439099791, 0.8504380599048643, 0.851558680193232, 0.8528469552195762, 0.8543008832604506, 0.8559182174172723, 0.8576964733555577, 0.8596329377273577, 0.8617246772097358, 0.8639685480891738, 0.8663612063198103, 0.8688991179823667, 0.8715785700705037, 0.8743956815320917, 0.8773464144944326, 0.8804265856047441, 0.8836318774201485, 0.8869578497848801, 0.8903999511363688, 0.8939535296861671, 0.8976138444262738, 0.9013760759161754, 0.9052353368108025, 0.9091866820945014, 0.9132251189909657, 0.9173456165238286, 0.9215431147071944, 0.9258125333497689, 0.9301487804603826, 0.9345467602465665, 0.939001380701407, 0.943507560777181, 0.9480602371472191, 0.9526543705600877, 0.9572849517925144, 0.9619470072095069, 0.9666356039418544, 0.9713458546926668, 0.9760729221858064, 0.9808120232700341, 0.9855584326934224, 0.990307486563138, 0.9950545855060371, 0.9997951975457082, 1.00452486071165, 1.0092391853961744, 1.0139338564744411, 1.0186046352027396, 1.0232473609097679, 1.0278579524952243, 1.0324324097495516, 1.036966814508136, 1.041457331652722, 1.0459002099722163, 1.0502917828944671, 1.0546284691000105, 1.0589067730281727, 1.063123285285328, 1.0672746829645254, 1.071357729885132, 1.0753692767605734, 1.0793062613017288, 1.0831657082630113, 1.0869447294376686, 1.0906405236083734, 1.094250376458709, 1.0977716604507424, 1.1012018346734622, 1.1045384446664837, 1.1077791222230609, 1.1109215851761183, 1.1139636371706876, 1.1169031674258536, 1.1197381504890387, 1.1224666459851904, 1.1250867983632213, 1.127596836641817, 1.1299950741565306, 1.1322799083099055, 1.1344498203261857, 1.1365033750120253, 1.1384392205244604, 1.1402560881472823, 1.1419527920768153, 1.1435282292180151, 1.144981378991683, 1.1463113031535084, 1.1475171456255762, 1.1485981323408783, 1.1495535711013276, 1.1503828514496837, 1.1510854445557537, 1.1516609031171832, 1.1521088612750914, 1.152429034544759, 1.152621219761553], [1.1365782951033216, 1.1365201670978964, 1.1363458214860913, 1.1360553734858239, 1.1356490151419425, 1.1351270153486195, 1.1344897198805204, 1.1337375514325725, 1.1328710096680918, 1.1318906712749857, 1.1307971900296714, 1.1295912968683048, 1.1282737999648353, 1.1268455848153431, 1.125307614328032, 1.1236609289181787, 1.1219066466072514, 1.1200459631253126, 1.1180801520157417, 1.116010564741183, 1.1138386307895316, 1.111565857778637, 1.1091938315582803, 1.1067242163078344, 1.10415875462787, 1.1014992676238125, 1.0987476549795718, 1.0959058950188962, 1.0929760447519963, 1.0899602399047765, 1.0868606949277964, 1.0836797029818355, 1.0804196358967, 1.0770829440996383, 1.0736721565094467, 1.0701898803920777, 1.0666388011732306, 1.0630216822031044, 1.0593413644681517, 1.055600766244326, 1.0518028826859698, 1.0479507853441081, 1.0440476216075565, 1.0400966140598507, 1.0361010597446434, 1.0320643293318073, 1.0279898661761087, 1.0238811852599385, 1.0197418720112097, 1.0155755809871865, 1.011386034414667, 1.0071770205766362, 1.0029523920352323, 0.9987160636806284, 0.9944720105952499, 0.9902242657226097, 0.9859769173299863, 0.9817341062541745, 0.9775000229196364, 0.973278904118578, 0.9690750295427709, 0.9648927180573703, 0.9607363237075236, 0.9566102314492618, 0.9525188525970167, 0.9484666199811091, 0.9444579828097418, 0.9404974012313965, 0.9365893405950719, 0.932738265407557, 0.9289486329888524, 0.9252248868289936, 0.9215714496518315, 0.9179927161938372, 0.9144930457086531, 0.9110767542109439, 0.9077481064760541, 0.904511307815048, 0.9013704956478593, 0.8983297309004743, 0.8953929892552769, 0.8925641522868588, 0.8898469985186909, 0.8872451944390082, 0.8847622855170473, 0.8824016872633065, 0.8801666763797602, 0.8780603820478473, 0.8760857774035747, 0.8742456712501177, 0.8725427000588796, 0.8709793203099931, 0.8695578012227372, 0.8682802179252139, 0.8671484451109477, 0.8661641512277435, 0.8653287932412711, 0.8646436120123688, 0.864109628323076, 0.8637276395819227, 0.8634982172340773, 0.8634217048966784, 0.8634982172340775, 0.8637276395819231, 0.8641096283230767, 0.8646436120123693, 0.865328793241272, 0.8661641512277444, 0.8671484451109487, 0.8682802179252153, 0.8695578012227385, 0.8709793203099949, 0.8725427000588813, 0.8742456712501195, 0.8760857774035766, 0.8780603820478494, 0.8801666763797623, 0.8824016872633088, 0.8847622855170497, 0.8872451944390107, 0.8898469985186936, 0.8925641522868617, 0.8953929892552799, 0.8983297309004773, 0.9013704956478624, 0.9045113078150512, 0.9077481064760575, 0.9110767542109474, 0.9144930457086565, 0.9179927161938409, 0.9215714496518352, 0.9252248868289974, 0.9289486329888563, 0.9327382654075609, 0.9365893405950759, 0.9404974012314005, 0.944457982809746, 0.9484666199811131, 0.9525188525970211, 0.956610231449266, 0.9607363237075278, 0.9648927180573748, 0.9690750295427754, 0.9732789041185823, 0.9775000229196409, 0.9817341062541787, 0.9859769173299906, 0.9902242657226141, 0.9944720105952544, 0.9987160636806328, 1.0029523920352366, 1.0071770205766406, 1.0113860344146712, 1.015575580987191, 1.019741872011214, 1.023881185259943, 1.027989866176113, 1.0320643293318115, 1.0361010597446474, 1.0400966140598547, 1.0440476216075605, 1.0479507853441121, 1.0518028826859736, 1.0556007662443299, 1.0593413644681555, 1.0630216822031084, 1.0666388011732344, 1.0701898803920813, 1.0736721565094502, 1.077082944099642, 1.0804196358967038, 1.0836797029818384, 1.0868606949277995, 1.0899602399047799, 1.0929760447519994, 1.0959058950188991, 1.0987476549795747, 1.1014992676238153, 1.1041587546278728, 1.1067242163078366, 1.1091938315582828, 1.1115658577786391, 1.1138386307895338, 1.1160105647411853, 1.118080152015744, 1.1200459631253143, 1.121906646607253, 1.1236609289181807, 1.1253076143280334, 1.1268455848153447, 1.1282737999648367, 1.129591296868306, 1.1307971900296727, 1.1318906712749868, 1.1328710096680927, 1.1337375514325734, 1.1344897198805215, 1.13512701534862, 1.1356490151419427, 1.136055373485824, 1.1363458214860918, 1.1365201670978964], [1.1213065999007172, 1.1212542685225173, 1.1210973103668491, 1.1208358333718849, 1.12047001743915, 1.1200001144402691, 1.1194264482262122, 1.118749414638809, 1.117969481524273, 1.11708718874839, 1.1161031482129666, 1.1150180438730641, 1.113832631754471, 1.112547739970796, 1.1111642687394747, 1.1096831903959166, 1.1081055494049104, 1.106432462368337, 1.104665118028123, 1.1028047772632732, 1.1008527730797166, 1.0988105105915722, 1.0966794669923325, 1.0944611915143303, 1.0921573053747056, 1.089769501705975, 1.08729954546912, 1.0847492733469801, 1.0821205936155502, 1.0794154859906215, 1.076636001447003, 1.0737842620073899, 1.0708624604977224, 1.0678728602656904, 1.0648177948588076, 1.0616996676582633, 1.0585209514645275, 1.055284188030452, 1.0519919875373596, 1.0486470280093816, 1.0452520546610449, 1.0418098791728645, 1.0383233788894517, 1.0347954959343952, 1.0312292362359383, 1.0276276684572365, 1.0239939228247585, 1.0203311898481853, 1.0166427189249636, 1.0129318168225099, 1.0092018460309005, 1.0054562229787851, 1.0016984161051625, 0.997931943779634, 0.9941603720637469, 0.9903873123061017, 0.9866164185640159, 0.9828513848447206, 0.9790959421593117, 0.9753538553830264, 0.9716289199158098, 0.9679249581376678, 0.9642458156538887, 0.9605953573259335, 0.9569774630846076, 0.9533960235230549, 0.9498549352681573, 0.9463580961300899, 0.9429094000310502, 0.9395127317155985, 0.9361719612465368, 0.932890938291905, 0.9296734862103859, 0.926523395944253, 0.9234444197309013, 0.9204402646459937, 0.9175145859932983, 0.9146709805583672, 0.911912979745313, 0.9092440426180178, 0.9066675488691718, 0.9041867917425253, 0.901804970935648, 0.8995251855122547, 0.8973504268547945, 0.8952835716894314, 0.8933273752167701, 0.8914844643826453, 0.8897573313240067, 0.8881483270253078, 0.8866596552208914, 0.8852933665785873, 0.8840513531991021, 0.8829353434647937, 0.8819468972700494, 0.8810874016637577, 0.8803580669322734, 0.8797599231488423, 0.8792938172127093, 0.8789604103980804, 0.8787601764298264, 0.8786934000992829, 0.8787601764298265, 0.8789604103980807, 0.8792938172127095, 0.8797599231488428, 0.880358066932274, 0.8810874016637585, 0.8819468972700503, 0.8829353434647947, 0.8840513531991033, 0.8852933665785887, 0.8866596552208929, 0.8881483270253091, 0.8897573313240085, 0.8914844643826473, 0.893327375216772, 0.8952835716894338, 0.8973504268547966, 0.899525185512257, 0.9018049709356505, 0.9041867917425278, 0.9066675488691742, 0.9092440426180205, 0.9119129797453158, 0.9146709805583702, 0.917514585993301, 0.9204402646459969, 0.9234444197309044, 0.9265233959442561, 0.9296734862103891, 0.9328909382919083, 0.9361719612465402, 0.9395127317156019, 0.9429094000310538, 0.9463580961300934, 0.9498549352681611, 0.9533960235230583, 0.9569774630846114, 0.9605953573259371, 0.9642458156538923, 0.9679249581376715, 0.9716289199158136, 0.9753538553830303, 0.9790959421593158, 0.9828513848447245, 0.9866164185640198, 0.9903873123061054, 0.9941603720637509, 0.9979319437796378, 1.0016984161051663, 1.005456222978789, 1.009201846030904, 1.0129318168225134, 1.0166427189249674, 1.020331189848189, 1.0239939228247625, 1.02762766845724, 1.0312292362359419, 1.0347954959343988, 1.0383233788894553, 1.041809879172868, 1.0452520546610484, 1.0486470280093851, 1.051991987537363, 1.0552841880304553, 1.0585209514645308, 1.0616996676582662, 1.0648177948588107, 1.0678728602656935, 1.0708624604977255, 1.0737842620073927, 1.076636001447006, 1.0794154859906244, 1.0821205936155531, 1.0847492733469828, 1.0872995454691228, 1.0897695017059774, 1.092157305374708, 1.0944611915143323, 1.0966794669923348, 1.0988105105915742, 1.1008527730797188, 1.1028047772632752, 1.1046651180281246, 1.1064324623683386, 1.1081055494049117, 1.1096831903959177, 1.1111642687394763, 1.1125477399707975, 1.1138326317544722, 1.1150180438730652, 1.1161031482129677, 1.1170871887483909, 1.1179694815242738, 1.1187494146388095, 1.119426448226213, 1.1200001144402696, 1.1204700174391498, 1.1208358333718853, 1.1210973103668493, 1.1212542685225177], [1.106884983813195, 1.1068382732234892, 1.1066981748213962, 1.1064647887065002, 1.1061382817064451, 1.1057188873693231, 1.1052069059528036, 1.1046027044097704, 1.103906716370178, 1.1031194421187789, 1.1022414485682877, 1.101273369227494, 1.1002159041637547, 1.0990698199592248, 1.0978359496601047, 1.0965151927181127, 1.0951085149232884, 1.0936169483271687, 1.0920415911552703, 1.090383607707728, 1.0886442282468325, 1.086824748870119, 1.0849265313675438, 1.0829510030611702, 1.0808996566256888, 1.0787740498879472, 1.076575805603572, 1.0743066112086044, 1.0719682185439634, 1.0695624435503936, 1.0670911659314177, 1.0645563287816688, 1.0619599381778242, 1.0593040627292047, 1.0565908330849563, 1.0538224413945583, 1.0510011407182551, 1.0481292443838404, 1.0452091252860567, 1.0422432151247292, 1.0392340035775813, 1.0361840374035367, 1.0330959194721587, 1.0299723077147516, 1.0268159139925046, 1.023629502876956, 1.0204158903379408, 1.0171779423341105, 1.0139185733010365, 1.0106407445318766, 1.0073474624455507, 1.0040417767374026, 1.0007267784073457, 0.9974055976605911, 0.9940814016761582, 0.990757392238543, 0.9874368032281186, 0.9841228979661167, 0.9808189664103362, 0.9775283221981171, 0.9742542995335444, 0.9710002499163437, 0.9677695387105126, 0.9645655415513491, 0.9613916405902698, 0.9582512205775776, 0.9551476647841964, 0.9520843507643263, 0.9490646459619554, 0.946091903165249, 0.9431694558139522, 0.9403006131661402, 0.9374886553318938, 0.9347368281827634, 0.93204833814721, 0.9294263469035678, 0.9268739659834275, 0.9243942512997146, 0.9219901976150814, 0.9196647329675538, 0.91742071307165, 0.9152609157143936, 0.9131880351667838, 0.9112046766322905, 0.9093133507548777, 0.9075164682098074, 0.9058163344011038, 0.9042151442900015, 0.9027149773789563, 0.9013177928758668, 0.9000254250629903, 0.8988395788946855, 0.8977618258475053, 0.8967936000453527, 0.8959361946813591, 0.8951907587568826, 0.8945582941565293, 0.8940396530764207, 0.8936355358210488, 0.8933464889820101, 0.8931729040097101, 0.893115016186805, 0.8931729040097101, 0.8933464889820103, 0.8936355358210494, 0.8940396530764212, 0.89455829415653, 0.8951907587568834, 0.89593619468136, 0.8967936000453536, 0.8977618258475065, 0.8988395788946865, 0.9000254250629915, 0.9013177928758681, 0.9027149773789579, 0.9042151442900029, 0.9058163344011056, 0.9075164682098094, 0.9093133507548796, 0.9112046766322925, 0.9131880351667859, 0.915260915714396, 0.9174207130716521, 0.9196647329675562, 0.9219901976150839, 0.9243942512997172, 0.92687396598343, 0.9294263469035705, 0.9320483381472129, 0.9347368281827662, 0.9374886553318966, 0.940300613166143, 0.9431694558139552, 0.9460919031652522, 0.9490646459619584, 0.9520843507643293, 0.9551476647841998, 0.9582512205775806, 0.9613916405902732, 0.9645655415513523, 0.967769538710516, 0.9710002499163471, 0.9742542995335477, 0.9775283221981205, 0.9808189664103395, 0.9841228979661204, 0.9874368032281221, 0.9907573922385463, 0.9940814016761618, 0.9974055976605944, 1.000726778407349, 1.004041776737406, 1.007347462445554, 1.0106407445318797, 1.0139185733010398, 1.0171779423341138, 1.0204158903379443, 1.0236295028769593, 1.026815913992508, 1.0299723077147547, 1.0330959194721616, 1.0361840374035396, 1.0392340035775847, 1.042243215124732, 1.0452091252860596, 1.0481292443838435, 1.0510011407182582, 1.0538224413945612, 1.0565908330849592, 1.0593040627292076, 1.061959938177827, 1.0645563287816715, 1.0670911659314202, 1.069562443550396, 1.0719682185439658, 1.0743066112086066, 1.0765758056035746, 1.0787740498879497, 1.080899656625691, 1.0829510030611724, 1.0849265313675456, 1.086824748870121, 1.0886442282468343, 1.0903836077077298, 1.092041591155272, 1.09361694832717, 1.0951085149232898, 1.096515192718114, 1.097835949660106, 1.099069819959226, 1.1002159041637558, 1.1012733692274952, 1.1022414485682885, 1.1031194421187798, 1.103906716370179, 1.1046027044097715, 1.1052069059528045, 1.1057188873693233, 1.1061382817064456, 1.1064647887065002, 1.106698174821396, 1.1068382732234892], [1.0933273988229149, 1.0932861074695746, 1.0931622640035132, 1.0929559602026107, 1.0926673490166492, 1.0922966445471753, 1.09184412201909, 1.0913101177437514, 1.0906950290732993, 1.089999314345868, 1.0892234928212625, 1.0883681446066311, 1.087433910571583, 1.0864214922521365, 1.08533165174281, 1.0841652115760996, 1.082923054588509, 1.0816061237722148, 1.0802154221113867, 1.0787520124020826, 1.0772170170545696, 1.075611617876826, 1.0739370558378987, 1.0721946308096926, 1.070385701285683, 1.0685116840749411, 1.0665740539697652, 1.064574343385117, 1.0625141419679536, 1.0603950961744513, 1.058218908813002, 1.0559873385507705, 1.0537021993814908, 1.051365360052069, 1.0489787434454647, 1.0465443259172171, 1.0440641365828736, 1.0415402565534908, 1.03897481811628, 1.0363700038573687, 1.0337280457235865, 1.0310512240200855, 1.0283418663405504, 1.0256023464266875, 1.022835082953643, 1.0200425382379505, 1.0172272168646084, 1.0143916642298667, 1.0115384649963288, 1.0086702414570066, 1.0057896518050229, 1.0028993883057418, 1.0000021753682158, 0.9971007675129784, 0.9941979472333772, 0.9912965227478518, 0.9883993256407952, 0.9855092083899135, 0.9826290417783168, 0.9797617121899255, 0.9769101187871807, 0.9740771705704813, 0.9712657833192611, 0.9684788764151457, 0.965719369548208, 0.9629901793079507, 0.9602942156613137, 0.9576343783207003, 0.9550135530057592, 0.9524346076034351, 0.9499003882316086, 0.9474137152124831, 0.9449773789627328, 0.9425941358083041, 0.9402667037326419, 0.9379977580680035, 0.9357899271403992, 0.9336457878795671, 0.9315678614062253, 0.92955860860966, 0.927620425729456, 0.9257556399558987, 0.923966505064203, 0.922255197098298, 0.9206238101203695, 0.9190743520427468, 0.9176087405589884, 0.9162287991911877, 0.9149362534705587, 0.9137327272682618, 0.9126197392932182, 0.911598699773289, 0.9106709073357069, 0.9098375461019931, 0.9090996830118365, 0.9084582653894809, 0.907914118765142, 0.9074679449628127, 0.907120320464541, 0.9068716950598998, 0.9067223907879016, 0.9066726011770851, 0.9067223907879016, 0.9068716950599001, 0.9071203204645413, 0.907467944962813, 0.9079141187651426, 0.9084582653894816, 0.9090996830118373, 0.9098375461019939, 0.9106709073357077, 0.91159869977329, 0.9126197392932193, 0.913732727268263, 0.9149362534705601, 0.9162287991911893, 0.9176087405589897, 0.9190743520427486, 0.9206238101203711, 0.9222551970982996, 0.923966505064205, 0.9257556399559008, 0.927620425729458, 0.9295586086096621, 0.9315678614062274, 0.9336457878795691, 0.9357899271404013, 0.9379977580680058, 0.9402667037326444, 0.9425941358083064, 0.9449773789627353, 0.9474137152124855, 0.9499003882316112, 0.9524346076034376, 0.9550135530057619, 0.957634378320703, 0.9602942156613165, 0.9629901793079536, 0.9657193695482108, 0.9684788764151485, 0.9712657833192639, 0.9740771705704844, 0.9769101187871836, 0.9797617121899284, 0.9826290417783198, 0.9855092083899167, 0.9883993256407982, 0.991296522747855, 0.9941979472333803, 0.9971007675129815, 1.0000021753682187, 1.0028993883057447, 1.0057896518050258, 1.0086702414570095, 1.0115384649963317, 1.0143916642298696, 1.0172272168646115, 1.0200425382379534, 1.022835082953646, 1.0256023464266901, 1.0283418663405528, 1.0310512240200882, 1.0337280457235893, 1.0363700038573713, 1.0389748181162826, 1.0415402565534935, 1.044064136582876, 1.0465443259172198, 1.0489787434454672, 1.0513653600520714, 1.0537021993814932, 1.0559873385507728, 1.058218908813004, 1.0603950961744537, 1.0625141419679558, 1.064574343385119, 1.0665740539697675, 1.0685116840749431, 1.070385701285685, 1.0721946308096941, 1.0739370558379004, 1.0756116178768278, 1.0772170170545714, 1.0787520124020842, 1.080215422111388, 1.0816061237722159, 1.08292305458851, 1.0841652115761007, 1.0853316517428109, 1.0864214922521378, 1.0874339105715838, 1.0883681446066318, 1.0892234928212632, 1.0899993143458686, 1.0906950290733004, 1.0913101177437519, 1.0918441220190909, 1.0922966445471756, 1.0926673490166496, 1.0929559602026109, 1.0931622640035135, 1.093286107469575], [1.0806469610177518, 1.0806108613328942, 1.0805025899699563, 1.0803222299977973, 1.0800699198443315, 1.0797458532661495, 1.079350279305795, 1.0788835022364907, 1.0783458814940583, 1.0777378315957267, 1.0770598220454426, 1.0763123772252647, 1.075496076272341, 1.0746115529409233, 1.073659495448804, 1.0726406463074987, 1.0715558021354379, 1.0704058134533663, 1.0691915844610798, 1.0679140727945684, 1.0665742892625658, 1.0651732975614334, 1.0637122139672497, 1.0621922070038894, 1.0606144970858276, 1.0589803561343132, 1.0572911071654998, 1.05554812384905, 1.0537528300356467, 1.051906699251794, 1.0500112541602034, 1.0480680659840058, 1.046078753892958, 1.044044984349747, 1.0419684704144376, 1.0398509710050503, 1.0376942901121966, 1.0355002759656584, 1.0332708201507441, 1.0310078566722185, 1.0287133609635768, 1.026389348839402, 1.0240378753885333, 1.021661033805765, 1.0192609541598094, 1.0168398020952627, 1.0143997774663476, 1.0119431129002627, 1.0094720722880095, 1.006988949200661, 1.0044960652291224, 1.0019957682455578, 0.9994904305847775, 0.996982447144054, 0.9944742334000017, 0.9919682233413627, 0.9894668673167696, 0.9869726297968092, 0.9844879870499846, 0.9820154247324908, 0.9795574353920362, 0.9771165158863179, 0.9746951647171301, 0.9722958792815095, 0.9699211530417512, 0.9675734726165967, 0.9652553147963754, 0.9629691434853935, 0.9607174065753843, 0.9585025327543749, 0.9563269282558876, 0.9541929735539413, 0.9521030200099101, 0.9500593864778457, 0.9480643558754576, 0.9461201717284898, 0.9442290346967939, 0.9423930990909116, 0.9406144693884962, 0.9388951967603668, 0.9372372756164244, 0.9356426401820562, 0.934113161115993, 0.9326506421808768, 0.9312568169780201, 0.9299333457580036, 0.9286818123188523, 0.9275037210035417, 0.9264004938085331, 0.9253734676148846, 0.9244238915532725, 0.9235529245139319, 0.9227616328121462, 0.9220509880194258, 0.9214218649699611, 0.9208750399512947, 0.9204111890874382, 0.9200308869218777, 0.9197346052070584, 0.919522711906027, 0.9193954704109533, 0.9193530389822482, 0.9193954704109535, 0.9195227119060272, 0.9197346052070586, 0.9200308869218781, 0.9204111890874386, 0.9208750399512953, 0.9214218649699618, 0.9220509880194264, 0.922761632812147, 0.9235529245139328, 0.9244238915532734, 0.9253734676148856, 0.9264004938085342, 0.927503721003543, 0.9286818123188536, 0.9299333457580049, 0.9312568169780217, 0.9326506421808783, 0.9341131611159946, 0.9356426401820579, 0.9372372756164262, 0.9388951967603686, 0.9406144693884979, 0.9423930990909134, 0.9442290346967959, 0.9461201717284919, 0.9480643558754596, 0.9500593864778479, 0.9521030200099122, 0.9541929735539435, 0.9563269282558897, 0.9585025327543771, 0.9607174065753865, 0.9629691434853958, 0.9652553147963778, 0.9675734726165992, 0.9699211530417539, 0.972295879281512, 0.9746951647171327, 0.9771165158863203, 0.9795574353920388, 0.9820154247324935, 0.9844879870499874, 0.9869726297968119, 0.9894668673167722, 0.9919682233413651, 0.9944742334000044, 0.9969824471440565, 0.99949043058478, 1.0019957682455605, 1.004496065229125, 1.0069889492006634, 1.0094720722880122, 1.0119431129002652, 1.0143997774663502, 1.0168398020952651, 1.019260954159812, 1.0216610338057672, 1.0240378753885353, 1.0263893488394045, 1.0287133609635792, 1.0310078566722207, 1.0332708201507466, 1.0355002759656609, 1.0376942901121986, 1.0398509710050523, 1.0419684704144399, 1.044044984349749, 1.0460787538929601, 1.0480680659840078, 1.0500112541602051, 1.0519066992517958, 1.053752830035649, 1.0555481238490516, 1.0572911071655016, 1.0589803561343147, 1.0606144970858293, 1.062192207003891, 1.0637122139672512, 1.065173297561435, 1.0665742892625674, 1.0679140727945697, 1.0691915844610809, 1.0704058134533674, 1.071555802135439, 1.0726406463074998, 1.0736594954488048, 1.0746115529409244, 1.0754960762723416, 1.0763123772252652, 1.0770598220454433, 1.0777378315957271, 1.078345881494059, 1.078883502236491, 1.0793502793057959, 1.0797458532661497, 1.0800699198443315, 1.0803222299977973, 1.0805025899699563, 1.0806108613328942], [1.0688559379023295, 1.068824776245451, 1.0687313159731842, 1.0685756311730623, 1.0683578452990394, 1.0680781311335004, 1.067736710733912, 1.0673338553639382, 1.0668698854088032, 1.0663451702746467, 1.0657601282715374, 1.065115226479803, 1.0644109805992459, 1.0636479547807942, 1.0628267614400728, 1.0619480610523289, 1.061012561928111, 1.0600210199690314, 1.0589742384029066, 1.0578730674975123, 1.0567184042521442, 1.0555111920661233, 1.0542524203833348, 1.0529431243118452, 1.0515843842175876, 1.0501773252910587, 1.048723117085933, 1.0472229730284375, 1.0456781498963024, 1.0440899472660532, 1.042459706927366, 1.040788812263177, 1.0390786875941989, 1.0373307974864605, 1.0355466460204628, 1.033727776020516, 1.031875768242803, 1.0299922405207005, 1.0280788468658721, 1.026137276523653, 1.0241692529812427, 1.0221765329272323, 1.0201609051610108, 1.0181241894506206, 1.0160682353376727, 1.0139949208879673, 1.01190615138653, 1.0098038579758388, 1.0076899962360946, 1.0055665447064759, 1.003435503346439, 1.001298891936217, 0.9991587484158337, 0.9970171271620747, 0.9948760972030276, 0.9927377403699922, 0.9906041493867375, 0.9884774258963146, 0.9863596784258436, 0.9842530202899478, 0.9821595674337645, 0.980081436216736, 0.978020741138672, 0.9759795925098821, 0.9739600940674951, 0.9719643405404037, 0.9699944151656211, 0.9680523871591803, 0.9661403091450645, 0.964260214546019, 0.9624141149404567, 0.9606039973900419, 0.9588318217428891, 0.9570995179176841, 0.9554089831743776, 0.9537620793774418, 0.9521606302580123, 0.9506064186815357, 0.9491011839278399, 0.9476466189908017, 0.946244367905019, 0.9448960231071031, 0.9436031228393753, 0.9423671486038772, 0.9411895226747015, 0.9400716056766977, 0.9390146942386031, 0.9380200187286113, 0.9370887410802946, 0.9362219527166463, 0.9354206725798273, 0.934685845273937, 0.9340183393278491, 0.933418945584792, 0.9328883757249687, 0.9324272609270625, 0.9320361506739898, 0.9317155117077385, 0.9314657271375638, 0.9312870957052101, 0.931179831210213, 0.9311440620976705, 0.9311798312102131, 0.9312870957052101, 0.9314657271375638, 0.9317155117077388, 0.93203615067399, 0.9324272609270631, 0.9328883757249693, 0.9334189455847925, 0.9340183393278498, 0.9346858452739376, 0.935420672579828, 0.936221952716647, 0.9370887410802955, 0.9380200187286125, 0.9390146942386042, 0.9400716056766989, 0.9411895226747027, 0.9423671486038784, 0.9436031228393768, 0.9448960231071046, 0.9462443679050203, 0.9476466189908033, 0.9491011839278414, 0.9506064186815372, 0.9521606302580139, 0.9537620793774436, 0.9554089831743793, 0.9570995179176858, 0.9588318217428907, 0.9606039973900437, 0.9624141149404585, 0.9642602145460207, 0.9661403091450665, 0.9680523871591822, 0.969994415165623, 0.9719643405404057, 0.9739600940674973, 0.975979592509884, 0.9780207411386741, 0.9800814362167383, 0.9821595674337666, 0.9842530202899498, 0.9863596784258457, 0.9884774258963169, 0.9906041493867397, 0.9927377403699942, 0.9948760972030298, 0.9970171271620769, 0.9991587484158359, 1.001298891936219, 1.003435503346441, 1.005566544706478, 1.0076899962360968, 1.009803857975841, 1.011906151386532, 1.0139949208879693, 1.016068235337675, 1.0181241894506226, 1.0201609051610125, 1.0221765329272343, 1.0241692529812447, 1.0261372765236547, 1.0280788468658741, 1.0299922405207027, 1.031875768242805, 1.0337277760205175, 1.0355466460204645, 1.0373307974864623, 1.0390786875942006, 1.0407888122631785, 1.0424597069273676, 1.044089947266055, 1.0456781498963041, 1.0472229730284388, 1.0487231170859346, 1.0501773252910602, 1.051584384217589, 1.0529431243118466, 1.054252420383336, 1.0555111920661244, 1.0567184042521456, 1.0578730674975134, 1.0589742384029077, 1.0600210199690323, 1.0610125619281119, 1.0619480610523298, 1.0628267614400735, 1.063647954780795, 1.0644109805992463, 1.0651152264798034, 1.065760128271538, 1.0663451702746471, 1.066869885408804, 1.0673338553639384, 1.0677367107339126, 1.0680781311335006, 1.0683578452990394, 1.0685756311730623, 1.0687313159731842, 1.0688247762454512], [1.0579657365300008, 1.0579392333990796, 1.0578597456646475, 1.057727338293165, 1.057542119533591, 1.0573042408746058, 1.0570138969845915, 1.0566713256342322, 1.056276807601569, 1.0558306665592976, 1.0553332689440642, 1.0547850238074747, 1.0541863826484956, 1.0535378392268904, 1.0528399293572916, 1.0520932306834823, 1.051298362432414, 1.0504559851474566, 1.0495668004003467, 1.0486315504812502, 1.0476510180663416, 1.046626025862246, 1.045557436226683, 1.0444461507645963, 1.0432931098990381, 1.0420992924160446, 1.040865714982708, 1.0395934316376332, 1.0382835332529323, 1.0369371469669015, 1.035555435586495, 1.0341395969587026, 1.0326908633099188, 1.0312105005523833, 1.0296998075567674, 1.0281601153899753, 1.0265927865172328, 1.024999213967543, 1.0233808204615937, 1.0217390575012246, 1.02007540441958, 1.0183913673911, 1.0166884784005394, 1.0149682941702398, 1.013232395044935, 1.0114823838334184, 1.0097198846064679, 1.0079465414504927, 1.0061640171764479, 1.0043739919836492, 1.0025781620782208, 1.0007782382460093, 0.9989759443799223, 0.9971730159617648, 0.9953711984987906, 0.9935722459153286, 0.9917779188999895, 0.9899899832091403, 0.9882102079274846, 0.9864403636867891, 0.9846822208439708, 0.9829375476199695, 0.9812081082010273, 0.9794956608042144, 0.9778019557092571, 0.9761287332589451, 0.9744777218306236, 0.9728506357815087, 0.9712491733707846, 0.9696750146616875, 0.9681298194069954, 0.9666152249215787, 0.9651328439458849, 0.963684262504445, 0.9622710377636953, 0.9608946958936059, 0.9595567299377921, 0.958258597696949, 0.9570017196306115, 0.955787476782373, 0.9546172087338102, 0.9534922115924639, 0.9524137360192882, 0.9513829853010348, 0.9504011134730519, 0.9494692234979791, 0.9485883655057777, 0.9477595351004724, 0.9469836717388876, 0.9462616571865363, 0.9455943140556607, 0.9449824044302444, 0.9444266285825914, 0.9439276237858327, 0.9434859632264408, 0.9431021550205354, 0.9427766413374402, 0.9425097976336009, 0.9423019319996043, 0.9421532846226551, 0.9420640273664519, 0.9420342634699993, 0.9420640273664519, 0.9421532846226552, 0.9423019319996047, 0.942509797633601, 0.9427766413374404, 0.9431021550205357, 0.9434859632264413, 0.9439276237858333, 0.9444266285825921, 0.9449824044302451, 0.9455943140556614, 0.9462616571865369, 0.9469836717388885, 0.9477595351004732, 0.9485883655057787, 0.9494692234979801, 0.9504011134730529, 0.9513829853010358, 0.9524137360192894, 0.953492211592465, 0.9546172087338115, 0.9557874767823742, 0.9570017196306128, 0.9582585976969502, 0.9595567299377934, 0.9608946958936074, 0.9622710377636967, 0.9636842625044466, 0.9651328439458864, 0.9666152249215801, 0.968129819406997, 0.9696750146616891, 0.9712491733707863, 0.9728506357815102, 0.9744777218306252, 0.9761287332589466, 0.9778019557092588, 0.979495660804216, 0.9812081082010289, 0.9829375476199714, 0.9846822208439726, 0.986440363686791, 0.9882102079274866, 0.9899899832091421, 0.9917779188999915, 0.9935722459153303, 0.9953711984987927, 0.9971730159617666, 0.9989759443799242, 1.000778238246011, 1.0025781620782224, 1.004373991983651, 1.0061640171764497, 1.0079465414504947, 1.0097198846064697, 1.01148238383342, 1.013232395044937, 1.0149682941702416, 1.0166884784005412, 1.0183913673911018, 1.0200754044195814, 1.0217390575012262, 1.0233808204615953, 1.0249992139675448, 1.0265927865172344, 1.0281601153899766, 1.0296998075567692, 1.0312105005523848, 1.0326908633099203, 1.0341395969587042, 1.0355554355864964, 1.0369371469669029, 1.0382835332529339, 1.0395934316376345, 1.0408657149827096, 1.042099292416046, 1.0432931098990395, 1.0444461507645975, 1.0455574362266842, 1.046626025862247, 1.0476510180663425, 1.0486315504812513, 1.0495668004003473, 1.050455985147457, 1.0512983624324146, 1.0520932306834831, 1.052839929357292, 1.053537839226891, 1.054186382648496, 1.054785023807475, 1.0553332689440647, 1.0558306665592982, 1.0562768076015696, 1.0566713256342326, 1.0570138969845921, 1.057304240874606, 1.057542119533591, 1.0577273382931653, 1.0578597456646477, 1.0579392333990798], [1.0479868924672608, 1.0479647429965895, 1.047898313205298, 1.0477876589466204, 1.047632873279501, 1.047434086423872, 1.0471914656979535, 1.0469052154374712, 1.0465755768966742, 1.0462028281310034, 1.0457872838612332, 1.0453292953188884, 1.0448292500727006, 1.0442875718358637, 1.0437047202537966, 1.0430811906721198, 1.042417513884516, 1.0417142558601253, 1.040972017450104, 1.040191434072952, 1.0393731753781958, 1.0385179448879949, 1.0376264796162167, 1.0366995496645122, 1.0357379577949124, 1.0347425389784386, 1.0337141599192228, 1.032653718553614, 1.0315621435237388, 1.0304403936249853, 1.0292894572268614, 1.028110351666694, 1.0269041226156208, 1.0256718434163425, 1.0244146143921027, 1.0231335621263746, 1.0218298387127518, 1.020504620974548, 1.0191591096536454, 1.017794528568142, 1.016412123738386, 1.0150131624810246, 1.0135989324707138, 1.0121707407692042, 1.0107299128215457, 1.0092777914192175, 1.007815735630048, 1.0063451196948492, 1.004867331890765, 1.0033837733614033, 1.0018958569139058, 1.0004050057831968, 0.9989126523637387, 0.9974202369092289, 0.9959292062007655, 0.9944410121841278, 0.992957110576924, 0.9914789594464817, 0.9900080177594763, 0.988545743904427, 0.9870935941883104, 0.9856530213086913, 0.9842254728028946, 0.9828123894758939, 0.9814152038087252, 0.9800353383493879, 0.9786742040883283, 0.9773331988207538, 0.9760137054981599, 0.9747170905716025, 0.9734447023293692, 0.9721978692318558, 0.9709778982465631, 0.9697860731862656, 0.9686236530535074, 0.9674918703946938, 0.9663919296671417, 0.9653250056225375, 0.9642922417103259, 0.9632947485046233, 0.9623336021582867, 0.9614098428878156, 0.9605244734927807, 0.9596784579134767, 0.9588727198304859, 0.9581081413098175, 0.9573855614972272, 0.9567057753652752, 0.9560695325165863, 0.9554775360466862, 0.9549304414696628, 0.954428855709776, 0.9539733361619801, 0.9535643898241598, 0.9532024725036913, 0.9528879881007528, 0.9526212879705753, 0.9524026703666187, 0.9522323799664077, 0.9521106074815152, 0.9520374893529249, 0.9520131075327393, 0.9520374893529249, 0.9521106074815153, 0.9522323799664079, 0.952402670366619, 0.9526212879705754, 0.9528879881007533, 0.9532024725036916, 0.95356438982416, 0.9539733361619807, 0.9544288557097765, 0.9549304414696632, 0.9554775360466866, 0.9560695325165871, 0.9567057753652759, 0.9573855614972281, 0.9581081413098184, 0.9588727198304868, 0.9596784579134775, 0.9605244734927819, 0.9614098428878165, 0.9623336021582876, 0.9632947485046242, 0.964292241710327, 0.9653250056225385, 0.9663919296671429, 0.967491870394695, 0.9686236530535085, 0.9697860731862669, 0.9709778982465644, 0.972197869231857, 0.9734447023293705, 0.9747170905716038, 0.9760137054981614, 0.9773331988207551, 0.9786742040883298, 0.9800353383493893, 0.9814152038087266, 0.9828123894758952, 0.984225472802896, 0.9856530213086927, 0.987093594188312, 0.9885457439044286, 0.9900080177594779, 0.9914789594464831, 0.9929571105769256, 0.9944410121841293, 0.9959292062007672, 0.9974202369092302, 0.9989126523637402, 1.0004050057831981, 1.0018958569139074, 1.0033837733614048, 1.0048673318907666, 1.0063451196948507, 1.0078157356300494, 1.009277791419219, 1.010729912821547, 1.0121707407692055, 1.0135989324707149, 1.015013162481026, 1.0164121237383876, 1.0177945285681433, 1.019159109653647, 1.0205046209745494, 1.021829838712753, 1.023133562126376, 1.024414614392104, 1.0256718434163439, 1.0269041226156221, 1.0281103516666952, 1.0292894572268627, 1.0304403936249864, 1.0315621435237399, 1.032653718553615, 1.033714159919224, 1.0347425389784397, 1.0357379577949135, 1.036699549664513, 1.0376264796162173, 1.0385179448879958, 1.0393731753781965, 1.0401914340729526, 1.0409720174501047, 1.0417142558601258, 1.0424175138845166, 1.0430811906721205, 1.0437047202537972, 1.0442875718358644, 1.044829250072701, 1.0453292953188889, 1.0457872838612337, 1.0462028281310038, 1.046575576896675, 1.0469052154374714, 1.0471914656979542, 1.0474340864238723, 1.0476328732795008, 1.0477876589466206, 1.0478983132052981, 1.04796474299659], [1.038929059601267, 1.0389109343601124, 1.038856574275301, 1.0387660262540048, 1.0386393684455555, 1.038476710197483, 1.0382781919939086, 1.0380439853762333, 1.0377742928460423, 1.0374693477501367, 1.0371294141475773, 1.036754786658618, 1.036345790295387, 1.0359027802741576, 1.0354261418090405, 1.0349162898869082, 1.03437366902336, 1.0337987529995083, 1.0331920445793714, 1.0325540752076339, 1.0318854046875365, 1.0311866208386369, 1.0304583391341864, 1.029701202317857, 1.0289158799995408, 1.0281030682299561, 1.0272634890537722, 1.026397890040985, 1.0255070437962561, 1.0245917474459516, 1.0236528221025996, 1.022691112306515, 1.0217074854443295, 1.0207028311441877, 1.019678060647378, 1.01863410615619, 1.0175719201577946, 1.0164924747239834, 1.0153967607866106, 1.0142857873886146, 1.0131605809105328, 1.0120221842724395, 1.0108716561112894, 1.0097100699336763, 1.0085385132440658, 1.0073580866486038, 1.0061699029346465, 1.0049750861262208, 1.0037747705156654, 1.002570099671776, 1.0013622254248202, 1.0001523068288791, 0.9989415091020104, 0.997731002544824, 0.9965219614381169, 0.9953155629203033, 0.9941129858454422, 0.9929154096227564, 0.9917240130386111, 0.9905399730620142, 0.9893644636347705, 0.9881986544475299, 0.9870437097030379, 0.985900786867997, 0.984771035415029, 0.9836555955563185, 0.9825555969706024, 0.981472157525255, 0.9804063819953014, 0.9793593607812722, 0.9783321686278847, 0.9773258633456195, 0.976341484537315, 0.9753800523319821, 0.9744425661280869, 0.9735300033486114, 0.9726433182102407, 0.9717834405090713, 0.9709512744252604, 0.9701476973490639, 0.9693735587307252, 0.9686296789566774, 0.9679168482545313, 0.9672358256292909, 0.9665873378332343, 0.9659720783718492, 0.9653907065481799, 0.9648438465478871, 0.964332086567251, 0.9638559779862899, 0.9634160345890663, 0.9630127318331677, 0.9626465061702469, 0.9623177544193886, 0.9620268331949501, 0.9617740583903989, 0.9615597047195205, 0.9613840053162399, 0.9612471513941364, 0.9611492919665827, 0.9610905336282716, 0.9610709403987331, 0.9610905336282716, 0.9611492919665828, 0.9612471513941365, 0.9613840053162401, 0.9615597047195207, 0.9617740583903992, 0.9620268331949505, 0.9623177544193889, 0.9626465061702474, 0.9630127318331682, 0.9634160345890668, 0.9638559779862904, 0.9643320865672513, 0.9648438465478876, 0.9653907065481806, 0.96597207837185, 0.966587337833235, 0.9672358256292916, 0.9679168482545321, 0.9686296789566782, 0.9693735587307258, 0.9701476973490647, 0.9709512744252612, 0.9717834405090723, 0.9726433182102415, 0.9735300033486124, 0.974442566128088, 0.9753800523319831, 0.9763414845373161, 0.9773258633456205, 0.9783321686278859, 0.9793593607812733, 0.9804063819953025, 0.981472157525256, 0.9825555969706036, 0.9836555955563195, 0.9847710354150302, 0.9859007868679982, 0.9870437097030393, 0.9881986544475312, 0.9893644636347718, 0.9905399730620156, 0.9917240130386125, 0.9929154096227575, 0.9941129858454435, 0.9953155629203048, 0.9965219614381182, 0.9977310025448252, 0.9989415091020116, 1.0001523068288802, 1.0013622254248213, 1.002570099671777, 1.0037747705156668, 1.004975086126222, 1.0061699029346478, 1.007358086648605, 1.008538513244067, 1.0097100699336774, 1.0108716561112903, 1.0120221842724406, 1.013160580910534, 1.0142857873886155, 1.0153967607866117, 1.016492474723985, 1.0175719201577957, 1.018634106156191, 1.0196780606473792, 1.0207028311441886, 1.0217074854443307, 1.0226911123065159, 1.0236528221026007, 1.0245917474459525, 1.0255070437962575, 1.0263978900409858, 1.0272634890537733, 1.028103068229957, 1.0289158799995417, 1.0297012023178576, 1.0304583391341873, 1.0311866208386375, 1.0318854046875372, 1.0325540752076345, 1.0331920445793716, 1.0337987529995087, 1.0343736690233607, 1.0349162898869089, 1.0354261418090407, 1.035902780274158, 1.0363457902953872, 1.0367547866586184, 1.0371294141475778, 1.0374693477501369, 1.0377742928460425, 1.0380439853762333, 1.0382781919939088, 1.038476710197483, 1.0386393684455555, 1.0387660262540048, 1.0388565742753013, 1.0389109343601128], [1.0308010008003263, 1.0307865469009239, 1.0307431979705137, 1.030670992304323, 1.0305699937005268, 1.030440291419423, 1.0302820001262505, 1.0300952598176158, 1.0298802357314902, 1.0296371182407347, 1.029366122730088, 1.0290674894565708, 1.0287414833932185, 1.0283883940560834, 1.0280085353144104, 1.027602245183907, 1.0271698856030096, 1.0267118421920456, 1.0262285239952003, 1.025720363205168, 1.0251878148703937, 1.024631356584789, 1.0240514881598146, 1.0234487312788216, 1.0228236291335444, 1.022176746042638, 1.021508667052162, 1.020819997517914, 1.0201113626695204, 1.0193834071562085, 1.0186367945741777, 1.0178722069755173, 1.0170903443586121, 1.016291924140001, 1.015477680607669, 1.0146483643557633, 1.013804741700748, 1.0129475940790318, 1.01207771742612, 1.0111959215373747, 1.0103030294104824, 1.0093998765697656, 1.0084873103724932, 1.0075661892973882, 1.0066373822155532, 1.0057017676440732, 1.0047602329825958, 1.0038136737332188, 1.00286299270406, 1.0019090991969293, 1.0009529081795565, 0.999995339442885, 0.9990373167439746, 0.9980797669351177, 0.9971236190798117, 0.9961698035562824, 0.9952192511493079, 0.9942728921311396, 0.9933316553323676, 0.9923964672036357, 0.9914682508691565, 0.9905479251730349, 0.989636403719458, 0.9887345939078582, 0.9878433959642102, 0.9869637019696731, 0.9860963948878309, 0.9852423475918357, 0.9844024218928036, 0.983577467570848, 0.9827683214101848, 0.9819758062397707, 0.9812007299809773, 0.9804438847038298, 0.9797060456933646, 0.9789879705276863, 0.9782903981693202, 0.977614048071471, 0.9769596193008047, 0.9763277896783805, 0.9757192149403526, 0.975134527920056, 0.9745743377530837, 0.9740392291069369, 0.9735297614368136, 0.9730464682690665, 0.9725898565138317, 0.9721604058082819, 0.971758567891919, 0.9713847660152609, 0.971039394383232, 0.9707228176344822, 0.9704353703578196, 0.9701773566468416, 0.9699490496937877, 0.9697506914235514, 0.9695824921686955, 0.9694446303862331, 0.9693372524168384, 0.9692604722870534, 0.9692143715549582, 0.9691989991996738, 0.9692143715549583, 0.9692604722870535, 0.9693372524168387, 0.9694446303862331, 0.9695824921686955, 0.9697506914235517, 0.969949049693788, 0.9701773566468419, 0.9704353703578199, 0.9707228176344823, 0.9710393943832322, 0.9713847660152612, 0.9717585678919192, 0.9721604058082826, 0.9725898565138321, 0.9730464682690672, 0.9735297614368141, 0.9740392291069374, 0.9745743377530843, 0.9751345279200566, 0.9757192149403532, 0.9763277896783811, 0.9769596193008052, 0.9776140480714717, 0.978290398169321, 0.978987970527687, 0.9797060456933654, 0.9804438847038306, 0.981200729980978, 0.9819758062397713, 0.9827683214101854, 0.9835774675708489, 0.9844024218928044, 0.9852423475918364, 0.9860963948878317, 0.986963701969674, 0.9878433959642111, 0.9887345939078592, 0.9896364037194592, 0.9905479251730359, 0.9914682508691574, 0.9923964672036368, 0.9933316553323687, 0.9942728921311407, 0.9952192511493088, 0.9961698035562833, 0.9971236190798126, 0.9980797669351188, 0.9990373167439753, 0.9999953394428859, 1.0009529081795574, 1.0019090991969302, 1.002862992704061, 1.0038136737332197, 1.0047602329825969, 1.005701767644074, 1.006637382215554, 1.0075661892973893, 1.008487310372494, 1.0093998765697665, 1.0103030294104833, 1.0111959215373754, 1.0120777174261208, 1.0129475940790327, 1.0138047417007492, 1.0146483643557642, 1.01547768060767, 1.0162919241400017, 1.0170903443586128, 1.0178722069755182, 1.0186367945741783, 1.019383407156209, 1.020111362669521, 1.0208199975179144, 1.0215086670521627, 1.0221767460426388, 1.022823629133545, 1.0234487312788223, 1.024051488159815, 1.0246313565847893, 1.0251878148703941, 1.0257203632051681, 1.0262285239952005, 1.026711842192046, 1.0271698856030098, 1.0276022451839077, 1.0280085353144106, 1.0283883940560838, 1.0287414833932187, 1.029067489456571, 1.0293661227300883, 1.029637118240735, 1.0298802357314907, 1.0300952598176156, 1.0302820001262507, 1.030440291419423, 1.0305699937005266, 1.030670992304323, 1.0307431979705137, 1.0307865469009243], [1.0236105794363861, 1.02359942195341, 1.0235659595692972, 1.0235102224713435, 1.0234322609478625, 1.023332145352411, 1.0232099660536986, 1.0230658333711717, 1.0228998774962588, 1.0227122483992723, 1.0225031157219457, 1.0222726686555959, 1.0220211158048909, 1.0217486850372104, 1.0214556233175744, 1.0211421965291303, 1.0208086892791743, 1.0204554046906937, 1.0200826641794132, 1.0196908072163342, 1.019280191075752, 1.0188511905687443, 1.0184041977621283, 1.0179396216828829, 1.0174578880080423, 1.0169594387400713, 1.0164447318677405, 1.0159142410125215, 1.01536845506054, 1.0148078777801257, 1.0142330274250093, 1.0136444363232306, 1.0130426504518313, 1.0124282289974194, 1.0118017439027045, 1.0111637793991197, 1.0105149315256619, 1.0098558076340944, 1.0091870258806808, 1.0085092147046293, 1.0078230122934546, 1.0071290660354777, 1.0064280319597099, 1.0057205741633886, 1.0050073642274557, 1.0042890806202935, 1.0035664080900581, 1.002840037045977, 1.0021106629290017, 1.0013789855722428, 1.0006457085516192, 0.9999115385272196, 0.9991771845758636, 0.9984433575154071, 0.9977107692213544, 0.99698013193637, 0.9962521575733166, 0.9955275570124744, 0.9948070393936239, 0.9940913114037103, 0.9933810765608282, 0.9926770344953036, 0.9919798802286744, 0.9912903034513901, 0.9906089878000975, 0.9899366101353814, 0.9892738398208715, 0.9886213380046425, 0.9879797569038508, 0.9873497390935858, 0.9867319168009127, 0.9861269112051164, 0.985535331745159, 0.9849577754353814, 0.9843948261904854, 0.9838470541608387, 0.9833150150791566, 0.9827992496196045, 0.9823002827703718, 0.9818186232207653, 0.9813547627638517, 0.9809091757156837, 0.980482318352118, 0.9800746283642251, 0.9796865243332666, 0.9793184052261948, 0.9789706499126042, 0.9786436167040324, 0.9783376429164806, 0.9780530444569809, 0.9777901154350099, 0.9775491277994967, 0.9773303310021381, 0.9771339516876805, 0.9769601934117856, 0.9768092363870399, 0.97668123725762, 0.9765763289030664, 0.9764946202715633, 0.9764361962430662, 0.9764011175225523, 0.9763894205636138, 0.9764011175225524, 0.9764361962430663, 0.9764946202715633, 0.9765763289030663, 0.9766812372576203, 0.9768092363870401, 0.9769601934117857, 0.9771339516876808, 0.9773303310021383, 0.977549127799497, 0.9777901154350104, 0.9780530444569813, 0.9783376429164811, 0.9786436167040329, 0.9789706499126044, 0.9793184052261952, 0.9796865243332671, 0.9800746283642257, 0.9804823183521184, 0.9809091757156841, 0.9813547627638523, 0.9818186232207657, 0.9823002827703724, 0.9827992496196049, 0.9833150150791571, 0.9838470541608393, 0.9843948261904859, 0.9849577754353821, 0.9855353317451596, 0.9861269112051169, 0.9867319168009132, 0.9873497390935864, 0.9879797569038514, 0.988621338004643, 0.9892738398208724, 0.989936610135382, 0.9906089878000982, 0.9912903034513908, 0.991979880228675, 0.9926770344953044, 0.9933810765608287, 0.994091311403711, 0.9948070393936248, 0.9955275570124751, 0.9962521575733173, 0.9969801319363708, 0.9977107692213553, 0.9984433575154078, 0.9991771845758641, 0.9999115385272203, 1.0006457085516198, 1.0013789855722435, 1.0021106629290026, 1.0028400370459774, 1.003566408090059, 1.0042890806202942, 1.0050073642274564, 1.0057205741633892, 1.0064280319597105, 1.0071290660354781, 1.0078230122934553, 1.00850921470463, 1.0091870258806814, 1.0098558076340953, 1.0105149315256625, 1.0111637793991204, 1.0118017439027052, 1.01242822899742, 1.013042650451832, 1.0136444363232313, 1.01423302742501, 1.0148078777801264, 1.0153684550605406, 1.0159142410125217, 1.0164447318677412, 1.016959438740072, 1.0174578880080427, 1.0179396216828833, 1.0184041977621288, 1.0188511905687445, 1.0192801910757525, 1.0196908072163346, 1.0200826641794136, 1.020455404690694, 1.0208086892791748, 1.0211421965291307, 1.0214556233175747, 1.0217486850372106, 1.0220211158048909, 1.0222726686555959, 1.0225031157219457, 1.0227122483992725, 1.0228998774962592, 1.0230658333711717, 1.023209966053699, 1.023332145352411, 1.0234322609478628, 1.0235102224713433, 1.023565959569297, 1.02359942195341], [1.0173647517777304, 1.0173564954743755, 1.0173317341499462, 1.0172904905554678, 1.0172328025897117, 1.017158723269789, 1.017068320689991, 1.0169616779688802, 1.0168388931846362, 1.0167000792986738, 1.016545364067539, 1.0163748899431002, 1.0161888139610515, 1.0159873076177475, 1.015770556735388, 1.015538761315587, 1.0152921353813442, 1.0150309068074592, 1.0147553171394212, 1.014465621400816, 1.014162087889295, 1.0138449979611552, 1.0135146458045914, 1.013171338201673, 1.0128153942791203, 1.0124471452479518, 1.012066934132081, 1.0116751154859562, 1.0112720551013352, 1.0108581297033035, 1.0104337266356442, 1.0099992435356895, 1.0095550879987798, 1.0091016772324792, 1.0086394377006955, 1.0081688047578758, 1.0076902222734487, 1.0072041422467057, 1.0067110244123236, 1.0062113358367393, 1.005705550505608, 1.0051941489025893, 1.0046776175797105, 1.0041564487195869, 1.00363113968978, 1.003102192589597, 1.0025701137896523, 1.0020354134645162, 1.0014986051188126, 1.000960205107121, 1.0004207321480716, 0.9998807068330302, 0.9993406511297908, 0.9988010878817045, 0.9982625403027001, 0.9977255314686537, 0.9971905838055966, 0.9966582185752534, 0.9961289553584273, 0.9956033115367591, 0.9950818017734036, 0.9945649374931813, 0.9940532263627782, 0.9935471717715738, 0.9930472723137007, 0.9925540212719365, 0.9920679061040529, 0.9915894079322494, 0.9911190010363042, 0.9906571523510945, 0.9902043209691316, 0.9897609576487688, 0.9893275043287452, 0.9889043936497228, 0.9884920484834875, 0.9880908814704717, 0.9877012945662653, 0.9873236785977707, 0.9869584128296569, 0.9866058645417621, 0.9862663886180799, 0.985940327147962, 0.9856280090401549, 0.9853297496502765, 0.9850458504223198, 0.9847765985447635, 0.9845222666218408, 0.9842831123605058, 0.9840593782736103, 0.9838512913997903, 0.9836590630405208, 0.9834828885147919, 0.9833229469318178, 0.9831794009821646, 0.9830523967476625, 0.9829420635304229, 0.9828485137012608, 0.9827718425677879, 0.9827121282624022, 0.9826694316503732, 0.9826437962581871, 0.9826352482222696, 0.982643796258187, 0.9826694316503732, 0.9827121282624022, 0.982771842567788, 0.9828485137012609, 0.9829420635304229, 0.9830523967476626, 0.9831794009821649, 0.983322946931818, 0.983482888514792, 0.983659063040521, 0.9838512913997906, 0.9840593782736107, 0.9842831123605059, 0.9845222666218413, 0.9847765985447638, 0.9850458504223201, 0.9853297496502768, 0.9856280090401552, 0.9859403271479623, 0.9862663886180802, 0.9866058645417625, 0.9869584128296572, 0.9873236785977709, 0.9877012945662658, 0.9880908814704722, 0.988492048483488, 0.9889043936497232, 0.9893275043287455, 0.9897609576487694, 0.990204320969132, 0.990657152351095, 0.9911190010363046, 0.9915894079322498, 0.9920679061040535, 0.9925540212719367, 0.9930472723137014, 0.9935471717715745, 0.9940532263627786, 0.9945649374931818, 0.9950818017734041, 0.9956033115367597, 0.996128955358428, 0.996658218575254, 0.997190583805597, 0.9977255314686542, 0.9982625403027007, 0.9988010878817052, 0.9993406511297913, 0.9998807068330309, 1.000420732148072, 1.0009602051071216, 1.0014986051188133, 1.0020354134645166, 1.0025701137896528, 1.0031021925895978, 1.0036311396897803, 1.0041564487195873, 1.004677617579711, 1.0051941489025897, 1.0057055505056087, 1.00621133583674, 1.0067110244123243, 1.0072041422467064, 1.0076902222734492, 1.0081688047578763, 1.008639437700696, 1.0091016772324797, 1.0095550879987802, 1.00999924353569, 1.0104337266356447, 1.010858129703304, 1.0112720551013357, 1.0116751154859565, 1.0120669341320816, 1.0124471452479522, 1.012815394279121, 1.0131713382016732, 1.0135146458045916, 1.0138449979611552, 1.0141620878892952, 1.0144656214008165, 1.0147553171394215, 1.0150309068074594, 1.0152921353813444, 1.0155387613155873, 1.0157705567353883, 1.015987307617748, 1.0161888139610518, 1.0163748899431004, 1.0165453640675393, 1.016700079298674, 1.0168388931846364, 1.0169616779688804, 1.0170683206899913, 1.017158723269789, 1.0172328025897117, 1.0172904905554678, 1.0173317341499462, 1.0173564954743757], [1.0120695602592384, 1.0120637916076622, 1.0120464910365554, 1.012017674692304, 1.0119773694706233, 1.0119256129941692, 1.0118624535812126, 1.0117879502053786, 1.0117021724464759, 1.0116052004324323, 1.0114971247723612, 1.0113780464807847, 1.0112480768930492, 1.0111073375719668, 1.010955960205718, 1.0107940864970697, 1.0106218680439474, 1.0104394662114207, 1.0102470519951567, 1.0100448058764053, 1.009832917668584, 1.0096115863555324, 1.0093810199215192, 1.0091414351730794, 1.0088930575527773, 1.0086361209449828, 1.0083708674737693, 1.008097547293036, 1.0078164183689697, 1.007527746254967, 1.007231803859143, 1.0069288712045619, 1.0066192351823293, 1.0063031892976986, 1.0059810334093406, 1.0056530734619509, 1.0053196212123559, 1.0049809939493068, 1.0046375142071446, 1.0042895094735327, 1.0039373118914634, 1.0035812579557564, 1.0032216882042606, 1.0028589469040015, 1.002493381732507, 1.002125343454564, 1.0017551855946614, 1.0013832641053853, 1.0010099370320453, 1.0006355641738116, 1.0002605067416575, 0.999885127013411, 0.999509787986221, 0.9991348530267588, 0.9987606855194823, 0.9983876485132955, 0.9980161043669458, 0.9976464143935087, 0.997278938504318, 0.9969140348527028, 0.9965520594779, 0.9961933659495255, 0.9958383050129745, 0.9954872242361481, 0.9951404676578908, 0.9947983754385349, 0.9944612835129555, 0.9941295232465324, 0.9938034210944248, 0.9934832982645678, 0.9931694703847925, 0.9928622471744806, 0.9925619321211596, 0.9922688221624443, 0.9919832073737276, 0.9917053706620231, 0.9914355874663571, 0.9911741254651026, 0.9909212442906449, 0.9906771952517612, 0.99044222106409, 0.9902165555890576, 0.9900004235816249, 0.9897940404472023, 0.9895976120080737, 0.9894113342796639, 0.9892353932569623, 0.9890699647114136, 0.988915213998567, 0.9887712958767624, 0.9886383543371231, 0.9885165224450976, 0.9884059221937921, 0.9883066643693057, 0.9882188484282723, 0.9881425623877919, 0.9880778827279142, 0.9880248743068268, 0.9879835902888693, 0.9879540720854882, 0.9879363493092181, 0.9879304397407617, 0.987936349309218, 0.9879540720854882, 0.9879835902888694, 0.988024874306827, 0.9880778827279142, 0.9881425623877919, 0.9882188484282725, 0.9883066643693059, 0.9884059221937922, 0.9885165224450978, 0.9886383543371232, 0.9887712958767625, 0.988915213998567, 0.9890699647114138, 0.9892353932569624, 0.9894113342796642, 0.989597612008074, 0.9897940404472024, 0.9900004235816254, 0.9902165555890579, 0.9904422210640902, 0.9906771952517615, 0.9909212442906452, 0.991174125465103, 0.9914355874663573, 0.9917053706620234, 0.9919832073737279, 0.9922688221624446, 0.9925619321211598, 0.9928622471744808, 0.9931694703847928, 0.9934832982645682, 0.9938034210944251, 0.9941295232465324, 0.9944612835129558, 0.9947983754385352, 0.9951404676578912, 0.9954872242361487, 0.9958383050129748, 0.9961933659495258, 0.9965520594779004, 0.996914034852703, 0.9972789385043186, 0.9976464143935091, 0.998016104366946, 0.998387648513296, 0.9987606855194827, 0.9991348530267592, 0.9995097879862214, 0.9998851270134115, 1.0002605067416577, 1.0006355641738118, 1.0010099370320458, 1.0013832641053857, 1.0017551855946618, 1.0021253434545645, 1.0024933817325075, 1.0028589469040017, 1.0032216882042608, 1.0035812579557568, 1.0039373118914636, 1.004289509473533, 1.004637514207145, 1.0049809939493073, 1.0053196212123559, 1.005653073461951, 1.0059810334093409, 1.006303189297699, 1.00661923518233, 1.006928871204562, 1.0072318038591435, 1.0075277462549672, 1.00781641836897, 1.008097547293036, 1.0083708674737697, 1.008636120944983, 1.0088930575527775, 1.0091414351730796, 1.0093810199215194, 1.0096115863555326, 1.0098329176685843, 1.0100448058764055, 1.0102470519951567, 1.0104394662114207, 1.0106218680439474, 1.01079408649707, 1.010955960205718, 1.0111073375719672, 1.0112480768930494, 1.0113780464807847, 1.0114971247723612, 1.0116052004324325, 1.011702172446476, 1.0117879502053788, 1.0118624535812129, 1.0119256129941692, 1.011977369470623, 1.0120176746923042, 1.0120464910365556, 1.0120637916076625], [1.0077301276367194, 1.0077264171130342, 1.007715289049741, 1.0076967539670425, 1.0076708293883272, 1.0076375398247492, 1.0075969167536565, 1.0075489985908768, 1.007493830656877, 1.0074314651368244, 1.0073619610345608, 1.0072853841205343, 1.0072018068737052, 1.0071113084174745, 1.0070139744496651, 1.0069098971666082, 1.0067991751813767, 1.0066819134362206, 1.0065582231092576, 1.0064282215154838, 1.0062920320021644, 1.006149783838674, 1.0060016121008601, 1.0058476575500073, 1.005688066506482, 1.0055229907181433, 1.0053525872236129, 1.005177018210495, 1.00499645086865, 1.00481105723862, 1.0046210140553193, 1.004426502587103, 1.0042277084703255, 1.0040248215395189, 1.0038180356533126, 1.0036075485162304, 1.0033935614964966, 1.0031762794399979, 1.0029559104805417, 1.0027326658465663, 1.002506759664454, 1.0022784087586114, 1.0020478324484798, 1.0018152523426422, 1.001580892130207, 1.0013449773696408, 1.0011077352752367, 1.000869394501405, 1.0006301849249755, 1.000390337425708, 1.0001500836652133, 0.999909655864482, 0.9996692865802358, 0.9994292084803051, 0.9991896541182512, 0.9989508557074499, 0.9987130448948555, 0.9984764525346697, 0.9982413084621411, 0.9980078412677242, 0.9977762780718258, 0.9975468443003751, 0.9973197634614478, 0.9970952569231822, 0.9968735436932222, 0.996654840199924, 0.9964393600755653, 0.9962273139417954, 0.99601890919756, 0.9958143498097415, 0.9956138361067508, 0.9954175645753001, 0.995225727660598, 0.9950385135701918, 0.9948561060816875, 0.9946786843545746, 0.9945064227463793, 0.9943394906333618, 0.9941780522359781, 0.9940222664493137, 0.9938722866787009, 0.9937282606807128, 0.9935903304097418, 0.993458631870343, 0.9933332949755331, 0.9932144434112198, 0.993102194506935, 0.9929966591130353, 0.9928979414845226, 0.9928061391716426, 0.9927213429173909, 0.9926436365620663, 0.9925730969549957, 0.9925097938735373, 0.9924537899494773, 0.9924051406029115, 0.9923638939836973, 0.992330090920557, 0.9923037648778954, 0.9922849419203928, 0.9922736406854145, 0.9922698723632805, 0.9922736406854146, 0.9922849419203928, 0.9923037648778955, 0.9923300909205569, 0.9923638939836974, 0.9924051406029116, 0.9924537899494775, 0.9925097938735373, 0.992573096954996, 0.9926436365620666, 0.9927213429173909, 0.9928061391716427, 0.9928979414845227, 0.9929966591130354, 0.9931021945069353, 0.9932144434112198, 0.9933332949755332, 0.9934586318703432, 0.9935903304097421, 0.993728260680713, 0.993872286678701, 0.9940222664493139, 0.9941780522359782, 0.9943394906333619, 0.9945064227463795, 0.9946786843545748, 0.9948561060816877, 0.995038513570192, 0.9952257276605981, 0.9954175645753002, 0.9956138361067508, 0.9958143498097417, 0.9960189091975602, 0.9962273139417955, 0.9964393600755658, 0.9966548401999242, 0.9968735436932226, 0.9970952569231825, 0.9973197634614479, 0.9975468443003752, 0.997776278071826, 0.9980078412677245, 0.9982413084621413, 0.9984764525346699, 0.9987130448948558, 0.9989508557074502, 0.9991896541182514, 0.9994292084803051, 0.9996692865802359, 0.9999096558644822, 1.0001500836652135, 1.0003903374257082, 1.0006301849249757, 1.0008693945014053, 1.0011077352752369, 1.0013449773696408, 1.0015808921302072, 1.0018152523426427, 1.00204783244848, 1.0022784087586116, 1.0025067596644541, 1.0027326658465667, 1.0029559104805421, 1.003176279439998, 1.0033935614964968, 1.0036075485162304, 1.0038180356533128, 1.004024821539519, 1.004227708470326, 1.0044265025871033, 1.0046210140553196, 1.00481105723862, 1.0049964508686502, 1.0051770182104953, 1.0053525872236133, 1.0055229907181436, 1.0056880665064822, 1.0058476575500075, 1.0060016121008601, 1.006149783838674, 1.0062920320021647, 1.0064282215154838, 1.0065582231092578, 1.0066819134362206, 1.006799175181377, 1.0069098971666082, 1.007013974449665, 1.0071113084174745, 1.0072018068737052, 1.0072853841205343, 1.0073619610345608, 1.0074314651368246, 1.0074938306568773, 1.0075489985908768, 1.007596916753657, 1.0076375398247492, 1.007670829388327, 1.0076967539670423, 1.0077152890497407, 1.0077264171130342], [1.0043506520309784, 1.0043485566575947, 1.0043422725383675, 1.0043318056742314, 1.0043171660606258, 1.0042983676783217, 1.00427542848059, 1.0042483703767193, 1.004217219211897, 1.00418200474347, 1.004142760613602, 1.004099524318346, 1.0040523371731633, 1.0040012442749078, 1.0039462944603073, 1.0038875402609773, 1.0038250378550007, 1.0037588470151053, 1.0036890310534932, 1.0036156567633479, 1.003538794357084, 1.0034585174013717, 1.003374902749, 1.0032880304676257, 1.0031979837654696, 1.0031048489140189, 1.0030087151677953, 1.0029096746812605, 1.0028078224229189, 1.0027032560866984, 1.0025960760006714, 1.0024863850332018, 1.0023742884965892, 1.0022598940482979, 1.0021433115898466, 1.0020246531634538, 1.0019040328465187, 1.0017815666440364, 1.0016573723790345, 1.0015315695811302, 1.0014042793733056, 1.0012756243569993, 1.0011457284956198, 1.0010147169965795, 1.000882716191964, 1.0007498534179378, 1.000616256892997, 1.0004820555951883, 1.0003473791383966, 1.0002123576478268, 1.0000771216347906, 0.9999418018709196, 0.9998065292619196, 0.9996714347209937, 0.9995366490420525, 0.9994023027728306, 0.9992685260880405, 0.9991354486626853, 0.9990031995456508, 0.9988719070337119, 0.9987416985460705, 0.9986127004995579, 0.9984850381846224, 0.9983588356422342, 0.9982342155418283, 0.9981112990604161, 0.997990205762987, 0.997871053484329, 0.9977539582123861, 0.9976390339732832, 0.9975263927181339, 0.9974161442117555, 0.9973083959234086, 0.9972032529196806, 0.9971008177596274, 0.997001190392287, 0.9969044680566802, 0.9968107451844036, 0.9967201133049248, 0.9966326609536857, 0.9965484735831118, 0.9964676334766319, 0.996390219665801, 0.9963163078506192, 0.9962459703231406, 0.9961792758944527, 0.9961162898251157, 0.9960570737591334, 0.9960016856615385, 0.9959501797596589, 0.9959026064881349, 0.9958590124377467, 0.9958194403081185, 0.9957839288643465, 0.9957525128976039, 0.9957252231897694, 0.9957020864821203, 0.995683125448123, 0.9956683586703593, 0.9956578006216074, 0.9956514616501074, 0.9956493479690216, 0.9956514616501075, 0.9956578006216076, 0.9956683586703593, 0.9956831254481231, 0.9957020864821202, 0.9957252231897695, 0.9957525128976039, 0.9957839288643465, 0.9958194403081185, 0.9958590124377467, 0.9959026064881349, 0.9959501797596592, 0.9960016856615386, 0.9960570737591334, 0.9961162898251158, 0.9961792758944528, 0.9962459703231406, 0.9963163078506193, 0.9963902196658012, 0.9964676334766323, 0.9965484735831119, 0.9966326609536857, 0.9967201133049249, 0.9968107451844037, 0.9969044680566802, 0.9970011903922871, 0.9971008177596276, 0.9972032529196807, 0.9973083959234086, 0.9974161442117555, 0.9975263927181339, 0.9976390339732832, 0.9977539582123862, 0.997871053484329, 0.9979902057629872, 0.9981112990604161, 0.9982342155418285, 0.9983588356422343, 0.9984850381846228, 0.998612700499558, 0.9987416985460708, 0.9988719070337119, 0.9990031995456509, 0.9991354486626853, 0.9992685260880408, 0.9994023027728307, 0.9995366490420529, 0.999671434720994, 0.9998065292619195, 0.9999418018709196, 1.0000771216347908, 1.0002123576478268, 1.0003473791383968, 1.0004820555951888, 1.0006162568929975, 1.0007498534179378, 1.0008827161919642, 1.0010147169965795, 1.0011457284956198, 1.0012756243569996, 1.0014042793733056, 1.0015315695811304, 1.0016573723790345, 1.0017815666440366, 1.001904032846519, 1.0020246531634538, 1.0021433115898468, 1.0022598940482979, 1.0023742884965894, 1.0024863850332018, 1.0025960760006714, 1.0027032560866984, 1.002807822422919, 1.0029096746812605, 1.0030087151677956, 1.003104848914019, 1.0031979837654696, 1.0032880304676255, 1.003374902749, 1.0034585174013717, 1.0035387943570842, 1.003615656763348, 1.003689031053493, 1.0037588470151053, 1.0038250378550004, 1.0038875402609773, 1.003946294460307, 1.0040012442749078, 1.0040523371731633, 1.004099524318346, 1.004142760613602, 1.00418200474347, 1.004217219211897, 1.0042483703767193, 1.0042754284805904, 1.004298367678322, 1.0043171660606258, 1.0043318056742312, 1.0043422725383675, 1.004348556657595], [1.0019344028664037, 1.001933468967583, 1.0019306681693885, 1.0019260031657715, 1.0019194784438221, 1.0019111002795276, 1.0019008767318403, 1.00188881763506, 1.0018749345895346, 1.0018592409506928, 1.001841751816413, 1.001822484012743, 1.0018014560779807, 1.001778688245132, 1.0017542024227613, 1.001728022174247, 1.0017001726954697, 1.0016706807909392, 1.0016395748483993, 1.0016068848119128, 1.0015726421534683, 1.0015368798431232, 1.0014996323177137, 1.0014609354481583, 1.0014208265053857, 1.0013793441249175, 1.0013365282701328, 1.0012924201942566, 1.0012470624010987, 1.0012004986045806, 1.0011527736870902, 1.001103933656697, 1.0010540256032705, 1.001003097653543, 1.0009511989251492, 1.0008983794796993, 1.000844690274914, 1.0007901831158754, 1.0007349106054348, 1.000678926093824, 1.0006222836275152, 1.0005650378973832, 1.0005072441862097, 1.000448958315584, 1.000390236592252, 1.000331135753957, 1.000271712914831, 1.0002120255103824, 1.0001521312421366, 1.0000920880219786, 1.0000319539162548, 0.9999717870896841, 0.9999116457491323, 0.9998515880873078, 0.9997916722264277, 0.9997319561619148, 0.9996724977061724, 0.9996133544325012, 0.9995545836192047, 0.9994962421939442, 0.9994383866783919, 0.9993810731332446, 0.9993243571036435, 0.999268293565062, 0.9992129368697101, 0.9991583406935113, 0.9991045579837032, 0.9990516409071182, 0.9989996407991901, 0.9989486081137434, 0.9988985923736138, 0.998849642122149, 0.9988018048756411, 0.9987551270767371, 0.9987096540488768, 0.9986654299518016, 0.9986224977381839, 0.9985808991114186, 0.9985406744846197, 0.9985018629408677, 0.9984645021947451, 0.9984286285552011, 0.998394276889784, 0.9983614805902806, 0.9983302715397923, 0.9983006800812897, 0.9982727349876735, 0.998246463433373, 0.9982218909675151, 0.9981990414886887, 0.9981779372213335, 0.9981585986937743, 0.9981410447179299, 0.9981252923707098, 0.9981113569771265, 0.9980992520951354, 0.9980889895022217, 0.9980805791837445, 0.9980740293230564, 0.9980693462934033, 0.9980665346516153, 0.9980655971335964, 0.9980665346516154, 0.9980693462934034, 0.9980740293230563, 0.9980805791837444, 0.9980889895022217, 0.9980992520951355, 0.9981113569771266, 0.9981252923707098, 0.9981410447179299, 0.9981585986937743, 0.9981779372213333, 0.9981990414886887, 0.9982218909675151, 0.9982464634333732, 0.9982727349876735, 0.9983006800812899, 0.9983302715397921, 0.9983614805902804, 0.9983942768897841, 0.9984286285552011, 0.9984645021947454, 0.9985018629408677, 0.9985406744846196, 0.9985808991114185, 0.9986224977381839, 0.9986654299518016, 0.9987096540488768, 0.9987551270767373, 0.998801804875641, 0.9988496421221491, 0.9988985923736139, 0.9989486081137435, 0.99899964079919, 0.9990516409071182, 0.9991045579837032, 0.9991583406935113, 0.9992129368697104, 0.9992682935650621, 0.9993243571036436, 0.9993810731332448, 0.9994383866783921, 0.9994962421939443, 0.9995545836192048, 0.9996133544325012, 0.9996724977061724, 0.9997319561619148, 0.9997916722264281, 0.9998515880873078, 0.9999116457491324, 0.9999717870896841, 1.000031953916255, 1.0000920880219786, 1.0001521312421364, 1.0002120255103826, 1.000271712914831, 1.000331135753957, 1.0003902365922521, 1.000448958315584, 1.0005072441862095, 1.0005650378973834, 1.0006222836275154, 1.0006789260938238, 1.0007349106054348, 1.0007901831158754, 1.000844690274914, 1.000898379479699, 1.0009511989251494, 1.001003097653543, 1.0010540256032707, 1.001103933656697, 1.0011527736870902, 1.0012004986045806, 1.0012470624010987, 1.0012924201942566, 1.0013365282701328, 1.0013793441249175, 1.0014208265053859, 1.001460935448158, 1.0014996323177134, 1.001536879843123, 1.0015726421534683, 1.0016068848119128, 1.0016395748483993, 1.0016706807909392, 1.0017001726954695, 1.0017280221742473, 1.0017542024227613, 1.001778688245132, 1.0018014560779804, 1.001822484012743, 1.0018417518164133, 1.0018592409506928, 1.0018749345895346, 1.00188881763506, 1.0019008767318405, 1.0019111002795273, 1.001919478443822, 1.0019260031657715, 1.0019306681693887, 1.0019334689675834], [1.0004837177080108, 1.0004834838382894, 1.000482782455051, 1.0004816142358564, 1.0004799803092497, 1.000477882253672, 1.0004753220959437, 1.0004723023093158, 1.000468825811089, 1.0004648959598093, 1.0004605165520353, 1.000455691818687, 1.000450426420976, 1.0004447254459188, 1.0004385944014438, 1.0004320392110904, 1.00042506620831, 1.000417682130369, 1.000409894111865, 1.0004017096778606, 1.0003931367366377, 1.0003841835720846, 1.0003748588357209, 1.0003651715383655, 1.0003551310414596, 1.0003447470480498, 1.0003340295934415, 1.0003229890355325, 1.000311636044831, 1.0002999815941747, 1.0002880369481553, 1.0002758136522605, 1.0002633235217444, 1.0002505786302356, 1.0002375912980934, 1.0002243740805268, 1.0002109397554828, 1.00019730131132, 1.0001834719342744, 1.0001694649957351, 1.000155294039337, 1.0001409727678874, 1.0001265150301335, 1.0001119348073897, 1.000097246200033, 1.000082463413881, 1.0000676007464662, 1.0000526725732204, 1.0000376933335768, 1.0000226775170145, 1.000007639649046, 0.9999925942771707, 0.999977555956804, 0.999962539237196, 0.9999475586473529, 0.999932628681977, 0.9999177637874355, 0.9999029783477758, 0.9998882866707968, 0.9998737029741916, 0.9998592413717773, 0.9998449158598193, 0.9998307403034712, 0.9998167284233359, 0.9998028937821669, 0.9997892497717188, 0.9997758095997625, 0.9997625862772773, 0.999749592605829, 0.9997368411651515, 0.9997243443009429, 0.9997121141128821, 0.9997001624428877, 0.9996885008636218, 0.9996771406672557, 0.9996660928545038, 0.9996553681239428, 0.9996449768616189, 0.9996349291309596, 0.9996252346629979, 0.9996159028469165, 0.9996069427209242, 0.9995983629634732, 0.9995901718848226, 0.9995823774189612, 0.9995749871158943, 0.9995680081343047, 0.999561447234589, 0.9995553107722867, 0.999549604691898, 0.9995443345211028, 0.9995395053653842, 0.9995351219030625, 0.9995311883807442, 0.9995277086091906, 0.9995246859596113, 0.9995221233603837, 0.9995200232942038, 0.9995183877956709, 0.9995172184493079, 0.9995165163880192, 0.9995162822919892, 0.9995165163880191, 0.9995172184493077, 0.9995183877956707, 0.9995200232942036, 0.9995221233603837, 0.9995246859596115, 0.9995277086091905, 0.9995311883807443, 0.9995351219030625, 0.9995395053653842, 0.9995443345211029, 0.9995496046918979, 0.9995553107722868, 0.9995614472345891, 0.9995680081343047, 0.9995749871158945, 0.999582377418961, 0.9995901718848225, 0.9995983629634733, 0.9996069427209245, 0.9996159028469165, 0.9996252346629978, 0.9996349291309596, 0.9996449768616189, 0.9996553681239428, 0.9996660928545039, 0.9996771406672557, 0.9996885008636218, 0.9997001624428876, 0.9997121141128822, 0.999724344300943, 0.9997368411651518, 0.9997495926058289, 0.9997625862772771, 0.9997758095997625, 0.9997892497717186, 0.9998028937821668, 0.9998167284233359, 0.9998307403034713, 0.9998449158598195, 0.9998592413717773, 0.9998737029741916, 0.9998882866707969, 0.9999029783477761, 0.9999177637874355, 0.9999326286819769, 0.9999475586473532, 0.999962539237196, 0.9999775559568042, 0.9999925942771707, 1.0000076396490458, 1.0000226775170145, 1.0000376933335768, 1.0000526725732204, 1.0000676007464664, 1.0000824634138807, 1.0000972462000328, 1.0001119348073897, 1.0001265150301335, 1.0001409727678876, 1.0001552940393372, 1.000169464995735, 1.0001834719342744, 1.0001973013113201, 1.0002109397554828, 1.0002243740805266, 1.0002375912980934, 1.0002505786302356, 1.0002633235217446, 1.0002758136522605, 1.000288036948155, 1.0002999815941747, 1.000311636044831, 1.0003229890355325, 1.0003340295934418, 1.0003447470480498, 1.0003551310414596, 1.0003651715383655, 1.0003748588357209, 1.0003841835720844, 1.0003931367366377, 1.0004017096778606, 1.000409894111865, 1.0004176821303687, 1.00042506620831, 1.0004320392110906, 1.0004385944014436, 1.0004447254459188, 1.0004504264209757, 1.000455691818687, 1.000460516552035, 1.0004648959598093, 1.000468825811089, 1.0004723023093158, 1.000475322095944, 1.000477882253672, 1.0004799803092497, 1.0004816142358561, 1.000482782455051, 1.0004834838382894]]}],                        {\"autosize\": false, \"height\": 500, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"showbackground\": false, \"title\": {\"text\": \"kx\"}}, \"yaxis\": {\"showbackground\": false, \"title\": {\"text\": \"ky\"}}, \"zaxis\": {\"showbackground\": false, \"title\": {\"text\": \"E [t]\"}}}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"width\": 800},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('30bb0bb8-b77f-4805-9683-d11d56288ffb');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig = go.Figure( data=DATA )\n",
    "\n",
    "fig.update_layout( autosize=False,\n",
    "                   width = 800, height = 500,\n",
    "                   margin= dict(l=65, r=50, b=65, t=90),\n",
    "                   scene = dict(xaxis_title=\"kx\", \n",
    "                                yaxis_title=\"ky\", \n",
    "                                zaxis_title=\"E [t]\", \n",
    "                                xaxis = dict(showbackground=False), \n",
    "                                yaxis = dict(showbackground=False),\n",
    "                                zaxis = dict(showbackground=False)))\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "source": [
    "En esta figura se presenta una realcion de dispersion propia de un semimetal de Weyl tipo I. Dicha relación se caracteriza porque la banda de conducción y valencia son simetricas al plano $K_x, K_y$"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "![Semimetal de Weyl Tipo I](WSM_MM_1.png)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.10"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
